(************** Content-type: application/mathematica **************
                     CreatedBy='Mathematica 5.0'

                    Mathematica-Compatible Notebook

This notebook can be used with any Mathematica-compatible
application, such as Mathematica, MathReader or Publicon. The data
for the notebook starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do
one of the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the
  application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing
the word CacheID, otherwise Mathematica-compatible applications may
try to use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
*******************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[   6189235,     145897]*)
(*NotebookOutlinePosition[   6189954,     145922]*)
(*  CellTagsIndexPosition[   6189910,     145918]*)
(*WindowFrame->Normal*)



Notebook[{
Cell["Detailed mixture-model example", "Title"],

Cell["\<\
This notebook assumes that the definitions in \
\"statistical_modeling.nb\" have already been evaluated. \
\>", "Text"],

Cell[CellGroupData[{

Cell["Local definitions", "Section"],

Cell[CellGroupData[{

Cell["Plot two Gaussians in different colors", "Subsection"],

Cell[BoxData[
    \(\(PlotMeansTwo[{\[Mu]_, \[CapitalSigma]_, priors_}, \ pr_, \ colors_, \ 
          opt___] := \[IndentingNewLine]Module[{lp, s, x, y, xmin, xmax, 
            ymin, ymax, g1, 
            g2}, \[IndentingNewLine]{xmin, xmax, ymin, ymax} = 
            Flatten[pr]; \[IndentingNewLine]s\  = \ \ convertSigma[{\[Mu], \
\[CapitalSigma]}]; \[IndentingNewLine]g1 = 
            Table[\[IndentingNewLine]lp\  = 
                logpdf[\[Mu][\([i]\)], s[\([i]\)], x, y]; 
              ImplicitPlot[
                lp\  \[Equal] \ \((lp\  /. \ {x \[Rule] \[Mu][\([i, 1]\)], 
                          y \[Rule] \[Mu][\([i, 2]\)]})\) - 0.5, \ {x, xmin, 
                  xmax}, {y, ymin, ymax}, nS, \ 
                PlotStyle \[Rule] {Thickness[ .005], colors[\([i]\)]}, \ 
                PlotRange \[Rule] \ All, \ Axes \[Rule] False], {i, 1, 
                Length[\[Mu]]}]; \[IndentingNewLine]g2\  = \ 
            Show[Graphics[{PointSize[ .03], {colors[\([1]\)], 
                    Point[\[Mu][\([1]\)]]}, {colors[\([2]\)], 
                    Point[\[Mu][\([2]\)]]}}], nS]; \[IndentingNewLine]{xmin, 
              xmax, ymin, ymax} = 
            Flatten[pr] + {\(- .01\),  .01, \(- .01\),  .01}; \
\[IndentingNewLine]Show[g1, g2, \ 
            PlotRange \[Rule] {{xmin, xmax}, {ymin, ymax}}, 
            Frame \[Rule] True, AspectRatio \[Rule] Automatic, 
            opt]\[IndentingNewLine]];\)\)], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  "Plot ",
  Cell[BoxData[
      \(TraditionalForm\`P(\[Omega]\_i | \[Theta], x\_j)\)]],
  " for sample point"
}], "Subsection"],

Cell[BoxData[
    \( (*\ Note : \ fix\ global\ pr\ reliance\ *) \)], "Input"],

Cell[BoxData[
    \(\(PlotExampleOne[x_, model_, colors_, gbase_, \ flag_:  0, 
          opts___] := \[IndentingNewLine]Module[{Ps, g1, g2, 
            gs}, \[IndentingNewLine]Ps = 
            ClassProbabilitiesDataSet[{x}, model]\  // \ 
              Flatten; \[IndentingNewLine]g1 = 
            Graphics[{{colors[\([1]\)], 
                  Rectangle[{0.60, \(-1\)}, {0.75, \(-1\) + 
                        Ps[\([1]\)]/2. }]}, {colors[\([2]\)], 
                  Rectangle[{0.80, \(-1\)}, {0.95, \(-1\) + 
                        Ps[\([2]\)]/2. }]}}]; \[IndentingNewLine]g2\  = \ 
            Graphics[{Magenta, PointSize[ .04], 
                Point[x]}]; \[IndentingNewLine]If[flag\  \[Equal] \ 0, 
            gs = {gbase, g2}, gs = {gbase, g1, g2}]; \[IndentingNewLine]Show[
            gs, PlotRange \[Rule] 
              pr + {{\(- .01\),  .01}, {\(- .01\),  .01}}, 
            Frame \[Rule] True, FrameTicks \[Rule] None, 
            AspectRatio \[Rule] Automatic, 
            opts]\[IndentingNewLine]];\)\)], "Input"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["Generate some sample data from two Gaussians", "Section"],

Cell[CellGroupData[{

Cell["Data definition", "Subsection"],

Cell[CellGroupData[{

Cell["Gaussian #1", "Subsubsection"],

Cell[BoxData[{
    \(\(\[Mu]1\  = \ { .3,  .3};\)\), "\n", 
    \(\(\[CapitalSigma]1\  = \  .07 {{1. , \(- .5\)}, {\(- .5\),  .5}};\)\), \
"\n", 
    \(\(n1\  = \ 35;\)\)}], "Input",
  CellFrame->True,
  Background->GrayLevel[0.849989]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Gaussian #2", "Subsubsection"],

Cell[BoxData[{
    \(\(\[Mu]2\  = \ {\(- .5\), \(- .5\)};\)\), "\n", 
    \(\(\[CapitalSigma]2\  = \  .04 {{1. ,  .5}, { .5,  .5}};\)\), "\n", 
    \(\(n2\  = \ 25;\)\)}], "Input",
  CellFrame->True,
  Background->GrayLevel[0.849989]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Data domain", "Subsubsection"],

Cell[BoxData[
    \(\(pr\  = \ {{\(-1\), 1}, {\(-1\), 1}};\)\)], "Input"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["Data generation", "Subsection"],

Cell[BoxData[{
    \(\(data1\  = \ 
        Table[rgBounded[{\[Mu]1, \ \[CapitalSigma]1}, 
            pr], {n1}];\)\), "\[IndentingNewLine]", 
    \(\(\(data2\  = \ 
        Table[rgBounded[{\[Mu]2, \ \[CapitalSigma]2}, 
            pr], {n2}];\)\(\[IndentingNewLine]\)
    \)\), "\n", 
    \(\(xd = data1~Join~data2\  // \ Sort;\)\)}], "Input"]
}, Closed]],

Cell[CellGroupData[{

Cell["Data plotting", "Subsection"],

Cell[CellGroupData[{

Cell["Default colors", "Subsubsection"],

Cell[BoxData[{
    \(\(colors\  = \ {Red, Blue};\)\), "\[IndentingNewLine]", 
    \(\(dataStyle\  = \ {Orange, \ PointSize[ .015]};\)\)}], "Input"]
}, Closed]],

Cell[CellGroupData[{

Cell["Visualize data", "Subsubsection"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(gdata\  = \ 
        PlotData2D[xd, pr, dataStyle, \ 
          FrameTicks \[Rule] None];\)\)], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.49505 0.5 0.49505 [
[ 0 0 -0.125 0 ]
[ 0 0 -0.125 0 ]
[ 0 1 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
0 0 m
1 0 L
s
0 0 m
0 1 L
s
0 1 m
1 1 L
s
1 0 m
1 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
1 .5 0 r
.015 w
.03175 .1355 Mdot
.03435 .12523 Mdot
.11137 .12765 Mdot
.14107 .18841 Mdot
.16218 .24538 Mdot
.17294 .21053 Mdot
.18267 .18577 Mdot
.18434 .1304 Mdot
.18553 .30956 Mdot
.20401 .239 Mdot
.21247 .27571 Mdot
.21687 .20845 Mdot
.22376 .2799 Mdot
.22832 .27485 Mdot
.29063 .20974 Mdot
.29686 .25079 Mdot
.30487 .22936 Mdot
.30683 .34623 Mdot
.32055 .20902 Mdot
.32574 .21979 Mdot
.34472 .28521 Mdot
.35998 .36393 Mdot
.36335 .24976 Mdot
.3794 .36608 Mdot
.42386 .66992 Mdot
.44391 .74519 Mdot
.45059 .34198 Mdot
.47208 .67586 Mdot
.47436 .71381 Mdot
.49778 .59825 Mdot
.50874 .91643 Mdot
.51516 .76219 Mdot
.53655 .61374 Mdot
.56563 .75219 Mdot
.59189 .65665 Mdot
.59581 .61604 Mdot
.59923 .6556 Mdot
.60292 .68499 Mdot
.62656 .67779 Mdot
.63555 .72451 Mdot
.63919 .652 Mdot
.64169 .6004 Mdot
.64246 .58611 Mdot
.64496 .54267 Mdot
.64608 .77288 Mdot
.65077 .64308 Mdot
.66065 .57816 Mdot
.67474 .59169 Mdot
.69296 .563 Mdot
.72815 .65902 Mdot
.73169 .58879 Mdot
.74669 .61318 Mdot
.74821 .65474 Mdot
.75963 .63781 Mdot
.79673 .57809 Mdot
.80925 .55852 Mdot
.81525 .58444 Mdot
.83417 .62985 Mdot
.83598 .55526 Mdot
.91595 .49319 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P000182000`400?l00000o`00003ooooooolQ
ooooo`00o`00000P0000007ooooo00000`00003oooooooooo`3ooooooacooooo0@000001ooooo`00
00<00000ooooooooool0oooooolLooooo`4000000Oooool0000300000?oooooooooo0?oooooo7?oo
ool10000007ooooo00000`00003oooooooooo`3ooooooacooooo0@000001ooooo`0000<00000oooo
ooooool0oooooolLooooo`4000000Oooool0000300000?oooooooooo0?oooooo7?ooool10000007o
oooo00000`00003oooooooooo`3ooooooacooooo0@000001ooooo`0000<00000ooooooooool0oooo
oolLooooo`4000000Oooool0000300000?oooooooooo0?oooooo7?ooool10000007ooooo00000`00
003oooooooooo`3ooooooacooooo0@000001ooooo`0000<00000ooooooooool0oooooolLooooo`40
00000Oooool0000300000?oooooooooo0?oooooo7?ooool10000007ooooo00000`00003ooooooooo
o`3ooooooacooooo0@000001ooooo`0000<00000ooooooooool0oooooolLooooo`4000000Oooool0
000300000?oooooooooo0?oooooo7?ooool10000007ooooo00000`00003oooooooooo`3ooooooaco
oooo0@000001ooooo`0000<00000ooooooooool0oooooolLooooo`4000000Oooool0000300000?oo
oooooooo0?oooooo7?ooool10000007ooooo00000`00003oooooooooo`3ooooooacooooo0@000001
ooooo`0000<00000ooooooooool0oooooolLooooo`4000000Oooool0000300000?oooooooooo0?oo
oooo7?ooool10000007ooooo00000`00003oooooooooo`3ooooooacooooo0@000001ooooo`0000<0
0000ooooooooool0oooooolLooooo`4000000Oooool0000300000?oooooooooo0?oooooo7?ooool1
0000007ooooo00000`00003oooooooooo`3ooooooacooooo0@000001ooooo`0000<00000oooooooo
ool0oooooolLooooo`4000000Oooool0000300000?oooooooooo0?oooooo7?ooool10000007ooooo
00000`00003oooooooooo`3ooooooacooooo0@000001ooooo`0000<00000ooooooooool0oooooolL
ooooo`4000000Oooool0000300000?oooooooooo0?oooooo7?ooool10000007ooooo00000`00003o
ooooooooo`3ooooooacooooo0@000001ooooo`0000<00000ooooooooool0oooooolLooooo`400000
0Oooool0000300000?oooooooooo0?oooooo7?ooool10000007ooooo00000`00003oooooooooo`06
ooooo`;oogl0oooooolDooooo`4000000Oooool0000300000?oooooooooo00Gooooo1?ooO`0Coooo
o`;oogl0oOooool10000007ooooo00000`00003oooooooooo`05ooooo`Coogl04_ooool4oomo01;o
oooo0_ooO`3Xooooo`4000000Oooool0000300000?oooooooooo00Gooooo0oooO`0Cooooo`Coogl0
4Oooool4oomo0>Oooooo0@000001ooooo`0000<00000ooooooooool01?ooool4oomo01Cooooo0_oo
O`0Booooo`Coogl0ioooool10000007ooooo00000`00003oooooooooo`04ooooo`Coogl0:Oooool2
oomo0>Sooooo0@000001ooooo`0000<00000ooooooooool01Oooool2oomo0?oooooo5Oooool10000
007ooooo00000`00003oooooooooo`3ooooooacooooo0@000001ooooo`0000<00000ooooooooool0
oooooolLooooo`4000000Oooool0000300000?oooooooooo0?oooooo7?ooool10000007ooooo0000
0`00003oooooooooo`3ooooooacooooo0@000001ooooo`0000<00000ooooooooool0oooooolLoooo
o`4000000Oooool0000300000?oooooooooo0?oooooo7?ooool10000007ooooo00000`00003ooooo
ooooo`3ooooooacooooo0@000001ooooo`0000<00000ooooooooool0oooooolLooooo`4000000Ooo
ool0000300000?oooooooooo0?oooooo7?ooool10000007ooooo00000`00003oooooooooo`3ooooo
oacooooo0@000001ooooo`0000<00000ooooooooool0oooooolLooooo`4000000Oooool000030000
0?oooooooooo02Cooooo0_ooO`0:ooooo`;oogl0jOooool10000007ooooo00000`00003ooooooooo
o`0Sooooo`Coogl02?ooool4oomo0>Sooooo0@000001ooooo`0000<00000ooooooooool08oooool4
oomo00Sooooo1?ooO`3Xooooo`4000000Oooool0000300000?oooooooooo02Cooooo0_ooO`0:oooo
o`;oogl0jOooool10000007ooooo00000`00003oooooooooo`3ooooooacooooo0@000001ooooo`00
00<00000ooooooooool0oooooolLooooo`4000000Oooool0000300000?oooooooooo03[ooooo0_oo
O`0Cooooo`;oogl01oooool2oomo0<7ooooo0@000001ooooo`0000<00000ooooooooool0;_ooool2
oomo00Wooooo1?ooO`0Aooooo`Coogl01Oooool4oomo0<3ooooo0@000001ooooo`0000<00000oooo
ooooool0;Oooool4oomo00Sooooo1?ooO`0Aooooo`Coogl01Oooool4oomo0<3ooooo0@000001oooo
o`0000<00000ooooooooool0;Oooool4oomo00Wooooo0_ooO`0Cooooo`;oogl01oooool3oomo0<3o
oooo0@000001ooooo`0000<00000ooooooooool0;_ooool2oomo02Sooooo1?ooO`2oooooo`400000
0Oooool0000300000?oooooooooo05Sooooo1?ooO`2oooooo`4000000Oooool0000300000?oooooo
oooo05?ooooo0_ooO`04ooooo`;oogl0`?ooool10000007ooooo00000`00003oooooooooo`1Boooo
o`Coogl0aOooool10000007ooooo00000`00003oooooooooo`1Booooo`Coogl0aOooool10000007o
oooo00000`00003oooooooooo`0gooooo`;oogl06_ooool2oomo0<Kooooo0@000001ooooo`0000<0
0000ooooooooool0=_ooool4oomo0>7ooooo0@000001ooooo`0000<00000ooooooooool0:oooool2
oomo00Wooooo1?ooO`3Qooooo`4000000Oooool0000300000?oooooooooo02[ooooo1?ooO`09oooo
o`;oogl06?ooool2oomo017ooooo0_ooO`2eooooo`4000000Oooool0000300000?oooooooooo02[o
oooo1?ooO`0Rooooo`Coogl03oooool4oomo0;Cooooo0@000001ooooo`0000<00000ooooooooool0
:oooool2oomo02?ooooo1?ooO`0?ooooo`Coogl0]?ooool10000007ooooo00000`00003ooooooooo
o`1Aooooo`;oogl04Oooool2oomo0;Gooooo0@000001ooooo`0000<00000ooooooooool0oooooolL
ooooo`4000000Oooool0000300000?oooooooooo0?oooooo7?ooool10000007ooooo00000`00003o
ooooooooo`3ooooooacooooo0@000001ooooo`0000<00000ooooooooool0>Oooool2oomo00;ooooo
0_ooO`3Looooo`4000000Oooool0000300000?oooooooooo03Sooooo2?ooO`3Kooooo`4000000Ooo
ool0000300000?oooooooooo03Sooooo2?ooO`3Kooooo`4000000Oooool0000300000?oooooooooo
03Wooooo1_ooO`0Pooooo`;oogl0^_ooool10000007ooooo00000`00003oooooooooo`0kooooo`Co
ogl07oooool4oomo0;Wooooo0@000001ooooo`0000<00000ooooooooool0??ooool2oomo023ooooo
1?ooO`2iooooo`4000000Oooool0000300000?oooooooooo05oooooo0_ooO`2jooooo`4000000Ooo
ool0000300000?oooooooooo0?oooooo7?ooool10000007ooooo00000`00003oooooooooo`3ooooo
oacooooo0@000001ooooo`0000<00000ooooooooool0oooooolLooooo`4000000Oooool000030000
0?oooooooooo037ooooo0_ooO`3Xooooo`4000000Oooool0000300000?oooooooooo033ooooo1?oo
O`3Wooooo`4000000Oooool0000300000?oooooooooo033ooooo1?ooO`3Wooooo`4000000Oooool0
000300000?oooooooooo037ooooo0_ooO`3Xooooo`4000000Oooool0000300000?oooooooooo0?oo
oooo7?ooool10000007ooooo00000`00003oooooooooo`3ooooooacooooo0@000001ooooo`0000<0
0000ooooooooool0oooooolLooooo`4000000Oooool0000300000?oooooooooo0?oooooo7?ooool1
0000007ooooo00000`00003oooooooooo`3ooooooacooooo0@000001ooooo`0000<00000oooooooo
ool0OOooool2oomo09cooooo0@000001ooooo`0000<00000ooooooooool0O?ooool4oomo09_ooooo
0@000001ooooo`0000<00000ooooooooool0E?ooool2oomo02Kooooo1?ooO`2Kooooo`4000000Ooo
ool0000300000?oooooooooo05?ooooo1?ooO`0Vooooo`;oogl0W?ooool10000007ooooo00000`00
003oooooooooo`1Cooooo`Coogl0a?ooool10000007ooooo00000`00003oooooooooo`1Dooooo`;o
ogl0aOooool10000007ooooo00000`00003oooooooooo`3ooooooacooooo0@000001ooooo`0000<0
0000ooooooooool0Hoooool2oomo00Cooooo0_ooO`2`ooooo`4000000Oooool0000300000?oooooo
oooo06;ooooo1?ooO`02ooooo`Coogl0[oooool10000007ooooo00000`00003oooooooooo`1Roooo
o`Coogl00_ooool4oomo0:oooooo0@000001ooooo`0000<00000ooooooooool0Hoooool2oomo00Co
oooo0_ooO`2`ooooo`4000000Oooool0000300000?oooooooooo0?oooooo7?ooool10000007ooooo
00000`00003oooooooooo`3ooooooacooooo0@000001ooooo`0000<00000ooooooooool0oooooolL
ooooo`4000000Oooool0000300000?oooooooooo0?oooooo7?ooool10000007ooooo00000`00003o
ooooooooo`3ooooooacooooo0@000001ooooo`0000<00000ooooooooool0oooooolLooooo`400000
0Oooool0000300000?oooooooooo0?oooooo7?ooool10000007ooooo00000`00003oooooooooo`3o
oooooacooooo0@000001ooooo`0000<00000ooooooooool0oooooolLooooo`4000000Oooool00003
00000?oooooooooo0?oooooo7?ooool10000007ooooo00000`00003oooooooooo`3ooooooacooooo
0@000001ooooo`0000<00000ooooooooool0oooooolLooooo`4000000Oooool0000300000?oooooo
oooo0?oooooo7?ooool10000007ooooo00000`00003oooooooooo`3ooooooacooooo0@000001oooo
o`0000<00000ooooooooool0oooooolLooooo`4000000Oooool0000300000?oooooooooo0?oooooo
7?ooool10000007ooooo00000`00003oooooooooo`3ooooooacooooo0@000001ooooo`0000<00000
ooooooooool0oooooolLooooo`4000000Oooool0000300000?oooooooooo0?oooooo7?ooool10000
007ooooo00000`00003oooooooooo`3ooooooacooooo0@000001ooooo`0000<00000ooooooooool0
oooooolLooooo`4000000Oooool0000300000?oooooooooo0?oooooo7?ooool10000007ooooo0000
0`00003oooooooooo`3ooooooacooooo0@000001ooooo`0000<00000ooooooooool0oooooolLoooo
o`4000000Oooool0000300000?oooooooooo0?oooooo7?ooool10000007ooooo00000`00003ooooo
ooooo`3ooooooacooooo0@000001ooooo`0000<00000ooooooooool0oooooolLooooo`4000000Ooo
ool0000300000?oooooooooo0?oooooo7?ooool10000007ooooo00000`00003oooooooooo`3ooooo
oacooooo0@000001ooooo`0000<00000ooooooooool0oooooolLooooo`4000000Oooool000030000
0?oooooooooo0?oooooo7?ooool10000007ooooo00000`00003oooooooooo`3ooooooacooooo0@00
0001ooooo`0000<00000ooooooooool0oooooolLooooo`4000000Oooool0000300000?oooooooooo
0?oooooo1?ooool2oomo01Kooooo0@000001ooooo`0000<00000ooooooooool0ooooool3ooooo`Co
ogl05Oooool10000007ooooo00000`00003oooooooooo`3oooooo`?ooooo1?ooO`0Eooooo`400000
0Oooool0000300000?oooooooooo0?oooooo1?ooool2oomo01Kooooo0@000001ooooo`0000<00000
ooooooooool0oooooolLooooo`4000000Oooool0000300000?oooooooooo0?oooooo7?ooool10000
007ooooo00000`00003oooooooooo`3ooooooacooooo0@000001ooooo`0000<00000ooooooooool0
oooooolLooooo`4000000Oooool0000300000?oooooooooo0?oooooo7?ooool10000007ooooo0000
0`00003oooooooooo`3ooooooacooooo0@000001ooooo`0000<00000ooooooooool0oooooolLoooo
o`4000000Oooool0000300000?oooooooooo0?oooooo7?ooool10000007ooooo00000`00003ooooo
ooooo`3ooooooacooooo0@000001ooooo`0000<00000ooooooooool0oooooolLooooo`4000000Ooo
ool0000300000?oooooooooo0;Gooooo0_ooO`1Tooooo`4000000Oooool0000300000?oooooooooo
0;Cooooo1?ooO`1Sooooo`4000000Oooool0000300000?oooooooooo0;Cooooo1?ooO`1Sooooo`40
00000Oooool0000300000?oooooooooo0;Gooooo0_ooO`0eooooo`;oogl0;Oooool10000007ooooo
00000`00003oooooooooo`3Tooooo`;oogl01Oooool4oomo02cooooo0@000001ooooo`0000<00000
ooooooooool0hoooool4oomo00Cooooo1?ooO`0/ooooo`4000000Oooool0000300000?oooooooooo
0<?ooooo0_ooO`0Nooooo`Coogl01Oooool2oomo02gooooo0@000001ooooo`0000<00000oooooooo
ool0`_ooool4oomo01kooooo0_ooO`0eooooo`4000000Oooool0000300000?oooooooooo0<;ooooo
1?ooO`1Eooooo`4000000Oooool0000300000?oooooooooo0<?ooooo0_ooO`1Fooooo`4000000Ooo
ool0000300000?oooooooooo0;Wooooo0_ooO`0Uooooo`;oogl0>Oooool10000007ooooo00000`00
003oooooooooo`2hooooo`Coogl08oooool4oomo03Sooooo0@000001ooooo`0000<00000oooooooo
ool0]?ooool2oomo00;ooooo1?ooO`0Sooooo`Coogl00oooool2oomo03?ooooo0@000001ooooo`00
00<00000ooooooooool0/oooool4oomo00;ooooo0_ooO`0Cooooo`;oogl04?ooool2oomo00?ooooo
1?ooO`0booooo`4000000Oooool0000300000?oooooooooo0;?ooooo1?ooO`06ooooo`;oogl03_oo
ool4oomo01Cooooo1?ooO`0booooo`4000000Oooool0000300000?oooooooooo0;Cooooo0_ooO`06
ooooo`Coogl03Oooool4oomo01Gooooo0_ooO`0cooooo`4000000Oooool0000300000?oooooooooo
08_ooooo0_ooO`0Wooooo`;oogl01_ooool4oomo00kooooo0_ooO`1;ooooo`4000000Oooool00003
00000?oooooooooo08[ooooo1?ooO`0Uooooo`Coogl01_ooool2oomo05cooooo0@000001ooooo`00
00<00000ooooooooool0R_ooool4oomo02Gooooo1?ooO`1Tooooo`4000000Oooool0000300000?oo
oooooooo08_ooooo0_ooO`0Wooooo`;oogl0IOooool10000007ooooo00000`00003oooooooooo`2F
ooooo`;oogl0>_ooool2oomo04Oooooo0@000001ooooo`0000<00000ooooooooool0UOooool4oomo
00kooooo0_ooO`0Xooooo`Coogl0A_ooool10000007ooooo00000`00003oooooooooo`2Eooooo`Co
ogl03Oooool4oomo02Oooooo1?ooO`16ooooo`4000000Oooool0000300000?oooooooooo09Kooooo
0_ooO`0>ooooo`Coogl0:?ooool2oomo04Oooooo0@000001ooooo`0000<00000ooooooooool0Yooo
ool2oomo07;ooooo0@000001ooooo`0000<00000ooooooooool0joooool2oomo02kooooo0@000001
ooooo`0000<00000ooooooooool0j_ooool4oomo02gooooo0@000001ooooo`0000<00000oooooooo
ool0e_ooool2oomo01;ooooo1?ooO`0]ooooo`4000000Oooool0000300000?oooooooooo0=Gooooo
1?ooO`0Booooo`;oogl0;_ooool10000007ooooo00000`00003oooooooooo`2gooooo`;oogl07?oo
ool4oomo04;ooooo0@000001ooooo`0000<00000ooooooooool0]_ooool4oomo01cooooo0_ooO`13
ooooo`4000000Oooool0000300000?oooooooooo0;?ooooo0_ooO`000oooooooogl0oomo0002oomo
067ooooo0@000001ooooo`0000<00000ooooooooool0Z?ooool2oomo00Sooooo1?ooO`000ooooooo
ogl0oomo000Jooooo`;oogl0A_ooool10000007ooooo00000`00003oooooooooo`2Vooooo`Googl0
1oooool4oomo01Oooooo0_ooO`03ooooo`Coogl0AOooool10000007ooooo00000`00003ooooooooo
o`2Uooooo`Koogl02?ooool2oomo01Oooooo1?ooO`02ooooo`Coogl0AOooool10000007ooooo0000
0`00003oooooooooo`2Uooooo`Googl08_ooool4oomo00?ooooo0_ooO`16ooooo`4000000Oooool0
000300000?oooooooooo07Kooooo0_ooO`0^ooooo`;oogl09Oooool2oomo04cooooo0@000001oooo
o`0000<00000ooooooooool0MOooool4oomo0:;ooooo0@000001ooooo`0000<00000ooooooooool0
MOooool4oomo00[ooooo0_ooO`2Fooooo`4000000Oooool0000300000?oooooooooo07Kooooo0_oo
O`0:ooooo`Coogl0:_ooool2oomo06Wooooo0@000001ooooo`0000<00000ooooooooool0P_ooool4
oomo02Wooooo1?ooO`1Xooooo`4000000Oooool0000300000?oooooooooo08?ooooo0_ooO`0Toooo
o`;oogl01?ooool4oomo06Sooooo0@000001ooooo`0000<00000ooooooooool0Z?ooool4oomo00Co
oooo0_ooO`1Yooooo`4000000Oooool0000300000?oooooooooo0:Sooooo1?ooO`1_ooooo`400000
0Oooool0000300000?oooooooooo0:Wooooo0_ooO`1`ooooo`4000000Oooool0000300000?oooooo
oooo0?oooooo7?ooool10000007ooooo00000`00003oooooooooo`3ooooooacooooo0@000001oooo
o`0000<00000ooooooooool0oooooolLooooo`4000000Oooool0000300000?oooooooooo0?oooooo
7?ooool10000007ooooo00000`00003oooooooooo`24ooooo`;oogl0UOooool10000007ooooo0000
0`00003oooooooooo`23ooooo`Coogl0U?ooool10000007ooooo00000`00003oooooooooo`23oooo
o`Coogl0U?ooool10000007ooooo00000`00003oooooooooo`24ooooo`;oogl0;?ooool2oomo06Oo
oooo0@000001ooooo`0000<00000ooooooooool0/Oooool4oomo06Kooooo0@000001ooooo`0000<0
0000ooooooooool0/Oooool4oomo06Kooooo0@000001ooooo`0000<00000ooooooooool0/_ooool2
oomo06Oooooo0@000001ooooo`0000<00000ooooooooool0oooooolLooooo`4000000Oooool00003
00000?oooooooooo0?oooooo7?ooool10000007ooooo00000`00003oooooooooo`1kooooo`;oogl0
W_ooool10000007ooooo00000`00003oooooooooo`1jooooo`Coogl0WOooool10000007ooooo0000
0`00003oooooooooo`1jooooo`Coogl08?ooool2oomo07_ooooo0@000001ooooo`0000<00000oooo
ooooool0Noooool2oomo023ooooo1?ooO`1jooooo`4000000Oooool0000300000?oooooooooo09go
oooo1?ooO`1jooooo`4000000Oooool0000300000?oooooooooo093ooooo0_ooO`0<ooooo`;oogl0
Noooool10000007ooooo00000`00003oooooooooo`2?ooooo`Coogl0R?ooool10000007ooooo0000
0`00003oooooooooo`2?ooooo`Coogl0R?ooool10000007ooooo00000`00003oooooooooo`2@oooo
o`;oogl08oooool2oomo06Cooooo0@000001ooooo`0000<00000ooooooooool0]?ooool4oomo06?o
oooo0@000001ooooo`0000<00000ooooooooool0]?ooool4oomo06?ooooo0@000001ooooo`0000<0
0000ooooooooool0]Oooool2oomo06Cooooo0@000001ooooo`0000<00000ooooooooool0oooooolL
ooooo`4000000Oooool0000300000?oooooooooo0?oooooo7?ooool10000007ooooo00000`00003o
ooooooooo`3ooooooacooooo0@000001ooooo`0000<00000ooooooooool0oooooolLooooo`400000
0Oooool0000300000?oooooooooo0?oooooo7?ooool10000007ooooo00000`00003oooooooooo`3o
oooooacooooo0@000001ooooo`0000<00000ooooooooool0oooooolLooooo`4000000Oooool00003
00000?oooooooooo0?oooooo7?ooool10000007ooooo00000`00003oooooooooo`3ooooooacooooo
0@000001ooooo`0000<00000ooooooooool0oooooolLooooo`4000000Oooool0000300000?oooooo
oooo0?oooooo7?ooool10000007ooooo00000`00003oooooooooo`3ooooooacooooo0@000001oooo
o`0000<00000ooooooooool0oooooolLooooo`4000000Oooool0000300000?oooooooooo0?oooooo
7?ooool10000007ooooo00000`00003oooooooooo`3ooooooacooooo0@000001ooooo`0000<00000
ooooooooool0oooooolLooooo`4000000Oooool0000300000?oooooooooo0?oooooo7?ooool10000
007ooooo00000`00003oooooooooo`3ooooooacooooo0@000001ooooo`0000<00000ooooooooool0
oooooolLooooo`4000000Oooool0000300000?oooooooooo0?oooooo7?ooool10000007ooooo0000
0`00003oooooooooo`3ooooooacooooo0@000001ooooo`0000<00000ooooooooool0oooooolLoooo
o`4000000Oooool0000300000?oooooooooo0?oooooo7?ooool10000007ooooo00000`00003ooooo
ooooo`3ooooooacooooo0@000001ooooo`0000<00000ooooooooool0oooooolLooooo`4000000Ooo
ool0000300000?oooooooooo0?oooooo7?ooool10000007ooooo00000`00003oooooooooo`3ooooo
oacooooo0@000001ooooo`0000<00000ooooooooool0oooooolLooooo`4000000Oooool000030000
0?oooooooooo0?oooooo7?ooool10000007ooooo00000`00003oooooooooo`3ooooooacooooo0@00
0001ooooo`0000<00000ooooooooool0oooooolLooooo`4000000Oooool0000300000?oooooooooo
0?oooooo7?ooool10000007ooooo00000`00003oooooooooo`3ooooooacooooo0@000001ooooo`00
00<00000ooooooooool0oooooolLooooo`4000000Oooool0000300000?oooooooooo0?oooooo7?oo
ool10000007ooooo00000`00003oooooooooo`3ooooooacooooo0@000001ooooo`0000<00000oooo
ooooool0oooooolLooooo`4000000Oooool0000300000?oooooooooo08kooooo0_ooO`2;ooooo`40
00000Oooool0000300000?oooooooooo08gooooo1?ooO`2:ooooo`4000000Oooool0000300000?oo
oooooooo08gooooo1?ooO`2:ooooo`4000000Oooool0000300000?oooooooooo08kooooo0_ooO`2;
ooooo`4000000Oooool0000300000?oooooooooo0?oooooo7?ooool10000007ooooo00000`00003o
ooooooooo`3ooooooacooooo0@000001ooooo`0000<00000ooooooooool0oooooolLooooo`400000
0Oooool0000300000?oooooooooo0?oooooo7?ooool10000007ooooo00000`00003oooooooooo`3o
oooooacooooo0@000001ooooo`0000<00000ooooooooool0oooooolLooooo`4000000Oooool00003
00000?oooooooooo0?oooooo7?ooool10000007ooooo00000`00003oooooooooo`3ooooooacooooo
0@000001ooooo`0000<00000ooooooooool0oooooolLooooo`4000000Oooool0000300000?oooooo
oooo0?oooooo7?ooool10000007ooooo00000`00003oooooooooo`3ooooooacooooo0@000001oooo
o`0000<00000ooooooooool0oooooolLooooo`4000000Oooool0000300000?oooooooooo0?oooooo
7?ooool10000007ooooo00000`00003oooooooooo`3ooooooacooooo0@000001ooooo`0000<00000
ooooooooool0oooooolLooooo`4000000Oooool0000300000?oooooooooo0?oooooo7?ooool10000
007ooooo00000`00003oooooooooo`3ooooooacooooo0@000001ooooo`0000<00000ooooooooool0
oooooolLooooo`4000000Oooool0000300000?oooooooooo0?oooooo7?ooool10000007ooooo0000
0`00003oooooooooo`3ooooooacooooo0@000001ooooo`0000<00000ooooooooool0oooooolLoooo
o`4000000Oooool00?l0000080000001ooooo`00\
\>"],
  ImageRangeCache->{{{0, 287}, {287, 0}} -> {-1.01089, -1.01089, 0.00704453, \
0.00704453}}]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["EM algorithm", "Section"],

Cell[CellGroupData[{

Cell["Initialize EM algorithm", "Subsection"],

Cell[BoxData[{
    \(\(k = 2;\)\), "\[IndentingNewLine]", 
    \(\(initialModel\  = \ EMInitializationFull[xd, k];\)\)}], "Input"]
}, Closed]],

Cell[CellGroupData[{

Cell["Compute EM trajectory", "Subsection"],

Cell[CellGroupData[{

Cell[BoxData[
    \(Timing[\(em\  = \ EM[xd, initialModel, 0.001];\)]\)], "Input"],

Cell[BoxData[
    \({0.`\ Second, Null}\)], "Output"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["Visualize EM solution", "Subsection"],

Cell[CellGroupData[{

Cell["Initial model", "Subsubsection"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(EMAllPlot[initialModel, \ gdata, pr];\)\)], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
%%ImageSize: 400 400 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.47619 0.0238095 0.47619 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.0238095 0.477324 0.477324 MathSubStart
%% ContourGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.480769 0.5 0.480769 [
[ 0 0 -0.125 0 ]
[ 0 0 -0.125 0 ]
[ 0 1 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
0 0 m
1 0 L
s
0 0 m
0 1 L
s
0 1 m
1 1 L
s
1 0 m
1 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
.01923 .98077 m
.98077 .98077 L
.98077 .01923 L
.01923 .01923 L
F
.5 Mabswid
.1 g
.01923 .71418 m
.03846 .7279 L
.04268 .73077 L
.05769 .7406 L
.07295 .75 L
.07692 .75235 L
.09615 .76318 L
.10761 .76923 L
.11538 .77315 L
.13462 .78228 L
.14871 .78846 L
.15385 .7906 L
.17308 .79812 L
.19231 .80488 L
.20098 .80769 L
.21154 .81089 L
.23077 .81615 L
.25 .82069 L
.26923 .82451 L
.28374 .82692 L
.28846 .82761 L
.30769 .82999 L
.32692 .83166 L
.34615 .83262 L
.36538 .83286 L
.38462 .83239 L
.40385 .83118 L
.42308 .82923 L
.43989 .82692 L
.44231 .82653 L
.46154 .82304 L
.48077 .81875 L
.5 .81364 L
.51922 .80769 L
.51923 .80769 L
.53846 .80082 L
.55769 .79302 L
.56795 .78846 L
.57692 .78422 L
.59615 .77436 L
.60539 .76923 L
.61538 .76336 L
.63462 .75112 L
.63627 .75 L
.65385 .7375 L
.66266 .73077 L
.67308 .72237 L
.68568 .71154 L
.69231 .70552 L
.70602 .69231 L
.71154 .68667 L
.72414 .67308 L
.73077 .66547 L
.74037 .65385 L
.75 .64139 L
.75496 .63462 L
.76808 .61538 L
.76923 .6136 L
.77988 .59615 L
.78846 .58075 L
.79048 .57692 L
.79995 .55769 L
.80769 .54016 L
.80839 .53846 L
.81584 .51923 L
.82238 .5 L
.82692 .48481 L
.82803 .48077 L
.83283 .46154 L
.83681 .44231 L
.84 .42308 L
.84242 .40385 L
.84409 .38462 L
.84501 .36538 L
.84519 .34615 L
.84465 .32692 L
.84339 .30769 L
.84141 .28846 L
.83871 .26923 L
.83529 .25 L
.83115 .23077 L
.82692 .21391 L
.82628 .21154 L
.82065 .19231 L
.81427 .17308 L
.80769 .15529 L
.80713 .15385 L
.79918 .13462 L
.79043 .11538 L
.78846 .11128 L
.78084 .09615 L
.77039 .07692 L
.76923 .07489 L
.75902 .05769 L
.75 .04345 L
.74671 .03846 L
.7334 .01923 L
.01923 .01923 L
F
0 g
.01923 .71418 m
.03846 .7279 L
.04268 .73077 L
.05769 .7406 L
.07295 .75 L
.07692 .75235 L
.09615 .76318 L
.10761 .76923 L
.11538 .77315 L
.13462 .78228 L
.14871 .78846 L
.15385 .7906 L
.17308 .79812 L
.19231 .80488 L
.20098 .80769 L
.21154 .81089 L
.23077 .81615 L
.25 .82069 L
.26923 .82451 L
.28374 .82692 L
.28846 .82761 L
.30769 .82999 L
.32692 .83166 L
.34615 .83262 L
.36538 .83286 L
.38462 .83239 L
.40385 .83118 L
.42308 .82923 L
.43989 .82692 L
.44231 .82653 L
.46154 .82304 L
.48077 .81875 L
.5 .81364 L
.51922 .80769 L
.51923 .80769 L
.53846 .80082 L
.55769 .79302 L
.56795 .78846 L
.57692 .78422 L
.59615 .77436 L
.60539 .76923 L
.61538 .76336 L
.63462 .75112 L
.63627 .75 L
.65385 .7375 L
.66266 .73077 L
.67308 .72237 L
.68568 .71154 L
.69231 .70552 L
.70602 .69231 L
Mistroke
.71154 .68667 L
.72414 .67308 L
.73077 .66547 L
.74037 .65385 L
.75 .64139 L
.75496 .63462 L
.76808 .61538 L
.76923 .6136 L
.77988 .59615 L
.78846 .58075 L
.79048 .57692 L
.79995 .55769 L
.80769 .54016 L
.80839 .53846 L
.81584 .51923 L
.82238 .5 L
.82692 .48481 L
.82803 .48077 L
.83283 .46154 L
.83681 .44231 L
.84 .42308 L
.84242 .40385 L
.84409 .38462 L
.84501 .36538 L
.84519 .34615 L
.84465 .32692 L
.84339 .30769 L
.84141 .28846 L
.83871 .26923 L
.83529 .25 L
.83115 .23077 L
.82692 .21391 L
.82628 .21154 L
.82065 .19231 L
.81427 .17308 L
.80769 .15529 L
.80713 .15385 L
.79918 .13462 L
.79043 .11538 L
.78846 .11128 L
.78084 .09615 L
.77039 .07692 L
.76923 .07489 L
.75902 .05769 L
.75 .04345 L
.74671 .03846 L
.7334 .01923 L
Mfstroke
.2 g
.01923 .5976 m
.03846 .61493 L
.03899 .61538 L
.05769 .63073 L
.06271 .63462 L
.07692 .64513 L
.08947 .65385 L
.09615 .65828 L
.11538 .67025 L
.12021 .67308 L
.13462 .68111 L
.15385 .69094 L
.1567 .69231 L
.17308 .69976 L
.19231 .70763 L
.2028 .71154 L
.21154 .71458 L
.23077 .72061 L
.25 .72578 L
.26923 .73007 L
.27272 .73077 L
.28846 .7335 L
.30769 .73607 L
.32692 .7378 L
.34615 .73867 L
.36538 .73867 L
.38462 .73781 L
.40385 .73605 L
.42308 .73338 L
.43751 .73077 L
.44231 .72976 L
.46154 .72516 L
.48077 .71955 L
.5 .71285 L
.50345 .71154 L
.51923 .70501 L
.53846 .69594 L
.54547 .69231 L
.55769 .68552 L
.57692 .67364 L
.57777 .67308 L
.59615 .66009 L
.60425 .65385 L
.61538 .64466 L
.62666 .63462 L
.63462 .62702 L
.64597 .61538 L
.65385 .6067 L
.66278 .59615 L
.67308 .58299 L
.67751 .57692 L
.69044 .55769 L
.69231 .5547 L
.70178 .53846 L
.71154 .51958 L
.7117 .51923 L
.72031 .5 L
.72773 .48077 L
.73077 .47191 L
.73402 .46154 L
.73924 .44231 L
.74346 .42308 L
.7467 .40385 L
.74902 .38462 L
.75 .37518 L
.75042 .36538 L
.75092 .34615 L
.75055 .32692 L
.75 .31665 L
.74932 .30769 L
.74721 .28846 L
.74425 .26923 L
.74042 .25 L
.73572 .23077 L
.73077 .21357 L
.73013 .21154 L
.72364 .19231 L
.71622 .17308 L
.71154 .16203 L
.70785 .15385 L
.69849 .13462 L
.69231 .12294 L
.68809 .11538 L
.67661 .09615 L
.67308 .09059 L
.66397 .07692 L
.65385 .06272 L
.65009 .05769 L
.63487 .03846 L
.63462 .03815 L
.61817 .01923 L
.01923 .01923 L
F
0 g
.01923 .5976 m
.03846 .61493 L
.03899 .61538 L
.05769 .63073 L
.06271 .63462 L
.07692 .64513 L
.08947 .65385 L
.09615 .65828 L
.11538 .67025 L
.12021 .67308 L
.13462 .68111 L
.15385 .69094 L
.1567 .69231 L
.17308 .69976 L
.19231 .70763 L
.2028 .71154 L
.21154 .71458 L
.23077 .72061 L
.25 .72578 L
.26923 .73007 L
.27272 .73077 L
.28846 .7335 L
.30769 .73607 L
.32692 .7378 L
.34615 .73867 L
.36538 .73867 L
.38462 .73781 L
.40385 .73605 L
.42308 .73338 L
.43751 .73077 L
.44231 .72976 L
.46154 .72516 L
.48077 .71955 L
.5 .71285 L
.50345 .71154 L
.51923 .70501 L
.53846 .69594 L
.54547 .69231 L
.55769 .68552 L
.57692 .67364 L
.57777 .67308 L
.59615 .66009 L
.60425 .65385 L
.61538 .64466 L
.62666 .63462 L
.63462 .62702 L
.64597 .61538 L
.65385 .6067 L
.66278 .59615 L
.67308 .58299 L
Mistroke
.67751 .57692 L
.69044 .55769 L
.69231 .5547 L
.70178 .53846 L
.71154 .51958 L
.7117 .51923 L
.72031 .5 L
.72773 .48077 L
.73077 .47191 L
.73402 .46154 L
.73924 .44231 L
.74346 .42308 L
.7467 .40385 L
.74902 .38462 L
.75 .37518 L
.75042 .36538 L
.75092 .34615 L
.75055 .32692 L
.75 .31665 L
.74932 .30769 L
.74721 .28846 L
.74425 .26923 L
.74042 .25 L
.73572 .23077 L
.73077 .21357 L
.73013 .21154 L
.72364 .19231 L
.71622 .17308 L
.71154 .16203 L
.70785 .15385 L
.69849 .13462 L
.69231 .12294 L
.68809 .11538 L
.67661 .09615 L
.67308 .09059 L
.66397 .07692 L
.65385 .06272 L
.65009 .05769 L
.63487 .03846 L
.63462 .03815 L
.61817 .01923 L
Mfstroke
.3 g
.01923 .51535 m
.02251 .51923 L
.03846 .53698 L
.03986 .53846 L
.05769 .55622 L
.05926 .55769 L
.07692 .57344 L
.08108 .57692 L
.09615 .58891 L
.10591 .59615 L
.11538 .60283 L
.13462 .61534 L
.1347 .61538 L
.15385 .62654 L
.1692 .63462 L
.17308 .63654 L
.19231 .64538 L
.21154 .65313 L
.21344 .65385 L
.23077 .65983 L
.25 .6655 L
.26923 .67017 L
.28382 .67308 L
.28846 .67386 L
.30769 .67656 L
.32692 .67829 L
.34615 .67904 L
.36538 .67879 L
.38462 .67753 L
.40385 .67523 L
.41699 .67308 L
.42308 .67186 L
.44231 .66735 L
.46154 .66167 L
.48077 .65473 L
.48298 .65385 L
.5 .64642 L
.51923 .63663 L
.52284 .63462 L
.53846 .62517 L
.55286 .61538 L
.55769 .61184 L
.57692 .59631 L
.5771 .59615 L
.59615 .57813 L
.59732 .57692 L
.61448 .55769 L
.61538 .55659 L
.62918 .53846 L
.63462 .53053 L
.64179 .51923 L
.65262 .5 L
.65385 .49762 L
.66184 .48077 L
.66963 .46154 L
.67308 .45177 L
.67608 .44231 L
.6813 .42308 L
.68536 .40385 L
.6883 .38462 L
.69017 .36538 L
.69101 .34615 L
.69083 .32692 L
.68966 .30769 L
.68749 .28846 L
.68434 .26923 L
.68019 .25 L
.67504 .23077 L
.67308 .22428 L
.66886 .21154 L
.66163 .19231 L
.65385 .17423 L
.65331 .17308 L
.64386 .15385 L
.63462 .13703 L
.63321 .13462 L
.62128 .11538 L
.61538 .10659 L
.60799 .09615 L
.59615 .08061 L
.5932 .07692 L
.57692 .0579 L
.57674 .05769 L
.55837 .03846 L
.55769 .03779 L
.53846 .01982 L
.53779 .01923 L
.01923 .01923 L
F
0 g
.01923 .51535 m
.02251 .51923 L
.03846 .53698 L
.03986 .53846 L
.05769 .55622 L
.05926 .55769 L
.07692 .57344 L
.08108 .57692 L
.09615 .58891 L
.10591 .59615 L
.11538 .60283 L
.13462 .61534 L
.1347 .61538 L
.15385 .62654 L
.1692 .63462 L
.17308 .63654 L
.19231 .64538 L
.21154 .65313 L
.21344 .65385 L
.23077 .65983 L
.25 .6655 L
.26923 .67017 L
.28382 .67308 L
.28846 .67386 L
.30769 .67656 L
.32692 .67829 L
.34615 .67904 L
.36538 .67879 L
.38462 .67753 L
.40385 .67523 L
.41699 .67308 L
.42308 .67186 L
.44231 .66735 L
.46154 .66167 L
.48077 .65473 L
.48298 .65385 L
.5 .64642 L
.51923 .63663 L
.52284 .63462 L
.53846 .62517 L
.55286 .61538 L
.55769 .61184 L
.57692 .59631 L
.5771 .59615 L
.59615 .57813 L
.59732 .57692 L
.61448 .55769 L
.61538 .55659 L
.62918 .53846 L
.63462 .53053 L
Mistroke
.64179 .51923 L
.65262 .5 L
.65385 .49762 L
.66184 .48077 L
.66963 .46154 L
.67308 .45177 L
.67608 .44231 L
.6813 .42308 L
.68536 .40385 L
.6883 .38462 L
.69017 .36538 L
.69101 .34615 L
.69083 .32692 L
.68966 .30769 L
.68749 .28846 L
.68434 .26923 L
.68019 .25 L
.67504 .23077 L
.67308 .22428 L
.66886 .21154 L
.66163 .19231 L
.65385 .17423 L
.65331 .17308 L
.64386 .15385 L
.63462 .13703 L
.63321 .13462 L
.62128 .11538 L
.61538 .10659 L
.60799 .09615 L
.59615 .08061 L
.5932 .07692 L
.57692 .0579 L
.57674 .05769 L
.55837 .03846 L
.55769 .03779 L
.53846 .01982 L
.53779 .01923 L
Mfstroke
.4 g
.01923 .43899 m
.02128 .44231 L
.03409 .46154 L
.03846 .4676 L
.04856 .48077 L
.05769 .4918 L
.06491 .5 L
.07692 .51276 L
.08342 .51923 L
.09615 .53114 L
.10453 .53846 L
.11538 .54738 L
.12892 .55769 L
.13462 .56177 L
.15385 .57452 L
.15776 .57692 L
.17308 .58577 L
.19231 .59565 L
.19336 .59615 L
.21154 .60424 L
.23077 .6116 L
.24206 .61538 L
.25 .61779 L
.26923 .62283 L
.28846 .62675 L
.30769 .62956 L
.32692 .63127 L
.34615 .63186 L
.36538 .63132 L
.38462 .62962 L
.40385 .62671 L
.42308 .62255 L
.44231 .61706 L
.44737 .61538 L
.46154 .61012 L
.48077 .60163 L
.49149 .59615 L
.5 .59138 L
.51923 .57916 L
.52241 .57692 L
.53846 .56459 L
.54651 .55769 L
.55769 .54718 L
.56612 .53846 L
.57692 .5261 L
.58241 .51923 L
.59606 .5 L
.59615 .49985 L
.60751 .48077 L
.61538 .46521 L
.61707 .46154 L
.62496 .44231 L
.63132 .42308 L
.63462 .411 L
.63628 .40385 L
.63993 .38462 L
.64234 .36538 L
.64355 .34615 L
.6436 .32692 L
.64252 .30769 L
.64031 .28846 L
.63699 .26923 L
.63462 .25826 L
.63254 .25 L
.62694 .23077 L
.62017 .21154 L
.61538 .19965 L
.61218 .19231 L
.60292 .17308 L
.59615 .16051 L
.59231 .15385 L
.58026 .13462 L
.57692 .12969 L
.56662 .11538 L
.55769 .10396 L
.55122 .09615 L
.53846 .08184 L
.5338 .07692 L
.51923 .06252 L
.51402 .05769 L
.5 .04549 L
.49133 .03846 L
.48077 .03041 L
.46485 .01923 L
.01923 .01923 L
F
0 g
.01923 .43899 m
.02128 .44231 L
.03409 .46154 L
.03846 .4676 L
.04856 .48077 L
.05769 .4918 L
.06491 .5 L
.07692 .51276 L
.08342 .51923 L
.09615 .53114 L
.10453 .53846 L
.11538 .54738 L
.12892 .55769 L
.13462 .56177 L
.15385 .57452 L
.15776 .57692 L
.17308 .58577 L
.19231 .59565 L
.19336 .59615 L
.21154 .60424 L
.23077 .6116 L
.24206 .61538 L
.25 .61779 L
.26923 .62283 L
.28846 .62675 L
.30769 .62956 L
.32692 .63127 L
.34615 .63186 L
.36538 .63132 L
.38462 .62962 L
.40385 .62671 L
.42308 .62255 L
.44231 .61706 L
.44737 .61538 L
.46154 .61012 L
.48077 .60163 L
.49149 .59615 L
.5 .59138 L
.51923 .57916 L
.52241 .57692 L
.53846 .56459 L
.54651 .55769 L
.55769 .54718 L
.56612 .53846 L
.57692 .5261 L
.58241 .51923 L
.59606 .5 L
.59615 .49985 L
.60751 .48077 L
.61538 .46521 L
Mistroke
.61707 .46154 L
.62496 .44231 L
.63132 .42308 L
.63462 .411 L
.63628 .40385 L
.63993 .38462 L
.64234 .36538 L
.64355 .34615 L
.6436 .32692 L
.64252 .30769 L
.64031 .28846 L
.63699 .26923 L
.63462 .25826 L
.63254 .25 L
.62694 .23077 L
.62017 .21154 L
.61538 .19965 L
.61218 .19231 L
.60292 .17308 L
.59615 .16051 L
.59231 .15385 L
.58026 .13462 L
.57692 .12969 L
.56662 .11538 L
.55769 .10396 L
.55122 .09615 L
.53846 .08184 L
.5338 .07692 L
.51923 .06252 L
.51402 .05769 L
.5 .04549 L
.49133 .03846 L
.48077 .03041 L
.46485 .01923 L
Mfstroke
.5 g
.01923 .34456 m
.01974 .34615 L
.02647 .36538 L
.03458 .38462 L
.03846 .39281 L
.04414 .40385 L
.05527 .42308 L
.05769 .42693 L
.0681 .44231 L
.07692 .45414 L
.08284 .46154 L
.09615 .47688 L
.09978 .48077 L
.11538 .49633 L
.11935 .5 L
.13462 .51318 L
.14223 .51923 L
.15385 .52785 L
.16962 .53846 L
.17308 .54063 L
.19231 .55172 L
.20396 .55769 L
.21154 .56127 L
.23077 .56938 L
.25 .57614 L
.25248 .57692 L
.26923 .58158 L
.28846 .58575 L
.30769 .58866 L
.32692 .59032 L
.34615 .59071 L
.36538 .58981 L
.38462 .58758 L
.40385 .58395 L
.42308 .57884 L
.4291 .57692 L
.44231 .57211 L
.46154 .5636 L
.47283 .55769 L
.48077 .55307 L
.5 .54019 L
.50232 .53846 L
.51923 .52444 L
.52481 .51923 L
.53846 .50498 L
.54275 .5 L
.55734 .48077 L
.55769 .48026 L
.56928 .46154 L
.57692 .4468 L
.579 .44231 L
.5868 .42308 L
.59287 .40385 L
.59615 .39069 L
.59738 .38462 L
.60043 .36538 L
.60209 .34615 L
.60243 .32692 L
.60147 .30769 L
.59925 .28846 L
.59615 .27099 L
.59575 .26923 L
.59098 .25 L
.5849 .23077 L
.57747 .21154 L
.57692 .21025 L
.56862 .19231 L
.55827 .17308 L
.55769 .17208 L
.54629 .15385 L
.53846 .1426 L
.53251 .13462 L
.51923 .11831 L
.51668 .11538 L
.5 .09768 L
.49845 .09615 L
.48077 .07988 L
.47729 .07692 L
.46154 .06441 L
.45229 .05769 L
.44231 .05092 L
.42308 .0392 L
.42178 .03846 L
.40385 .02906 L
.38462 .0204 L
.38177 .01923 L
.01923 .01923 L
F
0 g
.01923 .34456 m
.01974 .34615 L
.02647 .36538 L
.03458 .38462 L
.03846 .39281 L
.04414 .40385 L
.05527 .42308 L
.05769 .42693 L
.0681 .44231 L
.07692 .45414 L
.08284 .46154 L
.09615 .47688 L
.09978 .48077 L
.11538 .49633 L
.11935 .5 L
.13462 .51318 L
.14223 .51923 L
.15385 .52785 L
.16962 .53846 L
.17308 .54063 L
.19231 .55172 L
.20396 .55769 L
.21154 .56127 L
.23077 .56938 L
.25 .57614 L
.25248 .57692 L
.26923 .58158 L
.28846 .58575 L
.30769 .58866 L
.32692 .59032 L
.34615 .59071 L
.36538 .58981 L
.38462 .58758 L
.40385 .58395 L
.42308 .57884 L
.4291 .57692 L
.44231 .57211 L
.46154 .5636 L
.47283 .55769 L
.48077 .55307 L
.5 .54019 L
.50232 .53846 L
.51923 .52444 L
.52481 .51923 L
.53846 .50498 L
.54275 .5 L
.55734 .48077 L
.55769 .48026 L
.56928 .46154 L
.57692 .4468 L
Mistroke
.579 .44231 L
.5868 .42308 L
.59287 .40385 L
.59615 .39069 L
.59738 .38462 L
.60043 .36538 L
.60209 .34615 L
.60243 .32692 L
.60147 .30769 L
.59925 .28846 L
.59615 .27099 L
.59575 .26923 L
.59098 .25 L
.5849 .23077 L
.57747 .21154 L
.57692 .21025 L
.56862 .19231 L
.55827 .17308 L
.55769 .17208 L
.54629 .15385 L
.53846 .1426 L
.53251 .13462 L
.51923 .11831 L
.51668 .11538 L
.5 .09768 L
.49845 .09615 L
.48077 .07988 L
.47729 .07692 L
.46154 .06441 L
.45229 .05769 L
.44231 .05092 L
.42308 .0392 L
.42178 .03846 L
.40385 .02906 L
.38462 .0204 L
.38177 .01923 L
Mfstroke
.4 g
.01923 .16916 m
.0249 .15385 L
.03366 .13462 L
.03846 .12557 L
.04447 .11538 L
.05769 .09618 L
.05771 .09615 L
.07392 .07692 L
.07692 .07376 L
.09399 .05769 L
.09615 .05586 L
.11538 .0413 L
.11963 .03846 L
.13462 .02939 L
.15385 .01968 L
.15483 .01923 L
.01923 .01923 L
F
0 g
.01923 .16916 m
.0249 .15385 L
.03366 .13462 L
.03846 .12557 L
.04447 .11538 L
.05769 .09618 L
.05771 .09615 L
.07392 .07692 L
.07692 .07376 L
.09399 .05769 L
.09615 .05586 L
.11538 .0413 L
.11963 .03846 L
.13462 .02939 L
.15385 .01968 L
.15483 .01923 L
s
.3 g
.01923 .07601 m
.03352 .05769 L
.03846 .05201 L
.05141 .03846 L
.05769 .03248 L
.07313 .01923 L
.01923 .01923 L
F
0 g
.01923 .07601 m
.03352 .05769 L
.03846 .05201 L
.05141 .03846 L
.05769 .03248 L
.07313 .01923 L
s
.6 g
.23077 .03723 m
.25 .03493 L
.26923 .03416 L
.28846 .03486 L
.30769 .037 L
.31708 .03846 L
.32692 .04056 L
.34615 .04557 L
.36538 .05207 L
.37926 .05769 L
.38462 .06011 L
.40385 .06979 L
.41617 .07692 L
.42308 .08127 L
.44231 .09474 L
.44416 .09615 L
.46154 .11052 L
.4669 .11538 L
.48077 .12907 L
.48593 .13462 L
.5 .15117 L
.5021 .15385 L
.51588 .17308 L
.51923 .17824 L
.52762 .19231 L
.53753 .21154 L
.53846 .21352 L
.54576 .23077 L
.55241 .25 L
.55756 .26923 L
.55769 .26976 L
.56124 .28846 L
.56347 .30769 L
.56425 .32692 L
.56354 .34615 L
.5613 .36538 L
.55769 .38363 L
.55743 .38462 L
.5518 .40385 L
.54424 .42308 L
.53846 .43503 L
.53447 .44231 L
.52209 .46154 L
.51923 .46541 L
.50647 .48077 L
.5 .48755 L
.48649 .5 L
.48077 .50467 L
.46154 .5182 L
.45988 .51923 L
.44231 .52892 L
.42308 .53731 L
.42006 .53846 L
.40385 .54369 L
.38462 .54826 L
.36538 .55117 L
.34615 .55252 L
.32692 .55239 L
.30769 .55081 L
.28846 .54779 L
.26923 .54335 L
.25297 .53846 L
.25 .53744 L
.23077 .53001 L
.21154 .52097 L
.20819 .51923 L
.19231 .51021 L
.17657 .5 L
.17308 .49754 L
.15385 .4827 L
.15155 .48077 L
.13462 .4653 L
.13085 .46154 L
.11538 .4447 L
.11336 .44231 L
.09847 .42308 L
.09615 .4198 L
.08577 .40385 L
.07692 .38832 L
.07499 .38462 L
.06596 .36538 L
.05856 .34615 L
.05769 .34366 L
.05268 .32692 L
.04829 .30769 L
.04536 .28846 L
.04387 .26923 L
.04385 .25 L
.04534 .23077 L
.0484 .21154 L
.05316 .19231 L
.05769 .17843 L
.05975 .17308 L
.06841 .15385 L
.07692 .13863 L
.07946 .13462 L
.0934 .11538 L
.09615 .11206 L
.11107 .09615 L
.11538 .09212 L
.13405 .07692 L
.13462 .07651 L
.15385 .06414 L
.16597 .05769 L
.17308 .05437 L
.19231 .04679 L
.21154 .04114 L
.22332 .03846 L
F
0 g
.23077 .03723 m
.25 .03493 L
.26923 .03416 L
.28846 .03486 L
.30769 .037 L
.31708 .03846 L
.32692 .04056 L
.34615 .04557 L
.36538 .05207 L
.37926 .05769 L
.38462 .06011 L
.40385 .06979 L
.41617 .07692 L
.42308 .08127 L
.44231 .09474 L
.44416 .09615 L
.46154 .11052 L
.4669 .11538 L
.48077 .12907 L
.48593 .13462 L
.5 .15117 L
.5021 .15385 L
.51588 .17308 L
.51923 .17824 L
.52762 .19231 L
.53753 .21154 L
.53846 .21352 L
.54576 .23077 L
.55241 .25 L
.55756 .26923 L
.55769 .26976 L
.56124 .28846 L
.56347 .30769 L
.56425 .32692 L
.56354 .34615 L
.5613 .36538 L
.55769 .38363 L
.55743 .38462 L
.5518 .40385 L
.54424 .42308 L
.53846 .43503 L
.53447 .44231 L
.52209 .46154 L
.51923 .46541 L
.50647 .48077 L
.5 .48755 L
.48649 .5 L
.48077 .50467 L
.46154 .5182 L
.45988 .51923 L
Mistroke
.44231 .52892 L
.42308 .53731 L
.42006 .53846 L
.40385 .54369 L
.38462 .54826 L
.36538 .55117 L
.34615 .55252 L
.32692 .55239 L
.30769 .55081 L
.28846 .54779 L
.26923 .54335 L
.25297 .53846 L
.25 .53744 L
.23077 .53001 L
.21154 .52097 L
.20819 .51923 L
.19231 .51021 L
.17657 .5 L
.17308 .49754 L
.15385 .4827 L
.15155 .48077 L
.13462 .4653 L
.13085 .46154 L
.11538 .4447 L
.11336 .44231 L
.09847 .42308 L
.09615 .4198 L
.08577 .40385 L
.07692 .38832 L
.07499 .38462 L
.06596 .36538 L
.05856 .34615 L
.05769 .34366 L
.05268 .32692 L
.04829 .30769 L
.04536 .28846 L
.04387 .26923 L
.04385 .25 L
.04534 .23077 L
.0484 .21154 L
.05316 .19231 L
.05769 .17843 L
.05975 .17308 L
.06841 .15385 L
.07692 .13863 L
.07946 .13462 L
.0934 .11538 L
.09615 .11206 L
.11107 .09615 L
.11538 .09212 L
Mistroke
.13405 .07692 L
.13462 .07651 L
.15385 .06414 L
.16597 .05769 L
.17308 .05437 L
.19231 .04679 L
.21154 .04114 L
.22332 .03846 L
.23077 .03723 L
Mfstroke
.7 g
.23077 .07568 m
.25 .07257 L
.26923 .07127 L
.28846 .07171 L
.30769 .07381 L
.32449 .07692 L
.32692 .07758 L
.34615 .08303 L
.36538 .09023 L
.37844 .09615 L
.38462 .09929 L
.40385 .11038 L
.41147 .11538 L
.42308 .12376 L
.43643 .13462 L
.44231 .13986 L
.45648 .15385 L
.46154 .15936 L
.473 .17308 L
.48077 .18352 L
.48672 .19231 L
.49808 .21154 L
.5 .21517 L
.50737 .23077 L
.51476 .25 L
.51923 .26466 L
.52037 .26923 L
.52428 .28846 L
.5265 .30769 L
.52702 .32692 L
.52581 .34615 L
.52276 .36538 L
.51923 .37994 L
.51773 .38462 L
.5105 .40385 L
.5007 .42308 L
.5 .42427 L
.48778 .44231 L
.48077 .4509 L
.47075 .46154 L
.46154 .46997 L
.44762 .48077 L
.44231 .48435 L
.42308 .4953 L
.41286 .5 L
.40385 .50351 L
.38462 .5094 L
.36538 .51325 L
.34615 .51524 L
.32692 .51546 L
.30769 .514 L
.28846 .51088 L
.26923 .50609 L
.25109 .5 L
.25 .49957 L
.23077 .49125 L
.21154 .48098 L
.21118 .48077 L
.19231 .46853 L
.18289 .46154 L
.17308 .45355 L
.16069 .44231 L
.15385 .43548 L
.14257 .42308 L
.13462 .41334 L
.12756 .40385 L
.11538 .38511 L
.11509 .38462 L
.10482 .36538 L
.09653 .34615 L
.09615 .34519 L
.09006 .32692 L
.08533 .30769 L
.0823 .28846 L
.08094 .26923 L
.0813 .25 L
.08344 .23077 L
.08748 .21154 L
.09361 .19231 L
.09615 .18586 L
.10211 .17308 L
.11342 .15385 L
.11538 .15098 L
.12829 .13462 L
.13462 .12782 L
.14809 .11538 L
.15385 .11078 L
.17308 .09785 L
.17601 .09615 L
.19231 .08802 L
.21154 .08075 L
.22498 .07692 L
F
0 g
.23077 .07568 m
.25 .07257 L
.26923 .07127 L
.28846 .07171 L
.30769 .07381 L
.32449 .07692 L
.32692 .07758 L
.34615 .08303 L
.36538 .09023 L
.37844 .09615 L
.38462 .09929 L
.40385 .11038 L
.41147 .11538 L
.42308 .12376 L
.43643 .13462 L
.44231 .13986 L
.45648 .15385 L
.46154 .15936 L
.473 .17308 L
.48077 .18352 L
.48672 .19231 L
.49808 .21154 L
.5 .21517 L
.50737 .23077 L
.51476 .25 L
.51923 .26466 L
.52037 .26923 L
.52428 .28846 L
.5265 .30769 L
.52702 .32692 L
.52581 .34615 L
.52276 .36538 L
.51923 .37994 L
.51773 .38462 L
.5105 .40385 L
.5007 .42308 L
.5 .42427 L
.48778 .44231 L
.48077 .4509 L
.47075 .46154 L
.46154 .46997 L
.44762 .48077 L
.44231 .48435 L
.42308 .4953 L
.41286 .5 L
.40385 .50351 L
.38462 .5094 L
.36538 .51325 L
.34615 .51524 L
.32692 .51546 L
Mistroke
.30769 .514 L
.28846 .51088 L
.26923 .50609 L
.25109 .5 L
.25 .49957 L
.23077 .49125 L
.21154 .48098 L
.21118 .48077 L
.19231 .46853 L
.18289 .46154 L
.17308 .45355 L
.16069 .44231 L
.15385 .43548 L
.14257 .42308 L
.13462 .41334 L
.12756 .40385 L
.11538 .38511 L
.11509 .38462 L
.10482 .36538 L
.09653 .34615 L
.09615 .34519 L
.09006 .32692 L
.08533 .30769 L
.0823 .28846 L
.08094 .26923 L
.0813 .25 L
.08344 .23077 L
.08748 .21154 L
.09361 .19231 L
.09615 .18586 L
.10211 .17308 L
.11342 .15385 L
.11538 .15098 L
.12829 .13462 L
.13462 .12782 L
.14809 .11538 L
.15385 .11078 L
.17308 .09785 L
.17601 .09615 L
.19231 .08802 L
.21154 .08075 L
.22498 .07692 L
.23077 .07568 L
Mfstroke
.8 g
.25 .11148 m
.26923 .10939 L
.28846 .10942 L
.30769 .11146 L
.3266 .11538 L
.32692 .1155 L
.34615 .12157 L
.36538 .1298 L
.37473 .13462 L
.38462 .1404 L
.40385 .15373 L
.404 .15385 L
.42308 .17037 L
.42582 .17308 L
.44231 .19149 L
.44296 .19231 L
.45665 .21154 L
.46154 .21958 L
.46754 .23077 L
.47601 .25 L
.48077 .26377 L
.48228 .26923 L
.48648 .28846 L
.48866 .30769 L
.48879 .32692 L
.4868 .34615 L
.48251 .36538 L
.48077 .37127 L
.47564 .38462 L
.46568 .40385 L
.46154 .41029 L
.45177 .42308 L
.44231 .43322 L
.43213 .44231 L
.42308 .44912 L
.40385 .46053 L
.40184 .46154 L
.38462 .46859 L
.36538 .47391 L
.34615 .47686 L
.32692 .47764 L
.30769 .47637 L
.28846 .47312 L
.26923 .46784 L
.25243 .46154 L
.25 .46046 L
.23077 .45082 L
.21691 .44231 L
.21154 .43861 L
.19231 .42334 L
.19201 .42308 L
.17308 .40414 L
.17281 .40385 L
.15755 .38462 L
.15385 .37924 L
.14536 .36538 L
.13575 .34615 L
.13462 .34359 L
.12843 .32692 L
.12323 .30769 L
.12007 .28846 L
.11894 .26923 L
.11988 .25 L
.12302 .23077 L
.12859 .21154 L
.13462 .19695 L
.13698 .19231 L
.14881 .17308 L
.15385 .16649 L
.16534 .15385 L
.17308 .14677 L
.18941 .13462 L
.19231 .13281 L
.21154 .12279 L
.23077 .11585 L
.23205 .11538 L
F
0 g
.25 .11148 m
.26923 .10939 L
.28846 .10942 L
.30769 .11146 L
.3266 .11538 L
.32692 .1155 L
.34615 .12157 L
.36538 .1298 L
.37473 .13462 L
.38462 .1404 L
.40385 .15373 L
.404 .15385 L
.42308 .17037 L
.42582 .17308 L
.44231 .19149 L
.44296 .19231 L
.45665 .21154 L
.46154 .21958 L
.46754 .23077 L
.47601 .25 L
.48077 .26377 L
.48228 .26923 L
.48648 .28846 L
.48866 .30769 L
.48879 .32692 L
.4868 .34615 L
.48251 .36538 L
.48077 .37127 L
.47564 .38462 L
.46568 .40385 L
.46154 .41029 L
.45177 .42308 L
.44231 .43322 L
.43213 .44231 L
.42308 .44912 L
.40385 .46053 L
.40184 .46154 L
.38462 .46859 L
.36538 .47391 L
.34615 .47686 L
.32692 .47764 L
.30769 .47637 L
.28846 .47312 L
.26923 .46784 L
.25243 .46154 L
.25 .46046 L
.23077 .45082 L
.21691 .44231 L
.21154 .43861 L
.19231 .42334 L
Mistroke
.19201 .42308 L
.17308 .40414 L
.17281 .40385 L
.15755 .38462 L
.15385 .37924 L
.14536 .36538 L
.13575 .34615 L
.13462 .34359 L
.12843 .32692 L
.12323 .30769 L
.12007 .28846 L
.11894 .26923 L
.11988 .25 L
.12302 .23077 L
.12859 .21154 L
.13462 .19695 L
.13698 .19231 L
.14881 .17308 L
.15385 .16649 L
.16534 .15385 L
.17308 .14677 L
.18941 .13462 L
.19231 .13281 L
.21154 .12279 L
.23077 .11585 L
.23205 .11538 L
.25 .11148 L
Mfstroke
.9 g
.26923 .15145 m
.28846 .15073 L
.30769 .15263 L
.3159 .15385 L
.32692 .1571 L
.34615 .16423 L
.36335 .17308 L
.36538 .17432 L
.38462 .18789 L
.38986 .19231 L
.40385 .20604 L
.40865 .21154 L
.42264 .23077 L
.42308 .23145 L
.43306 .25 L
.44045 .26923 L
.44231 .27392 L
.44513 .28846 L
.4472 .30769 L
.44663 .32692 L
.44321 .34615 L
.44231 .34984 L
.43656 .36538 L
.42581 .38462 L
.42308 .38845 L
.40923 .40385 L
.40385 .40854 L
.38462 .42137 L
.38149 .42308 L
.36538 .42961 L
.34615 .43434 L
.32692 .43612 L
.30769 .43522 L
.28846 .43175 L
.26923 .42566 L
.26278 .42308 L
.25 .41678 L
.23077 .40464 L
.22968 .40385 L
.21154 .38846 L
.2077 .38462 L
.19231 .36637 L
.19159 .36538 L
.17952 .34615 L
.17308 .33292 L
.17072 .32692 L
.16473 .30769 L
.1614 .28846 L
.16067 .26923 L
.16267 .25 L
.16768 .23077 L
.17308 .21746 L
.1763 .21154 L
.18972 .19231 L
.19231 .18939 L
.21091 .17308 L
.21154 .17264 L
.23077 .16176 L
.25 .15499 L
.25473 .15385 L
F
0 g
.26923 .15145 m
.28846 .15073 L
.30769 .15263 L
.3159 .15385 L
.32692 .1571 L
.34615 .16423 L
.36335 .17308 L
.36538 .17432 L
.38462 .18789 L
.38986 .19231 L
.40385 .20604 L
.40865 .21154 L
.42264 .23077 L
.42308 .23145 L
.43306 .25 L
.44045 .26923 L
.44231 .27392 L
.44513 .28846 L
.4472 .30769 L
.44663 .32692 L
.44321 .34615 L
.44231 .34984 L
.43656 .36538 L
.42581 .38462 L
.42308 .38845 L
.40923 .40385 L
.40385 .40854 L
.38462 .42137 L
.38149 .42308 L
.36538 .42961 L
.34615 .43434 L
.32692 .43612 L
.30769 .43522 L
.28846 .43175 L
.26923 .42566 L
.26278 .42308 L
.25 .41678 L
.23077 .40464 L
.22968 .40385 L
.21154 .38846 L
.2077 .38462 L
.19231 .36637 L
.19159 .36538 L
.17952 .34615 L
.17308 .33292 L
.17072 .32692 L
.16473 .30769 L
.1614 .28846 L
.16067 .26923 L
.16267 .25 L
Mistroke
.16768 .23077 L
.17308 .21746 L
.1763 .21154 L
.18972 .19231 L
.19231 .18939 L
.21091 .17308 L
.21154 .17264 L
.23077 .16176 L
.25 .15499 L
.25473 .15385 L
.26923 .15145 L
Mfstroke
1 g
.26923 .20537 m
.28846 .2026 L
.30769 .20408 L
.32692 .20966 L
.33174 .21154 L
.34615 .21961 L
.36053 .23077 L
.36538 .23552 L
.37714 .25 L
.38462 .26236 L
.38754 .26923 L
.39344 .28846 L
.39519 .30769 L
.39266 .32692 L
.38489 .34615 L
.38462 .34665 L
.36927 .36538 L
.36538 .36849 L
.34615 .37908 L
.32692 .38362 L
.30769 .38373 L
.28846 .37983 L
.26923 .37164 L
.25891 .36538 L
.25 .35833 L
.23791 .34615 L
.23077 .33699 L
.22481 .32692 L
.21681 .30769 L
.21311 .28846 L
.2135 .26923 L
.21844 .25 L
.22975 .23077 L
.23077 .22951 L
.25 .21333 L
.25203 .21154 L
F
0 g
.26923 .20537 m
.28846 .2026 L
.30769 .20408 L
.32692 .20966 L
.33174 .21154 L
.34615 .21961 L
.36053 .23077 L
.36538 .23552 L
.37714 .25 L
.38462 .26236 L
.38754 .26923 L
.39344 .28846 L
.39519 .30769 L
.39266 .32692 L
.38489 .34615 L
.38462 .34665 L
.36927 .36538 L
.36538 .36849 L
.34615 .37908 L
.32692 .38362 L
.30769 .38373 L
.28846 .37983 L
.26923 .37164 L
.25891 .36538 L
.25 .35833 L
.23791 .34615 L
.23077 .33699 L
.22481 .32692 L
.21681 .30769 L
.21311 .28846 L
.2135 .26923 L
.21844 .25 L
.22975 .23077 L
.23077 .22951 L
.25 .21333 L
.25203 .21154 L
.26923 .20537 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.522676 0.0238095 0.97619 0.477324 MathSubStart
%% SurfaceGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1.04977 -0.0679587 1.04977 [
[ 0 0 0 0 ]
[ 1 .81114 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.39787 .81114 L
s
.39787 .81114 m
.40529 .59895 L
s
.40529 .59895 m
.03716 .25514 L
s
.68874 0 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.68874 0 m
.03716 .25514 L
s
.40529 .59895 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.39787 .81114 L
s
.39787 .81114 m
.40529 .59895 L
s
0 0 m
1 0 L
1 .81114 L
0 .81114 L
closepath
clip
newpath
.658 .748 .916 r
.39899 .59894 .4051 .6044 .41534 .60143 .40925 .59598 Mtetra
.658 .748 .917 r
.40925 .59598 .41534 .60143 .42562 .59846 .41956 .59301 Mtetra
.657 .749 .918 r
.41956 .59301 .42562 .59846 .43595 .59548 .42991 .59004 Mtetra
.657 .75 .919 r
.42991 .59004 .43595 .59548 .44631 .59249 .44029 .58706 Mtetra
.657 .752 .92 r
.44029 .58706 .44631 .59249 .45671 .5895 .45072 .58408 Mtetra
.657 .753 .921 r
.45072 .58408 .45671 .5895 .46715 .58649 .46119 .58109 Mtetra
.656 .754 .922 r
.46119 .58109 .46715 .58649 .47764 .58348 .4717 .57809 Mtetra
.656 .755 .923 r
.4717 .57809 .47764 .58348 .48816 .58045 .48225 .57508 Mtetra
.656 .756 .924 r
.48225 .57508 .48816 .58045 .49873 .57741 .49285 .57205 Mtetra
.656 .758 .924 r
.49285 .57205 .49873 .57741 .50934 .57435 .50349 .569 Mtetra
.657 .759 .925 r
.50349 .569 .50934 .57435 .51999 .57127 .51416 .56593 Mtetra
.657 .76 .926 r
.51416 .56593 .51999 .57127 .53068 .56817 .52489 .56284 Mtetra
.657 .761 .926 r
.52489 .56284 .53068 .56817 .54142 .56505 .53565 .55972 Mtetra
.658 .762 .927 r
.53565 .55972 .54142 .56505 .5522 .5619 .54646 .55657 Mtetra
.659 .763 .927 r
.54646 .55657 .5522 .5619 .56302 .55873 .55731 .55339 Mtetra
.659 .764 .927 r
.55731 .55339 .56302 .55873 .57388 .55552 .5682 .55017 Mtetra
.66 .765 .927 r
.5682 .55017 .57388 .55552 .58479 .55229 .57914 .54692 Mtetra
.661 .765 .927 r
.57914 .54692 .58479 .55229 .59574 .54902 .59012 .54364 Mtetra
.662 .766 .927 r
.59012 .54364 .59574 .54902 .60673 .54572 .60114 .54031 Mtetra
.663 .766 .926 r
.60114 .54031 .60673 .54572 .61776 .54239 .61221 .53695 Mtetra
.664 .766 .926 r
.61221 .53695 .61776 .54239 .62884 .53903 .62332 .53355 Mtetra
.665 .766 .925 r
.62332 .53355 .62884 .53903 .63996 .53564 .63447 .53012 Mtetra
.665 .765 .925 r
.63447 .53012 .63996 .53564 .65112 .53222 .64566 .52666 Mtetra
.666 .765 .924 r
.64566 .52666 .65112 .53222 .66233 .52877 .6569 .52316 Mtetra
.667 .764 .923 r
.6569 .52316 .66233 .52877 .67358 .5253 .66819 .51963 Mtetra
.667 .763 .922 r
.66819 .51963 .67358 .5253 .68487 .5218 .67951 .51608 Mtetra
.668 .762 .921 r
.67951 .51608 .68487 .5218 .69621 .51828 .69088 .5125 Mtetra
.668 .761 .92 r
.69088 .5125 .69621 .51828 .7076 .51474 .7023 .50889 Mtetra
.668 .76 .919 r
.7023 .50889 .7076 .51474 .71902 .51118 .71376 .50527 Mtetra
.668 .759 .918 r
.71376 .50527 .71902 .51118 .7305 .5076 .72526 .50163 Mtetra
.668 .757 .917 r
.72526 .50163 .7305 .5076 .74201 .50401 .73681 .49798 Mtetra
.668 .756 .916 r
.73681 .49798 .74201 .50401 .75358 .50041 .74841 .49432 Mtetra
.668 .755 .915 r
.74841 .49432 .75358 .50041 .76519 .4968 .76005 .49065 Mtetra
.668 .754 .914 r
.76005 .49065 .76519 .4968 .77685 .49318 .77174 .48697 Mtetra
.668 .752 .914 r
.77174 .48697 .77685 .49318 .78855 .48955 .78347 .48328 Mtetra
.668 .751 .913 r
.78347 .48328 .78855 .48955 .8003 .48592 .79526 .47959 Mtetra
.667 .75 .912 r
.79526 .47959 .8003 .48592 .8121 .48227 .80709 .47589 Mtetra
.667 .749 .912 r
.80709 .47589 .8121 .48227 .82395 .47862 .81897 .47219 Mtetra
.667 .748 .911 r
.81897 .47219 .82395 .47862 .83585 .47497 .8309 .46848 Mtetra
.666 .747 .911 r
.8309 .46848 .83585 .47497 .84779 .47131 .84288 .46477 Mtetra
.666 .746 .91 r
.84288 .46477 .84779 .47131 .85979 .46764 .85491 .46106 Mtetra
.85491 .46106 .85979 .46764 .87183 .46396 .86699 .45734 Mtetra
.666 .745 .909 r
.86699 .45734 .87183 .46396 .88393 .46028 .87912 .45361 Mtetra
.665 .744 .909 r
.87912 .45361 .88393 .46028 .89607 .45659 .89131 .44988 Mtetra
.89131 .44988 .89607 .45659 .90827 .45289 .90354 .44614 Mtetra
.665 .743 .909 r
.90354 .44614 .90827 .45289 .92052 .44918 .91582 .4424 Mtetra
.91582 .4424 .92052 .44918 .93282 .44547 .92816 .43864 Mtetra
.664 .743 .908 r
.92816 .43864 .93282 .44547 .94517 .44174 .94055 .43488 Mtetra
.664 .742 .908 r
.94055 .43488 .94517 .44174 .95758 .43799 .95299 .4311 Mtetra
.95299 .4311 .95758 .43799 .97003 .43424 .96549 .42732 Mtetra
.657 .749 .918 r
.39283 .59349 .39899 .59894 .40925 .59598 .40312 .59054 Mtetra
.656 .75 .919 r
.40312 .59054 .40925 .59598 .41956 .59301 .41345 .58759 Mtetra
.656 .751 .92 r
.41345 .58759 .41956 .59301 .42991 .59004 .42382 .58464 Mtetra
.655 .753 .921 r
.42382 .58464 .42991 .59004 .44029 .58706 .43423 .58168 Mtetra
.655 .754 .923 r
.43423 .58168 .44029 .58706 .45072 .58408 .44469 .57872 Mtetra
.655 .755 .924 r
.44469 .57872 .45072 .58408 .46119 .58109 .45518 .57575 Mtetra
.654 .757 .925 r
.45518 .57575 .46119 .58109 .4717 .57809 .46572 .57278 Mtetra
.654 .759 .926 r
.46572 .57278 .4717 .57809 .48225 .57508 .4763 .56978 Mtetra
.654 .76 .927 r
.4763 .56978 .48225 .57508 .49285 .57205 .48692 .56677 Mtetra
.654 .762 .928 r
.48692 .56677 .49285 .57205 .50349 .569 .49759 .56375 Mtetra
.655 .763 .929 r
.49759 .56375 .50349 .569 .51416 .56593 .50829 .56069 Mtetra
.655 .765 .93 r
.50829 .56069 .51416 .56593 .52489 .56284 .51905 .55761 Mtetra
.656 .766 .931 r
.51905 .55761 .52489 .56284 .53565 .55972 .52984 .5545 Mtetra
.656 .767 .931 r
.52984 .5545 .53565 .55972 .54646 .55657 .54068 .55135 Mtetra
.657 .769 .932 r
.54068 .55135 .54646 .55657 .55731 .55339 .55156 .54817 Mtetra
.658 .77 .932 r
.55156 .54817 .55731 .55339 .5682 .55017 .56248 .54494 Mtetra
.659 .771 .932 r
.56248 .54494 .5682 .55017 .57914 .54692 .57345 .54168 Mtetra
.66 .771 .932 r
.57345 .54168 .57914 .54692 .59012 .54364 .58446 .53837 Mtetra
.661 .772 .931 r
.58446 .53837 .59012 .54364 .60114 .54031 .59552 .53502 Mtetra
.663 .772 .931 r
.59552 .53502 .60114 .54031 .61221 .53695 .60662 .53163 Mtetra
.664 .772 .93 r
.60662 .53163 .61221 .53695 .62332 .53355 .61776 .52819 Mtetra
.665 .772 .929 r
.61776 .52819 .62332 .53355 .63447 .53012 .62894 .52472 Mtetra
.666 .771 .928 r
.62894 .52472 .63447 .53012 .64566 .52666 .64017 .5212 Mtetra
.667 .77 .927 r
.64017 .5212 .64566 .52666 .6569 .52316 .65144 .51764 Mtetra
.668 .769 .926 r
.65144 .51764 .6569 .52316 .66819 .51963 .66276 .51406 Mtetra
.668 .768 .925 r
.66276 .51406 .66819 .51963 .67951 .51608 .67411 .51044 Mtetra
.669 .767 .924 r
.67411 .51044 .67951 .51608 .69088 .5125 .68552 .50679 Mtetra
.669 .766 .923 r
.68552 .50679 .69088 .5125 .7023 .50889 .69696 .50312 Mtetra
.67 .764 .921 r
.69696 .50312 .7023 .50889 .71376 .50527 .70845 .49943 Mtetra
.67 .763 .92 r
.70845 .49943 .71376 .50527 .72526 .50163 .71999 .49572 Mtetra
.67 .761 .919 r
.71999 .49572 .72526 .50163 .73681 .49798 .73157 .49199 Mtetra
.67 .76 .918 r
.73157 .49199 .73681 .49798 .74841 .49432 .7432 .48826 Mtetra
.67 .758 .917 r
.7432 .48826 .74841 .49432 .76005 .49065 .75487 .48452 Mtetra
.669 .756 .916 r
.75487 .48452 .76005 .49065 .77174 .48697 .7666 .48077 Mtetra
.669 .755 .915 r
.7666 .48077 .77174 .48697 .78347 .48328 .77836 .47701 Mtetra
.669 .753 .914 r
.77836 .47701 .78347 .48328 .79526 .47959 .79018 .47326 Mtetra
.668 .752 .913 r
.79018 .47326 .79526 .47959 .80709 .47589 .80205 .4695 Mtetra
.668 .751 .912 r
.80205 .4695 .80709 .47589 .81897 .47219 .81396 .46574 Mtetra
.668 .75 .912 r
.81396 .46574 .81897 .47219 .8309 .46848 .82593 .46197 Mtetra
.667 .748 .911 r
.82593 .46197 .8309 .46848 .84288 .46477 .83794 .45821 Mtetra
.667 .747 .911 r
.83794 .45821 .84288 .46477 .85491 .46106 .85 .45445 Mtetra
.666 .747 .91 r
.85 .45445 .85491 .46106 .86699 .45734 .86212 .45068 Mtetra
.666 .746 .91 r
.86212 .45068 .86699 .45734 .87912 .45361 .87428 .44691 Mtetra
.666 .745 .909 r
.87428 .44691 .87912 .45361 .89131 .44988 .8865 .44313 Mtetra
.665 .744 .909 r
.8865 .44313 .89131 .44988 .90354 .44614 .89877 .43935 Mtetra
.89877 .43935 .90354 .44614 .91582 .4424 .91109 .43557 Mtetra
.665 .743 .909 r
.91109 .43557 .91582 .4424 .92816 .43864 .92347 .43178 Mtetra
.92347 .43178 .92816 .43864 .94055 .43488 .93589 .42797 Mtetra
.664 .743 .908 r
.93589 .42797 .94055 .43488 .95299 .4311 .94837 .42416 Mtetra
.664 .742 .908 r
.94837 .42416 .95299 .4311 .96549 .42732 .9609 .42034 Mtetra
.655 .751 .92 r
.38662 .58806 .39283 .59349 .40312 .59054 .39694 .58513 Mtetra
.654 .752 .922 r
.39694 .58513 .40312 .59054 .41345 .58759 .40729 .58221 Mtetra
.654 .754 .923 r
.40729 .58221 .41345 .58759 .42382 .58464 .41769 .57929 Mtetra
.653 .755 .925 r
.41769 .57929 .42382 .58464 .43423 .58168 .42812 .57636 Mtetra
.652 .757 .926 r
.42812 .57636 .43423 .58168 .44469 .57872 .4386 .57343 Mtetra
.652 .759 .928 r
.4386 .57343 .44469 .57872 .45518 .57575 .44912 .57049 Mtetra
.652 .761 .929 r
.44912 .57049 .45518 .57575 .46572 .57278 .45969 .56755 Mtetra
.651 .763 .931 r
.45969 .56755 .46572 .57278 .4763 .56978 .4703 .56459 Mtetra
.651 .764 .932 r
.4703 .56459 .4763 .56978 .48692 .56677 .48095 .56161 Mtetra
.652 .766 .933 r
.48095 .56161 .48692 .56677 .49759 .56375 .49164 .55861 Mtetra
.652 .768 .934 r
.49164 .55861 .49759 .56375 .50829 .56069 .50238 .55558 Mtetra
.652 .77 .935 r
.50238 .55558 .50829 .56069 .51905 .55761 .51316 .55251 Mtetra
.653 .772 .936 r
.51316 .55251 .51905 .55761 .52984 .5545 .52398 .54942 Mtetra
.654 .774 .937 r
.52398 .54942 .52984 .5545 .54068 .55135 .53485 .54628 Mtetra
.655 .775 .937 r
.53485 .54628 .54068 .55135 .55156 .54817 .54576 .5431 Mtetra
.656 .776 .937 r
.54576 .5431 .55156 .54817 .56248 .54494 .55672 .53987 Mtetra
.658 .777 .937 r
.55672 .53987 .56248 .54494 .57345 .54168 .56772 .53659 Mtetra
.659 .778 .937 r
.56772 .53659 .57345 .54168 .58446 .53837 .57877 .53327 Mtetra
.661 .779 .936 r
.57877 .53327 .58446 .53837 .59552 .53502 .58985 .52989 Mtetra
.662 .779 .936 r
.58985 .52989 .59552 .53502 .60662 .53163 .60098 .52646 Mtetra
.664 .779 .935 r
.60098 .52646 .60662 .53163 .61776 .52819 .61216 .52298 Mtetra
.665 .779 .934 r
.61216 .52298 .61776 .52819 .62894 .52472 .62338 .51945 Mtetra
.666 .778 .933 r
.62338 .51945 .62894 .52472 .64017 .5212 .63464 .51587 Mtetra
.667 .777 .931 r
.63464 .51587 .64017 .5212 .65144 .51764 .64594 .51226 Mtetra
.669 .776 .93 r
.64594 .51226 .65144 .51764 .66276 .51406 .65729 .5086 Mtetra
.669 .775 .929 r
.65729 .5086 .66276 .51406 .67411 .51044 .66868 .50491 Mtetra
.67 .773 .927 r
.66868 .50491 .67411 .51044 .68552 .50679 .68011 .50118 Mtetra
.671 .771 .926 r
.68011 .50118 .68552 .50679 .69696 .50312 .69159 .49743 Mtetra
.671 .77 .924 r
.69159 .49743 .69696 .50312 .70845 .49943 .70312 .49366 Mtetra
.671 .768 .923 r
.70312 .49366 .70845 .49943 .71999 .49572 .71469 .48987 Mtetra
.672 .766 .921 r
.71469 .48987 .71999 .49572 .73157 .49199 .7263 .48606 Mtetra
.671 .764 .92 r
.7263 .48606 .73157 .49199 .7432 .48826 .73796 .48224 Mtetra
.671 .762 .918 r
.73796 .48224 .7432 .48826 .75487 .48452 .74967 .47842 Mtetra
.671 .76 .917 r
.74967 .47842 .75487 .48452 .7666 .48077 .76142 .47459 Mtetra
.671 .758 .916 r
.76142 .47459 .7666 .48077 .77836 .47701 .77322 .47076 Mtetra
.67 .756 .915 r
.77322 .47076 .77836 .47701 .79018 .47326 .78507 .46693 Mtetra
.67 .755 .914 r
.78507 .46693 .79018 .47326 .80205 .4695 .79697 .46311 Mtetra
.669 .753 .913 r
.79697 .46311 .80205 .4695 .81396 .46574 .80891 .45928 Mtetra
.669 .751 .912 r
.80891 .45928 .81396 .46574 .82593 .46197 .82091 .45546 Mtetra
.668 .75 .912 r
.82091 .45546 .82593 .46197 .83794 .45821 .83296 .45163 Mtetra
.668 .749 .911 r
.83296 .45163 .83794 .45821 .85 .45445 .84506 .44781 Mtetra
.667 .748 .911 r
.84506 .44781 .85 .45445 .86212 .45068 .85721 .44399 Mtetra
.667 .747 .91 r
.85721 .44399 .86212 .45068 .87428 .44691 .86941 .44017 Mtetra
.666 .746 .91 r
.86941 .44017 .87428 .44691 .8865 .44313 .88166 .43635 Mtetra
.666 .745 .909 r
.88166 .43635 .8865 .44313 .89877 .43935 .89397 .43252 Mtetra
.666 .744 .909 r
.89397 .43252 .89877 .43935 .91109 .43557 .90632 .4287 Mtetra
.665 .744 .909 r
.90632 .4287 .91109 .43557 .92347 .43178 .91874 .42486 Mtetra
.665 .743 .909 r
.91874 .42486 .92347 .43178 .93589 .42797 .9312 .42102 Mtetra
.9312 .42102 .93589 .42797 .94837 .42416 .94372 .41717 Mtetra
.664 .743 .908 r
.94372 .41717 .94837 .42416 .9609 .42034 .95629 .41331 Mtetra
.653 .753 .923 r
.38037 .58267 .38662 .58806 .39694 .58513 .3907 .57978 Mtetra
.652 .755 .925 r
.3907 .57978 .39694 .58513 .40729 .58221 .40108 .57689 Mtetra
.651 .756 .927 r
.40108 .57689 .40729 .58221 .41769 .57929 .4115 .574 Mtetra
.65 .758 .929 r
.4115 .574 .41769 .57929 .42812 .57636 .42197 .57112 Mtetra
.649 .76 .931 r
.42197 .57112 .42812 .57636 .4386 .57343 .43247 .56823 Mtetra
.649 .763 .932 r
.43247 .56823 .4386 .57343 .44912 .57049 .44302 .56534 Mtetra
.648 .765 .934 r
.44302 .56534 .44912 .57049 .45969 .56755 .45361 .56243 Mtetra
.648 .767 .936 r
.45361 .56243 .45969 .56755 .4703 .56459 .46424 .55952 Mtetra
.648 .77 .937 r
.46424 .55952 .4703 .56459 .48095 .56161 .47492 .55658 Mtetra
.648 .772 .939 r
.47492 .55658 .48095 .56161 .49164 .55861 .48564 .55361 Mtetra
.648 .774 .94 r
.48564 .55361 .49164 .55861 .50238 .55558 .49641 .55062 Mtetra
.649 .777 .941 r
.49641 .55062 .50238 .55558 .51316 .55251 .50722 .54758 Mtetra
.65 .779 .942 r
.50722 .54758 .51316 .55251 .52398 .54942 .51808 .54451 Mtetra
.651 .781 .943 r
.51808 .54451 .52398 .54942 .53485 .54628 .52898 .54138 Mtetra
.652 .783 .943 r
.52898 .54138 .53485 .54628 .54576 .5431 .53993 .53821 Mtetra
.654 .784 .943 r
.53993 .53821 .54576 .5431 .55672 .53987 .55091 .53498 Mtetra
.656 .785 .943 r
.55091 .53498 .55672 .53987 .56772 .53659 .56195 .53169 Mtetra
.658 .786 .943 r
.56195 .53169 .56772 .53659 .57877 .53327 .57303 .52834 Mtetra
.659 .787 .942 r
.57303 .52834 .57877 .53327 .58985 .52989 .58415 .52494 Mtetra
.661 .787 .941 r
.58415 .52494 .58985 .52989 .60098 .52646 .59531 .52147 Mtetra
.663 .787 .94 r
.59531 .52147 .60098 .52646 .61216 .52298 .60652 .51794 Mtetra
.665 .787 .939 r
.60652 .51794 .61216 .52298 .62338 .51945 .61777 .51435 Mtetra
.667 .786 .938 r
.61777 .51435 .62338 .51945 .63464 .51587 .62907 .51071 Mtetra
.668 .785 .936 r
.62907 .51071 .63464 .51587 .64594 .51226 .6404 .50702 Mtetra
.67 .784 .934 r
.6404 .50702 .64594 .51226 .65729 .5086 .65178 .50329 Mtetra
.671 .782 .933 r
.65178 .50329 .65729 .5086 .66868 .50491 .66321 .49951 Mtetra
.672 .78 .931 r
.66321 .49951 .66868 .50491 .68011 .50118 .67468 .4957 Mtetra
.673 .778 .929 r
.67468 .4957 .68011 .50118 .69159 .49743 .68619 .49185 Mtetra
.673 .776 .927 r
.68619 .49185 .69159 .49743 .70312 .49366 .69774 .48799 Mtetra
.673 .773 .925 r
.69774 .48799 .70312 .49366 .71469 .48987 .70935 .4841 Mtetra
.674 .771 .924 r
.70935 .4841 .71469 .48987 .7263 .48606 .72099 .4802 Mtetra
.674 .769 .922 r
.72099 .4802 .7263 .48606 .73796 .48224 .73268 .47629 Mtetra
.673 .766 .92 r
.73268 .47629 .73796 .48224 .74967 .47842 .74442 .47238 Mtetra
.673 .764 .919 r
.74442 .47238 .74967 .47842 .76142 .47459 .75621 .46846 Mtetra
.672 .762 .918 r
.75621 .46846 .76142 .47459 .77322 .47076 .76804 .46454 Mtetra
.672 .759 .916 r
.76804 .46454 .77322 .47076 .78507 .46693 .77992 .46063 Mtetra
.671 .757 .915 r
.77992 .46063 .78507 .46693 .79697 .46311 .79185 .45673 Mtetra
.671 .755 .914 r
.79185 .45673 .79697 .46311 .80891 .45928 .80383 .45282 Mtetra
.67 .754 .913 r
.80383 .45282 .80891 .45928 .82091 .45546 .81586 .44893 Mtetra
.669 .752 .912 r
.81586 .44893 .82091 .45546 .83296 .45163 .82794 .44504 Mtetra
.669 .75 .912 r
.82794 .44504 .83296 .45163 .84506 .44781 .84008 .44116 Mtetra
.668 .749 .911 r
.84008 .44116 .84506 .44781 .85721 .44399 .85226 .43728 Mtetra
.668 .748 .911 r
.85226 .43728 .85721 .44399 .86941 .44017 .8645 .4334 Mtetra
.667 .747 .91 r
.8645 .4334 .86941 .44017 .88166 .43635 .87678 .42953 Mtetra
.666 .746 .91 r
.87678 .42953 .88166 .43635 .89397 .43252 .88913 .42566 Mtetra
.666 .745 .909 r
.88913 .42566 .89397 .43252 .90632 .4287 .90152 .42178 Mtetra
.666 .744 .909 r
.90152 .42178 .90632 .4287 .91874 .42486 .91397 .4179 Mtetra
.665 .744 .909 r
.91397 .4179 .91874 .42486 .9312 .42102 .92647 .41402 Mtetra
.665 .743 .909 r
.92647 .41402 .9312 .42102 .94372 .41717 .93903 .41013 Mtetra
.665 .743 .908 r
.93903 .41013 .94372 .41717 .95629 .41331 .95164 .40624 Mtetra
.65 .755 .927 r
.37406 .57733 .38037 .58267 .3907 .57978 .38442 .57448 Mtetra
.648 .758 .929 r
.38442 .57448 .3907 .57978 .40108 .57689 .39483 .57164 Mtetra
.647 .76 .931 r
.39483 .57164 .40108 .57689 .4115 .574 .40527 .5688 Mtetra
.646 .762 .933 r
.40527 .5688 .4115 .574 .42197 .57112 .41576 .56597 Mtetra
.645 .765 .936 r
.41576 .56597 .42197 .57112 .43247 .56823 .42629 .56314 Mtetra
.644 .767 .938 r
.42629 .56314 .43247 .56823 .44302 .56534 .43686 .56031 Mtetra
.644 .77 .94 r
.43686 .56031 .44302 .56534 .45361 .56243 .44748 .55746 Mtetra
.643 .773 .942 r
.44748 .55746 .45361 .56243 .46424 .55952 .45814 .5546 Mtetra
.643 .776 .944 r
.45814 .5546 .46424 .55952 .47492 .55658 .46885 .55171 Mtetra
.643 .779 .946 r
.46885 .55171 .47492 .55658 .48564 .55361 .4796 .5488 Mtetra
.644 .781 .947 r
.4796 .5488 .48564 .55361 .49641 .55062 .4904 .54584 Mtetra
.645 .784 .948 r
.4904 .54584 .49641 .55062 .50722 .54758 .50124 .54285 Mtetra
.646 .787 .949 r
.50124 .54285 .50722 .54758 .51808 .54451 .51213 .5398 Mtetra
.647 .789 .95 r
.51213 .5398 .51808 .54451 .52898 .54138 .52306 .5367 Mtetra
.649 .791 .95 r
.52306 .5367 .52898 .54138 .53993 .53821 .53404 .53354 Mtetra
.651 .793 .951 r
.53404 .53354 .53993 .53821 .55091 .53498 .54506 .53031 Mtetra
.653 .795 .95 r
.54506 .53031 .55091 .53498 .56195 .53169 .55613 .52702 Mtetra
.655 .796 .95 r
.55613 .52702 .56195 .53169 .57303 .52834 .56724 .52365 Mtetra
.658 .797 .949 r
.56724 .52365 .57303 .52834 .58415 .52494 .5784 .52021 Mtetra
.66 .797 .948 r
.5784 .52021 .58415 .52494 .59531 .52147 .5896 .5167 Mtetra
.663 .797 .947 r
.5896 .5167 .59531 .52147 .60652 .51794 .60084 .51311 Mtetra
.665 .797 .945 r
.60084 .51311 .60652 .51794 .61777 .51435 .61213 .50946 Mtetra
.667 .796 .943 r
.61213 .50946 .61777 .51435 .62907 .51071 .62346 .50575 Mtetra
.669 .794 .941 r
.62346 .50575 .62907 .51071 .6404 .50702 .63483 .50198 Mtetra
.671 .793 .939 r
.63483 .50198 .6404 .50702 .65178 .50329 .64624 .49815 Mtetra
.673 .791 .937 r
.64624 .49815 .65178 .50329 .66321 .49951 .6577 .49427 Mtetra
.674 .788 .935 r
.6577 .49427 .66321 .49951 .67468 .4957 .6692 .49036 Mtetra
.675 .786 .933 r
.6692 .49036 .67468 .4957 .68619 .49185 .68075 .48641 Mtetra
.676 .783 .931 r
.68075 .48641 .68619 .49185 .69774 .48799 .69234 .48244 Mtetra
.676 .78 .929 r
.69234 .48244 .69774 .48799 .70935 .4841 .70397 .47844 Mtetra
.676 .777 .926 r
.70397 .47844 .70935 .4841 .72099 .4802 .71565 .47443 Mtetra
.676 .774 .924 r
.71565 .47443 .72099 .4802 .73268 .47629 .72737 .47041 Mtetra
.676 .771 .923 r
.72737 .47041 .73268 .47629 .74442 .47238 .73914 .46639 Mtetra
.675 .769 .921 r
.73914 .46639 .74442 .47238 .75621 .46846 .75096 .46238 Mtetra
.675 .766 .919 r
.75096 .46238 .75621 .46846 .76804 .46454 .76283 .45836 Mtetra
.674 .763 .918 r
.76283 .45836 .76804 .46454 .77992 .46063 .77474 .45436 Mtetra
.673 .761 .916 r
.77474 .45436 .77992 .46063 .79185 .45673 .7867 .45036 Mtetra
.672 .758 .915 r
.7867 .45036 .79185 .45673 .80383 .45282 .79872 .44638 Mtetra
.672 .756 .914 r
.79872 .44638 .80383 .45282 .81586 .44893 .81078 .4424 Mtetra
.671 .754 .913 r
.81078 .4424 .81586 .44893 .82794 .44504 .82289 .43844 Mtetra
.67 .752 .912 r
.82289 .43844 .82794 .44504 .84008 .44116 .83506 .43449 Mtetra
.669 .751 .912 r
.83506 .43449 .84008 .44116 .85226 .43728 .84728 .43054 Mtetra
.668 .749 .911 r
.84728 .43054 .85226 .43728 .8645 .4334 .85955 .42661 Mtetra
.668 .748 .91 r
.85955 .42661 .8645 .4334 .87678 .42953 .87187 .42268 Mtetra
.667 .747 .91 r
.87187 .42268 .87678 .42953 .88913 .42566 .88425 .41875 Mtetra
.667 .746 .91 r
.88425 .41875 .88913 .42566 .90152 .42178 .89668 .41483 Mtetra
.666 .745 .909 r
.89668 .41483 .90152 .42178 .91397 .4179 .90917 .4109 Mtetra
.666 .744 .909 r
.90917 .4109 .91397 .4179 .92647 .41402 .92171 .40698 Mtetra
.665 .744 .909 r
.92171 .40698 .92647 .41402 .93903 .41013 .9343 .40305 Mtetra
.665 .743 .909 r
.9343 .40305 .93903 .41013 .95164 .40624 .94695 .39911 Mtetra
.646 .758 .931 r
.3677 .57206 .37406 .57733 .38442 .57448 .37809 .56927 Mtetra
.644 .761 .934 r
.37809 .56927 .38442 .57448 .39483 .57164 .38851 .56649 Mtetra
.643 .763 .936 r
.38851 .56649 .39483 .57164 .40527 .5688 .39898 .56372 Mtetra
.641 .766 .939 r
.39898 .56372 .40527 .5688 .41576 .56597 .40949 .56095 Mtetra
.64 .769 .941 r
.40949 .56095 .41576 .56597 .42629 .56314 .42005 .55819 Mtetra
.639 .772 .944 r
.42005 .55819 .42629 .56314 .43686 .56031 .43065 .55543 Mtetra
.638 .776 .947 r
.43065 .55543 .43686 .56031 .44748 .55746 .44129 .55265 Mtetra
.637 .779 .949 r
.44129 .55265 .44748 .55746 .45814 .5546 .45198 .54986 Mtetra
.637 .783 .951 r
.45198 .54986 .45814 .5546 .46885 .55171 .46272 .54704 Mtetra
.637 .786 .953 r
.46272 .54704 .46885 .55171 .4796 .5488 .4735 .54419 Mtetra
.638 .79 .955 r
.4735 .54419 .4796 .5488 .4904 .54584 .48433 .5413 Mtetra
.639 .793 .956 r
.48433 .5413 .4904 .54584 .50124 .54285 .4952 .53835 Mtetra
.64 .796 .957 r
.4952 .53835 .50124 .54285 .51213 .5398 .50612 .53535 Mtetra
.642 .799 .958 r
.50612 .53535 .51213 .5398 .52306 .5367 .51709 .53228 Mtetra
.644 .802 .959 r
.51709 .53228 .52306 .5367 .53404 .53354 .5281 .52913 Mtetra
.646 .804 .959 r
.5281 .52913 .53404 .53354 .54506 .53031 .53916 .52591 Mtetra
.649 .806 .958 r
.53916 .52591 .54506 .53031 .55613 .52702 .55026 .52261 Mtetra
.652 .807 .958 r
.55026 .52261 .55613 .52702 .56724 .52365 .56141 .51922 Mtetra
.655 .808 .957 r
.56141 .51922 .56724 .52365 .5784 .52021 .57261 .51574 Mtetra
.659 .809 .955 r
.57261 .51574 .5784 .52021 .5896 .5167 .58384 .51218 Mtetra
.662 .809 .954 r
.58384 .51218 .5896 .5167 .60084 .51311 .59512 .50854 Mtetra
.665 .808 .952 r
.59512 .50854 .60084 .51311 .61213 .50946 .60644 .50482 Mtetra
.668 .807 .949 r
.60644 .50482 .61213 .50946 .62346 .50575 .61781 .50102 Mtetra
.67 .805 .947 r
.61781 .50102 .62346 .50575 .63483 .50198 .62922 .49715 Mtetra
.673 .803 .945 r
.62922 .49715 .63483 .50198 .64624 .49815 .64067 .49322 Mtetra
.675 .801 .942 r
.64067 .49322 .64624 .49815 .6577 .49427 .65216 .48923 Mtetra
.676 .798 .94 r
.65216 .48923 .6577 .49427 .6692 .49036 .66369 .4852 Mtetra
.678 .795 .937 r
.66369 .4852 .6692 .49036 .68075 .48641 .67527 .48113 Mtetra
.678 .791 .934 r
.67527 .48113 .68075 .48641 .69234 .48244 .6869 .47703 Mtetra
.679 .788 .932 r
.6869 .47703 .69234 .48244 .70397 .47844 .69856 .47291 Mtetra
.679 .784 .93 r
.69856 .47291 .70397 .47844 .71565 .47443 .71027 .46877 Mtetra
.679 .781 .927 r
.71027 .46877 .71565 .47443 .72737 .47041 .72203 .46463 Mtetra
.679 .777 .925 r
.72203 .46463 .72737 .47041 .73914 .46639 .73383 .46049 Mtetra
.678 .774 .923 r
.73383 .46049 .73914 .46639 .75096 .46238 .74568 .45636 Mtetra
.677 .771 .921 r
.74568 .45636 .75096 .46238 .76283 .45836 .75758 .45223 Mtetra
.676 .767 .919 r
.75758 .45223 .76283 .45836 .77474 .45436 .76952 .44812 Mtetra
.675 .764 .918 r
.76952 .44812 .77474 .45436 .7867 .45036 .78152 .44402 Mtetra
.674 .762 .916 r
.78152 .44402 .7867 .45036 .79872 .44638 .79356 .43994 Mtetra
.673 .759 .915 r
.79356 .43994 .79872 .44638 .81078 .4424 .80566 .43588 Mtetra
.672 .757 .914 r
.80566 .43588 .81078 .4424 .82289 .43844 .81781 .43183 Mtetra
.671 .755 .913 r
.81781 .43183 .82289 .43844 .83506 .43449 .83001 .4278 Mtetra
.67 .753 .912 r
.83001 .4278 .83506 .43449 .84728 .43054 .84226 .42379 Mtetra
.67 .751 .911 r
.84226 .42379 .84728 .43054 .85955 .42661 .85456 .41979 Mtetra
.669 .749 .911 r
.85456 .41979 .85955 .42661 .87187 .42268 .86692 .41579 Mtetra
.668 .748 .91 r
.86692 .41579 .87187 .42268 .88425 .41875 .87934 .41181 Mtetra
.667 .747 .91 r
.87934 .41181 .88425 .41875 .89668 .41483 .8918 .40783 Mtetra
.667 .746 .909 r
.8918 .40783 .89668 .41483 .90917 .4109 .90433 .40386 Mtetra
.666 .745 .909 r
.90433 .40386 .90917 .4109 .92171 .40698 .9169 .39989 Mtetra
.666 .744 .909 r
.9169 .39989 .92171 .40698 .9343 .40305 .92954 .39591 Mtetra
.665 .744 .909 r
.92954 .39591 .9343 .40305 .94695 .39911 .94222 .39193 Mtetra
.641 .762 .936 r
.36129 .56687 .3677 .57206 .37809 .56927 .3717 .56415 Mtetra
.639 .765 .939 r
.3717 .56415 .37809 .56927 .38851 .56649 .38215 .56145 Mtetra
.637 .768 .942 r
.38215 .56145 .38851 .56649 .39898 .56372 .39264 .55876 Mtetra
.635 .771 .945 r
.39264 .55876 .39898 .56372 .40949 .56095 .40318 .55608 Mtetra
.633 .775 .948 r
.40318 .55608 .40949 .56095 .42005 .55819 .41376 .55341 Mtetra
.632 .778 .951 r
.41376 .55341 .42005 .55819 .43065 .55543 .42438 .55073 Mtetra
.631 .782 .954 r
.42438 .55073 .43065 .55543 .44129 .55265 .43505 .54805 Mtetra
.63 .786 .957 r
.43505 .54805 .44129 .55265 .45198 .54986 .44577 .54534 Mtetra
.629 .791 .959 r
.44577 .54534 .45198 .54986 .46272 .54704 .45654 .54261 Mtetra
.629 .795 .962 r
.45654 .54261 .46272 .54704 .4735 .54419 .46735 .53984 Mtetra
.63 .799 .964 r
.46735 .53984 .4735 .54419 .48433 .5413 .47821 .53701 Mtetra
.631 .803 .965 r
.47821 .53701 .48433 .5413 .4952 .53835 .48911 .53413 Mtetra
.632 .807 .966 r
.48911 .53413 .4952 .53835 .50612 .53535 .50007 .53118 Mtetra
.635 .81 .967 r
.50007 .53118 .50612 .53535 .51709 .53228 .51107 .52814 Mtetra
.637 .813 .967 r
.51107 .52814 .51709 .53228 .5281 .52913 .52212 .52503 Mtetra
.64 .816 .967 r
.52212 .52503 .5281 .52913 .53916 .52591 .53321 .52181 Mtetra
.644 .818 .967 r
.53321 .52181 .53916 .52591 .55026 .52261 .54435 .51851 Mtetra
.648 .82 .966 r
.54435 .51851 .55026 .52261 .56141 .51922 .55554 .5151 Mtetra
.652 .821 .965 r
.55554 .5151 .56141 .51922 .57261 .51574 .56677 .51158 Mtetra
.656 .822 .963 r
.56677 .51158 .57261 .51574 .58384 .51218 .57804 .50797 Mtetra
.66 .822 .961 r
.57804 .50797 .58384 .51218 .59512 .50854 .58936 .50426 Mtetra
.664 .821 .959 r
.58936 .50426 .59512 .50854 .60644 .50482 .60072 .50045 Mtetra
.668 .819 .956 r
.60072 .50045 .60644 .50482 .61781 .50102 .61212 .49655 Mtetra
.672 .817 .953 r
.61212 .49655 .61781 .50102 .62922 .49715 .62356 .49257 Mtetra
.674 .815 .951 r
.62356 .49257 .62922 .49715 .64067 .49322 .63505 .48852 Mtetra
.677 .812 .948 r
.63505 .48852 .64067 .49322 .65216 .48923 .64658 .48441 Mtetra
.679 .809 .945 r
.64658 .48441 .65216 .48923 .66369 .4852 .65815 .48024 Mtetra
.681 .805 .941 r
.65815 .48024 .66369 .4852 .67527 .48113 .66976 .47603 Mtetra
.682 .801 .939 r
.66976 .47603 .67527 .48113 .6869 .47703 .68142 .47179 Mtetra
.682 .797 .936 r
.68142 .47179 .6869 .47703 .69856 .47291 .69312 .46752 Mtetra
.683 .793 .933 r
.69312 .46752 .69856 .47291 .71027 .46877 .70486 .46325 Mtetra
.682 .788 .93 r
.70486 .46325 .71027 .46877 .72203 .46463 .71665 .45897 Mtetra
.682 .784 .928 r
.71665 .45897 .72203 .46463 .73383 .46049 .72848 .45469 Mtetra
.681 .78 .925 r
.72848 .45469 .73383 .46049 .74568 .45636 .74036 .45042 Mtetra
.68 .776 .923 r
.74036 .45042 .74568 .45636 .75758 .45223 .75229 .44617 Mtetra
.679 .772 .921 r
.75229 .44617 .75758 .45223 .76952 .44812 .76427 .44193 Mtetra
.678 .769 .919 r
.76427 .44193 .76952 .44812 .78152 .44402 .7763 .43772 Mtetra
.677 .765 .918 r
.7763 .43772 .78152 .44402 .79356 .43994 .78838 .43353 Mtetra
.676 .762 .916 r
.78838 .43353 .79356 .43994 .80566 .43588 .8005 .42937 Mtetra
.674 .76 .915 r
.8005 .42937 .80566 .43588 .81781 .43183 .81269 .42523 Mtetra
.673 .757 .914 r
.81269 .42523 .81781 .43183 .83001 .4278 .82492 .42111 Mtetra
.672 .755 .913 r
.82492 .42111 .83001 .4278 .84226 .42379 .8372 .41702 Mtetra
.671 .753 .912 r
.8372 .41702 .84226 .42379 .85456 .41979 .84954 .41294 Mtetra
.67 .751 .911 r
.84954 .41294 .85456 .41979 .86692 .41579 .86194 .40888 Mtetra
.669 .749 .911 r
.86194 .40888 .86692 .41579 .87934 .41181 .87439 .40484 Mtetra
.668 .748 .91 r
.87439 .40484 .87934 .41181 .8918 .40783 .88689 .4008 Mtetra
.667 .747 .91 r
.88689 .4008 .8918 .40783 .90433 .40386 .89945 .39677 Mtetra
.667 .746 .909 r
.89945 .39677 .90433 .40386 .9169 .39989 .91207 .39275 Mtetra
.666 .745 .909 r
.91207 .39275 .9169 .39989 .92954 .39591 .92474 .38873 Mtetra
.666 .744 .909 r
.92474 .38873 .92954 .39591 .94222 .39193 .93746 .38471 Mtetra
.635 .765 .941 r
.35483 .56179 .36129 .56687 .3717 .56415 .36525 .55915 Mtetra
.633 .769 .945 r
.36525 .55915 .3717 .56415 .38215 .56145 .37573 .55654 Mtetra
.63 .772 .949 r
.37573 .55654 .38215 .56145 .39264 .55876 .38624 .55395 Mtetra
.627 .776 .952 r
.38624 .55395 .39264 .55876 .40318 .55608 .3968 .55138 Mtetra
.625 .781 .956 r
.3968 .55138 .40318 .55608 .41376 .55341 .4074 .54882 Mtetra
.623 .785 .959 r
.4074 .54882 .41376 .55341 .42438 .55073 .41806 .54625 Mtetra
.621 .79 .963 r
.41806 .54625 .42438 .55073 .43505 .54805 .42875 .54368 Mtetra
.619 .794 .966 r
.42875 .54368 .43505 .54805 .44577 .54534 .4395 .54108 Mtetra
.619 .799 .969 r
.4395 .54108 .44577 .54534 .45654 .54261 .45029 .53845 Mtetra
.618 .804 .971 r
.45029 .53845 .45654 .54261 .46735 .53984 .46114 .53577 Mtetra
.619 .809 .973 r
.46114 .53577 .46735 .53984 .47821 .53701 .47203 .53303 Mtetra
.62 .814 .975 r
.47203 .53303 .47821 .53701 .48911 .53413 .48297 .53022 Mtetra
.622 .818 .976 r
.48297 .53022 .48911 .53413 .50007 .53118 .49396 .52733 Mtetra
.625 .822 .976 r
.49396 .52733 .50007 .53118 .51107 .52814 .50499 .52435 Mtetra
.628 .826 .977 r
.50499 .52435 .51107 .52814 .52212 .52503 .51608 .52127 Mtetra
.632 .829 .976 r
.51608 .52127 .52212 .52503 .53321 .52181 .52721 .51807 Mtetra
.637 .832 .976 r
.52721 .51807 .53321 .52181 .54435 .51851 .53839 .51476 Mtetra
.642 .834 .974 r
.53839 .51476 .54435 .51851 .55554 .5151 .54961 .51132 Mtetra
.647 .836 .973 r
.54961 .51132 .55554 .5151 .56677 .51158 .56088 .50777 Mtetra
.653 .836 .971 r
.56088 .50777 .56677 .51158 .57804 .50797 .57219 .5041 Mtetra
.658 .836 .968 r
.57219 .5041 .57804 .50797 .58936 .50426 .58355 .50031 Mtetra
.663 .835 .966 r
.58355 .50031 .58936 .50426 .60072 .50045 .59495 .4964 Mtetra
.668 .834 .963 r
.59495 .4964 .60072 .50045 .61212 .49655 .60639 .49239 Mtetra
.672 .831 .96 r
.60639 .49239 .61212 .49655 .62356 .49257 .61787 .48829 Mtetra
.676 .828 .956 r
.61787 .48829 .62356 .49257 .63505 .48852 .62939 .4841 Mtetra
.68 .825 .953 r
.62939 .4841 .63505 .48852 .64658 .48441 .64096 .47984 Mtetra
.682 .821 .95 r
.64096 .47984 .64658 .48441 .65815 .48024 .65256 .47552 Mtetra
.684 .816 .946 r
.65256 .47552 .65815 .48024 .66976 .47603 .66421 .47115 Mtetra
.686 .812 .943 r
.66421 .47115 .66976 .47603 .68142 .47179 .6759 .46674 Mtetra
.686 .807 .939 r
.6759 .46674 .68142 .47179 .69312 .46752 .68764 .46231 Mtetra
.687 .802 .936 r
.68764 .46231 .69312 .46752 .70486 .46325 .69941 .45787 Mtetra
.687 .797 .933 r
.69941 .45787 .70486 .46325 .71665 .45897 .71123 .45343 Mtetra
.686 .792 .93 r
.71123 .45343 .71665 .45897 .72848 .45469 .7231 .44899 Mtetra
.685 .787 .927 r
.7231 .44899 .72848 .45469 .74036 .45042 .73501 .44457 Mtetra
.684 .782 .925 r
.73501 .44457 .74036 .45042 .75229 .44617 .74697 .44018 Mtetra
.683 .778 .923 r
.74697 .44018 .75229 .44617 .76427 .44193 .75898 .4358 Mtetra
.681 .774 .921 r
.75898 .4358 .76427 .44193 .7763 .43772 .77104 .43146 Mtetra
.68 .77 .919 r
.77104 .43146 .7763 .43772 .78838 .43353 .78315 .42715 Mtetra
.678 .766 .917 r
.78315 .42715 .78838 .43353 .8005 .42937 .79531 .42288 Mtetra
.677 .763 .916 r
.79531 .42288 .8005 .42937 .81269 .42523 .80753 .41863 Mtetra
.675 .76 .914 r
.80753 .41863 .81269 .42523 .82492 .42111 .81979 .41442 Mtetra
.674 .757 .913 r
.81979 .41442 .82492 .42111 .8372 .41702 .83211 .41024 Mtetra
.673 .755 .912 r
.83211 .41024 .8372 .41702 .84954 .41294 .84449 .40608 Mtetra
.671 .753 .912 r
.84449 .40608 .84954 .41294 .86194 .40888 .85692 .40195 Mtetra
.67 .751 .911 r
.85692 .40195 .86194 .40888 .87439 .40484 .8694 .39783 Mtetra
.669 .749 .91 r
.8694 .39783 .87439 .40484 .88689 .4008 .88194 .39373 Mtetra
.668 .748 .91 r
.88194 .39373 .88689 .4008 .89945 .39677 .89454 .38965 Mtetra
.667 .747 .909 r
.89454 .38965 .89945 .39677 .91207 .39275 .90719 .38557 Mtetra
.667 .746 .909 r
.90719 .38557 .91207 .39275 .92474 .38873 .9199 .3815 Mtetra
.666 .745 .909 r
.9199 .3815 .92474 .38873 .93746 .38471 .93266 .37743 Mtetra
.628 .769 .948 r
.3483 .55682 .35483 .56179 .36525 .55915 .35875 .55429 Mtetra
.624 .773 .952 r
.35875 .55429 .36525 .55915 .37573 .55654 .36924 .5518 Mtetra
.621 .778 .956 r
.36924 .5518 .37573 .55654 .38624 .55395 .37978 .54933 Mtetra
.617 .782 .96 r
.37978 .54933 .38624 .55395 .3968 .55138 .39036 .54689 Mtetra
.614 .787 .964 r
.39036 .54689 .3968 .55138 .4074 .54882 .40099 .54445 Mtetra
.611 .792 .968 r
.40099 .54445 .4074 .54882 .41806 .54625 .41167 .54202 Mtetra
.608 .797 .972 r
.41167 .54202 .41806 .54625 .42875 .54368 .42239 .53957 Mtetra
.606 .803 .975 r
.42239 .53957 .42875 .54368 .4395 .54108 .43317 .5371 Mtetra
.604 .808 .978 r
.43317 .5371 .4395 .54108 .45029 .53845 .44399 .53459 Mtetra
.604 .814 .981 r
.44399 .53459 .45029 .53845 .46114 .53577 .45486 .53203 Mtetra
.604 .819 .983 r
.45486 .53203 .46114 .53577 .47203 .53303 .46579 .5294 Mtetra
.605 .825 .984 r
.46579 .5294 .47203 .53303 .48297 .53022 .47676 .52668 Mtetra
.608 .83 .985 r
.47676 .52668 .48297 .53022 .49396 .52733 .48779 .52387 Mtetra
.611 .835 .985 r
.48779 .52387 .49396 .52733 .50499 .52435 .49886 .52094 Mtetra
.615 .839 .985 r
.49886 .52094 .50499 .52435 .51608 .52127 .50998 .5179 Mtetra
.62 .843 .985 r
.50998 .5179 .51608 .52127 .52721 .51807 .52115 .51472 Mtetra
.627 .847 .984 r
.52115 .51472 .52721 .51807 .53839 .51476 .53237 .51141 Mtetra
.633 .849 .982 r
.53237 .51141 .53839 .51476 .54961 .51132 .54363 .50795 Mtetra
.64 .851 .981 r
.54363 .50795 .54961 .51132 .56088 .50777 .55494 .50435 Mtetra
.647 .852 .978 r
.55494 .50435 .56088 .50777 .57219 .5041 .5663 .50061 Mtetra
.654 .852 .976 r
.5663 .50061 .57219 .5041 .58355 .50031 .57769 .49673 Mtetra
.661 .851 .973 r
.57769 .49673 .58355 .50031 .59495 .4964 .58913 .49271 Mtetra
.667 .849 .969 r
.58913 .49271 .59495 .4964 .60639 .49239 .60061 .48858 Mtetra
.673 .847 .966 r
.60061 .48858 .60639 .49239 .61787 .48829 .61214 .48433 Mtetra
.678 .843 .962 r
.61214 .48433 .61787 .48829 .62939 .4841 .6237 .47999 Mtetra
.682 .839 .959 r
.6237 .47999 .62939 .4841 .64096 .47984 .6353 .47556 Mtetra
.686 .834 .955 r
.6353 .47556 .64096 .47984 .65256 .47552 .64694 .47106 Mtetra
.688 .829 .951 r
.64694 .47106 .65256 .47552 .66421 .47115 .65863 .4665 Mtetra
.69 .824 .947 r
.65863 .4665 .66421 .47115 .6759 .46674 .67035 .46191 Mtetra
.691 .818 .943 r
.67035 .46191 .6759 .46674 .68764 .46231 .68212 .45729 Mtetra
.691 .812 .94 r
.68212 .45729 .68764 .46231 .69941 .45787 .69393 .45267 Mtetra
.691 .806 .936 r
.69393 .45267 .69941 .45787 .71123 .45343 .70578 .44804 Mtetra
.691 .8 .933 r
.70578 .44804 .71123 .45343 .7231 .44899 .71768 .44343 Mtetra
.69 .794 .93 r
.71768 .44343 .7231 .44899 .73501 .44457 .72963 .43883 Mtetra
.688 .789 .927 r
.72963 .43883 .73501 .44457 .74697 .44018 .74162 .43427 Mtetra
.687 .784 .924 r
.74162 .43427 .74697 .44018 .75898 .4358 .75366 .42975 Mtetra
.685 .779 .922 r
.75366 .42975 .75898 .4358 .77104 .43146 .76575 .42526 Mtetra
.683 .774 .92 r
.76575 .42526 .77104 .43146 .78315 .42715 .77789 .42081 Mtetra
.681 .77 .918 r
.77789 .42081 .78315 .42715 .79531 .42288 .79009 .41641 Mtetra
.679 .766 .917 r
.79009 .41641 .79531 .42288 .80753 .41863 .80233 .41205 Mtetra
.678 .763 .915 r
.80233 .41205 .80753 .41863 .81979 .41442 .81463 .40773 Mtetra
.676 .76 .914 r
.81463 .40773 .81979 .41442 .83211 .41024 .82698 .40345 Mtetra
.674 .757 .913 r
.82698 .40345 .83211 .41024 .84449 .40608 .83939 .3992 Mtetra
.673 .754 .912 r
.83939 .3992 .84449 .40608 .85692 .40195 .85186 .39499 Mtetra
.671 .752 .911 r
.85186 .39499 .85692 .40195 .8694 .39783 .86438 .3908 Mtetra
.67 .75 .911 r
.86438 .3908 .8694 .39783 .88194 .39373 .87695 .38663 Mtetra
.669 .749 .91 r
.87695 .38663 .88194 .39373 .89454 .38965 .88959 .38248 Mtetra
.668 .747 .91 r
.88959 .38248 .89454 .38965 .90719 .38557 .90228 .37835 Mtetra
.667 .746 .909 r
.90228 .37835 .90719 .38557 .9199 .3815 .91502 .37422 Mtetra
.667 .745 .909 r
.91502 .37422 .9199 .3815 .93266 .37743 .92783 .3701 Mtetra
.618 .774 .955 r
.34171 .55199 .3483 .55682 .35875 .55429 .35218 .54959 Mtetra
.614 .778 .96 r
.35218 .54959 .35875 .55429 .36924 .5518 .36269 .54724 Mtetra
.609 .783 .964 r
.36269 .54724 .36924 .5518 .37978 .54933 .37325 .54492 Mtetra
.604 .788 .969 r
.37325 .54492 .37978 .54933 .39036 .54689 .38386 .54262 Mtetra
.599 .794 .974 r
.38386 .54262 .39036 .54689 .40099 .54445 .39451 .54034 Mtetra
.595 .799 .978 r
.39451 .54034 .40099 .54445 .41167 .54202 .40521 .53806 Mtetra
.591 .805 .981 r
.40521 .53806 .41167 .54202 .42239 .53957 .41596 .53577 Mtetra
.588 .811 .985 r
.41596 .53577 .42239 .53957 .43317 .5371 .42677 .53345 Mtetra
.586 .818 .988 r
.42677 .53345 .43317 .5371 .44399 .53459 .43762 .53109 Mtetra
.584 .824 .99 r
.43762 .53109 .44399 .53459 .45486 .53203 .44853 .52866 Mtetra
.584 .83 .991 r
.44853 .52866 .45486 .53203 .46579 .5294 .45948 .52615 Mtetra
.585 .836 .992 r
.45948 .52615 .46579 .5294 .47676 .52668 .47049 .52354 Mtetra
.588 .842 .993 r
.47049 .52354 .47676 .52668 .48779 .52387 .48155 .52082 Mtetra
.592 .848 .993 r
.48155 .52082 .48779 .52387 .49886 .52094 .49266 .51797 Mtetra
.597 .853 .992 r
.49266 .51797 .49886 .52094 .50998 .5179 .50383 .51497 Mtetra
.604 .858 .992 r
.50383 .51497 .50998 .5179 .52115 .51472 .51504 .51181 Mtetra
.612 .862 .99 r
.51504 .51181 .52115 .51472 .53237 .51141 .5263 .5085 Mtetra
.621 .865 .989 r
.5263 .5085 .53237 .51141 .54363 .50795 .5376 .50502 Mtetra
.63 .867 .987 r
.5376 .50502 .54363 .50795 .55494 .50435 .54896 .50136 Mtetra
.639 .869 .984 r
.54896 .50136 .55494 .50435 .5663 .50061 .56035 .49754 Mtetra
.649 .869 .982 r
.56035 .49754 .5663 .50061 .57769 .49673 .57179 .49356 Mtetra
.658 .868 .979 r
.57179 .49356 .57769 .49673 .58913 .49271 .58327 .48943 Mtetra
.666 .866 .975 r
.58327 .48943 .58913 .49271 .60061 .48858 .59479 .48515 Mtetra
.673 .863 .972 r
.59479 .48515 .60061 .48858 .61214 .48433 .60636 .48074 Mtetra
.68 .86 .968 r
.60636 .48074 .61214 .48433 .6237 .47999 .61796 .47621 Mtetra
.685 .855 .964 r
.61796 .47621 .6237 .47999 .6353 .47556 .6296 .47159 Mtetra
.69 .849 .959 r
.6296 .47159 .6353 .47556 .64694 .47106 .64128 .46689 Mtetra
.693 .843 .955 r
.64128 .46689 .64694 .47106 .65863 .4665 .653 .46213 Mtetra
.695 .837 .951 r
.653 .46213 .65863 .4665 .67035 .46191 .66477 .45732 Mtetra
.696 .83 .947 r
.66477 .45732 .67035 .46191 .68212 .45729 .67657 .45249 Mtetra
.697 .823 .943 r
.67657 .45249 .68212 .45729 .69393 .45267 .68841 .44765 Mtetra
.697 .816 .939 r
.68841 .44765 .69393 .45267 .70578 .44804 .7003 .44281 Mtetra
.696 .809 .935 r
.7003 .44281 .70578 .44804 .71768 .44343 .71223 .438 Mtetra
.695 .803 .932 r
.71223 .438 .71768 .44343 .72963 .43883 .72421 .43321 Mtetra
.693 .796 .929 r
.72421 .43321 .72963 .43883 .74162 .43427 .73623 .42847 Mtetra
.691 .79 .926 r
.73623 .42847 .74162 .43427 .75366 .42975 .7483 .42376 Mtetra
.689 .785 .924 r
.7483 .42376 .75366 .42975 .76575 .42526 .76043 .41911 Mtetra
.687 .779 .921 r
.76043 .41911 .76575 .42526 .77789 .42081 .7726 .41452 Mtetra
.685 .775 .919 r
.7726 .41452 .77789 .42081 .79009 .41641 .78482 .40997 Mtetra
.683 .77 .917 r
.78482 .40997 .79009 .41641 .80233 .41205 .7971 .40548 Mtetra
.68 .766 .916 r
.7971 .40548 .80233 .41205 .81463 .40773 .80943 .40104 Mtetra
.678 .762 .915 r
.80943 .40104 .81463 .40773 .82698 .40345 .82182 .39665 Mtetra
.676 .759 .913 r
.82182 .39665 .82698 .40345 .83939 .3992 .83426 .39231 Mtetra
.675 .756 .912 r
.83426 .39231 .83939 .3992 .85186 .39499 .84676 .388 Mtetra
.673 .754 .912 r
.84676 .388 .85186 .39499 .86438 .3908 .85932 .38373 Mtetra
.672 .752 .911 r
.85932 .38373 .86438 .3908 .87695 .38663 .87193 .37949 Mtetra
.67 .75 .91 r
.87193 .37949 .87695 .38663 .88959 .38248 .8846 .37528 Mtetra
.669 .748 .91 r
.8846 .37528 .88959 .38248 .90228 .37835 .89732 .37108 Mtetra
.668 .747 .909 r
.89732 .37108 .90228 .37835 .91502 .37422 .91011 .3669 Mtetra
.667 .746 .909 r
.91011 .3669 .91502 .37422 .92783 .3701 .92295 .36273 Mtetra
.607 .778 .963 r
.33506 .54733 .34171 .55199 .35218 .54959 .34555 .54508 Mtetra
.6 .783 .968 r
.34555 .54508 .35218 .54959 .36269 .54724 .35608 .54289 Mtetra
.594 .789 .973 r
.35608 .54289 .36269 .54724 .37325 .54492 .36666 .54074 Mtetra
.587 .794 .978 r
.36666 .54074 .37325 .54492 .38386 .54262 .37729 .53862 Mtetra
.581 .8 .983 r
.37729 .53862 .38386 .54262 .39451 .54034 .38796 .53652 Mtetra
.574 .806 .987 r
.38796 .53652 .39451 .54034 .40521 .53806 .39869 .53443 Mtetra
.569 .812 .99 r
.39869 .53443 .40521 .53806 .41596 .53577 .40947 .53232 Mtetra
.564 .819 .993 r
.40947 .53232 .41596 .53577 .42677 .53345 .4203 .53017 Mtetra
.56 .825 .995 r
.4203 .53017 .42677 .53345 .43762 .53109 .43118 .52798 Mtetra
.558 .832 .997 r
.43118 .52798 .43762 .53109 .44853 .52866 .44212 .5257 Mtetra
.557 .839 .998 r
.44212 .5257 .44853 .52866 .45948 .52615 .45311 .52334 Mtetra
.558 .845 .998 r
.45311 .52334 .45948 .52615 .47049 .52354 .46415 .52085 Mtetra
.561 .852 .997 r
.46415 .52085 .47049 .52354 .48155 .52082 .47525 .51823 Mtetra
.566 .858 .997 r
.47525 .51823 .48155 .52082 .49266 .51797 .4864 .51546 Mtetra
.573 .864 .996 r
.4864 .51546 .49266 .51797 .50383 .51497 .49761 .51252 Mtetra
.582 .87 .995 r
.49761 .51252 .50383 .51497 .51504 .51181 .50886 .5094 Mtetra
.592 .875 .993 r
.50886 .5094 .51504 .51181 .5263 .5085 .52016 .50608 Mtetra
.604 .88 .992 r
.52016 .50608 .5263 .5085 .5376 .50502 .53151 .50257 Mtetra
.616 .883 .99 r
.53151 .50257 .5376 .50502 .54896 .50136 .54291 .49886 Mtetra
.628 .885 .988 r
.54291 .49886 .54896 .50136 .56035 .49754 .55435 .49495 Mtetra
.641 .886 .985 r
.55435 .49495 .56035 .49754 .57179 .49356 .56584 .49085 Mtetra
.652 .886 .982 r
.56584 .49085 .57179 .49356 .58327 .48943 .57736 .48657 Mtetra
.663 .884 .979 r
.57736 .48657 .58327 .48943 .59479 .48515 .58893 .48213 Mtetra
.673 .881 .976 r
.58893 .48213 .59479 .48515 .60636 .48074 .60053 .47753 Mtetra
.681 .877 .972 r
.60053 .47753 .60636 .48074 .61796 .47621 .61218 .4728 Mtetra
.688 .871 .968 r
.61218 .4728 .61796 .47621 .6296 .47159 .62386 .46796 Mtetra
.694 .865 .963 r
.62386 .46796 .6296 .47159 .64128 .46689 .63558 .46303 Mtetra
.698 .858 .959 r
.63558 .46303 .64128 .46689 .653 .46213 .64734 .45803 Mtetra
.701 .851 .954 r
.64734 .45803 .653 .46213 .66477 .45732 .65914 .45299 Mtetra
.703 .843 .95 r
.65914 .45299 .66477 .45732 .67657 .45249 .67098 .44792 Mtetra
.703 .835 .946 r
.67098 .44792 .67657 .45249 .68841 .44765 .68286 .44284 Mtetra
.703 .827 .941 r
.68286 .44284 .68841 .44765 .7003 .44281 .69478 .43777 Mtetra
.702 .819 .938 r
.69478 .43777 .7003 .44281 .71223 .438 .70674 .43273 Mtetra
.701 .812 .934 r
.70674 .43273 .71223 .438 .72421 .43321 .71875 .42772 Mtetra
.699 .804 .931 r
.71875 .42772 .72421 .43321 .73623 .42847 .73081 .42277 Mtetra
.696 .798 .928 r
.73081 .42277 .73623 .42847 .7483 .42376 .74291 .41787 Mtetra
.694 .791 .925 r
.74291 .41787 .7483 .42376 .76043 .41911 .75506 .41304 Mtetra
.691 .785 .922 r
.75506 .41304 .76043 .41911 .7726 .41452 .76727 .40827 Mtetra
.689 .779 .92 r
.76727 .40827 .7726 .41452 .78482 .40997 .77952 .40357 Mtetra
.686 .774 .918 r
.77952 .40357 .78482 .40997 .7971 .40548 .79183 .39894 Mtetra
.683 .77 .917 r
.79183 .39894 .7971 .40548 .80943 .40104 .8042 .39437 Mtetra
.681 .765 .915 r
.8042 .39437 .80943 .40104 .82182 .39665 .81662 .38986 Mtetra
.679 .762 .914 r
.81662 .38986 .82182 .39665 .83426 .39231 .82909 .3854 Mtetra
.677 .759 .913 r
.82909 .3854 .83426 .39231 .84676 .388 .84163 .381 Mtetra
.675 .756 .912 r
.84163 .381 .84676 .388 .85932 .38373 .85422 .37664 Mtetra
.673 .753 .911 r
.85422 .37664 .85932 .38373 .87193 .37949 .86686 .37232 Mtetra
.671 .751 .91 r
.86686 .37232 .87193 .37949 .8846 .37528 .87957 .36803 Mtetra
.67 .749 .91 r
.87957 .36803 .8846 .37528 .89732 .37108 .89233 .36377 Mtetra
.669 .748 .909 r
.89233 .36377 .89732 .37108 .91011 .3669 .90516 .35953 Mtetra
.668 .747 .909 r
.90516 .35953 .91011 .3669 .92295 .36273 .91804 .3553 Mtetra
.592 .783 .971 r
.32834 .54285 .33506 .54733 .34555 .54508 .33885 .54078 Mtetra
.583 .788 .977 r
.33885 .54078 .34555 .54508 .35608 .54289 .3494 .53877 Mtetra
.574 .794 .982 r
.3494 .53877 .35608 .54289 .36666 .54074 .36 .53682 Mtetra
.565 .799 .987 r
.36 .53682 .36666 .54074 .37729 .53862 .37064 .53491 Mtetra
.556 .805 .991 r
.37064 .53491 .37729 .53862 .38796 .53652 .38134 .53302 Mtetra
.547 .812 .995 r
.38134 .53302 .38796 .53652 .39869 .53443 .39209 .53113 Mtetra
.539 .818 .997 r
.39209 .53113 .39869 .53443 .40947 .53232 .40289 .52923 Mtetra
.531 .824 .999 r
.40289 .52923 .40947 .53232 .4203 .53017 .41375 .52729 Mtetra
.525 .83 1 r
.41375 .52729 .4203 .53017 .43118 .52798 .42467 .52529 Mtetra
.521 .837 .999 r
.42467 .52529 .43118 .52798 .44212 .5257 .43564 .5232 Mtetra
.52 .844 .998 r
.43564 .5232 .44212 .5257 .45311 .52334 .44666 .52099 Mtetra
.52 .85 .997 r
.44666 .52099 .45311 .52334 .46415 .52085 .45774 .51865 Mtetra
.524 .857 .995 r
.45774 .51865 .46415 .52085 .47525 .51823 .46888 .51615 Mtetra
.53 .865 .994 r
.46888 .51615 .47525 .51823 .4864 .51546 .48007 .51347 Mtetra
.539 .872 .992 r
.48007 .51347 .4864 .51546 .49761 .51252 .49132 .51059 Mtetra
.551 .879 .991 r
.49132 .51059 .49761 .51252 .50886 .5094 .50262 .5075 Mtetra
.565 .885 .99 r
.50262 .5075 .50886 .5094 .52016 .50608 .51397 .50419 Mtetra
.58 .891 .989 r
.51397 .50419 .52016 .50608 .53151 .50257 .52536 .50064 Mtetra
.596 .896 .988 r
.52536 .50064 .53151 .50257 .54291 .49886 .53681 .49686 Mtetra
.613 .9 .987 r
.53681 .49686 .54291 .49886 .55435 .49495 .54829 .49285 Mtetra
.629 .902 .985 r
.54829 .49285 .55435 .49495 .56584 .49085 .55983 .48862 Mtetra
.644 .903 .983 r
.55983 .48862 .56584 .49085 .57736 .48657 .5714 .48419 Mtetra
.659 .901 .981 r
.5714 .48419 .57736 .48657 .58893 .48213 .58301 .47955 Mtetra
.671 .899 .978 r
.58301 .47955 .58893 .48213 .60053 .47753 .59466 .47475 Mtetra
.682 .894 .974 r
.59466 .47475 .60053 .47753 .61218 .4728 .60635 .46979 Mtetra
.691 .889 .97 r
.60635 .46979 .61218 .4728 .62386 .46796 .61808 .4647 Mtetra
.698 .882 .966 r
.61808 .4647 .62386 .46796 .63558 .46303 .62984 .45952 Mtetra
.704 .874 .961 r
.62984 .45952 .63558 .46303 .64734 .45803 .64164 .45425 Mtetra
.707 .866 .957 r
.64164 .45425 .64734 .45803 .65914 .45299 .65347 .44894 Mtetra
.71 .857 .952 r
.65347 .44894 .65914 .45299 .67098 .44792 .66535 .44359 Mtetra
.71 .848 .948 r
.66535 .44359 .67098 .44792 .68286 .44284 .67726 .43825 Mtetra
.71 .839 .944 r
.67726 .43825 .68286 .44284 .69478 .43777 .68922 .43292 Mtetra
.709 .83 .939 r
.68922 .43292 .69478 .43777 .70674 .43273 .70121 .42762 Mtetra
.707 .821 .936 r
.70121 .42762 .70674 .43273 .71875 .42772 .71326 .42237 Mtetra
.705 .813 .932 r
.71326 .42237 .71875 .42772 .73081 .42277 .72534 .41719 Mtetra
.702 .805 .929 r
.72534 .41719 .73081 .42277 .74291 .41787 .73748 .41207 Mtetra
.699 .798 .926 r
.73748 .41207 .74291 .41787 .75506 .41304 .74966 .40704 Mtetra
.696 .791 .923 r
.74966 .40704 .75506 .41304 .76727 .40827 .7619 .40208 Mtetra
.693 .784 .921 r
.7619 .40208 .76727 .40827 .77952 .40357 .77419 .39721 Mtetra
.69 .779 .919 r
.77419 .39721 .77952 .40357 .79183 .39894 .78653 .39241 Mtetra
.687 .773 .917 r
.78653 .39241 .79183 .39894 .8042 .39437 .79892 .3877 Mtetra
.684 .769 .915 r
.79892 .3877 .8042 .39437 .81662 .38986 .81138 .38306 Mtetra
.681 .765 .914 r
.81138 .38306 .81662 .38986 .82909 .3854 .82388 .37849 Mtetra
.679 .761 .913 r
.82388 .37849 .82909 .3854 .84163 .381 .83645 .37398 Mtetra
.677 .758 .912 r
.83645 .37398 .84163 .381 .85422 .37664 .84908 .36952 Mtetra
.675 .755 .911 r
.84908 .36952 .85422 .37664 .86686 .37232 .86176 .36511 Mtetra
.673 .753 .911 r
.86176 .36511 .86686 .37232 .87957 .36803 .8745 .36075 Mtetra
.671 .75 .91 r
.8745 .36075 .87957 .36803 .89233 .36377 .88731 .35641 Mtetra
.67 .749 .91 r
.88731 .35641 .89233 .36377 .90516 .35953 .90017 .35211 Mtetra
.669 .747 .909 r
.90017 .35211 .90516 .35953 .91804 .3553 .91309 .34782 Mtetra
.573 .786 .98 r
.32155 .53856 .32834 .54285 .33885 .54078 .33207 .5367 Mtetra
.561 .792 .985 r
.33207 .5367 .33885 .54078 .3494 .53877 .34264 .53492 Mtetra
.549 .797 .991 r
.34264 .53492 .3494 .53877 .36 .53682 .35326 .53319 Mtetra
.536 .803 .995 r
.35326 .53319 .36 .53682 .37064 .53491 .36392 .53151 Mtetra
.523 .808 .998 r
.36392 .53151 .37064 .53491 .38134 .53302 .37464 .52986 Mtetra
.511 .814 1 r
.37464 .52986 .38134 .53302 .39209 .53113 .38542 .52822 Mtetra
.499 .819 1 r
.38542 .52822 .39209 .53113 .40289 .52923 .39624 .52655 Mtetra
.488 .824 .999 r
.39624 .52655 .40289 .52923 .41375 .52729 .40713 .52484 Mtetra
.479 .829 .997 r
.40713 .52484 .41375 .52729 .42467 .52529 .41807 .52306 Mtetra
.473 .835 .994 r
.41807 .52306 .42467 .52529 .43564 .5232 .42908 .52117 Mtetra
.47 .841 .99 r
.42908 .52117 .43564 .5232 .44666 .52099 .44014 .51916 Mtetra
.47 .847 .986 r
.44014 .51916 .44666 .52099 .45774 .51865 .45126 .51698 Mtetra
.474 .855 .983 r
.45126 .51698 .45774 .51865 .46888 .51615 .46243 .51461 Mtetra
.482 .863 .98 r
.46243 .51461 .46888 .51615 .48007 .51347 .47367 .51204 Mtetra
.494 .871 .978 r
.47367 .51204 .48007 .51347 .49132 .51059 .48496 .50923 Mtetra
.51 .88 .977 r
.48496 .50923 .49132 .51059 .50262 .5075 .4963 .50617 Mtetra
.528 .889 .977 r
.4963 .50617 .50262 .5075 .51397 .50419 .5077 .50285 Mtetra
.548 .897 .977 r
.5077 .50285 .51397 .50419 .52536 .50064 .51915 .49927 Mtetra
.57 .905 .978 r
.51915 .49927 .52536 .50064 .53681 .49686 .53064 .49541 Mtetra
.592 .911 .979 r
.53064 .49541 .53681 .49686 .54829 .49285 .54218 .49129 Mtetra
.613 .915 .979 r
.54218 .49129 .54829 .49285 .55983 .48862 .55376 .48691 Mtetra
.633 .918 .979 r
.55376 .48691 .55983 .48862 .5714 .48419 .56538 .48229 Mtetra
.652 .918 .978 r
.56538 .48229 .5714 .48419 .58301 .47955 .57704 .47745 Mtetra
.669 .916 .976 r
.57704 .47745 .58301 .47955 .59466 .47475 .58874 .47241 Mtetra
.683 .912 .974 r
.58874 .47241 .59466 .47475 .60635 .46979 .60047 .46719 Mtetra
.694 .906 .971 r
.60047 .46719 .60635 .46979 .61808 .4647 .61224 .46183 Mtetra
.703 .899 .967 r
.61224 .46183 .61808 .4647 .62984 .45952 .62405 .45635 Mtetra
.71 .89 .963 r
.62405 .45635 .62984 .45952 .64164 .45425 .63589 .45079 Mtetra
.714 .881 .958 r
.63589 .45079 .64164 .45425 .65347 .44894 .64776 .44517 Mtetra
.717 .871 .954 r
.64776 .44517 .65347 .44894 .66535 .44359 .65968 .43953 Mtetra
.718 .861 .949 r
.65968 .43953 .66535 .44359 .67726 .43825 .67163 .43388 Mtetra
.718 .851 .945 r
.67163 .43388 .67726 .43825 .68922 .43292 .68362 .42826 Mtetra
.717 .841 .941 r
.68362 .42826 .68922 .43292 .70121 .42762 .69565 .42268 Mtetra
.715 .831 .937 r
.69565 .42268 .70121 .42762 .71326 .42237 .70772 .41717 Mtetra
.712 .822 .933 r
.70772 .41717 .71326 .42237 .72534 .41719 .71984 .41172 Mtetra
.709 .813 .93 r
.71984 .41172 .72534 .41719 .73748 .41207 .73201 .40637 Mtetra
.705 .805 .927 r
.73201 .40637 .73748 .41207 .74966 .40704 .74422 .40111 Mtetra
.702 .797 .924 r
.74422 .40111 .74966 .40704 .7619 .40208 .75649 .39595 Mtetra
.698 .79 .921 r
.75649 .39595 .7619 .40208 .77419 .39721 .76881 .39088 Mtetra
.694 .783 .919 r
.76881 .39088 .77419 .39721 .78653 .39241 .78118 .38592 Mtetra
.691 .777 .917 r
.78118 .38592 .78653 .39241 .79892 .3877 .79361 .38104 Mtetra
.687 .772 .916 r
.79361 .38104 .79892 .3877 .81138 .38306 .8061 .37626 Mtetra
.684 .767 .914 r
.8061 .37626 .81138 .38306 .82388 .37849 .81864 .37156 Mtetra
.681 .763 .913 r
.81864 .37156 .82388 .37849 .83645 .37398 .83124 .36693 Mtetra
.679 .76 .912 r
.83124 .36693 .83645 .37398 .84908 .36952 .8439 .36237 Mtetra
.676 .757 .911 r
.8439 .36237 .84908 .36952 .86176 .36511 .85662 .35787 Mtetra
.674 .754 .911 r
.85662 .35787 .86176 .36511 .8745 .36075 .8694 .35342 Mtetra
.673 .752 .91 r
.8694 .35342 .8745 .36075 .88731 .35641 .88224 .34901 Mtetra
.671 .75 .91 r
.88224 .34901 .88731 .35641 .90017 .35211 .89514 .34464 Mtetra
.67 .748 .909 r
.89514 .34464 .90017 .35211 .91309 .34782 .9081 .34029 Mtetra
.548 .789 .988 r
.31469 .5345 .32155 .53856 .33207 .5367 .32522 .53288 Mtetra
.533 .794 .993 r
.32522 .53288 .33207 .5367 .34264 .53492 .33581 .53134 Mtetra
.516 .798 .997 r
.33581 .53134 .34264 .53492 .35326 .53319 .34644 .52987 Mtetra
.499 .803 .999 r
.34644 .52987 .35326 .53319 .36392 .53151 .35712 .52846 Mtetra
.481 .807 1 r
.35712 .52846 .36392 .53151 .37464 .52986 .36786 .52708 Mtetra
.463 .81 .998 r
.36786 .52708 .37464 .52986 .38542 .52822 .37866 .52571 Mtetra
.446 .813 .995 r
.37866 .52571 .38542 .52822 .39624 .52655 .38951 .52431 Mtetra
.431 .816 .989 r
.38951 .52431 .39624 .52655 .40713 .52484 .40042 .52286 Mtetra
.418 .819 .982 r
.40042 .52286 .40713 .52484 .41807 .52306 .4114 .52133 Mtetra
.409 .822 .974 r
.4114 .52133 .41807 .52306 .42908 .52117 .42243 .51967 Mtetra
.405 .826 .967 r
.42243 .51967 .42908 .52117 .44014 .51916 .43353 .51786 Mtetra
.405 .832 .959 r
.43353 .51786 .44014 .51916 .45126 .51698 .44469 .51586 Mtetra
.41 .839 .954 r
.44469 .51586 .45126 .51698 .46243 .51461 .45591 .51365 Mtetra
.421 .848 .95 r
.45591 .51365 .46243 .51461 .47367 .51204 .46719 .51119 Mtetra
.436 .859 .948 r
.46719 .51119 .47367 .51204 .48496 .50923 .47852 .50846 Mtetra
.457 .87 .948 r
.47852 .50846 .48496 .50923 .4963 .50617 .48992 .50544 Mtetra
.481 .883 .95 r
.48992 .50544 .4963 .50617 .5077 .50285 .50136 .50211 Mtetra
.507 .895 .953 r
.50136 .50211 .5077 .50285 .51915 .49927 .51286 .49848 Mtetra
.536 .906 .958 r
.51286 .49848 .51915 .49927 .53064 .49541 .5244 .49454 Mtetra
.564 .916 .962 r
.5244 .49454 .53064 .49541 .54218 .49129 .536 .49029 Mtetra
.593 .924 .965 r
.536 .49029 .54218 .49129 .55376 .48691 .54763 .48574 Mtetra
.619 .929 .968 r
.54763 .48574 .55376 .48691 .56538 .48229 .5593 .48092 Mtetra
.643 .931 .97 r
.5593 .48092 .56538 .48229 .57704 .47745 .57102 .47584 Mtetra
.664 .931 .971 r
.57102 .47584 .57704 .47745 .58874 .47241 .58276 .47053 Mtetra
.682 .928 .97 r
.58276 .47053 .58874 .47241 .60047 .46719 .59455 .46502 Mtetra
.697 .922 .968 r
.59455 .46502 .60047 .46719 .61224 .46183 .60636 .45936 Mtetra
.708 .915 .966 r
.60636 .45936 .61224 .46183 .62405 .45635 .61821 .45356 Mtetra
.716 .906 .962 r
.61821 .45356 .62405 .45635 .63589 .45079 .63009 .44766 Mtetra
.722 .896 .958 r
.63009 .44766 .63589 .45079 .64776 .44517 .64201 .44171 Mtetra
.726 .885 .954 r
.64201 .44171 .64776 .44517 .65968 .43953 .65396 .43573 Mtetra
.727 .874 .95 r
.65396 .43573 .65968 .43953 .67163 .43388 .66595 .42976 Mtetra
.727 .863 .945 r
.66595 .42976 .67163 .43388 .68362 .42826 .67798 .42381 Mtetra
.726 .852 .941 r
.67798 .42381 .68362 .42826 .69565 .42268 .69004 .41792 Mtetra
.723 .841 .937 r
.69004 .41792 .69565 .42268 .70772 .41717 .70215 .41211 Mtetra
.72 .831 .934 r
.70215 .41211 .70772 .41717 .71984 .41172 .7143 .40639 Mtetra
.716 .821 .93 r
.7143 .40639 .71984 .41172 .73201 .40637 .7265 .40077 Mtetra
.712 .812 .927 r
.7265 .40077 .73201 .40637 .74422 .40111 .73875 .39526 Mtetra
.708 .803 .924 r
.73875 .39526 .74422 .40111 .75649 .39595 .75104 .38987 Mtetra
.703 .795 .922 r
.75104 .38987 .75649 .39595 .76881 .39088 .76339 .3846 Mtetra
.699 .788 .92 r
.76339 .3846 .76881 .39088 .78118 .38592 .7758 .37944 Mtetra
.695 .782 .918 r
.7758 .37944 .78118 .38592 .79361 .38104 .78826 .3744 Mtetra
.691 .776 .916 r
.78826 .3744 .79361 .38104 .8061 .37626 .80078 .36946 Mtetra
.688 .77 .915 r
.80078 .36946 .8061 .37626 .81864 .37156 .81335 .36462 Mtetra
.684 .766 .913 r
.81335 .36462 .81864 .37156 .83124 .36693 .82599 .35987 Mtetra
.681 .762 .912 r
.82599 .35987 .83124 .36693 .8439 .36237 .83868 .3552 Mtetra
.678 .758 .911 r
.83868 .3552 .8439 .36237 .85662 .35787 .85144 .3506 Mtetra
.676 .755 .911 r
.85144 .3506 .85662 .35787 .8694 .35342 .86425 .34606 Mtetra
.674 .753 .91 r
.86425 .34606 .8694 .35342 .88224 .34901 .87713 .34157 Mtetra
.672 .751 .91 r
.87713 .34157 .88224 .34901 .89514 .34464 .89007 .33712 Mtetra
.671 .749 .909 r
.89007 .33712 .89514 .34464 .9081 .34029 .90307 .33271 Mtetra
.518 .789 .995 r
.30775 .53068 .31469 .5345 .32522 .53288 .3183 .52932 Mtetra
.497 .793 .998 r
.3183 .52932 .32522 .53288 .33581 .53134 .32889 .52806 Mtetra
.474 .795 .999 r
.32889 .52806 .33581 .53134 .34644 .52987 .33954 .52688 Mtetra
.45 .797 .998 r
.33954 .52688 .34644 .52987 .35712 .52846 .35024 .52577 Mtetra
.426 .797 .994 r
.35024 .52577 .35712 .52846 .36786 .52708 .36099 .5247 Mtetra
.401 .797 .986 r
.36099 .5247 .36786 .52708 .37866 .52571 .37181 .52363 Mtetra
.378 .796 .976 r
.37181 .52363 .37866 .52571 .38951 .52431 .38269 .52253 Mtetra
.358 .794 .964 r
.38269 .52253 .38951 .52431 .40042 .52286 .39363 .52137 Mtetra
.341 .793 .95 r
.39363 .52137 .40042 .52286 .4114 .52133 .40463 .52011 Mtetra
.329 .793 .936 r
.40463 .52011 .4114 .52133 .42243 .51967 .4157 .51871 Mtetra
.323 .795 .923 r
.4157 .51871 .42243 .51967 .43353 .51786 .42683 .51713 Mtetra
.324 .799 .913 r
.42683 .51713 .43353 .51786 .44469 .51586 .43803 .51533 Mtetra
.331 .807 .905 r
.43803 .51533 .44469 .51586 .45591 .51365 .44929 .51328 Mtetra
.345 .817 .901 r
.44929 .51328 .45591 .51365 .46719 .51119 .46062 .51094 Mtetra
.366 .831 .9 r
.46062 .51094 .46719 .51119 .47852 .50846 .472 .50829 Mtetra
.392 .846 .903 r
.472 .50829 .47852 .50846 .48992 .50544 .48345 .50531 Mtetra
.423 .864 .908 r
.48345 .50531 .48992 .50544 .50136 .50211 .49495 .50198 Mtetra
.458 .881 .916 r
.49495 .50198 .50136 .50211 .51286 .49848 .5065 .49829 Mtetra
.494 .899 .925 r
.5065 .49829 .51286 .49848 .5244 .49454 .5181 .49425 Mtetra
.531 .914 .935 r
.5181 .49425 .5244 .49454 .536 .49029 .52974 .48985 Mtetra
.567 .927 .943 r
.52974 .48985 .536 .49029 .54763 .48574 .54143 .48512 Mtetra
.601 .936 .951 r
.54143 .48512 .54763 .48574 .5593 .48092 .55316 .48006 Mtetra
.632 .942 .957 r
.55316 .48006 .5593 .48092 .57102 .47584 .56493 .47472 Mtetra
.659 .944 .961 r
.56493 .47472 .57102 .47584 .58276 .47053 .57673 .46912 Mtetra
.681 .942 .963 r
.57673 .46912 .58276 .47053 .59455 .46502 .58856 .46329 Mtetra
.699 .937 .963 r
.58856 .46329 .59455 .46502 .60636 .45936 .60043 .45728 Mtetra
.713 .93 .962 r
.60043 .45728 .60636 .45936 .61821 .45356 .61232 .45113 Mtetra
.724 .921 .959 r
.61232 .45113 .61821 .45356 .63009 .44766 .62425 .44487 Mtetra
.731 .911 .956 r
.62425 .44487 .63009 .44766 .64201 .44171 .63621 .43855 Mtetra
.735 .899 .953 r
.63621 .43855 .64201 .44171 .65396 .43573 .6482 .4322 Mtetra
.737 .887 .949 r
.6482 .4322 .65396 .43573 .66595 .42976 .66023 .42586 Mtetra
.736 .875 .945 r
.66023 .42586 .66595 .42976 .67798 .42381 .67229 .41956 Mtetra
.735 .863 .941 r
.67229 .41956 .67798 .42381 .69004 .41792 .68439 .41333 Mtetra
.732 .851 .937 r
.68439 .41333 .69004 .41792 .70215 .41211 .69653 .4072 Mtetra
.728 .84 .933 r
.69653 .4072 .70215 .41211 .7143 .40639 .70872 .40117 Mtetra
.724 .829 .93 r
.70872 .40117 .7143 .40639 .7265 .40077 .72095 .39526 Mtetra
.719 .819 .927 r
.72095 .39526 .7265 .40077 .73875 .39526 .73323 .38949 Mtetra
.714 .809 .924 r
.73323 .38949 .73875 .39526 .75104 .38987 .74556 .38385 Mtetra
.709 .801 .922 r
.74556 .38385 .75104 .38987 .76339 .3846 .75794 .37835 Mtetra
.704 .793 .919 r
.75794 .37835 .76339 .3846 .7758 .37944 .77037 .37299 Mtetra
.7 .786 .918 r
.77037 .37299 .7758 .37944 .78826 .3744 .78287 .36776 Mtetra
.695 .779 .916 r
.78287 .36776 .78826 .3744 .80078 .36946 .79542 .36266 Mtetra
.691 .773 .914 r
.79542 .36266 .80078 .36946 .81335 .36462 .80802 .35767 Mtetra
.687 .768 .913 r
.80802 .35767 .81335 .36462 .82599 .35987 .82069 .35279 Mtetra
.684 .764 .912 r
.82069 .35279 .82599 .35987 .83868 .3552 .83342 .348 Mtetra
.681 .76 .911 r
.83342 .348 .83868 .3552 .85144 .3506 .84621 .34329 Mtetra
.678 .757 .911 r
.84621 .34329 .85144 .3506 .86425 .34606 .85907 .33866 Mtetra
.675 .754 .91 r
.85907 .33866 .86425 .34606 .87713 .34157 .87198 .33408 Mtetra
.673 .752 .91 r
.87198 .33408 .87713 .34157 .89007 .33712 .88496 .32956 Mtetra
.672 .75 .909 r
.88496 .32956 .89007 .33712 .90307 .33271 .89799 .32508 Mtetra
.479 .786 .998 r
.30073 .5271 .30775 .53068 .3183 .52932 .31128 .52604 Mtetra
.451 .786 .998 r
.31128 .52604 .3183 .52932 .32889 .52806 .32189 .52509 Mtetra
.42 .785 .995 r
.32189 .52509 .32889 .52806 .33954 .52688 .33255 .52424 Mtetra
.388 .782 .988 r
.33255 .52424 .33954 .52688 .35024 .52577 .34326 .52346 Mtetra
.356 .777 .976 r
.34326 .52346 .35024 .52577 .36099 .5247 .35404 .52272 Mtetra
.323 .77 .96 r
.35404 .52272 .36099 .5247 .37181 .52363 .36487 .52199 Mtetra
.294 .763 .94 r
.36487 .52199 .37181 .52363 .38269 .52253 .37577 .52123 Mtetra
.268 .755 .918 r
.37577 .52123 .38269 .52253 .39363 .52137 .38674 .52038 Mtetra
.247 .748 .896 r
.38674 .52038 .39363 .52137 .40463 .52011 .39777 .51942 Mtetra
.234 .744 .875 r
.39777 .51942 .40463 .52011 .4157 .51871 .40887 .5183 Mtetra
.228 .744 .857 r
.40887 .5183 .4157 .51871 .42683 .51713 .42004 .51697 Mtetra
.23 .747 .844 r
.42004 .51697 .42683 .51713 .43803 .51533 .43128 .51539 Mtetra
.241 .756 .835 r
.43128 .51539 .43803 .51533 .44929 .51328 .44259 .51352 Mtetra
.259 .769 .831 r
.44259 .51352 .44929 .51328 .46062 .51094 .45396 .51131 Mtetra
.286 .787 .833 r
.45396 .51131 .46062 .51094 .472 .50829 .4654 .50875 Mtetra
.319 .808 .84 r
.4654 .50875 .472 .50829 .48345 .50531 .47689 .50581 Mtetra
.358 .831 .852 r
.47689 .50581 .48345 .50531 .49495 .50198 .48845 .50247 Mtetra
.402 .856 .866 r
.48845 .50247 .49495 .50198 .5065 .49829 .50006 .49871 Mtetra
.447 .881 .882 r
.50006 .49871 .5065 .49829 .5181 .49425 .51172 .49455 Mtetra
.494 .903 .898 r
.51172 .49455 .5181 .49425 .52974 .48985 .52342 .48999 Mtetra
.539 .923 .913 r
.52342 .48999 .52974 .48985 .54143 .48512 .53517 .48504 Mtetra
.581 .938 .927 r
.53517 .48504 .54143 .48512 .55316 .48006 .54696 .47973 Mtetra
.619 .948 .938 r
.54696 .47973 .55316 .48006 .56493 .47472 .55878 .4741 Mtetra
.652 .953 .946 r
.55878 .4741 .56493 .47472 .57673 .46912 .57063 .46817 Mtetra
.68 .954 .951 r
.57063 .46817 .57673 .46912 .58856 .46329 .58252 .46199 Mtetra
.702 .951 .954 r
.58252 .46199 .58856 .46329 .60043 .45728 .59444 .45561 Mtetra
.719 .944 .955 r
.59444 .45561 .60043 .45728 .61232 .45113 .60638 .44906 Mtetra
.731 .935 .955 r
.60638 .44906 .61232 .45113 .62425 .44487 .61836 .4424 Mtetra
.74 .924 .953 r
.61836 .4424 .62425 .44487 .63621 .43855 .63036 .43568 Mtetra
.745 .912 .95 r
.63036 .43568 .63621 .43855 .6482 .4322 .6424 .42893 Mtetra
.747 .9 .946 r
.6424 .42893 .6482 .4322 .66023 .42586 .65446 .42219 Mtetra
.747 .886 .943 r
.65446 .42219 .66023 .42586 .67229 .41956 .66656 .41551 Mtetra
.745 .873 .939 r
.66656 .41551 .67229 .41956 .68439 .41333 .6787 .40891 Mtetra
.742 .861 .936 r
.6787 .40891 .68439 .41333 .69653 .4072 .69088 .40242 Mtetra
.737 .848 .932 r
.69088 .40242 .69653 .4072 .70872 .40117 .70309 .39606 Mtetra
.732 .837 .929 r
.70309 .39606 .70872 .40117 .72095 .39526 .71536 .38985 Mtetra
.727 .826 .926 r
.71536 .38985 .72095 .39526 .73323 .38949 .72767 .38378 Mtetra
.721 .816 .923 r
.72767 .38378 .73323 .38949 .74556 .38385 .74003 .37788 Mtetra
.716 .806 .921 r
.74003 .37788 .74556 .38385 .75794 .37835 .75244 .37214 Mtetra
.71 .798 .919 r
.75244 .37214 .75794 .37835 .77037 .37299 .76491 .36656 Mtetra
.705 .79 .917 r
.76491 .36656 .77037 .37299 .78287 .36776 .77743 .36114 Mtetra
.7 .783 .916 r
.77743 .36114 .78287 .36776 .79542 .36266 .79001 .35585 Mtetra
.695 .776 .914 r
.79001 .35585 .79542 .36266 .80802 .35767 .80266 .3507 Mtetra
.691 .771 .913 r
.80266 .3507 .80802 .35767 .82069 .35279 .81536 .34568 Mtetra
.687 .766 .912 r
.81536 .34568 .82069 .35279 .83342 .348 .82812 .34076 Mtetra
.683 .762 .911 r
.82812 .34076 .83342 .348 .84621 .34329 .84095 .33594 Mtetra
.68 .758 .911 r
.84095 .33594 .84621 .34329 .85907 .33866 .85384 .33121 Mtetra
.677 .755 .91 r
.85384 .33121 .85907 .33866 .87198 .33408 .86679 .32655 Mtetra
.675 .753 .91 r
.86679 .32655 .87198 .33408 .88496 .32956 .8798 .32194 Mtetra
.673 .75 .909 r
.8798 .32194 .88496 .32956 .89799 .32508 .89288 .31739 Mtetra
.43 .777 .997 r
.29362 .52378 .30073 .5271 .31128 .52604 .30418 .52305 Mtetra
.393 .772 .991 r
.30418 .52305 .31128 .52604 .32189 .52509 .3148 .52245 Mtetra
.353 .765 .98 r
.3148 .52245 .32189 .52509 .33255 .52424 .32547 .52196 Mtetra
.312 .755 .964 r
.32547 .52196 .33255 .52424 .34326 .52346 .33619 .52154 Mtetra
.27 .742 .941 r
.33619 .52154 .34326 .52346 .35404 .52272 .34698 .52117 Mtetra
.23 .727 .913 r
.34698 .52117 .35404 .52272 .36487 .52199 .35784 .52081 Mtetra
.194 .711 .882 r
.35784 .52081 .36487 .52199 .37577 .52123 .36876 .5204 Mtetra
.164 .696 .85 r
.36876 .5204 .37577 .52123 .38674 .52038 .37975 .51991 Mtetra
.142 .684 .82 r
.37975 .51991 .38674 .52038 .39777 .51942 .39081 .51928 Mtetra
.129 .677 .793 r
.39081 .51928 .39777 .51942 .40887 .5183 .40195 .51846 Mtetra
.124 .674 .771 r
.40195 .51846 .40887 .5183 .42004 .51697 .41315 .5174 Mtetra
.13 .678 .756 r
.41315 .5174 .42004 .51697 .43128 .51539 .42443 .51605 Mtetra
.145 .689 .748 r
.42443 .51605 .43128 .51539 .44259 .51352 .43579 .51437 Mtetra
.169 .706 .747 r
.43579 .51437 .44259 .51352 .45396 .51131 .44721 .51231 Mtetra
.202 .729 .753 r
.44721 .51231 .45396 .51131 .4654 .50875 .4587 .50984 Mtetra
.243 .757 .766 r
.4587 .50984 .4654 .50875 .47689 .50581 .47025 .50693 Mtetra
.29 .788 .784 r
.47025 .50693 .47689 .50581 .48845 .50247 .48186 .50356 Mtetra
.343 .821 .805 r
.48186 .50356 .48845 .50247 .50006 .49871 .49353 .49973 Mtetra
.398 .854 .829 r
.49353 .49973 .50006 .49871 .51172 .49455 .50525 .49544 Mtetra
.454 .885 .853 r
.50525 .49544 .51172 .49455 .52342 .48999 .51702 .49069 Mtetra
.509 .912 .876 r
.51702 .49069 .52342 .48999 .53517 .48504 .52883 .48551 Mtetra
.56 .934 .897 r
.52883 .48551 .53517 .48504 .54696 .47973 .54068 .47992 Mtetra
.606 .95 .914 r
.54068 .47992 .54696 .47973 .55878 .4741 .55256 .47396 Mtetra
.646 .96 .928 r
.55256 .47396 .55878 .4741 .57063 .46817 .56447 .46767 Mtetra
.679 .963 .937 r
.56447 .46767 .57063 .46817 .58252 .46199 .57642 .4611 Mtetra
.706 .962 .943 r
.57642 .4611 .58252 .46199 .59444 .45561 .58839 .45431 Mtetra
.726 .956 .946 r
.58839 .45431 .59444 .45561 .60638 .44906 .60039 .44734 Mtetra
.74 .948 .948 r
.60039 .44734 .60638 .44906 .61836 .4424 .61241 .44025 Mtetra
.75 .937 .947 r
.61241 .44025 .61836 .4424 .63036 .43568 .62446 .43308 Mtetra
.755 .924 .945 r
.62446 .43308 .63036 .43568 .6424 .42893 .63654 .4259 Mtetra
.758 .911 .943 r
.63654 .4259 .6424 .42893 .65446 .42219 .64865 .41874 Mtetra
.758 .897 .94 r
.64865 .41874 .65446 .42219 .66656 .41551 .66079 .41164 Mtetra
.755 .883 .937 r
.66079 .41164 .66656 .41551 .6787 .40891 .67296 .40464 Mtetra
.752 .87 .933 r
.67296 .40464 .6787 .40891 .69088 .40242 .68517 .39778 Mtetra
.747 .856 .93 r
.68517 .39778 .69088 .40242 .70309 .39606 .69743 .39106 Mtetra
.741 .844 .927 r
.69743 .39106 .70309 .39606 .71536 .38985 .70972 .38451 Mtetra
.735 .832 .925 r
.70972 .38451 .71536 .38985 .72767 .38378 .72206 .37814 Mtetra
.729 .821 .922 r
.72206 .37814 .72767 .38378 .74003 .37788 .73446 .37196 Mtetra
.722 .811 .92 r
.73446 .37196 .74003 .37788 .75244 .37214 .7469 .36596 Mtetra
.716 .802 .918 r
.7469 .36596 .75244 .37214 .76491 .36656 .7594 .36015 Mtetra
.71 .794 .916 r
.7594 .36015 .76491 .36656 .77743 .36114 .77196 .35451 Mtetra
.704 .786 .915 r
.77196 .35451 .77743 .36114 .79001 .35585 .78457 .34904 Mtetra
.699 .779 .914 r
.78457 .34904 .79001 .35585 .80266 .3507 .79724 .34372 Mtetra
.694 .773 .913 r
.79724 .34372 .80266 .3507 .81536 .34568 .80998 .33854 Mtetra
.689 .768 .912 r
.80998 .33854 .81536 .34568 .82812 .34076 .82278 .33349 Mtetra
.685 .764 .911 r
.82278 .33349 .82812 .34076 .84095 .33594 .83564 .32856 Mtetra
.682 .76 .91 r
.83564 .32856 .84095 .33594 .85384 .33121 .84857 .32372 Mtetra
.679 .756 .91 r
.84857 .32372 .85384 .33121 .86679 .32655 .86156 .31896 Mtetra
.676 .754 .909 r
.86156 .31896 .86679 .32655 .8798 .32194 .87461 .31427 Mtetra
.674 .751 .909 r
.87461 .31427 .8798 .32194 .89288 .31739 .88773 .30964 Mtetra
.37 .76 .988 r
.28643 .52072 .29362 .52378 .30418 .52305 .297 .52035 Mtetra
.323 .748 .974 r
.297 .52035 .30418 .52305 .3148 .52245 .30761 .52013 Mtetra
.273 .732 .952 r
.30761 .52013 .3148 .52245 .32547 .52196 .31829 .52003 Mtetra
.221 .712 .922 r
.31829 .52003 .32547 .52196 .33619 .52154 .32903 .52001 Mtetra
.171 .689 .886 r
.32903 .52001 .33619 .52154 .34698 .52117 .33983 .52005 Mtetra
.125 .664 .845 r
.33983 .52005 .34698 .52117 .35784 .52081 .3507 .52008 Mtetra
.085 .641 .803 r
.3507 .52008 .35784 .52081 .36876 .5204 .36164 .52007 Mtetra
.055 .62 .762 r
.36164 .52007 .36876 .5204 .37975 .51991 .37266 .51995 Mtetra
.033 .604 .726 r
.37266 .51995 .37975 .51991 .39081 .51928 .38375 .51967 Mtetra
0 0 0 r
.38375 .51967 .39081 .51928 .40195 .51846 .39492 .51918 Mtetra
.39492 .51918 .40195 .51846 .41315 .5174 .40616 .51841 Mtetra
.40616 .51841 .41315 .5174 .42443 .51605 .41749 .5173 Mtetra
.41749 .5173 .42443 .51605 .43579 .51437 .42888 .51582 Mtetra
.42888 .51582 .43579 .51437 .44721 .51231 .44036 .5139 Mtetra
.44036 .5139 .44721 .51231 .4587 .50984 .4519 .51152 Mtetra
.4519 .51152 .4587 .50984 .47025 .50693 .46351 .50865 Mtetra
.225 .739 .711 r
.46351 .50865 .47025 .50693 .48186 .50356 .47518 .50525 Mtetra
.286 .781 .741 r
.47518 .50525 .48186 .50356 .49353 .49973 .48692 .50133 Mtetra
.351 .823 .773 r
.48692 .50133 .49353 .49973 .50525 .49544 .4987 .49688 Mtetra
.417 .863 .806 r
.4987 .49688 .50525 .49544 .51702 .49069 .51053 .49193 Mtetra
.481 .898 .837 r
.51053 .49193 .51702 .49069 .52883 .48551 .52241 .48648 Mtetra
.542 .928 .865 r
.52241 .48648 .52883 .48551 .54068 .47992 .53432 .48058 Mtetra
.596 .949 .888 r
.53432 .48058 .54068 .47992 .55256 .47396 .54627 .47427 Mtetra
.642 .963 .907 r
.54627 .47427 .55256 .47396 .56447 .46767 .55824 .46759 Mtetra
.68 .97 .921 r
.55824 .46759 .56447 .46767 .57642 .4611 .57025 .4606 Mtetra
.711 .971 .93 r
.57025 .4606 .57642 .4611 .58839 .45431 .58228 .45336 Mtetra
.734 .966 .936 r
.58228 .45336 .58839 .45431 .60039 .44734 .59433 .44593 Mtetra
.75 .958 .939 r
.59433 .44593 .60039 .44734 .61241 .44025 .6064 .43837 Mtetra
.761 .947 .94 r
.6064 .43837 .61241 .44025 .62446 .43308 .6185 .43074 Mtetra
.767 .934 .939 r
.6185 .43074 .62446 .43308 .63654 .4259 .63063 .42309 Mtetra
.77 .92 .937 r
.63063 .42309 .63654 .4259 .64865 .41874 .64278 .41547 Mtetra
.769 .906 .935 r
.64278 .41547 .64865 .41874 .66079 .41164 .65496 .40793 Mtetra
.767 .892 .933 r
.65496 .40793 .66079 .41164 .67296 .40464 .66717 .40051 Mtetra
.762 .877 .93 r
.66717 .40051 .67296 .40464 .68517 .39778 .67942 .39324 Mtetra
.757 .864 .927 r
.67942 .39324 .68517 .39778 .69743 .39106 .69171 .38614 Mtetra
.75 .85 .925 r
.69171 .38614 .69743 .39106 .70972 .38451 .70404 .37924 Mtetra
.744 .838 .923 r
.70404 .37924 .70972 .38451 .72206 .37814 .71641 .37255 Mtetra
.736 .827 .92 r
.71641 .37255 .72206 .37814 .73446 .37196 .72884 .36606 Mtetra
.729 .816 .919 r
.72884 .36606 .73446 .37196 .7469 .36596 .74131 .35979 Mtetra
.722 .806 .917 r
.74131 .35979 .7469 .36596 .7594 .36015 .75385 .35373 Mtetra
.715 .797 .915 r
.75385 .35373 .7594 .36015 .77196 .35451 .76643 .34787 Mtetra
.709 .789 .914 r
.76643 .34787 .77196 .35451 .78457 .34904 .77908 .3422 Mtetra
.703 .782 .913 r
.77908 .3422 .78457 .34904 .79724 .34372 .79179 .33671 Mtetra
.698 .776 .912 r
.79179 .33671 .79724 .34372 .80998 .33854 .80456 .33137 Mtetra
.693 .77 .911 r
.80456 .33137 .80998 .33854 .82278 .33349 .81739 .32619 Mtetra
.688 .765 .911 r
.81739 .32619 .82278 .33349 .83564 .32856 .83029 .32113 Mtetra
.684 .761 .91 r
.83029 .32113 .83564 .32856 .84857 .32372 .84325 .31618 Mtetra
.681 .758 .909 r
.84325 .31618 .84857 .32372 .86156 .31896 .85628 .31132 Mtetra
.678 .755 .909 r
.85628 .31132 .86156 .31896 .87461 .31427 .86937 .30655 Mtetra
.675 .752 .909 r
.86937 .30655 .87461 .31427 .88773 .30964 .88253 .30184 Mtetra
.299 .733 .968 r
.27914 .51793 .28643 .52072 .297 .52035 .28971 .51795 Mtetra
.24 .711 .942 r
.28971 .51795 .297 .52035 .30761 .52013 .30034 .51813 Mtetra
.179 .684 .906 r
.30034 .51813 .30761 .52013 .31829 .52003 .31102 .51845 Mtetra
.119 .653 .862 r
.31102 .51845 .31829 .52003 .32903 .52001 .32176 .51887 Mtetra
.063 .62 .812 r
.32176 .51887 .32903 .52001 .33983 .52005 .33258 .51934 Mtetra
.015 .587 .76 r
.33258 .51934 .33983 .52005 .3507 .52008 .34346 .5198 Mtetra
0 .557 .709 r
.34346 .5198 .3507 .52008 .36164 .52007 .35442 .5202 Mtetra
.053 0 0 r
.35442 .5202 .36164 .52007 .37266 .51995 .36546 .52049 Mtetra
.07 0 0 r
.36546 .52049 .37266 .51995 .38375 .51967 .37658 .52059 Mtetra
.076 0 0 r
.37658 .52059 .38375 .51967 .39492 .51918 .38778 .52043 Mtetra
.072 0 0 r
.38778 .52043 .39492 .51918 .40616 .51841 .39906 .51997 Mtetra
.056 0 0 r
.39906 .51997 .40616 .51841 .41749 .5173 .41043 .51912 Mtetra
.031 0 0 r
.41043 .51912 .41749 .5173 .42888 .51582 .42188 .51784 Mtetra
0 0 0 r
.42188 .51784 .42888 .51582 .44036 .5139 .4334 .51608 Mtetra
.4334 .51608 .44036 .5139 .4519 .51152 .445 .51378 Mtetra
.445 .51378 .4519 .51152 .46351 .50865 .45667 .51093 Mtetra
.45667 .51093 .46351 .50865 .47518 .50525 .46841 .50749 Mtetra
.236 .74 .678 r
.46841 .50749 .47518 .50525 .48692 .50133 .48021 .50347 Mtetra
.31 .791 .719 r
.48021 .50347 .48692 .50133 .4987 .49688 .49206 .49885 Mtetra
.385 .84 .76 r
.49206 .49885 .4987 .49688 .51053 .49193 .50396 .49366 Mtetra
.458 .884 .799 r
.50396 .49366 .51053 .49193 .52241 .48648 .5159 .48793 Mtetra
.527 .92 .834 r
.5159 .48793 .52241 .48648 .53432 .48058 .52789 .48169 Mtetra
.589 .947 .863 r
.52789 .48169 .53432 .48058 .54627 .47427 .5399 .47499 Mtetra
.641 .966 .887 r
.5399 .47499 .54627 .47427 .55824 .46759 .55194 .46789 Mtetra
.684 .975 .904 r
.55194 .46789 .55824 .46759 .57025 .4606 .56401 .46045 Mtetra
.718 .978 .917 r
.56401 .46045 .57025 .4606 .58228 .45336 .5761 .45273 Mtetra
.743 .974 .925 r
.5761 .45273 .58228 .45336 .59433 .44593 .5882 .44481 Mtetra
.761 .967 .929 r
.5882 .44481 .59433 .44593 .6064 .43837 .60033 .43675 Mtetra
.773 .956 .931 r
.60033 .43675 .6064 .43837 .6185 .43074 .61249 .42861 Mtetra
.779 .943 .932 r
.61249 .42861 .6185 .43074 .63063 .42309 .62466 .42046 Mtetra
.782 .928 .931 r
.62466 .42046 .63063 .42309 .64278 .41547 .63685 .41236 Mtetra
.781 .914 .929 r
.63685 .41236 .64278 .41547 .65496 .40793 .64908 .40435 Mtetra
.778 .899 .928 r
.64908 .40435 .65496 .40793 .66717 .40051 .66133 .39648 Mtetra
.773 .884 .926 r
.66133 .39648 .66717 .40051 .67942 .39324 .67362 .38879 Mtetra
.767 .87 .924 r
.67362 .38879 .67942 .39324 .69171 .38614 .68594 .38129 Mtetra
.76 .856 .922 r
.68594 .38129 .69171 .38614 .70404 .37924 .69831 .37402 Mtetra
.752 .843 .92 r
.69831 .37402 .70404 .37924 .71641 .37255 .71072 .36698 Mtetra
.744 .831 .918 r
.71072 .36698 .71641 .37255 .72884 .36606 .72317 .36019 Mtetra
.736 .82 .916 r
.72317 .36019 .72884 .36606 .74131 .35979 .73568 .35363 Mtetra
.729 .81 .915 r
.73568 .35363 .74131 .35979 .75385 .35373 .74825 .34731 Mtetra
.721 .801 .914 r
.74825 .34731 .75385 .35373 .76643 .34787 .76087 .34122 Mtetra
.714 .792 .913 r
.76087 .34122 .76643 .34787 .77908 .3422 .77355 .33534 Mtetra
.707 .785 .912 r
.77355 .33534 .77908 .3422 .79179 .33671 .78629 .32966 Mtetra
.701 .778 .911 r
.78629 .32966 .79179 .33671 .80456 .33137 .79909 .32417 Mtetra
.696 .772 .91 r
.79909 .32417 .80456 .33137 .81739 .32619 .81196 .31883 Mtetra
.691 .767 .91 r
.81196 .31883 .81739 .32619 .83029 .32113 .8249 .31365 Mtetra
.686 .763 .909 r
.8249 .31365 .83029 .32113 .84325 .31618 .8379 .30858 Mtetra
.683 .759 .909 r
.8379 .30858 .84325 .31618 .85628 .31132 .85096 .30363 Mtetra
.679 .756 .909 r
.85096 .30363 .85628 .31132 .86937 .30655 .86409 .29877 Mtetra
.676 .753 .909 r
.86409 .29877 .86937 .30655 .88253 .30184 .87729 .29398 Mtetra
.216 .694 .936 r
.27177 .51538 .27914 .51793 .28971 .51795 .28234 .51582 Mtetra
.147 .661 .895 r
.28234 .51582 .28971 .51795 .30034 .51813 .29296 .51644 Mtetra
.078 .622 .844 r
.29296 .51644 .30034 .51813 .31102 .51845 .30364 .51722 Mtetra
.013 .58 .785 r
.30364 .51722 .31102 .51845 .32176 .51887 .31439 .51809 Mtetra
0 .538 .724 r
.31439 .51809 .32176 .51887 .33258 .51934 .32522 .51902 Mtetra
.091 0 0 r
.32522 .51902 .33258 .51934 .34346 .5198 .33611 .51994 Mtetra
.127 0 0 r
.33611 .51994 .34346 .5198 .35442 .5202 .34709 .52078 Mtetra
.15 0 0 r
.34709 .52078 .35442 .5202 .36546 .52049 .35815 .52149 Mtetra
.162 0 0 r
.35815 .52149 .36546 .52049 .37658 .52059 .3693 .52198 Mtetra
.163 0 0 r
.3693 .52198 .37658 .52059 .38778 .52043 .38053 .52219 Mtetra
.153 0 0 r
.38053 .52219 .38778 .52043 .39906 .51997 .39185 .52204 Mtetra
.132 0 0 r
.39185 .52204 .39906 .51997 .41043 .51912 .40326 .52146 Mtetra
.101 0 0 r
.40326 .52146 .41043 .51912 .42188 .51784 .41476 .52039 Mtetra
.061 0 0 r
.41476 .52039 .42188 .51784 .4334 .51608 .42634 .51877 Mtetra
.01 0 0 r
.42634 .51877 .4334 .51608 .445 .51378 .438 .51656 Mtetra
0 0 0 r
.438 .51656 .445 .51378 .45667 .51093 .44973 .51373 Mtetra
.44973 .51373 .45667 .51093 .46841 .50749 .46154 .51023 Mtetra
.46154 .51023 .46841 .50749 .48021 .50347 .4734 .50608 Mtetra
.278 .763 .672 r
.4734 .50608 .48021 .50347 .49206 .49885 .48533 .50128 Mtetra
.362 .82 .72 r
.48533 .50128 .49206 .49885 .50396 .49366 .4973 .49583 Mtetra
.444 .871 .766 r
.4973 .49583 .50396 .49366 .5159 .48793 .50931 .48978 Mtetra
.52 .914 .807 r
.50931 .48978 .5159 .48793 .52789 .48169 .52137 .48318 Mtetra
.588 .946 .841 r
.52137 .48318 .52789 .48169 .5399 .47499 .53345 .47606 Mtetra
.646 .968 .869 r
.53345 .47606 .5399 .47499 .55194 .46789 .54556 .46851 Mtetra
.692 .98 .889 r
.54556 .46851 .55194 .46789 .56401 .46045 .55769 .46058 Mtetra
.728 .984 .904 r
.55769 .46058 .56401 .46045 .5761 .45273 .56984 .45236 Mtetra
.755 .981 .913 r
.56984 .45236 .5761 .45273 .5882 .44481 .58201 .44391 Mtetra
.774 .973 .919 r
.58201 .44391 .5882 .44481 .60033 .43675 .5942 .43532 Mtetra
.786 .962 .922 r
.5942 .43532 .60033 .43675 .61249 .42861 .6064 .42665 Mtetra
.792 .949 .923 r
.6064 .42665 .61249 .42861 .62466 .42046 .61863 .41798 Mtetra
.794 .934 .923 r
.61863 .41798 .62466 .42046 .63685 .41236 .63087 .40937 Mtetra
.793 .919 .923 r
.63087 .40937 .63685 .41236 .64908 .40435 .64314 .40087 Mtetra
.789 .904 .922 r
.64314 .40087 .64908 .40435 .66133 .39648 .65543 .39253 Mtetra
.784 .889 .92 r
.65543 .39253 .66133 .39648 .67362 .38879 .66776 .38439 Mtetra
.777 .874 .919 r
.66776 .38439 .67362 .38879 .68594 .38129 .68012 .37648 Mtetra
.769 .86 .917 r
.68012 .37648 .68594 .38129 .69831 .37402 .69252 .36882 Mtetra
.761 .847 .916 r
.69252 .36882 .69831 .37402 .71072 .36698 .70497 .36143 Mtetra
.752 .835 .915 r
.70497 .36143 .71072 .36698 .72317 .36019 .71746 .35431 Mtetra
.744 .824 .914 r
.71746 .35431 .72317 .36019 .73568 .35363 .73 .34745 Mtetra
.735 .813 .913 r
.73 .34745 .73568 .35363 .74825 .34731 .7426 .34087 Mtetra
.727 .803 .912 r
.7426 .34087 .74825 .34731 .76087 .34122 .75525 .33454 Mtetra
.719 .795 .911 r
.75525 .33454 .76087 .34122 .77355 .33534 .76797 .32845 Mtetra
.712 .787 .911 r
.76797 .32845 .77355 .33534 .78629 .32966 .78074 .32258 Mtetra
.705 .78 .91 r
.78074 .32258 .78629 .32966 .79909 .32417 .79358 .31691 Mtetra
.699 .774 .91 r
.79358 .31691 .79909 .32417 .81196 .31883 .80649 .31143 Mtetra
.693 .768 .909 r
.80649 .31143 .81196 .31883 .8249 .31365 .81946 .30611 Mtetra
.689 .764 .909 r
.81946 .30611 .8249 .31365 .8379 .30858 .83249 .30093 Mtetra
.684 .76 .909 r
.83249 .30093 .8379 .30858 .85096 .30363 .8456 .29588 Mtetra
.681 .756 .908 r
.8456 .29588 .85096 .30363 .86409 .29877 .85877 .29092 Mtetra
.678 .753 .908 r
.85877 .29092 .86409 .29877 .87729 .29398 .872 .28606 Mtetra
.126 .642 .89 r
.2643 .51307 .27177 .51538 .28234 .51582 .27486 .51396 Mtetra
.048 .597 .834 r
.27486 .51396 .28234 .51582 .29296 .51644 .28548 .51504 Mtetra
0 .548 .768 r
.28548 .51504 .29296 .51644 .30364 .51722 .29617 .51629 Mtetra
.091 0 0 r
.29617 .51629 .30364 .51722 .31439 .51809 .30692 .51765 Mtetra
.146 0 0 r
.30692 .51765 .31439 .51809 .32522 .51902 .31775 .51906 Mtetra
.187 0 0 r
.31775 .51906 .32522 .51902 .33611 .51994 .32866 .52046 Mtetra
.217 0 0 r
.32866 .52046 .33611 .51994 .34709 .52078 .33965 .52177 Mtetra
.234 0 0 r
.33965 .52177 .34709 .52078 .35815 .52149 .35073 .52292 Mtetra
.239 0 0 r
.35073 .52292 .35815 .52149 .3693 .52198 .3619 .52382 Mtetra
.234 0 0 r
.3619 .52382 .3693 .52198 .38053 .52219 .37317 .5244 Mtetra
.219 0 0 r
.37317 .5244 .38053 .52219 .39185 .52204 .38453 .52458 Mtetra
.194 0 0 r
.38453 .52458 .39185 .52204 .40326 .52146 .39598 .52427 Mtetra
.158 0 0 r
.39598 .52427 .40326 .52146 .41476 .52039 .40753 .52341 Mtetra
.113 0 0 r
.40753 .52341 .41476 .52039 .42634 .51877 .41917 .52193 Mtetra
.057 0 0 r
.41917 .52193 .42634 .51877 .438 .51656 .43089 .5198 Mtetra
0 0 0 r
.43089 .5198 .438 .51656 .44973 .51373 .44269 .51696 Mtetra
.44269 .51696 .44973 .51373 .46154 .51023 .45456 .5134 Mtetra
.45456 .5134 .46154 .51023 .4734 .50608 .4665 .50911 Mtetra
.4665 .50911 .4734 .50608 .48533 .50128 .47849 .50408 Mtetra
.35 .808 .69 r
.47849 .50408 .48533 .50128 .4973 .49583 .49054 .49836 Mtetra
.44 .865 .742 r
.49054 .49836 .4973 .49583 .50931 .48978 .50263 .49197 Mtetra
.522 .912 .787 r
.50263 .49197 .50931 .48978 .52137 .48318 .51476 .48497 Mtetra
.595 .948 .825 r
.51476 .48497 .52137 .48318 .53345 .47606 .52691 .47741 Mtetra
.656 .971 .855 r
.52691 .47741 .53345 .47606 .54556 .46851 .5391 .46937 Mtetra
.705 .984 .877 r
.5391 .46937 .54556 .46851 .55769 .46058 .5513 .46093 Mtetra
.742 .988 .892 r
.5513 .46093 .55769 .46058 .56984 .45236 .56352 .45217 Mtetra
.769 .985 .903 r
.56352 .45217 .56984 .45236 .58201 .44391 .57575 .44317 Mtetra
.788 .977 .909 r
.57575 .44317 .58201 .44391 .5942 .43532 .588 .43402 Mtetra
.799 .966 .913 r
.588 .43402 .5942 .43532 .6064 .42665 .60026 .4248 Mtetra
.805 .952 .914 r
.60026 .4248 .6064 .42665 .61863 .41798 .61253 .41559 Mtetra
.807 .938 .915 r
.61253 .41559 .61863 .41798 .63087 .40937 .62483 .40644 Mtetra
.805 .922 .915 r
.62483 .40644 .63087 .40937 .64314 .40087 .63714 .39743 Mtetra
.801 .907 .915 r
.63714 .39743 .64314 .40087 .65543 .39253 .64948 .38861 Mtetra
.795 .892 .914 r
.64948 .38861 .65543 .39253 .66776 .38439 .66185 .38001 Mtetra
.787 .877 .913 r
.66185 .38001 .66776 .38439 .68012 .37648 .67425 .37167 Mtetra
.778 .863 .912 r
.67425 .37167 .68012 .37648 .69252 .36882 .68668 .36362 Mtetra
.769 .85 .912 r
.68668 .36362 .69252 .36882 .70497 .36143 .69917 .35586 Mtetra
.76 .838 .911 r
.69917 .35586 .70497 .36143 .71746 .35431 .71169 .3484 Mtetra
.751 .826 .911 r
.71169 .3484 .71746 .35431 .73 .34745 .72427 .34125 Mtetra
.741 .815 .91 r
.72427 .34125 .73 .34745 .7426 .34087 .7369 .33439 Mtetra
.732 .806 .91 r
.7369 .33439 .7426 .34087 .75525 .33454 .74959 .32781 Mtetra
.724 .797 .909 r
.74959 .32781 .75525 .33454 .76797 .32845 .76234 .3215 Mtetra
.716 .789 .909 r
.76234 .3215 .76797 .32845 .78074 .32258 .77515 .31544 Mtetra
.709 .782 .909 r
.77515 .31544 .78074 .32258 .79358 .31691 .78802 .3096 Mtetra
.702 .775 .908 r
.78802 .3096 .79358 .31691 .80649 .31143 .80096 .30397 Mtetra
.696 .77 .908 r
.80096 .30397 .80649 .31143 .81946 .30611 .81397 .29852 Mtetra
.691 .765 .908 r
.81397 .29852 .81946 .30611 .83249 .30093 .82704 .29322 Mtetra
.686 .761 .908 r
.82704 .29322 .83249 .30093 .8456 .29588 .84019 .28806 Mtetra
.682 .757 .908 r
.84019 .28806 .8456 .29588 .85877 .29092 .8534 .28302 Mtetra
.679 .754 .908 r
.8534 .28302 .85877 .29092 .872 .28606 .86667 .27807 Mtetra
.031 .581 .832 r
.25673 .51097 .2643 .51307 .27486 .51396 .26729 .51232 Mtetra
0 .525 .762 r
.26729 .51232 .27486 .51396 .28548 .51504 .2779 .5139 Mtetra
.124 0 0 r
.2779 .5139 .28548 .51504 .29617 .51629 .28858 .51565 Mtetra
.186 0 0 r
.28858 .51565 .29617 .51629 .30692 .51765 .29934 .51751 Mtetra
.234 0 0 r
.29934 .51751 .30692 .51765 .31775 .51906 .31017 .51943 Mtetra
.27 0 0 r
.31017 .51943 .31775 .51906 .32866 .52046 .32109 .52132 Mtetra
.292 0 0 r
.32109 .52132 .32866 .52046 .33965 .52177 .33209 .52311 Mtetra
.302 0 0 r
.33209 .52311 .33965 .52177 .35073 .52292 .34319 .52472 Mtetra
.34319 .52472 .35073 .52292 .3619 .52382 .35439 .52604 Mtetra
.292 0 0 r
.35439 .52604 .3619 .52382 .37317 .5244 .36569 .527 Mtetra
.272 0 0 r
.36569 .527 .37317 .5244 .38453 .52458 .37709 .5275 Mtetra
.242 0 0 r
.37709 .5275 .38453 .52458 .39598 .52427 .38859 .52746 Mtetra
.202 0 0 r
.38859 .52746 .39598 .52427 .40753 .52341 .40019 .5268 Mtetra
.152 0 0 r
.40019 .5268 .40753 .52341 .41917 .52193 .41188 .52547 Mtetra
.091 0 0 r
.41188 .52547 .41917 .52193 .43089 .5198 .42366 .5234 Mtetra
.019 0 0 r
.42366 .5234 .43089 .5198 .44269 .51696 .43553 .52055 Mtetra
0 0 0 r
.43553 .52055 .44269 .51696 .45456 .5134 .44747 .5169 Mtetra
.44747 .5169 .45456 .5134 .4665 .50911 .45949 .51244 Mtetra
.45949 .51244 .4665 .50911 .47849 .50408 .47156 .50718 Mtetra
.352 .805 .674 r
.47156 .50718 .47849 .50408 .49054 .49836 .48368 .50115 Mtetra
.447 .866 .729 r
.48368 .50115 .49054 .49836 .50263 .49197 .49585 .49439 Mtetra
.535 .916 .777 r
.49585 .49439 .50263 .49197 .51476 .48497 .50806 .48697 Mtetra
.611 .953 .817 r
.50806 .48697 .51476 .48497 .52691 .47741 .52029 .47894 Mtetra
.674 .976 .847 r
.52029 .47894 .52691 .47741 .5391 .46937 .53255 .47039 Mtetra
.723 .989 .868 r
.53255 .47039 .5391 .46937 .5513 .46093 .54482 .46141 Mtetra
.759 .991 .884 r
.54482 .46141 .5513 .46093 .56352 .45217 .55711 .45209 Mtetra
.786 .987 .893 r
.55711 .45209 .56352 .45217 .57575 .44317 .56941 .44252 Mtetra
.803 .979 .9 r
.56941 .44252 .57575 .44317 .588 .43402 .58172 .43279 Mtetra
.814 .967 .903 r
.58172 .43279 .588 .43402 .60026 .4248 .59404 .423 Mtetra
.818 .953 .905 r
.59404 .423 .60026 .4248 .61253 .41559 .60637 .41322 Mtetra
.819 .939 .906 r
.60637 .41322 .61253 .41559 .62483 .40644 .61871 .40353 Mtetra
.817 .923 .907 r
.61871 .40353 .62483 .40644 .63714 .39743 .63108 .394 Mtetra
.812 .908 .907 r
.63108 .394 .63714 .39743 .64948 .38861 .64346 .38468 Mtetra
.805 .893 .907 r
.64346 .38468 .64948 .38861 .66185 .38001 .65587 .37561 Mtetra
.796 .879 .907 r
.65587 .37561 .66185 .38001 .67425 .37167 .66831 .36683 Mtetra
.787 .865 .907 r
.66831 .36683 .67425 .37167 .68668 .36362 .68079 .35837 Mtetra
.777 .852 .907 r
.68079 .35837 .68668 .36362 .69917 .35586 .69331 .35024 Mtetra
.767 .839 .907 r
.69331 .35024 .69917 .35586 .71169 .3484 .70587 .34245 Mtetra
.757 .828 .907 r
.70587 .34245 .71169 .3484 .72427 .34125 .71848 .33499 Mtetra
.747 .817 .907 r
.71848 .33499 .72427 .34125 .7369 .33439 .73115 .32785 Mtetra
.738 .807 .907 r
.73115 .32785 .7369 .33439 .74959 .32781 .74387 .32103 Mtetra
.729 .798 .907 r
.74387 .32103 .74959 .32781 .76234 .3215 .75666 .3145 Mtetra
.72 .79 .907 r
.75666 .3145 .76234 .3215 .77515 .31544 .7695 .30824 Mtetra
.712 .783 .907 r
.7695 .30824 .77515 .31544 .78802 .3096 .78242 .30223 Mtetra
.705 .776 .907 r
.78242 .30223 .78802 .3096 .80096 .30397 .79539 .29645 Mtetra
.699 .771 .907 r
.79539 .29645 .80096 .30397 .81397 .29852 .80844 .29086 Mtetra
.693 .766 .907 r
.80844 .29086 .81397 .29852 .82704 .29322 .82155 .28544 Mtetra
.688 .761 .907 r
.82155 .28544 .82704 .29322 .84019 .28806 .83473 .28018 Mtetra
.684 .758 .907 r
.83473 .28018 .84019 .28806 .8534 .28302 .84798 .27504 Mtetra
.68 .755 .907 r
.84798 .27504 .8534 .28302 .86667 .27807 .8613 .27001 Mtetra
0 .513 .766 r
.24907 .50904 .25673 .51097 .26729 .51232 .25961 .51089 Mtetra
.143 0 0 r
.25961 .51089 .26729 .51232 .2779 .5139 .27022 .51297 Mtetra
.213 0 0 r
.27022 .51297 .2779 .5139 .28858 .51565 .2809 .51523 Mtetra
.268 0 0 r
.2809 .51523 .28858 .51565 .29934 .51751 .29165 .51762 Mtetra
.309 0 0 r
.29165 .51762 .29934 .51751 .31017 .51943 .30248 .52005 Mtetra
.337 0 0 r
.30248 .52005 .31017 .51943 .32109 .52132 .31341 .52246 Mtetra
.353 0 0 r
.31341 .52246 .32109 .52132 .33209 .52311 .32443 .52474 Mtetra
.357 0 0 r
.32443 .52474 .33209 .52311 .34319 .52472 .33555 .5268 Mtetra
.352 0 0 r
.33555 .5268 .34319 .52472 .35439 .52604 .34677 .52855 Mtetra
.337 0 0 r
.34677 .52855 .35439 .52604 .36569 .527 .3581 .52989 Mtetra
.313 0 0 r
.3581 .52989 .36569 .527 .37709 .5275 .36954 .53071 Mtetra
.279 0 0 r
.36954 .53071 .37709 .5275 .38859 .52746 .38108 .53094 Mtetra
.234 0 0 r
.38108 .53094 .38859 .52746 .40019 .5268 .39273 .53048 Mtetra
.179 0 0 r
.39273 .53048 .40019 .5268 .41188 .52547 .40448 .52927 Mtetra
.112 0 0 r
.40448 .52927 .41188 .52547 .42366 .5234 .41633 .52725 Mtetra
.034 0 0 r
.41633 .52725 .42366 .5234 .43553 .52055 .42826 .52437 Mtetra
0 0 0 r
.42826 .52437 .43553 .52055 .44747 .5169 .44028 .52061 Mtetra
.44028 .52061 .44747 .5169 .45949 .51244 .45237 .51596 Mtetra
.45237 .51596 .45949 .51244 .47156 .50718 .46452 .51045 Mtetra
.367 .812 .672 r
.46452 .51045 .47156 .50718 .48368 .50115 .47673 .50409 Mtetra
.468 .876 .729 r
.47673 .50409 .48368 .50115 .49585 .49439 .48898 .49694 Mtetra
.559 .927 .778 r
.48898 .49694 .49585 .49439 .50806 .48697 .50127 .48907 Mtetra
.636 .962 .816 r
.50127 .48907 .50806 .48697 .52029 .47894 .51358 .48055 Mtetra
.698 .983 .844 r
.51358 .48055 .52029 .47894 .53255 .47039 .52592 .47147 Mtetra
.745 .993 .864 r
.52592 .47147 .53255 .47039 .54482 .46141 .53826 .46193 Mtetra
.779 .993 .877 r
.53826 .46193 .54482 .46141 .55711 .45209 .55062 .45202 Mtetra
.804 .988 .886 r
.55062 .45202 .55711 .45209 .56941 .44252 .56299 .44186 Mtetra
.819 .978 .891 r
.56299 .44186 .56941 .44252 .58172 .43279 .57537 .43155 Mtetra
.828 .966 .894 r
.57537 .43155 .58172 .43279 .59404 .423 .58775 .42117 Mtetra
.831 .952 .896 r
.58775 .42117 .59404 .423 .60637 .41322 .60014 .41081 Mtetra
.831 .937 .897 r
.60014 .41081 .60637 .41322 .61871 .40353 .61253 .40057 Mtetra
.827 .922 .898 r
.61253 .40057 .61871 .40353 .63108 .394 .62495 .39051 Mtetra
.822 .907 .899 r
.62495 .39051 .63108 .394 .64346 .38468 .63738 .38068 Mtetra
.814 .893 .899 r
.63738 .38068 .64346 .38468 .65587 .37561 .64984 .37114 Mtetra
.805 .879 .9 r
.64984 .37114 .65587 .37561 .66831 .36683 .66232 .36192 Mtetra
.795 .865 .9 r
.66232 .36192 .66831 .36683 .68079 .35837 .67484 .35305 Mtetra
.785 .852 .901 r
.67484 .35305 .68079 .35837 .69331 .35024 .68739 .34455 Mtetra
.774 .84 .902 r
.68739 .34455 .69331 .35024 .70587 .34245 .69999 .33641 Mtetra
.764 .828 .902 r
.69999 .33641 .70587 .34245 .71848 .33499 .71264 .32865 Mtetra
.753 .818 .903 r
.71264 .32865 .71848 .33499 .73115 .32785 .72535 .32124 Mtetra
.743 .808 .904 r
.72535 .32124 .73115 .32785 .74387 .32103 .73811 .31417 Mtetra
.733 .799 .904 r
.73811 .31417 .74387 .32103 .75666 .3145 .75093 .30742 Mtetra
.724 .791 .905 r
.75093 .30742 .75666 .3145 .7695 .30824 .76381 .30096 Mtetra
.716 .784 .905 r
.76381 .30096 .7695 .30824 .78242 .30223 .77676 .29478 Mtetra
.708 .777 .906 r
.77676 .29478 .78242 .30223 .79539 .29645 .78977 .28885 Mtetra
.702 .771 .906 r
.78977 .28885 .79539 .29645 .80844 .29086 .80285 .28312 Mtetra
.695 .766 .906 r
.80285 .28312 .80844 .29086 .82155 .28544 .816 .27759 Mtetra
.69 .762 .907 r
.816 .27759 .82155 .28544 .83473 .28018 .82922 .27222 Mtetra
.685 .758 .907 r
.82922 .27222 .83473 .28018 .84798 .27504 .84251 .26699 Mtetra
.681 .755 .907 r
.84251 .26699 .84798 .27504 .8613 .27001 .85587 .26187 Mtetra
0 .443 .698 r
.24131 .50725 .24907 .50904 .25961 .51089 .25185 .5096 Mtetra
.225 0 0 r
.25185 .5096 .25961 .51089 .27022 .51297 .26244 .5122 Mtetra
.289 0 0 r
.26244 .5122 .27022 .51297 .2809 .51523 .27311 .51499 Mtetra
.337 0 0 r
.27311 .51499 .2809 .51523 .29165 .51762 .28386 .51791 Mtetra
.371 0 0 r
.28386 .51791 .29165 .51762 .30248 .52005 .29469 .52087 Mtetra
.392 0 0 r
.29469 .52087 .30248 .52005 .31341 .52246 .30562 .52378 Mtetra
.402 0 0 r
.30562 .52378 .31341 .52246 .32443 .52474 .31665 .52656 Mtetra
.401 0 0 r
.31665 .52656 .32443 .52474 .33555 .5268 .32778 .52908 Mtetra
.391 0 0 r
.32778 .52908 .33555 .5268 .34677 .52855 .33903 .53126 Mtetra
.372 0 0 r
.33903 .53126 .34677 .52855 .3581 .52989 .35039 .53297 Mtetra
.344 0 0 r
.35039 .53297 .3581 .52989 .36954 .53071 .36187 .53411 Mtetra
.305 0 0 r
.36187 .53411 .36954 .53071 .38108 .53094 .37346 .53459 Mtetra
.256 0 0 r
.37346 .53459 .38108 .53094 .39273 .53048 .38516 .53432 Mtetra
.195 0 0 r
.38516 .53432 .39273 .53048 .40448 .52927 .39697 .53322 Mtetra
.122 0 0 r
.39697 .53322 .40448 .52927 .41633 .52725 .40888 .53122 Mtetra
.035 0 0 r
.40888 .53122 .41633 .52725 .42826 .52437 .42089 .52829 Mtetra
0 0 0 r
.42089 .52829 .42826 .52437 .44028 .52061 .43298 .52441 Mtetra
.43298 .52441 .44028 .52061 .45237 .51596 .44515 .51955 Mtetra
.44515 .51955 .45237 .51596 .46452 .51045 .45739 .51375 Mtetra
.398 .831 .685 r
.45739 .51375 .46452 .51045 .47673 .50409 .46968 .50705 Mtetra
.502 .895 .742 r
.46968 .50705 .47673 .50409 .48898 .49694 .48201 .49948 Mtetra
.593 .942 .788 r
.48201 .49948 .48898 .49694 .50127 .48907 .49438 .49114 Mtetra
.668 .973 .822 r
.49438 .49114 .50127 .48907 .51358 .48055 .50678 .48211 Mtetra
.727 .99 .847 r
.50678 .48211 .51358 .48055 .52592 .47147 .51919 .47248 Mtetra
.77 .996 .863 r
.51919 .47248 .52592 .47147 .53826 .46193 .53162 .46236 Mtetra
.801 .993 .873 r
.53162 .46236 .53826 .46193 .55062 .45202 .54405 .45187 Mtetra
.822 .986 .879 r
.54405 .45187 .55062 .45202 .56299 .44186 .55649 .44111 Mtetra
.835 .975 .883 r
.55649 .44111 .56299 .44186 .57537 .43155 .56893 .43019 Mtetra
.841 .961 .885 r
.56893 .43019 .57537 .43155 .58775 .42117 .58138 .41922 Mtetra
.843 .947 .887 r
.58138 .41922 .58775 .42117 .60014 .41081 .59383 .40829 Mtetra
.842 .933 .888 r
.59383 .40829 .60014 .41081 .61253 .40057 .60628 .39749 Mtetra
.837 .918 .889 r
.60628 .39749 .61253 .40057 .62495 .39051 .61875 .38689 Mtetra
.831 .904 .89 r
.61875 .38689 .62495 .39051 .63738 .38068 .63123 .37656 Mtetra
.822 .89 .891 r
.63123 .37656 .63738 .38068 .64984 .37114 .64373 .36655 Mtetra
.813 .876 .892 r
.64373 .36655 .64984 .37114 .66232 .36192 .65626 .35689 Mtetra
.803 .863 .894 r
.65626 .35689 .66232 .36192 .67484 .35305 .66882 .34762 Mtetra
.792 .851 .895 r
.66882 .34762 .67484 .35305 .68739 .34455 .68142 .33875 Mtetra
.781 .839 .897 r
.68142 .33875 .68739 .34455 .69999 .33641 .69406 .33028 Mtetra
.769 .828 .898 r
.69406 .33028 .69999 .33641 .71264 .32865 .70675 .32221 Mtetra
.758 .818 .899 r
.70675 .32221 .71264 .32865 .72535 .32124 .71949 .31452 Mtetra
.748 .808 .9 r
.71949 .31452 .72535 .32124 .73811 .31417 .73229 .30721 Mtetra
.738 .799 .901 r
.73229 .30721 .73811 .31417 .75093 .30742 .74514 .30024 Mtetra
.728 .791 .902 r
.74514 .30024 .75093 .30742 .76381 .30096 .75806 .2936 Mtetra
.719 .784 .903 r
.75806 .2936 .76381 .30096 .77676 .29478 .77105 .28725 Mtetra
.711 .777 .904 r
.77105 .28725 .77676 .29478 .78977 .28885 .7841 .28116 Mtetra
.704 .772 .905 r
.7841 .28116 .78977 .28885 .80285 .28312 .79722 .27531 Mtetra
.698 .767 .905 r
.79722 .27531 .80285 .28312 .816 .27759 .81041 .26966 Mtetra
.692 .762 .906 r
.81041 .26966 .816 .27759 .82922 .27222 .82367 .26419 Mtetra
.687 .758 .906 r
.82367 .26419 .82922 .27222 .84251 .26699 .837 .25886 Mtetra
.683 .755 .906 r
.837 .25886 .84251 .26699 .85587 .26187 .8504 .25366 Mtetra
.224 0 0 r
.23347 .50555 .24131 .50725 .25185 .5096 .24398 .5084 Mtetra
.296 0 0 r
.24398 .5084 .25185 .5096 .26244 .5122 .25456 .51152 Mtetra
.352 0 0 r
.25456 .51152 .26244 .5122 .27311 .51499 .26522 .51484 Mtetra
.393 0 0 r
.26522 .51484 .27311 .51499 .28386 .51791 .27596 .51829 Mtetra
.42 0 0 r
.27596 .51829 .28386 .51791 .29469 .52087 .28679 .52178 Mtetra
.435 0 0 r
.28679 .52178 .29469 .52087 .30562 .52378 .29772 .52521 Mtetra
.44 0 0 r
.29772 .52521 .30562 .52378 .31665 .52656 .30876 .52848 Mtetra
.435 0 0 r
.30876 .52848 .31665 .52656 .32778 .52908 .31991 .53146 Mtetra
.421 0 0 r
.31991 .53146 .32778 .52908 .33903 .53126 .33118 .53404 Mtetra
.398 0 0 r
.33118 .53404 .33903 .53126 .35039 .53297 .34258 .53612 Mtetra
.366 0 0 r
.34258 .53612 .35039 .53297 .36187 .53411 .35409 .53757 Mtetra
.323 0 0 r
.35409 .53757 .36187 .53411 .37346 .53459 .36573 .53829 Mtetra
.268 0 0 r
.36573 .53829 .37346 .53459 .38516 .53432 .37748 .53818 Mtetra
.201 0 0 r
.37748 .53818 .38516 .53432 .39697 .53322 .38935 .53717 Mtetra
.119 0 0 r
.38935 .53717 .39697 .53322 .40888 .53122 .40133 .53518 Mtetra
.023 0 0 r
.40133 .53518 .40888 .53122 .42089 .52829 .41341 .53218 Mtetra
0 0 0 r
.41341 .53218 .42089 .52829 .43298 .52441 .42558 .52814 Mtetra
.42558 .52814 .43298 .52441 .44515 .51955 .43783 .52306 Mtetra
.326 .784 .648 r
.43783 .52306 .44515 .51955 .45739 .51375 .45015 .51695 Mtetra
.443 .861 .712 r
.45015 .51695 .45739 .51375 .46968 .50705 .46252 .50987 Mtetra
.548 .92 .766 r
.46252 .50987 .46968 .50705 .48201 .49948 .47494 .50188 Mtetra
.636 .961 .806 r
.47494 .50188 .48201 .49948 .49438 .49114 .4874 .49306 Mtetra
.706 .985 .834 r
.4874 .49306 .49438 .49114 .50678 .48211 .49988 .4835 Mtetra
.759 .995 .853 r
.49988 .4835 .50678 .48211 .51919 .47248 .51238 .47331 Mtetra
.797 .996 .864 r
.51238 .47331 .51919 .47248 .53162 .46236 .52489 .46261 Mtetra
.823 .99 .87 r
.52489 .46261 .53162 .46236 .54405 .45187 .5374 .45151 Mtetra
.84 .98 .874 r
.5374 .45151 .54405 .45187 .55649 .44111 .54991 .44015 Mtetra
.849 .968 .876 r
.54991 .44015 .55649 .44111 .56893 .43019 .56242 .42863 Mtetra
.854 .954 .877 r
.56242 .42863 .56893 .43019 .58138 .41922 .57493 .41706 Mtetra
.854 .94 .878 r
.57493 .41706 .58138 .41922 .59383 .40829 .58744 .40556 Mtetra
.851 .926 .878 r
.58744 .40556 .59383 .40829 .60628 .39749 .59996 .39421 Mtetra
.846 .912 .88 r
.59996 .39421 .60628 .39749 .61875 .38689 .61248 .38308 Mtetra
.838 .898 .881 r
.61248 .38308 .61875 .38689 .63123 .37656 .62501 .37226 Mtetra
.83 .885 .883 r
.62501 .37226 .63123 .37656 .64373 .36655 .63756 .36179 Mtetra
.82 .872 .885 r
.63756 .36179 .64373 .36655 .65626 .35689 .65014 .3517 Mtetra
.809 .86 .887 r
.65014 .3517 .65626 .35689 .66882 .34762 .66274 .34203 Mtetra
.798 .848 .889 r
.66274 .34203 .66882 .34762 .68142 .33875 .67538 .3328 Mtetra
.786 .837 .891 r
.67538 .3328 .68142 .33875 .69406 .33028 .68806 .324 Mtetra
.775 .827 .893 r
.68806 .324 .69406 .33028 .70675 .32221 .70079 .31564 Mtetra
.763 .817 .895 r
.70079 .31564 .70675 .32221 .71949 .31452 .71357 .30769 Mtetra
.752 .807 .897 r
.71357 .30769 .71949 .31452 .73229 .30721 .72641 .30014 Mtetra
.742 .799 .898 r
.72641 .30014 .73229 .30721 .74514 .30024 .7393 .29296 Mtetra
.732 .791 .9 r
.7393 .29296 .74514 .30024 .75806 .2936 .75226 .28613 Mtetra
.722 .784 .901 r
.75226 .28613 .75806 .2936 .77105 .28725 .76528 .27962 Mtetra
.714 .777 .902 r
.76528 .27962 .77105 .28725 .7841 .28116 .77838 .27339 Mtetra
.706 .772 .903 r
.77838 .27339 .7841 .28116 .79722 .27531 .79154 .2674 Mtetra
.7 .767 .904 r
.79154 .2674 .79722 .27531 .81041 .26966 .80477 .26164 Mtetra
.694 .762 .905 r
.80477 .26164 .81041 .26966 .82367 .26419 .81807 .25607 Mtetra
.688 .759 .905 r
.81807 .25607 .82367 .26419 .837 .25886 .83144 .25065 Mtetra
.684 .755 .906 r
.83144 .25065 .837 .25886 .8504 .25366 .84488 .24537 Mtetra
.289 0 0 r
.22553 .50386 .23347 .50555 .24398 .5084 .23603 .50722 Mtetra
.354 0 0 r
.23603 .50722 .24398 .5084 .25456 .51152 .24659 .51086 Mtetra
.403 0 0 r
.24659 .51086 .25456 .51152 .26522 .51484 .25723 .51471 Mtetra
.438 0 0 r
.25723 .51471 .26522 .51484 .27596 .51829 .26797 .51869 Mtetra
.459 0 0 r
.26797 .51869 .27596 .51829 .28679 .52178 .27879 .5227 Mtetra
.47 0 0 r
.27879 .5227 .28679 .52178 .29772 .52521 .28973 .52664 Mtetra
.28973 .52664 .29772 .52521 .30876 .52848 .30077 .53038 Mtetra
.462 0 0 r
.30077 .53038 .30876 .52848 .31991 .53146 .31194 .5338 Mtetra
.444 0 0 r
.31194 .5338 .31991 .53146 .33118 .53404 .32323 .53678 Mtetra
.417 0 0 r
.32323 .53678 .33118 .53404 .34258 .53612 .33465 .5392 Mtetra
.38 0 0 r
.33465 .5392 .34258 .53612 .35409 .53757 .34621 .54094 Mtetra
.332 0 0 r
.34621 .54094 .35409 .53757 .36573 .53829 .35789 .54187 Mtetra
.271 0 0 r
.35789 .54187 .36573 .53829 .37748 .53818 .3697 .54191 Mtetra
.195 0 0 r
.3697 .54191 .37748 .53818 .38935 .53717 .38163 .54096 Mtetra
.103 0 0 r
.38163 .54096 .38935 .53717 .40133 .53518 .39368 .53896 Mtetra
0 0 0 r
.39368 .53896 .40133 .53518 .41341 .53218 .40583 .53586 Mtetra
.40583 .53586 .41341 .53218 .42558 .52814 .41808 .53164 Mtetra
.41808 .53164 .42558 .52814 .43783 .52306 .43041 .52631 Mtetra
.383 .825 .691 r
.43041 .52631 .43783 .52306 .45015 .51695 .44281 .51988 Mtetra
.502 .897 .752 r
.44281 .51988 .45015 .51695 .46252 .50987 .45527 .51242 Mtetra
.603 .948 .797 r
.45527 .51242 .46252 .50987 .47494 .50188 .46778 .50398 Mtetra
.685 .979 .829 r
.46778 .50398 .47494 .50188 .4874 .49306 .48033 .49466 Mtetra
.747 .994 .848 r
.48033 .49466 .4874 .49306 .49988 .4835 .49289 .48456 Mtetra
.791 .997 .86 r
.49289 .48456 .49988 .4835 .51238 .47331 .50548 .47381 Mtetra
.822 .992 .865 r
.50548 .47381 .51238 .47331 .52489 .46261 .51807 .46252 Mtetra
.843 .983 .867 r
.51807 .46252 .52489 .46261 .5374 .45151 .53066 .45083 Mtetra
.855 .971 .868 r
.53066 .45083 .5374 .45151 .54991 .44015 .54325 .43887 Mtetra
.862 .958 .868 r
.54325 .43887 .54991 .44015 .56242 .42863 .55583 .42676 Mtetra
.864 .944 .868 r
.55583 .42676 .56242 .42863 .57493 .41706 .56841 .41461 Mtetra
.863 .93 .868 r
.56841 .41461 .57493 .41706 .58744 .40556 .58098 .40255 Mtetra
.859 .917 .869 r
.58098 .40255 .58744 .40556 .59996 .39421 .59356 .39065 Mtetra
.852 .904 .87 r
.59356 .39065 .59996 .39421 .61248 .38308 .60614 .37902 Mtetra
.844 .891 .872 r
.60614 .37902 .61248 .38308 .62501 .37226 .61872 .36772 Mtetra
.835 .879 .874 r
.61872 .36772 .62501 .37226 .63756 .36179 .63132 .35679 Mtetra
.825 .867 .877 r
.63132 .35679 .63756 .36179 .65014 .3517 .64395 .3463 Mtetra
.814 .855 .879 r
.64395 .3463 .65014 .3517 .66274 .34203 .6566 .33625 Mtetra
.803 .844 .882 r
.6566 .33625 .66274 .34203 .67538 .3328 .66928 .32667 Mtetra
.791 .834 .885 r
.66928 .32667 .67538 .3328 .68806 .324 .682 .31756 Mtetra
.779 .824 .888 r
.682 .31756 .68806 .324 .70079 .31564 .69477 .30891 Mtetra
.767 .815 .89 r
.69477 .30891 .70079 .31564 .71357 .30769 .70759 .30071 Mtetra
.756 .806 .893 r
.70759 .30071 .71357 .30769 .72641 .30014 .72047 .29293 Mtetra
.745 .798 .895 r
.72047 .29293 .72641 .30014 .7393 .29296 .7334 .28556 Mtetra
.735 .79 .897 r
.7334 .28556 .7393 .29296 .75226 .28613 .7464 .27855 Mtetra
.725 .783 .899 r
.7464 .27855 .75226 .28613 .76528 .27962 .75947 .27188 Mtetra
.716 .777 .9 r
.75947 .27188 .76528 .27962 .77838 .27339 .7726 .26551 Mtetra
.708 .772 .901 r
.7726 .26551 .77838 .27339 .79154 .2674 .7858 .2594 Mtetra
.701 .767 .903 r
.7858 .2594 .79154 .2674 .80477 .26164 .79907 .25353 Mtetra
.695 .762 .904 r
.79907 .25353 .80477 .26164 .81807 .25607 .81241 .24786 Mtetra
.69 .759 .904 r
.81241 .24786 .81807 .25607 .83144 .25065 .82583 .24236 Mtetra
.685 .755 .905 r
.82583 .24236 .83144 .25065 .84488 .24537 .83932 .237 Mtetra
.342 0 0 r
.21751 .50213 .22553 .50386 .23603 .50722 .22798 .50599 Mtetra
.401 0 0 r
.22798 .50599 .23603 .50722 .24659 .51086 .23853 .51014 Mtetra
.444 0 0 r
.23853 .51014 .24659 .51086 .25723 .51471 .24916 .51451 Mtetra
.473 0 0 r
.24916 .51451 .25723 .51471 .26797 .51869 .25988 .51901 Mtetra
.49 0 0 r
.25988 .51901 .26797 .51869 .27879 .5227 .2707 .52352 Mtetra
.496 0 0 r
.2707 .52352 .27879 .5227 .28973 .52664 .28164 .52794 Mtetra
.493 0 0 r
.28164 .52794 .28973 .52664 .30077 .53038 .29269 .53213 Mtetra
.481 0 0 r
.29269 .53213 .30077 .53038 .31194 .5338 .30387 .53598 Mtetra
.46 0 0 r
.30387 .53598 .31194 .5338 .32323 .53678 .31518 .53933 Mtetra
.429 0 0 r
.31518 .53933 .32323 .53678 .33465 .5392 .32663 .54207 Mtetra
.387 0 0 r
.32663 .54207 .33465 .5392 .34621 .54094 .33822 .54406 Mtetra
.332 0 0 r
.33822 .54406 .34621 .54094 .35789 .54187 .34995 .54519 Mtetra
.263 0 0 r
.34995 .54519 .35789 .54187 .3697 .54191 .36182 .54534 Mtetra
.176 0 0 r
.36182 .54534 .3697 .54191 .38163 .54096 .37381 .54442 Mtetra
.072 0 0 r
.37381 .54442 .38163 .54096 .39368 .53896 .38592 .54238 Mtetra
0 0 0 r
.38592 .54238 .39368 .53896 .40583 .53586 .39815 .53916 Mtetra
.39815 .53916 .40583 .53586 .41808 .53164 .41048 .53475 Mtetra
.323 .79 .68 r
.41048 .53475 .41808 .53164 .43041 .52631 .42289 .52914 Mtetra
.455 .874 .748 r
.42289 .52914 .43041 .52631 .44281 .51988 .43538 .52238 Mtetra
.57 .934 .798 r
.43538 .52238 .44281 .51988 .45527 .51242 .44793 .51451 Mtetra
.663 .972 .832 r
.44793 .51451 .45527 .51242 .46778 .50398 .46053 .50561 Mtetra
.734 .991 .852 r
.46053 .50561 .46778 .50398 .48033 .49466 .47316 .49579 Mtetra
.785 .996 .862 r
.47316 .49579 .48033 .49466 .49289 .48456 .48582 .48516 Mtetra
.821 .993 .865 r
.48582 .48516 .49289 .48456 .50548 .47381 .49849 .47385 Mtetra
.844 .984 .865 r
.49849 .47385 .50548 .47381 .51807 .46252 .51116 .46198 Mtetra
.86 .971 .864 r
.51116 .46198 .51807 .46252 .53066 .45083 .52383 .44971 Mtetra
.868 .958 .862 r
.52383 .44971 .53066 .45083 .54325 .43887 .5365 .43716 Mtetra
.872 .945 .86 r
.5365 .43716 .54325 .43887 .55583 .42676 .54915 .42447 Mtetra
.872 .931 .859 r
.54915 .42447 .55583 .42676 .56841 .41461 .5618 .41177 Mtetra
.869 .918 .859 r
.5618 .41177 .56841 .41461 .58098 .40255 .57444 .39916 Mtetra
.864 .905 .86 r
.57444 .39916 .58098 .40255 .59356 .39065 .58708 .38675 Mtetra
.857 .893 .861 r
.58708 .38675 .59356 .39065 .60614 .37902 .59972 .37463 Mtetra
.849 .882 .863 r
.59972 .37463 .60614 .37902 .61872 .36772 .61236 .36287 Mtetra
.839 .87 .866 r
.61236 .36287 .61872 .36772 .63132 .35679 .62501 .35152 Mtetra
.829 .86 .869 r
.62501 .35152 .63132 .35679 .64395 .3463 .63769 .34063 Mtetra
.818 .849 .872 r
.63769 .34063 .64395 .3463 .6566 .33625 .65038 .33023 Mtetra
.806 .839 .875 r
.65038 .33023 .6566 .33625 .66928 .32667 .66311 .32032 Mtetra
.795 .83 .879 r
.66311 .32032 .66928 .32667 .682 .31756 .67588 .31092 Mtetra
.783 .821 .882 r
.67588 .31092 .682 .31756 .69477 .30891 .68869 .302 Mtetra
.771 .812 .886 r
.68869 .302 .69477 .30891 .70759 .30071 .70156 .29356 Mtetra
.759 .804 .889 r
.70156 .29356 .70759 .30071 .72047 .29293 .71447 .28558 Mtetra
.748 .796 .891 r
.71447 .28558 .72047 .29293 .7334 .28556 .72745 .27801 Mtetra
.737 .789 .894 r
.72745 .27801 .7334 .28556 .7464 .27855 .74049 .27084 Mtetra
.728 .782 .896 r
.74049 .27084 .7464 .27855 .75947 .27188 .75359 .26402 Mtetra
.718 .776 .898 r
.75359 .26402 .75947 .27188 .7726 .26551 .76677 .25752 Mtetra
.71 .771 .9 r
.76677 .25752 .7726 .26551 .7858 .2594 .78001 .25129 Mtetra
.703 .766 .901 r
.78001 .25129 .7858 .2594 .79907 .25353 .79332 .24532 Mtetra
.696 .762 .902 r
.79332 .24532 .79907 .25353 .81241 .24786 .80671 .23956 Mtetra
.691 .758 .903 r
.80671 .23956 .81241 .24786 .82583 .24236 .82017 .23397 Mtetra
.686 .755 .904 r
.82017 .23397 .82583 .24236 .83932 .237 .8337 .22854 Mtetra
.385 0 0 r
.20941 .50028 .21751 .50213 .22798 .50599 .21986 .50462 Mtetra
.438 0 0 r
.21986 .50462 .22798 .50599 .23853 .51014 .23039 .50927 Mtetra
.476 0 0 r
.23039 .50927 .23853 .51014 .24916 .51451 .241 .51414 Mtetra
.5 0 0 r
.241 .51414 .24916 .51451 .25988 .51901 .25171 .51912 Mtetra
.513 0 0 r
.25171 .51912 .25988 .51901 .2707 .52352 .26253 .52411 Mtetra
.516 0 0 r
.26253 .52411 .2707 .52352 .28164 .52794 .27346 .52899 Mtetra
.51 0 0 r
.27346 .52899 .28164 .52794 .29269 .53213 .28452 .53361 Mtetra
.494 0 0 r
.28452 .53361 .29269 .53213 .30387 .53598 .29571 .53784 Mtetra
.469 0 0 r
.29571 .53784 .30387 .53598 .31518 .53933 .30705 .54154 Mtetra
.434 0 0 r
.30705 .54154 .31518 .53933 .32663 .54207 .31853 .54457 Mtetra
.385 0 0 r
.31853 .54457 .32663 .54207 .33822 .54406 .33015 .54678 Mtetra
.323 0 0 r
.33015 .54678 .33822 .54406 .34995 .54519 .34193 .54806 Mtetra
.242 0 0 r
.34193 .54806 .34995 .54519 .36182 .54534 .35384 .54829 Mtetra
.142 0 0 r
.35384 .54829 .36182 .54534 .37381 .54442 .3659 .54738 Mtetra
.022 0 0 r
.3659 .54738 .37381 .54442 .38592 .54238 .37808 .54527 Mtetra
0 0 0 r
.37808 .54527 .38592 .54238 .39815 .53916 .39038 .54191 Mtetra
.263 .756 .68 r
.39038 .54191 .39815 .53916 .41048 .53475 .40279 .53727 Mtetra
.407 .851 .754 r
.40279 .53727 .41048 .53475 .42289 .52914 .41529 .53138 Mtetra
.535 .921 .809 r
.41529 .53138 .42289 .52914 .43538 .52238 .42786 .52426 Mtetra
.64 .966 .845 r
.42786 .52426 .43538 .52238 .44793 .51451 .4405 .51598 Mtetra
.72 .988 .864 r
.4405 .51598 .44793 .51451 .46053 .50561 .45319 .50663 Mtetra
.778 .995 .871 r
.45319 .50663 .46053 .50561 .47316 .49579 .46591 .49631 Mtetra
.818 .991 .871 r
.46591 .49631 .47316 .49579 .48582 .48516 .47865 .48515 Mtetra
.845 .981 .868 r
.47865 .48515 .48582 .48516 .49849 .47385 .49141 .47329 Mtetra
.862 .969 .863 r
.49141 .47329 .49849 .47385 .51116 .46198 .50417 .46086 Mtetra
.872 .955 .859 r
.50417 .46086 .51116 .46198 .52383 .44971 .51692 .44802 Mtetra
.877 .942 .855 r
.51692 .44802 .52383 .44971 .5365 .43716 .52966 .43491 Mtetra
.878 .928 .852 r
.52966 .43491 .5365 .43716 .54915 .42447 .5424 .42167 Mtetra
.877 .915 .85 r
.5424 .42167 .54915 .42447 .5618 .41177 .55512 .40843 Mtetra
.873 .903 .85 r
.55512 .40843 .5618 .41177 .57444 .39916 .56782 .39532 Mtetra
.867 .892 .85 r
.56782 .39532 .57444 .39916 .58708 .38675 .58052 .38242 Mtetra
.86 .881 .852 r
.58052 .38242 .58708 .38675 .59972 .37463 .59322 .36985 Mtetra
.852 .871 .854 r
.59322 .36985 .59972 .37463 .61236 .36287 .60592 .35766 Mtetra
.842 .861 .857 r
.60592 .35766 .61236 .36287 .62501 .35152 .61863 .34592 Mtetra
.832 .851 .861 r
.61863 .34592 .62501 .35152 .63769 .34063 .63135 .33467 Mtetra
.821 .842 .865 r
.63135 .33467 .63769 .34063 .65038 .33023 .6441 .32393 Mtetra
.809 .833 .869 r
.6441 .32393 .65038 .33023 .66311 .32032 .65688 .31372 Mtetra
.797 .825 .873 r
.65688 .31372 .66311 .32032 .67588 .31092 .66969 .30404 Mtetra
.785 .816 .877 r
.66969 .30404 .67588 .31092 .68869 .302 .68255 .29489 Mtetra
.773 .808 .881 r
.68255 .29489 .68869 .302 .70156 .29356 .69546 .28623 Mtetra
.762 .801 .885 r
.69546 .28623 .70156 .29356 .71447 .28558 .70842 .27805 Mtetra
.75 .794 .888 r
.70842 .27805 .71447 .28558 .72745 .27801 .72144 .27031 Mtetra
.74 .787 .891 r
.72144 .27031 .72745 .27801 .74049 .27084 .73452 .26298 Mtetra
.729 .781 .894 r
.73452 .26298 .74049 .27084 .75359 .26402 .74766 .25603 Mtetra
.72 .775 .896 r
.74766 .25603 .75359 .26402 .76677 .25752 .76088 .2494 Mtetra
.712 .77 .898 r
.76088 .2494 .76677 .25752 .78001 .25129 .77417 .24307 Mtetra
.704 .766 .9 r
.77417 .24307 .78001 .25129 .79332 .24532 .78752 .237 Mtetra
.697 .762 .901 r
.78752 .237 .79332 .24532 .80671 .23956 .80095 .23115 Mtetra
.692 .758 .903 r
.80095 .23115 .80671 .23956 .82017 .23397 .81445 .22549 Mtetra
.686 .755 .904 r
.81445 .22549 .82017 .23397 .8337 .22854 .82803 .21999 Mtetra
.417 0 0 r
.20123 .49823 .20941 .50028 .21986 .50462 .21167 .50303 Mtetra
.466 0 0 r
.21167 .50303 .21986 .50462 .23039 .50927 .22217 .50814 Mtetra
.499 0 0 r
.22217 .50814 .23039 .50927 .241 .51414 .23277 .51348 Mtetra
.52 0 0 r
.23277 .51348 .241 .51414 .25171 .51912 .24347 .51892 Mtetra
.53 0 0 r
.24347 .51892 .25171 .51912 .26253 .52411 .25428 .52436 Mtetra
.25428 .52436 .26253 .52411 .27346 .52899 .26521 .52965 Mtetra
.52 0 0 r
.26521 .52965 .27346 .52899 .28452 .53361 .27627 .53467 Mtetra
.501 0 0 r
.27627 .53467 .28452 .53361 .29571 .53784 .28748 .53925 Mtetra
.472 0 0 r
.28748 .53925 .29571 .53784 .30705 .54154 .29883 .54325 Mtetra
.43 0 0 r
.29883 .54325 .30705 .54154 .31853 .54457 .31034 .54652 Mtetra
.374 0 0 r
.31034 .54652 .31853 .54457 .33015 .54678 .32201 .54891 Mtetra
.301 0 0 r
.32201 .54891 .33015 .54678 .34193 .54806 .33383 .55031 Mtetra
.207 0 0 r
.33383 .55031 .34193 .54806 .35384 .54829 .34579 .55059 Mtetra
.09 0 0 r
.34579 .55059 .35384 .54829 .3659 .54738 .35791 .54966 Mtetra
0 0 0 r
.35791 .54966 .3659 .54738 .37808 .54527 .37016 .54744 Mtetra
.203 .721 .69 r
.37016 .54744 .37808 .54527 .39038 .54191 .38253 .54391 Mtetra
.359 .827 .771 r
.38253 .54391 .39038 .54191 .40279 .53727 .39502 .53903 Mtetra
.5 .907 .831 r
.39502 .53903 .40279 .53727 .41529 .53138 .4076 .53283 Mtetra
.617 .958 .867 r
.4076 .53283 .41529 .53138 .42786 .52426 .42026 .52535 Mtetra
.705 .984 .884 r
.42026 .52535 .42786 .52426 .4405 .51598 .43299 .51666 Mtetra
.769 .991 .887 r
.43299 .51666 .4405 .51598 .45319 .50663 .44577 .50685 Mtetra
.813 .987 .883 r
.44577 .50685 .45319 .50663 .46591 .49631 .45858 .49605 Mtetra
.842 .977 .875 r
.45858 .49605 .46591 .49631 .47865 .48515 .47141 .48438 Mtetra
.861 .963 .867 r
.47141 .48438 .47865 .48515 .49141 .47329 .48425 .47198 Mtetra
.873 .949 .859 r
.48425 .47198 .49141 .47329 .50417 .46086 .49709 .45902 Mtetra
.879 .935 .852 r
.49709 .45902 .50417 .46086 .51692 .44802 .50993 .44565 Mtetra
.882 .922 .846 r
.50993 .44565 .51692 .44802 .52966 .43491 .52275 .43201 Mtetra
.881 .91 .843 r
.52275 .43201 .52966 .43491 .5424 .42167 .53556 .41826 Mtetra
.879 .898 .841 r
.53556 .41826 .5424 .42167 .55512 .40843 .54835 .40453 Mtetra
.874 .887 .84 r
.54835 .40453 .55512 .40843 .56782 .39532 .56113 .39094 Mtetra
.868 .877 .841 r
.56113 .39094 .56782 .39532 .58052 .38242 .57389 .3776 Mtetra
.861 .868 .843 r
.57389 .3776 .58052 .38242 .59322 .36985 .58665 .3646 Mtetra
.853 .859 .845 r
.58665 .3646 .59322 .36985 .60592 .35766 .59941 .35203 Mtetra
.843 .85 .849 r
.59941 .35203 .60592 .35766 .61863 .34592 .61217 .33993 Mtetra
.833 .842 .853 r
.61217 .33993 .61863 .34592 .63135 .33467 .62495 .32835 Mtetra
.822 .834 .858 r
.62495 .32835 .63135 .33467 .6441 .32393 .63775 .31731 Mtetra
.811 .826 .862 r
.63775 .31731 .6441 .32393 .65688 .31372 .65058 .30684 Mtetra
.799 .819 .867 r
.65058 .30684 .65688 .31372 .66969 .30404 .66344 .29692 Mtetra
.787 .811 .872 r
.66344 .29692 .66969 .30404 .68255 .29489 .67634 .28754 Mtetra
.775 .804 .876 r
.67634 .28754 .68255 .29489 .69546 .28623 .68929 .27869 Mtetra
.763 .797 .881 r
.68929 .27869 .69546 .28623 .70842 .27805 .7023 .27033 Mtetra
.752 .791 .884 r
.7023 .27033 .70842 .27805 .72144 .27031 .71536 .26244 Mtetra
.741 .785 .888 r
.71536 .26244 .72144 .27031 .73452 .26298 .72849 .25498 Mtetra
.731 .779 .891 r
.72849 .25498 .73452 .26298 .74766 .25603 .74168 .2479 Mtetra
.722 .774 .894 r
.74168 .2479 .74766 .25603 .76088 .2494 .75494 .24116 Mtetra
.713 .769 .896 r
.75494 .24116 .76088 .2494 .77417 .24307 .76827 .23474 Mtetra
.705 .765 .898 r
.76827 .23474 .77417 .24307 .78752 .237 .78167 .22858 Mtetra
.698 .761 .9 r
.78167 .22858 .78752 .237 .80095 .23115 .79514 .22265 Mtetra
.692 .757 .902 r
.79514 .22265 .80095 .23115 .81445 .22549 .80869 .21691 Mtetra
.687 .755 .903 r
.80869 .21691 .81445 .22549 .82803 .21999 .82231 .21134 Mtetra
.44 0 0 r
.193 .4959 .20123 .49823 .21167 .50303 .20341 .50113 Mtetra
.485 0 0 r
.20341 .50113 .21167 .50303 .22217 .50814 .2139 .50667 Mtetra
.515 0 0 r
.2139 .50667 .22217 .50814 .23277 .51348 .22448 .51243 Mtetra
.533 0 0 r
.22448 .51243 .23277 .51348 .24347 .51892 .23516 .51829 Mtetra
.54 0 0 r
.23516 .51829 .24347 .51892 .25428 .52436 .24596 .52413 Mtetra
.537 0 0 r
.24596 .52413 .25428 .52436 .26521 .52965 .25689 .5298 Mtetra
.524 0 0 r
.25689 .5298 .26521 .52965 .27627 .53467 .26796 .53515 Mtetra
.501 0 0 r
.26796 .53515 .27627 .53467 .28748 .53925 .27918 .54004 Mtetra
.466 0 0 r
.27918 .54004 .28748 .53925 .29883 .54325 .29056 .54429 Mtetra
.417 0 0 r
.29056 .54429 .29883 .54325 .31034 .54652 .30209 .54776 Mtetra
.351 0 0 r
.30209 .54776 .31034 .54652 .32201 .54891 .31379 .55029 Mtetra
.263 0 0 r
.31379 .55029 .32201 .54891 .33383 .55031 .32566 .55176 Mtetra
.151 0 0 r
.32566 .55176 .33383 .55031 .34579 .55059 .33768 .55205 Mtetra
.013 0 0 r
.33768 .55205 .34579 .55059 .35791 .54966 .34985 .55106 Mtetra
.145 .685 .71 r
.34985 .55106 .35791 .54966 .37016 .54744 .36217 .54871 Mtetra
.309 .8 .796 r
.36217 .54871 .37016 .54744 .38253 .54391 .37462 .54498 Mtetra
.462 .889 .86 r
.37462 .54498 .38253 .54391 .39502 .53903 .38718 .53985 Mtetra
.59 .947 .896 r
.38718 .53985 .39502 .53903 .4076 .53283 .39984 .53333 Mtetra
.688 .975 .91 r
.39984 .53333 .4076 .53283 .42026 .52535 .41259 .52549 Mtetra
.757 .983 .908 r
.41259 .52549 .42026 .52535 .43299 .51666 .42541 .51639 Mtetra
.805 .979 .899 r
.42541 .51639 .43299 .51666 .44577 .50685 .43827 .50614 Mtetra
.837 .968 .886 r
.43827 .50614 .44577 .50685 .45858 .49605 .45117 .49486 Mtetra
.858 .954 .873 r
.45117 .49486 .45858 .49605 .47141 .48438 .46409 .48271 Mtetra
.871 .94 .861 r
.46409 .48271 .47141 .48438 .48425 .47198 .47702 .46982 Mtetra
.878 .925 .851 r
.47702 .46982 .48425 .47198 .49709 .45902 .48994 .45636 Mtetra
.882 .912 .843 r
.48994 .45636 .49709 .45902 .50993 .44565 .50286 .44249 Mtetra
.883 .9 .837 r
.50286 .44249 .50993 .44565 .52275 .43201 .51576 .42837 Mtetra
.881 .889 .833 r
.51576 .42837 .52275 .43201 .53556 .41826 .52864 .41414 Mtetra
.878 .879 .831 r
.52864 .41414 .53556 .41826 .54835 .40453 .54151 .39996 Mtetra
.873 .87 .831 r
.54151 .39996 .54835 .40453 .56113 .39094 .55435 .38595 Mtetra
.867 .861 .832 r
.55435 .38595 .56113 .39094 .57389 .3776 .56718 .37221 Mtetra
.86 .853 .834 r
.56718 .37221 .57389 .3776 .58665 .3646 .58 .35885 Mtetra
.852 .846 .837 r
.58 .35885 .58665 .3646 .59941 .35203 .59282 .34593 Mtetra
.843 .839 .841 r
.59282 .34593 .59941 .35203 .61217 .33993 .60564 .33352 Mtetra
.833 .832 .846 r
.60564 .33352 .61217 .33993 .62495 .32835 .61848 .32165 Mtetra
.822 .825 .851 r
.61848 .32165 .62495 .32835 .63775 .31731 .63133 .31035 Mtetra
.811 .818 .856 r
.63133 .31035 .63775 .31731 .65058 .30684 .6442 .29964 Mtetra
.8 .812 .861 r
.6442 .29964 .65058 .30684 .66344 .29692 .65711 .28951 Mtetra
.788 .806 .867 r
.65711 .28951 .66344 .29692 .67634 .28754 .67007 .27994 Mtetra
.776 .799 .872 r
.67007 .27994 .67634 .28754 .68929 .27869 .68306 .27092 Mtetra
.764 .793 .877 r
.68306 .27092 .68929 .27869 .7023 .27033 .69612 .26242 Mtetra
.753 .788 .881 r
.69612 .26242 .7023 .27033 .71536 .26244 .70922 .25439 Mtetra
.742 .782 .885 r
.70922 .25439 .71536 .26244 .72849 .25498 .72239 .2468 Mtetra
.732 .777 .889 r
.72239 .2468 .72849 .25498 .74168 .2479 .73563 .23962 Mtetra
.722 .772 .892 r
.73563 .23962 .74168 .2479 .75494 .24116 .74893 .23279 Mtetra
.714 .768 .895 r
.74893 .23279 .75494 .24116 .76827 .23474 .76231 .22627 Mtetra
.706 .764 .897 r
.76231 .22627 .76827 .23474 .78167 .22858 .77576 .22003 Mtetra
.699 .76 .899 r
.77576 .22003 .78167 .22858 .79514 .22265 .78927 .21403 Mtetra
.693 .757 .901 r
.78927 .21403 .79514 .22265 .80869 .21691 .80287 .20823 Mtetra
.688 .754 .902 r
.80287 .20823 .80869 .21691 .82231 .21134 .81653 .2026 Mtetra
.454 0 0 r
.18471 .4932 .193 .4959 .20341 .50113 .1951 .49881 Mtetra
.495 0 0 r
.1951 .49881 .20341 .50113 .2139 .50667 .20557 .50474 Mtetra
.523 0 0 r
.20557 .50474 .2139 .50667 .22448 .51243 .21613 .51088 Mtetra
.538 0 0 r
.21613 .51088 .22448 .51243 .23516 .51829 .2268 .51711 Mtetra
.543 0 0 r
.2268 .51711 .23516 .51829 .24596 .52413 .23759 .52329 Mtetra
.537 0 0 r
.23759 .52329 .24596 .52413 .25689 .5298 .24852 .52928 Mtetra
.52 0 0 r
.24852 .52928 .25689 .5298 .26796 .53515 .2596 .53493 Mtetra
.492 0 0 r
.2596 .53493 .26796 .53515 .27918 .54004 .27083 .54006 Mtetra
.45 0 0 r
.27083 .54006 .27918 .54004 .29056 .54429 .28223 .54451 Mtetra
.391 0 0 r
.28223 .54451 .29056 .54429 .30209 .54776 .29379 .54812 Mtetra
.311 0 0 r
.29379 .54812 .30209 .54776 .31379 .55029 .30553 .55075 Mtetra
.205 0 0 r
.30553 .55075 .31379 .55029 .32566 .55176 .31744 .55225 Mtetra
.071 0 0 r
.31744 .55225 .32566 .55176 .33768 .55205 .32951 .5525 Mtetra
.088 .647 .735 r
.32951 .5525 .33768 .55205 .34985 .55106 .34175 .55141 Mtetra
.259 .769 .827 r
.34175 .55141 .34985 .55106 .36217 .54871 .35413 .54891 Mtetra
.422 .865 .893 r
.35413 .54891 .36217 .54871 .37462 .54498 .36665 .54496 Mtetra
.56 .928 .929 r
.36665 .54496 .37462 .54498 .38718 .53985 .37929 .53955 Mtetra
.665 .96 .939 r
.37929 .53955 .38718 .53985 .39984 .53333 .39203 .53272 Mtetra
.741 .969 .932 r
.39203 .53272 .39984 .53333 .41259 .52549 .40486 .52451 Mtetra
.793 .965 .917 r
.40486 .52451 .41259 .52549 .42541 .51639 .41776 .51501 Mtetra
.827 .954 .899 r
.41776 .51501 .42541 .51639 .43827 .50614 .43071 .50434 Mtetra
.85 .94 .881 r
.43071 .50434 .43827 .50614 .45117 .49486 .44369 .49262 Mtetra
.865 .925 .865 r
.44369 .49262 .45117 .49486 .46409 .48271 .4567 .48001 Mtetra
.874 .912 .852 r
.4567 .48001 .46409 .48271 .47702 .46982 .46971 .46666 Mtetra
.879 .899 .841 r
.46971 .46666 .47702 .46982 .48994 .45636 .48272 .45275 Mtetra
.881 .887 .833 r
.48272 .45275 .48994 .45636 .50286 .44249 .49572 .43843 Mtetra
.88 .877 .827 r
.49572 .43843 .50286 .44249 .51576 .42837 .50869 .42388 Mtetra
.878 .867 .824 r
.50869 .42388 .51576 .42837 .52864 .41414 .52165 .40925 Mtetra
.875 .859 .822 r
.52165 .40925 .52864 .41414 .54151 .39996 .53459 .39467 Mtetra
.87 .852 .822 r
.53459 .39467 .54151 .39996 .55435 .38595 .5475 .38029 Mtetra
.865 .845 .823 r
.5475 .38029 .55435 .38595 .56718 .37221 .5604 .36621 Mtetra
.858 .838 .825 r
.5604 .36621 .56718 .37221 .58 .35885 .57328 .35253 Mtetra
.85 .832 .829 r
.57328 .35253 .58 .35885 .59282 .34593 .58616 .33932 Mtetra
.841 .826 .834 r
.58616 .33932 .59282 .34593 .60564 .33352 .59904 .32664 Mtetra
.832 .821 .839 r
.59904 .32664 .60564 .33352 .61848 .32165 .61193 .31453 Mtetra
.821 .816 .844 r
.61193 .31453 .61848 .32165 .63133 .31035 .62483 .30302 Mtetra
.811 .81 .85 r
.62483 .30302 .63133 .31035 .6442 .29964 .63776 .29211 Mtetra
.799 .805 .856 r
.63776 .29211 .6442 .29964 .65711 .28951 .65072 .2818 Mtetra
.788 .799 .862 r
.65072 .2818 .65711 .28951 .67007 .27994 .66372 .27208 Mtetra
.776 .794 .868 r
.66372 .27208 .67007 .27994 .68306 .27092 .67677 .26292 Mtetra
.765 .789 .873 r
.67677 .26292 .68306 .27092 .69612 .26242 .68987 .25429 Mtetra
.753 .784 .878 r
.68987 .25429 .69612 .26242 .70922 .25439 .70303 .24615 Mtetra
.743 .779 .882 r
.70303 .24615 .70922 .25439 .72239 .2468 .71624 .23846 Mtetra
.732 .774 .886 r
.71624 .23846 .72239 .2468 .73563 .23962 .72952 .23118 Mtetra
.723 .77 .89 r
.72952 .23118 .73563 .23962 .74893 .23279 .74288 .22427 Mtetra
.714 .766 .893 r
.74288 .22427 .74893 .23279 .76231 .22627 .7563 .21768 Mtetra
.706 .762 .896 r
.7563 .21768 .76231 .22627 .77576 .22003 .76979 .21137 Mtetra
.699 .759 .898 r
.76979 .21137 .77576 .22003 .78927 .21403 .78335 .2053 Mtetra
.693 .756 .9 r
.78335 .2053 .78927 .21403 .80287 .20823 .79699 .19944 Mtetra
.688 .753 .901 r
.79699 .19944 .80287 .20823 .81653 .2026 .81071 .19375 Mtetra
.459 0 0 r
.17637 .49005 .18471 .4932 .1951 .49881 .18674 .496 Mtetra
.497 0 0 r
.18674 .496 .1951 .49881 .20557 .50474 .19719 .50225 Mtetra
.522 0 0 r
.19719 .50225 .20557 .50474 .21613 .51088 .20774 .50871 Mtetra
.535 0 0 r
.20774 .50871 .21613 .51088 .2268 .51711 .2184 .51525 Mtetra
.537 0 0 r
.2184 .51525 .2268 .51711 .23759 .52329 .22919 .52173 Mtetra
.527 0 0 r
.22919 .52173 .23759 .52329 .24852 .52928 .24012 .52798 Mtetra
.506 0 0 r
.24012 .52798 .24852 .52928 .2596 .53493 .2512 .53385 Mtetra
.471 0 0 r
.2512 .53385 .2596 .53493 .27083 .54006 .26245 .53916 Mtetra
.419 0 0 r
.26245 .53916 .27083 .54006 .28223 .54451 .27387 .54376 Mtetra
.346 0 0 r
.27387 .54376 .28223 .54451 .29379 .54812 .28546 .54746 Mtetra
.247 0 0 r
.28546 .54746 .29379 .54812 .30553 .55075 .29723 .55012 Mtetra
.119 0 0 r
.29723 .55012 .30553 .55075 .31744 .55225 .30918 .5516 Mtetra
.036 .605 .763 r
.30918 .5516 .31744 .55225 .32951 .5525 .32131 .55177 Mtetra
.209 .729 .858 r
.32131 .55177 .32951 .5525 .34175 .55141 .3336 .55055 Mtetra
.378 .831 .926 r
.3336 .55055 .34175 .55141 .35413 .54891 .34605 .54786 Mtetra
.523 .899 .96 r
.34605 .54786 .35413 .54891 .36665 .54496 .35863 .54368 Mtetra
.636 .934 .967 r
.35863 .54368 .36665 .54496 .37929 .53955 .37135 .53799 Mtetra
.718 .946 .955 r
.37135 .53799 .37929 .53955 .39203 .53272 .38417 .53084 Mtetra
.774 .943 .934 r
.38417 .53084 .39203 .53272 .40486 .52451 .39708 .52228 Mtetra
.812 .933 .912 r
.39708 .52228 .40486 .52451 .41776 .51501 .41006 .5124 Mtetra
.837 .92 .89 r
.41006 .5124 .41776 .51501 .43071 .50434 .42309 .50133 Mtetra
.853 .907 .87 r
.42309 .50133 .43071 .50434 .44369 .49262 .43616 .48921 Mtetra
.864 .894 .854 r
.43616 .48921 .44369 .49262 .4567 .48001 .44925 .47618 Mtetra
.871 .882 .841 r
.44925 .47618 .4567 .48001 .46971 .46666 .46234 .46243 Mtetra
.874 .871 .83 r
.46234 .46243 .46971 .46666 .48272 .45275 .47543 .44811 Mtetra
.876 .861 .823 r
.47543 .44811 .48272 .45275 .49572 .43843 .4885 .43341 Mtetra
.875 .853 .817 r
.4885 .43341 .49572 .43843 .50869 .42388 .50156 .41848 Mtetra
.873 .846 .814 r
.50156 .41848 .50869 .42388 .52165 .40925 .51459 .4035 Mtetra
.87 .839 .812 r
.51459 .4035 .52165 .40925 .53459 .39467 .52759 .38859 Mtetra
.866 .833 .813 r
.52759 .38859 .53459 .39467 .5475 .38029 .54058 .37391 Mtetra
.86 .828 .814 r
.54058 .37391 .5475 .38029 .5604 .36621 .55354 .35954 Mtetra
.854 .823 .818 r
.55354 .35954 .5604 .36621 .57328 .35253 .56649 .3456 Mtetra
.846 .819 .822 r
.56649 .3456 .57328 .35253 .58616 .33932 .57943 .33216 Mtetra
.838 .814 .827 r
.57943 .33216 .58616 .33932 .59904 .32664 .59236 .31927 Mtetra
.829 .81 .832 r
.59236 .31927 .59904 .32664 .61193 .31453 .60531 .30697 Mtetra
.819 .806 .838 r
.60531 .30697 .61193 .31453 .62483 .30302 .61827 .29529 Mtetra
.809 .802 .845 r
.61827 .29529 .62483 .30302 .63776 .29211 .63125 .28422 Mtetra
.798 .797 .851 r
.63125 .28422 .63776 .29211 .65072 .2818 .64427 .27378 Mtetra
.787 .793 .857 r
.64427 .27378 .65072 .2818 .66372 .27208 .65732 .26393 Mtetra
.776 .789 .864 r
.65732 .26393 .66372 .27208 .67677 .26292 .67041 .25466 Mtetra
.764 .784 .869 r
.67041 .25466 .67677 .26292 .68987 .25429 .68356 .24593 Mtetra
.753 .78 .875 r
.68356 .24593 .68987 .25429 .70303 .24615 .69676 .2377 Mtetra
.743 .776 .88 r
.69676 .2377 .70303 .24615 .71624 .23846 .71003 .22994 Mtetra
.733 .772 .884 r
.71003 .22994 .71624 .23846 .72952 .23118 .72336 .22259 Mtetra
.723 .768 .888 r
.72336 .22259 .72952 .23118 .74288 .22427 .73676 .2156 Mtetra
.714 .764 .892 r
.73676 .2156 .74288 .22427 .7563 .21768 .75022 .20895 Mtetra
.706 .761 .894 r
.75022 .20895 .7563 .21768 .76979 .21137 .76376 .20258 Mtetra
.699 .758 .897 r
.76376 .20258 .76979 .21137 .78335 .2053 .77738 .19646 Mtetra
.693 .755 .899 r
.77738 .19646 .78335 .2053 .79699 .19944 .79106 .19055 Mtetra
.688 .753 .901 r
.79106 .19055 .79699 .19944 .81071 .19375 .80482 .18481 Mtetra
.453 0 0 r
.168 .48638 .17637 .49005 .18674 .496 .17835 .49259 Mtetra
.489 0 0 r
.17835 .49259 .18674 .496 .19719 .50225 .18879 .49912 Mtetra
.512 0 0 r
.18879 .49912 .19719 .50225 .20774 .50871 .19933 .50584 Mtetra
.522 0 0 r
.19933 .50584 .20774 .50871 .2184 .51525 .20998 .51262 Mtetra
.52 0 0 r
.20998 .51262 .2184 .51525 .22919 .52173 .22076 .51931 Mtetra
.506 0 0 r
.22076 .51931 .22919 .52173 .24012 .52798 .2317 .52576 Mtetra
.477 0 0 r
.2317 .52576 .24012 .52798 .2512 .53385 .24279 .53178 Mtetra
.433 0 0 r
.24279 .53178 .2512 .53385 .26245 .53916 .25405 .53722 Mtetra
.367 0 0 r
.25405 .53722 .26245 .53916 .27387 .54376 .26548 .54189 Mtetra
.277 0 0 r
.26548 .54189 .27387 .54376 .28546 .54746 .27711 .54562 Mtetra
.157 0 0 r
.27711 .54562 .28546 .54746 .29723 .55012 .28892 .54826 Mtetra
0 .559 .789 r
.28892 .54826 .29723 .55012 .30918 .5516 .30091 .54967 Mtetra
.161 .682 .883 r
.30091 .54967 .30918 .5516 .32131 .55177 .31308 .54973 Mtetra
.331 .785 .95 r
.31308 .54973 .32131 .55177 .3336 .55055 .32543 .54834 Mtetra
.481 .857 .984 r
.32543 .54834 .3336 .55055 .34605 .54786 .33794 .54545 Mtetra
.6 .897 .988 r
.33794 .54545 .34605 .54786 .35863 .54368 .35059 .54101 Mtetra
.687 .912 .973 r
.35059 .54101 .35863 .54368 .37135 .53799 .36337 .53504 Mtetra
.747 .913 .948 r
.36337 .53504 .37135 .53799 .38417 .53084 .37627 .52757 Mtetra
.789 .905 .922 r
.37627 .52757 .38417 .53084 .39708 .52228 .38926 .51867 Mtetra
.818 .895 .897 r
.38926 .51867 .39708 .52228 .41006 .5124 .40232 .50844 Mtetra
.837 .883 .875 r
.40232 .50844 .41006 .5124 .42309 .50133 .41543 .49701 Mtetra
.85 .871 .856 r
.41543 .49701 .42309 .50133 .43616 .48921 .42858 .48452 Mtetra
.859 .861 .841 r
.42858 .48452 .43616 .48921 .44925 .47618 .44174 .47114 Mtetra
.864 .851 .828 r
.44174 .47114 .44925 .47618 .46234 .46243 .45492 .45703 Mtetra
.867 .843 .819 r
.45492 .45703 .46234 .46243 .47543 .44811 .46808 .44237 Mtetra
.868 .836 .812 r
.46808 .44237 .47543 .44811 .4885 .43341 .48123 .42735 Mtetra
.868 .829 .807 r
.48123 .42735 .4885 .43341 .50156 .41848 .49436 .41212 Mtetra
.866 .824 .804 r
.49436 .41212 .50156 .41848 .51459 .4035 .50746 .39685 Mtetra
.863 .819 .804 r
.50746 .39685 .51459 .4035 .52759 .38859 .52053 .38169 Mtetra
.86 .815 .804 r
.52053 .38169 .52759 .38859 .54058 .37391 .53358 .36676 Mtetra
.855 .811 .807 r
.53358 .36676 .54058 .37391 .55354 .35954 .54661 .35218 Mtetra
.849 .808 .81 r
.54661 .35218 .55354 .35954 .56649 .3456 .55962 .33805 Mtetra
.842 .805 .815 r
.55962 .33805 .56649 .3456 .57943 .33216 .57262 .32443 Mtetra
.834 .802 .82 r
.57262 .32443 .57943 .33216 .59236 .31927 .58562 .31138 Mtetra
.826 .799 .826 r
.58562 .31138 .59236 .31927 .60531 .30697 .59862 .29895 Mtetra
.816 .796 .833 r
.59862 .29895 .60531 .30697 .61827 .29529 .61164 .28714 Mtetra
.807 .793 .839 r
.61164 .28714 .61827 .29529 .63125 .28422 .62467 .27597 Mtetra
.796 .79 .846 r
.62467 .27597 .63125 .28422 .64427 .27378 .63774 .26543 Mtetra
.785 .786 .853 r
.63774 .26543 .64427 .27378 .65732 .26393 .65084 .2555 Mtetra
.774 .783 .86 r
.65084 .2555 .65732 .26393 .67041 .25466 .66399 .24615 Mtetra
.763 .779 .866 r
.66399 .24615 .67041 .25466 .68356 .24593 .67719 .23735 Mtetra
.753 .776 .872 r
.67719 .23735 .68356 .24593 .69676 .2377 .69044 .22906 Mtetra
.742 .772 .877 r
.69044 .22906 .69676 .2377 .71003 .22994 .70376 .22123 Mtetra
.732 .769 .882 r
.70376 .22123 .71003 .22994 .72336 .22259 .71713 .21382 Mtetra
.723 .765 .886 r
.71713 .21382 .72336 .22259 .73676 .2156 .73058 .20679 Mtetra
.714 .762 .89 r
.73058 .20679 .73676 .2156 .75022 .20895 .7441 .20009 Mtetra
.706 .759 .893 r
.7441 .20009 .75022 .20895 .76376 .20258 .75768 .19367 Mtetra
.699 .756 .896 r
.75768 .19367 .76376 .20258 .77738 .19646 .77134 .1875 Mtetra
.693 .754 .898 r
.77134 .1875 .77738 .19646 .79106 .19055 .78508 .18154 Mtetra
.688 .752 .9 r
.78508 .18154 .79106 .19055 .80482 .18481 .79889 .17576 Mtetra
.436 0 0 r
.15961 .4821 .168 .48638 .17835 .49259 .16995 .48852 Mtetra
.469 0 0 r
.16995 .48852 .17835 .49259 .18879 .49912 .18037 .49525 Mtetra
.489 0 0 r
.18037 .49525 .18879 .49912 .19933 .50584 .1909 .50216 Mtetra
.496 0 0 r
.1909 .50216 .19933 .50584 .20998 .51262 .20155 .50911 Mtetra
.489 0 0 r
.20155 .50911 .20998 .51262 .22076 .51931 .21233 .51595 Mtetra
.468 0 0 r
.21233 .51595 .22076 .51931 .2317 .52576 .22327 .52251 Mtetra
.43 0 0 r
.22327 .52251 .2317 .52576 .24279 .53178 .23437 .52862 Mtetra
.372 0 0 r
.23437 .52862 .24279 .53178 .25405 .53722 .24564 .53411 Mtetra
.29 0 0 r
.24564 .53411 .25405 .53722 .26548 .54189 .2571 .53878 Mtetra
0 .399 .714 r
.2571 .53878 .26548 .54189 .27711 .54562 .26875 .54249 Mtetra
0 .512 .81 r
.26875 .54249 .27711 .54562 .28892 .54826 .2806 .54505 Mtetra
.119 .628 .898 r
.2806 .54505 .28892 .54826 .30091 .54967 .29263 .54634 Mtetra
.284 .728 .962 r
.29263 .54634 .30091 .54967 .31308 .54973 .30486 .54624 Mtetra
.434 .802 .995 r
.30486 .54624 .31308 .54973 .32543 .54834 .31726 .54466 Mtetra
.556 .847 .998 r
.31726 .54466 .32543 .54834 .33794 .54545 .32982 .54153 Mtetra
.647 .868 .982 r
.32982 .54153 .33794 .54545 .35059 .54101 .34254 .53684 Mtetra
.713 .873 .956 r
.34254 .53684 .35059 .54101 .36337 .53504 .35539 .53058 Mtetra
.76 .87 .928 r
.35539 .53058 .36337 .53504 .37627 .52757 .36835 .52281 Mtetra
.792 .863 .902 r
.36835 .52281 .37627 .52757 .38926 .51867 .38141 .5136 Mtetra
.815 .854 .878 r
.38141 .5136 .38926 .51867 .40232 .50844 .39454 .50305 Mtetra
.831 .845 .857 r
.39454 .50305 .40232 .50844 .41543 .49701 .40773 .4913 Mtetra
.842 .836 .84 r
.40773 .4913 .41543 .49701 .42858 .48452 .42095 .47849 Mtetra
.85 .829 .826 r
.42095 .47849 .42858 .48452 .44174 .47114 .43419 .46481 Mtetra
.855 .822 .815 r
.43419 .46481 .44174 .47114 .45492 .45703 .44744 .45041 Mtetra
.858 .816 .807 r
.44744 .45041 .45492 .45703 .46808 .44237 .46068 .43548 Mtetra
.859 .811 .801 r
.46068 .43548 .46808 .44237 .48123 .42735 .4739 .4202 Mtetra
.859 .807 .797 r
.4739 .4202 .48123 .42735 .49436 .41212 .4871 .40475 Mtetra
.858 .803 .796 r
.4871 .40475 .49436 .41212 .50746 .39685 .50027 .38927 Mtetra
.856 .8 .795 r
.50027 .38927 .50746 .39685 .52053 .38169 .51341 .37392 Mtetra
.852 .798 .797 r
.51341 .37392 .52053 .38169 .53358 .36676 .52652 .35883 Mtetra
.848 .795 .8 r
.52652 .35883 .53358 .36676 .54661 .35218 .53962 .34411 Mtetra
.843 .793 .803 r
.53962 .34411 .54661 .35218 .55962 .33805 .55269 .32985 Mtetra
.837 .792 .808 r
.55269 .32985 .55962 .33805 .57262 .32443 .56575 .31612 Mtetra
.829 .79 .814 r
.56575 .31612 .57262 .32443 .58562 .31138 .5788 .30298 Mtetra
.822 .788 .821 r
.5788 .30298 .58562 .31138 .59862 .29895 .59186 .29046 Mtetra
.813 .786 .828 r
.59186 .29046 .59862 .29895 .61164 .28714 .60494 .27858 Mtetra
.803 .784 .835 r
.60494 .27858 .61164 .28714 .62467 .27597 .61803 .26735 Mtetra
.793 .782 .842 r
.61803 .26735 .62467 .27597 .63774 .26543 .63115 .25675 Mtetra
.783 .78 .85 r
.63115 .25675 .63774 .26543 .65084 .2555 .6443 .24677 Mtetra
.772 .777 .857 r
.6443 .24677 .65084 .2555 .66399 .24615 .6575 .23738 Mtetra
.762 .774 .863 r
.6575 .23738 .66399 .24615 .67719 .23735 .67075 .22854 Mtetra
.751 .772 .87 r
.67075 .22854 .67719 .23735 .69044 .22906 .68406 .22021 Mtetra
.741 .769 .875 r
.68406 .22021 .69044 .22906 .70376 .22123 .69742 .21234 Mtetra
.731 .766 .88 r
.69742 .21234 .70376 .22123 .71713 .21382 .71085 .2049 Mtetra
.722 .763 .885 r
.71085 .2049 .71713 .21382 .73058 .20679 .72434 .19783 Mtetra
.714 .76 .889 r
.72434 .19783 .73058 .20679 .7441 .20009 .73791 .19109 Mtetra
.706 .757 .892 r
.73791 .19109 .7441 .20009 .75768 .19367 .75154 .18464 Mtetra
.699 .755 .895 r
.75154 .18464 .75768 .19367 .77134 .1875 .76525 .17843 Mtetra
.693 .753 .898 r
.76525 .17843 .77134 .1875 .78508 .18154 .77904 .17243 Mtetra
.688 .751 .9 r
.77904 .17243 .78508 .18154 .79889 .17576 .7929 .1666 Mtetra
.407 0 0 r
.15121 .47715 .15961 .4821 .16995 .48852 .16153 .48372 Mtetra
.437 0 0 r
.16153 .48372 .16995 .48852 .18037 .49525 .17195 .49057 Mtetra
.453 0 0 r
.17195 .49057 .18037 .49525 .1909 .50216 .18247 .4976 Mtetra
.454 0 0 r
.18247 .4976 .1909 .50216 .20155 .50911 .19312 .50464 Mtetra
.44 0 0 r
.19312 .50464 .20155 .50911 .21233 .51595 .2039 .51155 Mtetra
.41 0 0 r
.2039 .51155 .21233 .51595 .22327 .52251 .21484 .51815 Mtetra
.36 0 0 r
.21484 .51815 .22327 .52251 .23437 .52862 .22596 .52427 Mtetra
0 .282 .661 r
.22596 .52427 .23437 .52862 .24564 .53411 .23725 .52973 Mtetra
0 .368 .739 r
.23725 .52973 .24564 .53411 .2571 .53878 .24873 .53435 Mtetra
0 .468 .823 r
.24873 .53435 .2571 .53878 .26875 .54249 .26041 .53795 Mtetra
.086 .571 .902 r
.26041 .53795 .26875 .54249 .2806 .54505 .27229 .54039 Mtetra
.241 .665 .96 r
.27229 .54039 .2806 .54505 .29263 .54634 .28437 .54152 Mtetra
.385 .738 .991 r
.28437 .54152 .29263 .54634 .30486 .54624 .29664 .54122 Mtetra
.507 .787 .996 r
.29664 .54122 .30486 .54624 .31726 .54466 .30909 .53941 Mtetra
.602 .814 .981 r
.30909 .53941 .31726 .54466 .32982 .54153 .32171 .53604 Mtetra
.673 .826 .957 r
.32171 .53604 .32982 .54153 .34254 .53684 .33448 .53108 Mtetra
.724 .828 .93 r
.33448 .53108 .34254 .53684 .35539 .53058 .34739 .52454 Mtetra
.761 .826 .903 r
.34739 .52454 .35539 .53058 .36835 .52281 .36042 .51649 Mtetra
.788 .821 .878 r
.36042 .51649 .36835 .52281 .38141 .5136 .37355 .50699 Mtetra
.807 .815 .857 r
.37355 .50699 .38141 .5136 .39454 .50305 .38675 .49616 Mtetra
.821 .809 .839 r
.38675 .49616 .39454 .50305 .40773 .4913 .40001 .48414 Mtetra
.832 .803 .824 r
.40001 .48414 .40773 .4913 .42095 .47849 .4133 .47108 Mtetra
.839 .798 .812 r
.4133 .47108 .42095 .47849 .43419 .46481 .42661 .45715 Mtetra
.844 .794 .803 r
.42661 .45715 .43419 .46481 .44744 .45041 .43992 .44254 Mtetra
.847 .791 .796 r
.43992 .44254 .44744 .45041 .46068 .43548 .45323 .42741 Mtetra
.849 .788 .791 r
.45323 .42741 .46068 .43548 .4739 .4202 .46652 .41196 Mtetra
.85 .785 .788 r
.46652 .41196 .4739 .4202 .4871 .40475 .47978 .39635 Mtetra
.849 .783 .787 r
.47978 .39635 .4871 .40475 .50027 .38927 .49302 .38075 Mtetra
.847 .782 .788 r
.49302 .38075 .50027 .38927 .51341 .37392 .50623 .36529 Mtetra
.845 .781 .79 r
.50623 .36529 .51341 .37392 .52652 .35883 .5194 .35011 Mtetra
.841 .78 .793 r
.5194 .35011 .52652 .35883 .53962 .34411 .53256 .33531 Mtetra
.836 .779 .798 r
.53256 .33531 .53962 .34411 .55269 .32985 .54569 .32099 Mtetra
.831 .779 .803 r
.54569 .32099 .55269 .32985 .56575 .31612 .55881 .30722 Mtetra
.824 .778 .809 r
.55881 .30722 .56575 .31612 .5788 .30298 .57192 .29404 Mtetra
.817 .778 .816 r
.57192 .29404 .5788 .30298 .59186 .29046 .58504 .2815 Mtetra
.808 .777 .823 r
.58504 .2815 .59186 .29046 .60494 .27858 .59817 .2696 Mtetra
.8 .776 .831 r
.59817 .2696 .60494 .27858 .61803 .26735 .61131 .25835 Mtetra
.79 .775 .839 r
.61131 .25835 .61803 .26735 .63115 .25675 .62449 .24774 Mtetra
.78 .773 .846 r
.62449 .24774 .63115 .25675 .6443 .24677 .6377 .23775 Mtetra
.77 .771 .854 r
.6377 .23775 .6443 .24677 .6575 .23738 .65095 .22835 Mtetra
.76 .769 .861 r
.65095 .22835 .6575 .23738 .67075 .22854 .66425 .21949 Mtetra
.749 .767 .867 r
.66425 .21949 .67075 .22854 .68406 .22021 .67761 .21115 Mtetra
.739 .765 .873 r
.67761 .21115 .68406 .22021 .69742 .21234 .69102 .20327 Mtetra
.73 .763 .879 r
.69102 .20327 .69742 .21234 .71085 .2049 .7045 .1958 Mtetra
.721 .76 .884 r
.7045 .1958 .71085 .2049 .72434 .19783 .71805 .18871 Mtetra
.713 .758 .888 r
.71805 .18871 .72434 .19783 .73791 .19109 .73166 .18195 Mtetra
.705 .756 .891 r
.73166 .18195 .73791 .19109 .75154 .18464 .74535 .17547 Mtetra
.698 .754 .894 r
.74535 .17547 .75154 .18464 .76525 .17843 .75911 .16923 Mtetra
.692 .752 .897 r
.75911 .16923 .76525 .17843 .77904 .17243 .77294 .1632 Mtetra
.687 .75 .899 r
.77294 .1632 .77904 .17243 .7929 .1666 .78685 .15735 Mtetra
0 .185 .615 r
.1428 .47148 .15121 .47715 .16153 .48372 .15312 .47812 Mtetra
0 .163 .591 r
.15312 .47812 .16153 .48372 .17195 .49057 .16353 .48503 Mtetra
.4 0 0 r
.16353 .48503 .17195 .49057 .18247 .4976 .17405 .49208 Mtetra
.395 0 0 r
.17405 .49208 .18247 .4976 .19312 .50464 .1847 .49913 Mtetra
0 .181 .605 r
.1847 .49913 .19312 .50464 .2039 .51155 .19549 .50603 Mtetra
0 .219 .642 r
.19549 .50603 .2039 .51155 .21484 .51815 .20644 .51259 Mtetra
0 .273 .695 r
.20644 .51259 .21484 .51815 .22596 .52427 .21757 .51865 Mtetra
0 .345 .759 r
.21757 .51865 .22596 .52427 .23725 .52973 .22888 .52401 Mtetra
0 .428 .83 r
.22888 .52401 .23725 .52973 .24873 .53435 .24039 .5285 Mtetra
.064 .518 .896 r
.24039 .5285 .24873 .53435 .26041 .53795 .2521 .53195 Mtetra
.204 .602 .947 r
.2521 .53195 .26041 .53795 .27229 .54039 .26402 .5342 Mtetra
.339 .672 .976 r
.26402 .5342 .27229 .54039 .28437 .54152 .27613 .53512 Mtetra
.457 .723 .982 r
.27613 .53512 .28437 .54152 .29664 .54122 .28844 .53459 Mtetra
.553 .755 .971 r
.28844 .53459 .29664 .54122 .30909 .53941 .30094 .53254 Mtetra
.628 .773 .95 r
.30094 .53254 .30909 .53941 .32171 .53604 .31361 .52891 Mtetra
.684 .782 .925 r
.31361 .52891 .32171 .53604 .33448 .53108 .32644 .52368 Mtetra
.725 .785 .9 r
.32644 .52368 .33448 .53108 .34739 .52454 .33941 .51688 Mtetra
.756 .784 .876 r
.33941 .51688 .34739 .52454 .36042 .51649 .3525 .50857 Mtetra
.78 .782 .855 r
.3525 .50857 .36042 .51649 .37355 .50699 .36569 .49882 Mtetra
.797 .779 .836 r
.36569 .49882 .37355 .50699 .38675 .49616 .37895 .48776 Mtetra
.81 .776 .821 r
.37895 .48776 .38675 .49616 .40001 .48414 .39227 .47552 Mtetra
.82 .773 .809 r
.39227 .47552 .40001 .48414 .4133 .47108 .40562 .46227 Mtetra
.827 .771 .799 r
.40562 .46227 .4133 .47108 .42661 .45715 .419 .44817 Mtetra
.833 .769 .791 r
.419 .44817 .42661 .45715 .43992 .44254 .43238 .43341 Mtetra
.836 .767 .786 r
.43238 .43341 .43992 .44254 .45323 .42741 .44575 .41817 Mtetra
.839 .766 .782 r
.44575 .41817 .45323 .42741 .46652 .41196 .4591 .40262 Mtetra
.84 .765 .78 r
.4591 .40262 .46652 .41196 .47978 .39635 .47242 .38694 Mtetra
.47242 .38694 .47978 .39635 .49302 .38075 .48572 .37128 Mtetra
.838 .765 .781 r
.48572 .37128 .49302 .38075 .50623 .36529 .49899 .3558 Mtetra
.836 .765 .784 r
.49899 .3558 .50623 .36529 .5194 .35011 .51222 .3406 Mtetra
.833 .765 .787 r
.51222 .3406 .5194 .35011 .53256 .33531 .52544 .32581 Mtetra
.829 .766 .792 r
.52544 .32581 .53256 .33531 .54569 .32099 .53863 .3115 Mtetra
.824 .767 .798 r
.53863 .3115 .54569 .32099 .55881 .30722 .55181 .29775 Mtetra
.818 .767 .805 r
.55181 .29775 .55881 .30722 .57192 .29404 .56498 .2846 Mtetra
.811 .767 .812 r
.56498 .2846 .57192 .29404 .58504 .2815 .57815 .27208 Mtetra
.804 .768 .82 r
.57815 .27208 .58504 .2815 .59817 .2696 .59133 .26021 Mtetra
.795 .768 .828 r
.59133 .26021 .59817 .2696 .61131 .25835 .60454 .249 Mtetra
.786 .767 .836 r
.60454 .249 .61131 .25835 .62449 .24774 .61777 .23841 Mtetra
.777 .767 .844 r
.61777 .23841 .62449 .24774 .6377 .23775 .63103 .22845 Mtetra
.767 .766 .852 r
.63103 .22845 .6377 .23775 .65095 .22835 .64433 .21906 Mtetra
.757 .764 .859 r
.64433 .21906 .65095 .22835 .66425 .21949 .65769 .21022 Mtetra
.747 .763 .866 r
.65769 .21022 .66425 .21949 .67761 .21115 .6711 .20189 Mtetra
.738 .761 .872 r
.6711 .20189 .67761 .21115 .69102 .20327 .68456 .19401 Mtetra
.728 .76 .878 r
.68456 .19401 .69102 .20327 .7045 .1958 .69809 .18655 Mtetra
.72 .758 .883 r
.69809 .18655 .7045 .1958 .71805 .18871 .71169 .17945 Mtetra
.711 .756 .887 r
.71169 .17945 .71805 .18871 .73166 .18195 .72536 .17268 Mtetra
.704 .754 .891 r
.72536 .17268 .73166 .18195 .74535 .17547 .73909 .16618 Mtetra
.698 .752 .894 r
.73909 .16618 .74535 .17547 .75911 .16923 .7529 .15992 Mtetra
.692 .75 .897 r
.7529 .15992 .75911 .16923 .77294 .1632 .76679 .15387 Mtetra
.687 .749 .899 r
.76679 .15387 .77294 .1632 .78685 .15735 .78075 .14798 Mtetra
0 .216 .668 r
.13439 .46506 .1428 .47148 .15312 .47812 .14472 .47168 Mtetra
0 .199 .652 r
.14472 .47168 .15312 .47812 .16353 .48503 .15513 .47856 Mtetra
0 .195 .649 r
.15513 .47856 .16353 .48503 .17405 .49208 .16566 .48557 Mtetra
0 .206 .661 r
.16566 .48557 .17405 .49208 .1847 .49913 .17631 .49255 Mtetra
0 .232 .687 r
.17631 .49255 .1847 .49913 .19549 .50603 .18711 .49935 Mtetra
0 .274 .726 r
.18711 .49935 .19549 .50603 .20644 .51259 .19808 .5058 Mtetra
0 .33 .776 r
.19808 .5058 .20644 .51259 .21757 .51865 .20923 .51171 Mtetra
0 .398 .832 r
.20923 .51171 .21757 .51865 .22888 .52401 .22056 .5169 Mtetra
.053 .472 .886 r
.22056 .5169 .22888 .52401 .24039 .5285 .23209 .5212 Mtetra
.177 .545 .928 r
.23209 .5212 .24039 .5285 .2521 .53195 .24383 .52443 Mtetra
.3 .609 .954 r
.24383 .52443 .2521 .53195 .26402 .5342 .25578 .52645 Mtetra
.411 .659 .961 r
.25578 .52645 .26402 .5342 .27613 .53512 .26794 .52712 Mtetra
.505 .695 .954 r
.26794 .52712 .27613 .53512 .28844 .53459 .28029 .52634 Mtetra
.581 .719 .937 r
.28029 .52634 .28844 .53459 .30094 .53254 .29283 .52402 Mtetra
.641 .733 .916 r
.29283 .52402 .30094 .53254 .31361 .52891 .30555 .52012 Mtetra
.686 .741 .893 r
.30555 .52012 .31361 .52891 .32644 .52368 .31843 .51464 Mtetra
.722 .745 .871 r
.31843 .51464 .32644 .52368 .33941 .51688 .33145 .5076 Mtetra
.749 .747 .851 r
.33145 .5076 .33941 .51688 .3525 .50857 .34459 .49905 Mtetra
.769 .747 .833 r
.34459 .49905 .3525 .50857 .36569 .49882 .35783 .48909 Mtetra
.786 .747 .818 r
.35783 .48909 .36569 .49882 .37895 .48776 .37115 .47785 Mtetra
.798 .746 .805 r
.37115 .47785 .37895 .48776 .39227 .47552 .38452 .46545 Mtetra
.808 .746 .795 r
.38452 .46545 .39227 .47552 .40562 .46227 .39793 .45207 Mtetra
.815 .746 .787 r
.39793 .45207 .40562 .46227 .419 .44817 .41136 .43788 Mtetra
.821 .746 .78 r
.41136 .43788 .419 .44817 .43238 .43341 .4248 .42305 Mtetra
.825 .746 .776 r
.4248 .42305 .43238 .43341 .44575 .41817 .43823 .40776 Mtetra
.828 .746 .774 r
.43823 .40776 .44575 .41817 .4591 .40262 .45164 .3922 Mtetra
.829 .747 .773 r
.45164 .3922 .4591 .40262 .47242 .38694 .46502 .37653 Mtetra
.83 .748 .773 r
.46502 .37653 .47242 .38694 .48572 .37128 .47837 .36091 Mtetra
.829 .749 .775 r
.47837 .36091 .48572 .37128 .49899 .3558 .4917 .34547 Mtetra
.828 .751 .778 r
.4917 .34547 .49899 .3558 .51222 .3406 .50499 .33034 Mtetra
.825 .752 .783 r
.50499 .33034 .51222 .3406 .52544 .32581 .51826 .31561 Mtetra
.822 .754 .788 r
.51826 .31561 .52544 .32581 .53863 .3115 .53151 .30139 Mtetra
.817 .755 .794 r
.53151 .30139 .53863 .3115 .55181 .29775 .54474 .28772 Mtetra
.812 .757 .801 r
.54474 .28772 .55181 .29775 .56498 .2846 .55797 .27465 Mtetra
.805 .758 .809 r
.55797 .27465 .56498 .2846 .57815 .27208 .5712 .26222 Mtetra
.798 .759 .817 r
.5712 .26222 .57815 .27208 .59133 .26021 .58444 .25043 Mtetra
.79 .76 .825 r
.58444 .25043 .59133 .26021 .60454 .249 .59769 .23929 Mtetra
.782 .76 .834 r
.59769 .23929 .60454 .249 .61777 .23841 .61098 .22877 Mtetra
.773 .761 .842 r
.61098 .22877 .61777 .23841 .63103 .22845 .6243 .21886 Mtetra
.764 .76 .85 r
.6243 .21886 .63103 .22845 .64433 .21906 .63766 .20953 Mtetra
.754 .76 .857 r
.63766 .20953 .64433 .21906 .65769 .21022 .65106 .20073 Mtetra
.744 .759 .864 r
.65106 .20073 .65769 .21022 .6711 .20189 .66452 .19243 Mtetra
.735 .758 .871 r
.66452 .19243 .6711 .20189 .68456 .19401 .67804 .18458 Mtetra
.726 .757 .877 r
.67804 .18458 .68456 .19401 .69809 .18655 .69163 .17713 Mtetra
.718 .755 .882 r
.69163 .17713 .69809 .18655 .71169 .17945 .70527 .17004 Mtetra
.71 .754 .886 r
.70527 .17004 .71169 .17945 .72536 .17268 .71899 .16327 Mtetra
.703 .752 .89 r
.71899 .16327 .72536 .17268 .73909 .16618 .73278 .15677 Mtetra
.696 .751 .893 r
.73278 .15677 .73909 .16618 .7529 .15992 .74664 .1505 Mtetra
.691 .749 .896 r
.74664 .1505 .7529 .15992 .76679 .15387 .76058 .14442 Mtetra
.686 .748 .899 r
.76058 .14442 .76679 .15387 .78075 .14798 .77459 .13851 Mtetra
0 .252 .72 r
.12601 .45785 .13439 .46506 .14472 .47168 .13633 .46438 Mtetra
0 .239 .711 r
.13633 .46438 .14472 .47168 .15513 .47856 .14676 .47115 Mtetra
0 .24 .713 r
.14676 .47115 .15513 .47856 .16566 .48557 .15729 .47803 Mtetra
0 .255 .729 r
.15729 .47803 .16566 .48557 .17631 .49255 .16796 .48487 Mtetra
0 .283 .755 r
.16796 .48487 .17631 .49255 .18711 .49935 .17878 .49149 Mtetra
0 .325 .792 r
.17878 .49149 .18711 .49935 .19808 .5058 .18976 .49774 Mtetra
0 .377 .833 r
.18976 .49774 .19808 .5058 .20923 .51171 .20093 .50343 Mtetra
.053 .437 .873 r
.20093 .50343 .20923 .51171 .22056 .5169 .21229 .50839 Mtetra
.16 .497 .907 r
.21229 .50839 .22056 .5169 .23209 .5212 .22385 .51243 Mtetra
.268 .554 .929 r
.22385 .51243 .23209 .5212 .24383 .52443 .23562 .5154 Mtetra
.37 .602 .937 r
.23562 .5154 .24383 .52443 .25578 .52645 .2476 .51714 Mtetra
.46 .639 .933 r
.2476 .51714 .25578 .52645 .26794 .52712 .25979 .51752 Mtetra
.536 .666 .921 r
.25979 .51752 .26794 .52712 .28029 .52634 .27218 .51645 Mtetra
.597 .685 .903 r
.27218 .51645 .28029 .52634 .29283 .52402 .28476 .51386 Mtetra
.646 .698 .883 r
.28476 .51386 .29283 .52402 .30555 .52012 .29752 .5097 Mtetra
.685 .706 .863 r
.29752 .5097 .30555 .52012 .31843 .51464 .31045 .50397 Mtetra
.716 .711 .845 r
.31045 .50397 .31843 .51464 .33145 .5076 .32351 .4967 Mtetra
.74 .715 .828 r
.32351 .4967 .33145 .5076 .34459 .49905 .3367 .48796 Mtetra
.759 .717 .813 r
.3367 .48796 .34459 .49905 .35783 .48909 .34999 .47785 Mtetra
.774 .719 .801 r
.34999 .47785 .35783 .48909 .37115 .47785 .36335 .46647 Mtetra
.786 .721 .791 r
.36335 .46647 .37115 .47785 .38452 .46545 .37678 .45398 Mtetra
.796 .722 .782 r
.37678 .45398 .38452 .46545 .39793 .45207 .39024 .44054 Mtetra
.804 .723 .776 r
.39024 .44054 .39793 .45207 .41136 .43788 .40372 .42632 Mtetra
.81 .725 .771 r
.40372 .42632 .41136 .43788 .4248 .42305 .4172 .4115 Mtetra
.814 .726 .768 r
.4172 .4115 .4248 .42305 .43823 .40776 .43068 .39625 Mtetra
.817 .728 .767 r
.43068 .39625 .43823 .40776 .45164 .3922 .44414 .38076 Mtetra
.819 .73 .766 r
.44414 .38076 .45164 .3922 .46502 .37653 .45758 .36518 Mtetra
.82 .732 .768 r
.45758 .36518 .46502 .37653 .47837 .36091 .47098 .34966 Mtetra
.82 .735 .77 r
.47098 .34966 .47837 .36091 .4917 .34547 .48436 .33435 Mtetra
.819 .737 .774 r
.48436 .33435 .4917 .34547 .50499 .33034 .49771 .31935 Mtetra
.817 .74 .779 r
.49771 .31935 .50499 .33034 .51826 .31561 .51103 .30477 Mtetra
.814 .742 .785 r
.51103 .30477 .51826 .31561 .53151 .30139 .52433 .29068 Mtetra
.81 .745 .791 r
.52433 .29068 .53151 .30139 .54474 .28772 .53762 .27716 Mtetra
.805 .747 .799 r
.53762 .27716 .54474 .28772 .55797 .27465 .5509 .26423 Mtetra
.799 .749 .807 r
.5509 .26423 .55797 .27465 .5712 .26222 .56419 .25194 Mtetra
.793 .751 .815 r
.56419 .25194 .5712 .26222 .58444 .25043 .57748 .24027 Mtetra
.785 .753 .823 r
.57748 .24027 .58444 .25043 .59769 .23929 .59079 .22925 Mtetra
.777 .754 .832 r
.59079 .22925 .59769 .23929 .61098 .22877 .60413 .21884 Mtetra
.769 .755 .84 r
.60413 .21884 .61098 .22877 .6243 .21886 .6175 .20902 Mtetra
.76 .755 .849 r
.6175 .20902 .6243 .21886 .63766 .20953 .63091 .19977 Mtetra
.751 .755 .856 r
.63091 .19977 .63766 .20953 .65106 .20073 .64437 .19104 Mtetra
.741 .755 .863 r
.64437 .19104 .65106 .20073 .66452 .19243 .65789 .18279 Mtetra
.733 .754 .87 r
.65789 .18279 .66452 .19243 .67804 .18458 .67146 .17498 Mtetra
.724 .754 .876 r
.67146 .17498 .67804 .18458 .69163 .17713 .6851 .16756 Mtetra
.716 .753 .881 r
.6851 .16756 .69163 .17713 .70527 .17004 .6988 .16049 Mtetra
.708 .752 .886 r
.6988 .16049 .70527 .17004 .71899 .16327 .71257 .15373 Mtetra
.701 .75 .89 r
.71257 .15373 .71899 .16327 .73278 .15677 .72641 .14723 Mtetra
.695 .749 .893 r
.72641 .14723 .73278 .15677 .74664 .1505 .74032 .14095 Mtetra
.69 .748 .896 r
.74032 .14095 .74664 .1505 .76058 .14442 .75431 .13487 Mtetra
.685 .747 .898 r
.75431 .13487 .76058 .14442 .77459 .13851 .76837 .12894 Mtetra
0 .289 .766 r
.11764 .44984 .12601 .45785 .13633 .46438 .12798 .45621 Mtetra
0 .28 .761 r
.12798 .45621 .13633 .46438 .14676 .47115 .13842 .4628 Mtetra
0 .284 .767 r
.13842 .4628 .14676 .47115 .15729 .47803 .14897 .46947 Mtetra
0 .3 .782 r
.14897 .46947 .15729 .47803 .16796 .48487 .15966 .47607 Mtetra
0 .328 .805 r
.15966 .47607 .16796 .48487 .17878 .49149 .17049 .48245 Mtetra
0 .367 .834 r
.17049 .48245 .17878 .49149 .18976 .49774 .1815 .48843 Mtetra
.063 .412 .862 r
.1815 .48843 .18976 .49774 .20093 .50343 .19269 .49383 Mtetra
.152 .461 .887 r
.19269 .49383 .20093 .50343 .21229 .50839 .20408 .49848 Mtetra
.246 .509 .905 r
.20408 .49848 .21229 .50839 .22385 .51243 .21567 .50221 Mtetra
.337 .552 .913 r
.21567 .50221 .22385 .51243 .23562 .5154 .22747 .50486 Mtetra
.421 .588 .911 r
.22747 .50486 .23562 .5154 .2476 .51714 .23948 .50628 Mtetra
.494 .617 .902 r
.23948 .50628 .2476 .51714 .25979 .51752 .25171 .50636 Mtetra
.556 .639 .888 r
.25171 .50636 .25979 .51752 .27218 .51645 .26413 .50499 Mtetra
.606 .655 .872 r
.26413 .50499 .27218 .51645 .28476 .51386 .27675 .50211 Mtetra
.648 .667 .855 r
.27675 .50211 .28476 .51386 .29752 .5097 .28955 .49769 Mtetra
.682 .676 .838 r
.28955 .49769 .29752 .5097 .31045 .50397 .30251 .49174 Mtetra
.709 .682 .823 r
.30251 .49174 .31045 .50397 .32351 .4967 .31561 .48427 Mtetra
.731 .688 .809 r
.31561 .48427 .32351 .4967 .3367 .48796 .32884 .47538 Mtetra
.749 .692 .797 r
.32884 .47538 .3367 .48796 .34999 .47785 .34217 .46514 Mtetra
.763 .695 .787 r
.34217 .46514 .34999 .47785 .36335 .46647 .35557 .45369 Mtetra
.775 .698 .778 r
.35557 .45369 .36335 .46647 .37678 .45398 .36904 .44117 Mtetra
.785 .701 .772 r
.36904 .44117 .37678 .45398 .39024 .44054 .38254 .42774 Mtetra
.792 .704 .767 r
.38254 .42774 .39024 .44054 .40372 .42632 .39606 .41357 Mtetra
.799 .707 .763 r
.39606 .41357 .40372 .42632 .4172 .4115 .40959 .39883 Mtetra
.803 .709 .761 r
.40959 .39883 .4172 .4115 .43068 .39625 .42312 .3837 Mtetra
.807 .712 .761 r
.42312 .3837 .43068 .39625 .44414 .38076 .43662 .36835 Mtetra
.809 .715 .761 r
.43662 .36835 .44414 .38076 .45758 .36518 .4501 .35293 Mtetra
.811 .719 .763 r
.4501 .35293 .45758 .36518 .47098 .34966 .46356 .3376 Mtetra
.811 .722 .766 r
.46356 .3376 .47098 .34966 .48436 .33435 .47698 .32248 Mtetra
.811 .725 .771 r
.47698 .32248 .48436 .33435 .49771 .31935 .49038 .30769 Mtetra
.809 .729 .776 r
.49038 .30769 .49771 .31935 .51103 .30477 .50375 .29332 Mtetra
.806 .732 .782 r
.50375 .29332 .51103 .30477 .52433 .29068 .5171 .27944 Mtetra
.803 .735 .789 r
.5171 .27944 .52433 .29068 .53762 .27716 .53044 .26611 Mtetra
.798 .738 .797 r
.53044 .26611 .53762 .27716 .5509 .26423 .54378 .25338 Mtetra
.793 .741 .805 r
.54378 .25338 .5509 .26423 .56419 .25194 .55712 .24126 Mtetra
.787 .744 .813 r
.55712 .24126 .56419 .25194 .57748 .24027 .57046 .22977 Mtetra
.78 .746 .822 r
.57046 .22977 .57748 .24027 .59079 .22925 .58383 .2189 Mtetra
.772 .748 .831 r
.58383 .2189 .59079 .22925 .60413 .21884 .59722 .20862 Mtetra
.764 .749 .839 r
.59722 .20862 .60413 .21884 .6175 .20902 .61064 .19893 Mtetra
.756 .75 .848 r
.61064 .19893 .6175 .20902 .63091 .19977 .62411 .18978 Mtetra
.747 .751 .856 r
.62411 .18978 .63091 .19977 .64437 .19104 .63763 .18114 Mtetra
.738 .751 .863 r
.63763 .18114 .64437 .19104 .65789 .18279 .65119 .17297 Mtetra
.73 .751 .87 r
.65119 .17297 .65789 .18279 .67146 .17498 .66482 .16522 Mtetra
.721 .751 .876 r
.66482 .16522 .67146 .17498 .6851 .16756 .67851 .15784 Mtetra
.714 .75 .881 r
.67851 .15784 .6851 .16756 .6988 .16049 .69226 .15081 Mtetra
.706 .75 .886 r
.69226 .15081 .6988 .16049 .71257 .15373 .70608 .14406 Mtetra
.7 .749 .89 r
.70608 .14406 .71257 .15373 .72641 .14723 .71998 .13757 Mtetra
.694 .748 .893 r
.71998 .13757 .72641 .14723 .74032 .14095 .73394 .1313 Mtetra
.689 .747 .896 r
.73394 .1313 .74032 .14095 .75431 .13487 .74798 .12521 Mtetra
.684 .746 .898 r
.74798 .12521 .75431 .13487 .76837 .12894 .7621 .11926 Mtetra
0 .325 .803 r
.1093 .44104 .11764 .44984 .12798 .45621 .11966 .44718 Mtetra
0 .319 .801 r
.11966 .44718 .12798 .45621 .13842 .4628 .13012 .4535 Mtetra
0 .325 .807 r
.13012 .4535 .13842 .4628 .14897 .46947 .14069 .45989 Mtetra
0 .341 .819 r
.14069 .45989 .14897 .46947 .15966 .47607 .1514 .46619 Mtetra
.018 .366 .836 r
.1514 .46619 .15966 .47607 .17049 .48245 .16227 .47224 Mtetra
.081 .399 .855 r
.16227 .47224 .17049 .48245 .1815 .48843 .1733 .47788 Mtetra
.154 .436 .872 r
.1733 .47788 .1815 .48843 .19269 .49383 .18452 .48293 Mtetra
.233 .475 .884 r
.18452 .48293 .19269 .49383 .20408 .49848 .19593 .48722 Mtetra
.313 .512 .891 r
.19593 .48722 .20408 .49848 .21567 .50221 .20755 .49059 Mtetra
.388 .546 .89 r
.20755 .49059 .21567 .50221 .22747 .50486 .21939 .49288 Mtetra
.457 .574 .884 r
.21939 .49288 .22747 .50486 .23948 .50628 .23143 .49395 Mtetra
.517 .597 .873 r
.23143 .49395 .23948 .50628 .25171 .50636 .24369 .49369 Mtetra
.569 .616 .86 r
.24369 .49369 .25171 .50636 .26413 .50499 .25614 .49201 Mtetra
.612 .631 .845 r
.25614 .49201 .26413 .50499 .27675 .50211 .2688 .48885 Mtetra
.648 .642 .831 r
.2688 .48885 .27675 .50211 .28955 .49769 .28163 .48419 Mtetra
.677 .651 .817 r
.28163 .48419 .28955 .49769 .30251 .49174 .29462 .47802 Mtetra
.702 .658 .804 r
.29462 .47802 .30251 .49174 .31561 .48427 .30776 .4704 Mtetra
.722 .665 .793 r
.30776 .4704 .31561 .48427 .32884 .47538 .32102 .46139 Mtetra
.739 .67 .783 r
.32102 .46139 .32884 .47538 .34217 .46514 .33437 .45108 Mtetra
.753 .674 .775 r
.33437 .45108 .34217 .46514 .35557 .45369 .34781 .43962 Mtetra
.764 .679 .768 r
.34781 .43962 .35557 .45369 .36904 .44117 .36131 .42713 Mtetra
.774 .683 .763 r
.36131 .42713 .36904 .44117 .38254 .42774 .37485 .41377 Mtetra
.782 .687 .759 r
.37485 .41377 .38254 .42774 .39606 .41357 .38841 .39972 Mtetra
.788 .691 .757 r
.38841 .39972 .39606 .41357 .40959 .39883 .40197 .38514 Mtetra
.793 .694 .755 r
.40197 .38514 .40959 .39883 .42312 .3837 .41553 .3702 Mtetra
.797 .698 .756 r
.41553 .3702 .42312 .3837 .43662 .36835 .42907 .35506 Mtetra
.8 .702 .757 r
.42907 .35506 .43662 .36835 .4501 .35293 .4426 .33989 Mtetra
.802 .706 .76 r
.4426 .33989 .4501 .35293 .46356 .3376 .45609 .32481 Mtetra
.802 .71 .763 r
.45609 .32481 .46356 .3376 .47698 .32248 .46956 .30995 Mtetra
.802 .714 .768 r
.46956 .30995 .47698 .32248 .49038 .30769 .483 .29542 Mtetra
.801 .719 .774 r
.483 .29542 .49038 .30769 .50375 .29332 .49642 .28132 Mtetra
.799 .723 .78 r
.49642 .28132 .50375 .29332 .5171 .27944 .50982 .2677 Mtetra
.796 .727 .788 r
.50982 .2677 .5171 .27944 .53044 .26611 .52321 .25463 Mtetra
.792 .73 .795 r
.52321 .25463 .53044 .26611 .54378 .25338 .5366 .24213 Mtetra
.787 .734 .804 r
.5366 .24213 .54378 .25338 .55712 .24126 .54999 .23024 Mtetra
.781 .737 .813 r
.54999 .23024 .55712 .24126 .57046 .22977 .56339 .21895 Mtetra
.774 .74 .822 r
.56339 .21895 .57046 .22977 .58383 .2189 .5768 .20827 Mtetra
.767 .742 .83 r
.5768 .20827 .58383 .2189 .59722 .20862 .59025 .19816 Mtetra
.759 .744 .839 r
.59025 .19816 .59722 .20862 .61064 .19893 .60373 .18861 Mtetra
.751 .746 .848 r
.60373 .18861 .61064 .19893 .62411 .18978 .61725 .17959 Mtetra
.743 .747 .855 r
.61725 .17959 .62411 .18978 .63763 .18114 .63082 .17106 Mtetra
.735 .748 .863 r
.63082 .17106 .63763 .18114 .65119 .17297 .64444 .16298 Mtetra
.726 .748 .87 r
.64444 .16298 .65119 .17297 .66482 .16522 .65812 .1553 Mtetra
.719 .748 .876 r
.65812 .1553 .66482 .16522 .67851 .15784 .67186 .14799 Mtetra
.711 .748 .881 r
.67186 .14799 .67851 .15784 .69226 .15081 .68566 .14099 Mtetra
.704 .748 .886 r
.68566 .14099 .69226 .15081 .70608 .14406 .69954 .13428 Mtetra
.698 .747 .89 r
.69954 .13428 .70608 .14406 .71998 .13757 .71349 .12781 Mtetra
.692 .747 .893 r
.71349 .12781 .71998 .13757 .73394 .1313 .7275 .12154 Mtetra
.687 .746 .896 r
.7275 .12154 .73394 .1313 .74798 .12521 .7416 .11544 Mtetra
.683 .745 .898 r
.7416 .11544 .74798 .12521 .7621 .11926 .75576 .10948 Mtetra
0 .358 .831 r
.10098 .43148 .1093 .44104 .11966 .44718 .11137 .43731 Mtetra
.001 .355 .829 r
.11137 .43731 .11966 .44718 .13012 .4535 .12186 .4433 Mtetra
.022 .36 .832 r
.12186 .4433 .13012 .4535 .14069 .45989 .13246 .44934 Mtetra
.058 .374 .84 r
.13246 .44934 .14069 .45989 .1514 .46619 .1432 .45526 Mtetra
.106 .395 .85 r
.1432 .45526 .1514 .46619 .16227 .47224 .1541 .46093 Mtetra
.164 .422 .861 r
.1541 .46093 .16227 .47224 .1733 .47788 .16516 .46617 Mtetra
.229 .452 .869 r
.16516 .46617 .1733 .47788 .18452 .48293 .17641 .47081 Mtetra
.297 .483 .873 r
.17641 .47081 .18452 .48293 .19593 .48722 .18786 .47469 Mtetra
.364 .512 .872 r
.18786 .47469 .19593 .48722 .20755 .49059 .19951 .47765 Mtetra
.427 .539 .867 r
.19951 .47765 .20755 .49059 .21939 .49288 .21137 .47954 Mtetra
.484 .562 .859 r
.21137 .47954 .21939 .49288 .23143 .49395 .22345 .48024 Mtetra
.534 .581 .848 r
.22345 .48024 .23143 .49395 .24369 .49369 .23574 .47963 Mtetra
.578 .597 .836 r
.23574 .47963 .24369 .49369 .25614 .49201 .24822 .47763 Mtetra
.615 .61 .823 r
.24822 .47763 .25614 .49201 .2688 .48885 .2609 .47419 Mtetra
.647 .621 .811 r
.2609 .47419 .2688 .48885 .28163 .48419 .27376 .46929 Mtetra
.673 .631 .799 r
.27376 .46929 .28163 .48419 .29462 .47802 .28678 .46295 Mtetra
.695 .639 .788 r
.28678 .46295 .29462 .47802 .30776 .4704 .29994 .4552 Mtetra
.714 .645 .779 r
.29994 .4552 .30776 .4704 .32102 .46139 .31323 .44611 Mtetra
.73 .652 .771 r
.31323 .44611 .32102 .46139 .33437 .45108 .32661 .43579 Mtetra
.743 .657 .765 r
.32661 .43579 .33437 .45108 .34781 .43962 .34008 .42436 Mtetra
.755 .662 .759 r
.34008 .42436 .34781 .43962 .36131 .42713 .3536 .41196 Mtetra
.764 .667 .755 r
.3536 .41196 .36131 .42713 .37485 .41377 .36716 .39875 Mtetra
.772 .672 .753 r
.36716 .39875 .37485 .41377 .38841 .39972 .38075 .38488 Mtetra
.779 .677 .751 r
.38075 .38488 .38841 .39972 .40197 .38514 .39434 .37052 Mtetra
.784 .681 .751 r
.39434 .37052 .40197 .38514 .41553 .3702 .40793 .35584 Mtetra
.788 .686 .752 r
.40793 .35584 .41553 .3702 .42907 .35506 .42151 .34099 Mtetra
.791 .691 .754 r
.42151 .34099 .42907 .35506 .4426 .33989 .43506 .32612 Mtetra
.793 .695 .757 r
.43506 .32612 .4426 .33989 .45609 .32481 .4486 .31136 Mtetra
.794 .7 .761 r
.4486 .31136 .45609 .32481 .46956 .30995 .4621 .29682 Mtetra
.794 .705 .766 r
.4621 .29682 .46956 .30995 .483 .29542 .47559 .28262 Mtetra
.793 .71 .772 r
.47559 .28262 .483 .29542 .49642 .28132 .48905 .26883 Mtetra
.791 .714 .779 r
.48905 .26883 .49642 .28132 .50982 .2677 .5025 .25553 Mtetra
.788 .719 .787 r
.5025 .25553 .50982 .2677 .52321 .25463 .51593 .24275 Mtetra
.785 .723 .795 r
.51593 .24275 .52321 .25463 .5366 .24213 .52936 .23054 Mtetra
.78 .727 .804 r
.52936 .23054 .5366 .24213 .54999 .23024 .5428 .2189 Mtetra
.775 .731 .813 r
.5428 .2189 .54999 .23024 .56339 .21895 .55625 .20786 Mtetra
.768 .735 .822 r
.55625 .20786 .56339 .21895 .5768 .20827 .56972 .19738 Mtetra
.762 .738 .831 r
.56972 .19738 .5768 .20827 .59025 .19816 .58322 .18747 Mtetra
.754 .74 .839 r
.58322 .18747 .59025 .19816 .60373 .18861 .59675 .1781 Mtetra
.747 .742 .848 r
.59675 .1781 .60373 .18861 .61725 .17959 .61032 .16922 Mtetra
.739 .744 .856 r
.61032 .16922 .61725 .17959 .63082 .17106 .62394 .16082 Mtetra
.731 .745 .863 r
.62394 .16082 .63082 .17106 .64444 .16298 .63762 .15284 Mtetra
.723 .746 .87 r
.63762 .15284 .64444 .16298 .65812 .1553 .65135 .14525 Mtetra
.716 .746 .876 r
.65135 .14525 .65812 .1553 .67186 .14799 .66515 .138 Mtetra
.709 .746 .881 r
.66515 .138 .67186 .14799 .68566 .14099 .67901 .13106 Mtetra
.702 .746 .886 r
.67901 .13106 .68566 .14099 .69954 .13428 .69294 .12438 Mtetra
.696 .746 .89 r
.69294 .12438 .69954 .13428 .71349 .12781 .70693 .11793 Mtetra
.691 .745 .893 r
.70693 .11793 .71349 .12781 .7275 .12154 .72101 .11167 Mtetra
.686 .745 .896 r
.72101 .11167 .7275 .12154 .7416 .11544 .73515 .10557 Mtetra
.682 .744 .898 r
.73515 .10557 .7416 .11544 .75576 .10948 .74937 .0996 Mtetra
.07 .388 .849 r
.09269 .4212 .10098 .43148 .11137 .43731 .10312 .42665 Mtetra
.08 .385 .846 r
.10312 .42665 .11137 .43731 .12186 .4433 .11364 .43225 Mtetra
.102 .389 .847 r
.11364 .43225 .12186 .4433 .13246 .44934 .12428 .43786 Mtetra
.137 .401 .85 r
.12428 .43786 .13246 .44934 .1432 .45526 .13506 .44336 Mtetra
.181 .418 .854 r
.13506 .44336 .1432 .45526 .1541 .46093 .14599 .44857 Mtetra
.233 .44 .858 r
.14599 .44857 .1541 .46093 .16516 .46617 .15709 .45336 Mtetra
.289 .463 .859 r
.15709 .45336 .16516 .46617 .17641 .47081 .16837 .45754 Mtetra
.347 .487 .858 r
.16837 .45754 .17641 .47081 .18786 .47469 .17985 .46097 Mtetra
.403 .511 .854 r
.17985 .46097 .18786 .47469 .19951 .47765 .19154 .46349 Mtetra
.456 .532 .846 r
.19154 .46349 .19951 .47765 .21137 .47954 .20343 .46496 Mtetra
.504 .551 .837 r
.20343 .46496 .21137 .47954 .22345 .48024 .21554 .46526 Mtetra
.547 .568 .827 r
.21554 .46526 .22345 .48024 .23574 .47963 .22785 .46429 Mtetra
.584 .582 .816 r
.22785 .46429 .23574 .47963 .24822 .47763 .24037 .46197 Mtetra
.617 .594 .805 r
.24037 .46197 .24822 .47763 .2609 .47419 .25307 .45827 Mtetra
.645 .605 .794 r
.25307 .45827 .2609 .47419 .27376 .46929 .26595 .45316 Mtetra
.669 .614 .785 r
.26595 .45316 .27376 .46929 .28678 .46295 .27899 .44666 Mtetra
.689 .622 .776 r
.27899 .44666 .28678 .46295 .29994 .4552 .29217 .43881 Mtetra
.707 .63 .768 r
.29217 .43881 .29994 .4552 .31323 .44611 .30547 .4297 Mtetra
.722 .636 .762 r
.30547 .4297 .31323 .44611 .32661 .43579 .31888 .41941 Mtetra
.735 .642 .757 r
.31888 .41941 .32661 .43579 .34008 .42436 .33236 .40807 Mtetra
.746 .648 .752 r
.33236 .40807 .34008 .42436 .3536 .41196 .3459 .39582 Mtetra
.755 .654 .75 r
.3459 .39582 .3536 .41196 .36716 .39875 .35948 .38281 Mtetra
.763 .659 .748 r
.35948 .38281 .36716 .39875 .38075 .38488 .37309 .36919 Mtetra
.769 .665 .747 r
.37309 .36919 .38075 .38488 .39434 .37052 .3867 .35512 Mtetra
.775 .67 .748 r
.3867 .35512 .39434 .37052 .40793 .35584 .40032 .34075 Mtetra
.779 .675 .749 r
.40032 .34075 .40793 .35584 .42151 .34099 .41392 .32625 Mtetra
.782 .681 .752 r
.41392 .32625 .42151 .34099 .43506 .32612 .4275 .31173 Mtetra
.784 .686 .756 r
.4275 .31173 .43506 .32612 .4486 .31136 .44107 .29735 Mtetra
.786 .691 .76 r
.44107 .29735 .4486 .31136 .4621 .29682 .45461 .28319 Mtetra
.786 .697 .766 r
.45461 .28319 .4621 .29682 .47559 .28262 .46813 .26936 Mtetra
.785 .702 .772 r
.46813 .26936 .47559 .28262 .48905 .26883 .48163 .25594 Mtetra
.784 .707 .779 r
.48163 .25594 .48905 .26883 .5025 .25553 .49512 .24298 Mtetra
.781 .712 .787 r
.49512 .24298 .5025 .25553 .51593 .24275 .5086 .23054 Mtetra
.778 .717 .796 r
.5086 .23054 .51593 .24275 .52936 .23054 .52208 .21864 Mtetra
.774 .722 .804 r
.52208 .21864 .52936 .23054 .5428 .2189 .53556 .2073 Mtetra
.768 .726 .813 r
.53556 .2073 .5428 .2189 .55625 .20786 .54906 .19652 Mtetra
.763 .73 .822 r
.54906 .19652 .55625 .20786 .56972 .19738 .56258 .18628 Mtetra
.756 .733 .831 r
.56258 .18628 .56972 .19738 .58322 .18747 .57613 .17659 Mtetra
.749 .736 .84 r
.57613 .17659 .58322 .18747 .59675 .1781 .58971 .1674 Mtetra
.742 .739 .849 r
.58971 .1674 .59675 .1781 .61032 .16922 .60334 .15869 Mtetra
.734 .741 .856 r
.60334 .15869 .61032 .16922 .62394 .16082 .61701 .15042 Mtetra
.727 .742 .864 r
.61701 .15042 .62394 .16082 .63762 .15284 .63074 .14256 Mtetra
.72 .743 .87 r
.63074 .14256 .63762 .15284 .65135 .14525 .64453 .13506 Mtetra
.712 .744 .876 r
.64453 .13506 .65135 .14525 .66515 .138 .65838 .12789 Mtetra
.706 .744 .882 r
.65838 .12789 .66515 .138 .67901 .13106 .67229 .121 Mtetra
.7 .744 .886 r
.67229 .121 .67901 .13106 .69294 .12438 .68627 .11436 Mtetra
.694 .744 .89 r
.68627 .11436 .69294 .12438 .70693 .11793 .70032 .10794 Mtetra
.689 .744 .893 r
.70032 .10794 .70693 .11793 .72101 .11167 .71445 .10169 Mtetra
.685 .744 .896 r
.71445 .10169 .72101 .11167 .73515 .10557 .72865 .0956 Mtetra
.681 .744 .899 r
.72865 .0956 .73515 .10557 .74937 .0996 .74292 .08963 Mtetra
.139 .414 .859 r
.08443 .41023 .09269 .4212 .10312 .42665 .0949 .41525 Mtetra
.15 .411 .855 r
.0949 .41525 .10312 .42665 .11364 .43225 .10546 .4204 Mtetra
.172 .414 .853 r
.10546 .4204 .11364 .43225 .12428 .43786 .11614 .42555 Mtetra
.204 .423 .852 r
.11614 .42555 .12428 .43786 .13506 .44336 .12696 .43055 Mtetra
.244 .436 .851 r
.12696 .43055 .13506 .44336 .14599 .44857 .13793 .43527 Mtetra
.289 .453 .85 r
.13793 .43527 .14599 .44857 .15709 .45336 .14907 .43955 Mtetra
.337 .471 .848 r
.14907 .43955 .15709 .45336 .16837 .45754 .1604 .44324 Mtetra
.386 .49 .843 r
.1604 .44324 .16837 .45754 .17985 .46097 .17191 .44618 Mtetra
.434 .509 .837 r
.17191 .44618 .17985 .46097 .19154 .46349 .18363 .44823 Mtetra
.479 .527 .829 r
.18363 .44823 .19154 .46349 .20343 .46496 .19556 .44926 Mtetra
.52 .543 .819 r
.19556 .44926 .20343 .46496 .21554 .46526 .20769 .44916 Mtetra
.557 .557 .81 r
.20769 .44916 .21554 .46526 .22785 .46429 .22003 .44782 Mtetra
.589 .57 .8 r
.22003 .44782 .22785 .46429 .24037 .46197 .23257 .4452 Mtetra
.618 .581 .79 r
.23257 .4452 .24037 .46197 .25307 .45827 .24529 .44124 Mtetra
.643 .592 .781 r
.24529 .44124 .25307 .45827 .26595 .45316 .25819 .43594 Mtetra
.665 .601 .773 r
.25819 .43594 .26595 .45316 .27899 .44666 .27125 .42931 Mtetra
.684 .609 .766 r
.27125 .42931 .27899 .44666 .29217 .43881 .28444 .42141 Mtetra
.701 .617 .76 r
.28444 .42141 .29217 .43881 .30547 .4297 .29775 .41231 Mtetra
.715 .624 .754 r
.29775 .41231 .30547 .4297 .31888 .41941 .31117 .4021 Mtetra
.727 .63 .75 r
.31117 .4021 .31888 .41941 .33236 .40807 .32466 .3909 Mtetra
.738 .637 .747 r
.32466 .3909 .33236 .40807 .3459 .39582 .33821 .37885 Mtetra
.747 .643 .745 r
.33821 .37885 .3459 .39582 .35948 .38281 .35181 .36609 Mtetra
.755 .649 .744 r
.35181 .36609 .35948 .38281 .37309 .36919 .36542 .35277 Mtetra
.761 .655 .744 r
.36542 .35277 .37309 .36919 .3867 .35512 .37906 .33904 Mtetra
.766 .661 .746 r
.37906 .33904 .3867 .35512 .40032 .34075 .39269 .32505 Mtetra
.771 .666 .748 r
.39269 .32505 .40032 .34075 .41392 .32625 .40631 .31094 Mtetra
.774 .672 .751 r
.40631 .31094 .41392 .32625 .4275 .31173 .41992 .29684 Mtetra
.776 .678 .755 r
.41992 .29684 .4275 .31173 .44107 .29735 .43351 .28287 Mtetra
.778 .684 .76 r
.43351 .28287 .44107 .29735 .45461 .28319 .44708 .26913 Mtetra
.778 .69 .766 r
.44708 .26913 .45461 .28319 .46813 .26936 .46063 .25572 Mtetra
.778 .696 .773 r
.46063 .25572 .46813 .26936 .48163 .25594 .47417 .2427 Mtetra
.777 .701 .78 r
.47417 .2427 .48163 .25594 .49512 .24298 .4877 .23013 Mtetra
.774 .707 .788 r
.4877 .23013 .49512 .24298 .5086 .23054 .50122 .21805 Mtetra
.771 .712 .797 r
.50122 .21805 .5086 .23054 .52208 .21864 .51474 .20649 Mtetra
.767 .717 .806 r
.51474 .20649 .52208 .21864 .53556 .2073 .52827 .19547 Mtetra
.762 .722 .815 r
.52827 .19547 .53556 .2073 .54906 .19652 .54182 .18497 Mtetra
.757 .726 .824 r
.54182 .18497 .54906 .19652 .56258 .18628 .55539 .175 Mtetra
.751 .73 .833 r
.55539 .175 .56258 .18628 .57613 .17659 .56898 .16553 Mtetra
.744 .733 .842 r
.56898 .16553 .57613 .17659 .58971 .1674 .58262 .15655 Mtetra
.737 .736 .85 r
.58262 .15655 .58971 .1674 .60334 .15869 .5963 .14801 Mtetra
.73 .738 .858 r
.5963 .14801 .60334 .15869 .61701 .15042 .61002 .1399 Mtetra
.723 .74 .865 r
.61002 .1399 .61701 .15042 .63074 .14256 .6238 .13216 Mtetra
.716 .741 .871 r
.6238 .13216 .63074 .14256 .64453 .13506 .63764 .12476 Mtetra
.709 .742 .877 r
.63764 .12476 .64453 .13506 .65838 .12789 .65154 .11767 Mtetra
.703 .743 .882 r
.65154 .11767 .65838 .12789 .67229 .121 .66551 .11084 Mtetra
.697 .743 .887 r
.66551 .11084 .67229 .121 .68627 .11436 .67955 .10425 Mtetra
.692 .743 .891 r
.67955 .10425 .68627 .11436 .70032 .10794 .69365 .09785 Mtetra
.687 .743 .894 r
.69365 .09785 .70032 .10794 .71445 .10169 .70783 .09162 Mtetra
.683 .743 .897 r
.70783 .09162 .71445 .10169 .72865 .0956 .72208 .08553 Mtetra
.68 .743 .899 r
.72208 .08553 .72865 .0956 .74292 .08963 .73641 .07955 Mtetra
.201 .437 .864 r
.07619 .39865 .08443 .41023 .0949 .41525 .0867 .4032 Mtetra
.212 .433 .858 r
.0867 .4032 .0949 .41525 .10546 .4204 .09732 .40785 Mtetra
.233 .435 .854 r
.09732 .40785 .10546 .4204 .11614 .42555 .10805 .41247 Mtetra
.261 .441 .85 r
.10805 .41247 .11614 .42555 .12696 .43055 .11891 .41695 Mtetra
.296 .451 .846 r
.11891 .41695 .12696 .43055 .13793 .43527 .12993 .42113 Mtetra
.335 .463 .842 r
.12993 .42113 .13793 .43527 .14907 .43955 .14111 .42487 Mtetra
.377 .478 .836 r
.14111 .42487 .14907 .43955 .1604 .44324 .15248 .42803 Mtetra
.418 .493 .83 r
.15248 .42803 .1604 .44324 .17191 .44618 .16403 .43046 Mtetra
.459 .508 .822 r
.16403 .43046 .17191 .44618 .18363 .44823 .17579 .43202 Mtetra
.497 .523 .814 r
.17579 .43202 .18363 .44823 .19556 .44926 .18775 .4326 Mtetra
.532 .537 .805 r
.18775 .4326 .19556 .44926 .20769 .44916 .19991 .43209 Mtetra
.565 .549 .796 r
.19991 .43209 .20769 .44916 .22003 .44782 .21227 .4304 Mtetra
.594 .561 .787 r
.21227 .4304 .22003 .44782 .23257 .4452 .22483 .42747 Mtetra
.619 .572 .779 r
.22483 .42747 .23257 .4452 .24529 .44124 .23757 .42328 Mtetra
.642 .581 .771 r
.23757 .42328 .24529 .44124 .25819 .43594 .25048 .41781 Mtetra
.662 .59 .764 r
.25048 .41781 .25819 .43594 .27125 .42931 .26354 .41109 Mtetra
.679 .599 .758 r
.26354 .41109 .27125 .42931 .28444 .42141 .27674 .40316 Mtetra
.695 .606 .753 r
.27674 .40316 .28444 .42141 .29775 .41231 .29006 .39411 Mtetra
.708 .614 .749 r
.29006 .39411 .29775 .41231 .31117 .4021 .30348 .38402 Mtetra
.72 .621 .746 r
.30348 .38402 .31117 .4021 .32466 .3909 .31698 .37301 Mtetra
.73 .627 .744 r
.31698 .37301 .32466 .3909 .33821 .37885 .33053 .36121 Mtetra
.739 .634 .742 r
.33053 .36121 .33821 .37885 .35181 .36609 .34413 .34875 Mtetra
.747 .64 .742 r
.34413 .34875 .35181 .36609 .36542 .35277 .35776 .33578 Mtetra
.753 .646 .743 r
.35776 .33578 .36542 .35277 .37906 .33904 .3714 .32244 Mtetra
.759 .653 .745 r
.3714 .32244 .37906 .33904 .39269 .32505 .38504 .30886 Mtetra
.763 .659 .747 r
.38504 .30886 .39269 .32505 .40631 .31094 .39868 .29519 Mtetra
.766 .665 .751 r
.39868 .29519 .40631 .31094 .41992 .29684 .4123 .28154 Mtetra
.769 .672 .755 r
.4123 .28154 .41992 .29684 .43351 .28287 .42592 .26803 Mtetra
.77 .678 .761 r
.42592 .26803 .43351 .28287 .44708 .26913 .43951 .25475 Mtetra
.771 .684 .767 r
.43951 .25475 .44708 .26913 .46063 .25572 .45309 .24178 Mtetra
.771 .69 .774 r
.45309 .24178 .46063 .25572 .47417 .2427 .46666 .22919 Mtetra
.77 .696 .782 r
.46666 .22919 .47417 .2427 .4877 .23013 .48023 .21703 Mtetra
.767 .702 .79 r
.48023 .21703 .4877 .23013 .50122 .21805 .49379 .20534 Mtetra
.764 .708 .799 r
.49379 .20534 .50122 .21805 .51474 .20649 .50735 .19415 Mtetra
.761 .713 .808 r
.50735 .19415 .51474 .20649 .52827 .19547 .52092 .18345 Mtetra
.756 .718 .817 r
.52092 .18345 .52827 .19547 .54182 .18497 .53452 .17326 Mtetra
.751 .722 .826 r
.53452 .17326 .54182 .18497 .55539 .175 .54813 .16356 Mtetra
.745 .727 .835 r
.54813 .16356 .55539 .175 .56898 .16553 .56178 .15434 Mtetra
.739 .73 .843 r
.56178 .15434 .56898 .16553 .58262 .15655 .57547 .14557 Mtetra
.732 .733 .851 r
.57547 .14557 .58262 .15655 .5963 .14801 .58919 .13722 Mtetra
.726 .736 .859 r
.58919 .13722 .5963 .14801 .61002 .1399 .60297 .12925 Mtetra
.719 .738 .866 r
.60297 .12925 .61002 .1399 .6238 .13216 .61681 .12164 Mtetra
.712 .739 .873 r
.61681 .12164 .6238 .13216 .63764 .12476 .6307 .11435 Mtetra
.706 .74 .878 r
.6307 .11435 .63764 .12476 .65154 .11767 .64465 .10734 Mtetra
.7 .741 .883 r
.64465 .10734 .65154 .11767 .66551 .11084 .65867 .10058 Mtetra
.695 .742 .887 r
.65867 .10058 .66551 .11084 .67955 .10425 .67276 .09403 Mtetra
.69 .742 .891 r
.67276 .09403 .67955 .10425 .69365 .09785 .68692 .08767 Mtetra
.686 .742 .894 r
.68692 .08767 .69365 .09785 .70783 .09162 .70115 .08145 Mtetra
.682 .742 .897 r
.70115 .08145 .70783 .09162 .72208 .08553 .71546 .07536 Mtetra
.678 .742 .899 r
.71546 .07536 .72208 .08553 .73641 .07955 .72984 .06938 Mtetra
.255 .457 .865 r
.06797 .38653 .07619 .39865 .0867 .4032 .07853 .39056 Mtetra
.266 .453 .858 r
.07853 .39056 .0867 .4032 .09732 .40785 .0892 .39467 Mtetra
.285 .452 .852 r
.0892 .39467 .09732 .40785 .10805 .41247 .09999 .39875 Mtetra
.31 .456 .845 r
.09999 .39875 .10805 .41247 .11891 .41695 .1109 .40266 Mtetra
.34 .463 .839 r
.1109 .40266 .11891 .41695 .12993 .42113 .12197 .40627 Mtetra
.373 .473 .833 r
.12197 .40627 .12993 .42113 .14111 .42487 .1332 .40945 Mtetra
.409 .484 .826 r
.1332 .40945 .14111 .42487 .15248 .42803 .14461 .41206 Mtetra
.444 .496 .818 r
.14461 .41206 .15248 .42803 .16403 .43046 .1562 .41396 Mtetra
.479 .509 .81 r
.1562 .41396 .16403 .43046 .17579 .43202 .16799 .41502 Mtetra
.512 .521 .802 r
.16799 .41502 .17579 .43202 .18775 .4326 .17998 .41514 Mtetra
.543 .533 .794 r
.17998 .41514 .18775 .4326 .19991 .43209 .19217 .41422 Mtetra
.571 .544 .786 r
.19217 .41422 .19991 .43209 .21227 .4304 .20455 .41218 Mtetra
.597 .555 .778 r
.20455 .41218 .21227 .4304 .22483 .42747 .21713 .40897 Mtetra
.62 .564 .77 r
.21713 .40897 .22483 .42747 .23757 .42328 .22988 .40456 Mtetra
.641 .574 .764 r
.22988 .40456 .23757 .42328 .25048 .41781 .2428 .39895 Mtetra
.659 .582 .758 r
.2428 .39895 .25048 .41781 .26354 .41109 .25587 .39217 Mtetra
.675 .59 .753 r
.25587 .39217 .26354 .41109 .27674 .40316 .26907 .38425 Mtetra
.69 .598 .748 r
.26907 .38425 .27674 .40316 .29006 .39411 .28239 .37528 Mtetra
.703 .606 .745 r
.28239 .37528 .29006 .39411 .30348 .38402 .29581 .36535 Mtetra
.714 .613 .743 r
.29581 .36535 .30348 .38402 .31698 .37301 .3093 .35457 Mtetra
.724 .62 .741 r
.3093 .35457 .31698 .37301 .33053 .36121 .32286 .34306 Mtetra
.732 .626 .741 r
.32286 .34306 .33053 .36121 .34413 .34875 .33645 .33094 Mtetra
.74 .633 .741 r
.33645 .33094 .34413 .34875 .35776 .33578 .35008 .31835 Mtetra
.746 .64 .742 r
.35008 .31835 .35776 .33578 .3714 .32244 .36373 .30544 Mtetra
.751 .646 .745 r
.36373 .30544 .3714 .32244 .38504 .30886 .37737 .29231 Mtetra
.756 .653 .748 r
.37737 .29231 .38504 .30886 .39868 .29519 .39102 .27911 Mtetra
.759 .66 .752 r
.39102 .27911 .39868 .29519 .4123 .28154 .40466 .26595 Mtetra
.762 .666 .757 r
.40466 .26595 .4123 .28154 .42592 .26803 .41829 .25292 Mtetra
.763 .673 .763 r
.41829 .25292 .42592 .26803 .43951 .25475 .43191 .24012 Mtetra
.764 .679 .769 r
.43191 .24012 .43951 .25475 .45309 .24178 .44552 .22762 Mtetra
.764 .686 .776 r
.44552 .22762 .45309 .24178 .46666 .22919 .45912 .21548 Mtetra
.763 .692 .784 r
.45912 .21548 .46666 .22919 .48023 .21703 .47271 .20375 Mtetra
.761 .698 .793 r
.47271 .20375 .48023 .21703 .49379 .20534 .48631 .19247 Mtetra
.758 .704 .801 r
.48631 .19247 .49379 .20534 .50735 .19415 .49991 .18165 Mtetra
.754 .71 .81 r
.49991 .18165 .50735 .19415 .52092 .18345 .51353 .1713 Mtetra
.75 .715 .819 r
.51353 .1713 .52092 .18345 .53452 .17326 .52716 .16142 Mtetra
.745 .72 .828 r
.52716 .16142 .53452 .17326 .54813 .16356 .54082 .15201 Mtetra
.74 .724 .837 r
.54082 .15201 .54813 .16356 .56178 .15434 .55452 .14303 Mtetra
.734 .728 .846 r
.55452 .14303 .56178 .15434 .57547 .14557 .56825 .13448 Mtetra
.727 .731 .854 r
.56825 .13448 .57547 .14557 .58919 .13722 .58203 .12631 Mtetra
.721 .734 .861 r
.58203 .12631 .58919 .13722 .60297 .12925 .59586 .11851 Mtetra
.715 .736 .868 r
.59586 .11851 .60297 .12925 .61681 .12164 .60975 .11103 Mtetra
.709 .738 .874 r
.60975 .11103 .61681 .12164 .6307 .11435 .62369 .10385 Mtetra
.703 .739 .879 r
.62369 .10385 .6307 .11435 .64465 .10734 .6377 .09692 Mtetra
.697 .74 .884 r
.6377 .09692 .64465 .10734 .65867 .10058 .65177 .09022 Mtetra
.692 .741 .888 r
.65177 .09022 .65867 .10058 .67276 .09403 .66592 .08372 Mtetra
.688 .741 .892 r
.66592 .08372 .67276 .09403 .68692 .08767 .68013 .07739 Mtetra
.684 .742 .895 r
.68013 .07739 .68692 .08767 .70115 .08145 .69441 .07119 Mtetra
.68 .742 .898 r
.69441 .07119 .70115 .08145 .71546 .07536 .70877 .06511 Mtetra
.677 .742 .9 r
.70877 .06511 .71546 .07536 .72984 .06938 .72321 .05911 Mtetra
.302 .475 .864 r
.05975 .37395 .06797 .38653 .07853 .39056 .07038 .37743 Mtetra
.312 .47 .856 r
.07038 .37743 .07853 .39056 .0892 .39467 .08111 .38098 Mtetra
.329 .468 .848 r
.08111 .38098 .0892 .39467 .09999 .39875 .09195 .38447 Mtetra
.351 .47 .841 r
.09195 .38447 .09999 .39875 .1109 .40266 .10292 .38779 Mtetra
.377 .475 .833 r
.10292 .38779 .1109 .40266 .12197 .40627 .11404 .39082 Mtetra
.405 .482 .825 r
.11404 .39082 .12197 .40627 .1332 .40945 .12532 .39341 Mtetra
.435 .49 .818 r
.12532 .39341 .1332 .40945 .14461 .41206 .13677 .39546 Mtetra
.466 .5 .809 r
.13677 .39546 .14461 .41206 .1562 .41396 .14841 .39682 Mtetra
.496 .51 .801 r
.14841 .39682 .1562 .41396 .16799 .41502 .16024 .39739 Mtetra
.525 .521 .793 r
.16024 .39739 .16799 .41502 .17998 .41514 .17226 .39706 Mtetra
.552 .531 .785 r
.17226 .39706 .17998 .41514 .19217 .41422 .18447 .39574 Mtetra
.577 .541 .778 r
.18447 .39574 .19217 .41422 .20455 .41218 .19688 .39336 Mtetra
.6 .55 .77 r
.19688 .39336 .20455 .41218 .21713 .40897 .20946 .38988 Mtetra
.621 .559 .764 r
.20946 .38988 .21713 .40897 .22988 .40456 .22222 .38528 Mtetra
.64 .568 .758 r
.22222 .38528 .22988 .40456 .2428 .39895 .23515 .37955 Mtetra
.657 .576 .753 r
.23515 .37955 .2428 .39895 .25587 .39217 .24822 .37273 Mtetra
.672 .584 .749 r
.24822 .37273 .25587 .39217 .26907 .38425 .26142 .36486 Mtetra
.685 .592 .745 r
.26142 .36486 .26907 .38425 .28239 .37528 .27473 .35601 Mtetra
.697 .599 .743 r
.27473 .35601 .28239 .37528 .29581 .36535 .28814 .34627 Mtetra
.708 .607 .741 r
.28814 .34627 .29581 .36535 .3093 .35457 .30163 .33574 Mtetra
.718 .614 .74 r
.30163 .33574 .3093 .35457 .32286 .34306 .31518 .32455 Mtetra
.726 .621 .74 r
.31518 .32455 .32286 .34306 .33645 .33094 .32877 .3128 Mtetra
.733 .628 .741 r
.32877 .3128 .33645 .33094 .35008 .31835 .34239 .30064 Mtetra
.739 .635 .743 r
.34239 .30064 .35008 .31835 .36373 .30544 .35603 .28817 Mtetra
.745 .642 .746 r
.35603 .28817 .36373 .30544 .37737 .29231 .36969 .27553 Mtetra
.749 .648 .749 r
.36969 .27553 .37737 .29231 .39102 .27911 .38334 .26282 Mtetra
.752 .655 .754 r
.38334 .26282 .39102 .27911 .40466 .26595 .39699 .25016 Mtetra
.755 .662 .759 r
.39699 .25016 .40466 .26595 .41829 .25292 .41063 .23764 Mtetra
.756 .669 .765 r
.41063 .23764 .41829 .25292 .43191 .24012 .42427 .22533 Mtetra
.757 .676 .772 r
.42427 .22533 .43191 .24012 .44552 .22762 .4379 .21332 Mtetra
.757 .683 .779 r
.4379 .21332 .44552 .22762 .45912 .21548 .45152 .20165 Mtetra
.756 .689 .787 r
.45152 .20165 .45912 .21548 .47271 .20375 .46515 .19036 Mtetra
.754 .696 .796 r
.46515 .19036 .47271 .20375 .48631 .19247 .47878 .17949 Mtetra
.752 .702 .805 r
.47878 .17949 .48631 .19247 .49991 .18165 .49242 .16905 Mtetra
.748 .707 .813 r
.49242 .16905 .49991 .18165 .51353 .1713 .50607 .15905 Mtetra
.744 .713 .822 r
.50607 .15905 .51353 .1713 .52716 .16142 .51975 .14949 Mtetra
.739 .718 .831 r
.51975 .14949 .52716 .16142 .54082 .15201 .53346 .14036 Mtetra
.734 .722 .84 r
.53346 .14036 .54082 .15201 .55452 .14303 .5472 .13164 Mtetra
.728 .726 .848 r
.5472 .13164 .55452 .14303 .56825 .13448 .56098 .1233 Mtetra
.723 .729 .856 r
.56098 .1233 .56825 .13448 .58203 .12631 .57481 .11532 Mtetra
.717 .732 .863 r
.57481 .11532 .58203 .12631 .59586 .11851 .58869 .10768 Mtetra
.711 .735 .87 r
.58869 .10768 .59586 .11851 .60975 .11103 .60263 .10033 Mtetra
.705 .737 .876 r
.60263 .10033 .60975 .11103 .62369 .10385 .61662 .09325 Mtetra
.7 .738 .881 r
.61662 .09325 .62369 .10385 .6377 .09692 .63068 .08641 Mtetra
.695 .739 .885 r
.63068 .08641 .6377 .09692 .65177 .09022 .64481 .07978 Mtetra
.69 .74 .889 r
.64481 .07978 .65177 .09022 .66592 .08372 .65901 .07332 Mtetra
.686 .741 .893 r
.65901 .07332 .66592 .08372 .68013 .07739 .67327 .06702 Mtetra
.682 .741 .896 r
.67327 .06702 .68013 .07739 .69441 .07119 .68761 .06083 Mtetra
.679 .741 .898 r
.68761 .06083 .69441 .07119 .70877 .06511 .70203 .05475 Mtetra
.676 .742 .9 r
.70203 .05475 .70877 .06511 .72321 .05911 .71651 .04876 Mtetra
.344 .491 .863 r
.05153 .361 .05975 .37395 .07038 .37743 .06223 .36391 Mtetra
.353 .485 .854 r
.06223 .36391 .07038 .37743 .08111 .38098 .07302 .36686 Mtetra
.367 .482 .845 r
.07302 .36686 .08111 .38098 .09195 .38447 .08392 .36976 Mtetra
.386 .483 .836 r
.08392 .36976 .09195 .38447 .10292 .38779 .09495 .37247 Mtetra
.408 .485 .828 r
.09495 .37247 .10292 .38779 .11404 .39082 .10613 .3749 Mtetra
.432 .49 .819 r
.10613 .3749 .11404 .39082 .12532 .39341 .11746 .37691 Mtetra
.458 .497 .811 r
.11746 .37691 .12532 .39341 .13677 .39546 .12896 .37839 Mtetra
.485 .505 .803 r
.12896 .37839 .13677 .39546 .14841 .39682 .14064 .37921 Mtetra
.511 .513 .794 r
.14064 .37921 .14841 .39682 .16024 .39739 .15251 .37929 Mtetra
.536 .522 .787 r
.15251 .37929 .16024 .39739 .17226 .39706 .16456 .37851 Mtetra
.56 .53 .779 r
.16456 .37851 .17226 .39706 .18447 .39574 .1768 .3768 Mtetra
.582 .539 .772 r
.1768 .3768 .18447 .39574 .19688 .39336 .18922 .37411 Mtetra
.603 .548 .766 r
.18922 .37411 .19688 .39336 .20946 .38988 .20182 .37038 Mtetra
.622 .556 .76 r
.20182 .37038 .20946 .38988 .22222 .38528 .21458 .3656 Mtetra
.639 .564 .755 r
.21458 .3656 .22222 .38528 .23515 .37955 .22751 .35979 Mtetra
.655 .572 .75 r
.22751 .35979 .23515 .37955 .24822 .37273 .24058 .35295 Mtetra
.669 .58 .747 r
.24058 .35295 .24822 .37273 .26142 .36486 .25377 .34515 Mtetra
.682 .588 .744 r
.25377 .34515 .26142 .36486 .27473 .35601 .26708 .33645 Mtetra
.693 .595 .742 r
.26708 .33645 .27473 .35601 .28814 .34627 .28047 .32693 Mtetra
.703 .602 .741 r
.28047 .32693 .28814 .34627 .30163 .33574 .29395 .31669 Mtetra
.712 .61 .741 r
.29395 .31669 .30163 .33574 .31518 .32455 .30748 .30584 Mtetra
.72 .617 .741 r
.30748 .30584 .31518 .32455 .32877 .3128 .32107 .29449 Mtetra
.727 .624 .743 r
.32107 .29449 .32877 .3128 .34239 .30064 .33468 .28276 Mtetra
.733 .631 .745 r
.33468 .28276 .34239 .30064 .35603 .28817 .34832 .27077 Mtetra
.738 .638 .748 r
.34832 .27077 .35603 .28817 .36969 .27553 .36197 .25862 Mtetra
.743 .645 .752 r
.36197 .25862 .36969 .27553 .38334 .26282 .37562 .24643 Mtetra
.746 .652 .757 r
.37562 .24643 .38334 .26282 .39699 .25016 .38928 .23428 Mtetra
.748 .659 .762 r
.38928 .23428 .39699 .25016 .41063 .23764 .40293 .22227 Mtetra
.75 .666 .769 r
.40293 .22227 .41063 .23764 .42427 .22533 .41658 .21047 Mtetra
.751 .673 .776 r
.41658 .21047 .42427 .22533 .4379 .21332 .43023 .19895 Mtetra
.751 .68 .783 r
.43023 .19895 .4379 .21332 .45152 .20165 .44388 .18774 Mtetra
.75 .687 .791 r
.44388 .18774 .45152 .20165 .46515 .19036 .45753 .1769 Mtetra
.748 .694 .8 r
.45753 .1769 .46515 .19036 .47878 .17949 .4712 .16645 Mtetra
.745 .7 .808 r
.4712 .16645 .47878 .17949 .49242 .16905 .48487 .15639 Mtetra
.742 .706 .817 r
.48487 .15639 .49242 .16905 .50607 .15905 .49856 .14674 Mtetra
.738 .711 .826 r
.49856 .14674 .50607 .15905 .51975 .14949 .51228 .1375 Mtetra
.734 .716 .835 r
.51228 .1375 .51975 .14949 .53346 .14036 .52603 .12865 Mtetra
.729 .721 .843 r
.52603 .12865 .53346 .14036 .5472 .13164 .53982 .12017 Mtetra
.723 .725 .851 r
.53982 .12017 .5472 .13164 .56098 .1233 .55365 .11205 Mtetra
.718 .728 .859 r
.55365 .11205 .56098 .1233 .57481 .11532 .56753 .10426 Mtetra
.712 .731 .865 r
.56753 .10426 .57481 .11532 .58869 .10768 .58146 .09677 Mtetra
.707 .734 .872 r
.58146 .09677 .58869 .10768 .60263 .10033 .59545 .08956 Mtetra
.701 .736 .877 r
.59545 .08956 .60263 .10033 .61662 .09325 .6095 .08258 Mtetra
.696 .737 .882 r
.6095 .08258 .61662 .09325 .63068 .08641 .62361 .07582 Mtetra
.692 .738 .887 r
.62361 .07582 .63068 .08641 .64481 .07978 .63779 .06925 Mtetra
.687 .739 .891 r
.63779 .06925 .64481 .07978 .65901 .07332 .65204 .06284 Mtetra
.684 .74 .894 r
.65204 .06284 .65901 .07332 .67327 .06702 .66636 .05656 Mtetra
.68 .741 .896 r
.66636 .05656 .67327 .06702 .68761 .06083 .68075 .05039 Mtetra
.677 .741 .899 r
.68075 .05039 .68761 .06083 .70203 .05475 .69522 .04431 Mtetra
.675 .741 .901 r
.69522 .04431 .70203 .05475 .71651 .04876 .70976 .0383 Mtetra
.38 .506 .86 r
.04331 .34775 .05153 .361 .06223 .36391 .05407 .35008 Mtetra
.387 .5 .851 r
.05407 .35008 .06223 .36391 .07302 .36686 .06493 .35244 Mtetra
.4 .496 .842 r
.06493 .35244 .07302 .36686 .08392 .36976 .07589 .35472 Mtetra
.416 .495 .833 r
.07589 .35472 .08392 .36976 .09495 .37247 .08699 .35683 Mtetra
.435 .496 .824 r
.08699 .35683 .09495 .37247 .10613 .3749 .09822 .35865 Mtetra
.456 .499 .815 r
.09822 .35865 .10613 .3749 .11746 .37691 .10961 .36007 Mtetra
.478 .504 .806 r
.10961 .36007 .11746 .37691 .12896 .37839 .12116 .36099 Mtetra
.501 .51 .798 r
.12116 .36099 .12896 .37839 .14064 .37921 .13289 .36129 Mtetra
.524 .517 .79 r
.13289 .36129 .14064 .37921 .15251 .37929 .14479 .36088 Mtetra
.546 .524 .782 r
.14479 .36088 .15251 .37929 .16456 .37851 .15687 .35967 Mtetra
.567 .532 .775 r
.15687 .35967 .16456 .37851 .1768 .3768 .16913 .35759 Mtetra
.587 .539 .769 r
.16913 .35759 .1768 .3768 .18922 .37411 .18157 .35459 Mtetra
.606 .547 .763 r
.18157 .35459 .18922 .37411 .20182 .37038 .19417 .35064 Mtetra
.623 .555 .757 r
.19417 .35064 .20182 .37038 .21458 .3656 .20695 .34572 Mtetra
.639 .563 .753 r
.20695 .34572 .21458 .3656 .22751 .35979 .21987 .33983 Mtetra
.653 .57 .749 r
.21987 .33983 .22751 .35979 .24058 .35295 .23293 .33301 Mtetra
.666 .578 .746 r
.23293 .33301 .24058 .35295 .25377 .34515 .24612 .3253 Mtetra
.678 .585 .744 r
.24612 .3253 .25377 .34515 .26708 .33645 .25941 .31676 Mtetra
.689 .592 .742 r
.25941 .31676 .26708 .33645 .28047 .32693 .27279 .30748 Mtetra
.699 .6 .742 r
.27279 .30748 .28047 .32693 .29395 .31669 .28625 .29755 Mtetra
.707 .607 .742 r
.28625 .29755 .29395 .31669 .30748 .30584 .29977 .28706 Mtetra
.715 .614 .743 r
.29977 .28706 .30748 .30584 .32107 .29449 .31334 .27613 Mtetra
.722 .621 .745 r
.31334 .27613 .32107 .29449 .33468 .28276 .32695 .26485 Mtetra
.728 .629 .748 r
.32695 .26485 .33468 .28276 .34832 .27077 .34057 .25334 Mtetra
.733 .636 .751 r
.34057 .25334 .34832 .27077 .36197 .25862 .35422 .24169 Mtetra
.737 .643 .756 r
.35422 .24169 .36197 .25862 .37562 .24643 .36787 .23002 Mtetra
.74 .65 .761 r
.36787 .23002 .37562 .24643 .38928 .23428 .38153 .21839 Mtetra
.742 .658 .766 r
.38153 .21839 .38928 .23428 .40293 .22227 .39519 .2069 Mtetra
.744 .665 .773 r
.39519 .2069 .40293 .22227 .41658 .21047 .40886 .19561 Mtetra
.744 .672 .78 r
.40886 .19561 .41658 .21047 .43023 .19895 .42252 .18457 Mtetra
.744 .679 .788 r
.42252 .18457 .43023 .19895 .44388 .18774 .43619 .17384 Mtetra
.743 .686 .796 r
.43619 .17384 .44388 .18774 .45753 .1769 .44987 .16343 Mtetra
.742 .693 .804 r
.44987 .16343 .45753 .1769 .4712 .16645 .46356 .15339 Mtetra
.739 .699 .813 r
.46356 .15339 .4712 .16645 .48487 .15639 .47727 .14371 Mtetra
.736 .705 .822 r
.47727 .14371 .48487 .15639 .49856 .14674 .491 .13441 Mtetra
.732 .71 .83 r
.491 .13441 .49856 .14674 .51228 .1375 .50476 .12547 Mtetra
.728 .715 .839 r
.50476 .12547 .51228 .1375 .52603 .12865 .51855 .1169 Mtetra
.723 .72 .847 r
.51855 .1169 .52603 .12865 .53982 .12017 .53238 .10867 Mtetra
.718 .724 .854 r
.53238 .10867 .53982 .12017 .55365 .11205 .54626 .10076 Mtetra
.713 .727 .861 r
.54626 .10076 .55365 .11205 .56753 .10426 .56019 .09315 Mtetra
.708 .73 .868 r
.56019 .09315 .56753 .10426 .58146 .09677 .57417 .08581 Mtetra
.703 .733 .874 r
.57417 .08581 .58146 .09677 .59545 .08956 .5882 .07871 Mtetra
.698 .735 .879 r
.5882 .07871 .59545 .08956 .6095 .08258 .6023 .07184 Mtetra
.693 .737 .884 r
.6023 .07184 .6095 .08258 .62361 .07582 .61647 .06516 Mtetra
.689 .738 .888 r
.61647 .06516 .62361 .07582 .63779 .06925 .6307 .05864 Mtetra
.685 .739 .892 r
.6307 .05864 .63779 .06925 .65204 .06284 .645 .05227 Mtetra
.682 .74 .895 r
.645 .05227 .65204 .06284 .66636 .05656 .65937 .04602 Mtetra
.679 .74 .897 r
.65937 .04602 .66636 .05656 .68075 .05039 .67382 .03986 Mtetra
.676 .741 .899 r
.67382 .03986 .68075 .05039 .69522 .04431 .68834 .03378 Mtetra
.674 .741 .901 r
.68834 .03378 .69522 .04431 .70976 .0383 .70294 .02776 Mtetra
.412 .521 .859 r
.03505 .3343 .04331 .34775 .05407 .35008 .04589 .33605 Mtetra
.418 .514 .849 r
.04589 .33605 .05407 .35008 .06493 .35244 .05682 .3378 Mtetra
.428 .509 .839 r
.05682 .3378 .06493 .35244 .07589 .35472 .06785 .33948 Mtetra
.442 .507 .83 r
.06785 .33948 .07589 .35472 .08699 .35683 .07901 .34098 Mtetra
.458 .507 .821 r
.07901 .34098 .08699 .35683 .09822 .35865 .09031 .3422 Mtetra
.476 .508 .812 r
.09031 .3422 .09822 .35865 .10961 .36007 .10175 .34305 Mtetra
.496 .512 .803 r
.10175 .34305 .10961 .36007 .12116 .36099 .11335 .34341 Mtetra
.515 .516 .795 r
.11335 .34341 .12116 .36099 .13289 .36129 .12512 .34319 Mtetra
.535 .522 .787 r
.12512 .34319 .13289 .36129 .14479 .36088 .13706 .34231 Mtetra
.555 .528 .78 r
.13706 .34231 .14479 .36088 .15687 .35967 .14917 .34069 Mtetra
.574 .534 .773 r
.14917 .34069 .15687 .35967 .16913 .35759 .16145 .33827 Mtetra
.591 .541 .767 r
.16145 .33827 .16913 .35759 .18157 .35459 .1739 .33499 Mtetra
.608 .548 .762 r
.1739 .33499 .18157 .35459 .19417 .35064 .18652 .33083 Mtetra
.624 .555 .757 r
.18652 .33083 .19417 .35064 .20695 .34572 .1993 .32578 Mtetra
.639 .562 .753 r
.1993 .32578 .20695 .34572 .21987 .33983 .21222 .31985 Mtetra
.652 .57 .749 r
.21222 .31985 .21987 .33983 .23293 .33301 .22527 .31306 Mtetra
.664 .577 .747 r
.22527 .31306 .23293 .33301 .24612 .3253 .23844 .30546 Mtetra
.676 .584 .745 r
.23844 .30546 .24612 .3253 .25941 .31676 .25172 .29711 Mtetra
.686 .591 .744 r
.25172 .29711 .25941 .31676 .27279 .30748 .26508 .28808 Mtetra
.695 .598 .744 r
.26508 .28808 .27279 .30748 .28625 .29755 .27853 .27847 Mtetra
.703 .606 .745 r
.27853 .27847 .28625 .29755 .29977 .28706 .29203 .26835 Mtetra
.71 .613 .746 r
.29203 .26835 .29977 .28706 .31334 .27613 .30558 .25783 Mtetra
.717 .62 .748 r
.30558 .25783 .31334 .27613 .32695 .26485 .31917 .24701 Mtetra
.722 .627 .752 r
.31917 .24701 .32695 .26485 .34057 .25334 .33279 .23599 Mtetra
.727 .635 .755 r
.33279 .23599 .34057 .25334 .35422 .24169 .34643 .22485 Mtetra
.731 .642 .76 r
.34643 .22485 .35422 .24169 .36787 .23002 .36008 .21369 Mtetra
.734 .65 .765 r
.36008 .21369 .36787 .23002 .38153 .21839 .37374 .20258 Mtetra
.736 .657 .771 r
.37374 .20258 .38153 .21839 .39519 .2069 .38741 .1916 Mtetra
.738 .664 .778 r
.38741 .1916 .39519 .2069 .40886 .19561 .40108 .1808 Mtetra
.738 .672 .785 r
.40108 .1808 .40886 .19561 .42252 .18457 .41476 .17025 Mtetra
.738 .679 .793 r
.41476 .17025 .42252 .18457 .43619 .17384 .42845 .15997 Mtetra
.737 .686 .801 r
.42845 .15997 .43619 .17384 .44987 .16343 .44215 .15 Mtetra
.736 .692 .809 r
.44215 .15 .44987 .16343 .46356 .15339 .45587 .14035 Mtetra
.733 .699 .818 r
.45587 .14035 .46356 .15339 .47727 .14371 .46961 .13104 Mtetra
.73 .705 .826 r
.46961 .13104 .47727 .14371 .491 .13441 .48338 .12207 Mtetra
.727 .71 .835 r
.48338 .12207 .491 .13441 .50476 .12547 .49718 .11344 Mtetra
.723 .715 .843 r
.49718 .11344 .50476 .12547 .51855 .1169 .51101 .10513 Mtetra
.718 .72 .85 r
.51101 .10513 .51855 .1169 .53238 .10867 .52489 .09713 Mtetra
.713 .724 .858 r
.52489 .09713 .53238 .10867 .54626 .10076 .53881 .08942 Mtetra
.709 .727 .865 r
.53881 .08942 .54626 .10076 .56019 .09315 .55278 .08198 Mtetra
.704 .73 .871 r
.55278 .08198 .56019 .09315 .57417 .08581 .56681 .07479 Mtetra
.699 .732 .876 r
.56681 .07479 .57417 .08581 .5882 .07871 .5809 .06781 Mtetra
.695 .734 .881 r
.5809 .06781 .5882 .07871 .6023 .07184 .59505 .06103 Mtetra
.69 .736 .886 r
.59505 .06103 .6023 .07184 .61647 .06516 .60927 .05443 Mtetra
.686 .737 .89 r
.60927 .05443 .61647 .06516 .6307 .05864 .62355 .04796 Mtetra
.683 .738 .893 r
.62355 .04796 .6307 .05864 .645 .05227 .6379 .04162 Mtetra
.68 .739 .896 r
.6379 .04162 .645 .05227 .65937 .04602 .65233 .03539 Mtetra
.677 .74 .898 r
.65233 .03539 .65937 .04602 .67382 .03986 .66683 .02924 Mtetra
.675 .74 .9 r
.66683 .02924 .67382 .03986 .68834 .03378 .6814 .02316 Mtetra
.672 .741 .902 r
.6814 .02316 .68834 .03378 .70294 .02776 .69606 .01712 Mtetra
.44 .535 .857 r
.02677 .32073 .03505 .3343 .04589 .33605 .03767 .32189 Mtetra
.445 .527 .848 r
.03767 .32189 .04589 .33605 .05682 .3378 .04868 .32305 Mtetra
.454 .522 .838 r
.04868 .32305 .05682 .3378 .06785 .33948 .05978 .32413 Mtetra
.465 .519 .829 r
.05978 .32413 .06785 .33948 .07901 .34098 .07101 .32503 Mtetra
.479 .518 .819 r
.07101 .32503 .07901 .34098 .09031 .3422 .08237 .32567 Mtetra
.495 .518 .81 r
.08237 .32567 .09031 .3422 .10175 .34305 .09387 .32595 Mtetra
.511 .52 .802 r
.09387 .32595 .10175 .34305 .11335 .34341 .10552 .32578 Mtetra
.528 .523 .794 r
.10552 .32578 .11335 .34341 .12512 .34319 .11733 .32507 Mtetra
.546 .528 .786 r
.11733 .32507 .12512 .34319 .13706 .34231 .1293 .32374 Mtetra
.563 .533 .779 r
.1293 .32374 .13706 .34231 .14917 .34069 .14144 .32172 Mtetra
.58 .538 .773 r
.14144 .32172 .14917 .34069 .16145 .33827 .15375 .31897 Mtetra
.596 .544 .767 r
.15375 .31897 .16145 .33827 .1739 .33499 .16622 .31543 Mtetra
.611 .551 .762 r
.16622 .31543 .1739 .33499 .18652 .33083 .17884 .31109 Mtetra
.625 .557 .758 r
.17884 .31109 .18652 .33083 .1993 .32578 .19162 .30593 Mtetra
.639 .564 .754 r
.19162 .30593 .1993 .32578 .21222 .31985 .20453 .29997 Mtetra
.651 .571 .751 r
.20453 .29997 .21222 .31985 .22527 .31306 .21757 .29324 Mtetra
.663 .578 .749 r
.21757 .29324 .22527 .31306 .23844 .30546 .23073 .28576 Mtetra
.673 .585 .748 r
.23073 .28576 .23844 .30546 .25172 .29711 .24399 .27761 Mtetra
.683 .592 .747 r
.24399 .27761 .25172 .29711 .26508 .28808 .25734 .26885 Mtetra
.691 .599 .748 r
.25734 .26885 .26508 .28808 .27853 .27847 .27076 .25956 Mtetra
.699 .606 .749 r
.27076 .25956 .27853 .27847 .29203 .26835 .28425 .24982 Mtetra
.706 .613 .75 r
.28425 .24982 .29203 .26835 .30558 .25783 .29778 .23972 Mtetra
.712 .62 .753 r
.29778 .23972 .30558 .25783 .31917 .24701 .31136 .22935 Mtetra
.718 .628 .756 r
.31136 .22935 .31917 .24701 .33279 .23599 .32496 .21881 Mtetra
.722 .635 .76 r
.32496 .21881 .33279 .23599 .34643 .22485 .33859 .20817 Mtetra
.726 .642 .765 r
.33859 .20817 .34643 .22485 .36008 .21369 .35223 .19751 Mtetra
.729 .65 .771 r
.35223 .19751 .36008 .21369 .37374 .20258 .36589 .18691 Mtetra
.731 .657 .777 r
.36589 .18691 .37374 .20258 .38741 .1916 .37957 .17642 Mtetra
.732 .665 .784 r
.37957 .17642 .38741 .1916 .40108 .1808 .39325 .16611 Mtetra
.733 .672 .791 r
.39325 .16611 .40108 .1808 .41476 .17025 .40694 .15602 Mtetra
.733 .679 .799 r
.40694 .15602 .41476 .17025 .42845 .15997 .42065 .14619 Mtetra
.732 .686 .807 r
.42065 .14619 .42845 .15997 .44215 .15 .43438 .13663 Mtetra
.73 .693 .815 r
.43438 .13663 .44215 .15 .45587 .14035 .44813 .12737 Mtetra
.728 .699 .823 r
.44813 .12737 .45587 .14035 .46961 .13104 .4619 .11841 Mtetra
.725 .705 .831 r
.4619 .11841 .46961 .13104 .48338 .12207 .4757 .10976 Mtetra
.721 .71 .839 r
.4757 .10976 .48338 .12207 .49718 .11344 .48953 .10142 Mtetra
.717 .715 .847 r
.48953 .10142 .49718 .11344 .51101 .10513 .50341 .09336 Mtetra
.713 .72 .854 r
.50341 .09336 .51101 .10513 .52489 .09713 .51733 .08559 Mtetra
.709 .723 .861 r
.51733 .08559 .52489 .09713 .53881 .08942 .53129 .07807 Mtetra
.704 .727 .868 r
.53129 .07807 .53881 .08942 .55278 .08198 .54532 .07079 Mtetra
.7 .73 .874 r
.54532 .07079 .55278 .08198 .56681 .07479 .55939 .06373 Mtetra
.696 .732 .879 r
.55939 .06373 .56681 .07479 .5809 .06781 .57353 .05686 Mtetra
.691 .734 .883 r
.57353 .05686 .5809 .06781 .59505 .06103 .58773 .05017 Mtetra
.688 .736 .888 r
.58773 .05017 .59505 .06103 .60927 .05443 .602 .04363 Mtetra
.684 .737 .891 r
.602 .04363 .60927 .05443 .62355 .04796 .61633 .03721 Mtetra
.681 .738 .894 r
.61633 .03721 .62355 .04796 .6379 .04162 .63074 .0309 Mtetra
.678 .739 .897 r
.63074 .0309 .6379 .04162 .65233 .03539 .64522 .02468 Mtetra
.675 .74 .899 r
.64522 .02468 .65233 .03539 .66683 .02924 .65977 .01854 Mtetra
.673 .74 .901 r
.65977 .01854 .66683 .02924 .6814 .02316 .6744 .01244 Mtetra
.671 .74 .902 r
.6744 .01244 .6814 .02316 .69606 .01712 .68911 .0064 Mtetra
0 g
.68874 0 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.68874 0 m
.03716 .25514 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 0.522676 0.477324 0.97619 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.49505 0.5 0.49505 [
[ 0 0 -0.125 0 ]
[ 0 0 -0.125 0 ]
[ 0 1 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
0 0 m
1 0 L
s
0 0 m
0 1 L
s
0 1 m
1 1 L
s
1 0 m
1 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
1 .5 0 r
.015 w
.03175 .1355 Mdot
.03435 .12523 Mdot
.11137 .12765 Mdot
.14107 .18841 Mdot
.16218 .24538 Mdot
.17294 .21053 Mdot
.18267 .18577 Mdot
.18434 .1304 Mdot
.18553 .30956 Mdot
.20401 .239 Mdot
.21247 .27571 Mdot
.21687 .20845 Mdot
.22376 .2799 Mdot
.22832 .27485 Mdot
.29063 .20974 Mdot
.29686 .25079 Mdot
.30487 .22936 Mdot
.30683 .34623 Mdot
.32055 .20902 Mdot
.32574 .21979 Mdot
.34472 .28521 Mdot
.35998 .36393 Mdot
.36335 .24976 Mdot
.3794 .36608 Mdot
.42386 .66992 Mdot
.44391 .74519 Mdot
.45059 .34198 Mdot
.47208 .67586 Mdot
.47436 .71381 Mdot
.49778 .59825 Mdot
.50874 .91643 Mdot
.51516 .76219 Mdot
.53655 .61374 Mdot
.56563 .75219 Mdot
.59189 .65665 Mdot
.59581 .61604 Mdot
.59923 .6556 Mdot
.60292 .68499 Mdot
.62656 .67779 Mdot
.63555 .72451 Mdot
.63919 .652 Mdot
.64169 .6004 Mdot
.64246 .58611 Mdot
.64496 .54267 Mdot
.64608 .77288 Mdot
.65077 .64308 Mdot
.66065 .57816 Mdot
.67474 .59169 Mdot
.69296 .563 Mdot
.72815 .65902 Mdot
.73169 .58879 Mdot
.74669 .61318 Mdot
.74821 .65474 Mdot
.75963 .63781 Mdot
.79673 .57809 Mdot
.80925 .55852 Mdot
.81525 .58444 Mdot
.83417 .62985 Mdot
.83598 .55526 Mdot
.91595 .49319 Mdot
0 0 1 r
.005 w
.00495 .28842 m
.00628 .29156 L
.01857 .31761 L
.03101 .33781 L
.03525 .34367 L
.05706 .36884 L
.05795 .36972 L
.08312 .39115 L
.08963 .39578 L
.10917 .40763 L
.13523 .41964 L
.14074 .42183 L
.16128 .42794 L
.18734 .43294 L
.21339 .43485 L
.23945 .43375 L
.2655 .42959 L
.29156 .42219 L
.29261 .42183 L
.31761 .41124 L
.34367 .39603 L
.34405 .39578 L
.36972 .37551 L
.37582 .36972 L
.39578 .34724 L
.39849 .34367 L
.41525 .31761 L
.42183 .30485 L
.4275 .29156 L
.436 .2655 L
.44117 .23945 L
.44325 .21339 L
.44232 .18734 L
.43834 .16128 L
.43114 .13523 L
.42183 .11212 L
.42037 .10917 L
.40546 .08312 L
.39578 .06961 L
.38528 .05706 L
.36972 .04137 L
.35758 .03101 L
.34367 .02092 L
.31761 .00569 L
.3162 .00495 L
s
.00495 .12854 m
.01344 .10917 L
.02832 .08312 L
.03101 .07912 L
.04848 .05706 L
.05706 .04802 L
.07619 .03101 L
.08312 .02579 L
.10917 .00934 L
.11742 .00495 L
s
.29156 .15739 m
.31761 .14824 L
.34367 .14249 L
.36972 .13986 L
.39578 .14025 L
.42183 .14366 L
.44789 .15025 L
.47394 .16034 L
.47599 .16128 L
.5 .17443 L
.51844 .18734 L
.52606 .19355 L
.54662 .21339 L
.55211 .21962 L
.56712 .23945 L
.57817 .25755 L
.58227 .2655 L
.59322 .29156 L
.60058 .31761 L
.60422 .3392 L
.60471 .34367 L
.6058 .36972 L
.60422 .39297 L
.60387 .39578 L
.59886 .42183 L
.59054 .44789 L
.57848 .47394 L
.57817 .47453 L
.562 .5 L
.55211 .51255 L
.53968 .52606 L
.52606 .53862 L
.50853 .55211 L
.5 .55773 L
.47394 .57183 L
.45901 .57817 L
.44789 .5819 L
.42183 .5885 L
.39578 .59192 L
.36972 .59231 L
.34367 .58968 L
.31761 .58392 L
.29972 .57817 L
.29156 .57477 L
.2655 .56178 L
.25025 .55211 L
.23945 .54409 L
.21914 .52606 L
.21339 .52008 L
.19681 .5 L
Mistroke
.18734 .48608 L
.18031 .47394 L
.16827 .44789 L
.16128 .42714 L
.15996 .42183 L
.15493 .39578 L
.153 .36972 L
.15409 .34367 L
.15823 .31761 L
.16128 .3045 L
.16559 .29156 L
.17653 .2655 L
.18734 .24609 L
.19169 .23945 L
.21221 .21339 L
.21339 .21211 L
.23945 .1881 L
.24041 .18734 L
.2655 .17038 L
.28271 .16128 L
.29156 .15739 L
Mfstroke
0 g
.03 w
.21687 .20845 Mdot
.3794 .36608 Mdot
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.522676 0.522676 0.97619 0.97619 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.49505 0.5 0.49505 [
[ 0 0 -0.125 0 ]
[ 0 0 -0.125 0 ]
[ 0 1 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
0 0 m
1 0 L
s
0 0 m
0 1 L
s
0 1 m
1 1 L
s
1 0 m
1 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
1 .5 0 r
.015 w
.03175 .1355 Mdot
.03435 .12523 Mdot
.11137 .12765 Mdot
.14107 .18841 Mdot
.16218 .24538 Mdot
.17294 .21053 Mdot
.18267 .18577 Mdot
.18434 .1304 Mdot
.18553 .30956 Mdot
.20401 .239 Mdot
.21247 .27571 Mdot
.21687 .20845 Mdot
.22376 .2799 Mdot
.22832 .27485 Mdot
.29063 .20974 Mdot
.29686 .25079 Mdot
.30487 .22936 Mdot
.30683 .34623 Mdot
.32055 .20902 Mdot
.32574 .21979 Mdot
.34472 .28521 Mdot
.35998 .36393 Mdot
.36335 .24976 Mdot
.3794 .36608 Mdot
.42386 .66992 Mdot
.44391 .74519 Mdot
.45059 .34198 Mdot
.47208 .67586 Mdot
.47436 .71381 Mdot
.49778 .59825 Mdot
.50874 .91643 Mdot
.51516 .76219 Mdot
.53655 .61374 Mdot
.56563 .75219 Mdot
.59189 .65665 Mdot
.59581 .61604 Mdot
.59923 .6556 Mdot
.60292 .68499 Mdot
.62656 .67779 Mdot
.63555 .72451 Mdot
.63919 .652 Mdot
.64169 .6004 Mdot
.64246 .58611 Mdot
.64496 .54267 Mdot
.64608 .77288 Mdot
.65077 .64308 Mdot
.66065 .57816 Mdot
.67474 .59169 Mdot
.69296 .563 Mdot
.72815 .65902 Mdot
.73169 .58879 Mdot
.74669 .61318 Mdot
.74821 .65474 Mdot
.75963 .63781 Mdot
.79673 .57809 Mdot
.80925 .55852 Mdot
.81525 .58444 Mdot
.83417 .62985 Mdot
.83598 .55526 Mdot
.91595 .49319 Mdot
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{400, 400},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40006@0001T2000`400?l00000o`00003ooooooonA
ooooo`00oooooonAooooo`00oooooonAooooo`00oooooonAooooo`00oooooonAooooo`00oooooonA
ooooo`00oooooonAooooo`00oooooonAooooo`00oooooonAooooo`00oooooonAooooo`002Ooooonf
00000=7ooooo0009ooooo`0300000?oooooooooo0;;ooooo00<00000ooooooooool0coooool000Wo
oooo00<00000ooooooooool0/_ooool00`00003oooooooooo`3?ooooo`002Oooool00`00003ooooo
ooooo`2booooo`0300000?oooooooooo0<oooooo0009ooooo`0300000?oooooooooo00[ooooo00?o
0000ooooooooool02_ooool200000003o`000?oooooooooo02Kooooo0_l00002000000_ooooo0P00
000;ooooo`03o`000000003ooooo00cooooo00<00000ooooooooool04_ooool00`00003ooooooooo
o`0]ooooo`0300000?oooooooooo0<oooooo0009ooooo`0400000?ooooooooooooooo`P0C4a<00?o
000006IVIP1VIVH02@1VIVH2000002l0Ogmo0P00000;06IVIP030000001<C4`0C4a<00X0C4a<00<0
000003<c<`0c<c<02`0c<c<00`0000006ATI01TI6@0A01TI6B`000001?ooool00`00003ooooooooo
o`3?ooooo`002Oooool01000003oooooooooooooool604a<C0;o00002`1VIVH00`000000Ogmo07mo
O`0B07moO`/00000501oOgl00`000000IVIV06IVIP0906IVIP8000002`1<C4`00`000000<c<c03<c
<`0;03<c<`030000000I6AT06ATI01406ATI:`000004ooooo`0300000?oooooooooo0<oooooo0009
ooooo`0400000?ooooooooooooooo`D0C4a<00?o000006IVIP1VIVH02P1VIVH00`000000Ogmo07mo
O`0>07moO`D000002`2IVIT00`00003o000000000004000000h0Ogmo00<00000o`00000000002P1V
IVH00`000000C4a<04a<C00904a<C0030000000c<c<0<c<c00/0<c<c00<0000001TI6@0I6AT04@0I
6ATZ000000Cooooo00<00000ooooooooool0coooool000Wooooo00@00000oooooooooooooooo1@1<
C4`00ol00000IVIV06IVIP0806IVIP0300000?l00000Ogmo00h0Ogmo0P00000G09VIV@<000003P1o
Ogl00`000000IVIV06IVIP0806IVIP03o`00001<C4`0C4a<00P0C4a<00<0000003<c<`0c<c<02`0c
<c<00`0000006ATI01TI6@0B01TI6@03o`0000000000000002H000001?ooool00`00003ooooooooo
o`3?ooooo`002Oooool01000003oooooooooooooool404a<C003o`00001VIVH0IVIV00P0IVIV00<0
000007moO`1oOgl02`1oOgl4000001`0VIVI00<0000007moO`1oOgl0301oOgl00`000000IVIV06IV
IP0806IVIP030000001<C4`0C4a<00P0C4a<00<0000003<c<`0c<c<02`0c<c<00`0000006ATI01TI
6@0A01TI6BT000001?ooool00`00003oooooooooo`3?ooooo`002Oooool01000003ooooooooooooo
ool304a<C003o`00001VIVH0IVIV00P0IVIV00<0000007moO`1oOgl02P1oOgl200000240VIVI0`00
000<07moO`030000001VIVH0IVIV00P0IVIV00<0000004a<C01<C4`0201<C4`00`000000<c<c0000
000;03<c<`030000000I6AT06ATI01406ATI:0000004ooooo`0300000?oooooooooo0<oooooo0009
ooooo`0400000?ooooooooooooooo`80C4a<00?o000006IVIP1VIVH01`1VIVH00`00003o000007mo
O`0:07moO`0300000?l00000VIVI02D0VIVI00?o00000000000000002P1oOgl2000000T0IVIV00<0
0000o`00001<C4`0201<C4`00`000000<c<c03<c<`0;03<c<`030000000I6AT06ATI01006ATI:000
0004ooooo`0300000?oooooooooo0<oooooo0009ooooo`0400000?ooooooooooooooo`80C4a<00?o
000006IVIP1VIVH01P1VIVH00`000000Ogmo07moO`0907moO`800000:`2IVIT00`000000Ogmo07mo
O`0907moO`030000001VIVH0IVIV00P0IVIV00<0000004a<C01<C4`01`1<C4`00`000000<c<c03<c
<`0:03<c<`030000000I6AT06ATI01006ATI:0000004ooooo`0300000?oooooooooo0<oooooo0009
ooooo`0600000?ooooooooooooooo`1<C4co0000201VIVH00`000000Ogmo07moO`0807moO`800000
4@2IVIT?000000h0VIVI0P00000:07moO`030000001VIVH0IVIV00P0IVIV00<0000004a<C01<C4`0
1`1<C4`00`000000<c<c03<c<`0:03<c<`030000000I6AT06ATI01006ATI9`000004ooooo`030000
0?oooooooooo0<oooooo0009ooooo`0500000?ooooooooooooooool00000201VIVH00ol00000Ogmo
07moO`0807moO`030000002IVIT0VIVI00d0VIVI00@00000o`000?l0000000003`2c/k<3000000d0
VIVI0P00000907moO`030000001VIVH0IVIV00P0IVIV00<0000004a<C01<C4`01`1<C4`00`000000
<c<c03<c<`0:03<c<`030000000I6AT06ATI01006ATI9P000004ooooo`0300000?oooooooooo0<oo
oooo0009ooooo`0400000?ooooooooooooooo`T0IVIV00<0000007moO`1oOgl01`1oOgl00`000000
VIVI09VIV@0;09VIV@<000005P2c/k<4000000/0VIVI0P00000807moO`03o`00001VIVH0IVIV00L0
IVIV00?o000004a<C01<C4`0201<C4`00ol00000<c<c03<c<`0903<c<`030000000I6AT06ATI0100
6ATI9P000004ooooo`0300000?oooooooooo0<oooooo0009ooooo`0400000?ooooooooooooooo`P0
IVIV00<0000007moO`1oOgl01`1oOgl00`000000VIVI09VIV@0909VIV@<000007@2c/k<2000000/0
VIVI00<0000007moO`1oOgl01P1oOgl00`000000IVIV06IVIP0706IVIP030000001<C4`0C4a<00L0
C4a<00<0000003<c<`0c<c<02P0c<c<00`0000006ATI01TI6@0@01TI6BD000001?ooool00`00003o
ooooooooo`3?ooooo`002Oooool01000003oooooooooooooool706IVIP800000201oOgl00`000000
VIVI09VIV@0909VIV@030000002c/k<0/k>c0200/k>c00<0000009VIV@2IVIT02@2IVIT00ol00000
Ogmo07moO`0607moO`030000001VIVH0IVIV00L0IVIV00<0000004a<C01<C4`01`1<C4`00`000000
<c<c03<c<`0:03<c<`030000000I6AT06ATI00l06ATI9@000004ooooo`0300000?oooooooooo08_o
oooo0_l00012ooooo`002Oooool01000003oooooooooooooool706IVIP030000001oOgl0Ogmo00H0
Ogmo00?o000009VIV@2IVIT01`2IVIT00`00003o00000000000T0;>c/`03o`0000000000000000P0
VIVI0P00000807moO`030000001VIVH0IVIV00L0IVIV00<0000004a<C01<C4`01`1<C4`00`000000
<c<c03<c<`0903<c<`03o`00000I6AT06ATI01006ATI90000004ooooo`0300000?oooooooooo08So
oooo0ol000000ooooooo0000ooooo`11ooooo`002Oooool01000003oooooooooooooool606IVIP03
0000001oOgl0Ogmo00H0Ogmo00<0000009VIV@2IVIT01`2IVIT00`000000/k>c0;>c/`0X0;>c/`03
0000002IVIT0VIVI00L0VIVI0P00000707moO`030000001VIVH0IVIV00L0IVIV00?o000004a<C01<
C4`01`1<C4`00ol00000<c<c03<c<`0803<c<`030000000I6AT06ATI01406ATI8`000004ooooo`03
00000?oooooooooo08Kooooo0_l00003ooooo`03oj^mi_l0003o0000047ooooo0009ooooo`040000
0?ooooooooooooooo`D0IVIV00<0000007moO`1oOgl01P1oOgl00`000000VIVI09VIV@0709VIV@03
0000002c/k<0/k>c00d0/k>c3`00000>0;>c/`03o`00002IVIT0VIVI00P0VIVI00?o000007moO`1o
Ogl01@1oOgl00`000000IVIV06IVIP0706IVIP030000001<C4`0C4a<00H0C4a<00<0000003<c<`0c
<c<02@0c<c<00`0000006ATI01TI6@0A01TI6B8000001?ooool00`00003oooooooooo`23ooooo`?o
00000_ooool01on/_NKoZkgVoj^mi_n[_NKo0000ooooool00000@?ooool000Wooooo00@00000oooo
oooooooooooo101VIVH00`000000Ogmo07moO`0607moO`03o`00002IVIT0VIVI00H0VIVI00<00000
o`00002c/k<02`2c/k<4000000l0c<c<0`00000<0;>c/`800000202IVIT2000000L0Ogmo00<00000
06IVIP1VIVH01`1VIVH00`000000C4a<04a<C00604a<C0030000000c<c<0<c<c00T0<c<c00<00000
01TI6@0I6AT0400I6AT00ol0000000000000000O000000Cooooo00<00000ooooooooool0P?ooool3
o`0000?ooooo1?n/_NH2oj^miP03o`000?oooooo0000043ooooo0009ooooo`0400000?oooooooooo
ooooo`@0IVIV00<0000007moO`1oOgl01@1oOgl00`000000VIVI09VIV@0609VIV@030000002c/k<0
/k>c00T0/k>c0`00000F0<c<c0<000002`2c/k<00`000000VIVI09VIV@0709VIV@030000001oOgl0
Ogmo00D0Ogmo00?o000006IVIP1VIVH01P1VIVH00`000000C4a<04a<C00704a<C0030000000c<c<0
<c<c00T0<c<c00?o000001TI6@0I6AT03`0I6ATR000000Cooooo00<00000ooooooooool0O_ooool2
o`0000Gooooo1on/_NH01?l0003o[;gVooooool0000oooooo`002Oooool01000003ooooooooooooo
ool306IVIP030000001oOgl0Ogmo00D0Ogmo00<0000009VIV@2IVIT01P2IVIT00`000000/k>c0;>c
/`090;>c/`030000003<c<`0c<c<01X0c<c<00<000000;>c/`2c/k<02@2c/k<2000000P0VIVI00?o
000007moO`1oOgl01@1oOgl00`000000IVIV06IVIP0606IVIP030000001<C4`0C4a<00L0C4a<00<0
000003<c<`0c<c<0200c<c<00`0000006ATI01TI6@0@01TI6B4000001?ooool00`00003ooooooooo
o`1kooooo`?o00001Oooool01On]_NGo[;gVojbmi_n/_NKo[KgU00Co[;gV00Go0000ojbmi_oooooo
ooooo`00000nooooo`002Oooool01000003oooooooooooooool206IVIP03o`00001oOgl0Ogmo00D0
Ogmo00<0000009VIV@2IVIT01P2IVIT00ol00000/k>c0;>c/`080;>c/`03o`0000000000c<c<01d0
c<c<0`00000:0;>c/`03o`00002IVIT0VIVI00H0VIVI00<0000007moO`1oOgl01@1oOgl00`000000
IVIV06IVIP0506IVIP0300000?l00000C4a<00P0C4a<00<0000003<c<`0c<c<0200c<c<00`000000
6ATI01TI6@0@01TI6B0000001?ooool00`00003oooooooooo`1iooooo`;o00001Oooool00on^_>Co
[KgUojfmi@02ojfmi@04ojbmi_n]_NGo[KgUojfmi@;o[;gV00Ko[KgVo`000?n/_NKo[;gVooooool0
000nooooo`002Oooool01000003oooooooooooooool206IVIP030000001oOgl0Ogmo00D0Ogmo00?o
000009VIV@2IVIT01P2IVIT00`000000/k>c0;>c/`070;>c/`030000003<c<`0c<c<0240c<c<00<0
00000;>c/`2c/k<0202c/k<00`000000VIVI09VIV@0509VIV@030000001oOgl0Ogmo00D0Ogmo00<0
000006IVIP1VIVH01P1VIVH00`000000C4a<04a<C00704a<C003o`00000c<c<0<c<c00P0<c<c00<0
000001TI6@0I6AT0400I6ATP000000Cooooo00<00000ooooooooool0M_ooool3o`0000Gooooo00Co
[kcTojjli?n^_>Co[[cT0_n]_ND2ojjmi@?o[KgU0on]_NH01_l0003o[;gVojbmi_n/_NKoooooo`00
03gooooo0009ooooo`0400000?ooooooooooooooo`80IVIV00<0000007moO`1oOgl01@1oOgl00`00
0000VIVI09VIV@0509VIV@030000002c/k<0/k>c00L0/k>c00<000000<c<c03<c<`08`3<c<`20000
00T0/k>c00<0000009VIV@2IVIT01@2IVIT00`000000Ogmo07moO`0507moO`030000001VIVH0IVIV
00H0IVIV00<0000004a<C01<C4`01P1<C4`00`000000<c<c03<c<`0903<c<`030000000I6AT06ATI
00l06ATI80000004ooooo`0300000?oooooooooo07Cooooo0_l00005ooooo`03ok2lhon__>Co[kcT
00;o[kcT0on^_>@4ojjmi@?o[KgU0_n]_NH00ol0003o[;gVojbmiP02ojbmiP03o`000?oooooooooo
03_ooooo0009ooooo`0600000?ooooooooooooooo`1VIVH000001`1oOgl00`000000VIVI09VIV@05
09VIV@030000002c/k<0/k>c00L0/k>c00<000000<c<c03<c<`04@3<c<`400000140c<c<00<00000
0;>c/`2c/k<01`2c/k<00`000000VIVI09VIV@0509VIV@03o`00001oOgl0Ogmo00D0Ogmo00<00000
06IVIP1VIVH01@1VIVH00`000000C4a<04a<C00704a<C0030000000c<c<0<c<c00P0<c<c00<00000
01TI6@0I6AT0400I6ATO000000Cooooo00<00000ooooooooool0LOooool3o`0000Cooooo0_n`^n83
ok2lh`;o[kcT00?o[kcSojjli?n^_>@00_n^_>@4ojjmi@06ojfmiOn^_NGo[KgVojfmi_l0003o[KgV
0_n/_NH00on]_NKoooooo`00000looooo`002Oooool01P00003oooooooooooooool0IVIV000000H0
Ogmo00<0000009VIV@2IVIT01P2IVIT00ol00000/k>c0;>c/`060;>c/`03o`00003<c<`0c<c<00/0
c<c<00<00000o`0000000000100000040>KViP0400000?l000000000000000h0c<c<0P0000080;>c
/`03o`00002IVIT0VIVI00D0VIVI00<0000007moO`1oOgl01@1oOgl00`000000IVIV06IVIP0506IV
IP030000001<C4`0C4a<00H0C4a<00<0000003<c<`0c<c<02@0c<c<00`0000006ATI01TI6@0?01TI
6Al000001?ooool00`00003oooooooooo`1^ooooo`?o00001Oooool00onb^n7o/;_Rok2khP02ok2k
hP03ok2lhon`_>;o/;cR00?o[kcS0_n^_>@2ojnmi0;o[[gU00Oo[kgTojjmiOn^_NGo[[gUojfmi_l0
003o[KgU00Co[KgV00?oooooo`000?ooool0>_ooool000Wooooo00H00000oooooooooooooooo06IV
IP00000607moO`030000002IVIT0VIVI00H0VIVI00<000000;>c/`2c/k<01@2c/k<00`000000c<c<
0<c<c0090<c<c0<000003`3Vi^H3000000d0c<c<00<000000;>c/`2c/k<01P2c/k<00`000000VIVI
09VIV@0409VIV@030000001oOgl0Ogmo00D0Ogmo00<0000006IVIP1VIVH01P1VIVH00ol00000C4a<
04a<C00504a<C0030000000c<c<0<c<c00X0<c<c00?o000001TI6@0I6AT03P0I6ATO000000Cooooo
00<00000ooooooooool0K?ooool2o`0000Oooooo0onb^n42ok2khP03ok6khOn`_>;o/;cR00;o/;cR
00?o[kcSok2lhon__N@01on__N@3ojjmi@03ojfmiOl0003o[KgU00?o[KgV00?oooooo`000?ooool0
>_ooool000Wooooo00D00000oooooooooooooooo0000000607moO`030000002IVIT0VIVI00H0VIVI
00<000000;>c/`2c/k<01@2c/k<00`000000c<c<0<c<c0080<c<c08000005@3Vi^H4000000X0c<c<
00<000000;>c/`2c/k<01P2c/k<00`000000VIVI09VIV@0409VIV@030000001oOgl0Ogmo00D0Ogmo
00<0000006IVIP1VIVH01@1VIVH00`000000C4a<04a<C00604a<C0030000000c<c<0<c<c00T0<c<c
00<0000001TI6@0I6AT03`0I6ATN000000Cooooo00<00000ooooooooool0JOooool3o`0000Oooooo
0_nc^]l3ok:kh@Co/K_Q0_n`_>801?na_>;o/;cSok2lhon`_><7ojnmi0Co[[gU00?o0000ojjmiOn]
_NH00on]_NH00ooooooo0000ooooo`0iooooo`002Oooool01@00003oooooooooooooool0000000H0
Ogmo00<0000009VIV@2IVIT01@2IVIT00`000000/k>c0;>c/`050;>c/`03o`00003<c<`0c<c<00P0
c<c<00<000000>KViP3Vi^H06@3Vi^H00ol00000c<c<0<c<c0080<c<c0030000002c/k<0/k>c00H0
/k>c00<0000009VIV@2IVIT0102IVIT00ol00000Ogmo07moO`0507moO`030000001VIVH0IVIV00D0
IVIV00<0000004a<C01<C4`01P1<C4`00`000000<c<c03<c<`0903<c<`030000000I6AT06ATI00h0
6ATI7P000004ooooo`0300000?oooooooooo06Oooooo0_l00008ooooo`03okBjg_nc^]oo/k[O00;o
/k[O00?o/[_Qok:kh?nb^n000_na^n400onb_>7o/KcRok6lhP02ok6lhP03ok2lhona_>?o/KcS00Oo
[kgT0_n^_ND01?n__NGo0000ojjmiOn^_ND3ojfmiP;ooooo00?o0000ooooooooool0=oooool000Wo
oooo00@00000oooooooooooooooo1`1oOgl00ol00000VIVI09VIV@0509VIV@030000002c/k<0/k>c
00D0/k>c00<000000<c<c03<c<`01`3<c<`00`000000i^KV0>KViP0J0>KViP8000002@3<c<`00`00
0000/k>c0;>c/`060;>c/`030000002IVIT0VIVI00D0VIVI00<0000007moO`1oOgl0101oOgl00`00
0000IVIV06IVIP0506IVIP030000001<C4`0C4a<00H0C4a<00?o000003<c<`0c<c<02@0c<c<00`00
00006ATI01TI6@0>01TI6Ah000001?ooool00`00003oooooooooo`1Tooooo`?o00002?ooool4okBj
gP;o/k[O00Go];[Nok:kh?nb^n3o/[_Pok>kg`03ok:lh@;o/KcR00?o/[cQok6lhona_><00_na_><0
0on__NCo/;gSok2mh`02ojnmi005ok2mi?n__NGo[kgUojnmiOl000000on^_ND3ojfmiP03ooooool0
003ooooo03Sooooo0009ooooo`0400000?ooooooooooooooo`L0Ogmo00<0000009VIV@2IVIT0102I
VIT00`000000/k>c0;>c/`050;>c/`030000003<c<`0c<c<00L0c<c<00<000000>KViP3Vi^H07@3V
i^H2000000P0c<c<00<000000;>c/`2c/k<01P2c/k<00`000000VIVI09VIV@0409VIV@030000001o
Ogl0Ogmo00D0Ogmo00<0000006IVIP1VIVH01@1VIVH00`000000C4a<04a<C00504a<C0030000000c
<c<0<c<c00T0<c<c00<0000001TI6@0I6AT03P0I6ATN000000Cooooo00<00000ooooooooool0H_oo
ool2o`0000[ooooo0_ne^M`2okBjgP03okFjgOnd^]ko];[N00;o];[N00Go/[_Pok>kgonc^moo/k_O
ok:lh@02ok>lh0?o/[cQ0_na_><2ok6mhP03ok2mhona_N?o/KgS00?o/;gT0_n__ND00ol0003o[[gU
ojjmi@02ojjmi@05ojfmi_n^_^Ko[[kVooooool00000>?ooool000Wooooo00@00000oooooooooooo
oooo1P1oOgl00`000000VIVI09VIV@0509VIV@030000002c/k<0/k>c00D0/k>c00<000000<c<c03<
c<`01P3<c<`00`000000i^KV0>KViP0P0>KViP03o`00003<c<`0c<c<00H0c<c<00<000000;>c/`2c
/k<01@2c/k<00`000000VIVI09VIV@0509VIV@030000001oOgl0Ogmo00@0Ogmo00<0000006IVIP1V
IVH01@1VIVH00`000000C4a<04a<C00604a<C0030000000c<c<0<c<c00T0<c<c00<0000001TI6@0I
6AT03P0I6ATM000000Cooooo00<00000ooooooooool0Goooool3o`0000[ooooo00Go][SJokFig?ne
^Mco]KWLokJif`03okFjg@;o];[N00Go]K[Nok>kgonc^moo/k_OokBkg`04ok>lh003ok:lhOnc_>7o
/KgR00;o/KgR00?o/[gRok6mhona_N<00_na_N<3ok2mi003ojnmi?l0003o[kgT00;o[[gU0_n^_^D3
ojjniP03ooooool0003ooooo03Kooooo0009ooooo`0400000?ooooooooooooooo`H0Ogmo00<00000
09VIV@2IVIT0102IVIT00ol00000/k>c0;>c/`050;>c/`030000003<c<`0c<c<00H0c<c<00?o0000
0>KViP3Vi^H08P3Vi^H00`000000c<c<0<c<c0060<c<c0030000002c/k<0/k>c00D0/k>c00<00000
09VIV@2IVIT0102IVIT00`000000Ogmo07moO`0507moO`030000001VIVH0IVIV00D0IVIV00<00000
04a<C01<C4`01P1<C4`00`000000<c<c03<c<`0803<c<`030000000I6AT06ATI00h06ATI7@000004
ooooo`0300000?oooooooooo05gooooo0_l0000:ooooo`03okNgf?nf^=[o][SJ00;o][SJ00Go]KWL
okJifonf^M_o][WKokFjg@02okJjg0?o]K[N00Co/k_OokBkgond^moo];_O0_nc_>001Ond_>3o/kcQ
ok>lhOnc_>7o/KgR00?o/[gR0ona_N<4ok2mi003o`000?n__^Co[[kU00;o[[kU00?o[kkUojjni_n^
_^H00_n^_^H00ol0003oooooooooo`0eooooo`002Oooool01000003oooooooooooooool607moO`03
0000002IVIT0VIVI00@0VIVI00<000000;>c/`2c/k<0102c/k<00ol00000c<c<0<c<c0070<c<c003
0000003Vi^H0i^KV02<0i^KV00<000000<c<c03<c<`01P3<c<`00`000000/k>c0;>c/`040;>c/`03
0000002IVIT0VIVI00@0VIVI00<0000007moO`1oOgl01@1oOgl00`000000IVIV06IVIP0506IVIP03
o`00001<C4`0C4a<00H0C4a<00<0000003<c<`0c<c<0200c<c<00`0000006ATI01TI6@0>01TI6Ad0
00001?ooool00`00003oooooooooo`1Jooooo`?o00002_ooool01?nh]MKo]kOHokNgf?ng]mP2okJh
fP05okNhfOnf^M_o][WKokJifong^MX01?nf^]`00one^]ko][_MokJkg@03okBkg`Co];cP00?o/kcQ
ok>mhOnc_N400onb_N84ok6mh`;o/;gT00Go/KkTo`000?n__^Co[kkTojjni@03ojnni@;o[[kV00?o
[[kUooooool00000=_ooool000Wooooo00@00000oooooooooooooooo1@1oOgl00`000000VIVI09VI
V@0409VIV@030000002c/k<0/k>c00D0/k>c00<000000<c<c03<c<`01P3<c<`00`000000i^KV0>KV
iP0<0>KViP_o00003P3Vi^H00ol00000c<c<0<c<c0060<c<c0030000002c/k<0/k>c00@0/k>c00<0
000009VIV@2IVIT0102IVIT00`000000Ogmo07moO`0507moO`030000001VIVH0IVIV00@0IVIV00<0
000004a<C01<C4`01`1<C4`00`000000<c<c03<c<`0803<c<`030000000I6AT06ATI00h06ATI7000
0004ooooo`0300000?oooooooooo05Oooooo0ol0000<ooooo`?o^;GF0_ng]mP01Oni]mOo]kSIokNh
fOng^=Wo][WK00?o]kWJ0_nf^]`00ong^]_o][_MokJkg@02okJkg@03okBkgonf_=ko][cN00;o];cP
00?o]KcOok>mhOnc_N400_nc_N400onb_N;o/kgRok>mhP02ok6mh`06ok:nhona_^Co/KkTok6ni?l0
003o[kkT0_n`_^@3ojnni@Co[[kU00?oooooo`000?ooool0=?ooool000Wooooo00@00000oooooooo
oooooooo1@1oOgl00`000000VIVI09VIV@0409VIV@030000002c/k<0/k>c00@0/k>c00<000000<c<
c03<c<`01P3<c<`00`000000i^KV0>KViP0;0>KViP;o00002`3oool3o`0000`0i^KV00<000000<c<
c03<c<`01P3<c<`00`000000/k>c0;>c/`040;>c/`03o`00002IVIT0VIVI00@0VIVI00?o000007mo
O`1oOgl0101oOgl00`000000IVIV06IVIP0506IVIP030000001<C4`0C4a<00H0C4a<00<0000003<c
<`0c<c<0200c<c<00`0000006ATI01TI6@0>01TI6A`000001?ooool00`00003oooooooooo`1Eoooo
o`;o00003_ooool4okReeP05okNgf?ni]mOo^KOGokVgeong^=T00_ni^=P3okNifP04okVifOng^]_o
]k[KokNjf`;o][_M00Go]k_LokJlg_nf_=ko][cNokNlgP03okFlg`;o/kgQ0_nd_N000onc_N;o/kkQ
ok>nh@03ok:nh`;o/KkT00?o0000ok6nhon`_^@00_n`_^@3ojnni@?o[[kU00?oooooo`000?ooool0
=?ooool000Wooooo00@00000oooooooooooooooo1@1oOgl00`000000VIVI09VIV@0409VIV@030000
002c/k<0/k>c00@0/k>c00<000000<c<c03<c<`01@3<c<`00ol00000i^KV0>KViP0;0>KViP03o`00
003oool0oooo00h0oooo00?o00000>KViP3Vi^H02@3Vi^H00`000000c<c<0<c<c0060<c<c0030000
002c/k<0/k>c00@0/k>c00<0000009VIV@2IVIT0102IVIT00`000000Ogmo07moO`0407moO`030000
001VIVH0IVIV00D0IVIV00<0000004a<C01<C4`01P1<C4`00`000000<c<c03<c<`0803<c<`03o`00
000I6AT06ATI00l06ATI00?o000000000000000060000004ooooo`0300000?oooooooooo05;ooooo
0ol0000?ooooo`;o^KCD0_nh]MH01Onj]MGo^KOGokVgeoni]mOo^[OF00Co^KSH00Ko]kWJokVifOni
^MWo^KWIokNjfoni^]/4okNkg006okJlg_ng_=ko]kcNokNlg_ne_=oo][gO0ond_N000one_N3o/kkQ
ok>nh@02ok>nh@06ok:nhonc_^;o/KkSok6nhol0003o/[kS1?n`_^@2ojnni@Co[[kU00?oooooo`00
0?ooool0<oooool000Wooooo00@00000oooooooooooooooo1@1oOgl00`000000VIVI09VIV@0409VI
V@030000002c/k<0/k>c00@0/k>c00<000000<c<c03<c<`01@3<c<`00`000000i^KV0>KViP0:0>KV
iP03o`00003oool0oooo0100oooo00?o00000>KViP3Vi^H02@3Vi^H00`000000c<c<0<c<c0060<c<
c0030000002c/k<0/k>c00<0/k>c00<0000009VIV@2IVIT0102IVIT00`000000Ogmo07moO`0507mo
O`030000001VIVH0IVIV00@0IVIV00<0000004a<C01<C4`01`1<C4`00`000000<c<c03<c<`0703<c
<`030000000I6AT06ATI00l06ATI6`000004ooooo`0300000?oooooooooo053ooooo0_l0000@oooo
o`05okZbd_ni]=Co^KCDokVde?nj]=<00onj]MD01?ni]mOo^[OFokZge_nj]mH2okVhf005okZheoni
^MWo^KWIokVifOnj^MT00oni^]/2okNkg005okRkg?ng_=ko]kcNokNlg_nh_=d00onf_Ml01?nd_N3o
]KgPokFmh?ne_N02ok>nh@06okBnhOnc_^;o/kkRok>nh_na_^?o00000_nb_^<2ok2ni004ok6oi?n_
_^Go[kkUojnni@;o[[kU0_n__^D00ol0003oooooooooo`0booooo`002Oooool01000003ooooooooo
ooooool407moO`030000002IVIT0VIVI00@0VIVI00<000000;>c/`2c/k<0102c/k<00`000000c<c<
0<c<c0050<c<c0030000003Vi^H0i^KV00X0i^KV00?o00000?ooo`3oool04P3oool00ol00000i^KV
0>KViP080>KViP030000003<c<`0c<c<00H0c<c<00<000000;>c/`2c/k<0102c/k<00`000000VIVI
09VIV@0409VIV@030000001oOgl0Ogmo00@0Ogmo00<0000006IVIP1VIVH01@1VIVH00`000000C4a<
04a<C00604a<C0030000000c<c<0<c<c00P0<c<c00<0000001TI6@0I6AT03P0I6ATK000000Cooooo
00<00000ooooooooool0COooool3o`00013ooooo1?nj/]801Oni]=Co^[CCokZddonj]=?o^[GE00;o
^kGD0onj]mH4okZhe`05okVifOnj^MWo^[WIokZifOni^]/00_nj^mX3okRkg005okNlg_nh_=go^;cM
okRlgOnf_Ml00_ng_Mh3okFmh0Co];kQ0onc_^800ol0003o/[kSok:oh`04ok6oi003ojnniOn`_nGo
[kkU00;o[kkU00?o[koUooooool00000<oooool000Wooooo00@00000oooooooooooooooo101oOgl0
0`000000VIVI09VIV@0409VIV@030000002c/k<0/k>c00@0/k>c00<000000<c<c03<c<`01@3<c<`0
0`000000i^KV0>KViP090>KViP03o`00003oool0oooo01@0oooo00?o00000>KViP3Vi^H0203Vi^H0
0ol0000000000<c<c0060<c<c0030000002c/k<0/k>c00@0/k>c00<0000009VIV@2IVIT0102IVIT0
0`000000Ogmo07moO`0407moO`030000001VIVH0IVIV00@0IVIV00<0000004a<C01<C4`01P1<C4`0
0ol00000<c<c03<c<`0803<c<`030000000I6AT06ATI00h06ATI6`000004ooooo`0300000?oooooo
oooo04_ooooo0_l0000Booooo`;o^[7@0_nj/]801Onk/]7o^[CCokZddonj]=?o_;CB00Co^kGD00?o
^[OFok^geOnk]mD00onj^=L3okZif@03ok^jf?nj^m[o^[_J00;o^[_J00?o^;_LokVlfoni_=/00_nh
_=d00oni_Mgo]kgNokNmgP02okNmgP03okFmh?nf_^3o][kP00;o];kQ00Go]KkQok>nh_nc_^;o/kkR
o`000003ok:oh`?o/KoT0on`_nD01_n__^Go[koUojnoiOn__nGoooooo`0003;ooooo0009ooooo`04
00000?ooooooooooooooo`@0Ogmo00<0000009VIV@2IVIT0102IVIT00`000000/k>c0;>c/`040;>c
/`030000003<c<`0c<c<00D0c<c<00<000000>KViP3Vi^H02@3Vi^H00ol00000oooo0?ooo`0E0?oo
o`03o`00003Vi^H0i^KV00P0i^KV00<000000<c<c03<c<`01@3<c<`00`000000/k>c0;>c/`040;>c
/`030000002IVIT0VIVI00@0VIVI00<0000007moO`1oOgl0101oOgl00`000000IVIV06IVIP0406IV
IP030000001<C4`0C4a<00H0C4a<00<0000003<c<`0c<c<0200c<c<00`0000006ATI01TI6@0>01TI
6A/000001?ooool00`00003oooooooooo`18ooooo`?o00004_ooool01Onk[lko^[7@okZad?nj/M3o
^[;B00?o^k;A00Co^[CCokbdd_nl]=;o_;CB0_nk]M@00onl]]?o^kOEok^ge@02ok^ge@04okZheonk
^=Oo^kSGokZif@?o^k[H0_nj^mX01Onk^mWo^KcKokVlfoni_=_o^[cK00?o^KgM0_ng_Mh2okRngP03
okJnh?ng_^3o]kkP00?o]KkQ00Ko/kkRokBoh_l0003o];oRok:ohonc_n<4ok6oi0Co/;oU00Co[koU
ojnoi_oooooo0000<_ooool000Wooooo00@00000oooooooooooooooo101oOgl00`000000VIVI09VI
V@0409VIV@030000002c/k<0/k>c00@0/k>c00<000000<c<c03<c<`01@3<c<`00`000000i^KV0>KV
iP080>KViP03o`00003oool0oooo01L0oooo00?o00000>KViP3Vi^H0203Vi^H00`000000c<c<0<c<
c0050<c<c0030000002c/k<0/k>c00@0/k>c00<0000009VIV@2IVIT0102IVIT00`000000Ogmo07mo
O`0407moO`030000001VIVH0IVIV00@0IVIV00<0000004a<C01<C4`01P1<C4`00`000000<c<c03<c
<`0803<c<`030000000I6AT06ATI00h06ATI6P000004ooooo`0300000?oooooooooo04Gooooo0ol0
000Dooooo`?o^jo>00?o^[7@okbaconl/Ll00onk/]401Onm/]3o_;CBokbdd_nl]=;o^kGD00?o_;KC
0_nk]mD01Onm]mCo^kSGok^heonk^=Oo_KWF00?o^k[H1?nk^mT01_ni_=_o^[cKokZlfonj_=_o^KgM
okZmg@?o^;kN00?o^KkNokNnh?ng_^000_ng_^001_ne_^7o][oQokJohOnd_n;o0000okBohP?o/koS
1?na_n@3ok2oi@?o[koV00?oooooo`000?ooool0<?ooool000Wooooo00@00000oooooooooooooooo
101oOgl00`000000VIVI09VIV@0409VIV@030000002c/k<0/k>c00@0/k>c00<000000<c<c03<c<`0
1@3<c<`00`000000i^KV0>KViP070>KViP03o`00003oool0oooo01T0oooo00?o00000>KViP3Vi^H0
1`3Vi^H00`000000c<c<0<c<c0050<c<c0030000002c/k<0/k>c00@0/k>c00<0000009VIV@2IVIT0
102IVIT00`000000Ogmo07moO`0407moO`030000001VIVH0IVIV00@0IVIV00<0000004a<C01<C4`0
1P1<C4`00`000000<c<c03<c<`0803<c<`030000000I6AT06ATI00h06ATI6P000004ooooo`030000
0?oooooooooo04?ooooo0_l0000Eooooo`;o^jg<0onk[lh4okbac`05ok^bdOnm/]3o_K;@okfbd?nl
]=800_nm]=43okbfd`Co_KOD00Go^kSGokfie_nm^MKo_KWFok^jf002okfje`;o^k_I00Go_;cIokZl
fonj_=_o^[cKok^mf`03okZmg@04okRng_ni_]ko^KkNokVngP;o]kkP00Ko^;oPokJohOnf_n7o][oQ
okBoh_l00002okBohPCo/koS00?o/KoTok;0i?n`_nD00on`_nD2ojnoiP;ooooo00?o0000oooooooo
ool0;_ooool000Wooooo00@00000oooooooooooooooo101oOgl00`000000VIVI09VIV@0409VIV@03
0000002c/k<0/k>c00@0/k>c00<000000<c<c03<c<`01@3<c<`00`000000i^KV0>KViP070>KViP03
o`00003oool0oooo01T0oooo00?o00000>KViP3Vi^H01`3Vi^H00`000000c<c<0<c<c0050<c<c003
0000002c/k<0/k>c00@0/k>c00<0000009VIV@2IVIT0102IVIT00`000000Ogmo07moO`0407moO`03
0000001VIVH0IVIV00@0IVIV00<0000004a<C01<C4`01P1<C4`00`000000<c<c03<c<`0803<c<`03
0000000I6AT06ATI00h06ATI6P000004ooooo`0300000?oooooooooo043ooooo0ol0000Eooooo`03
ok^/b_nk[Lco^jg<00;o^jg<00?o^jo>okb_cOnl[ld00_nl/Ll01Onm/Lgo_K;@okfbd?nm/]3o_[?>
00Co_KCA00?o_;KCokjfd_nn]]800_nm]m@01Onn^=?o_KWFokfie_nm^MKo_[[E00?o_K[G00Go_[_G
okblfOnl_=Wo_;cIokZlf`03ok^mf`03okZmgOnk_]co^kkL00?o^KkN1?nh_n03okJoh@03o`000?nd
_n;o]L3R00?o/koS00Co/l3Sok;0i?nb`>Co//3T0_n`_nD01_na_nGo[koVojnoi_n__nKoooooo`00
033ooooo0009ooooo`0400000?ooooooooooooooo`@0Ogmo00<0000009VIV@2IVIT0102IVIT00`00
0000/k>c0;>c/`040;>c/`030000003<c<`0c<c<00D0c<c<00<000000>KViP3Vi^H01`3Vi^H00ol0
0000oooo0?ooo`0J0?ooo`03o`00003Vi^H0i^KV00L0i^KV00<000000<c<c03<c<`01@3<c<`00`00
0000/k>c0;>c/`040;>c/`030000002IVIT0VIVI00<0VIVI00<0000007moO`1oOgl0101oOgl00`00
0000IVIV06IVIP0506IVIP030000001<C4`0C4a<00D0C4a<00<0000003<c<`0c<c<0200c<c<00`00
00006ATI01TI6@0>01TI6AX000001?ooool00`00003oooooooooo`0nooooo`;o00005oooool3ok^/
bP;o^jg<00Go_:g;okb_cOnl[lgo_:o=okbac`03okfac@04okfbd?nn/lko_[?>okjccP;o_KCA00Go
_kC@okjfd_nn]];o_[KBokngd@03okjhd`05okfie_nn^]Go_[[EokjjeOnm^]L00onn^mL00onl_=Wo
_KgIok^mf`02ok^mf`03okfnfonk_]co^kkL00;o^kkL00?o^KkNokVog_ni_mh00_nh_n02okS0h003
okJohOng`>7o000000?o]L3R00Co/koSok?0honc`>?o/l3S0_nb`>@4ok6oi@?o[koV00?oooooo`00
0?ooool0;_ooool000Wooooo00@00000oooooooooooooooo101oOgl00`000000VIVI09VIV@0409VI
V@030000002c/k<0/k>c00@0/k>c00<000000<c<c03<c<`0103<c<`00`000000i^KV0>KViP070>KV
iP03o`00003oool0oooo01`0oooo00?o00000>KViP3Vi^H01P3Vi^H00`000000c<c<0<c<c0050<c<
c003o`00002c/k<0/k>c00@0/k>c00?o000009VIV@2IVIT0102IVIT00`000000Ogmo07moO`0407mo
O`030000001VIVH0IVIV00@0IVIV00<0000004a<C01<C4`01P1<C4`00`000000<c<c03<c<`0803<c
<`030000000I6AT06ATI00h06ATI6@000004ooooo`0300000?oooooooooo03_ooooo0ol0000Hoooo
o`Co^jc:00Co^jg<okb]bonl[L_o_:g;0_nl[ld01?nn[l_o_K7=okfacOnm/Ld4okjccP05okfddOno
]=3o_kC@okndd?nn]]800ono]m400onn^=?o`;SCokjje@02okjje@05ol2jeOnn^mOo_[_Gokjkeono
_=L00onm_MT01?nk_M_o_KkKokfnfonm_]/2ok^ng0;o_;oL00?o^KoNok[0g_nh`>000_nh`>001_ni
`N3o]l3QokO0hOl0003o]l3QokG0hP;o]L7R0_nc`><01?nd`NCo//3Tok;0i?nb`>@2ok6oi@;o/L3U
00Go[koVok30i_n``>Koooooo`00000^ooooo`002Oooool01000003oooooooooooooool407moO`03
0000002IVIT0VIVI00@0VIVI00<000000;>c/`2c/k<0102c/k<00`000000c<c<0<c<c0040<c<c003
0000003Vi^H0i^KV00L0i^KV00?o00000?ooo`3oool0703oool00ol00000i^KV0>KViP070>KViP03
o`00003<c<`0c<c<00@0c<c<00<000000;>c/`2c/k<0102c/k<00`000000VIVI09VIV@0409VIV@03
0000001oOgl0Ogmo00@0Ogmo00<0000006IVIP1VIVH0101VIVH00`000000C4a<04a<C00604a<C003
0000000c<c<0<c<c00P0<c<c00<0000001TI6@0I6AT03P0I6ATI000000Cooooo00<00000oooooooo
ool0>Oooool2o`0001[ooooo0_nkZ/P3ok^/bPCo_:g;00Go_:o=okj_bonn[l_o_Zo;okfac@02okna
c0?o_[?>0ono]=001Oo1]Loo_kOAokngdOno]m7o`KOA00?o`;SC00Go_[[Eol2jeOo0^]Go`;[Eokjk
e`03oknle`03okfmfOno_MWo_kgI00?o_KkK0onl_m`01Onl`=co^/3Nok[0g_nj`=ko^<3P00?o^L7P
00?o]l3Qo`000?ng`N400one`N84okC1i003ok;0i?nb`NCo//7T00?o/L3U1?n``>H00ol0003ooooo
ooooo`0/ooooo`002Oooool01000003oooooooooooooool407moO`030000002IVIT0VIVI00@0VIVI
00<000000;>c/`2c/k<0102c/k<00`000000c<c<0<c<c0040<c<c0030000003Vi^H0i^KV00L0i^KV
00?o00000?ooo`3oool0703oool00ol00000i^KV0>KViP070>KViP030000003<c<`0c<c<00@0c<c<
00<000000;>c/`2c/k<0102c/k<00`000000VIVI09VIV@0409VIV@030000001oOgl0Ogmo00@0Ogmo
00<0000006IVIP1VIVH0101VIVH00`000000C4a<04a<C00604a<C0030000000c<c<0<c<c00P0<c<c
00<0000001TI6@0I6AT03P0I6ATI000000Cooooo00<00000ooooooooool0=_ooool3o`0001[ooooo
00?o^jS6ok^Zb?nkZ/P00_nkZ/P00onk[<[o_:c8okb/b002okb]b`05okj]bOnn[l_o_Zo;okj_bono
[lX01?no/L`01?nn/lko`;?>ol2cc_no]=03ol6ec`04okngdOo1]m7o`KOAol6gd@;o`;SC00Go`KWB
ol2jeOo0^]Go`;[Eol6ke003oknle`Co_kgI00Co_KkKokjof_nn_m[o_;oL0onl`=`00onj`=ko^l7N
ok_1gP03okW1h005okO1hOl0003o]l7QokO1hOne`N800_nf`N<3okC1i0?o//7T00Co//7Uok70iOna
`>Go/L3U0on``>H00ooooooo0000ooooo`0/ooooo`002Oooool01000003oooooooooooooool407mo
O`030000002IVIT0VIVI00@0VIVI00<000000;>c/`2c/k<0102c/k<00`000000c<c<0<c<c0040<c<
c0030000003Vi^H0i^KV00L0i^KV00?o00000?ooo`3oool07@3oool00ol00000i^KV0>KViP060>KV
iP030000003<c<`0c<c<00D0c<c<00<000000;>c/`2c/k<0102c/k<00`000000VIVI09VIV@0409VI
V@030000001oOgl0Ogmo00<0Ogmo00<0000006IVIP1VIVH01@1VIVH00`000000C4a<04a<C00504a<
C0030000000c<c<0<c<c00P0<c<c00<0000001TI6@0I6AT03P0I6ATI000000Cooooo00<00000oooo
ooooool0<oooool3o`0001cooooo0onkZ<H2ok^Zb005okbYaonl[<So_:c8okb/b?nl[L/00onn[LT0
1?nn[l_o_jo:okn_b_no[lX2oknac005ol6bboo0/lko`;?>ol2cc_o2]<d00oo1]Ll01Oo2]/ko`KOA
ol6gdOo1]m7o`;SC00?o`KWB00Go`;[Eol6ke?o1^mCo`K_Doknle`02ol6meP;o_kgI0_o0_]T00onn
_m[o_l3Koko0f`03okc0g0Co^l7N0oni`N001Ol0003o]l7QokS2h_nh`^;o]/7S00;o]/;S0ond`N@0
1_nb`NCo//7Uok;1iOnb`NGo/L3Uok71i@Co/<3V00?o0000ooooooooool0:oooool000Wooooo00@0
0000oooooooooooooooo101oOgl00`000000VIVI09VIV@0409VIV@030000002c/k<0/k>c00@0/k>c
00<000000<c<c03<c<`0103<c<`00`000000i^KV0>KViP070>KViP03o`00003oool0oooo01d0oooo
00?o00000>KViP3Vi^H01`3Vi^H00`000000c<c<0<c<c0040<c<c0030000002c/k<0/k>c00@0/k>c
00<0000009VIV@2IVIT0102IVIT00`000000Ogmo07moO`0307moO`030000001VIVH0IVIV00D0IVIV
00<0000004a<C01<C4`01@1<C4`00`000000<c<c03<c<`0803<c<`030000000I6AT06ATI00h06ATI
6@000004ooooo`0300000?oooooooooo037ooooo0_l0000Nooooo`Co^jS600Co^j[8okbYaonlZLOo
_:W70_nl[<P01?nn[<Oo_Zg9okj]bOnn[LT4okn_bP05oknac?o1//_o`K;;ol6bboo0/lh00oo2]<d0
1_o1]Loo`[K>ol:fc_o2]/ko`KOAol>hd0?o`KWB00Go`k[Bol6ke?o1^mCo`K_Dol>le003ol6meP?o
`;kI00?o`KoIoko0fono`=/00_no`=/00onl`=co_L7Lokg1g002ok_1gP;o_<;N00Co^L7Pok[2h?nh
`^;o00000_nh`^84okK2h`?o]<7T0onb`ND3ok71i@Co/<3V00?o0000ooooooooool0:_ooool000Wo
oooo00@00000oooooooooooooooo101oOgl00`000000VIVI09VIV@0409VIV@030000002c/k<0/k>c
00@0/k>c00<000000<c<c03<c<`0103<c<`00`000000i^KV0>KViP070>KViP03o`00003oool0oooo
01d0oooo00?o00000>KViP3Vi^H01`3Vi^H00`000000c<c<0<c<c0040<c<c0030000002c/k<0/k>c
00@0/k>c00<0000009VIV@2IVIT0102IVIT00`000000Ogmo07moO`0307moO`030000001VIVH0IVIV
00D0IVIV00<0000004a<C01<C4`01@1<C4`00`000000<c<c03<c<`0803<c<`030000000I6AT06ATI
00h06ATI6@000004ooooo`0300000?oooooooooo02kooooo0ol0000Oooooo`;o^ZK50onkZ<H4okbY
a`05okb/b?nn[<Oo_Zc7okj/aonn[LT00_o0[/P3okn_bP04ol6`bOo1//_o`K;;ol6bb`?o`[C=00Go
`kG<ol:fc_o2]/ko`[K>olBgcP03ol>hd005ol6id_o3^];o`k[Bol>jd_o1^m@00oo3_=@01?o1_MKo
`[kFol:ne_o0_]T3ol6of@;o_l3K0_o0`M/00onm`Mco_/;Mokc2gP02okc2gP05okc2gonj`^3o^/;P
ok[2h?l000000onh`^84okK2h`03okC1i?nd`^Co//7U00?o//7U00?o/L7Uok71i_na`NH00on``>H0
0ooooooo0000ooooo`0Zooooo`002Oooool01000003oooooooooooooool407moO`030000002IVIT0
VIVI00@0VIVI00<000000;>c/`2c/k<0102c/k<00`000000c<c<0<c<c0040<c<c0030000003Vi^H0
i^KV00L0i^KV00?o00000?ooo`3oool07@3oool00ol00000i^KV0>KViP070>KViP030000003<c<`0
c<c<00@0c<c<00<000000;>c/`2c/k<0102c/k<00`000000VIVI09VIV@0409VIV@030000001oOgl0
Ogmo00<0Ogmo00<0000006IVIP1VIVH01@1VIVH00`000000C4a<04a<C00504a<C0030000000c<c<0
<c<c00P0<c<c00<0000001TI6@0I6AT03P0I6ATI000000Cooooo00<00000ooooooooool0;?ooool2
o`00023ooooo00?o^JC3okZVaOnjY/D00_njY/D00onkZ<Ko_:S5okbXa@03okbYa`?o_Zc700?o`:c6
ol2^b?o0[/P00_o0[/P01Ono[l[o`K39ol6`bOo1/<Wo`K;;00;o`[;;00Go`[C=ol>ec?o3]Lco`kG<
ol:fcP03olBgcP;o`kS@00Coa;W@ol>jd_o3^];o`k[B0oo3_=@01Oo4_MCo`[kFol:ne_o2_]Ko`koF
00?o`KoI0oo0`M/01Oo1`]_o_/;Mokk2gOnn`]go_<;N00?o_<;O00Ko^/;Pok[3hOl0003o^/?QokS2
h_nh`n83okK2h`04okK3hond`^Co]<;TokC2i0;o//7U0_nb`^D2ok71iPCo/<3V00?o0000oooooooo
ool0:Oooool000Wooooo00@00000oooooooooooooooo1@1oOgl00`000000VIVI09VIV@0409VIV@03
0000002c/k<0/k>c00<0/k>c00<000000<c<c03<c<`01@3<c<`00`000000i^KV0>KViP060>KViP03
o`00003oool0oooo01h0oooo00?o00000>KViP3Vi^H01P3Vi^H00`000000c<c<0<c<c0040<c<c003
0000002c/k<0/k>c00@0/k>c00<0000009VIV@2IVIT0102IVIT00`000000Ogmo07moO`0407moO`03
0000001VIVH0IVIV00@0IVIV00<0000004a<C01<C4`01P1<C4`00`000000<c<c03<c<`0803<c<`03
0000000I6AT06ATI00h06ATI60000004ooooo`0300000?oooooooooo02Wooooo0ol0000Qooooo`?o
^JC30_njY/D00onkY/?o_:S5okbXa@02okbXa@04okbYaonnZ/Go_Z[5okj/a`?o`:c60_o0[/P01Oo1
[/Oo`K39ol6`bOo1/<Wo`k7800?o`[;;1?o3]L`4olBgcP05ol>hd?o4^M3oa;W@olBid?o3^]800_o4
_=801Oo3_=Coa;gDolBme?o4_MCo`[kF00?o`koF00Co`KoIol;1fOo2`MWo`<7K0oo1`]/01_nn`]go
_l?Moko3gOno`mgo_<;Ookg3g`;o^/?Q00?o0000ok_4hOnh`n800_nh`n801?nf`^?o]/?SokK3honf
`n<3okC2i0?o//;U0ona`NH2ok30iP;o/<7V00?o0000ooooooooool0:?ooool000Wooooo00@00000
oooooooooooooooo1@1oOgl00`000000VIVI09VIV@0409VIV@030000002c/k<0/k>c00<0/k>c00<0
00000<c<c03<c<`01@3<c<`00`000000i^KV0>KViP060>KViP03o`00003oool0oooo01h0oooo00?o
00000>KViP3Vi^H01P3Vi^H00`000000c<c<0<c<c0040<c<c0030000002c/k<0/k>c00@0/k>c00<0
000009VIV@2IVIT0102IVIT00`000000Ogmo07moO`0407moO`030000001VIVH0IVIV00@0IVIV00<0
000004a<C01<C4`01P1<C4`00`000000<c<c03<c<`0803<c<`030000000I6AT06ATI00h06ATI6000
0004ooooo`0300000?oooooooooo02Oooooo0_l0000Sooooo`Co^JC300Co^ZK5ok^V`onkY/?o^jK3
0_nlZ<D01?nmZ<Co_Z[5okjZaOnnZ/D4ol2/aP05ol2^b?o1[/Oo`Jk7ol6^aoo1/<T00oo3/LP00oo2
//_oa;?:olBcbP03ol>ec004olFfc?o4]lkoa;O>olJhc@?oa;W@00Goa[_@olBld_o4_=;oa;cBolJm
dP03olBme0?o`koF00Goa<7Gol;1fOo2`MWo`/7Iol?2f@03ol72f`?o_l?M00Ko_lCMokg3gonm`moo
_L?Ook[3hOl00002ok_4h@03okS3h_ni`n;o^L?R00;o]/?S00Co]/?TokC2i?nd`^Co]<;T1?nb`^D3
ok71iP;o/<7V00?o[l7Wooooool00000:Oooool000Wooooo00@00000oooooooooooooooo1@1oOgl0
0`000000VIVI09VIV@0409VIV@030000002c/k<0/k>c00<0/k>c00<000000<c<c03<c<`01@3<c<`0
0`000000i^KV0>KViP060>KViP03o`00003oool0oooo01h0oooo00?o00000>KViP3Vi^H01P3Vi^H0
0`000000c<c<0<c<c0040<c<c0030000002c/k<0/k>c00@0/k>c00<0000009VIV@2IVIT0102IVIT0
0`000000Ogmo07moO`0407moO`030000001VIVH0IVIV00@0IVIV00<0000004a<C01<C4`01P1<C4`0
0`000000<c<c03<c<`0803<c<`03o`00000I6AT06ATI00h06ATI60000004ooooo`0300000?oooooo
oooo02Cooooo0ol0000Tooooo`;o^:;20oniY<<4ok^V``05okbXaOnmZ<Co_JS4okfXa?nnZ/D00_no
Z/@3ol2/aP04ol6]aOo1[/Oo`Jk7ol6^a`Co`k781?o4/lX01?o3]LcoaKK<olFfc?o4]lh3olJhc@05
olBid?o6^m3oa[_@olJkd?o4_=800oo6_M801?o4_MCoaKoDolFoe?o3_mH3olC1e`05ol;1fOo3`]Wo
`l;Iol?2fOo1`]/00_o1`m/01Ono`mgo_lCMoko4gOnoa=go_L?O00;o_LCO00Ko0000ok_4hOnka>7o
^lCQokW3h_nia><4okK3i003okC2i?nd`nGo]<?U00;o//;U0_nb`^H2ok71iPCo[l7W00?o0000oooo
ooooool09oooool000Wooooo00@00000oooooooooooooooo1P1oOgl00`000000VIVI09VIV@0309VI
V@030000002c/k<0/k>c00@0/k>c00<000000<c<c03<c<`01@3<c<`00`000000i^KV0>KViP060>KV
iP03o`00003oool0oooo01`0oooo00?o00000>KViP3Vi^H01`3Vi^H00`000000c<c<0<c<c0040<c<
c0030000002c/k<0/k>c00@0/k>c00<0000009VIV@2IVIT0102IVIT00`000000Ogmo07moO`0407mo
O`030000001VIVH0IVIV00@0IVIV00<0000004a<C01<C4`01P1<C4`00`000000<c<c03<c<`0803<c
<`030000000I6AT06ATI00h06ATI60000004ooooo`0300000?oooooooooo02;ooooo0_l0000Uoooo
o`03okNP`OnhX/;o^:;200;o^:;200?o^JC3ok^T`_nkY<800onkY/<4okfXa0Co_j[400Go`:c6ol6]
aOo1[LGo`Jg5ol6^a`02ol>_aP;o`k780_o5//P2olBcbP05olJdbOo5]/coaKK<olFfc?o7]l/00oo6
^<d01?o7^/goa[_@olJkd?o6^m03olJmdP05olNnd_o5_mCoaKoDolFoe?o6`M@00oo4`ML00oo5`]Oo
`l;Iol?2f@02olC4fP03ol73foo2a=co`/CL00;o_lCM00Go`<GNokg4gonma=oo_LCOo`000002ok_4
h@04ok_5h_nia>?o^LCSokW4h`;o]/?T0_nfa>@3okC3i@?o//;V0ona`NH4ojo1i`03o`000?oooooo
oooo02Kooooo0009ooooo`0400000?ooooooooooooooo`H0Ogmo00<0000009VIV@2IVIT00`2IVIT0
0`000000/k>c0;>c/`040;>c/`030000003<c<`0c<c<00D0c<c<00<000000>KViP3Vi^H01`3Vi^H0
0ol00000oooo0?ooo`0K0?ooo`03o`00003Vi^H0i^KV00L0i^KV00<000000<c<c03<c<`0103<c<`0
0`000000/k>c0;>c/`040;>c/`030000002IVIT0VIVI00@0VIVI00<0000007moO`1oOgl0101oOgl0
0`000000IVIV06IVIP0406IVIP030000001<C4`0C4a<00H0C4a<00<0000003<c<`0c<c<0200c<c<0
0`0000006ATI01TI6@0>01TI6AP000001?ooool00`00003oooooooooo`0Oooooo`?o00009_ooool3
okNP`@;o^:;200?o^Z;1ok^T`_nkY<800_nkY<800onkY/?o_JK2okfV`P02okfXa0;o_jS30_noZ/@0
0oo1Zl?o`Jg5ol6]a@02ol6]a@?o`jo600Go`k78olFbb?o5//SoaK;8olBcbP03olJdb@05olFfc?o7
]l_oakO;olNgboo6^<d00oo7^/d01?o6^m3oakc@olNld?o6_M83olNndP05olFoe?o6`MCoa/7DolK1
e?o4`ML00_o5`]L3olC4fP05olG5f_o2a=co`/CLol;4g?o3a]`00oo0aMh01?nma=oo_LGPo`000?nk
a>43ok_5hP06okW4honiaN?o^LGSokW5honfa>Co]/CU0ond`nD4ok;2iP03ok71i_na`^Oo/L;W00?o
[l7W00?oooooo`000?ooool09_ooool000Wooooo00@00000oooooooooooooooo1P1oOgl00`000000
VIVI09VIV@0309VIV@030000002c/k<0/k>c00@0/k>c00<000000<c<c03<c<`01@3<c<`00ol00000
i^KV0>KViP070>KViP03o`00003oool0oooo01/0oooo00?o00000>KViP3Vi^H01`3Vi^H00`000000
c<c<0<c<c0040<c<c0030000002c/k<0/k>c00@0/k>c00<0000009VIV@2IVIT0102IVIT00`000000
Ogmo07moO`0407moO`030000001VIVH0IVIV00@0IVIV00<0000004a<C01<C4`01P1<C4`00`000000
<c<c03<c<`0803<c<`030000000I6AT06ATI00h06ATI60000004ooooo`0300000?oooooooooo01co
oooo0ol0000Wooooo`03okJN`?ngX<7o]j3100;o]j3100Co^:;2okZR`OnjX/7o^Z;10_nkY<801Onl
Y<7o_JK2okfV`_nmY/;o_JS400?o_jS300Co_j[4ol6[`oo1Zl?o`J_30_o1[LD2ol>]a0;o`jo600Go
aK36olFbb?o5//SoaK;8olJca`03olJdb@?oakO;00Gob;W;olNjcOo7^/goak[=olVkc@03olNld0?o
akkB0_o8`=82olK1e0;ob<;E00CoaL;GolK4f?o6a=Soa<CJ0oo5aMX01Oo2a=co`lKLol?6g?o3a]co
`<GN00;o`<KO00Go_LGPo`000?nna^7o_/KQok_5hP02ok_6hP;o^LGS00Co^<GTokK4iOnfa>Go]/CU
0ond`nD2ok;2iP;o//?V00?o/L;Wok32ion_`NL00on_`NL00ol0003oooooooooo`0Uooooo`002Ooo
ool01000003oooooooooooooool707moO`030000002IVIT0VIVI00<0VIVI00<000000;>c/`2c/k<0
102c/k<00`000000c<c<0<c<c0040<c<c0030000003Vi^H0i^KV00P0i^KV00?o00000?ooo`3oool0
6P3oool00ol00000i^KV0>KViP070>KViP030000003<c<`0c<c<00@0c<c<00<000000;>c/`2c/k<0
102c/k<00`000000VIVI09VIV@0409VIV@030000001oOgl0Ogmo00@0Ogmo00<0000006IVIP1VIVH0
101VIVH00`000000C4a<04a<C00604a<C0030000000c<c<0<c<c00P0<c<c00<0000001TI6@0I6AT0
3P0I6ATH000000Cooooo00<00000ooooooooool06_ooool2o`0002Sooooo00Co]9bookJN`?nfW/3o
]Yk00ongX<44okZR`@04ok^T`_nlY<7o_:C1okbT`@;o_JK200Co_ZK1oknX`onoZ<?o_jS31?o1Zl<0
1Oo1[LGo`jg4ol>]a?o3[LCo`jo600?oaK3600GoaK;8olJcaoo6/lOoa[?7olJdb@02olNfb@05olNg
boo8^L_ob;W;olRiboo7^/d00oo9^ld01?o7_=3obKk@olVnd?o7_]83olS0dP?ob<;E00GobLCFolK4
f?o6a=Soa/CHolO5f003olG5fP?o`lKL00So`lOMol36goo0a]oo`<KOokk6hOl0003o_/KQokk7h@?o
^lKR1?nhaN@3okK4i@03okC3iOnda>Ko]<CV00?o//?V0on``^L3ojo1i`03ooooool0003ooooo02Go
oooo0009ooooo`0500000?ooooooooooooooool000001P1oOgl00`000000VIVI09VIV@0309VIV@03
0000002c/k<0/k>c00@0/k>c00<000000<c<c03<c<`01@3<c<`00`000000i^KV0>KViP070>KViP03
o`00003oool0oooo01T0oooo00?o00000>KViP3Vi^H01`3Vi^H00`000000c<c<0<c<c0050<c<c003
0000002c/k<0/k>c00@0/k>c00<0000009VIV@2IVIT0102IVIT00`000000Ogmo07moO`0407moO`03
0000001VIVH0IVIV00@0IVIV00<0000004a<C01<C4`01P1<C4`00`000000<c<c03<c<`0803<c<`03
0000000I6AT06ATI00h06ATI60000004ooooo`0300000?oooooooooo01Oooooo0ol0000Yooooo`;o
]9bo1?nfW/000ongX<7o^:30okRP`003okZR`@Co_:C100Go_JK2okjV`OnnY/7o_ZK1oknX``02ol6Y
`P?o`J_300Co`jc3ol>]a?o3[LCo`jg40oo5/<H01Oo7//Goa[?7olJcaoo6/lOob;C700?oakK900Co
bKS9olRiboo8^L_ob;W;0oo9^ld01?o;_LkobKk@olVnd?o9_]02ol_0d004olS0d_o:`]?ob/;ColS2
e@?obLCF00Goa/CHolO5f?o7aMSoalGHolG5fP02olG6f`06ol?6g?o3amgo`lOMol?7gOo0a]oo`<OO
0_l00003okk7h@03ok_6h_nka^?o^lKS00;o^<GT0_nha^@00onfa>Go]/GUokC4iP03okC4iP?o//?V
0on``^L3ojo1i`03ooooool0003ooooo02Cooooo0009ooooo`0500000?ooooooooooooooo`000000
1P1oOgl00ol00000VIVI09VIV@0409VIV@030000002c/k<0/k>c00@0/k>c00?o00000<c<c03<c<`0
1@3<c<`00`000000i^KV0>KViP070>KViP03o`00003oool0oooo01P0oooo00?o00000>KViP3Vi^H0
1`3Vi^H00`000000c<c<0<c<c0050<c<c0030000002c/k<0/k>c00@0/k>c00<0000009VIV@2IVIT0
102IVIT00`000000Ogmo07moO`0407moO`030000001VIVH0IVIV00@0IVIV00<0000004a<C01<C4`0
1P1<C4`00`000000<c<c03<c<`0803<c<`030000000I6AT06ATI00h06ATI60000004ooooo`030000
0?oooooooooo01Kooooo0_l0000Zooooo`Co]9bo0_nfW/000ongW[oo^:30okRP`002okRP`003okZR
`OnkX/3o^j;000;o_:C100?o_ZG0okjV`OnnY/400_nnY/44ol6Y`P05ol6[`oo3[<?o`jc3ol>/`oo3
[L@00_o5[l@01Oo5/<Koak;5olNbaOo7//Goa[?700?ob;C700GoakK9olVhbOo9^<WobKS9olRib`02
olZjb`05olVkcOo;_Lkobkg>ol^mc_o9_]000oo;`=03ol[2d`04ol_4doo9a=KobLCFolW4eP?oalGH
0_o8amT00oo5a]_oa/SLolK8g002ol?7g@?o000000Co`<SPo`000?nnan7o_/OQ0_nmb>800onka^?o
^lOTok_7i002okS6i004okS6iOnfaNGo]/GUokK5i@;o]<CV0_nca>H00onb`nKo/L?Wok73i`02ok32
i`Co[l7W00?o0000ooooooooool08oooool000Wooooo00D00000oooooooooooooooo0000000607mo
O`030000002IVIT0VIVI00@0VIVI00<000000;>c/`2c/k<0102c/k<00`000000c<c<0<c<c0050<c<
c0030000003Vi^H0i^KV00P0i^KV00?o00000?ooo`3oool05P3oool00ol00000i^KV0>KViP080>KV
iP030000003<c<`0c<c<00D0c<c<00<000000;>c/`2c/k<0102c/k<00`000000VIVI09VIV@0409VI
V@030000001oOgl0Ogmo00@0Ogmo00<0000006IVIP1VIVH0101VIVH00`000000C4a<04a<C00604a<
C0030000000c<c<0<c<c00P0<c<c00<0000001TI6@0I6AT03P0I6ATH000000Cooooo00<00000oooo
ooooool05_ooool00ol0003oooooo`00000Xooooo`;o/Y^o0ondW;l01?nfW/3o]ijookNN_ongW[l2
okRP`005okZQ_onkX/3o^j;0ok^R`?nlY<400onnYL02okjV`@;o`:O10_o1ZL800oo3Z/7o`jc3ol>/
``02ol>/``?oaJo41?o7//D4olRda`CobKS90oo:^//01?o<_<cobkg>ol^mc_o;_Lh3ol_0d0;oc<;A
00Gob/;Col_4doo;a=?oblCColW4eP02ol[6eP04olO5f?o8amWob<OIolS9fP;oa/SL0ol000000oo3
b=ko`lWOol38h002ol38h004o`000?nmb>;o_LSRokg8h`?o^lOT1?nha^D00onfaNGo]LGVokG5iP02
ok?4iP;o/lCW0_na`nL3ok32i`;o[l7W0_n^`NL00ol0003oooooooooo`0Rooooo`002Oooool01P00
003oooooooooooooool0IVIV000000H0Ogmo00<0000009VIV@2IVIT0102IVIT00`000000/k>c0;>c
/`040;>c/`030000003<c<`0c<c<00D0c<c<00<000000>KViP3Vi^H0203Vi^H2o`0001D0oooo00?o
00000>KViP3Vi^H0203Vi^H00`000000c<c<0<c<c0050<c<c0030000002c/k<0/k>c00D0/k>c00<0
000009VIV@2IVIT0102IVIT00`000000Ogmo07moO`0407moO`030000001VIVH0IVIV00@0IVIV00<0
000004a<C01<C4`01P1<C4`00`000000<c<c03<c<`0803<c<`030000000I6AT06ATI00h06ATI6000
0004ooooo`0300000?oooooooooo01Kooooo00Co0000oooooooooooo00009_ooool3ok:K_`?o]9bo
1?ngW[l01?nhX<3o^Z6ookZQ_onjXKl2ok^R`0Co_ZG000Go_ZK1ol2W`Oo0Yl7o`:O1ol6Y`P03ol>Z
`@;o`jc30_o5[L82olF_a005olN`a?o7//Goak;5olNbaOo8/lD00_o8]<L2olZfa`;obKS90_o;^/T0
1Oo:^/_oc;c<olblc?o<_<cobkg>00;oc;o>00Cobl3@olc2dOo<`]7oc<;A0oo;a=<2olc6e005ol[6
e_o;b=OoblSGolS7fOo8bMX00ol00002olK9g@05ol?8g_o3bMoo`lWOol?9goo0b>000_o0bN401Ol0
003o_LSSokg8honmb>?o^lOT00;o^/OT0_nha^D2okO6i@?o]LGV0onca>L3ok73i`03ok32ion_`^Oo
[l;W00;o[/7W00?o[/7Xo`000?ooool08oooool000Wooooo00H00000oooooooooooooooo06IVIP00
000607moO`030000002IVIT0VIVI00@0VIVI00<000000;>c/`2c/k<0102c/k<00`000000c<c<0<c<
c0060<c<c0030000003Vi^H0i^KV00T0i^KV0_l0000B0?ooo`03o`00003Vi^H0i^KV00T0i^KV00<0
00000<c<c03<c<`01@3<c<`00ol00000/k>c0;>c/`050;>c/`030000002IVIT0VIVI00@0VIVI00<0
000007moO`1oOgl0101oOgl00`000000IVIV06IVIP0406IVIP030000001<C4`0C4a<00H0C4a<00<0
000003<c<`0c<c<0200c<c<00`0000006ATI01TI6@0>01TI6AP000001?ooool00`00003ooooooooo
o`0Fooooo`05o`000?ooooooooooooooool000009?ooool00on`VKoo/Y^ook:K_`02ok:K_`03okBL
_oneW;ko]Ibn00?o]ijo1?njXKl00onkX/3o_:>ookbS_`03okjU`0Co`:O11?o3Z/401Oo3[<?oaJg2
olF]`_o5[L;oaJo400?oak3400Coak;5olRcaOo8/lGob;C70oo:]/L01?o9^<Wobk[9ol^jbOo;^/T3
olblc004oljoc?o<_lkoc;o>olbocP;oc/;?00Coc<;Aolg4dOo=a=7oblCC0oo<a]@2ol_8e`?o0000
0_o8bMX00oo9bm_oa/WMolK;gP02olK;gP04ol?9goo3bn3o`l_Pol39h@;o`<[R00Go0000okg8honm
bNCo_LWTok[7i002ok[8i@;o]lKU00Co]lKVokG5i_neaNKo]LGV1?nca>L3ok73i`03ojo2ion_`^So
[/7X00?o[/7X00?o0000ooooooooool08Oooool000Wooooo00H00000oooooooooooooooo06IVIP00
000607moO`030000002IVIT0VIVI00@0VIVI00<000000;>c/`2c/k<0102c/k<00`000000c<c<0<c<
c0060<c<c0030000003Vi^H0i^KV00/0i^KV0_l0000>0?ooo`;o0000303Vi^H00`000000c<c<0<c<
c0050<c<c0030000002c/k<0/k>c00D0/k>c00<0000009VIV@2IVIT0102IVIT00`000000Ogmo07mo
O`0407moO`030000001VIVH0IVIV00@0IVIV00<0000004a<C01<C4`01P1<C4`00`000000<c<c03<c
<`0803<c<`030000000I6AT06ATI00h06ATI60000004ooooo`0300000?oooooooooo01Gooooo00?o
0000ooooooooool00oooool00ol0003oooooooooo`0Oooooo`04ojjG_on`VKoo/9Vook2I_`;o/Y^o
00?o/i^nokFL__neW;h00_neW;h00ongW[oo^9jnokRN_P03okZQ_`Co_:>o00?o_ZG0oknU_onoYKl0
0oo0Yl401?o2Z<3o`j[1ol>Z`Oo3Z/43olF]`P05olN_`_o7/<Coak34olN`a?o9//@00oo8/lD01Oo;
]LGob[K7olZfaoo:]/Ooc;W700?obk[900?ocKc9olblc?o>_l`00_o>_l`01?o<_lkoc/;?olk2coo>
`/l3olg4d@?oc<KD0ol00003ol_:f003olS9f_o9bm_obL_K00?oa/_N00Goa/cOol?;h?o3bn3o`l_P
ol?<h@02ol3:hP04o`000?nobn?o_LWTokc9i0?o^/SU1?nga^H00oneaNKo]<GWokC5i`02ok?4i`;o
//CW00?o/L?Wok33j?n_`^P00_n_`^P4ojk1j003o`000?oooooooooo023ooooo0009ooooo`060000
0?ooooooooooooooo`1VIVH000001`1oOgl00`000000VIVI09VIV@0409VIV@030000002c/k<0/k>c
00@0/k>c00<000000<c<c03<c<`01P3<c<`00`000000i^KV0>KViP0<0>KViP03o`00003oool0oooo
00X0oooo00?o00000>KViP3Vi^H02`3Vi^H00`000000c<c<0<c<c0060<c<c0030000002c/k<0/k>c
00@0/k>c00<0000009VIV@2IVIT0102IVIT00`000000Ogmo07moO`0507moO`030000001VIVH0IVIV
00@0IVIV00<0000004a<C01<C4`01P1<C4`00`000000<c<c03<c<`0803<c<`030000000I6AT06ATI
00h06ATI60000004ooooo`0300000?oooooooooo01Gooooo00?o0000ooooooooool01?ooool00ol0
003oooooooooo`0Looooo`Co[YNo0_n`VKl01?nbVkoo/i^nok>K__ncVkh2okFL_P03okNM__nhW[ko
^9jn00;o^9jn00?o^Z6ook^Q__nkXKh00_nlXkl00onnY;ko_jFooknU_`02oknU_`05ol2W`Oo2Z<3o
`ZS0ol:X`?o3Z/400_o4[<401Oo5[L;oajo2olN_`_o7[l;oak3400?obK;400Gob;?5ol^eaOo;]LGo
bkG5olZfa`03olbia`04ol^jbOo=_<WocKc9olnnbP?oc[o<0oo>`/l2olo4c`03olg4dOo>a];o0000
00;o00000_o=b=D3ol_:f0;oc<cI00CobL_KolW<g?o9c=coa/_N0oo6c=l00oo3bn3o`lcQol?<h@03
oko;h`05o`000?nlbNCo_<WTokc9i?njb>D00_nib>H2okO6iP;o]/KV0ondaNL2ok;4i`04ok74ion`
`nSo/<?Xok33j0?o[l;X0_n^`NP00on]`NSo0000ooooo`0Qooooo`002Oooool01000003ooooooooo
ooooool206IVIP030000001oOgl0Ogmo00@0Ogmo00<0000009VIV@2IVIT0102IVIT00`000000/k>c
0;>c/`050;>c/`030000003<c<`0c<c<00H0c<c<00<000000>KViP3Vi^H0303Vi^H<o`0000h0i^KV
00<000000<c<c03<c<`01@3<c<`00`000000/k>c0;>c/`050;>c/`03o`00002IVIT0VIVI00@0VIVI
00?o000007moO`1oOgl0101oOgl00`000000IVIV06IVIP0506IVIP030000001<C4`0C4a<00D0C4a<
00<0000003<c<`0c<c<02@0c<c<00`0000006ATI01TI6@0>01TI6AP000001?ooool00`00003ooooo
ooooo`0Eooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool06_ooool2ojbE_`?o[YNo
00?o/9Vook6I__ncVkh00oncVkh01?neW;ko]ifnokNM__ngWKh2okRN_P05okZO__nkXKko^j6nok^Q
__nlXkl00onnY;h2oknU_`03ol6W_oo2Z<3o`ZS000;o`ZS00oo4[<44olN_`PCobK;41?o;]LD3olbi
a`04oljkb?o=_<WocKc9olflb@;ockk:00Coc[o<olo1cOo?`Lgoc/;?0_o?a<l3o`000004olk6d_o@
bM?od<WColg8e@;oc/_F00?obl[Holc<fOo<c=T00_o<c]/00oo9c=cobLkMolW>g@02olK<g`;oa/gP
00Co`lcQol?=h_o3cN;o_l_S0_nobn@01Ol0003o_<WTokc:iOnlb^Go^LSV00?o^<SV00Go]/KVokK6
ionfa^Oo]<GWok?5i`04ok74i`05ok33j?n``^So/<;Xojo2j?n^`NP01?n]`NP00ol0003ooooooooo
o`0Oooooo`002Oooool01000003oooooooooooooool206IVIP03o`00001oOgl0Ogmo00D0Ogmo00<0
000009VIV@2IVIT0102IVIT00`000000/k>c0;>c/`050;>c/`03o`00003<c<`0c<c<00H0c<c<0P00
000U0>KViP030000003<c<`0c<c<00H0c<c<00<000000;>c/`2c/k<01@2c/k<00`000000VIVI09VI
V@0409VIV@030000001oOgl0Ogmo00@0Ogmo00<0000006IVIP1VIVH01@1VIVH00`000000C4a<04a<
C00504a<C0030000000c<c<0<c<c00P0<c<c00<0000001TI6@0I6AT03`0I6ATH000000Cooooo00<0
0000ooooooooool05Oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo01Oooooo00Co
ZI>oojbE_on/UKoo[9Fo0on^Ukl3ok6I_P?o/i^n1?ngWKh00onhW[ko^YnnokZO_P03ok^Q_PCo_ZBn
00Co_jFool6W_oo1Ykoo`JNo0_o2Z<02olBZ`0;oa:c100GoaZg1olN_`_o7[l;oajo2olV``P03olVb
a003ol^da?o;]LGobkG500;ocKS600Goc;W7oljkb?o>^lSoc[_8olflb@03olnnbP?ocl7=0ol00002
om77d004olk6d_o@bM?od<WCom3;e@?oc/_F00?oclgHolc<fOo<c]/00_o<c]/3olW>g@;obLoO00Co
a/gPolG>hOo5c^7o`lgR0_o2cN<2oko;i003okk<iOl0003o_<[U00;o^l[V0_nhb>H2okS8i`03okK6
ionea^Oo/lGW00;o/lGW0_naa>L2ok74j003ok32j?n_`^So[/7X00;o[/7X0_n]`NP2ojg0j003o`00
0?oooooooooo01kooooo0009ooooo`0400000?ooooooooooooooo`<0IVIV00<0000007moO`1oOgl0
101oOgl00`000000VIVI09VIV@0409VIV@030000002c/k<0/k>c00D0/k>c00<000000<c<c03<c<`0
203<c<`00`000000i^KV0>KViP0Q0>KViP030000003<c<`0c<c<00L0c<c<00<000000;>c/`2c/k<0
1@2c/k<00`000000VIVI09VIV@0409VIV@030000001oOgl0Ogmo00@0Ogmo00?o000006IVIP1VIVH0
1@1VIVH00`000000C4a<04a<C00504a<C0030000000c<c<0<c<c00P0<c<c00<0000001TI6@0I6AT0
3`0I6ATH000000Cooooo00<00000ooooooooool05Oooool00ol0003oooooooooo`07ooooo`03o`00
0?oooooooooo01?ooooo00?oYY;0ojVC_onYTkl00_nYTkl3ojbE_`03ojjG_on_Ukko/IVn00?o/IVn
00?o/i^nokBK_OndVkd00ongWKh4okZO_P;o^j6n00Co_J:nokjT__nnY;ko_ZBn1?o1Ykl01Oo2Z<3o
a:[0olBZ`?o4Z/3oa:c100?oaZg100Goajo2olV``_o9/<;obK32olVba002ol^da004ol^eaOo=^<Ko
cKS6olfhaP?oc[_800Cod;g8olnnb_o?_/[ockk:0_oA`L/2o`000003om74c_oBaloodLO@00;odLO@
00?od/WBom39doo@bmD00_o@bmD00oo>bmKoclgHolo=f002olo?f@04olc>foo<cmcoc<oLolW>g@;o
bLoO00Cob=3PolG>hOo5c^7oaLkQ0oo2cN<01oo1c^Co_/cUokk<iOl0003o_LcUok_:i_njb^H00onh
b>L01Ongb>Oo]LKWokG6ionea^Oo/lGW00;o//GX0_naa>P01?n``nSo[l;Xojo2j?n_`^P3ojk1j0?o
[L3X00?o0000ooooooooool07_ooool000Wooooo00@00000oooooooooooooooo0`1VIVH00`000000
Ogmo07moO`0507moO`030000002IVIT0VIVI00@0VIVI00<000000;>c/`2c/k<01@2c/k<00`000000
c<c<0<c<c0080<c<c0030000003Vi^H0i^KV01l0i^KV00<000000<c<c03<c<`01`3<c<`00`000000
/k>c0;>c/`050;>c/`030000002IVIT0VIVI00@0VIVI00<0000007moO`1oOgl01@1oOgl00`000000
IVIV06IVIP0406IVIP030000001<C4`0C4a<00H0C4a<00<0000003<c<`0c<c<0200c<c<00`000000
6ATI01TI6@0>01TI6AT000001?ooool00`00003oooooooooo`0Eooooo`03o`000?oooooooooo00So
oooo00?o0000ooooooooool04?ooool01?nST<7oYY;0ojJB`?nVT/03ojVC_`;o[9Fo00Co[IFnojnG
__n_Ukko[iNn0_naVKh00onbVKgo]9^mokBK_@02okBK_@03okNM__nhWKgo^Ynn00?o^Ynn00Go^j6n
okfR__nmX[ko_J:nokjT_P02ol2U_P?o`JNo00Co`jRoolBZ`?o4Z/3oa:[01?o6[L43olV``P05ol^c
`_o;]<CobkC4ol^da?o=]/@00oo=^<H00oo?^/Koc[_8om2mb002om2mb004olnnb_l0003o0000o`00
00?odLC>0_oBall01?oAam3od/WBom;9d_oCc=<3om3;e@05om7>e_o?cMSocloIolo?fOo?dM/00oo<
cm`00oo<dMgobLoOolS@h002olS@h004olG>hOo5cn;oaLoRol;=h`;o`LkT00Co`<kUokg<iOnmc>Go
00000onjb^H01Onhb>Oo]lSWokO8iongb>Oo]LKW00;o]<KX0_nbaNP4ok33j0?o[l;X00?o[/7Xojg1
j?n]`>P00on]`>P00ol0003oooooooooo`0Mooooo`002Oooool01000003oooooooooooooool406IV
IP030000001oOgl0Ogmo00D0Ogmo00<0000009VIV@2IVIT0102IVIT00`000000/k>c0;>c/`050;>c
/`030000003<c<`0c<c<00P0c<c<0P00000N0>KViP03o`00003<c<`0c<c<00L0c<c<00?o00000;>c
/`2c/k<01@2c/k<00`000000VIVI09VIV@0509VIV@030000001oOgl0Ogmo00@0Ogmo00<0000006IV
IP1VIVH01@1VIVH00`000000C4a<04a<C00604a<C0030000000c<c<0<c<c00P0<c<c00<0000001TI
6@0I6AT03P0I6ATI000000Cooooo00<00000ooooooooool05?ooool00ol0003oooooooooo`0:oooo
o`03o`000?oooooooooo00gooooo00?oWhk2oj>@`OnST<400onVT/03ojVC_`Co[IFn0_n_Ukh01?na
VKko/YVmok:I_OnbVKd2okBK_@04okJL_OnhWKgo^9fmokRM_@;o^Ynn00?o^j2mokfR__nmX[h00_nm
X[h4ol2U_P05ol6W_oo3Z;oo`jRool>X_oo4Z/000_o6[<02olJ]`@;ob:o100GobK32ol^c`_o;/l;o
bk?2ol^da003olffa005olfha_o?^/Kock[6om6maoo@_LP00ol000001OoA`L_od/C<om;4c?oBa<co
dLC>00;od/O?0_oDb]001OoBbM;odlcCom?<dooCc=?od<_E00;odLkF00?od]3Holo?fOo?dM/00_o?
dM/01?o<cmcoc=7MolcAgOo<dml2olS@h0;ob=;Q00CoaLoRolC@hoo4d>?o`LkT0oo0c^D01?nmc>Go
_<cVo`000?njb^H2okW:i`;o]lSW0_nfb>P00onda^So/lKXok?6j002ok;5j0Co/<?X00?o[l;Xojk2
j?n^`^P00_n]`NP2ojg0j0;o[<3X00?o0000ooooooooool07?ooool000Wooooo00@00000oooooooo
oooooooo101VIVH00`000000Ogmo07moO`0507moO`030000002IVIT0VIVI00@0VIVI00<000000;>c
/`2c/k<01P2c/k<00`000000c<c<0<c<c0090<c<c0030000003Vi^H0i^KV01T0i^KV0P00000:0<c<
c0030000002c/k<0/k>c00D0/k>c00<0000009VIV@2IVIT01@2IVIT00`000000Ogmo07moO`0407mo
O`030000001VIVH0IVIV00D0IVIV00?o000004a<C01<C4`01P1<C4`00`000000<c<c03<c<`0803<c
<`030000000I6AT06ATI00h06ATI6@000004ooooo`0300000?oooooooooo01Cooooo00?o0000oooo
ooooool02oooool00ol0003oooooooooo`09ooooo`04oib=`onOS/;oWhk2oin>`P?oXi310onVT/03
ojVC_`?o[IFn00?o[iNnok2G_OnbVKd00onbVKd00ondVkgo]YbmokJL_@03okRM_@04okZO__nkX;go
^j2mok^P_@;o_J:n0_nnXkd2ol2U_P03ol:W__o3Z;oo`jRo00;o`jRo0oo6[<001?o6[L7ob:o1olR_
`Oo8[l44ol^c`P?ocKK400?ockW5olnja_o?^/H00ol000001?o@_LSod/79om;1bOoDa<X3om;4c003
omC7cOoBalooe<[@00;oe<[@0ooCc=<2omC?e003om7>e_oBd=Sod]3H00?ocm7K0_o?dm`00oo<dMgo
c=?OolcCg`03olSBh@;oam;S00?oa=3Sol?AiOo3dND00_o0c^D2oko>iP04okc<i_nkc>Oo0000okW:
i`;o^<[X0_nfb>P2okG8j003ok?6j?nba^So/LCX00;o/LCX0_n``nP2ojo3j0;o[/;X0on]`NP3ojc0
j003o`000?oooooooooo01cooooo0009ooooo`0400000?ooooooooooooooo`D0IVIV00<0000007mo
O`1oOgl01@1oOgl00`000000VIVI09VIV@0409VIV@030000002c/k<0/k>c00H0/k>c00<000000<c<
c03<c<`02@3<c<`2000001P0i^KV00<000000<c<c03<c<`02P3<c<`00`000000/k>c0;>c/`050;>c
/`030000002IVIT0VIVI00@0VIVI00<0000007moO`1oOgl01@1oOgl00`000000IVIV06IVIP0506IV
IP030000001<C4`0C4a<00H0C4a<00<0000003<c<`0c<c<0200c<c<00`0000006ATI01TI6@0>01TI
6AT000001?ooool00`00003oooooooooo`0Dooooo`03o`000?oooooooooo00cooooo00?o0000oooo
ooooool01_ooool01?nHRlCoW8g3oib=`onLSL<3oin>`P;oXi310_nVT/001?nVTKooZI>oojVC_onY
Tkl3ojfE_P?o/9Nm0onbVKd4okJL_@;o^9fm1?nkX;d01OnmX[ko_Z>mokjS_OnnXkgo`:Fn00?o`ZNn
0_o3Z;l2olFZ_`;oaZc000Gob:k0olR_`Oo8[l7ob:o1ol^a`@03ol^c`P03olfe`oo=]/CockW500?o
00000ooA_LL3om;1b@;oe<C:00Cod/C<omC7cOoDalgoe/[>0ooDb]001?oEcM7odlcComC?e?oDcm@2
omCBeP04om;@f?oBdmWod]?IoloAf`?ocm?L00GocmGNolcCgoo;e>7obmCQolSBh@02olOBh`;oa]?T
00?o`m7Uol;Ai_o2dNH00_noc^H2okk>i`04ok_<iol0003o^/cXokS:j0;o]lWX0_neb>P01OndanSo
//KXok;6j?nba^So/LCX00;o/<CX0_n_`nP01?n_`^So[/;Xojk2j?n^`^P3ojg1j0?o[<3X00?o0000
ooooooooool06oooool000Wooooo00@00000oooooooooooooooo1@1VIVH00`000000Ogmo07moO`06
07moO`030000002IVIT0VIVI00@0VIVI00<000000;>c/`2c/k<01P2c/k<00`000000c<c<0<c<c00:
0<c<c0030000003Vi^H0i^KV01@0i^KV00?o00000<c<c03<c<`02P3<c<`00`000000/k>c0;>c/`05
0;>c/`030000002IVIT0VIVI00D0VIVI00<0000007moO`1oOgl0101oOgl00`000000IVIV06IVIP05
06IVIP030000001<C4`0C4a<00H0C4a<00<0000003<c<`0c<c<0200c<c<00`0000006ATI01TI6@0?
01TI6AT000001?ooool00`00003oooooooooo`0Dooooo`04o`000?m`R=_oLHKIog66f@cooooo00Go
0000oooooooooooooooooi28a`02oiB9a@;oV8_40onLSL<3oin>`P03oj>@`OnSSl3oYY6o00?oYY6o
0onYTkl2ojfE_PCo/9Nm00?o/YVmok>J_OncV[d00onfW;d00onhWKgo^IjmokVN_@03ok^P_@Co_Z>m
1?o2Ykh01Oo3Z;ooaJZoolFZ_oo5Z[ooaZc000?ob:k000Kob:o1ol^a`Oo;/L7obk71ol^c`_o=]L<3
o`0000;ockW50ooA_LL2om?0b004om;1bOoDa<[oe<C:omC4bP?oe<O=0_oFb/h01OoDb]3oeLgAomG=
dOoFd=?oe<oD00?oe=;F0ooBdmT2om;Ef`05oloCg?o?eMkocmGNolkFgoo;e>400_o:eN801?o7d^?o
a]?TolKCi?o6dn@3ol;AiP03ol3Aionnc^Oo_/kW00;o_<kX00?o^/cXo`000?ngbNP00_ngbNP4okC7
j005ok;6j?nbaNSo//GXok34j?n``nT01?n_`^P01On^`^So[L7Xojg1j?n]`NSo[<3X00?o[;oX00?o
ooooo`000?ooool06oooool000Wooooo00@00000oooooooooooooooo1P1VIVH00ol00000000007mo
O`0507moO`03o`00002IVIT0VIVI00D0VIVI00<000000;>c/`2c/k<01P2c/k<2000000/0c<c<00@0
0000o`00000000000000403Vi^H2000000/0c<c<0P0000070;>c/`0300000?l00000VIVI00D0VIVI
00<0000007moO`1oOgl01@1oOgl00`000000IVIV06IVIP0506IVIP030000001<C4`0C4a<00H0C4a<
00<0000003<c<`0c<c<0200c<c<00`0000006ATI01TI6@0?01TI6AT000001?ooool00`00003ooooo
ooooo`0Dooooo`04o`000?m`R=_oL8SKog66f@;oM8GF0_mgQ=@2ogZ4d@;oOXC?0_n2QLd2ohN5b`;o
RhO90on@R<L3oiB9a@;oV8_40onLSL<00onOS/;oWhk1oj>?`002oj>?`0?oYY6o0_nYTkl01?nZTkko
[IFnojfE__n]UKh2ok2G_@04ok6H_OncV[go/iZmok>J_@?o]Ybm1?niW[d00onkX;go_J:mokfR_@03
okjS_@04ol2U__o2Ykko`ZNnol:W_PCoaJZo1?o8[/03ol^a`@?o000000?ocKG3olnha?o?^LD00_o?
^LD00ooA_<KodKg7om?0b002om?0b0?oe<C:0_oFal`00ooDalgoe/[>omK:cP02omO>d003omG=dOoF
d=?oe]3C00;oem?E00Coe=;FomGDf?oEe=Sod]?I0_oBeM/2om;Gg@05oloEg_o>e]ooc]KOolgHhOo:
eN800oo9e^@01?o6dnCoa=?UolCCiOo2dNH2ol3Ai`?o_<kX00Go^lkXokW<j?nic>So0000okO9j002
okK9j@;o]<OX0_ncanT00onbaNSo/LGYok75j@02ok33j@;o[l;X00Co[/;Xojg1j?n]`NSo[L7X0on/
`>P3ojboj003o`000?oooooooooo01[ooooo0009ooooo`0400000?ooooooooooooooo`L0IVIV00<0
000007moO`1oOgl01@1oOgl00`000000VIVI09VIV@0509VIV@030000002c/k<0/k>c00L0/k>c00<0
00000<c<c03<c<`0303<c<`3000000X0i^KV0`00000<0<c<c0030000002c/k<0/k>c00L0/k>c00<0
000009VIV@2IVIT01@2IVIT00`000000Ogmo07moO`0507moO`030000001VIVH0IVIV00D0IVIV00<0
000004a<C01<C4`01P1<C4`00`000000<c<c03<c<`0803<c<`030000000I6AT06ATI00l06ATI6@00
0004ooooo`0300000?oooooooooo01Cooooo00?o0000og28fom`R=/00_maQ]T2ogB5eP;oMhCD0_mj
Q=42ogj4c`;oPXG=0_n7QL/2oh^7b@?oT8S70_nDRLD2oiR;a0;oW8g300?oVhc3oin>`OnOS/400onS
Sl03ojJA_`?oZY>n0on]UKh00on`Ukgo/IRmok6H_@04ok>J_@03okJL_OngWKgo]ifm00;o^Ijm00?o
^j2mokfR_OnmX[d00_nmX[d01OnnXkgo`:Fnol2U__o0YKko`ZNn00;oa:Vn0_o5Z[l2olN/_`;ob:k0
00Cob[31o`000?l0003o00000_o=]<801Oo=]L?ockS4olnha?o?^<CockW500;odKc600Kodl37om?0
b?oC`<Sodl38omG3bOoDa<X3omK7c003omO;cOoFb/koelk@00;oelk@0ooFd=<2omOCe@?oeMCH00Co
eMOJom;EfooBemgod]OM0_oAfMl01?o>e]oocMSQolgHhOo<fN<2olWFi0;oamKU00Coa=?Uol?Ci_o3
dnKo`=7W0_nodNP02?nlc^So^lkXok_>j?nkc^So^LcXo`000?nhbnWo]/WY0_ndb>T2ok?7j@;o//KY
00?o/LGYok34jOn_`nT00_n_`nT00on^`^So[/;Yojk2j@03ojg1j0?o[<3X00Co[;oXoj^oj?oooooo
00006oooool000Wooooo00D00000ooooooooooooooooo`00000706IVIP030000001oOgl0Ogmo00D0
Ogmo00<0000009VIV@2IVIT01@2IVIT00`000000/k>c0;>c/`070;>c/`030000003<c<`0c<c<00h0
c<c<2P00000>0<c<c0030000002c/k<0/k>c00L0/k>c00<0000009VIV@2IVIT01@2IVIT00ol00000
Ogmo07moO`0507moO`030000001VIVH0IVIV00D0IVIV00<0000004a<C01<C4`01P1<C4`00`000000
<c<c03<c<`0903<c<`030000000I6AT06ATI00h06ATI6P000004ooooo`0300000?oooooooooo01?o
oooo00?o0000ooooooooool00_mYQM/00om[PmWoKH;Foff2eP02ogN4e0;oNXCA0_mnQ<l3oh:5c@;o
QhG;0_n;QlT2oi28a`04oiB9aOnBR<GoUh[4oiN:a0?oVhc30onOS/43oj>?`003ojJA_onWTKooYi6o
00?oZY>n0_n]UKh4ok6H_@;o/iZm00Go]I^mokNM_OngWKgo]ifmokVN_@03ok^P_@;o_J:m00?o_j>m
ol2U__o0YKh00_o0YKh3olBY_P04olFZ_oo7[;ooajboolN/_`?o000000?ob[31ol^a`Oo=]<800_o=
]<83olnha004om6laOoA_<KodKc6om6laP;odl3700?odl38omG3bOoE`lT00_oGal/01?oFalcoel_=
omO;cOoIc/l3omO>d004omSAd_oFd=?oem?EomOCe@;oemKG00GoeMCHomGGf_oEem[oe=WLom;Gg@03
om7Ig`05om3JhOo=f>7oc=WSolcIhoo:fND00_o7e^D2olKGiP04ol?Ci_o1dnSo`M?XokoAj0;o_M3X
0_nkc^P2ok[=j@04okS;jOl0003o]/[YokC8j@;o/lSY0_nba^T01OnaaNWo/<CYok34jOn`a>Wo[l?Y
00;o[/?Y00?o[/;Yojg1jOn/`NP00on/`NP3ojc0j0;oZkoX00?o0000ooooooooool06Oooool000Wo
oooo00D00000oooooooooooooooo0000000706IVIP030000001oOgl0Ogmo00H0Ogmo00<0000009VI
V@2IVIT01@2IVIT00ol00000/k>c0;>c/`070;>c/`03o`0000000000c<c<02@0c<c<00?o00000;>c
/`2c/k<01`2c/k<00`000000VIVI09VIV@0609VIV@030000001oOgl0Ogmo00D0Ogmo00<0000006IV
IP1VIVH01@1VIVH00`000000C4a<04a<C00604a<C0030000000c<c<0<c<c00T0<c<c00<0000001TI
6@0I6AT03P0I6ATJ000000Cooooo00<00000ooooooooool04oooool01?l0003oooooooooooooool2
ofV5f`04of^3fOm]P]KoKH;Fog61e0;oMH7B0_miP/l3ogj3c@;oPhC;0_n8QLT2ohj7a`?oTXS50_nG
R/@3oi^<``;oWhk10_nSSl001?nST<3oYi6oojNA_onWTKl3ojZC_P03ojfE__n^U[ko[YJn00?o/IRm
00Co/iZmokFK_OneVkgo]I^m0_ngWKd4ok^P_@04okfR_OnoXkgo_j>moknS_@;o`:Fn0_o2Ykh2olBY
_P;oajbo0_l000001?o9[l3ob[31olZ``Oo:/<43olfd`P;ockS300GockS4om6laOoA_<GodKc5om6l
aP02om?0a`;oe/?800CoeL?9omO7booGal_oelO;0ooGbld2omW>c`05omO>d?oHdM;of=7BomWDe?oG
dmD00_oGe]L2omOIf@03omGGf_oDfMcoe=WL00;oe=cN00GodMWOom3JhOo@f^7ocmcSolcIh`02ol[I
i@03olSJi_o6enKoa]OV00;oa=KX00Co`M?Xol3CjOo0dnWo_M3X0_nld>T2ok[=j@;o^<gY00Go]/[Y
o`000?nebNWo/lSYok;7j@04ok75j@05ok34jOn_a>Wo[lCYojk3jOn^`^T00on]`NT2ojc1j0?o[<3X
1?n[_nP00ol0003oooooooooo`0Hooooo`002Oooool01@00003oooooooooooooool0000000P0IVIV
00<0000007moO`1oOgl01@1oOgl00ol00000VIVI09VIV@0609VIV@030000002c/k<0/k>c00P0/k>c
00<000000<c<c03<c<`0803<c<`2000000X0/k>c00<0000009VIV@2IVIT01P2IVIT00`000000Ogmo
07moO`0407moO`03o`00001VIVH0IVIV00H0IVIV00<0000004a<C01<C4`01P1<C4`00`000000<c<c
03<c<`0903<c<`030000000I6AT06ATI00h06ATI6P000004ooooo`0300000?oooooooooo01?ooooo
00Co0000oooooooooooooooo0_mQPM`2of=of@;oKH;F00?oLH7DogF1d_mePM800_miP/l3ogj3c@;o
PhC;0_n8QLT2ohj7a`;oTXS50onGR/@2oi^<``;oWhk11?nST<03ojNA_`03ojZC__n[U;oo[YJn00;o
[YJn0onaV;d4okFK_@03okNM_OniW[go^Ijm00?o^j2m1?noXkd01Oo0YKko`ZNnol:W__o2Ykkoa:Vn
00?o00000_o7[;l2olV_`004olZ``Oo</l7oc;?1olfd`P?ockS300KodK_4om6laOoA_<GodKc5omBo
a_oC`<L3omK3b0?oelO;0_oIbl`00ooGblgofLk?omW>c`02om[Bd@05omSAd_oIe=CofMCDom[He_oG
e]L00ooGfMT01?oGg=_oe=WLomCLg_oDg=h2om?Mh005om3JhOo?g>?ocmcSolgLi?o:fND00_o8f^H0
1_o6f^Soa=KXolCFj?o4e^So`]KYol3Cj@;o_];Y00?o_=3Yok[?j_njcnX00_nhcNT2okO<jP03okG9
jOl0003o//OY00;o//OY0_naaNT00on`aNWo[lCYojo4j@02ojo3j@;o[/;Y0on]`NT3ojc0j0KoZkoX
00?o0000ooooooooool05oooool000Wooooo00H00000oooooooooooooooo04a<C000000806IVIP03
0000001oOgl0Ogmo00D0Ogmo00<0000009VIV@2IVIT01P2IVIT00`000000/k>c0;>c/`080;>c/`<0
00007@3<c<`2000000/0/k>c00<0000009VIV@2IVIT01P2IVIT00`000000Ogmo07moO`0507moO`03
0000001VIVH0IVIV00H0IVIV00<0000004a<C01<C4`01P1<C4`00`000000<c<c03<c<`0903<c<`03
0000000I6AT06ATI00h06ATI6P000004ooooo`0300000?oooooooooo01?ooooo00?o0000oooooooo
ool00_ooool2of61g003of=ofOmVO]OoIWkG00;oJWkE0_mePM82ogV2c`;oOX?=0_n3Q</2ohR5b@;o
SXO70onBR<D01?nGR/CoUXW4oi^<`onKS<<3oin>`@?oXi300_nWTKl01?nWT[ooZiBooj^D_on[U;l3
ojjF_P03ok6H_OnbVKko/YVn00?o]I^m1?niW[d00onkX;go_J:mokfR_@03oknS_@;o`ZNn0ol00003
olJ[_`04olN/_oo9[l3obJo0olV_`0?oc;?100CockO2olnh`oo?^<?ockS30_oA^l@01?oA_<Goe;o6
omBoa_oF`lL3omK3b003omS7b_oGal_ofL_<00;ofL_<00Cof/o>omW>cooJd]7of];A0_oKe]<00ooI
e=Cof]SFom[HeP02om[Kf005omOIfOoGg=_oemcKomKNgOoDg=h00_oCgN02om7OhP05oloLhoo=g>Co
cMcTol_Mi_o8f^H00oo6f^P01Oo4e^So`]KYol;FjOo0eN[o_];Y00;o_=7Z00?o^/oZokS>j_nhc^X0
0_ngc>X2okG;jP03o`000?ndbN[o//OY00;o/LKY00?o/<GYojo4jOn_a>T00_n_`nT01On^`nWo[L;Y
ojg2jOn]`^Wo[L7Y00;o[<7Y0on/`>P5oj^oj003o`000?oooooooooo01Oooooo0009ooooo`060000
0?ooooooooooooooo`1<C4`00000201VIVH00`000000Ogmo07moO`0607moO`030000002IVIT0VIVI
00H0VIVI00<000000;>c/`2c/k<02P2c/k<00`000000c<c<0<c<c00I0<c<c003o`00002c/k<0/k>c
00X0/k>c00<0000009VIV@2IVIT01P2IVIT00`000000Ogmo07moO`0507moO`030000001VIVH0IVIV
00H0IVIV00<0000004a<C01<C4`01`1<C4`00`000000<c<c03<c<`0803<c<`030000000I6AT06ATI
00l06ATI6P000004ooooo`0300000?oooooooooo01?ooooo00?o0000ooooooooool00_ooool2oeQm
g0;oHgoI0_mVO]L00omZO]GoKgkBofmndP02ogAod0;oNX7>0_n0P/`2ohJ4bP;oRhK80onAR<H2oiJ9
a0?oVhc30onOS/400onST<3oXi31ojNB_`02ojNB_`?oZiBo0_n^U[h00on_Ukko/YVnok:I_P02ok:I
_P03okFK_OnfW;ko^Ijm00?o^Ijm1?nmX[d01?noXkgo0000o`000?l00002ol:W_P04olBZ_oo6Zkoo
aZ^oolR^`0?obJo00_o<//42olbc`@;ockO200CockS3om6ka?oA^lCodK_40ooD_lH2omK3a`03omK3
b?oHal[of<O:00;of/c<00GofL_<om[?c_oJclkog=?@om[Bd@03om_Fd`04omcJeOoJf=Kof]_Hom[K
f0;of]kJ00GoemcKomKNgOoFg]goeN7Oom?Mh002om7OhP;od>3T00CocMcTol_Mi_o9gNSobMgX0_o6
f^P2olCIj@05ol;FjOo0eN[o`=GZokkDjonldNX00_njd>/00onhc^[o]lg[okO=j`02okG;jP05okC:
j_ncb>[o0000ok?8j_naa^T00_n`aNT2ojo4j@Co[/?Y00Go[L;Yojg1jOn]`NWo[<7Yojc0j@09oj^o
j003o`000?oooooooooo01Kooooo0009ooooo`0400000?ooooooooooooooo`80C4a<00?o000006IV
IP1VIVH01P1VIVH2000000L0Ogmo0P00000709VIV@8000002`2c/k<00ol0000000000000000G0<c<
c08000002`2c/k<00ol00000VIVI09VIV@0609VIV@030000001oOgl0Ogmo00H0Ogmo00<0000006IV
IP1VIVH01@1VIVH00ol00000000004a<C00704a<C0030000000c<c<0<c<c00T0<c<c00<0000001TI
6@0I6AT03`0I6ATJ000000Cooooo00<00000ooooooooool04oooool00ol0003oooooooooo`03oooo
o`;oF7gL00?oFWcJoeekf?mMNmP00_mZO]D2ofmndP;oM7o@00?oNX7>oh22c?n0P/`00on6Q<X2oh^6
b0?oTHS60_nFRL@3oi^<``03oin>`OnOS/;oXi3100;oXi310onWT[l2oj^D_`Co[iNn0_nbVKh01?nc
Vkko]YbnokJL__nfW;h2okVN_@03okZP__nmX[go_J:m00?o00000oo1Y[h01?o2Ykkoa:ZoolBZ_oo6
Zkl3olR^`005olV_`?o<//7oc;;1olbb`Oo</l400oo?]l83om6ka0;oe;o500Coe;o6omK3aooF`lOo
e/?70ooHalX2om[<c0?of/o>00Cog=?@omgHd_oMf=;ofmKC0_oLf]D00ooLg]Oof]_Hom[NfP02om[N
fP03omWQg?oFg]goeN7O00;oe>;R0_oBhn@01Oo@h>Coc^7VolkQi_o;hNSobMgX00;oamcY0_o4fNT2
ol;HjP05ol3Ej_nne>_o_]C[okcCjonjd>/00_nhcn/00ongcN_o]Lc[okC:jP03okC:jP04ok?8j_l0
003o/LOZok35j@;o/<GZ0_n_a>T2ojk3j@;o[L;Y00?o[L7Yojc1jOn/`NT00_n/`>T7oj^oj0;oZ[kX
00?o0000ooooooooool05Oooool000Wooooo00@00000oooooooooooooooo0`1<C4`00`000000IVIV
06IVIP0706IVIP030000001oOgl0Ogmo00H0Ogmo00<0000009VIV@2IVIT01P2IVIT2000000`0/k>c
0`00000@0<c<c0@000002`2c/k<2000000T0VIVI00<0000007moO`1oOgl01P1oOgl00`000000IVIV
06IVIP0506IVIP030000001<C4`0C4a<00L0C4a<00<0000003<c<`0c<c<0200c<c<00ol000006ATI
01TI6@0@01TI6AX000001?ooool00`00003oooooooooo`0Booooo`03o`000?oooooooooo00Gooooo
0_mHOM`01?mJO=[oGG_Hof9ke_mRNmH2ofmndP;oM7o@0_mjPLh2oh22c0;oQXC:0_n;Q/P3oi68aP;o
UXW40_nKS<<00onJS<CoWhk2oin>`P03oj>@`@?oYi:o00?oZiBoojbE_on/UKl00on_Ukh00onbVKko
/i^nok>K_P03okJL_P03okVN_OnjX;ko000000;o000000?o_J:moknT__noY;h00_o1Y[h01?o3Z;oo
a:ZoolBZ_oo4Z[l4olR^`0Coc;;10oo?]l82om6ja004om6ka?oD_lGoe;o5omBoa@?oe/?70_oHb<T0
0ooHal[of/c<om[<c002omc@c@03om[?c_oLdm3og=?@00;ogMSB00CogMcDomcJeOoLg]Oog=kG0_oL
hMX01_oJg][ofN7LomWQg?oHi=ooe^GQomCRhP;od^?T0_o@i>H01Oo>hNKobn7Xol_Qj?o9h>WoamcY
00;oa=cZ0_o2f>X2ol3Gj`06okkDjonldn_o_=?[ok[Bk?nhcn_o]lk[0onec>/2okC:jP;o/lW[00Go
/LOZo`000?n`a^[o/<GZojo4j@03ojk3j@Co[L;Y00?o[<7Yojc0jOn[`>P00_n[`>P6oj^oj0;oZ[kX
00?o0000ooooooooool05Oooool000Wooooo00@00000oooooooooooooooo101<C4`00`000000IVIV
06IVIP0706IVIP03o`00001oOgl0Ogmo00H0Ogmo00<0000009VIV@2IVIT01`2IVIT00`000000/k>c
0;>c/`0<0;>c/a0000003P2c/k<00`000000VIVI09VIV@0809VIV@030000001oOgl0Ogmo00H0Ogmo
00<0000006IVIP1VIVH01@1VIVH00`000000C4a<04a<C00704a<C0030000000c<c<0<c<c00T0<c<c
00<0000001TI6@0I6AT03`0I6ATK000000Cooooo00<00000ooooooooool04_ooool00ol0003ooooo
ooooo`05ooooo`;oCGWM0_m?N=/01?mMNmSoHW_Fof9ke_mXO=<2ofimd@;oMGo?0_n0P/`3ohJ4bP;o
RhK800CoTHS6ohn7aonDRLGoU8W50onJS<@3oin>`P?oXi3100?oYi:oojRC`?n/UKl00_n/UKl3ojnG
_PCo/i^n00Co]Ybno`000?l0003o00000_njX;h01OnmX[go_jBnoknT__noY;ko`JJn00?o`jRo0_o4
Z[l01Oo7[L3ob:k0olR^`?o8[/3obk7100?oc;;100?oc[K2olng`_oA^/@00_oA^/@3omBoa@;oel?7
00Koe/?7omS8bOoHb<Wof<S9om_<booJc<`2omc@c@;ogMG@00?og=?@omgHd_oMf=800_oMg=@01?oN
h=Oog=kGomcQf_oLhMX2om_Tg006omWQg?oHi=ooe^GQomKUhOoDin?od^?T0_o@i>H2olkTj005ol_Q
j?o9h>WobN3YolKOjoo4g>X00_o2fn`2ol3Gj`;o_]K/00?o_=?[ok[Bk?njd^`00ongc^/00onec>_o
]<_[okC;j`02ok?9j`;o/LS[00?o0000ojo5j_n_aNX00_n_a>T00on^`nWo[L;Yojg2j@02ojg2j@05
ojc1jOn/`>Wo[<3Yojc0jOn[`>P01_n[_nP4ojZnj003o`000?oooooooooo01Cooooo0009ooooo`04
00000?ooooooooooooooo`D0C4a<00<0000006IVIP1VIVH01P1VIVH00`000000Ogmo07moO`0707mo
O`030000002IVIT0VIVI00L0VIVI0P00000Y0;>c/`03o`00002IVIT0VIVI00L0VIVI0P00000807mo
O`030000001VIVH0IVIV00H0IVIV00<0000004a<C01<C4`01`1<C4`00`000000<c<c03<c<`0903<c
<`030000000I6AT06ATI00l06ATI6`000004ooooo`0300000?oooooooooo01;ooooo00?o0000oooo
ooooool01_ooool2odeig@03odmhfomDMmWoE7OI00;oHW_F00CoJ7cCofimdOm^OM7oMGo?0_mlPLd3
oh:3b`;oRHG90_n?QlL3oiB9a@?oVXc40_nOS/82oj>@`@04oj>A`_nXTl3oZ9?0ojRC`0?o[9Fo00Co
[iNnok2I_on`VKoo/i^n0ol00002okRN_P?o^Z2n1?noY;h4ol>X_`05olBZ_oo7[L3oajg0olN]`?o8
[/000oo;/L400oo<//7oc[K2oljf`P04om6ja0;oe;o50ooG`lL01ooIb<Wof<S9omS8bOoHb<Woflc;
omcAcOoLd<d00ooMeM000ooNf];ogMSBomgLe002omgLe003omkPeooMi=Wog>7J00;ofnCL0_oJimh0
1_oHjN7oe^GQomCWhooDin?od^SVom3TiP;oc^CX0_o;i>T01Oo9h>Woa]o[olCNk?o4g^co`]_/00;o
_mW/0_nne^`2okcDk004ok[Bk?nhd>co^=3/okO>j`;o]Lg/00?o]<_[ok;9jonbbN/00_nab>/2ok36
jP03o`000?n_a>[o[/?Y00;o[/?Y0on]`^T2ojc1j@Co[<3Y1On[_nP6ojZnj003o`000?oooooooooo
01?ooooo0009ooooo`0400000?ooooooooooooooo`H0C4a<00<0000006IVIP1VIVH01P1VIVH00`00
0000Ogmo07moO`0707moO`030000002IVIT0VIVI00P0VIVI0P00000U0;>c/`8000002@2IVIT00`00
0000Ogmo07moO`0707moO`030000001VIVH0IVIV00L0IVIV00<0000004a<C01<C4`01`1<C4`00`00
0000<c<c03<c<`0903<c<`030000000I6AT06ATI00l06ATI00?o000000000000000060000004oooo
o`0300000?oooooooooo01;ooooo00?o0000ooooooooool01oooool01?m1M=goCgSKodmhfomDMmT2
oeUhe`;oH7WE0_m^OM400omeOlooO87=ogb1c@03oh:3b`;oRHG90_n?QlL3oiB9a@;oVXc400?oWhk2
oij?`onSTL800onSTL82ojRC`0;o[9Fo00?o[9O0ok2I_on`VKl00_l000000oncVkko]IfookRN_P03
okRN_P03okZP__nlXkoo_:>o00?o_jBn00Co`JNool>X_oo3Z;ooaJc00oo7[L001Oo9/<7obk71ol^a
`Oo;/L7ocKG200?oc[K20ooA^/@2omBoa@Coel?70_oIb<T01OoHb<Woflc;om_<booLdLgog]K?00?o
gMG@00Cog][BomoNe?oOg]CogMcD0_oNh=L00ooMi=WogNOLom_Tg002om[WgP;of>WQ00?oe^_SomCW
hooBj>H00_o?j>P2olgXjP05ol_TjOo8hn_ob>?[olGRkOo4g^`00_o1gNd00onofNco_MS]okgHk@02
okcDk0;o^]?]00Co^=3/okK?k?nfcnco]Lg/0_ncbn`00onbbN_o/LS[ok78j`02ok36jP;o[lGZ00?o
0000ojo4j_n^`nT00_n]`nT00on]`^Wo[<7Yojc1j@02ojc1j@;o[<3Y0_n[_nT3oj^oj0;oZ[oX1OnZ
_^P00ol0003oooooooooo`0Cooooo`002Oooool01000003oooooooooooooool704a<C003o`00001V
IVH0IVIV00H0IVIV00<0000007moO`1oOgl01`1oOgl00`000000VIVI09VIV@0909VIV@<000008@2c
/k<00`000000VIVI09VIV@0809VIV@030000001oOgl0Ogmo00L0Ogmo00<0000006IVIP1VIVH01`1V
IVH00`000000C4a<04a<C00704a<C0030000000c<c<0<c<c00T0<c<c00<0000001TI6@0I6AT0400I
6ATK000000Cooooo00<00000ooooooooool04_ooool00ol0003oooooooooo`08ooooo`04od5dgOm4
Lm_oE7OIoeAgf@;oFGSG00?oH7WEofMkdomWNm<00_m_OM42ogb1c@;oPX?;0_n9QLT2ohn7a`;oU8W5
00?oTh[7oiV<aOnIS<D00onNSl<3oj>A`P04ojRC`?nXU<;o[9O0ojbG`0?o000000?o/9VookFM_one
WKl00_neWKl2okRN_P03okZQ_onlXkoo_:>o00;o_:>o00Co_jBnol6W_oo1Ykoo`jRo0oo5[<001Oo7
[L3obK31olV``Oo9/<7obk7100?ocKG200Coc[K2om6ja?oA^/CodK[40ooD_lD3omO3a`;ofLS90_oK
cL/00ooKc<_og=7=omcAc@02omkFc`04omgEd?oNf];ogmkDomoNe0;ogn?G00Gog^3GomgTfOoMimco
gNOLom_ZgP02omW]h006omSYhOoFjn?oe^_Som?/iOoAk>SocnSX0_o=j>X2olWWk005olSSjoo5h^go
aN;]ol?Pk_o1gNd00_nofnh00onmf>go^mK]ok_Fk@02ok[Ck@;o^=7]00Co]/o/okG=k?necNco/l_/
0_nbb^/00onab>_o/<O[ok37j`02ojo5jP05ojk5j_n^`n[o0000ojk3j_n]`nT00_n]`^T3ojc1j@;o
Zl3Y0_n[_nT4oj^oj003ojZoj?nZ_^SoZ[kX00GoZ[kX00?o0000ooooooooool04_ooool000Wooooo
00@00000oooooooooooooooo201<C4`00`000000IVIV06IVIP0606IVIP03o`0000000000Ogmo00L0
Ogmo00<00000o`00000000002`2IVIT2000001/0/k>c1000000:09VIV@03o`00001oOgl0Ogmo00L0
Ogmo00<0000006IVIP1VIVH01`1VIVH00`000000C4a<04a<C00704a<C0030000000c<c<0<c<c00T0
<c<c00<0000001TI6@0I6AT0400I6ATL000000Cooooo00<00000ooooooooool04_ooool00ol0003o
ooooooooo`08ooooo`;o<foM00CoA7?KodQcf_m?M=SoCgCH0_mPNMD2ofMkd`03ofmmdOmgOlooMgo?
00;oOX;=0_n6QL/2ohf7b0?oTh[70onIS<D3oij?``03oj>A`_nTT/?oZ9C200?o00000_n/Ul000on`
VKoo/I_0ok6K`003okFM_`04okRN__njXKoo^Z6ookZQ_`;o_:>o00Co_ZG0ol6W_oo1Ykoo`JNo1?o5
[<04olV``@CocKG20ooA^/@2om>naP04omBoaOoG`lOoel?7omO3a`;ofLS90ooKcL/01?oMd/gog=7=
omkFcooNe/l2omoKdP04on3Qe?oOg]Cogn?GomoSe`;ognOI00?og^_KomgWg?oKj]h00_oIkN02omO^
h`06omK[hooCk>GodNcXom7/j?o>k>[ocNSZ0_o9in`2olOVk@05olGRkOo3h>ko`=k^ol3Nk_nofnh0
0_nlfNh00onke^go^MC^okWDkP02okSAk@;o]/o]00Co]Lg/ok?<k?ncc>co//[[0_nab>/00on`an_o
[lK[ojo6j`02ojk5jP05ojk3j_l0003o[L?Zojg3j_n]`^T01?n/`NT3oj_0j@CoZkoX0_nZ_nP7ojZn
j003o`000?oooooooooo01;ooooo0009ooooo`0400000?ooooooooooooooo`P0C4a<00<0000006IV
IP1VIVH01`1VIVH00`000000Ogmo07moO`0907moO`030000002IVIT0VIVI00X0VIVI0P00000G0;>c
/`8000003@2IVIT00`000000Ogmo07moO`0707moO`03o`00001VIVH0IVIV00P0IVIV00<0000004a<
C01<C4`01`1<C4`00`000000<c<c03<c<`0903<c<`030000000I6AT06ATI01006ATI70000004oooo
o`0300000?oooooooooo01;ooooo00?o0000ooooooooool02Oooool01OlcKmgo=VkKocI^fom8Lm[o
CgCH00;oEgKF0_mWNm<2ofmmd@;oMgo?0_mnP/d2ohJ5b`;oSHO80onCR/L2oiV<a@;oWXo300CoWY35
o`000?l0003o00000onXU<800on/Ul3o[IW2ok6K`002ok6K`0?o]Ifo1?njXKl01?nlXkoo_ZG0okjU
`?nnYL02ol6W_`05ol>Z`Oo5[<3oaJc0olF/`?o8[l800oo9/<400oo<]<?ocKG2olfe`P02om2ia004
om6ja?oC_/Kodkk6om>naP?oel?70_oIb<T3om_=b`;ogM;=00?ogmS@omkFcooOfm800_oOfm800ooP
hMCohNGGomoSe`03omoWf@04omk[fooLk]kof_3PomW]h0;oenkS0_oDknD00ooAl>OodNcXolk/jP02
ol_[k0;oanW]00GoanK]olCTk_o4i>ko`N;_ol3NkP02okgLk`04okcIk_njenko^]O^okWDkP;o]m;^
0_nfcnd2okC>k@04ok?<k?nbb^co//[/ok78j`;o/<O[00?o[lK[ojk5j_n^a>X00_n^a>X01?n]`n[o
0000ojg2jOn]`^T3ojc1j@?oZl3Y00CoZkoYoj^oj?n[_nSoZkoX0_nZ_nP9ojZnj003o`000?oooooo
oooo017ooooo0009ooooo`0400000?ooooooooooooooo`T0C4a<00<0000006IVIP1VIVH01`1VIVH0
0`000000Ogmo07moO`0907moO`800000302IVIT6000000d0/k>c1000000>09VIV@030000001oOgl0
Ogmo00P0Ogmo00<0000006IVIP1VIVH01`1VIVH00`000000C4a<04a<C00704a<C0030000000c<c<0
<c<c00X0<c<c00<0000001TI6@0I6AT0400I6ATL000000Cooooo00<00000ooooooooool04Oooool0
0ol0003oooooooooo`0;ooooo`05ob=YfolfK]_o>foJoc]_f_m?M=P00_mGM]H00omONMGoJ7_CofQk
d`02ogMoc`;oOX;=0on6QL/2ohf7b0;oTh[700?oVHc5oiR>aol000000_l00003ojBB``;oZ9C200Co
ZIO3ojfI`_n]VL;o[IW20onaVl000oneWKoo]io1okNO`@03okZQ_`Co_ZG000Go`JNool>Z`Oo3Z/7o
`j[1olF/`003olR_`P04olV``Oo<]<?oc;C3olfe`P?od;W41?oC_/H00ooFa<Soel?7omW8b@02omW8
b@03om_>c?oKcL_ogM;=00;ogM;=00CogmS@on3Md_oPgM;ogm_B0_oPhM@01OoQiMOoh>[Ion3ZfOoO
imWog^_K00;og>kN00Kof_3PomObhooDlnGoe??UomC_iOoAl>L2olk`jP04ol__k?o;jncoanW]olOY
k@;oa>O_00Goa>C^ol7Rkonngo3o_]o`okgLk`02ok_Ik`04ok[Gk_nhe>oo^=C_okOBkP;o]M3^0_nd
c^d2ok;<k@04ok;:k?n`b>co/<S/ok37j`;o[lK[0_n^aNX01On^a>[o[L?Zojg3j_n]`^Wo000000Co
[<7Y0on[`>T2oj^oj@03oj^oj?nZ_nSoZ[oX00_oZ[kX00?o0000ooooooooool04?ooool000Wooooo
00D00000ooooooooooooooooo`00000904a<C003o`00001VIVH0IVIV00L0IVIV0P00000;07moO`03
0000002IVIT0VIVI00l0VIVI3@00000A09VIV@030000001oOgl0Ogmo00P0Ogmo00<0000006IVIP1V
IVH01`1VIVH00`000000C4a<04a<C00804a<C0030000000c<c<0<c<c00T0<c<c00<0000001TI6@0I
6AT0400I6ATM000000Cooooo00<00000ooooooooool04Oooool00ol0003oooooooooo`0<ooooo`03
ob=YfolVJM[o>foJ00;o@W3I0_mGM]H01?mONMGoJ7_Cog5ndOmaO]42ogZ2c`?oPhG=0_n;R</01OnB
RlWo0000o`000?l0003oV8k700?oWY350_nTT/<00onXU<;oZIO3ojVG``03ojfI`P;o/I_000?o/ig2
okNO`OngWl400_ngWl400onjXKoo_:C1okbT`@03okjU`0?o`j[100?oaZk3olR_`_o8[l800_o8[l83
olbd``04olniaOo@^LCod;W4om2ia0?odkk60_oFa<P2omW9bP03omW8bOoKc/coflk<00;og]C>00?o
gM;=omoHd?oOf=000_oPgM800ooQhmGoh>7Don7Ue`02on3Zf@;ognkK00CogO7Nomc^g_oJl>3oeo;S
0_oDlnD2om7ci`03olkcjOo>l>[obno/00;ob>g^00CoaN__olCWkoo4inoo`^G`0_noh_401?nngo3o
_=c`okcLl?nkfNl2okWGk`04okSDkonfd^ko]];^okG@kP;o/lk]0_nbc>d2ok7:k005ok38k?n_an_o
[lO[ojo6jon^aN/00on]a>X01On]`n[o[<;Yojc2jOn/`NWo000000;o[<7Y0on[`>T01On[_nWoZkoX
oj^oj?n[_nSoZ[oX00_oZ[kX00?oZKkXo`000?ooool04Oooool000Wooooo00D00000oooooooooooo
oooo0000000:04a<C08000002@1VIVH00`000000Ogmo07moO`0907moO`800000:P2IVIT200000003
o`00001oOgl0Ogmo00P0Ogmo00<0000006IVIP1VIVH01`1VIVH00`000000C4a<04a<C00804a<C003
0000000c<c<0<c<c00X0<c<c00<0000001TI6@0I6AT0400I6ATM000000Cooooo00<00000oooooooo
ool04Oooool00ol0003oooooooooo`0<ooooo`;o4F?I00?o9VWJobaYf_m2L=T00_m;LmP2oeEfe`03
ofQkdomaO]7oLGkA00;oNX;?0_n3QLd3o`0000;oTX_90onHS/L2oij@a@03ojBB`onTU<GoZIO300?o
ZIO30_n]VL84ok>M`P;o]io100?o^:;3okbT`OnlY<400_nlY<401?nnYL3o`JW2ol6Y`_o3Z/43olJ^
``;ob:o20_o:]<@01Oo<]<?ockW5olniaOo?^LGod;W400?odkk600?oe/C9omK4b?oIbLX00_oIbLX0
0ooKclgoflk<omkDcP02omkDcP04omoJdOoOf=3oh=gBon3MdP;ohN?E00?ohNSGon3]f_oPj]T00_oO
k]/2omgagP04om[dh?oGm^;odoOTomCci@;odO?W00Koc_?Yol[bk?o:l^coao7^olS]k_o5jnl2ol;Y
l@03ol;Ul?noh_7o_n;a00;o_=oa00Co_=c`okWJl?nif_3o^MO_0_nge>l01?nfd^ko]=3^okC@k_nc
c^d2ok;<k@;o/L[/0_n`b>`00on_an_o[/K[ojk6j`02ojk5j`04ojg4j_n]`n[o[L?Zojc2j@;o[<7Y
00?o0000ojc1jOn[`>T00on[`>T2oj^oj@03oj^oj?nZ_nSoZ[oX00_oZ[kX00?oZKkXojVmj?l00000
4Oooool000Wooooo00H00000oooooooooooooooo03<c<`00000;04a<C0030000001VIVH0IVIV00L0
IVIV00<0000007moO`1oOgl02P1oOgl2000002L0VIVI00<0000007moO`1oOgl02@1oOgl00`00003o
000006IVIP0806IVIP03o`00001<C4`0C4a<00T0C4a<00<0000003<c<`0c<c<02P0c<c<00`000000
6ATI01TI6@0@01TI6Ad000001?ooool00`00003oooooooooo`0Aooooo`03o`000?oooooooooo00go
oooo00?o4F?IoaARf?lDH]P00_ldK=X2od]cf003oeEfeomPN]KoH7[F00;oLGkA0ol000000on3QLgo
RhS;oh^8b`02oi:;b@;oV8k700?oV8o9oijBaonNT/L00onTU<D3ojVG``03ojfI`_n_VlCo[i_400?o
/ig200Co]io1okRR`onhX/?o^:;30_nlY<401?nnZ<?o`JW2ol6Y`_o1ZL84olJ^``04olR_`_o:]<Co
b[C4olZda0?ockW500Cod[k7om>na_oC_/Kodkk60_oFa<T3omW9bP;oflo=0ooNe<h2omoJd@04on7P
dooPgM;ohN?Eon7Se@;ohNSG00Soh>gJomoag?oOlMcog?GNomgag_oJm>3oeoKRom?gi0;od?OW0_o<
mnT01?o9m^cob_;/olOak_o4ko02ol7/l@04ol;YlOnoi_;o_>?bokcSlP;o_=oa0_njg?401?nif_3o
]mO`okGDl?nee?02okCBk`04okC@k_nbcNko//g^ok;<k@;o/<[]0_n`b>`2ojo7k003ojk6jon^aN_o
[LCZ00;o[LCZ00?o[L?Zojc2j_n/`^X00on/`NT01Ol0003oZl3Yoj_0jOn[`>WoZkoY00?oZkoX00?o
Z[oXojZnj?nZ_^P02OnZ_^P01OnY_^SoZKgXojVmj?nY_NSo0000013ooooo0009ooooo`0400000?oo
ooooooooooooo`80<c<c00<0000004a<C01<C4`02@1<C4`00ol00000IVIV06IVIP0706IVIP<00000
2`1oOgl300000280VIVI0P00000;07moO`030000001VIVH0IVIV00P0IVIV00<0000004a<C01<C4`0
2@1<C4`00`000000<c<c03<c<`0:03<c<`030000000I6AT06ATI01006ATI7P000004ooooo`030000
0?oooooooooo017ooooo00?o0000ooooooooool03_ooool01?l0FmCo56;HoaYSf?ldK=X2oci_f@;o
EGKG0ol00002ogF2dP;oOhG@0_n8RLh2oi2<b`?oV8o90onNT/L3ojBDa@03ojVG`onZVLGo[i_400;o
[i_40oncWL84okRR``04okbT`OnnZ<?o_ZS3okjX``;o`JW200Go`jg4olJ^`oo6[/?oaZk3olRca@03
olZda003olfia_o?^LGod[k700;od[k700Kodkk6omK4bOoFa<Woe/C9omS:booIbLX3om_?c@04omkF
cooNe<kogm[AomoJd@;ohN3C0_oRi]H00ooQk=SohNSGon3]fP02omoag0;og?GN00GofOOPomGih_oA
n^CocO[Vom3gi`02olcgj@07olWfk?o5m>ko`_;`ol;bl?noko;o`NcaokkYl`02okcVl`06okcSl_nj
go?o^]ocok[Olonjg?7o]mWa0_nee_401Onee?3o/m7`ok?Al?nccnoo/Lg^00?o/L_]00?o/<[]ojo8
k?n_b>`00_n_an`01On^a^_o[/G[ojk5jon^aN_o[LCZ00;o[L?Z00?o[<;Zojc1jOn/`NT00_n[`NT0
0on[`>Wo0000oj_0j@02oj^oj@;oZkoX0_nZ_nP:ojZnj003ojVnj?nY_NSoZKgX00;oZKgX00?o0000
ooooooooool03_ooool000Wooooo00@00000oooooooooooooooo0`0c<c<00`000000C4a<04a<C009
04a<C0030000001VIVH0IVIV00T0IVIV00?o000007moO`1oOgl02`1oOgl01000003o000000000000
000J09VIV@80000000?o00000000001oOgl02`1oOgl00`000000IVIV06IVIP0806IVIP030000001<
C4`0C4a<00T0C4a<00?o000003<c<`0c<c<02P0c<c<00`0000006ATI01TI6@0@01TI6Al000001?oo
ool00`00003oooooooooo`0Aooooo`03o`000?oooooooooo00oooooo00Go05_Do`1Je?lJHmSo8fKI
oci_f@02o`0000;oH7[F0_m[O]@2ogF2dP;oOhG@0_n8RLh2oi2<b`?oV8o90_nNT/L2ojBDa@04ojBG
aonZVLGoZYW5ojZIa@?o[i_400?o/ig2okBQa?ndXL@00onhX/<4okjX``05ol6Y`_o3[LCo`jg4ol>]
a?o6[/<00oo8/lD01?o:]<CocKW6olfia_o@_/T3om:na`;oeLC:00?oe/C9omS:booHb//00_oKd<h0
0ooKclgog]K?omkFc`02on3LdP04on7SeOoQh=?oh^KFon;VeP;ohNcH00?oh?7Jomkeg?oOlM`00_oL
mMh01?oImn3oeOWRom7ji?o=n^H2olWjj006olKijoo2mngo`_O]okoel?o2l_3o_nob0_nmk?<01?nk
jOCo_>KcokWRm?nih_@2ok[Ol`04okOLl_nefO;o]MWbokGFl@;o/m?`00?o/m7`ok;?konbcnl00_na
cNh01?nabngo/<W]ok39kOn_b>`2ojk7k003ojk6jon]a>_o[LC[00?o[L?[00Go[L?Zojc2j_n/`^[o
[<7Yoj_1j@04oj_0j@04o`000?n[_nWoZkoYoj^oj@;oZ[oX2OnZ_^P3ojVnj005ojVmj?oooooooooo
ooooool000004?ooool000Wooooo00@00000oooooooooooooooo100c<c<00`000000C4a<04a<C009
04a<C0030000001VIVH0IVIV00P0IVIV0P00000@07moO`<00000502IVIT3000000h0Ogmo00<00000
o`00001VIVH02P1VIVH00`000000C4a<04a<C00904a<C0030000000c<c<0<c<c00X0<c<c00<00000
01TI6@0I6AT0400I6AT00ol0000000000000000L000000Cooooo00<00000ooooooooool04?ooool0
0ol0003oooooooooo`0@ooooo`;o05?=0ol000001?l^Jm[oBG?IoeIhfOmFN=T2of9me`;oMH;B0_mo
QM03ohR9cP;oT8c;0_nHSlT00onNT/OoWYC:ojBGa`03ojBGa`;oZYW50_n_Vl@00on`WlKo]:74okBQ
a002okBQa003okRR`onjY/Go^ZK500?o_ZS30oo3[L@01Oo6//Oob;?5olRcaOo8/lGobkS800?ocKW6
0_o@_/T01?oB_/OoeLC:omG4b_oEa<X3omS:b`;ofm3>00CogMOAomkFcooPg=;oh=cB0_oQhmD01OoQ
jMOoh^KFon7/f?oQk=Soh?7J00;og_GL00Wof_SNomOjgooBo>7od_cQolglh_o9o>Coa?cWol7kjOo6
nN/00_o2mnd01_nomO3o_O;bok__m?nkkoCo_Nccok_Ym0;o^>Ge00Co^N;dokONm?nefo?o]M_c0_ne
fO82ok?ElP04ok?Cl?nbd?3o/]3`ok;?k`;o/<c^0_n`bnh01?n`bNgo[lS/ojo8k?n^an`2ojg5j`03
ojg4jon/`n_o[<?Z00?o[<?Z00?o[<;Zojc1jOn/`NT00_n[`NT01On[`>WoZkoYoj^ojOl0003oZ[oY
00?oZ[oX2onZ_^P00onY_^Soooooooooo`03ooooo`03o`000?oooooooooo00kooooo0009ooooo`04
00000?ooooooooooooooo`D0<c<c00<0000004a<C01<C4`02@1<C4`00`000000IVIV06IVIP0906IV
IP8000004@1oOgl3000000d0VIVI1000000@07moO`030000001VIVH0IVIV00X0IVIV00<0000004a<
C01<C4`02@1<C4`00`000000<c<c03<c<`0:03<c<`030000000I6AT06ATI01406ATI7`000004oooo
o`0300000?oooooooooo013ooooo00?o0000ooooooooool03oooool3o`0000;o057=0_l>GmL2oc]`
f`;oEWSI00?oHWgGofn2e_m_P]H00_mjQ]@3ohF;d@;oSXk?0_nFTL`3oijDbP?oY9O700?oZYW5oj^M
b?n`WlH00on`WlH2okBQa003okJUaonjY/Go^ZK500;o^ZK500Co_ZS3ol2/a_o0[<Ko`jg40oo6//L0
1Oo8/lGobkS8ol^hb?o;^<SocKW600?od;k90ooEa<X2omS;c@03omS:booKd<kofm3>00;ogMOA00?o
gmkDon3Ld_oQhmD00_oQhmD02?oQjMOohNoJon7_f_oOm=_og?SMomkeg?oJn=koeo[O0_oBo>401?o=
o>;obOcTolClioo1nnT2okkik006ok_gkonim?;o^OCbokSam?nkkoCo^N_e0_ngioH01OnhiOGo]^7e
okCMm?ndgOCo]M_c00;o/mOc0_nceO82ok;Bl@04ok;@l?n`c^oo/<k_ok3<kP;o[l[^0_n_bNd01?n_
b>co[/K/ojk6k?n]aN/2ojg4j`;o[<?[0_n/`nX01?n/`^[o[<7Yojc1jOn[`NT3oj_0j@?oZkoY00?o
0000ojZojOnZ_nP02OnZ_^P:ooooo`03o`000?oooooooooo00gooooo0009ooooo`0400000?oooooo
ooooooooo`H0<c<c00<0000004a<C01<C4`02@1<C4`00`000000IVIV06IVIP0:06IVIP8000004P1o
Ogl=000001<0Ogmo00<0000006IVIP1VIVH02P1VIVH00`000000C4a<04a<C00904a<C0030000000c
<c<0<c<c00X0<c<c00<0000001TI6@0I6AT04@0I6ATP000000Cooooo00<00000ooooooooool04?oo
ool00ol0003oooooooooo`0<ooooo`?o00001?ooool01?l0DLgo05?>o`iOeolKIMT2oc]`f`03odUf
fomROMOoHWgG00;oKh;F0_mjQ]@3ohF;d@;oSXk?0_nFTL`3oijDbP03ojBGaonUV/_oZig800;oZig8
0on`WlH4okJUa`;o^ZK500Co_J_8ol2/a_o0[<Ko`:c61?o6//L01?o9^<[obkS8ol^hb?o;^<P3om2n
b@;odlG<00KoeLC:omS;cOoHblgof<_=om[Bd?oKd<h3omgGd@05omoNe?oQi]OohNKGon7SeOoQjML0
0_oQkmX01_oOm=_og?SMomchgOoGnmgod_gNolgng`;oaokP00?o`_gRok[kiongn^X00_nfn>h2okCf
l@03okWdl_nhlOCo]^kf00;o]N[g00Go]nOfokGSm_ndgoKo]=ofokCMm002ok?Im003ok?Glonbe?;o
/]Cb00;o/];a0_n`co001?n`c^oo[lc^ojo<k_n_b^h2ojk8k@;o[/O/00Co[/K/ojg5jon]aN_o[LC[
0_n/`n/3ojc2jPGoZl7Y00SoZl3Yoj^ojOn[_nWoZkoYojZojOnZ_nSo0000ojZoj0KoZ[kX3Oooool0
0ol0003oooooooooo`0=ooooo`002Oooool01000003oooooooooooooool703<c<`030000001<C4`0
C4a<00T0C4a<00?o000006IVIP1VIVH02`1VIVH00ol00000Ogmo07moO`0]07moO`0300000?l00000
IVIV00X0IVIV0P00000;04a<C0030000000c<c<0<c<c00/0<c<c00?o000001TI6@0I6AT04@0I6ATP
000000Cooooo00<00000ooooooooool04?ooool00ol0003oooooooooo`09ooooo`?o00002?ooool0
1?l0@;So05?>o`1GdOlKIMT2oc]`f`03odUffomHO=_oF7cK00;oKh;F0_mjQ]@2ohF;d@;oSXk?0_nF
TL`2oijDbP04oifHc_nUV/_oYI[;ojFJb`?oZig800?o/9o6ok6SbOnaXlT00onfYLL01OnjY/Go_J_8
okf[b?nmZlSo`:c600;o`k790oo6//L2olVhbP04ol^hb?o>_/_oc[k;om2nb@?odlG<0_oFc<l00ooH
blgof];@om[Bd002omgId`04omgGdOoOg]CogmkDon7Ve`;oh>cI00?ogo;Kon7_f_oOm=/00_oLn=d0
0ooGnmgod_gNolgng`02olOnh005ol;mh_nan^?o[oWWojkhjonfn>h00_ndm_401_ncloCo/^ofok;/
monbk?Oo]N[gok?Vm`;o/^7g00Co]=ofok;KmOnbfoGo/mWd0_nae_<00onbe?;o/=7aok3Al@02ok3?
l0;o[lg_00Co[lc^ojk9k_n^bNko[/S]1?n]a^`01On]aN_o[<C[ojc4jon/`n_o[<;Z00?oZl7Z00?o
Zl7Yoj_0jOn[`>T00_n[`>T2oj^oj@CoZ[oY00Co0000ojZnj?nZ_^SoZ[kX4Oooool00ol0003ooooo
ooooo`0=ooooo`002Oooool01000003oooooooooooooool803<c<`030000001<C4`0C4a<00T0C4a<
0P00000<06IVIP<00000:P1oOgl2000000`0IVIV00<0000004a<C01<C4`02P1<C4`00`000000<c<c
03<c<`0<03<c<`030000000I6AT06ATI01406ATI80000004ooooo`0300000?oooooooooo013ooooo
00?o0000ooooooooool01_ooool3o`0000gooooo00Co03ffo`1GdOlYK=co:FcL0_ljLmh00omHO=_o
Ih;JofN2fP02ogB8f0;oPHgF0_n<TM<2oiFDd0CoWIS>0onUV//00on[WLSo[:7<ok6Sb@03ok6Sb@03
okJUaonhZ/_o^:[;00?o_J_81?o3/LT01?o6//OobKS:olVhb_o9^<X3oljnb`;odLG?00KodlG<omK<
cooFc<ooe/c?omWDdooJd]02omgId`;og^7G00?ogmkDon7VeooPk=T00_oPk=T00ooOl]_og?SLomSk
g@02om;mg@0:olcngOnno]go__kMokWmg_ndnn3o/O[Sojoiion^n>_o[OK_ojkdl`;o[_7f0_n^kOP0
1Onbk?Oo/NOhok3Sn?n`hoSo/^7g00;o/Mgf00Co/]_eok7Gm?naeoCo/MKc0_n`d_800on`dO7o[lk`
ojo>l002ojo=k`;o[/_^00?o[/W^ojg7kOn]and00on]a^`3ojc4j`;o[<?[0_n/`^X00on[`N[oZl7Y
oj_1j@02oj_0j@?oZkoY0onZ_nT3ojZnj003o`000?oooooooooo017ooooo00?o0000ooooooooool0
3Oooool000Wooooo00@00000oooooooooooooooo2@0c<c<00`000000C4a<04a<C00:04a<C0800000
3@1VIVH4000002@0Ogmo0P00000=06IVIP030000001<C4`0C4a<00X0C4a<00<0000003<c<`0c<c<0
300c<c<00`0000006ATI01TI6@0A01TI6B4000001?ooool00`00003oooooooooo`0@ooooo`03o`00
0?oooooooooo00?ooooo0ol0000Aooooo`;o04c80_lYK=`00oljLmkoC7_Oodakg`02ofN2fP;oM8SH
0_n1SMH2ohbAd`;oUIC@0onMV<h2ojFJb`04ojFNcon/XLco[:7<ojbQc0;o/J?900?o/jS=okRZbonh
Z//00_nhZ//00onmZlSo_k7<oknac002ol>ab@04olJhcOo9^<[obKS:olVhbP;oc;k>00Coc[k;om75
cooAaLoodLG?0ooFc<l2omWDd`03om_LeooMfM?og^7G00;og^7G00OognWJomk`g?oNl=coh>cIomob
fooLn=cof?_M00;od_gM00[oc?kMok;kf?n/nMSoYoSJojGgg_nTmn?oY?KXojGekOnVlo;oZ?7f0onY
k_P01_n^kOSo[^WiojkTnOn^i?Wo/>?hok3Nm`;o[m[f00Co/=WeojoEm?n_eOCo/=Cc0_n_d?800on_
co7o[/g`ojk=l002ojk<k`;o[/_^00?o[LS^ojg7kOn]and00_n]a^`2ojg5k004ojc4jon/`n_o[<?[
ojc3j`;oZl;Z0_n[`NX00on[`NWoZl3Yoj_0j@02oj_0j@04oj^ojOnZ_nWoZ[oYojZoj@Gooooo00?o
0000ooooooooool04?ooool00ol0003oooooooooo`0=ooooo`002Oooool01000003ooooooooooooo
ool:03<c<`03o`0000000000C4a<00/0C4a<00?o00000000001VIVH03P1VIVH01?l0000000000000
0000000M07moO`<000003P1VIVH00`000000C4a<04a<C00:04a<C0030000000c<c<0<c<c00`0<c<c
00<0000001TI6@0I6AT04@0I6ATR000000Cooooo00<00000ooooooooool03oooool01?l0003ooooo
ooooooooool3o`0001Gooooo00?o04c8o`1Cc_l0Dlh00_ljLmh00om<NmooGH?Ooef3g`02ogB8f0;o
PHgF0on<TM<2oiFDd003oifHc_nMW=;oYIk?00?oYIk?0_n/XL`01?naXlWo/jS=ok>XcOncZ<d2okRZ
b`05ok^`cono/Lco_k7<oknac?o3/LT00oo6^<d01?o9^<[oc;k>olbnc_o<_/h3om75c`;oe<gB00Go
e/c?omWDdooIe=?ofMCCom_Le`02omgTfP04omkQeooOjM[og_3Lomk`g0;og?KM00gof?_Nom;ngOo:
omco`_kJok[mf?nbnmSoV?;CoiKbeonFl]coV?;Soi_cjOnNl_3oXO7d00;oY>kh0_nYk_P01On[j_Wo
ZnKjoj_Vn_n^i?Wo[^3h00;o[]cg00Co[m[fojkFmOn^e_Go[mGd0_n^d_<01?n_d?;o[/k`ojk>l?n^
cO02ojg:k`;o[LW^00?o[LS^ojg6kOn]a^d00_n]a^`2ojc4k0;o[<C[00Go[<?[oj_2j_n[`^[oZl;Z
oj_1jP04oj_0j@GoZ[oY2?ooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo00gooooo
0009ooooo`0400000?ooooooooooooooo``0<c<c00<0000004a<C01<C4`02`1<C4`00`000000IVIV
06IVIP0@06IVIP<000005`1oOgl200000003o`00001VIVH0IVIV00d0IVIV00<00000o`00001<C4`0
2`1<C4`00`00003o000003<c<`0<03<c<`03o`00000I6AT06ATI01806ATI00?o0000000000000000
7`000004ooooo`0300000?oooooooooo00oooooo1?l0000Iooooo`06o`0YUol0Dlko05gEo`1MeOlW
Kmoo>gWR0_mMPml2off9g@;oNhoK0_n8U=T2oi>HeP?oWIcB0onUW/l00on/XLco[JKAojfVd@03ok>X
c@05okRZbonk/<oo^k3?ok^`cono/L`00_o2]m03olJhc@;obKoA00Coc;k>olo6d_o?a];odLG?0ooD
cM82omOFe`04omWDdooKg=OofmcGomgTfP;ogNcM00OofoCOomk`g?oLm]gog?KMomSkg_oBo]gob_oL
00;oZoWB00SoW??AoiSbdon6jmGoR^gMoho_iOnDl>goVNocoik]m`;oX^_j00?oY^_jojSVnonXi_/0
0_nYh_X01?n/hOWo[=chojcLn?n^g?L2ojgGmP04ojkFmOn^do?o[]?cojkBl`;o[Loa00Co[/k`ojg;
kon]bnoo[L[_0_n]b>h2ojg7k@03ojg6kOn/aNco[<G/00;o[<C/1?n[`n/00on[`^[oZl7Zoj_1jP02
oj_1jP?oZl3Y00?oZ[oYooooooooool02_ooool00ol0003oooooooooo`0?ooooo`03o`000?oooooo
oooo00gooooo0009ooooo`0400000?ooooooooooooooo`d0<c<c00<0000004a<C01<C4`02`1<C4`2
000001<0IVIV0`00000=07moO`L00000401VIVH2000000d0C4a<00<0000003<c<`0c<c<03@0c<c<0
0`0000006ATI01TI6@0B01TI6B8000001?ooool00`00003oooooooooo`0?ooooo`;o00007Oooool0
1Ol0=:Wo05gEoa1Yg?l@JMco>gWR00;oD8?T0_m]RMd2og^?f`;oR9CI0_nCV=H3oifLdP03ojFNconU
Y=Co[JKA00?o[JKA00?o/jS=okF^d_ne[]800onk/<l4ol:gd004olJhcOo9_m7obKoAolc7eP?oclKB
0_oBcmH00ooDcM;oemKGomOFe`02omWNf`03om_LeooMi=[ogNcM00;ogNcM00KofoCOomOjgooAoMko
dOgNolSng?ndo=D2oj_idP07ohGYbOmeh/coNnGFoh;Yh?n9k>WoTNgaoiO/m`02oicZnP03oj;[n_nT
io_oY^;k00;oY^;k00GoZN;joj[MnOnZgOWo[=chojcHm`02ojcDm@;o[M?d00Co[]?cojg?l_n]co;o
[Loa0_n]c?001?n]bnoo[<W^ojc9k_n]b>h2ojc6k@?o[<G/0_n/a>/00on[`n_oZl;[oj_2jP03oj_2
jP03oj_1j_n[`NWoZl7Y00?oZl3Y3oooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo
00cooooo0009ooooo`0400000?ooooooooooooooo`h0<c<c00?o000004a<C01<C4`0301<C4`20000
01@0IVIV3@00000F06IVIP030000001<C4`0C4a<00`0C4a<00<0000003<c<`0c<c<03@0c<c<00`00
00006ATI01TI6@0B01TI6B<000001?ooool00`00003oooooooooo`0Aooooo`03o`000?oooooooooo
01cooooo00Go03^_oa1Yg?lVM^?o9WKSoe23i002of>;h`;oM9;R0_n4V=l3oi6Mg0;oW:7H0onUY=@2
ojfVd@03ojj]e_ne[];o]JkB00;o]JkB00?o^k3?okfgdonm]m<00_o2]m02olBoe@05olVodOo<amKo
c<OFolc7e_o?a]800_oBcmH2omCHf`05omOFeooIg]_ofMkKomWNfooJj=h00_oIl>400ooMk=gofoCO
omOjg`02om7mgP04olSng?nGlLWoUo79oho]a`;oJ]c>00GoM>;JogkWiOn7jNooT>[foiOYnP02oicV
o003oj7Vo?nTh_coY]kk00;oY]kk00CoZ=kjojWInOnYfOWoZ]Wh0_n[eOH01?n/e?Go[=7cojcAlon/
d?<4ojc=l@04ojg<l?n/bNoo[<W_ojc9kP;o[<O]00?o[<K]oj_5k?n[aN`00_n[a>`00on/a>_oZl;[
oj_2j`02oj_2j`;oZl;Z00?oZl7Zoj_1jOn[`NT05?ooool00ol0003oooooooooo`0>ooooo`03o`00
0?oooooooooo00cooooo0009ooooo`0500000?ooooooooooooooo`0000003P0c<c<2000000h0C4a<
0`00000b06IVIP0300000?l00000C4a<00d0C4a<00<0000003<c<`0c<c<03@0c<c<00`0000006ATI
01TI6@0B01TI6B@000001?ooool00`00003oooooooooo`0Booooo`03o`000?oooooooooo01cooooo
00?o04Jio`1PeOlVM^<00_lnP^L2of>;h`;oM9;R0_n4V=l3oi6Mg0;oW:7H00?oYJCDojFZf_nUZ]X0
0on^[MH2okF^dP05okNff?nm]m?o_KOCokfgdono_mT00oo4_mD01_o7b=[oc<OFolc7e_o<amKoc]3K
om;?eP?oe=SK0_oFh]l01?oIg]_of^SNomW`hOoIl>42omKghP04om3lh_o7o]ko^ogJojoje0;oMn2j
00CoFM;5ofKKgOmehN[oPNGc0_n<iOX01OnAio[oV>GloigRoOnMh_goX>;l00;oXmkk0_nVg_/2ojOJ
n@04ojWInOnYeOOoZMGgoj_EmP;oZm7d00Co[=7coj_>l_n[c_;o[<ga0_n[bo000on/b^ooZlS^oj_8
kP02ojc7kP04ojc7kOn[aNgoZlG]oj_5k0CoZl?[00?oZl;[oj_1j_n[`NX00on[`NXHooooo`03o`00
0?oooooooooo00gooooo00?o0000ooooooooool03?ooool000Wooooo00H00000oooooooooooooooo
01TI6@00000?03<c<`8000003`1<C4`2000002h0IVIV0P00000?04a<C0030000000c<c<0<c<c00d0
<c<c00<0000001TI6@0I6AT04`0I6ATT000000Cooooo00<00000ooooooooool04oooool00ol0003o
ooooooooo`0Looooo`03o`16^Ol0H=Go3FoO00;o?X;W0_mFSNT01_m[U^WoQ9SOohBHgon4V=ooTIgL
ohjSh`?oVjOO0onUZ]X00on^[MKo[kCLojndg003okNff005okfgdono_mWo_koIoknofOo4_mD00oo7
b=X00oo<amKoc]3Kolk@f`02om3Jh003omCHfooFh]ooe^;O00;oe^_S00WodoCVomW`hOoFmn;oe_OR
om3lh_o7o]koV_;<ohc[a?mMcj`00_mKe=X00om/gNSoNn;cohOSnP02oi3Ro@05oiCToOnJhOgoW]gm
oikMoOnQgO`00_nSfO/2ojGJnP;oYmKh00CoZ=KgojSBm_nXd_KoZM;e0_nZc_<3oj_>lP?oZl_`0_n[
b>l00on[b>koZlK]oj_6k@03oj_5k@;oZlC/0on[`n/2oj_2j`03oj_1j_oooooooooo01[ooooo00?o
0000ooooooooool03Oooool00ol0003oooooooooo`0<ooooo`002Oooool01000003ooooooooooooo
ool201TI6@030000000c<c<0<c<c00h0<c<c00<0000004a<C01<C4`03P1<C4`2000002T0IVIV0`00
000@04a<C0030000000c<c<0<c<c00d0<c<c00<0000001TI6@0I6AT04`0I6ATU000000Cooooo00<0
0000ooooooooool05?ooool2o`0001kooooo00Co05C6o`e_golXOnSo:7oX0_mFSNT00om[U^WoOYgV
ogjMiP03ohjSh`?oVjOO00?oYJ[JojFbh_n_]=`00on_]=`00ong]]So^;kNoknof@02oknof@04ol78
h?o7b=[oalSJolO8fP;obM;P00?oc]3Kom3Jh?o@f^000_oAiND00ooFh]ooe^_SomK[h`02om?diP05
olkji_o4oN?o^?cMojWhe?mag;H00_mMe>H01Om_fo;oO]kjohWOoOn9gogoSN7m00;oU=kn00CoUmon
oicLoOnLg?goW]gm0_nRfO/01OnSfO_oYMKiojGFnOnUe_WoYmKh00;oYm;f00CoZ=;fojW?m?nYcoCo
Z/kc0_nZc?42oj[;l@04oj_;l?n[b>ooZlS_oj_8k`;oZlK^00?oZlK]oj_4k?n[a>`00on[a>`5oj_2
jaoooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0<ooooo`002Oooool01000003o
ooooooooooooool301TI6@8000003`0c<c<200000100C4a<0P0000000ol00000IVIV06IVIP0R06IV
IP800000401<C4`00`00003o00000000000?03<c<`03o`00000I6AT06ATI01<06ATI9P000004oooo
o`0300000?oooooooooo01Kooooo00?o0000ooooooooool07Oooool01?l0IMCo:7oXobQoj?m4SNd2
oejJk`;oOYgV0_n>Xn<2oi^Wg`04oiR_ionU/^;oYK;RojFbhP;o[kCL00Go[kgTokRng_nh_]ko^;kN
oknof@03ol78h006olO8f_o9d^3obM;PolWBh?o:g>Kod=[P0ooAiND01Oo?k^WoboOZol_gj_oCm>Ko
c_[V00;oXoOH00KoP>G0ofSFm?mif__oNM[kog_Ln_n7gOh2oi3Ko`04oi;Mo_nHf_goV=[moi[Ko@;o
W]Ol00?oX=Skoj?DnOnSe?T00_nTeOT2ojGAm`03ojKBmonWc_CoYlkd00;oZ<od00CoZLodojW<l_nY
c?;oZ/ca0onZbO02oj[7kP;oZ/K^00GoZlK^oj_4kOn[a>goZlC/oj[3k003oj_3j`03oj_2jooooooo
oooo02;ooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0<ooooo`002Oooool01000
003oooooooooooooool501TI6@030000000c<c<0<c<c00h0<c<c0P00000A04a<C0<000007`1VIVH0
0`00003o000004a<C00@04a<C0030000000c<c<0<c<c00l0<c<c00<0000001TI6@0I6AT0500I6ATV
000000Cooooo00<00000ooooooooool05oooool00ol0003oooooooooo`0Mooooo`04oe`00?l=N>;o
;H_]obf;k@;oGY[_0_meXnh3ohVZj`;oV:oW00?oYK;RojBkj_nT^nX00on__N@01Onh_]ko^LSVokW8
i_nib>Ko`LSP00?o`]?W00?obM;Pol[Li_o:g>H00_o9in`01_oAiNGocnkYol_gj_o;mn[o`O_XokCk
hP;oXoOH0_n5f?l01?n5fOooS]SoohkHoon?f_l2oiKGoP04oiOIo_nLeOcoW=GloigFo0;oX=?j0_nQ
e?T01OnSe?WoY=7gojCAmonTdOOoYM7g00;oY/ke00CoYlkdojS<l_nXc?;oZ<cb1?nYbO001?nZbO3o
Z/O_oj[7konZanh4oj[5k@03oj_4kOnZ`ncoZ/?/00;oZ/?/00?oZl?[ooooooooool09Oooool00ol0
003oooooooooo`0:ooooo`03o`000?oooooooooo00cooooo0009ooooo`0400000?oooooooooooooo
o`H06ATI00<0000003<c<`0c<c<03`0c<c<200000180C4a<1`00000A06IVIPL000004P1<C4`00`00
0000<c<c03<c<`0?03<c<`030000000I6AT06ATI01@06ATI9`000004ooooo`0300000?oooooooooo
01Sooooo00?o0000ooooooooool07_ooool01Ol0B:Wo;H_]obf;kOl]RngoC9_d00;oJJSf0_n1/O@3
oiBhk`?oY;_Z00Go[kgTojo8k?n_b>co[lS/okW8iP02okWCkP;o`]?W0_o2g^d00oo:g>KobNO/olWW
k002olKak`03okghk_n`nNSo/?WX00;oR>_?00CoQMKoohkDoon>e?ooS]Ko0_nEe?d00onEe_goV]?k
oi[Cn`02oi_Do004oicEo?nOd_WoWm;ioj3CnPCoXm3g0_nUcOD00onVc_GoYl_cojO;l`02ojO;l`04
ojS<l_nXbO7oZ<WaojW9l0CoZLO_00CoZ/O_oj[5kOnZaNgoZ/G]1OnZ`n`[ooooo`03o`000?oooooo
oooo00_ooooo00?o0000ooooooooool02oooool000Wooooo00@00000oooooooooooooooo1`0I6AT0
0ol00000<c<c03<c<`0@03<c<`030000001<C4`0C4a<01H0C4a<4@00000H04a<C0030000000c<c<0
<c<c00l0<c<c00<0000001TI6@0I6AT05@0I6ATW000000Cooooo00<00000ooooooooool06Oooool2
o`00023ooooo00Co05jmoa24iOl@Q>Go=9[b0_mYZ?H2oh6am003oiBhkon=`OSoSL7h00?oX<Gc0_n_
b>`2ojcCm005okWCk_nfgoCo]]odokKOm?o2g^d00_nojO82okObm007olKakonmn>ko/?WXok3ij?mX
fL7oT=7nohoCoP02oiKAo003oiGBoOnJd?_oV]3k00;oV]7k00GoV]?koik@nOnNd?WoW]3ioioAn@02
oj7>m`03oj;?monTc?GoY<ce00;oY<ge00CoYLgeojK;lonVbo?oYl_c0_nWb?43ojS9l@?oZLO_1?nY
aNh01?nZaNgoZ/C/oj[4k?nZ`n``ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool0
2oooool000Wooooo00@00000oooooooooooooooo1`0I6AT200000180<c<c0P00000l04a<C0030000
0?l0000000000140<c<c00<0000001TI6@0I6AT05@0I6ATX000000Cooooo00<00000ooooooooool0
6oooool00ol0003oooooooooo`0Pooooo`;o07OB0_mF[?T3ogBin`;oSL7h00GoX<Gcoi[@nonJd?_o
V]3kojcCm002ojGNn`;o]]od00Ko[nWioj;_monRkoOoX^ogokObm?nZmO02oiObi@04oiS<n_nGc__o
UlkkoiK?o0?oVlgi00?oV/kjoi[@nonNcOP00_nNcOP00onNcoWoXLcfoj7<mP02oj7=m`04oj7>monS
boCoXl_dojC<m@;oYLWc00?oY/[cojK8lOnVb?400onWb?42ojS6k`;oZ<O_00CoZLO_ojW5k_nYaNko
ZLG^1?nYa>d00onZa>coooooooooo`0aooooo`03o`000?oooooooooo00Wooooo00?o0000oooooooo
ool02oooool000Wooooo00@00000oooooooooooooooo2@0I6AT00`000000<c<c03<c<`0A03<c<`80
0000>01<C4`2000001<0<c<c00<0000001TI6@0I6AT05@0I6AT00ol0000000000000000V000000Co
oooo00<00000ooooooooool07?ooool00ol0003oooooooooo`0Rooooo`03o`23colmZ_Go?J[e00;o
H[cm0_n1bOh2oi[@n`;oS]So00?oYMkkoiWUo?nIiO`00_n5i_D2oj;_m`03oho]kOmfhmcoV/Wh00;o
VL_i00CoV<cjoic:monLb_OoVlch0_nNb_H2oik;m`03oik<n?nQb_GoXL[e00;oXL_f00CoXLcfoj?:
m?nSb_CoXl_d0_nUb?82ojG9lP04ojG9lonVao7oY/OaojK8l@CoYlK_00CoZ<K_ojS5k_nXaNkoZ<G^
0_nY`nd3ojW4kCSooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`0;ooooo`002Ooo
ool01000003oooooooooooooool:01TI6@8000004`0c<c<3000003<0C4a<0P00000C03<c<`800000
5`0I6ATZ000000Cooooo00<00000ooooooooool07Oooool00ol0003oooooooooo`0Uooooo`?oB;[f
00?oKlgnoeC8lomDb?<00_mkfo/01OmPe>go@/CCod;4dolU[kGoWLOe00;oVlSf00CoV/Whoig8mOnM
b?GoWLWf0_nOao@2oio8m@03oik:m_nQb?CoXLSd00;oXLWd00CoXL[eoj?8lonSb??oXlWc1?nTao80
0onUb?;oY/K`ojK6l003ojK7l@?oYlK_0_nXa>h3ojS5kP;oZ<?]00?oZL?]ooooooooool0>_ooool0
0ol0003oooooooooo`08ooooo`03o`000?oooooooooo00_ooooo0009ooooo`0400000?oooooooooo
ooooo``06ATI0P00000D03<c<`04o`00000000000000000002`0C4a<0`00000D03<c<`030000000I
6AT06ATI01H06ATI:`000004ooooo`0300000?oooooooooo01kooooo0_l0000^ooooo`03oik6m?nP
a?;oX<Cb00;oWlGc00?oW/Odoj75l_nQaO800_nPa_<00onOaoCoX/Kboj;6lP02oj77l`04oj78m?nS
a_;oXlKboj?7lP;oY<Ga0_nTa_400onTao;oYLG`ojG5l002ojG6l004ojK6l?nVaNooY/G_ojO5k`Co
YlC^00?oZ<C^ojS3kOnX`nd00onX`ndoooooo`03o`000?oooooooooo00Oooooo00?o0000oooooooo
ool02oooool000Wooooo00@00000oooooooooooooooo3P0I6AT2000001H0<c<c0`00000X04a<C003
0000000c<c<0<c<c01@0<c<c00?o000001TI6@0I6AT05P0I6AT/000000Cooooo00<00000oooooooo
ool08?ooool00ol0003oooooooooo`0/ooooo`03oj34l_nR`o3oX/?`00;oX/Ca00?oXLGboj?4lOnS
a?400_nRaO401?nRa_;oXlC`oj?4l?nSaO42ojC4l0;oY<G`00?oY<GaojG4konUa>l00_nUaNl00onU
aO3oY/C^ojK4kP02ojK4k`04ojK5konW`nkoYl?^ojO4kP;oZ<;]0onX`ne4ooooo`03o`000?oooooo
oooo00Oooooo00?o0000ooooooooool02_ooool000Wooooo00@00000oooooooooooooooo400I6AT0
0`000000<c<c03<c<`0F03<c<`<000008P1<C4`3000001H0<c<c00<0000001TI6@0I6AT05P0I6AT]
000000Cooooo00<00000ooooooooool08Oooool00ol0003oooooooooo`0/ooooo`03oj;3l?nT`noo
Y<?_00;oXl?`00?oXlCaojC3konT`nl00_nTa?001?nSa?3oYL?_ojG3konTa?02ojK3kP;oYL?_00?o
YLC_ojK3k_nV`nh00_nV`nh00onVa>koYl?]ojO3k@02ojO3k@04ojO3k_nX`^goZ<;]ojS2kDWooooo
00?o0000ooooooooool01_ooool00ol0003oooooooooo`0:ooooo`002Oooool01000003ooooooooo
oooooolA01TI6@03o`00000c<c<0<c<c01P0<c<c0`00000L04a<C0<00000600c<c<00`0000006ATI
01TI6@0G01TI6Bd000001?ooool00`00003oooooooooo`0Rooooo`03o`000?oooooooooo02gooooo
00GoY<?_ojG2k_nU`^koY<;_ojC3k`02ojG2kP03ojG3k_nV`^goY/;]00;oY/;^00?oY/?^ojK2kOnV
`^d00_nV`^d00onV`nkoYl;]ojO2k@02ojO2k@04ojO3kOnW`^coYl;/ojS2k4gooooo00?o0000oooo
ooooool01_ooool00ol0003oooooooooo`0:ooooo`002Oooool01000003ooooooooooooooolB01TI
6@8000006`0c<c<00ol00000000000000005000000d0C4a<1`00000H03<c<`0300000?l000000000
01T06ATI;P000004ooooo`0300000?oooooooooo02?ooooo00?o0000ooooooooool0;Oooool01?nU
`^koY/7]ojK1kOnU`^d2ojK1k0;oY/7]00GoY/;]ojO1k?nW`NcoY/7]ojK2k@04ojO1k003ojO2kOnW
`NcoYl7/00;oYl7/00?oYl;/ooooooooool0C_ooool00ol0003oooooooooo`05ooooo`03o`000?oo
oooooooo00[ooooo0009ooooo`0400000?oooooooooooooooa@06ATI0P00000Q03<c<`d000007P0c
<c<00`0000006ATI01TI6@0I01TI6Bl000001?ooool00`00003oooooooooo`0Tooooo`;o0000;_oo
ool01?nV`NgoYl3/ojO0k?nV`N`2ojO0k0?oYl7/0_nW`>/3ojO1k0;oZ<3[0_nW`NaEooooo`03o`00
0?oooooooooo00Cooooo00?o0000ooooooooool02_ooool000Wooooo00@00000oooooooooooooooo
5P0I6AT2000004P0<c<c0P00000K01TI6C0000001?ooool00`00003oooooooooo`0Vooooo`03o`00
0?oooooooooo02cooooo00CoYl3/ojO0jonW`>_oYl3/0_nW_n/3ojO0j`;oZ;o[0onX`>]Hooooo`03
o`000?oooooooooo00Cooooo00?o0000ooooooooool02_ooool000Wooooo00@00000oooooooooooo
oooo600I6AT2000004@0<c<c0P00000L01TI6@03o`0000000000000002h000001?ooool00`00003o
ooooooooo`0Wooooo`03o`000?oooooooooo02gooooo0_nX_n/00onW_n_oZ;oZojRojP03ojRojego
oooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0:ooooo`002Oooool01000003ooooo
oooooooooolJ01TI6@030000000c<c<0<c<c03l0<c<c0P00000M01TI6C8000001?ooool00`00003o
ooooooooo`0Xooooo`03o`000?oooooooooo02gooooo0onX_nYRooooo`03o`000?oooooooooo00?o
oooo00?o0000ooooooooool02Oooool000Wooooo00@00000oooooooooooooooo6`0I6AT3000003d0
<c<c00<0000001TI6@0I6AT0700I6ATc000000Cooooo00<00000ooooooooool0:Oooool2o`0002go
oooo00?o0000ooooooooool0Hoooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Wo
oooo0009ooooo`0400000?oooooooooooooooah06ATI0`00000h03<c<`8000007P0I6ATd000000Co
oooo00<00000ooooooooool0:oooool00ol0003oooooooooo`0Zooooo`03o`000?oooooooooo06?o
oooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`09ooooo`002Oooool01@00003ooooo
ooooooooool0000002006ATI00Co00000000000000000000<00c<c<01000003o000000000000000O
01TI6@03o`00000000000000038000001?ooool00`00003oooooooooo`0/ooooo`03o`000?oooooo
oooo02Wooooo00?o0000ooooooooool0I?ooool01Ol0003ooooooooooooooooo000000_ooooo0009
ooooo`0400000?ooooooooooooooo`8000008`0I6AT4000002T0<c<c0`00000R01TI6CH000001?oo
ool00`00003oooooooooo`0]ooooo`03o`000?oooooooooo02Sooooo00?o0000ooooooooool0IOoo
ool01?l0003oooooooooool0000;ooooo`002Oooool01000003oooooooooooooool3000002H06ATI
0`00000R03<c<`@000008`0I6ATh000000Cooooo00<00000ooooooooool0;_ooool2o`0002Sooooo
00?o0000ooooooooool0I_ooool00ol0003oooooo`00000;ooooo`002Oooool01000003ooooooooo
ooooool300000003o`0000000000000002H06ATI1000000J03<c<`0400000?l000000000000002D0
6ATI>P000004ooooo`0300000?oooooooooo033ooooo00?o0000ooooooooool09Oooool00ol0003o
ooooooooo`1Vooooo`03o`000?oooooo000000_ooooo0009ooooo`0400000?ooooooooooooooo`L0
0000:@0I6AT:000000H0<c<c2P00000X01TI6C/000001?ooool00`00003oooooooooo`0aooooo`03
o`000?oooooooooo02Cooooo00?o0000ooooooooool0Ioooool00ol0003oooooo`00000:ooooo`00
2Oooool01000003oooooooooooooool8000003806ATI1P00000a01TI6C`000001?ooool00`00003o
ooooooooo`0booooo`03o`000?oooooooooo02?ooooo00?o0000ooooooooool0J?ooool2o`0000[o
oooo0009ooooo`0400000?ooooooooooooooo`T00000I`0I6ATm000000Cooooo00<00000oooooooo
ool0<oooool2o`0002?ooooo00?o0000ooooooooool0Ioooool3o`0000[ooooo0009ooooo`040000
0?ooooooooooooooo`T0000000?o0000000000000000HP0I6ATo000000Cooooo00<00000oooooooo
ool0=Oooool00ol0003oooooooooo`0Pooooo`03o`000?oooooooooo06?ooooo1?l0000=ooooo`00
2Oooool01000003oooooooooooooool>000005h06ATI@@000004ooooo`0300000?oooooooooo03Ko
oooo00?o0000ooooooooool07oooool00ol0003oooooooooo`1Pooooo`?o00004Oooool000Wooooo
00@00000oooooooooooooooo4000001K01TI6D8000001?ooool00`00003oooooooooo`0gooooo`03
o`000?oooooooooo01kooooo00?o0000ooooooooool0G?ooool4o`0001Cooooo0009ooooo`040000
0?oooooooooooooooa00000000?o000001TI6@0I6AT0EP0I6AT00`00003o000000000011000000Co
oooo00<00000ooooooooool0>?ooool2o`0001kooooo00?o0000ooooooooool0F?ooool4o`0001So
oooo0009ooooo`0400000?oooooooooooooooa<00000E00I6AU6000000Cooooo00<00000oooooooo
ool0>_ooool00ol0003oooooooooo`0Kooooo`03o`000?oooooooooo05Cooooo1?l0000Looooo`00
2Oooool01000003ooooooooooooooolD000005406ATIB0000004ooooo`0300000?oooooooooo03_o
oooo00?o0000ooooooooool06_ooool00ol0003oooooooooo`1Aooooo`?o00008?ooool000Wooooo
00@00000oooooooooooooooo5`00001=01TI6DT000001?ooool00`00003oooooooooo`0looooo`03
o`000?oooooooooo01Wooooo00?o0000ooooooooool0COooool4o`0002?ooooo0009ooooo`040000
0?oooooooooooooooaL0000000Co00000000000000000000A@0I6AT300000003o`00000000000000
04L000001?ooool00`00003oooooooooo`0mooooo`;o00006Oooool00ol0003oooooooooo`19oooo
o`Co00009oooool000Wooooo00@00000oooooooooooooooo7@00001101TI6Dl000001?ooool00`00
003oooooooooo`0oooooo`03o`000?oooooooooo01Kooooo00?o0000ooooooooool0AOooool4o`00
02_ooooo0009ooooo`0400000?oooooooooooooooal00000?@0I6AUA000000Cooooo00<00000oooo
ooooool0@?ooool00ol0003oooooooooo`0Dooooo`03o`000?oooooooooo04?ooooo0ol0000_oooo
o`002Oooool01000003ooooooooooooooolO00000003o`0000000000000003H06ATIE@000004oooo
o`0300000?oooooooooo047ooooo00?o0000ooooooooool04oooool00ol0003oooooooooo`0ooooo
o`Co0000<_ooool000Wooooo00@00000oooooooooooooooo9@00000`01TI6EP000001?ooool00`00
003oooooooooo`12ooooo`;o00004oooool00ol0003oooooooooo`0kooooo`Co0000=_ooool000Wo
oooo00@00000oooooooooooooooo;000000V01TI6E/000001?ooool00`00003oooooooooo`14oooo
o`03o`000?oooooooooo013ooooo00?o0000ooooooooool0=oooool4o`0003[ooooo0009ooooo`04
00000?ooooooooooooooobl000007@0I6AUQ000000Cooooo00<00000ooooooooool0AOooool00ol0
003oooooooooo`0?ooooo`03o`000?oooooooooo03?ooooo1?l0000nooooo`002Oooool01000003o
ooooooooooooool_00000003o`0000000000000000P000002P0I6AT800000003o`00000000000000
05h000001?ooool00`00003oooooooooo`16ooooo`03o`000?oooooooooo00kooooo00?o0000oooo
ooooool0<?ooool3o`0004;ooooo0009ooooo`0400000?ooooooooooooooojd000001?ooool00`00
003oooooooooo`17ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool0;?ooool4o`00
04Gooooo0009ooooo`0400000?ooooooooooooooojd000001?ooool00`00003oooooooooo`18oooo
o`;o00003Oooool00ol0003oooooooooo`0Xooooo`Co0000BOooool000Wooooo00@00000oooooooo
oooooooo[@000004ooooo`0300000?oooooooooo04[ooooo00?o0000ooooooooool02_ooool00ol0
003oooooooooo`0Tooooo`Co0000COooool000Wooooo00@00000oooooooooooooooo[@000004oooo
o`0300000?oooooooooo04_ooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`0Qoooo
o`?o0000DOooool000Wooooo00@00000oooooooooooooooo[@000004ooooo`0300000?oooooooooo
04cooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`0Mooooo`Co0000E?ooool000Wo
oooo00@00000oooooooooooooooo[@000004ooooo`0300000?oooooooooo04gooooo0_l00008oooo
o`03o`000?oooooooooo01Wooooo1?l0001Hooooo`002Oooool01000003ooooooooooooooon]0000
00Cooooo00<00000ooooooooool0Coooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo
01Gooooo1?l0001Looooo`002Oooool01000003ooooooooooooooon]000000Cooooo00<00000oooo
ooooool0D?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo01;ooooo0ol0001Poooo
o`002Oooool01000003ooooooooooooooon]000000Cooooo00<00000ooooooooool0DOooool00ol0
003oooooooooo`03ooooo`03o`000?oooooooooo00kooooo1?l0001Sooooo`002Oooool01000003o
oooooooooooooon]000000Cooooo00<00000ooooooooool0D_ooool2o`0000?ooooo00?o0000oooo
ooooool02_ooool4o`0006Oooooo0009ooooo`0400000?ooooooooooooooojd000001?ooool00`00
003oooooooooo`1Dooooo`04o`000?ooooooooooo`0000Sooooo1?l0001[ooooo`002Oooool01000
003ooooooooooooooon]000000Cooooo00<00000ooooooooool0EOooool00ol0003oooooo`000005
ooooo`?o0000Koooool000Wooooo00@00000oooooooooooooooo[@000004ooooo`0300000?oooooo
oooo05Kooooo0_l000000ooooooo0000o`000002o`0007;ooooo0009ooooo`0400000?oooooooooo
ooooojd000001?ooool00`00003oooooooooo`1Gooooo`;o0000M_ooool000Wooooo00@00000oooo
oooooooooooo[@000004ooooo`0300000?oooooooooo0<oooooo0009ooooo`0400000?oooooooooo
ooooojd000001?ooool00`00003oooooooooo`3?ooooo`002Oooool01000003ooooooooooooooon]
000000Cooooo00<00000ooooooooool0coooool000Wooooo00@00000oooooooooooooooo[@000004
ooooo`0300000?oooooooooo0<oooooo0009ooooo`0400000?ooooooooooooooojd000001?ooool0
0`00003oooooooooo`3?ooooo`002Oooool01000003ooooooooooooooon]000000Cooooo00<00000
ooooooooool0coooool000Wooooo00@00000oooooooooooooooo[@000004ooooo`0300000?oooooo
oooo0<oooooo0009ooooo`0400000?ooooooooooooooojd000001?ooool00`00003oooooooooo`3?
ooooo`002Oooool01000003ooooooooooooooon]000000Cooooo00<00000ooooooooool0coooool0
00Wooooo00@00000oooooooooooooooo[@000004ooooo`0300000?oooooooooo0<oooooo0009oooo
o`0400000?ooooooooooooooojd000001?ooool00`00003oooooooooo`3?ooooo`002Oooool01000
003ooooooooooooooon]000000Cooooo00<00000ooooooooool0coooool000Wooooo00@00000oooo
oooooooooooo[@000004ooooo`0300000?oooooooooo0<oooooo0009ooooo`0300000?oooooooooo
0;;ooooo00<00000ooooooooool0coooool000Wooooo00<00000ooooooooool0/_ooool00`00003o
ooooooooo`3?ooooo`002Oooool00`00003oooooooooo`2booooo`0300000?oooooooooo0<oooooo
0009oooookH00000dOooool00?ooooooTOooool00?ooooooTOooool00?ooooooTOooool00?oooooo
TOooool00?ooooooTOooool00?ooooooTOooool00?ooooooTOooool00?ooooooTOooool00?oooooo
TOooool00?ooooooTOooool00?ooooooTOooool00?ooooooTOooool00?ooooooTOooool00?oooooo
TOooool00?ooooooTOooool00?ooooooTOooool00?ooooooTOooool000Wooooo]_l0000AoooookKo
00002_ooool000Wooooo00?o0000ooooooooool04_ooool00ol00?ooooooooooo`0Qooooo`?o003o
NOooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo0;;ooooo00?o0000ooooooooool0
2?ooool000Wooooo00?o0000ooooooooool04?ooool2o`00obOooooo00?o003oooooooooool0M_oo
ool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo0;;ooooo00?o0000ooooooooool02?oo
ool000Wooooo00?o0000ooooooooool03_ooool2o`00ob[ooooo00?o003oooooooooool0MOooool0
0ol0003oooooooooo`0?ooooo`03o`000?oooooooooo0;;ooooo00?o0000ooooooooool02?ooool0
00Wooooo00?o0000ooooooooool03Oooool00ol00?ooooooooooo`0[ooooo`;o003oMOooool00ol0
003oooooooooo`0?ooooo`03o`000?oooooooooo0;;ooooo00?o0000ooooooooool02?ooool000Wo
oooo00?o0000ooooooooool03?ooool00ol00?ooooooooooo`0^ooooo`03o`00oooooooooooo07;o
oooo00?o0000ooooooooool03oooool00ol0003oooooooooo`2booooo`03o`000?oooooooooo00So
oooo0009ooooo`03o`000?oooooooooo00[ooooo0_l00?lbooooo`03o`00oooooooooooo077ooooo
00?o0000ooooooooool03oooool00ol0003oooooooooo`2booooo`03o`000?oooooooooo00Sooooo
0009ooooo`03o`000?oooooooooo00Wooooo00?o003oooooooooool0<oooool00ol00?oooooooooo
o`1`ooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool0/_ooool00ol0003ooooooooo
o`08ooooo`002Oooool00ol0003oooooooooo`08ooooo`03o`00oooooooooooo03Gooooo0_l00?m`
ooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool0/_ooool00ol0003oooooooooo`08
ooooo`002Oooool00ol0003oooooooooo`07ooooo`03o`00oooooooooooo03Sooooo00?o003ooooo
ooooool0KOooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo0;;ooooo00?o0000oooo
ooooool02?ooool000Wooooo00?o0000ooooooooool01_ooool00ol00?ooooooooooo`0jooooo`03
o`00oooooooooooo06cooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`2booooo`03
o`000?oooooooooo00Sooooo0009ooooo`03o`000?oooooooooo00Kooooo00?o003oooooooooool0
>_ooool00ol00?ooooooooooo`1/ooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool0
/_ooool00ol0003oooooooooo`08ooooo`002Oooool00ol0003oooooooooo`05ooooo`03o`00oooo
oooooooo03cooooo00?o003oooooooooool0Joooool00ol0003oooooooooo`0?ooooo`03o`000?oo
oooooooo0;;ooooo00?o0000ooooooooool02?ooool000Wooooo00?o0000ooooooooool01?ooool0
0ol00?ooooooooooo`0nooooo`03o`00oooooooooooo06[ooooo00?o0000ooooooooool03oooool0
0ol0003oooooooooo`2booooo`03o`000?oooooooooo00Sooooo0009ooooo`03o`000?oooooooooo
00?ooooo00?o003oooooooooool0?oooool00ol00?ooooooooooo`1Zooooo`03o`000?oooooooooo
00oooooo00?o0000ooooooooool0/_ooool00ol0003oooooooooo`08ooooo`002Oooool00ol0003o
ooooooooo`02ooooo`03o`00oooooooooooo047ooooo00?o003oooooooooool0JOooool00ol0003o
ooooooooo`0?ooooo`03o`000?oooooooooo0;;ooooo00?o0000ooooooooool02?ooool000Wooooo
00?o0000ooooooooool00_ooool00ol00?ooooooooooo`11ooooo`03o`00oooooooooooo06Wooooo
00?o0000ooooooooool03oooool00ol0003oooooooooo`2booooo`03o`000?oooooooooo00Sooooo
0009ooooo`05o`000?ooooooooooooooool00?l0AOooool00ol00?ooooooooooo`1Xooooo`03o`00
0?oooooooooo00oooooo00?o0000ooooooooool0/_ooool00ol0003oooooooooo`08ooooo`002Ooo
ool01Ol0003ooooooooooooooooo003o04Kooooo00?o003oooooooooool0Ioooool00ol0003ooooo
ooooo`0?ooooo`03o`000?oooooooooo0;;ooooo00?o0000ooooooooool02?ooool000Wooooo00Go
0000ooooooooooooooooo`00o`16ooooo`03o`00oooooooooooo06Oooooo00?o0000ooooooooool0
3oooool00ol0003oooooooooo`2booooo`03o`000?oooooooooo00Sooooo0009ooooo`04o`000?oo
ooooooooo`00odSooooo00?o003oooooooooool0I_ooool00ol0003oooooooooo`0?ooooo`03o`00
0?oooooooooo0;;ooooo00?o0000ooooooooool02?ooool000Wooooo00Co0000oooooooooooo003o
B?ooool00ol00?ooooooooooo`1Vooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool0
/_ooool00ol0003oooooooooo`08ooooo`002Oooool00ol0003oooooo`00o`1:ooooo`03o`00oooo
oooooooo06Gooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`2booooo`03o`000?oo
oooooooo00Sooooo0009ooooo`03o`000?l00?oooooo00?ooooo0_ooO`0;ooooo`;oogl0>?ooool0
0ol00?ooooooooooo`1Uooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool00oooool2
oomo00_ooooo0_ooO`2Pooooo`03o`000?oooooooooo00Sooooo0009ooooo`03o`000?oooooooooo
00;ooooo0oooO`0;ooooo`;oogl03?ooool2oomo02[ooooo00?o003oooooooooool0IOooool00ol0
003oooooooooo`0?ooooo`03o`000?oooooooooo00;ooooo0oooO`0;ooooo`;oogl03?ooool2oomo
09;ooooo00?o0000ooooooooool02?ooool000Wooooo00?o0000ooooooooool00_ooool2oomo01[o
oooo0_ooO`0Nooooo`Ko003o1oooool00ol00?ooooooooooo`1Tooooo`03o`000?oooooooooo00oo
oooo00?o0000ooooooooool00_ooool2oomo01[ooooo0_ooO`2Booooo`03o`000?oooooooooo00So
oooo0009ooooo`03o`000?oooooooooo03Wooooo1Ol00?l6ooooo`Wo003oIOooool00ol0003ooooo
ooooo`0?ooooo`03o`000?oooooooooo0;;ooooo00?o0000ooooooooool02?ooool000Wooooo00?o
0000ooooooooool0=_ooool3o`00oa;ooooo00?o003oooooool00?l00_l00?mRooooo`03o`000?oo
oooooooo00oooooo00?o0000ooooooooool0/_ooool00ol0003oooooooooo`08ooooo`002Oooool0
0ol0003oooooooooo`0cooooo`?o003o5_ooool01?l00?ooooooooooooooool3o`00oeoooooo00?o
0000ooooooooool03oooool00ol0003oooooooooo`2booooo`03o`000?oooooooooo00Sooooo0009
ooooo`03o`000?oooooooooo02oooooo10000?lIooooo`03o`00oooooooooooo00Cooooo0_l00?mM
ooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool0/_ooool00ol0003oooooooooo`08
ooooo`002Oooool00ol0003oooooooooo`0^ooooo`030000oooooooooooo01_ooooo00?o003ooooo
ooooool01_ooool00ol00?ooooooooooo`1Jooooo`03o`000?oooooooooo00oooooo00?o0000oooo
ooooool0/_ooool00ol0003oooooooooo`08ooooo`002Oooool00ol0003oooooooooo`0/ooooo`80
003o7_ooool00ol00?ooooooooooo`07ooooo`03o`00oooooooooooo05Wooooo00?o0000oooooooo
ool03oooool00ol0003oooooooooo`2booooo`03o`000?oooooooooo00Sooooo0009ooooo`03o`00
0?oooooooooo02_ooooo00<0003oooooooooool07oooool00ol00?ooooooooooo`07ooooo`;o003o
FOooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo0;;ooooo00?o0000ooooooooool0
2?ooool000Wooooo00?o0000ooooooooool0:_ooool00`000?ooooooooooo`0Pooooo`03o`00oooo
oooooooo00Wooooo0_l00?mGooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool0/_oo
ool00ol0003oooooooooo`08ooooo`002Oooool00ol0003oooooooooo`0Fooooo`;oogl01Oooool2
oomo00Wooooo00?o003o0000ooooool08_ooool00ol00?ooooooooooo`0;ooooo`03o`00oooooooo
oooo05Cooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`0Fooooo`;oogl01Oooool2
oomo09?ooooo00?o0000ooooooooool02?ooool000Wooooo00?o0000ooooooooool05_ooool2oomo
00Gooooo0_ooO`09ooooo`030000oooooooooooo02;ooooo00?o003oooooooooool03?ooool00ol0
0?ooooooooooo`1Cooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool05_ooool2oomo
00Gooooo0_ooO`2Cooooo`03o`000?oooooooooo00Sooooo0009ooooo`03o`000?oooooooooo02?o
oooo0ol000000oooool0003oooooo`0Tooooo`03o`00oooooooooooo00gooooo00?o003ooooooooo
ool0D_ooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo0;;ooooo00?o0000oooooooo
ool02?ooool000Wooooo00?o0000ooooooooool08_ooool5o`0002Kooooo00?o003oooooooooool0
3_ooool00ol00?ooooooooooo`1Aooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool0
/_ooool00ol0003oooooooooo`08ooooo`002Oooool00ol0003oooooooooo`0Looooo`;oogl01?oo
ool5o`0000[ooooo0_ooO`03ooooo`;oogl05Oooool00ol00?ooooooooooo`0?ooooo`03o`00oooo
oooooooo053ooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`0Looooo`;oogl01_oo
ool2oomo00_ooooo0_ooO`03ooooo`;oogl0N_ooool00ol0003oooooooooo`08ooooo`002Oooool0
0ol0003oooooooooo`0Looooo`;oogl01?ooool5o`0000[ooooo0_ooO`03ooooo`;oogl05Oooool0
0ol00?ooooooooooo`0@ooooo`03o`00oooooooooooo04oooooo00?o0000ooooooooool03oooool0
0ol0003oooooooooo`0Looooo`;oogl01_ooool2oomo00_ooooo0_ooO`03ooooo`;oogl0N_ooool0
0ol0003oooooooooo`08ooooo`002Oooool00ol0003oooooooooo`0Sooooo`?o00004Oooool2oomo
01Cooooo00?o003oooooooooool04Oooool00ol00?ooooooooooo`1>ooooo`03o`000?oooooooooo
00oooooo00?o0000ooooooooool0=oooool2oomo07Wooooo00?o0000ooooooooool02?ooool000Wo
oooo00?o0000ooooooooool08_ooool00`000?ooooooooooo`0>ooooo`;oogl00_ooool2oomo01Co
oooo00?o003oooooooooool04_ooool00ol00?ooooooooooo`1=ooooo`03o`000?oooooooooo00oo
oooo00?o0000ooooooooool0<oooool2oomo00;ooooo0_ooO`1iooooo`03o`000?oooooooooo00So
oooo0009ooooo`03o`000?oooooooooo027ooooo00<0003oooooooooool03oooool2oomo01Sooooo
00?o003oooooooooool04oooool00ol00?ooooooooooo`1<ooooo`03o`000?oooooooooo00oooooo
00?o0000ooooooooool0<oooool2oomo07gooooo00?o0000ooooooooool02?ooool000Wooooo00?o
0000ooooooooool08?ooool00`000?ooogl0oomo000Zooooo`03o`00oooooooooooo01Cooooo00?o
003oooooooooool0Boooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo027ooooo0_oo
O`2?ooooo`03o`000?oooooooooo00Sooooo0009ooooo`03o`000?oooooooooo01[ooooo0_ooO`04
ooooo`030000ooooO`3oogl002[ooooo00?o003oooooooooool05?ooool00ol00?ooooooooooo`1;
ooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool06_ooool2oomo00Gooooo0_ooO`2?
ooooo`03o`000?oooooooooo00Sooooo0009ooooo`03o`000?oooooooooo01[ooooo0_ooO`03oooo
o`030000oooooooooooo013ooooo0_ooO`0:ooooo`;oogl03Oooool00ol00?ooooooooooo`0Eoooo
o`03o`00oooooooooooo04[ooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`0Joooo
o`;oogl05_ooool2oomo00[ooooo0_ooO`1booooo`03o`000?oooooooooo00Sooooo0009ooooo`03
o`000?oooooooooo01oooooo00<0003oooooooooool04?ooool2oomo00[ooooo0_ooO`0<ooooo`03
o`00oooooooooooo01Kooooo00?o003oooooooooool0B_ooool00ol0003oooooooooo`0?ooooo`03
o`000?oooooooooo03;ooooo0_ooO`0:ooooo`;oogl0L_ooool00ol0003oooooooooo`08ooooo`00
2Oooool00ol0003oooooooooo`0Nooooo`030000oooooooooooo02_ooooo00?o003oooooooooool0
5oooool00ol00?ooooooooooo`19ooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool0
/_ooool00ol0003oooooooooo`08ooooo`002Oooool00ol0003oooooooooo`0Mooooo`030000oooo
oooooooo02cooooo00?o003oooooooooool05oooool00ol00?ooooooooooo`19ooooo`03o`000?oo
oooooooo00oooooo00?o0000ooooooooool0/_ooool00ol0003oooooooooo`08ooooo`002Oooool0
0ol0003oooooooooo`0Mooooo`030000oooooooooooo02cooooo00?o003oooooooooool05oooool0
0ol00?ooooooooooo`19ooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool0/_ooool0
0ol0003oooooooooo`08ooooo`002Oooool00ol0003oooooooooo`0Looooo`030000oooooooooooo
00Cooooo0_ooO`000oooooooogl0oomo000Sooooo`03o`00oooooooooooo01Wooooo00?o003ooooo
ooooool0B?ooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo02?ooooo0_ooO`000ooo
ooooogl0oomo002:ooooo`03o`000?oooooooooo00Sooooo0009ooooo`03o`000?oooooooooo01co
oooo00<0003oooooooooool01?ooool5oomo02?ooooo00?o003oooooooooool06Oooool00ol00?oo
ooooooooo`18ooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool08oooool5oomo08[o
oooo00?o0000ooooooooool02?ooool000Wooooo00?o0000o`00ooooool07?ooool00`000?oooooo
ooooo`06ooooo`;oogl05?ooool2oomo00kooooo00?o003oooooooooool06Oooool00ol00?oooooo
ooooo`18ooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool09Oooool2oomo01Cooooo
0_ooO`1eooooo`03o`000?oooooooooo00Sooooo0009ooooo`03o`000?l00?oooooo01_ooooo00<0
003oooooooooool07Oooool2oomo00gooooo00?o003oooooooooool06oooool00ol00?oooooooooo
o`17ooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool0>oooool2oomo07Gooooo00?o
0000ooooooooool02?ooool000Wooooo00?o0000o`00ooooool06oooool00`000?ooooooooooo`0/
ooooo`03o`00oooooooooooo01_ooooo00?o003oooooooooool0Aoooool00ol0003oooooooooo`0?
ooooo`03o`000?oooooooooo0;;ooooo00?o0000ooooooooool02?ooool000Wooooo00?o0000oooo
ool00?l06_ooool00`000?ooooooooooo`0/ooooo`03o`00oooooooooooo01gooooo00?o003ooooo
ooooool0A_ooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo0;;ooooo00?o0000oooo
ooooool02?ooool000Wooooo00?o0000ooooool00?l06_ooool010000?ooooooooooooooool2oomo
02Wooooo00?o003oooooooooool07Oooool00ol00?ooooooooooo`16ooooo`03o`000?oooooooooo
00oooooo00?o0000ooooooooool07_ooool2oomo09;ooooo00?o0000ooooooooool02?ooool000Wo
oooo00?o0000ooooool00?l06_ooool010000?ooooooooooooooool2oomo02Sooooo00?o003ooooo
ooooool07_ooool00ol00?ooooooooooo`16ooooo`03o`000?oooooooooo00oooooo00?o0000oooo
ooooool07_ooool2oomo09;ooooo00?o0000ooooooooool02?ooool000Wooooo00Co0000oooooooo
oooo003o6Oooool00`000?ooooooooooo`0[ooooo`03o`00oooooooooooo01oooooo00?o003ooooo
ooooool0AOooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo0;;ooooo00?o0000oooo
ooooool02?ooool000Wooooo00Go0000ooooooooooooooooo`00o`0Hooooo`030000oooooooooooo
02_ooooo00?o003oooooooooool07oooool00ol00?ooooooooooo`15ooooo`03o`000?oooooooooo
00oooooo00?o0000ooooooooool0/_ooool00ol0003oooooooooo`08ooooo`002Oooool00ol0003o
ooooooooo`02ooooo`03o`00oooooooooooo01Gooooo00<0003oooooooooool0:_ooool00ol00?oo
ooooooooo`0Pooooo`03o`00oooooooooooo04Gooooo00?o0000ooooooooool03oooool00ol0003o
ooooooooo`2booooo`03o`000?oooooooooo00Sooooo0009ooooo`03o`000?oooooooooo00?ooooo
00?o003oooooooooool04oooool00`000?ooooooooooo`0Zooooo`03o`00oooooooooooo027ooooo
00?o003oooooooooool0AOooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo0;;ooooo
00?o0000ooooooooool02?ooool000Wooooo00?o0000ooooooooool00oooool00ol00?oooooooooo
o`0Cooooo`030000oooooooooooo02Wooooo00?o003oooooooooool01_ooool2oomo01[ooooo00?o
003oooooooooool0AOooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo04kooooo0_oo
O`1Rooooo`03o`000?oooooooooo00Sooooo0009ooooo`03o`000?oooooooooo00?ooooo00?o003o
ooooooooool04oooool00`000?ooooooooooo`0Hooooo`;oogl03oooool00ol00?ooooooooooo`06
ooooo`;oogl06_ooool00ol00?ooooooooooo`15ooooo`03o`000?oooooooooo00oooooo00?o0000
ooooooooool0=?ooool2oomo01Sooooo0_ooO`1Rooooo`03o`000?oooooooooo00Sooooo0009oooo
o`03o`000?oooooooooo00Cooooo00?o003oooooooooool04_ooool00`000?ooooooooooo`0Hoooo
o`;oogl03_ooool00ol00?ooooooooooo`0Sooooo`03o`00oooooooooooo04Gooooo00?o0000oooo
ooooool03oooool00ol0003oooooooooo`0dooooo`;oogl0O?ooool00ol0003oooooooooo`08oooo
o`002Oooool00ol0003oooooooooo`05ooooo`03o`00oooooooooooo017ooooo00<0003ooooooooo
ool09?ooool3o`000003o`00oooooooooooo02Gooooo00?o003oooooooooool0A?ooool00ol0003o
ooooooooo`0?ooooo`03o`000?oooooooooo0;;ooooo00?o0000ooooooooool02?ooool000Wooooo
00?o0000ooooooooool01_ooool00ol00?ooooooooooo`0@ooooo`030000oooooooooooo027ooooo
0_ooO`05o`0002Oooooo00?o003oooooooooool0A?ooool00ol0003oooooooooo`0?ooooo`03o`00
0?oooooooooo03gooooo0_ooO`02ooooo`;oogl0Koooool00ol0003oooooooooo`08ooooo`002Ooo
ool00ol0003oooooooooo`07ooooo`;o003o4?ooool00`000?ooooooooooo`0Qooooo`;oogl01Ol0
000Wooooo`03o`00oooooooooooo04Cooooo00?o0000ooooooooool03oooool00ol0003ooooooooo
o`0mooooo`;oogl00_ooool2oomo06oooooo00?o0000ooooooooool02?ooool000Wooooo00?o0000
ooooooooool02Oooool00ol00?ooooooooooo`0=ooooo`030000oooooooooooo02?ooooo1Ol0000W
ooooo`03o`00oooooooooooo04Cooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`2b
ooooo`03o`000?oooooooooo00Sooooo0009ooooo`03o`000?oooooooooo00[ooooo00?o003ooooo
ooooool03?ooool00`000?ooooooooooo`0Rooooo`03o`00oooooooo000000;o0000:?ooool00ol0
0?ooooooooooo`14ooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool0/_ooool00ol0
003oooooooooo`08ooooo`002Oooool00ol0003oooooooooo`0;ooooo`03o`00oooooooooooo00_o
oooo00<0003oooooooooool08Oooool00ol00?ooooooooooo`0Zooooo`03o`00oooooooooooo04Go
oooo00?o0000ooooooooool03oooool00ol0003oooooooooo`2booooo`03o`000?oooooooooo00So
oooo0009ooooo`03o`000?oooooooooo00cooooo00?o003oooooooooool02_ooool00`000?oooooo
ooooo`0Pooooo`03o`00oooooooooooo02_ooooo00?o003oooooooooool0AOooool00ol0003ooooo
ooooo`0?ooooo`03o`000?oooooooooo0;;ooooo00?o0000ooooooooool02?ooool000Wooooo00?o
0000ooooooooool03Oooool2o`00o`[ooooo00<0003oooooooooool07_ooool2o`00obkooooo00?o
003oooooooooool0AOooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo0;;ooooo00?o
0000ooooooooool02?ooool000Wooooo00?o0000ooooooooool03oooool2o`00o`Sooooo00<0003o
ooooooooool07?ooool2o`00oc3ooooo00?o003oooooooooool0AOooool00ol0003oooooooooo`0?
ooooo`03o`000?oooooooooo0;;ooooo00?o0000ooooooooool02?ooool000Wooooo00?o0000oooo
ooooool04Oooool2o`00o`Kooooo00<0003oooooooooool06_ooool2o`00oc;ooooo00?o003ooooo
ooooool0AOooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo0;;ooooo00?o0000oooo
ooooool02?ooool000Wooooo00?o0000ooooooooool04oooool3o`00o`Cooooo00<0003ooooooooo
ool05_ooool3o`00oc?ooooo00?o003oooooooooool0A_ooool00ol0003oooooooooo`0?ooooo`03
o`000?oooooooooo0;;ooooo00?o0000ooooooooool02?ooool000Wooooo00?o0000ooooooooool0
5_ooool3o`00o`03ooooo`000?oooooo01Gooooo0_l00?lfooooo`03o`00oooooooooooo04Kooooo
00?o0000ooooooooool03oooool00ol0003oooooooooo`2booooo`03o`000?oooooooooo00Sooooo
0009ooooo`03o`000?oooooooooo01Wooooo0_l00?lCooooo`?o003o>?ooool00ol00?oooooooooo
o`16ooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool0/_ooool00ol0003ooooooooo
o`08ooooo`002Oooool00ol0003oooooooooo`0Jooooo`030000ool00?oo003o00Ko003o2?ooool3
o`00oc_ooooo00?o003oooooooooool0A_ooool00ol0003oooooooooo`0?ooooo`03o`000?oooooo
oooo0;;ooooo00?o0000ooooooooool02?ooool000Wooooo00?o0000ooooooooool06oooool00`00
0?ooooooooooo`05ooooo`So003o?Oooool00ol00?ooooooooooo`17ooooo`03o`000?oooooooooo
00oooooo00?o0000ooooooooool0/_ooool00ol0003oooooooooo`08ooooo`002Oooool00ol0003o
ooooooooo`0Kooooo`030000oooooooooooo04[ooooo00?o003oooooooooool0Aoooool00ol0003o
ooooooooo`0?ooooo`03o`000?oooooooooo0;;ooooo00?o0000ooooooooool02?ooool000Wooooo
00?o0000ooooooooool07?ooool00`000?ooooooooooo`19ooooo`03o`00oooooooooooo04Oooooo
00?o0000ooooooooool03oooool00ol0003oooooooooo`2booooo`03o`000?oooooooooo00Sooooo
0009ooooo`03o`000?oooooooooo01cooooo00<0003oooooooooool0BOooool00ol00?oooooooooo
o`17ooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool0/_ooool00ol0003ooooooooo
o`08ooooo`002Oooool00ol0003oooooooooo`0Mooooo`030000oooooooooooo04Oooooo00?o003o
ooooooooool0B?ooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo0;;ooooo00?o0000
ooooooooool02?ooool000Wooooo00?o0000ooooooooool07Oooool00`000?ooooooooooo`17oooo
o`03o`00oooooooooooo04Sooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`2boooo
o`03o`000?oooooooooo00Sooooo0009ooooo`03o`000?oooooooooo01gooooo00<0003ooooooooo
ool0Aoooool00ol00?ooooooooooo`18ooooo`03o`000?oooooooooo00oooooo00?o0000oooooooo
ool0/_ooool00ol0003oooooooooo`08ooooo`002Oooool00ol0003oooooooooo`0Nooooo`030000
oooooooooooo04Gooooo00?o003oooooooooool0BOooool00ol0003oooooooooo`0?ooooo`03o`00
0?oooooooooo0;;ooooo00?o0000ooooooooool02?ooool000Wooooo00?o0000ooooooooool07_oo
ool00`000?ooooooooooo`15ooooo`03o`00oooooooooooo04Wooooo00?o0000ooooooooool03ooo
ool00ol0003oooooooooo`2booooo`03o`000?oooooooooo00Sooooo0009ooooo`03o`000?oooooo
oooo01oooooo00<0003oooooooooool0@oooool00ol00?ooooooooooo`1:ooooo`03o`000?oooooo
oooo00oooooo00?o0000ooooooooool0/_ooool00ol0003oooooooooo`08ooooo`002Oooool00ol0
003oooooooooo`0Oooooo`030000oooooooooooo04;ooooo00?o003oooooooooool0>oooool2oomo
00kooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`2Rooooo`;oogl03_ooool00ol0
003oooooooooo`08ooooo`002Oooool00ol0003oooooooooo`0Pooooo`030000oooooooooooo047o
oooo00?o003oooooooooool0>oooool2oomo00kooooo00?o0000ooooooooool03oooool00ol0003o
ooooooooo`2Rooooo`;oogl03_ooool00ol0003oooooooooo`08ooooo`002Oooool00ol0003ooooo
ooooo`0Qooooo`030000oooooooooooo03oooooo00?o003oooooooooool0C?ooool00ol0003ooooo
ooooo`0?ooooo`03o`000?oooooooooo0;;ooooo00?o0000ooooooooool02?ooool000Wooooo00?o
0000ooooooooool08_ooool00ol00?ooooooooooo`0mooooo`03o`00oooooooooooo04gooooo00?o
0000ooooooooool03oooool00ol0003oooooooooo`2booooo`03o`000?oooooooooo00Sooooo0009
ooooo`03o`000?oooooooooo02?ooooo00?o003oooooooooool0>oooool00ol00?ooooooooooo`1>
ooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool0/_ooool00ol0003oooooooooo`08
ooooo`002Oooool00ol0003oooooooooo`0Tooooo`03o`00oooooooooooo03Wooooo00?o003ooooo
ooooool0Coooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo0;;ooooo00?o0000oooo
ooooool02?ooool000Wooooo00?o0000ooooooooool09Oooool00ol00?ooooooooooo`0gooooo`03
o`00oooooooooooo053ooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`2booooo`03
o`000?oooooooooo00Sooooo0009ooooo`03o`000?oooooooooo02Kooooo00?o003oooooooooool0
=Oooool00ol00?ooooooooooo`1Aooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool0
/_ooool00ol0003oooooooooo`08ooooo`002Oooool00ol0003oooooooooo`0Wooooo`03o`00oooo
oooooooo03?ooooo00?o003oooooooooool0D_ooool00ol0003oooooooooo`0?ooooo`03o`000?oo
oooooooo0;;ooooo00?o0000ooooooooool02?ooool000Wooooo00?o0000ooooooooool0:?ooool0
0ol00?ooooooooooo`0`ooooo`;o003o5?ooool2oomo03oooooo00?o0000ooooooooool03oooool0
0ol0003oooooooooo`1aooooo`;oogl0?oooool00ol0003oooooooooo`08ooooo`002Oooool00ol0
003oooooooooo`0Yooooo`03o`00oooooooooooo02kooooo00?o003oooooooooool05?ooool2oomo
03oooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`1aooooo`;oogl0?oooool00ol0
003oooooooooo`08ooooo`002Oooool00ol0003oooooooooo`0Zooooo`;o003o;?ooool2o`00ocWo
oooo0_ooO`0Mooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool0Toooool2oomo01go
oooo00?o0000ooooooooool02?ooool000Wooooo00?o0000ooooooooool0;?ooool00ol00?oooooo
ooooo`0Wooooo`;o003o=oooool2oomo00;ooooo0_ooO`0Mooooo`03o`000?oooooooooo00oooooo
00?o0000ooooooooool0Soooool2oomo00;ooooo0_ooO`0Mooooo`03o`000?oooooooooo00Sooooo
0009ooooo`03o`000?oooooooooo02gooooo0_l00?lVooooo`03o`00oooooooooooo02;ooooo0_oo
O`0Cooooo`;oogl08Oooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo07[ooooo0_oo
O`0Cooooo`;oogl08Oooool00ol0003oooooooooo`08ooooo`002Oooool00ol0003oooooooooo`0_
ooooo`?o003o8_ooool00ol00?ooooooooooo`0Sooooo`;oogl0=_ooool00ol0003oooooooooo`0?
ooooo`03o`000?oooooooooo07[ooooo0_ooO`0fooooo`03o`000?oooooooooo00Sooooo0009oooo
o`03o`000?oooooooooo03;ooooo00?o003oooooooooool07Oooool2o`00ob3ooooo0_ooO`0Foooo
o`;oogl09?ooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo07Cooooo0_ooO`0Foooo
o`;oogl09?ooool00ol0003oooooooooo`08ooooo`002Oooool00ol0003oooooooooo`0cooooo`?o
003o5oooool5o`00ob;ooooo0_ooO`0Fooooo`;oogl09?ooool00ol0003oooooooooo`0?ooooo`03
o`000?oooooooooo07Cooooo0_ooO`0Fooooo`;oogl09?ooool00ol0003oooooooooo`08ooooo`00
2Oooool00ol0003oooooooooo`0fooooo`Co003o4?ooool3o`00ob?ooooo0_ooO`0?ooooo`;oogl0
3Oooool2oomo023ooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`1`ooooo`;oogl0
3oooool2oomo00gooooo0_ooO`0Pooooo`03o`000?oooooooooo00Sooooo0009ooooo`03o`000?oo
oooooooo03[ooooo4?l00?lVooooo`;oogl01?ooool2oomo00Wooooo0_ooO`0=ooooo`;oogl08?oo
ool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo073ooooo0_ooO`04ooooo`;oogl02Ooo
ool2oomo00gooooo0_ooO`0Pooooo`03o`000?oooooooooo00Sooooo0009ooooo`03o`000?oooooo
oooo05Kooooo0_ooO`0Hooooo`;oogl01?ooool2oomo03[ooooo00?o0000ooooooooool03oooool0
0ol0003oooooooooo`1Fooooo`;oogl06?ooool2oomo00Cooooo0_ooO`0jooooo`03o`000?oooooo
oooo00Sooooo0009ooooo`03o`000?oooooooooo05Kooooo0_ooO`0Hooooo`;oogl0@?ooool00ol0
003oooooooooo`0?ooooo`03o`000?oooooooooo05Kooooo0_ooO`0Hooooo`;oogl0@?ooool00ol0
003oooooooooo`08ooooo`002Oooool00ol0003oooooooooo`2booooo`03o`000?oooooooooo00oo
oooo00?o0000ooooooooool0/_ooool00ol0003oooooooooo`08ooooo`002Oooool00ol0003ooooo
ooooo`1Mooooo`;oogl02Oooool2oomo01Wooooo0_ooO`0]ooooo`03o`000?oooooooooo00oooooo
00?o0000ooooooooool0GOooool2oomo00Wooooo0_ooO`0Iooooo`;oogl0;Oooool00ol0003ooooo
ooooo`08ooooo`002Oooool00ol0003oooooooooo`1Mooooo`;oogl02Oooool2oomo01Wooooo0_oo
O`0]ooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool0GOooool2oomo00Wooooo0_oo
O`0Iooooo`;oogl0;Oooool00ol0003oooooooooo`08ooooo`002Oooool00ol0003oooooooooo`2b
ooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool0/_ooool00ol0003oooooooooo`08
ooooo`002Oooool00ol0003oooooooooo`2Cooooo`;oogl07Oooool00ol0003oooooooooo`0?oooo
o`03o`000?oooooooooo09?ooooo0_ooO`0Mooooo`03o`000?oooooooooo00Sooooo0009ooooo`03
o`000?oooooooooo08Kooooo0_ooO`0;ooooo`;oogl07Oooool00ol0003oooooooooo`0?ooooo`03
o`000?oooooooooo08Kooooo0_ooO`0;ooooo`;oogl07Oooool00ol0003oooooooooo`08ooooo`00
2Oooool00ol0003oooooooooo`1booooo`;oogl04_ooool2oomo02[ooooo00?o0000ooooooooool0
3oooool00ol0003oooooooooo`1booooo`;oogl04_ooool2oomo02[ooooo00?o0000ooooooooool0
2?ooool000Wooooo00?o0000ooooooooool0L_ooool2oomo03kooooo00?o0000ooooooooool03ooo
ool00ol0003oooooooooo`1booooo`;oogl0?_ooool00ol0003oooooooooo`08ooooo`002Oooool0
0ol0003oooooooooo`1Yooooo`;oogl01Oooool2oomo01;ooooo0_ooO`0/ooooo`03o`000?oooooo
oooo00oooooo00?o0000ooooooooool0JOooool2oomo00Gooooo0_ooO`0Booooo`;oogl0;?ooool0
0ol0003oooooooooo`08ooooo`002Oooool00ol0003oooooooooo`1Wooooo`Coogl01Oooool2oomo
00kooooo0_ooO`02ooooo`;oogl0;?ooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo
06Oooooo1?ooO`05ooooo`;oogl03_ooool2oomo00;ooooo0_ooO`0/ooooo`03o`000?oooooooooo
00Sooooo0009ooooo`03o`000?oooooooooo06Oooooo0_ooO`0Gooooo`;oogl0<?ooool00ol0003o
ooooooooo`0?ooooo`03o`000?oooooooooo06Oooooo0_ooO`0Gooooo`;oogl0<?ooool00ol0003o
ooooooooo`08ooooo`002Oooool00ol0003oooooooooo`19ooooo`;oogl0Ioooool00ol0003ooooo
ooooo`0?ooooo`03o`000?oooooooooo04Wooooo0_ooO`1Wooooo`03o`000?oooooooooo00Sooooo
0009ooooo`03o`000?oooooooooo04Wooooo0_ooO`07ooooo`;oogl06_ooool2oomo04;ooooo00?o
0000ooooooooool03oooool00ol0003oooooooooo`19ooooo`;oogl01oooool2oomo01[ooooo0_oo
O`12ooooo`03o`000?oooooooooo00Sooooo0009ooooo`03o`000?oooooooooo05;ooooo0_ooO`0J
ooooo`;oogl0@_ooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo05;ooooo0_ooO`0J
ooooo`;oogl0@_ooool00ol0003oooooooooo`08ooooo`002Oooool00ol0003oooooooooo`1Yoooo
o`;oogl0Aoooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo06Wooooo0_ooO`17oooo
o`03o`000?oooooooooo00Sooooo0009ooooo`03o`000?oooooooooo06Wooooo0_ooO`17ooooo`03
o`000?oooooooooo00oooooo00?o0000ooooooooool0JOooool2oomo04Oooooo00?o0000oooooooo
ool02?ooool000Wooooo00?o0000ooooooooool0/_ooool00ol0003oooooooooo`0?ooooo`03o`00
0?oooooooooo0;;ooooo00?o0000ooooooooool02?ooool000Wooooo00?o0000ooooooooool0/_oo
ool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo0;;ooooo00?o0000ooooooooool02?oo
ool000Wooooo00?o0000ooooooooool0/_ooool00ol0003oooooooooo`0?ooooo`03o`000?oooooo
oooo0;;ooooo00?o0000ooooooooool02?ooool000Wooooo00?o0000ooooooooool0D_ooool2oomo
05kooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`1Booooo`;oogl0G_ooool00ol0
003oooooooooo`08ooooo`002Oooool00ol0003oooooooooo`1Booooo`;oogl0G_ooool00ol0003o
ooooooooo`0?ooooo`03o`000?oooooooooo05;ooooo0_ooO`1Nooooo`03o`000?oooooooooo00So
oooo0009ooooo`03o`000?oooooooooo06oooooo0_ooO`11ooooo`03o`000?oooooooooo00oooooo
00?o0000ooooooooool0Koooool2oomo047ooooo00?o0000ooooooooool02?ooool000Wooooo00?o
0000ooooooooool0Koooool2oomo047ooooo00?o0000ooooooooool03oooool00ol0003ooooooooo
o`1_ooooo`;oogl0@Oooool00ol0003oooooooooo`08ooooo`002Oooool00ol0003oooooooooo`2b
ooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool0/_ooool00ol0003oooooooooo`08
ooooo`002Oooool00ol0003oooooooooo`2booooo`03o`000?oooooooooo00oooooo00?o0000oooo
ooooool0/_ooool00ol0003oooooooooo`08ooooo`002Oooool00ol0003oooooooooo`1=ooooo`;o
ogl0Hoooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo04gooooo0_ooO`1Sooooo`03
o`000?oooooooooo00Sooooo0009ooooo`03o`000?oooooooooo04gooooo0_ooO`0Dooooo`;oogl0
COooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo04gooooo0_ooO`0Dooooo`;oogl0
COooool00ol0003oooooooooo`08ooooo`002Oooool00ol0003oooooooooo`1Sooooo`;oogl0COoo
ool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo06?ooooo0_ooO`1=ooooo`03o`000?oo
oooooooo00Sooooo0009ooooo`03o`000?oooooooooo05Wooooo0_ooO`1Gooooo`03o`000?oooooo
oooo00oooooo00?o0000ooooooooool0FOooool2oomo05Oooooo00?o0000ooooooooool02?ooool0
00Wooooo00?o0000ooooooooool0FOooool2oomo05Oooooo00?o0000ooooooooool03oooool00ol0
003oooooooooo`1Iooooo`;oogl0Eoooool00ol0003oooooooooo`08ooooo`002Oooool00ol0003o
ooooooooo`1aooooo`;oogl0?oooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo077o
oooo0_ooO`0oooooo`03o`000?oooooooooo00Sooooo0009ooooo`03o`000?oooooooooo077ooooo
0_ooO`0oooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool0LOooool2oomo03oooooo
00?o0000ooooooooool02?ooool000Wooooo00?o0000ooooooooool0/_ooool00ol0003ooooooooo
o`0?ooooo`03o`000?oooooooooo0;;ooooo00?o0000ooooooooool02?ooool000Wooooo00?o0000
ooooooooool0/_ooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo0;;ooooo00?o0000
ooooooooool02?ooool000Wooooo00?o0000ooooooooool0/_ooool00ol0003oooooooooo`0?oooo
o`03o`000?oooooooooo0;;ooooo00?o0000ooooooooool02?ooool000Wooooo00?o0000oooooooo
ool0/_ooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo0;;ooooo00?o0000oooooooo
ool02?ooool000Wooooo00?o0000ooooooooool0/_ooool00ol0003oooooooooo`0?ooooo`03o`00
0?oooooooooo0;;ooooo00?o0000ooooooooool02?ooool000Wooooo00?o0000ooooooooool0/_oo
ool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo0;;ooooo00?o0000ooooooooool02?oo
ool000Wooooo00?o0000ooooooooool0/_ooool00ol0003oooooooooo`0?ooooo`03o`000?oooooo
oooo0;;ooooo00?o0000ooooooooool02?ooool000Wooooo00?o0000ooooooooool0/_ooool00ol0
003oooooooooo`0?ooooo`03o`000?oooooooooo0;;ooooo00?o0000ooooooooool02?ooool000Wo
oooo00?o0000ooooooooool0/_ooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo0;;o
oooo00?o0000ooooooooool02?ooool000Wooooo00?o0000ooooooooool0/_ooool00ol0003ooooo
ooooo`0?ooooo`03o`000?oooooooooo0;;ooooo00?o0000ooooooooool02?ooool000Wooooo00?o
0000ooooooooool0/_ooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo0;;ooooo00?o
0000ooooooooool02?ooool000Wooooo00?o0000ooooooooool0/_ooool00ol0003oooooooooo`0?
ooooo`03o`000?oooooooooo0;;ooooo00?o0000ooooooooool02?ooool000Wooooo00?o0000oooo
ooooool0/_ooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo0;;ooooo00?o0000oooo
ooooool02?ooool000Wooooo00?o0000ooooooooool0/_ooool00ol0003oooooooooo`0?ooooo`03
o`000?oooooooooo0;;ooooo00?o0000ooooooooool02?ooool000Wooooo00?o0000ooooooooool0
/_ooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo0;;ooooo00?o0000ooooooooool0
2?ooool000Wooooo00?o0000ooooooooool0/_ooool00ol0003oooooooooo`0?ooooo`03o`000?oo
oooooooo0;;ooooo00?o0000ooooooooool02?ooool000Wooooo00?o0000ooooooooool0/_ooool0
0ol0003oooooooooo`0?ooooo`03o`000?oooooooooo0;;ooooo00?o0000ooooooooool02?ooool0
00Wooooo00?o0000ooooooooool0/_ooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo
0;;ooooo00?o0000ooooooooool02?ooool000Wooooo00?o0000ooooooooool0/_ooool00ol0003o
ooooooooo`0?ooooo`03o`000?oooooooooo0;;ooooo00?o0000ooooooooool02?ooool000Wooooo
00?o0000ooooooooool0/_ooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo0;;ooooo
00?o0000ooooooooool02?ooool000Wooooo00?o0000ooooooooool0/_ooool00ol0003ooooooooo
o`0?ooooo`03o`000?oooooooooo0;;ooooo00?o0000ooooooooool02?ooool000Wooooo00?o0000
ooooooooool0/_ooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo0;;ooooo00?o0000
ooooooooool02?ooool000Wooooo00?o0000ooooooooool0/_ooool00ol0003oooooooooo`0?oooo
o`03o`000?oooooooooo0;;ooooo00?o0000ooooooooool02?ooool000Wooooo00?o0000oooooooo
ool0/_ooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo0;;ooooo00?o0000oooooooo
ool02?ooool000Wooooo00?o0000ooooooooool0F?ooool2oomo05Sooooo00?o0000ooooooooool0
3oooool00ol0003oooooooooo`1Hooooo`;oogl0F?ooool00ol0003oooooooooo`08ooooo`002Ooo
ool00ol0003oooooooooo`1Hooooo`;oogl0F?ooool00ol0003oooooooooo`0?ooooo`03o`000?oo
oooooooo05Sooooo0_ooO`1Hooooo`03o`000?oooooooooo00Sooooo0009ooooo`03o`000?oooooo
oooo0;;ooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`2booooo`03o`000?oooooo
oooo00Sooooo0009ooooo`03o`000?oooooooooo0;;ooooo00?o0000ooooooooool03oooool00ol0
003oooooooooo`2booooo`03o`000?oooooooooo00Sooooo0009ooooo`03o`000?oooooooooo0;;o
oooo00?o0000ooooooooool03oooool00ol0003oooooooooo`2booooo`03o`000?oooooooooo00So
oooo0009ooooo`03o`000?oooooooooo0;;ooooo00?o0000ooooooooool03oooool00ol0003ooooo
ooooo`2booooo`03o`000?oooooooooo00Sooooo0009ooooo`03o`000?oooooooooo0;;ooooo00?o
0000ooooooooool03oooool00ol0003oooooooooo`2booooo`03o`000?oooooooooo00Sooooo0009
ooooo`03o`000?oooooooooo0;;ooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`2b
ooooo`03o`000?oooooooooo00Sooooo0009ooooo`03o`000?oooooooooo0;;ooooo00?o0000oooo
ooooool03oooool00ol0003oooooooooo`2booooo`03o`000?oooooooooo00Sooooo0009ooooo`03
o`000?oooooooooo0;;ooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`2booooo`03
o`000?oooooooooo00Sooooo0009ooooo`03o`000?oooooooooo0;;ooooo00?o0000ooooooooool0
3oooool00ol0003oooooooooo`2booooo`03o`000?oooooooooo00Sooooo0009ooooo`03o`000?oo
oooooooo0;;ooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`2booooo`03o`000?oo
oooooooo00Sooooo0009ooooo`03o`000?oooooooooo0;;ooooo00?o0000ooooooooool03oooool0
0ol0003oooooooooo`2booooo`03o`000?oooooooooo00Sooooo0009ooooo`03o`000?oooooooooo
0;;ooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`2booooo`03o`000?oooooooooo
00Sooooo0009ooooo`03o`000?oooooooooo0;;ooooo00?o0000ooooooooool03oooool00ol0003o
ooooooooo`2booooo`03o`000?oooooooooo00Sooooo0009oooookKo00004Ooooonfo`0000[ooooo
003ooooooi7ooooo003ooooooi7ooooo003ooooooi7ooooo003ooooooi7ooooo003ooooooi7ooooo
003ooooooi7ooooo003ooooooi7ooooo003ooooooi7ooooo003ooooooi7ooooo0000\
\>"],
  ImageRangeCache->{{{0, 399}, {399, 0}} -> {-0.0500105, -0.0500105, \
0.00526322, 0.00526322}, {{9.5, 190.438}, {389.5, 208.5}} -> {-1.15081, \
-1.15117, 0.0115117, 0.0115117}, {{208.5, 389.438}, {389.5, 208.5}} -> \
{-1.09771, -0.0754011, 0.0052648, 0.0052648}, {{9.5, 190.438}, {190.438, \
9.5}} -> {-1.11761, -3.34306, 0.0111796, 0.0111796}, {{208.5, 389.438}, \
{190.438, 9.5}} -> {-3.34236, -3.34306, 0.0111796, 0.0111796}}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Final model", "Subsubsection"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(EMAllPlot[em\  // \ Last, \ gdata, pr];\)\)], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
%%ImageSize: 400 400 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.47619 0.0238095 0.47619 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.0238095 0.477324 0.477324 MathSubStart
%% ContourGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.480769 0.5 0.480769 [
[ 0 0 -0.125 0 ]
[ 0 0 -0.125 0 ]
[ 0 1 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
0 0 m
1 0 L
s
0 0 m
0 1 L
s
0 1 m
1 1 L
s
1 0 m
1 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
.01923 .98077 m
.98077 .98077 L
.98077 .01923 L
.01923 .01923 L
F
.5 Mabswid
.1 g
.01923 .14789 m
.02076 .15385 L
.02872 .17308 L
.03846 .18928 L
.04079 .19231 L
.05562 .21154 L
.05769 .21419 L
.07306 .23077 L
.07692 .2348 L
.09275 .25 L
.09615 .25296 L
.11457 .26923 L
.11538 .26979 L
.13462 .28478 L
.13927 .28846 L
.15385 .29805 L
.16669 .30769 L
.17308 .31081 L
.19231 .32393 L
.19675 .32692 L
.21154 .33398 L
.23067 .34615 L
.23077 .34621 L
.25 .35437 L
.26923 .36502 L
.26995 .36538 L
.28846 .37164 L
.30769 .38029 L
.31809 .38462 L
.32692 .38649 L
.34615 .39213 L
.36538 .39757 L
.38462 .40168 L
.4009 .40385 L
.40385 .40404 L
.42308 .4044 L
.43172 .40385 L
.44231 .40217 L
.46154 .39533 L
.47331 .38462 L
.48017 .36538 L
.4781 .34615 L
.47064 .32692 L
.46154 .30978 L
.45991 .30769 L
.44559 .28846 L
.44231 .28416 L
.42874 .26923 L
.42308 .26317 L
.40955 .25 L
.40385 .24484 L
.38809 .23077 L
.38462 .22817 L
.36538 .21228 L
.36446 .21154 L
.34615 .19884 L
.3375 .19231 L
.32692 .18644 L
.30826 .17308 L
.30769 .1729 L
.28846 .16256 L
.27494 .15385 L
.26923 .15204 L
.25 .14187 L
.23713 .13462 L
.23077 .13296 L
.21154 .12457 L
.19231 .11563 L
.19174 .11538 L
.17308 .11033 L
.15385 .10379 L
.13462 .09815 L
.12705 .09615 L
.11538 .09465 L
.09615 .09234 L
.07692 .09151 L
.05769 .09317 L
.04504 .09615 L
.03846 .09912 L
.02176 .11538 L
.01923 .12157 L
F
0 g
.01923 .14789 m
.02076 .15385 L
.02872 .17308 L
.03846 .18928 L
.04079 .19231 L
.05562 .21154 L
.05769 .21419 L
.07306 .23077 L
.07692 .2348 L
.09275 .25 L
.09615 .25296 L
.11457 .26923 L
.11538 .26979 L
.13462 .28478 L
.13927 .28846 L
.15385 .29805 L
.16669 .30769 L
.17308 .31081 L
.19231 .32393 L
.19675 .32692 L
.21154 .33398 L
.23067 .34615 L
.23077 .34621 L
.25 .35437 L
.26923 .36502 L
.26995 .36538 L
.28846 .37164 L
.30769 .38029 L
.31809 .38462 L
.32692 .38649 L
.34615 .39213 L
.36538 .39757 L
.38462 .40168 L
.4009 .40385 L
.40385 .40404 L
.42308 .4044 L
.43172 .40385 L
.44231 .40217 L
.46154 .39533 L
.47331 .38462 L
.48017 .36538 L
.4781 .34615 L
.47064 .32692 L
.46154 .30978 L
.45991 .30769 L
.44559 .28846 L
.44231 .28416 L
.42874 .26923 L
.42308 .26317 L
.40955 .25 L
Mistroke
.40385 .24484 L
.38809 .23077 L
.38462 .22817 L
.36538 .21228 L
.36446 .21154 L
.34615 .19884 L
.3375 .19231 L
.32692 .18644 L
.30826 .17308 L
.30769 .1729 L
.28846 .16256 L
.27494 .15385 L
.26923 .15204 L
.25 .14187 L
.23713 .13462 L
.23077 .13296 L
.21154 .12457 L
.19231 .11563 L
.19174 .11538 L
.17308 .11033 L
.15385 .10379 L
.13462 .09815 L
.12705 .09615 L
.11538 .09465 L
.09615 .09234 L
.07692 .09151 L
.05769 .09317 L
.04504 .09615 L
.03846 .09912 L
.02176 .11538 L
.01923 .12157 L
Mfstroke
.2 g
.07692 .1245 m
.09615 .11965 L
.11538 .11898 L
.13462 .12091 L
.15385 .12474 L
.17308 .12989 L
.19012 .13462 L
.19231 .13545 L
.21154 .14327 L
.23077 .15141 L
.23752 .15385 L
.25 .16037 L
.26923 .17048 L
.27509 .17308 L
.28846 .18134 L
.30731 .19231 L
.30769 .19257 L
.32692 .20613 L
.33517 .21154 L
.34615 .22002 L
.36002 .23077 L
.36538 .23531 L
.38186 .25 L
.38462 .25259 L
.4007 .26923 L
.40385 .27259 L
.41643 .28846 L
.42308 .29699 L
.42879 .30769 L
.43701 .32692 L
.43906 .34615 L
.42901 .36538 L
.42308 .36966 L
.40385 .37564 L
.38462 .37664 L
.36538 .37492 L
.34615 .37135 L
.32692 .36675 L
.3211 .36538 L
.30769 .36069 L
.28846 .3531 L
.26976 .34615 L
.26923 .3459 L
.25 .33612 L
.23077 .32703 L
.23048 .32692 L
.21154 .31545 L
.19741 .30769 L
.19231 .3043 L
.17308 .29124 L
.16858 .28846 L
.15385 .27725 L
.14313 .26923 L
.13462 .26214 L
.12063 .25 L
.11538 .24516 L
.1011 .23077 L
.09615 .22557 L
.08464 .21154 L
.07692 .20174 L
.07142 .19231 L
.06213 .17308 L
.05841 .15385 L
.06457 .13462 L
F
0 g
.07692 .1245 m
.09615 .11965 L
.11538 .11898 L
.13462 .12091 L
.15385 .12474 L
.17308 .12989 L
.19012 .13462 L
.19231 .13545 L
.21154 .14327 L
.23077 .15141 L
.23752 .15385 L
.25 .16037 L
.26923 .17048 L
.27509 .17308 L
.28846 .18134 L
.30731 .19231 L
.30769 .19257 L
.32692 .20613 L
.33517 .21154 L
.34615 .22002 L
.36002 .23077 L
.36538 .23531 L
.38186 .25 L
.38462 .25259 L
.4007 .26923 L
.40385 .27259 L
.41643 .28846 L
.42308 .29699 L
.42879 .30769 L
.43701 .32692 L
.43906 .34615 L
.42901 .36538 L
.42308 .36966 L
.40385 .37564 L
.38462 .37664 L
.36538 .37492 L
.34615 .37135 L
.32692 .36675 L
.3211 .36538 L
.30769 .36069 L
.28846 .3531 L
.26976 .34615 L
.26923 .3459 L
.25 .33612 L
.23077 .32703 L
.23048 .32692 L
.21154 .31545 L
.19741 .30769 L
.19231 .3043 L
.17308 .29124 L
Mistroke
.16858 .28846 L
.15385 .27725 L
.14313 .26923 L
.13462 .26214 L
.12063 .25 L
.11538 .24516 L
.1011 .23077 L
.09615 .22557 L
.08464 .21154 L
.07692 .20174 L
.07142 .19231 L
.06213 .17308 L
.05841 .15385 L
.06457 .13462 L
.07692 .1245 L
Mfstroke
.3 g
.09615 .14112 m
.11538 .13705 L
.13462 .13642 L
.15385 .13858 L
.17308 .1428 L
.19231 .14849 L
.20891 .15385 L
.21154 .15492 L
.23077 .16328 L
.25 .17202 L
.25249 .17308 L
.26923 .18234 L
.28729 .19231 L
.28846 .19304 L
.30769 .20571 L
.31667 .21154 L
.32692 .2191 L
.34219 .23077 L
.34615 .23403 L
.36419 .25 L
.36538 .2511 L
.38274 .26923 L
.38462 .2711 L
.39766 .28846 L
.40385 .29348 L
.40841 .30769 L
.41342 .32692 L
.40779 .34615 L
.40385 .35095 L
.38462 .3583 L
.36538 .35929 L
.34615 .35733 L
.32692 .35334 L
.30769 .34806 L
.30099 .34615 L
.28846 .34141 L
.26923 .33329 L
.25411 .32692 L
.25 .32483 L
.23077 .31447 L
.21783 .30769 L
.21154 .30382 L
.19231 .29153 L
.18735 .28846 L
.17308 .27814 L
.16105 .26923 L
.15385 .26342 L
.13827 .25 L
.13462 .24668 L
.11893 .23077 L
.11538 .22715 L
.10315 .21154 L
.09615 .2036 L
.09134 .19231 L
.0848 .17308 L
.08708 .15385 L
F
0 g
.09615 .14112 m
.11538 .13705 L
.13462 .13642 L
.15385 .13858 L
.17308 .1428 L
.19231 .14849 L
.20891 .15385 L
.21154 .15492 L
.23077 .16328 L
.25 .17202 L
.25249 .17308 L
.26923 .18234 L
.28729 .19231 L
.28846 .19304 L
.30769 .20571 L
.31667 .21154 L
.32692 .2191 L
.34219 .23077 L
.34615 .23403 L
.36419 .25 L
.36538 .2511 L
.38274 .26923 L
.38462 .2711 L
.39766 .28846 L
.40385 .29348 L
.40841 .30769 L
.41342 .32692 L
.40779 .34615 L
.40385 .35095 L
.38462 .3583 L
.36538 .35929 L
.34615 .35733 L
.32692 .35334 L
.30769 .34806 L
.30099 .34615 L
.28846 .34141 L
.26923 .33329 L
.25411 .32692 L
.25 .32483 L
.23077 .31447 L
.21783 .30769 L
.21154 .30382 L
.19231 .29153 L
.18735 .28846 L
.17308 .27814 L
.16105 .26923 L
.15385 .26342 L
.13827 .25 L
.13462 .24668 L
.11893 .23077 L
Mistroke
.11538 .22715 L
.10315 .21154 L
.09615 .2036 L
.09134 .19231 L
.0848 .17308 L
.08708 .15385 L
.09615 .14112 L
Mfstroke
.4 g
.13462 .15051 m
.15385 .15059 L
.17308 .15343 L
.17564 .15385 L
.19231 .15832 L
.21154 .1649 L
.23077 .17241 L
.23246 .17308 L
.25 .18155 L
.26923 .19151 L
.27079 .19231 L
.28846 .20306 L
.30186 .21154 L
.30769 .21559 L
.32692 .22988 L
.32807 .23077 L
.34615 .24623 L
.35016 .25 L
.36538 .26553 L
.36844 .26923 L
.38256 .28846 L
.38462 .29202 L
.3914 .30769 L
.39203 .32692 L
.38462 .3373 L
.36538 .34516 L
.34615 .34533 L
.32692 .34269 L
.30769 .3379 L
.28846 .33158 L
.27547 .32692 L
.26923 .3242 L
.25 .31515 L
.23484 .30769 L
.23077 .30542 L
.21154 .29397 L
.20246 .28846 L
.19231 .28155 L
.17522 .26923 L
.17308 .26759 L
.15385 .25148 L
.15221 .25 L
.13462 .23256 L
.13306 .23077 L
.11796 .21154 L
.11538 .20748 L
.10779 .19231 L
.10476 .17308 L
.11538 .15667 L
.12086 .15385 L
F
0 g
.13462 .15051 m
.15385 .15059 L
.17308 .15343 L
.17564 .15385 L
.19231 .15832 L
.21154 .1649 L
.23077 .17241 L
.23246 .17308 L
.25 .18155 L
.26923 .19151 L
.27079 .19231 L
.28846 .20306 L
.30186 .21154 L
.30769 .21559 L
.32692 .22988 L
.32807 .23077 L
.34615 .24623 L
.35016 .25 L
.36538 .26553 L
.36844 .26923 L
.38256 .28846 L
.38462 .29202 L
.3914 .30769 L
.39203 .32692 L
.38462 .3373 L
.36538 .34516 L
.34615 .34533 L
.32692 .34269 L
.30769 .3379 L
.28846 .33158 L
.27547 .32692 L
.26923 .3242 L
.25 .31515 L
.23484 .30769 L
.23077 .30542 L
.21154 .29397 L
.20246 .28846 L
.19231 .28155 L
.17522 .26923 L
.17308 .26759 L
.15385 .25148 L
.15221 .25 L
.13462 .23256 L
.13306 .23077 L
.11796 .21154 L
.11538 .20748 L
.10779 .19231 L
.10476 .17308 L
.11538 .15667 L
.12086 .15385 L
Mistroke
.13462 .15051 L
Mfstroke
.5 g
.13462 .16338 m
.15385 .16153 L
.17308 .16323 L
.19231 .16737 L
.21135 .17308 L
.21154 .17317 L
.23077 .18073 L
.25 .18963 L
.25556 .19231 L
.26923 .19983 L
.28846 .2114 L
.28869 .21154 L
.30769 .22472 L
.31571 .23077 L
.32692 .23977 L
.33807 .25 L
.34615 .25733 L
.35599 .26923 L
.36538 .2783 L
.36902 .28846 L
.37545 .30769 L
.36758 .32692 L
.36538 .32865 L
.34615 .33376 L
.32692 .33266 L
.30769 .32888 L
.29908 .32692 L
.28846 .32325 L
.26923 .31581 L
.25086 .30769 L
.25 .30726 L
.23077 .29704 L
.21593 .28846 L
.21154 .28571 L
.19231 .27257 L
.18771 .26923 L
.17308 .25771 L
.16436 .25 L
.15385 .2404 L
.14542 .23077 L
.13462 .21873 L
.13118 .21154 L
.12297 .19231 L
.12555 .17308 L
F
0 g
.13462 .16338 m
.15385 .16153 L
.17308 .16323 L
.19231 .16737 L
.21135 .17308 L
.21154 .17317 L
.23077 .18073 L
.25 .18963 L
.25556 .19231 L
.26923 .19983 L
.28846 .2114 L
.28869 .21154 L
.30769 .22472 L
.31571 .23077 L
.32692 .23977 L
.33807 .25 L
.34615 .25733 L
.35599 .26923 L
.36538 .2783 L
.36902 .28846 L
.37545 .30769 L
.36758 .32692 L
.36538 .32865 L
.34615 .33376 L
.32692 .33266 L
.30769 .32888 L
.29908 .32692 L
.28846 .32325 L
.26923 .31581 L
.25086 .30769 L
.25 .30726 L
.23077 .29704 L
.21593 .28846 L
.21154 .28571 L
.19231 .27257 L
.18771 .26923 L
.17308 .25771 L
.16436 .25 L
.15385 .2404 L
.14542 .23077 L
.13462 .21873 L
.13118 .21154 L
.12297 .19231 L
.12555 .17308 L
.13462 .16338 L
s
.6 g
.15385 .17502 m
.17308 .17314 L
.19231 .17566 L
.21154 .18107 L
.23077 .18836 L
.24018 .19231 L
.25 .19702 L
.26923 .20749 L
.27614 .21154 L
.28846 .21933 L
.30431 .23077 L
.30769 .23311 L
.3269 .25 L
.32692 .25 L
.34441 .26923 L
.34615 .27162 L
.3561 .28846 L
.35891 .30769 L
.34615 .31981 L
.32692 .32367 L
.30769 .3205 L
.28846 .31523 L
.26923 .30825 L
.26778 .30769 L
.25 .29969 L
.23077 .28948 L
.22894 .28846 L
.21154 .27775 L
.19928 .26923 L
.19231 .26431 L
.1755 .25 L
.17308 .24857 L
.15682 .23077 L
.15385 .22701 L
.14368 .21154 L
.13835 .19231 L
F
0 g
.15385 .17502 m
.17308 .17314 L
.19231 .17566 L
.21154 .18107 L
.23077 .18836 L
.24018 .19231 L
.25 .19702 L
.26923 .20749 L
.27614 .21154 L
.28846 .21933 L
.30431 .23077 L
.30769 .23311 L
.3269 .25 L
.32692 .25 L
.34441 .26923 L
.34615 .27162 L
.3561 .28846 L
.35891 .30769 L
.34615 .31981 L
.32692 .32367 L
.30769 .3205 L
.28846 .31523 L
.26923 .30825 L
.26778 .30769 L
.25 .29969 L
.23077 .28948 L
.22894 .28846 L
.21154 .27775 L
.19928 .26923 L
.19231 .26431 L
.1755 .25 L
.17308 .24857 L
.15682 .23077 L
.15385 .22701 L
.14368 .21154 L
.13835 .19231 L
.15385 .17502 L
s
.7 g
.17308 .18111 m
.19231 .18417 L
.21154 .18901 L
.22351 .19231 L
.23077 .19546 L
.25 .20433 L
.26355 .21154 L
.26923 .21461 L
.28846 .22735 L
.2931 .23077 L
.30769 .24172 L
.31606 .25 L
.32692 .25751 L
.33301 .26923 L
.34284 .28846 L
.33594 .30769 L
.32692 .31196 L
.30769 .3114 L
.29028 .30769 L
.28846 .30736 L
.26923 .30109 L
.25 .29234 L
.2422 .28846 L
.23077 .28236 L
.21154 .2698 L
.21073 .26923 L
.19231 .25551 L
.18637 .25 L
.17308 .23853 L
.16803 .23077 L
.15635 .21154 L
.15706 .19231 L
F
0 g
.17308 .18111 m
.19231 .18417 L
.21154 .18901 L
.22351 .19231 L
.23077 .19546 L
.25 .20433 L
.26355 .21154 L
.26923 .21461 L
.28846 .22735 L
.2931 .23077 L
.30769 .24172 L
.31606 .25 L
.32692 .25751 L
.33301 .26923 L
.34284 .28846 L
.33594 .30769 L
.32692 .31196 L
.30769 .3114 L
.29028 .30769 L
.28846 .30736 L
.26923 .30109 L
.25 .29234 L
.2422 .28846 L
.23077 .28236 L
.21154 .2698 L
.21073 .26923 L
.19231 .25551 L
.18637 .25 L
.17308 .23853 L
.16803 .23077 L
.15635 .21154 L
.15706 .19231 L
.17308 .18111 L
s
.8 g
.17308 .20181 m
.19231 .19485 L
.21154 .19477 L
.23077 .20283 L
.24954 .21154 L
.25 .21168 L
.26923 .22201 L
.28172 .23077 L
.28846 .23286 L
.30506 .25 L
.30769 .25283 L
.32135 .26923 L
.32692 .28453 L
.32703 .28846 L
.32692 .28896 L
.30769 .30072 L
.28846 .30057 L
.26923 .29331 L
.25628 .28846 L
.25 .2859 L
.23077 .27467 L
.22245 .26923 L
.21154 .2634 L
.1973 .25 L
.19231 .24506 L
.1794 .23077 L
.17308 .21922 L
.17058 .21154 L
F
0 g
.17308 .20181 m
.19231 .19485 L
.21154 .19477 L
.23077 .20283 L
.24954 .21154 L
.25 .21168 L
.26923 .22201 L
.28172 .23077 L
.28846 .23286 L
.30506 .25 L
.30769 .25283 L
.32135 .26923 L
.32692 .28453 L
.32703 .28846 L
.32692 .28896 L
.30769 .30072 L
.28846 .30057 L
.26923 .29331 L
.25628 .28846 L
.25 .2859 L
.23077 .27467 L
.22245 .26923 L
.21154 .2634 L
.1973 .25 L
.19231 .24506 L
.1794 .23077 L
.17308 .21922 L
.17058 .21154 L
.17308 .20181 L
s
.9 g
.19231 .2099 m
.21154 .20493 L
.22939 .21154 L
.23077 .21201 L
.25 .21651 L
.26892 .23077 L
.26923 .2313 L
.28846 .24353 L
.293 .25 L
.30737 .26923 L
.29815 .28846 L
.28846 .28875 L
.28659 .28846 L
.26923 .28435 L
.25 .2784 L
.23457 .26923 L
.23077 .26576 L
.21154 .25224 L
.20955 .25 L
.19243 .23077 L
.19231 .23006 L
.19045 .21154 L
F
0 g
.19231 .2099 m
.21154 .20493 L
.22939 .21154 L
.23077 .21201 L
.25 .21651 L
.26892 .23077 L
.26923 .2313 L
.28846 .24353 L
.293 .25 L
.30737 .26923 L
.29815 .28846 L
.28846 .28875 L
.28659 .28846 L
.26923 .28435 L
.25 .2784 L
.23457 .26923 L
.23077 .26576 L
.21154 .25224 L
.20955 .25 L
.19243 .23077 L
.19231 .23006 L
.19045 .21154 L
.19231 .2099 L
s
1 g
.21154 .22563 m
.23077 .22325 L
.25 .23024 L
.25095 .23077 L
.26923 .2428 L
.28153 .25 L
.287 .26923 L
.26923 .27299 L
.25677 .26923 L
.25 .26621 L
.23077 .25463 L
.22268 .25 L
.21154 .23356 L
.20994 .23077 L
F
0 g
.21154 .22563 m
.23077 .22325 L
.25 .23024 L
.25095 .23077 L
.26923 .2428 L
.28153 .25 L
.287 .26923 L
.26923 .27299 L
.25677 .26923 L
.25 .26621 L
.23077 .25463 L
.22268 .25 L
.21154 .23356 L
.20994 .23077 L
.21154 .22563 L
s
.1 g
.71154 .47745 m
.73077 .47292 L
.75 .46901 L
.76923 .46606 L
.78846 .46428 L
.80769 .46384 L
.82692 .46498 L
.84615 .46812 L
.86538 .47403 L
.87891 .48077 L
.88462 .48459 L
.89921 .5 L
.90385 .50854 L
.9073 .51923 L
.90867 .53846 L
.90544 .55769 L
.90385 .56476 L
.89845 .57692 L
.88838 .59615 L
.88462 .60249 L
.87552 .61538 L
.86538 .62857 L
.86017 .63462 L
.84615 .64994 L
.84227 .65385 L
.82692 .66845 L
.82177 .67308 L
.80769 .68491 L
.79859 .69231 L
.78846 .6998 L
.77262 .71154 L
.76923 .71369 L
.75 .72639 L
.74328 .73077 L
.73077 .73776 L
.71154 .74911 L
.70997 .75 L
.69231 .75853 L
.67308 .76833 L
.67122 .76923 L
.65385 .77615 L
.63462 .78426 L
.6241 .78846 L
.61538 .79106 L
.59615 .79711 L
.57692 .80285 L
.55805 .80769 L
.55769 .80776 L
.53846 .81108 L
.51923 .81379 L
.5 .81551 L
.48077 .81597 L
.46154 .81488 L
.44231 .81181 L
.42762 .80769 L
.42308 .80589 L
.40385 .7951 L
.39643 .78846 L
.38462 .77092 L
.38407 .76923 L
.38013 .75 L
.38152 .73077 L
.38462 .71814 L
.3869 .71154 L
.39576 .69231 L
.40385 .67811 L
.40729 .67308 L
.42157 .65385 L
.42308 .65194 L
.43848 .63462 L
.44231 .63056 L
.45782 .61538 L
.46154 .61199 L
.47967 .59615 L
.48077 .59529 L
.5 .58028 L
.50443 .57692 L
.51923 .56676 L
.53228 .55769 L
.53846 .55409 L
.55769 .54212 L
.56366 .53846 L
.57692 .53169 L
.59615 .5211 L
.59967 .51923 L
.61538 .51244 L
.63462 .50351 L
.64254 .5 L
.65385 .49616 L
.67308 .48916 L
.69231 .4825 L
.69773 .48077 L
F
0 g
.71154 .47745 m
.73077 .47292 L
.75 .46901 L
.76923 .46606 L
.78846 .46428 L
.80769 .46384 L
.82692 .46498 L
.84615 .46812 L
.86538 .47403 L
.87891 .48077 L
.88462 .48459 L
.89921 .5 L
.90385 .50854 L
.9073 .51923 L
.90867 .53846 L
.90544 .55769 L
.90385 .56476 L
.89845 .57692 L
.88838 .59615 L
.88462 .60249 L
.87552 .61538 L
.86538 .62857 L
.86017 .63462 L
.84615 .64994 L
.84227 .65385 L
.82692 .66845 L
.82177 .67308 L
.80769 .68491 L
.79859 .69231 L
.78846 .6998 L
.77262 .71154 L
.76923 .71369 L
.75 .72639 L
.74328 .73077 L
.73077 .73776 L
.71154 .74911 L
.70997 .75 L
.69231 .75853 L
.67308 .76833 L
.67122 .76923 L
.65385 .77615 L
.63462 .78426 L
.6241 .78846 L
.61538 .79106 L
.59615 .79711 L
.57692 .80285 L
.55805 .80769 L
.55769 .80776 L
.53846 .81108 L
.51923 .81379 L
Mistroke
.5 .81551 L
.48077 .81597 L
.46154 .81488 L
.44231 .81181 L
.42762 .80769 L
.42308 .80589 L
.40385 .7951 L
.39643 .78846 L
.38462 .77092 L
.38407 .76923 L
.38013 .75 L
.38152 .73077 L
.38462 .71814 L
.3869 .71154 L
.39576 .69231 L
.40385 .67811 L
.40729 .67308 L
.42157 .65385 L
.42308 .65194 L
.43848 .63462 L
.44231 .63056 L
.45782 .61538 L
.46154 .61199 L
.47967 .59615 L
.48077 .59529 L
.5 .58028 L
.50443 .57692 L
.51923 .56676 L
.53228 .55769 L
.53846 .55409 L
.55769 .54212 L
.56366 .53846 L
.57692 .53169 L
.59615 .5211 L
.59967 .51923 L
.61538 .51244 L
.63462 .50351 L
.64254 .5 L
.65385 .49616 L
.67308 .48916 L
.69231 .4825 L
.69773 .48077 L
.71154 .47745 L
Mfstroke
.2 g
.75 .49779 m
.76923 .49656 L
.78846 .49698 L
.80769 .49964 L
.80947 .5 L
.82692 .5057 L
.84615 .51868 L
.84667 .51923 L
.85782 .53846 L
.85974 .55769 L
.85589 .57692 L
.84781 .59615 L
.84615 .59948 L
.83604 .61538 L
.82692 .62775 L
.82111 .63462 L
.80769 .64926 L
.80306 .65385 L
.78846 .66738 L
.78185 .67308 L
.76923 .68321 L
.75728 .69231 L
.75 .69737 L
.73077 .71035 L
.72892 .71154 L
.71154 .72175 L
.69569 .73077 L
.69231 .73243 L
.67308 .74186 L
.65564 .75 L
.65385 .7507 L
.63462 .75814 L
.61538 .76513 L
.60279 .76923 L
.59615 .77099 L
.57692 .77572 L
.55769 .77957 L
.53846 .78225 L
.51923 .78351 L
.5 .78303 L
.48077 .78028 L
.46154 .77409 L
.45249 .76923 L
.44231 .76168 L
.43442 .75 L
.42913 .73077 L
.43069 .71154 L
.43705 .69231 L
.44231 .68069 L
.44723 .67308 L
.46076 .65385 L
.46154 .65284 L
.47751 .63462 L
.48077 .6312 L
.4973 .61538 L
.5 .613 L
.51923 .597 L
.52031 .59615 L
.53846 .58288 L
.547 .57692 L
.55769 .57015 L
.57692 .55826 L
.57789 .55769 L
.59615 .54795 L
.61455 .53846 L
.61538 .5381 L
.63462 .52975 L
.65385 .52178 L
.66046 .51923 L
.67308 .51515 L
.69231 .50929 L
.71154 .50425 L
.73077 .50031 L
.73165 .5 L
F
0 g
.75 .49779 m
.76923 .49656 L
.78846 .49698 L
.80769 .49964 L
.80947 .5 L
.82692 .5057 L
.84615 .51868 L
.84667 .51923 L
.85782 .53846 L
.85974 .55769 L
.85589 .57692 L
.84781 .59615 L
.84615 .59948 L
.83604 .61538 L
.82692 .62775 L
.82111 .63462 L
.80769 .64926 L
.80306 .65385 L
.78846 .66738 L
.78185 .67308 L
.76923 .68321 L
.75728 .69231 L
.75 .69737 L
.73077 .71035 L
.72892 .71154 L
.71154 .72175 L
.69569 .73077 L
.69231 .73243 L
.67308 .74186 L
.65564 .75 L
.65385 .7507 L
.63462 .75814 L
.61538 .76513 L
.60279 .76923 L
.59615 .77099 L
.57692 .77572 L
.55769 .77957 L
.53846 .78225 L
.51923 .78351 L
.5 .78303 L
.48077 .78028 L
.46154 .77409 L
.45249 .76923 L
.44231 .76168 L
.43442 .75 L
.42913 .73077 L
.43069 .71154 L
.43705 .69231 L
.44231 .68069 L
.44723 .67308 L
Mistroke
.46076 .65385 L
.46154 .65284 L
.47751 .63462 L
.48077 .6312 L
.4973 .61538 L
.5 .613 L
.51923 .597 L
.52031 .59615 L
.53846 .58288 L
.547 .57692 L
.55769 .57015 L
.57692 .55826 L
.57789 .55769 L
.59615 .54795 L
.61455 .53846 L
.61538 .5381 L
.63462 .52975 L
.65385 .52178 L
.66046 .51923 L
.67308 .51515 L
.69231 .50929 L
.71154 .50425 L
.73077 .50031 L
.73165 .5 L
.75 .49779 L
Mfstroke
.3 g
.73077 .51874 m
.75 .5173 L
.76923 .51778 L
.78032 .51923 L
.78846 .52098 L
.80769 .52865 L
.81899 .53846 L
.82692 .55323 L
.82799 .55769 L
.82764 .57692 L
.82692 .58025 L
.82143 .59615 L
.81075 .61538 L
.80769 .62006 L
.79619 .63462 L
.78846 .64337 L
.77802 .65385 L
.76923 .662 L
.75616 .67308 L
.75 .6779 L
.73077 .69195 L
.73025 .69231 L
.71154 .70426 L
.69934 .71154 L
.69231 .71533 L
.67308 .72525 L
.66152 .73077 L
.65385 .73401 L
.63462 .74169 L
.61538 .74846 L
.61062 .75 L
.59615 .75389 L
.57692 .75821 L
.55769 .76125 L
.53846 .76273 L
.51923 .76221 L
.5 .75895 L
.48077 .75082 L
.47952 .75 L
.46329 .73077 L
.46154 .72529 L
.46022 .71154 L
.46154 .70166 L
.46409 .69231 L
.47294 .67308 L
.48077 .66024 L
.48582 .65385 L
.5 .63708 L
.50239 .63462 L
.51923 .61835 L
.52262 .61538 L
.53846 .60241 L
.54672 .59615 L
.55769 .58846 L
.57526 .57692 L
.57692 .57594 L
.59615 .56491 L
.60967 .55769 L
.61538 .55497 L
.63462 .5462 L
.65345 .53846 L
.65385 .53832 L
.67308 .53184 L
.69231 .52623 L
.71154 .52179 L
.72565 .51923 L
F
0 g
.73077 .51874 m
.75 .5173 L
.76923 .51778 L
.78032 .51923 L
.78846 .52098 L
.80769 .52865 L
.81899 .53846 L
.82692 .55323 L
.82799 .55769 L
.82764 .57692 L
.82692 .58025 L
.82143 .59615 L
.81075 .61538 L
.80769 .62006 L
.79619 .63462 L
.78846 .64337 L
.77802 .65385 L
.76923 .662 L
.75616 .67308 L
.75 .6779 L
.73077 .69195 L
.73025 .69231 L
.71154 .70426 L
.69934 .71154 L
.69231 .71533 L
.67308 .72525 L
.66152 .73077 L
.65385 .73401 L
.63462 .74169 L
.61538 .74846 L
.61062 .75 L
.59615 .75389 L
.57692 .75821 L
.55769 .76125 L
.53846 .76273 L
.51923 .76221 L
.5 .75895 L
.48077 .75082 L
.47952 .75 L
.46329 .73077 L
.46154 .72529 L
.46022 .71154 L
.46154 .70166 L
.46409 .69231 L
.47294 .67308 L
.48077 .66024 L
.48582 .65385 L
.5 .63708 L
.50239 .63462 L
.51923 .61835 L
Mistroke
.52262 .61538 L
.53846 .60241 L
.54672 .59615 L
.55769 .58846 L
.57526 .57692 L
.57692 .57594 L
.59615 .56491 L
.60967 .55769 L
.61538 .55497 L
.63462 .5462 L
.65345 .53846 L
.65385 .53832 L
.67308 .53184 L
.69231 .52623 L
.71154 .52179 L
.72565 .51923 L
.73077 .51874 L
Mfstroke
.4 g
.71154 .53617 m
.73077 .53408 L
.75 .53407 L
.76923 .53711 L
.77409 .53846 L
.78846 .54454 L
.79932 .55769 L
.80383 .57692 L
.79995 .59615 L
.79045 .61538 L
.78846 .61876 L
.77635 .63462 L
.76923 .64279 L
.75805 .65385 L
.75 .66118 L
.73545 .67308 L
.73077 .67661 L
.71154 .68999 L
.70793 .69231 L
.69231 .70161 L
.67389 .71154 L
.67308 .71193 L
.65385 .7208 L
.63462 .72859 L
.6287 .73077 L
.61538 .73499 L
.59615 .74015 L
.57692 .74392 L
.55769 .74601 L
.53846 .74597 L
.51923 .74298 L
.5 .73417 L
.49619 .73077 L
.48568 .71154 L
.48641 .69231 L
.49365 .67308 L
.5 .66086 L
.5058 .65385 L
.51923 .63763 L
.52225 .63462 L
.53846 .61916 L
.54293 .61538 L
.55769 .6037 L
.5682 .59615 L
.57692 .59035 L
.59615 .57858 L
.59907 .57692 L
.61538 .56838 L
.63462 .55932 L
.63834 .55769 L
.65385 .55167 L
.67308 .54514 L
.69231 .5399 L
.69731 .53846 L
F
0 g
.71154 .53617 m
.73077 .53408 L
.75 .53407 L
.76923 .53711 L
.77409 .53846 L
.78846 .54454 L
.79932 .55769 L
.80383 .57692 L
.79995 .59615 L
.79045 .61538 L
.78846 .61876 L
.77635 .63462 L
.76923 .64279 L
.75805 .65385 L
.75 .66118 L
.73545 .67308 L
.73077 .67661 L
.71154 .68999 L
.70793 .69231 L
.69231 .70161 L
.67389 .71154 L
.67308 .71193 L
.65385 .7208 L
.63462 .72859 L
.6287 .73077 L
.61538 .73499 L
.59615 .74015 L
.57692 .74392 L
.55769 .74601 L
.53846 .74597 L
.51923 .74298 L
.5 .73417 L
.49619 .73077 L
.48568 .71154 L
.48641 .69231 L
.49365 .67308 L
.5 .66086 L
.5058 .65385 L
.51923 .63763 L
.52225 .63462 L
.53846 .61916 L
.54293 .61538 L
.55769 .6037 L
.5682 .59615 L
.57692 .59035 L
.59615 .57858 L
.59907 .57692 L
.61538 .56838 L
.63462 .55932 L
.63834 .55769 L
Mistroke
.65385 .55167 L
.67308 .54514 L
.69231 .5399 L
.69731 .53846 L
.71154 .53617 L
Mfstroke
.5 g
.67308 .55697 m
.69231 .55223 L
.71154 .5492 L
.73077 .54832 L
.75 .55055 L
.76737 .55769 L
.76923 .55921 L
.78109 .57692 L
.78044 .59615 L
.77239 .61538 L
.76923 .6215 L
.75885 .63462 L
.75 .64479 L
.74041 .65385 L
.73077 .66235 L
.7169 .67308 L
.71154 .67691 L
.69231 .68938 L
.68731 .69231 L
.67308 .70002 L
.65385 .70921 L
.6485 .71154 L
.63462 .71688 L
.61538 .72317 L
.59615 .72791 L
.57771 .73077 L
.57692 .73085 L
.55769 .73161 L
.54716 .73077 L
.53846 .72939 L
.51923 .72272 L
.51109 .71154 L
.50702 .69231 L
.5122 .67308 L
.51923 .6601 L
.52345 .65385 L
.53846 .63577 L
.53976 .63462 L
.55769 .618 L
.56098 .61538 L
.57692 .60336 L
.58771 .59615 L
.59615 .59093 L
.61538 .58017 L
.6218 .57692 L
.63462 .57103 L
.65385 .56326 L
.67049 .55769 L
F
0 g
.67308 .55697 m
.69231 .55223 L
.71154 .5492 L
.73077 .54832 L
.75 .55055 L
.76737 .55769 L
.76923 .55921 L
.78109 .57692 L
.78044 .59615 L
.77239 .61538 L
.76923 .6215 L
.75885 .63462 L
.75 .64479 L
.74041 .65385 L
.73077 .66235 L
.7169 .67308 L
.71154 .67691 L
.69231 .68938 L
.68731 .69231 L
.67308 .70002 L
.65385 .70921 L
.6485 .71154 L
.63462 .71688 L
.61538 .72317 L
.59615 .72791 L
.57771 .73077 L
.57692 .73085 L
.55769 .73161 L
.54716 .73077 L
.53846 .72939 L
.51923 .72272 L
.51109 .71154 L
.50702 .69231 L
.5122 .67308 L
.51923 .6601 L
.52345 .65385 L
.53846 .63577 L
.53976 .63462 L
.55769 .618 L
.56098 .61538 L
.57692 .60336 L
.58771 .59615 L
.59615 .59093 L
.61538 .58017 L
.6218 .57692 L
.63462 .57103 L
.65385 .56326 L
.67049 .55769 L
.67308 .55697 L
s
.6 g
.65385 .57428 m
.67308 .5682 L
.69231 .56397 L
.71154 .56196 L
.73077 .5628 L
.75 .56903 L
.75626 .57692 L
.76117 .59615 L
.75516 .61538 L
.75 .62832 L
.74234 .63462 L
.73077 .64787 L
.72371 .65385 L
.71154 .66414 L
.69899 .67308 L
.69231 .67752 L
.67308 .68884 L
.66635 .69231 L
.65385 .6982 L
.63462 .70595 L
.61678 .71154 L
.61538 .71188 L
.59615 .71604 L
.57692 .71797 L
.55769 .71673 L
.54126 .71154 L
.53846 .7087 L
.52799 .69231 L
.5301 .67308 L
.53846 .65643 L
.54016 .65385 L
.55629 .63462 L
.55769 .63315 L
.57692 .61631 L
.57822 .61538 L
.59615 .60268 L
.60698 .59615 L
.61538 .59146 L
.63462 .58196 L
.64661 .57692 L
F
0 g
.65385 .57428 m
.67308 .5682 L
.69231 .56397 L
.71154 .56196 L
.73077 .5628 L
.75 .56903 L
.75626 .57692 L
.76117 .59615 L
.75516 .61538 L
.75 .62832 L
.74234 .63462 L
.73077 .64787 L
.72371 .65385 L
.71154 .66414 L
.69899 .67308 L
.69231 .67752 L
.67308 .68884 L
.66635 .69231 L
.65385 .6982 L
.63462 .70595 L
.61678 .71154 L
.61538 .71188 L
.59615 .71604 L
.57692 .71797 L
.55769 .71673 L
.54126 .71154 L
.53846 .7087 L
.52799 .69231 L
.5301 .67308 L
.53846 .65643 L
.54016 .65385 L
.55629 .63462 L
.55769 .63315 L
.57692 .61631 L
.57822 .61538 L
.59615 .60268 L
.60698 .59615 L
.61538 .59146 L
.63462 .58196 L
.64661 .57692 L
.65385 .57428 L
s
.7 g
.69231 .57643 m
.71154 .57642 L
.71478 .57692 L
.73077 .58294 L
.7402 .59615 L
.73757 .61538 L
.73077 .62774 L
.72581 .63462 L
.71154 .6511 L
.70689 .65385 L
.69231 .66558 L
.68035 .67308 L
.67308 .67742 L
.65385 .68735 L
.64188 .69231 L
.63462 .69487 L
.61538 .70063 L
.59615 .70408 L
.57692 .70473 L
.55769 .69978 L
.55258 .69231 L
.54874 .67308 L
.55702 .65385 L
.55769 .65242 L
.57284 .63462 L
.57692 .6304 L
.59586 .61538 L
.59615 .61517 L
.61538 .60264 L
.628 .59615 L
.63462 .59303 L
.65385 .58513 L
.67308 .57947 L
.68813 .57692 L
F
0 g
.69231 .57643 m
.71154 .57642 L
.71478 .57692 L
.73077 .58294 L
.7402 .59615 L
.73757 .61538 L
.73077 .62774 L
.72581 .63462 L
.71154 .6511 L
.70689 .65385 L
.69231 .66558 L
.68035 .67308 L
.67308 .67742 L
.65385 .68735 L
.64188 .69231 L
.63462 .69487 L
.61538 .70063 L
.59615 .70408 L
.57692 .70473 L
.55769 .69978 L
.55258 .69231 L
.54874 .67308 L
.55702 .65385 L
.55769 .65242 L
.57284 .63462 L
.57692 .6304 L
.59586 .61538 L
.59615 .61517 L
.61538 .60264 L
.628 .59615 L
.63462 .59303 L
.65385 .58513 L
.67308 .57947 L
.68813 .57692 L
.69231 .57643 L
s
.8 g
.67308 .59203 m
.69231 .58992 L
.71067 .59615 L
.71154 .59679 L
.71784 .61538 L
.71154 .62925 L
.70799 .63462 L
.69231 .65061 L
.68862 .65385 L
.67308 .66587 L
.65836 .67308 L
.65385 .67527 L
.63462 .6836 L
.61538 .68931 L
.59615 .68904 L
.57692 .68281 L
.57063 .67308 L
.5754 .65385 L
.57692 .65136 L
.59069 .63462 L
.59615 .62879 L
.61538 .61561 L
.61569 .61538 L
.63462 .60427 L
.65385 .5968 L
.65749 .59615 L
F
0 g
.67308 .59203 m
.69231 .58992 L
.71067 .59615 L
.71154 .59679 L
.71784 .61538 L
.71154 .62925 L
.70799 .63462 L
.69231 .65061 L
.68862 .65385 L
.67308 .66587 L
.65836 .67308 L
.65385 .67527 L
.63462 .6836 L
.61538 .68931 L
.59615 .68904 L
.57692 .68281 L
.57063 .67308 L
.5754 .65385 L
.57692 .65136 L
.59069 .63462 L
.59615 .62879 L
.61538 .61561 L
.61569 .61538 L
.63462 .60427 L
.65385 .5968 L
.65749 .59615 L
.67308 .59203 L
s
.9 g
.65385 .61123 m
.67308 .60952 L
.68836 .61538 L
.68703 .63462 L
.67308 .64748 L
.66688 .65385 L
.65385 .66367 L
.63462 .66774 L
.61538 .67052 L
.59929 .65385 L
.61306 .63462 L
.61538 .63281 L
.63462 .62017 L
.64503 .61538 L
F
0 g
.65385 .61123 m
.67308 .60952 L
.68836 .61538 L
.68703 .63462 L
.67308 .64748 L
.66688 .65385 L
.65385 .66367 L
.63462 .66774 L
.61538 .67052 L
.59929 .65385 L
.61306 .63462 L
.61538 .63281 L
.63462 .62017 L
.64503 .61538 L
.65385 .61123 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.522676 0.0238095 0.97619 0.477324 MathSubStart
%% SurfaceGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.11022e-16 1.04977 -0.0679587 1.04977 [
[ 0 0 0 0 ]
[ 1 .81114 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.39787 .81114 L
s
.39787 .81114 m
.40529 .59895 L
s
.40529 .59895 m
.03716 .25514 L
s
.68874 0 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.68874 0 m
.03716 .25514 L
s
.40529 .59895 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.39787 .81114 L
s
.39787 .81114 m
.40529 .59895 L
s
0 0 m
1 0 L
1 .81114 L
0 .81114 L
closepath
clip
newpath
.664 .741 .908 r
.39902 .59803 .40512 .60371 .41537 .60064 .40929 .59494 Mtetra
.40929 .59494 .41537 .60064 .42565 .59755 .4196 .59183 Mtetra
.4196 .59183 .42565 .59755 .43597 .59446 .42994 .58871 Mtetra
.42994 .58871 .43597 .59446 .44633 .59135 .44033 .58558 Mtetra
.44033 .58558 .44633 .59135 .45674 .58823 .45076 .58244 Mtetra
.45076 .58244 .45674 .58823 .46718 .5851 .46122 .57928 Mtetra
.663 .741 .908 r
.46122 .57928 .46718 .5851 .47766 .58195 .47173 .57612 Mtetra
.47173 .57612 .47766 .58195 .48818 .5788 .48228 .57294 Mtetra
.48228 .57294 .48818 .5788 .49874 .57563 .49287 .56975 Mtetra
.49287 .56975 .49874 .57563 .50935 .57245 .5035 .56655 Mtetra
.5035 .56655 .50935 .57245 .51999 .56926 .51417 .56334 Mtetra
.663 .742 .908 r
.51417 .56334 .51999 .56926 .53068 .56605 .52489 .56011 Mtetra
.52489 .56011 .53068 .56605 .54141 .56284 .53564 .55688 Mtetra
.53564 .55688 .54141 .56284 .55218 .55961 .54644 .55363 Mtetra
.54644 .55363 .55218 .55961 .56299 .55636 .55728 .55036 Mtetra
.55728 .55036 .56299 .55636 .57385 .55311 .56816 .54709 Mtetra
.56816 .54709 .57385 .55311 .58474 .54984 .57909 .54379 Mtetra
.664 .742 .909 r
.57909 .54379 .58474 .54984 .59568 .54656 .59006 .54049 Mtetra
.59006 .54049 .59568 .54656 .60667 .54326 .60107 .53717 Mtetra
.664 .742 .908 r
.60107 .53717 .60667 .54326 .61769 .53995 .61213 .53383 Mtetra
.61213 .53383 .61769 .53995 .62876 .53663 .62323 .53048 Mtetra
.62323 .53048 .62876 .53663 .63988 .53329 .63437 .52712 Mtetra
.63437 .52712 .63988 .53329 .65104 .52994 .64556 .52374 Mtetra
.64556 .52374 .65104 .52994 .66224 .52658 .65679 .52035 Mtetra
.65679 .52035 .66224 .52658 .67349 .52321 .66807 .51695 Mtetra
.66807 .51695 .67349 .52321 .68478 .51982 .67939 .51353 Mtetra
.67939 .51353 .68478 .51982 .69612 .51642 .69076 .5101 Mtetra
.664 .741 .908 r
.69076 .5101 .69612 .51642 .7075 .513 .70218 .50666 Mtetra
.70218 .50666 .7075 .513 .71893 .50957 .71364 .50321 Mtetra
.71364 .50321 .71893 .50957 .73041 .50613 .72515 .49974 Mtetra
.72515 .49974 .73041 .50613 .74193 .50267 .7367 .49625 Mtetra
.7367 .49625 .74193 .50267 .7535 .4992 .7483 .49276 Mtetra
.7483 .49276 .7535 .4992 .76511 .49572 .75995 .48925 Mtetra
.75995 .48925 .76511 .49572 .77677 .49222 .77165 .48572 Mtetra
.77165 .48572 .77677 .49222 .78848 .48871 .78339 .48218 Mtetra
.78339 .48218 .78848 .48871 .80024 .48518 .79518 .47863 Mtetra
.79518 .47863 .80024 .48518 .81205 .48164 .80702 .47506 Mtetra
.80702 .47506 .81205 .48164 .8239 .47808 .81891 .47148 Mtetra
.81891 .47148 .8239 .47808 .8358 .47451 .83085 .46788 Mtetra
.83085 .46788 .8358 .47451 .84775 .47092 .84283 .46427 Mtetra
.84283 .46427 .84775 .47092 .85976 .46732 .85487 .46064 Mtetra
.85487 .46064 .85976 .46732 .87181 .46371 .86696 .45699 Mtetra
.86696 .45699 .87181 .46371 .88391 .46008 .87909 .45334 Mtetra
.87909 .45334 .88391 .46008 .89606 .45643 .89128 .44966 Mtetra
.89128 .44966 .89606 .45643 .90826 .45277 .90352 .44598 Mtetra
.90352 .44598 .90826 .45277 .92051 .4491 .91581 .44227 Mtetra
.91581 .44227 .92051 .4491 .93281 .44541 .92815 .43855 Mtetra
.92815 .43855 .93281 .44541 .94517 .4417 .94054 .43482 Mtetra
.94054 .43482 .94517 .4417 .95757 .43798 .95299 .43107 Mtetra
.95299 .43107 .95757 .43798 .97003 .43424 .96548 .4273 Mtetra
.39287 .59231 .39902 .59803 .40929 .59494 .40317 .58919 Mtetra
.40317 .58919 .40929 .59494 .4196 .59183 .4135 .58606 Mtetra
.4135 .58606 .4196 .59183 .42994 .58871 .42387 .58292 Mtetra
.42387 .58292 .42994 .58871 .44033 .58558 .43428 .57977 Mtetra
.43428 .57977 .44033 .58558 .45076 .58244 .44474 .5766 Mtetra
.663 .741 .908 r
.44474 .5766 .45076 .58244 .46122 .57928 .45523 .57343 Mtetra
.45523 .57343 .46122 .57928 .47173 .57612 .46576 .57024 Mtetra
.46576 .57024 .47173 .57612 .48228 .57294 .47634 .56704 Mtetra
.47634 .56704 .48228 .57294 .49287 .56975 .48695 .56383 Mtetra
.48695 .56383 .49287 .56975 .5035 .56655 .49761 .56061 Mtetra
.663 .742 .908 r
.49761 .56061 .5035 .56655 .51417 .56334 .50831 .55738 Mtetra
.50831 .55738 .51417 .56334 .52489 .56011 .51905 .55414 Mtetra
.663 .742 .909 r
.51905 .55414 .52489 .56011 .53564 .55688 .52983 .55089 Mtetra
.52983 .55089 .53564 .55688 .54644 .55363 .54066 .54762 Mtetra
.54066 .54762 .54644 .55363 .55728 .55036 .55153 .54434 Mtetra
.663 .743 .909 r
.55153 .54434 .55728 .55036 .56816 .54709 .56244 .54105 Mtetra
.56244 .54105 .56816 .54709 .57909 .54379 .5734 .53774 Mtetra
.5734 .53774 .57909 .54379 .59006 .54049 .58439 .53441 Mtetra
.664 .743 .909 r
.58439 .53441 .59006 .54049 .60107 .53717 .59544 .53107 Mtetra
.59544 .53107 .60107 .53717 .61213 .53383 .60652 .52771 Mtetra
.60652 .52771 .61213 .53383 .62323 .53048 .61765 .52433 Mtetra
.61765 .52433 .62323 .53048 .63437 .52712 .62882 .52093 Mtetra
.62882 .52093 .63437 .52712 .64556 .52374 .64004 .51752 Mtetra
.64004 .51752 .64556 .52374 .65679 .52035 .65131 .5141 Mtetra
.65131 .5141 .65679 .52035 .66807 .51695 .66262 .51067 Mtetra
.664 .742 .908 r
.66262 .51067 .66807 .51695 .67939 .51353 .67397 .50722 Mtetra
.67397 .50722 .67939 .51353 .69076 .5101 .68537 .50376 Mtetra
.68537 .50376 .69076 .5101 .70218 .50666 .69682 .50028 Mtetra
.69682 .50028 .70218 .50666 .71364 .50321 .70831 .4968 Mtetra
.70831 .4968 .71364 .50321 .72515 .49974 .71985 .4933 Mtetra
.664 .741 .908 r
.71985 .4933 .72515 .49974 .7367 .49625 .73144 .48979 Mtetra
.73144 .48979 .7367 .49625 .7483 .49276 .74307 .48627 Mtetra
.74307 .48627 .7483 .49276 .75995 .48925 .75475 .48273 Mtetra
.75475 .48273 .75995 .48925 .77165 .48572 .76648 .47918 Mtetra
.76648 .47918 .77165 .48572 .78339 .48218 .77826 .47561 Mtetra
.77826 .47561 .78339 .48218 .79518 .47863 .79008 .47203 Mtetra
.79008 .47203 .79518 .47863 .80702 .47506 .80196 .46843 Mtetra
.80196 .46843 .80702 .47506 .81891 .47148 .81388 .46482 Mtetra
.81388 .46482 .81891 .47148 .83085 .46788 .82585 .4612 Mtetra
.82585 .4612 .83085 .46788 .84283 .46427 .83788 .45756 Mtetra
.83788 .45756 .84283 .46427 .85487 .46064 .84995 .4539 Mtetra
.84995 .4539 .85487 .46064 .86696 .45699 .86207 .45023 Mtetra
.86207 .45023 .86696 .45699 .87909 .45334 .87424 .44654 Mtetra
.87424 .44654 .87909 .45334 .89128 .44966 .88647 .44284 Mtetra
.88647 .44284 .89128 .44966 .90352 .44598 .89874 .43913 Mtetra
.89874 .43913 .90352 .44598 .91581 .44227 .91107 .43539 Mtetra
.91107 .43539 .91581 .44227 .92815 .43855 .92345 .43164 Mtetra
.92345 .43164 .92815 .43855 .94054 .43482 .93588 .42788 Mtetra
.93588 .42788 .94054 .43482 .95299 .43107 .94836 .4241 Mtetra
.94836 .4241 .95299 .43107 .96548 .4273 .9609 .4203 Mtetra
.38668 .58654 .39287 .59231 .40317 .58919 .397 .5834 Mtetra
.397 .5834 .40317 .58919 .4135 .58606 .40736 .58025 Mtetra
.40736 .58025 .4135 .58606 .42387 .58292 .41776 .57709 Mtetra
.41776 .57709 .42387 .58292 .43428 .57977 .42819 .57392 Mtetra
.663 .741 .908 r
.42819 .57392 .43428 .57977 .44474 .5766 .43867 .57073 Mtetra
.43867 .57073 .44474 .5766 .45523 .57343 .44919 .56753 Mtetra
.44919 .56753 .45523 .57343 .46576 .57024 .45975 .56432 Mtetra
.45975 .56432 .46576 .57024 .47634 .56704 .47035 .56111 Mtetra
.47035 .56111 .47634 .56704 .48695 .56383 .48099 .55788 Mtetra
.663 .742 .908 r
.48099 .55788 .48695 .56383 .49761 .56061 .49168 .55464 Mtetra
.663 .742 .909 r
.49168 .55464 .49761 .56061 .50831 .55738 .5024 .5514 Mtetra
.5024 .5514 .50831 .55738 .51905 .55414 .51317 .54814 Mtetra
.51317 .54814 .51905 .55414 .52983 .55089 .52398 .54488 Mtetra
.662 .743 .91 r
.52398 .54488 .52983 .55089 .54066 .54762 .53484 .54161 Mtetra
.53484 .54161 .54066 .54762 .55153 .54434 .54574 .53832 Mtetra
.662 .744 .911 r
.54574 .53832 .55153 .54434 .56244 .54105 .55668 .53502 Mtetra
.663 .745 .911 r
.55668 .53502 .56244 .54105 .5734 .53774 .56766 .53171 Mtetra
.56766 .53171 .5734 .53774 .58439 .53441 .57869 .52837 Mtetra
.663 .746 .912 r
.57869 .52837 .58439 .53441 .59544 .53107 .58976 .52501 Mtetra
.58976 .52501 .59544 .53107 .60652 .52771 .60087 .52162 Mtetra
.664 .746 .912 r
.60087 .52162 .60652 .52771 .61765 .52433 .61203 .51822 Mtetra
.664 .746 .911 r
.61203 .51822 .61765 .52433 .62882 .52093 .62324 .51479 Mtetra
.62324 .51479 .62882 .52093 .64004 .51752 .63449 .51134 Mtetra
.63449 .51134 .64004 .51752 .65131 .5141 .64578 .50787 Mtetra
.664 .745 .91 r
.64578 .50787 .65131 .5141 .66262 .51067 .65712 .50439 Mtetra
.664 .744 .91 r
.65712 .50439 .66262 .51067 .67397 .50722 .66851 .5009 Mtetra
.664 .744 .909 r
.66851 .5009 .67397 .50722 .68537 .50376 .67994 .4974 Mtetra
.664 .743 .909 r
.67994 .4974 .68537 .50376 .69682 .50028 .69142 .49388 Mtetra
.69142 .49388 .69682 .50028 .70831 .4968 .70294 .49036 Mtetra
.664 .742 .908 r
.70294 .49036 .70831 .4968 .71985 .4933 .71451 .48683 Mtetra
.71451 .48683 .71985 .4933 .73144 .48979 .72613 .48329 Mtetra
.72613 .48329 .73144 .48979 .74307 .48627 .7378 .47973 Mtetra
.7378 .47973 .74307 .48627 .75475 .48273 .74951 .47616 Mtetra
.664 .741 .908 r
.74951 .47616 .75475 .48273 .76648 .47918 .76127 .47258 Mtetra
.76127 .47258 .76648 .47918 .77826 .47561 .77309 .46899 Mtetra
.77309 .46899 .77826 .47561 .79008 .47203 .78495 .46538 Mtetra
.78495 .46538 .79008 .47203 .80196 .46843 .79686 .46176 Mtetra
.79686 .46176 .80196 .46843 .81388 .46482 .80881 .45812 Mtetra
.80881 .45812 .81388 .46482 .82585 .4612 .82082 .45446 Mtetra
.82082 .45446 .82585 .4612 .83788 .45756 .83288 .4508 Mtetra
.83288 .4508 .83788 .45756 .84995 .4539 .84499 .44711 Mtetra
.84499 .44711 .84995 .4539 .86207 .45023 .85715 .44341 Mtetra
.85715 .44341 .86207 .45023 .87424 .44654 .86936 .4397 Mtetra
.86936 .4397 .87424 .44654 .88647 .44284 .88162 .43597 Mtetra
.88162 .43597 .88647 .44284 .89874 .43913 .89393 .43222 Mtetra
.89393 .43222 .89874 .43913 .91107 .43539 .9063 .42846 Mtetra
.9063 .42846 .91107 .43539 .92345 .43164 .91871 .42468 Mtetra
.91871 .42468 .92345 .43164 .93588 .42788 .93118 .42089 Mtetra
.93118 .42089 .93588 .42788 .94836 .4241 .94371 .41708 Mtetra
.94371 .41708 .94836 .4241 .9609 .4203 .95628 .41325 Mtetra
.38045 .58074 .38668 .58654 .397 .5834 .39079 .57758 Mtetra
.39079 .57758 .397 .5834 .40736 .58025 .40117 .5744 Mtetra
.40117 .5744 .40736 .58025 .41776 .57709 .4116 .57122 Mtetra
.4116 .57122 .41776 .57709 .42819 .57392 .42206 .56802 Mtetra
.663 .741 .908 r
.42206 .56802 .42819 .57392 .43867 .57073 .43256 .56481 Mtetra
.43256 .56481 .43867 .57073 .44919 .56753 .44311 .56159 Mtetra
.44311 .56159 .44919 .56753 .45975 .56432 .45369 .55837 Mtetra
.45369 .55837 .45975 .56432 .47035 .56111 .46432 .55513 Mtetra
.46432 .55513 .47035 .56111 .48099 .55788 .47499 .55188 Mtetra
.663 .742 .909 r
.47499 .55188 .48099 .55788 .49168 .55464 .4857 .54863 Mtetra
.662 .742 .909 r
.4857 .54863 .49168 .55464 .5024 .5514 .49646 .54538 Mtetra
.662 .742 .91 r
.49646 .54538 .5024 .5514 .51317 .54814 .50725 .54212 Mtetra
.662 .743 .91 r
.50725 .54212 .51317 .54814 .52398 .54488 .51809 .53887 Mtetra
.661 .744 .911 r
.51809 .53887 .52398 .54488 .53484 .54161 .52897 .5356 Mtetra
.661 .745 .912 r
.52897 .5356 .53484 .54161 .54574 .53832 .5399 .53234 Mtetra
.661 .746 .913 r
.5399 .53234 .54574 .53832 .55668 .53502 .55087 .52906 Mtetra
.661 .748 .914 r
.55087 .52906 .55668 .53502 .56766 .53171 .56188 .52576 Mtetra
.661 .749 .915 r
.56188 .52576 .56766 .53171 .57869 .52837 .57294 .52244 Mtetra
.662 .751 .916 r
.57294 .52244 .57869 .52837 .58976 .52501 .58404 .51908 Mtetra
.663 .752 .917 r
.58404 .51908 .58976 .52501 .60087 .52162 .59519 .51569 Mtetra
.663 .753 .917 r
.59519 .51569 .60087 .52162 .61203 .51822 .60638 .51226 Mtetra
.664 .753 .916 r
.60638 .51226 .61203 .51822 .62324 .51479 .61762 .50879 Mtetra
.665 .753 .916 r
.61762 .50879 .62324 .51479 .63449 .51134 .6289 .50529 Mtetra
.665 .752 .915 r
.6289 .50529 .63449 .51134 .64578 .50787 .64022 .50177 Mtetra
.666 .751 .914 r
.64022 .50177 .64578 .50787 .65712 .50439 .65159 .49822 Mtetra
.666 .75 .913 r
.65159 .49822 .65712 .50439 .66851 .5009 .66301 .49466 Mtetra
.666 .748 .912 r
.66301 .49466 .66851 .5009 .67994 .4974 .67447 .49109 Mtetra
.665 .747 .911 r
.67447 .49109 .67994 .4974 .69142 .49388 .68598 .48751 Mtetra
.665 .745 .91 r
.68598 .48751 .69142 .49388 .70294 .49036 .69753 .48393 Mtetra
.665 .744 .909 r
.69753 .48393 .70294 .49036 .71451 .48683 .70914 .48035 Mtetra
.664 .743 .909 r
.70914 .48035 .71451 .48683 .72613 .48329 .72079 .47676 Mtetra
.72079 .47676 .72613 .48329 .7378 .47973 .73249 .47316 Mtetra
.664 .742 .908 r
.73249 .47316 .7378 .47973 .74951 .47616 .74423 .46956 Mtetra
.74423 .46956 .74951 .47616 .76127 .47258 .75603 .46594 Mtetra
.75603 .46594 .76127 .47258 .77309 .46899 .76788 .46232 Mtetra
.664 .741 .908 r
.76788 .46232 .77309 .46899 .78495 .46538 .77977 .45868 Mtetra
.77977 .45868 .78495 .46538 .79686 .46176 .79171 .45503 Mtetra
.79171 .45503 .79686 .46176 .80881 .45812 .80371 .45136 Mtetra
.80371 .45136 .80881 .45812 .82082 .45446 .81575 .44768 Mtetra
.81575 .44768 .82082 .45446 .83288 .4508 .82785 .44398 Mtetra
.82785 .44398 .83288 .4508 .84499 .44711 .83999 .44027 Mtetra
.83999 .44027 .84499 .44711 .85715 .44341 .85219 .43654 Mtetra
.85219 .43654 .85715 .44341 .86936 .4397 .86443 .4328 Mtetra
.86443 .4328 .86936 .4397 .88162 .43597 .87673 .42904 Mtetra
.87673 .42904 .88162 .43597 .89393 .43222 .88908 .42526 Mtetra
.88908 .42526 .89393 .43222 .9063 .42846 .90148 .42147 Mtetra
.90148 .42147 .9063 .42846 .91871 .42468 .91394 .41767 Mtetra
.91394 .41767 .91871 .42468 .93118 .42089 .92645 .41384 Mtetra
.92645 .41384 .93118 .42089 .94371 .41708 .93901 .41 Mtetra
.93901 .41 .94371 .41708 .95628 .41325 .95162 .40615 Mtetra
.37417 .57489 .38045 .58074 .39079 .57758 .38454 .57171 Mtetra
.38454 .57171 .39079 .57758 .40117 .5744 .39494 .56851 Mtetra
.39494 .56851 .40117 .5744 .4116 .57122 .40539 .56531 Mtetra
.663 .741 .908 r
.40539 .56531 .4116 .57122 .42206 .56802 .41588 .56209 Mtetra
.41588 .56209 .42206 .56802 .43256 .56481 .42641 .55885 Mtetra
.42641 .55885 .43256 .56481 .44311 .56159 .43698 .55561 Mtetra
.43698 .55561 .44311 .56159 .45369 .55837 .44759 .55236 Mtetra
.44759 .55236 .45369 .55837 .46432 .55513 .45825 .54911 Mtetra
.663 .741 .909 r
.45825 .54911 .46432 .55513 .47499 .55188 .46894 .54585 Mtetra
.662 .742 .909 r
.46894 .54585 .47499 .55188 .4857 .54863 .47968 .54259 Mtetra
.662 .742 .91 r
.47968 .54259 .4857 .54863 .49646 .54538 .49046 .53933 Mtetra
.661 .742 .91 r
.49046 .53933 .49646 .54538 .50725 .54212 .50129 .53609 Mtetra
.66 .743 .912 r
.50129 .53609 .50725 .54212 .51809 .53887 .51215 .53285 Mtetra
.659 .744 .913 r
.51215 .53285 .51809 .53887 .52897 .5356 .52306 .52962 Mtetra
.658 .746 .915 r
.52306 .52962 .52897 .5356 .5399 .53234 .53402 .52641 Mtetra
.657 .749 .917 r
.53402 .52641 .5399 .53234 .55087 .52906 .54502 .52319 Mtetra
.657 .751 .919 r
.54502 .52319 .55087 .52906 .56188 .52576 .55606 .51996 Mtetra
.657 .755 .922 r
.55606 .51996 .56188 .52576 .57294 .52244 .56715 .51671 Mtetra
.658 .758 .924 r
.56715 .51671 .57294 .52244 .58404 .51908 .57829 .51341 Mtetra
.659 .761 .925 r
.57829 .51341 .58404 .51908 .59519 .51569 .58947 .51006 Mtetra
.661 .764 .926 r
.58947 .51006 .59519 .51569 .60638 .51226 .60069 .50664 Mtetra
.663 .766 .927 r
.60069 .50664 .60638 .51226 .61762 .50879 .61196 .50316 Mtetra
.665 .767 .926 r
.61196 .50316 .61762 .50879 .6289 .50529 .62327 .49961 Mtetra
.666 .767 .925 r
.62327 .49961 .6289 .50529 .64022 .50177 .63463 .496 Mtetra
.668 .765 .923 r
.63463 .496 .64022 .50177 .65159 .49822 .64603 .49235 Mtetra
.668 .762 .921 r
.64603 .49235 .65159 .49822 .66301 .49466 .65748 .48867 Mtetra
.668 .759 .919 r
.65748 .48867 .66301 .49466 .67447 .49109 .66897 .48498 Mtetra
.668 .756 .916 r
.66897 .48498 .67447 .49109 .68598 .48751 .68051 .48129 Mtetra
.667 .753 .914 r
.68051 .48129 .68598 .48751 .69753 .48393 .69209 .4776 Mtetra
.667 .75 .913 r
.69209 .4776 .69753 .48393 .70914 .48035 .70373 .47392 Mtetra
.666 .748 .911 r
.70373 .47392 .70914 .48035 .72079 .47676 .71541 .47026 Mtetra
.665 .746 .91 r
.71541 .47026 .72079 .47676 .73249 .47316 .72714 .46659 Mtetra
.665 .744 .909 r
.72714 .46659 .73249 .47316 .74423 .46956 .73892 .46294 Mtetra
.664 .743 .909 r
.73892 .46294 .74423 .46956 .75603 .46594 .75075 .45928 Mtetra
.664 .742 .908 r
.75075 .45928 .75603 .46594 .76788 .46232 .76263 .45561 Mtetra
.76263 .45561 .76788 .46232 .77977 .45868 .77456 .45194 Mtetra
.77456 .45194 .77977 .45868 .79171 .45503 .78653 .44825 Mtetra
.664 .741 .908 r
.78653 .44825 .79171 .45503 .80371 .45136 .79856 .44456 Mtetra
.79856 .44456 .80371 .45136 .81575 .44768 .81064 .44084 Mtetra
.81064 .44084 .81575 .44768 .82785 .44398 .82277 .43712 Mtetra
.82277 .43712 .82785 .44398 .83999 .44027 .83495 .43338 Mtetra
.83495 .43338 .83999 .44027 .85219 .43654 .84719 .42962 Mtetra
.84719 .42962 .85219 .43654 .86443 .4328 .85947 .42585 Mtetra
.85947 .42585 .86443 .4328 .87673 .42904 .87181 .42206 Mtetra
.87181 .42206 .87673 .42904 .88908 .42526 .88419 .41825 Mtetra
.88419 .41825 .88908 .42526 .90148 .42147 .89664 .41443 Mtetra
.89664 .41443 .90148 .42147 .91394 .41767 .90913 .4106 Mtetra
.90913 .4106 .91394 .41767 .92645 .41384 .92168 .40674 Mtetra
.92168 .40674 .92645 .41384 .93901 .41 .93428 .40287 Mtetra
.93428 .40287 .93901 .41 .95162 .40615 .94693 .39899 Mtetra
.36785 .56901 .37417 .57489 .38454 .57171 .37824 .5658 Mtetra
.37824 .5658 .38454 .57171 .39494 .56851 .38867 .56258 Mtetra
.38867 .56258 .39494 .56851 .40539 .56531 .39914 .55935 Mtetra
.663 .741 .908 r
.39914 .55935 .40539 .56531 .41588 .56209 .40966 .55611 Mtetra
.40966 .55611 .41588 .56209 .42641 .55885 .42022 .55285 Mtetra
.42022 .55285 .42641 .55885 .43698 .55561 .43081 .54959 Mtetra
.43081 .54959 .43698 .55561 .44759 .55236 .44145 .54632 Mtetra
.44145 .54632 .44759 .55236 .45825 .54911 .45213 .54304 Mtetra
.662 .741 .909 r
.45213 .54304 .45825 .54911 .46894 .54585 .46285 .53977 Mtetra
.46285 .53977 .46894 .54585 .47968 .54259 .47362 .5365 Mtetra
.661 .742 .91 r
.47362 .5365 .47968 .54259 .49046 .53933 .48443 .53325 Mtetra
.659 .742 .911 r
.48443 .53325 .49046 .53933 .50129 .53609 .49528 .53002 Mtetra
.658 .743 .913 r
.49528 .53002 .50129 .53609 .51215 .53285 .50617 .52683 Mtetra
.656 .745 .915 r
.50617 .52683 .51215 .53285 .52306 .52962 .51711 .52367 Mtetra
.654 .747 .919 r
.51711 .52367 .52306 .52962 .53402 .52641 .5281 .52055 Mtetra
.652 .751 .922 r
.5281 .52055 .53402 .52641 .54502 .52319 .53913 .51746 Mtetra
.65 .756 .927 r
.53913 .51746 .54502 .52319 .55606 .51996 .5502 .51438 Mtetra
.649 .762 .931 r
.5502 .51438 .55606 .51996 .56715 .51671 .56133 .51129 Mtetra
.649 .768 .936 r
.56133 .51129 .56715 .51671 .57829 .51341 .5725 .50816 Mtetra
.651 .776 .94 r
.5725 .50816 .57829 .51341 .58947 .51006 .58371 .50495 Mtetra
.653 .783 .943 r
.58371 .50495 .58947 .51006 .60069 .50664 .59497 .50164 Mtetra
.657 .789 .945 r
.59497 .50164 .60069 .50664 .61196 .50316 .60628 .49821 Mtetra
.661 .793 .945 r
.60628 .49821 .61196 .50316 .62327 .49961 .61763 .49464 Mtetra
.665 .794 .944 r
.61763 .49464 .62327 .49961 .63463 .496 .62902 .49096 Mtetra
.669 .793 .941 r
.62902 .49096 .63463 .496 .64603 .49235 .64045 .48717 Mtetra
.671 .79 .938 r
.64045 .48717 .64603 .49235 .65748 .48867 .65193 .48331 Mtetra
.673 .785 .933 r
.65193 .48331 .65748 .48867 .66897 .48498 .66345 .47941 Mtetra
.673 .778 .929 r
.66345 .47941 .66897 .48498 .68051 .48129 .67502 .4755 Mtetra
.673 .771 .924 r
.67502 .4755 .68051 .48129 .69209 .4776 .68663 .47161 Mtetra
.672 .765 .92 r
.68663 .47161 .69209 .4776 .70373 .47392 .69829 .46774 Mtetra
.67 .759 .917 r
.69829 .46774 .70373 .47392 .71541 .47026 .71 .46392 Mtetra
.669 .754 .914 r
.71 .46392 .71541 .47026 .72714 .46659 .72176 .46012 Mtetra
.667 .75 .912 r
.72176 .46012 .72714 .46659 .73892 .46294 .73357 .45636 Mtetra
.666 .747 .911 r
.73357 .45636 .73892 .46294 .75075 .45928 .74543 .45262 Mtetra
.665 .745 .91 r
.74543 .45262 .75075 .45928 .76263 .45561 .75734 .44889 Mtetra
.665 .743 .909 r
.75734 .44889 .76263 .45561 .77456 .45194 .7693 .44516 Mtetra
.664 .742 .908 r
.7693 .44516 .77456 .45194 .78653 .44825 .78132 .44144 Mtetra
.78132 .44144 .78653 .44825 .79856 .44456 .79338 .4377 Mtetra
.79338 .4377 .79856 .44456 .81064 .44084 .80549 .43396 Mtetra
.664 .741 .908 r
.80549 .43396 .81064 .44084 .82277 .43712 .81766 .4302 Mtetra
.81766 .4302 .82277 .43712 .83495 .43338 .82988 .42643 Mtetra
.82988 .42643 .83495 .43338 .84719 .42962 .84215 .42264 Mtetra
.84215 .42264 .84719 .42962 .85947 .42585 .85447 .41884 Mtetra
.85447 .41884 .85947 .42585 .87181 .42206 .86684 .41502 Mtetra
.86684 .41502 .87181 .42206 .88419 .41825 .87927 .41119 Mtetra
.87927 .41119 .88419 .41825 .89664 .41443 .89175 .40734 Mtetra
.89175 .40734 .89664 .41443 .90913 .4106 .90428 .40347 Mtetra
.90428 .40347 .90913 .4106 .92168 .40674 .91687 .39958 Mtetra
.91687 .39958 .92168 .40674 .93428 .40287 .92951 .39568 Mtetra
.92951 .39568 .93428 .40287 .94693 .39899 .9422 .39177 Mtetra
.36148 .56307 .36785 .56901 .37824 .5658 .37189 .55985 Mtetra
.37189 .55985 .37824 .5658 .38867 .56258 .38235 .5566 Mtetra
.38235 .5566 .38867 .56258 .39914 .55935 .39285 .55335 Mtetra
.663 .741 .908 r
.39285 .55335 .39914 .55935 .40966 .55611 .40339 .55008 Mtetra
.40339 .55008 .40966 .55611 .42022 .55285 .41397 .5468 Mtetra
.41397 .5468 .42022 .55285 .43081 .54959 .4246 .54352 Mtetra
.4246 .54352 .43081 .54959 .44145 .54632 .43526 .54022 Mtetra
.43526 .54022 .44145 .54632 .45213 .54304 .44597 .53693 Mtetra
.662 .741 .909 r
.44597 .53693 .45213 .54304 .46285 .53977 .45672 .53364 Mtetra
.661 .741 .909 r
.45672 .53364 .46285 .53977 .47362 .5365 .46751 .53036 Mtetra
.66 .741 .91 r
.46751 .53036 .47362 .5365 .48443 .53325 .47835 .52712 Mtetra
.657 .742 .912 r
.47835 .52712 .48443 .53325 .49528 .53002 .48922 .52392 Mtetra
.655 .742 .914 r
.48922 .52392 .49528 .53002 .50617 .52683 .50015 .52078 Mtetra
.651 .744 .918 r
.50015 .52078 .50617 .52683 .51711 .52367 .51111 .51772 Mtetra
.647 .747 .922 r
.51111 .51772 .51711 .52367 .5281 .52055 .52213 .51475 Mtetra
.642 .752 .928 r
.52213 .51475 .5281 .52055 .53913 .51746 .53319 .51186 Mtetra
.638 .758 .935 r
.53319 .51186 .53913 .51746 .5502 .51438 .5443 .50905 Mtetra
.634 .767 .944 r
.5443 .50905 .5502 .51438 .56133 .51129 .55546 .50627 Mtetra
.631 .779 .952 r
.55546 .50627 .56133 .51129 .5725 .50816 .56666 .50347 Mtetra
.629 .792 .96 r
.56666 .50347 .5725 .50816 .58371 .50495 .57792 .50059 Mtetra
.63 .807 .967 r
.57792 .50059 .58371 .50495 .59497 .50164 .58923 .49758 Mtetra
.634 .821 .972 r
.58923 .49758 .59497 .50164 .60628 .49821 .60058 .49436 Mtetra
.641 .833 .974 r
.60058 .49436 .60628 .49821 .61763 .49464 .61197 .49092 Mtetra
.65 .841 .974 r
.61197 .49092 .61763 .49464 .62902 .49096 .6234 .48723 Mtetra
.659 .845 .971 r
.6234 .48723 .62902 .49096 .64045 .48717 .63488 .48331 Mtetra
.669 .843 .967 r
.63488 .48331 .64045 .48717 .65193 .48331 .64639 .47922 Mtetra
.676 .836 .96 r
.64639 .47922 .65193 .48331 .66345 .47941 .65794 .475 Mtetra
.68 .826 .953 r
.65794 .475 .66345 .47941 .67502 .4755 .66953 .47072 Mtetra
.682 .813 .945 r
.66953 .47072 .67502 .4755 .68663 .47161 .68116 .46644 Mtetra
.681 .799 .937 r
.68116 .46644 .68663 .47161 .69829 .46774 .69284 .46221 Mtetra
.679 .786 .93 r
.69284 .46221 .69829 .46774 .71 .46392 .70458 .45805 Mtetra
.676 .774 .924 r
.70458 .45805 .71 .46392 .72176 .46012 .71636 .45398 Mtetra
.673 .764 .919 r
.71636 .45398 .72176 .46012 .73357 .45636 .72819 .45 Mtetra
.67 .757 .916 r
.72819 .45 .73357 .45636 .74543 .45262 .74008 .44608 Mtetra
.668 .752 .913 r
.74008 .44608 .74543 .45262 .75734 .44889 .75202 .44223 Mtetra
.667 .748 .911 r
.75202 .44223 .75734 .44889 .7693 .44516 .76401 .43841 Mtetra
.665 .745 .91 r
.76401 .43841 .7693 .44516 .78132 .44144 .77606 .43461 Mtetra
.665 .743 .909 r
.77606 .43461 .78132 .44144 .79338 .4377 .78816 .43082 Mtetra
.664 .743 .908 r
.78816 .43082 .79338 .4377 .80549 .43396 .80031 .42703 Mtetra
.664 .742 .908 r
.80031 .42703 .80549 .43396 .81766 .4302 .81251 .42324 Mtetra
.81251 .42324 .81766 .4302 .82988 .42643 .82476 .41943 Mtetra
.664 .741 .908 r
.82476 .41943 .82988 .42643 .84215 .42264 .83707 .41561 Mtetra
.83707 .41561 .84215 .42264 .85447 .41884 .84943 .41178 Mtetra
.84943 .41178 .85447 .41884 .86684 .41502 .86184 .40793 Mtetra
.86184 .40793 .86684 .41502 .87927 .41119 .8743 .40406 Mtetra
.8743 .40406 .87927 .41119 .89175 .40734 .88682 .40018 Mtetra
.88682 .40018 .89175 .40734 .90428 .40347 .89939 .39628 Mtetra
.89939 .39628 .90428 .40347 .91687 .39958 .91202 .39237 Mtetra
.91202 .39237 .91687 .39958 .92951 .39568 .9247 .38844 Mtetra
.9247 .38844 .92951 .39568 .9422 .39177 .93743 .38449 Mtetra
.35506 .5571 .36148 .56307 .37189 .55985 .3655 .55385 Mtetra
.3655 .55385 .37189 .55985 .38235 .5566 .37599 .55058 Mtetra
.37599 .55058 .38235 .5566 .39285 .55335 .38651 .5473 Mtetra
.663 .741 .908 r
.38651 .5473 .39285 .55335 .40339 .55008 .39708 .54401 Mtetra
.39708 .54401 .40339 .55008 .41397 .5468 .40769 .54071 Mtetra
.40769 .54071 .41397 .5468 .4246 .54352 .41834 .5374 Mtetra
.41834 .5374 .4246 .54352 .43526 .54022 .42903 .53408 Mtetra
.42903 .53408 .43526 .54022 .44597 .53693 .43976 .53077 Mtetra
.662 .741 .909 r
.43976 .53077 .44597 .53693 .45672 .53364 .45054 .52746 Mtetra
.661 .741 .909 r
.45054 .52746 .45672 .53364 .46751 .53036 .46136 .52417 Mtetra
.659 .741 .91 r
.46136 .52417 .46751 .53036 .47835 .52712 .47222 .52093 Mtetra
.656 .741 .912 r
.47222 .52093 .47835 .52712 .48922 .52392 .48312 .51775 Mtetra
.652 .741 .915 r
.48312 .51775 .48922 .52392 .50015 .52078 .49407 .51467 Mtetra
.646 .742 .919 r
.49407 .51467 .50015 .52078 .51111 .51772 .50507 .51173 Mtetra
.639 .745 .925 r
.50507 .51173 .51111 .51772 .52213 .51475 .51611 .50894 Mtetra
.63 .749 .933 r
.51611 .50894 .52213 .51475 .53319 .51186 .5272 .50633 Mtetra
.62 .756 .944 r
.5272 .50633 .53319 .51186 .5443 .50905 .53834 .50389 Mtetra
.608 .768 .956 r
.53834 .50389 .5443 .50905 .55546 .50627 .54954 .50159 Mtetra
.596 .783 .97 r
.54954 .50159 .55546 .50627 .56666 .50347 .56079 .49936 Mtetra
.584 .803 .983 r
.56079 .49936 .56666 .50347 .57792 .50059 .57209 .4971 Mtetra
.573 .826 .993 r
.57209 .4971 .57792 .50059 .58923 .49758 .58345 .49469 Mtetra
.566 .849 .997 r
.58345 .49469 .58923 .49758 .60058 .49436 .59485 .49202 Mtetra
.565 .871 .995 r
.59485 .49202 .60058 .49436 .61197 .49092 .6063 .48899 Mtetra
.573 .889 .989 r
.6063 .48899 .61197 .49092 .6234 .48723 .61779 .48553 Mtetra
.59 .904 .983 r
.61779 .48553 .6234 .48723 .63488 .48331 .62932 .48163 Mtetra
.615 .913 .98 r
.62932 .48163 .63488 .48331 .64639 .47922 .64087 .47733 Mtetra
.642 .916 .979 r
.64087 .47733 .64639 .47922 .65794 .475 .65246 .4727 Mtetra
.667 .909 .978 r
.65246 .4727 .65794 .475 .66953 .47072 .66407 .46788 Mtetra
.683 .893 .973 r
.66407 .46788 .66953 .47072 .68116 .46644 .67573 .46297 Mtetra
.692 .87 .966 r
.67573 .46297 .68116 .46644 .69284 .46221 .68743 .45808 Mtetra
.694 .845 .956 r
.68743 .45808 .69284 .46221 .70458 .45805 .69917 .4533 Mtetra
.691 .821 .945 r
.69917 .4533 .70458 .45805 .71636 .45398 .71096 .44867 Mtetra
.686 .8 .935 r
.71096 .44867 .71636 .45398 .72819 .45 .72281 .44422 Mtetra
.681 .782 .927 r
.72281 .44422 .72819 .45 .74008 .44608 .73472 .43994 Mtetra
.676 .769 .921 r
.73472 .43994 .74008 .44608 .75202 .44223 .74668 .4358 Mtetra
.672 .759 .916 r
.74668 .4358 .75202 .44223 .76401 .43841 .7587 .43178 Mtetra
.669 .752 .913 r
.7587 .43178 .76401 .43841 .77606 .43461 .77077 .42784 Mtetra
.667 .748 .911 r
.77077 .42784 .77606 .43461 .78816 .43082 .7829 .42395 Mtetra
.666 .745 .91 r
.7829 .42395 .78816 .43082 .80031 .42703 .79508 .42009 Mtetra
.665 .743 .909 r
.79508 .42009 .80031 .42703 .81251 .42324 .80732 .41624 Mtetra
.664 .742 .908 r
.80732 .41624 .81251 .42324 .82476 .41943 .81961 .41239 Mtetra
.81961 .41239 .82476 .41943 .83707 .41561 .83195 .40853 Mtetra
.83195 .40853 .83707 .41561 .84943 .41178 .84435 .40466 Mtetra
.664 .741 .908 r
.84435 .40466 .84943 .41178 .86184 .40793 .8568 .40078 Mtetra
.8568 .40078 .86184 .40793 .8743 .40406 .8693 .39689 Mtetra
.8693 .39689 .8743 .40406 .88682 .40018 .88186 .39297 Mtetra
.88186 .39297 .88682 .40018 .89939 .39628 .89447 .38904 Mtetra
.89447 .38904 .89939 .39628 .91202 .39237 .90713 .3851 Mtetra
.90713 .3851 .91202 .39237 .9247 .38844 .91985 .38114 Mtetra
.91985 .38114 .9247 .38844 .93743 .38449 .93263 .37715 Mtetra
.3486 .55109 .35506 .5571 .3655 .55385 .35907 .54781 Mtetra
.35907 .54781 .3655 .55385 .37599 .55058 .36958 .54452 Mtetra
.36958 .54452 .37599 .55058 .38651 .5473 .38013 .54122 Mtetra
.38013 .54122 .38651 .5473 .39708 .54401 .39072 .5379 Mtetra
.663 .741 .908 r
.39072 .5379 .39708 .54401 .40769 .54071 .40135 .53458 Mtetra
.40135 .53458 .40769 .54071 .41834 .5374 .41203 .53124 Mtetra
.41203 .53124 .41834 .5374 .42903 .53408 .42275 .5279 Mtetra
.42275 .5279 .42903 .53408 .43976 .53077 .43351 .52455 Mtetra
.662 .741 .909 r
.43351 .52455 .43976 .53077 .45054 .52746 .44431 .52122 Mtetra
.66 .74 .909 r
.44431 .52122 .45054 .52746 .46136 .52417 .45516 .51791 Mtetra
.658 .74 .91 r
.45516 .51791 .46136 .52417 .47222 .52093 .46605 .51466 Mtetra
.655 .739 .912 r
.46605 .51466 .47222 .52093 .48312 .51775 .47698 .5115 Mtetra
.649 .739 .915 r
.47698 .5115 .48312 .51775 .49407 .51467 .48796 .50846 Mtetra
.641 .739 .92 r
.48796 .50846 .49407 .51467 .50507 .51173 .49898 .50562 Mtetra
.631 .74 .926 r
.49898 .50562 .50507 .51173 .51611 .50894 .51005 .50303 Mtetra
.616 .743 .936 r
.51005 .50303 .51611 .50894 .5272 .50633 .52117 .50073 Mtetra
.598 .748 .949 r
.52117 .50073 .5272 .50633 .53834 .50389 .53234 .49875 Mtetra
.574 .758 .965 r
.53234 .49875 .53834 .50389 .54954 .50159 .54357 .49707 Mtetra
.544 .773 .983 r
.54357 .49707 .54954 .50159 .56079 .49936 .55487 .49564 Mtetra
.504 .791 .997 r
.55487 .49564 .56079 .49936 .57209 .4971 .56622 .49433 Mtetra
.455 .809 .997 r
.56622 .49433 .57209 .4971 .58345 .49469 .57763 .49297 Mtetra
.397 .818 .97 r
.57763 .49297 .58345 .49469 .59485 .49202 .58911 .49134 Mtetra
.341 .812 .911 r
.58911 .49134 .59485 .49202 .6063 .48899 .60063 .48924 Mtetra
.303 .797 .838 r
.60063 .48924 .6063 .48899 .61779 .48553 .61219 .4865 Mtetra
.296 .791 .779 r
.61219 .4865 .61779 .48553 .62932 .48163 .62379 .483 Mtetra
.326 .806 .755 r
.62379 .483 .62932 .48163 .64087 .47733 .63541 .47875 Mtetra
.389 .844 .771 r
.63541 .47875 .64087 .47733 .65246 .4727 .64705 .4738 Mtetra
.474 .894 .82 r
.64705 .4738 .65246 .4727 .66407 .46788 .6587 .46833 Mtetra
.564 .937 .882 r
.6587 .46833 .66407 .46788 .67573 .46297 .67038 .46253 Mtetra
.638 .955 .933 r
.67038 .46253 .67573 .46297 .68743 .45808 .68209 .45661 Mtetra
.684 .944 .961 r
.68209 .45661 .68743 .45808 .69917 .4533 .69383 .45076 Mtetra
.704 .913 .967 r
.69383 .45076 .69917 .4533 .71096 .44867 .70562 .44512 Mtetra
.707 .876 .96 r
.70562 .44512 .71096 .44867 .72281 .44422 .71747 .43977 Mtetra
.701 .84 .949 r
.71747 .43977 .72281 .44422 .73472 .43994 .72937 .43475 Mtetra
.693 .81 .938 r
.72937 .43475 .73472 .43994 .74668 .4358 .74134 .43003 Mtetra
.685 .787 .928 r
.74134 .43003 .74668 .4358 .7587 .43178 .75337 .42556 Mtetra
.678 .771 .921 r
.75337 .42556 .7587 .43178 .77077 .42784 .76546 .42131 Mtetra
.673 .76 .916 r
.76546 .42131 .77077 .42784 .7829 .42395 .77761 .4172 Mtetra
.669 .752 .913 r
.77761 .4172 .7829 .42395 .79508 .42009 .78982 .41319 Mtetra
.667 .747 .911 r
.78982 .41319 .79508 .42009 .80732 .41624 .80209 .40924 Mtetra
.665 .745 .909 r
.80209 .40924 .80732 .41624 .81961 .41239 .81442 .40532 Mtetra
.665 .743 .909 r
.81442 .40532 .81961 .41239 .83195 .40853 .82679 .40141 Mtetra
.664 .742 .908 r
.82679 .40141 .83195 .40853 .84435 .40466 .83923 .3975 Mtetra
.83923 .3975 .84435 .40466 .8568 .40078 .85171 .39358 Mtetra
.664 .741 .908 r
.85171 .39358 .8568 .40078 .8693 .39689 .86426 .38965 Mtetra
.86426 .38965 .8693 .39689 .88186 .39297 .87685 .38571 Mtetra
.87685 .38571 .88186 .39297 .89447 .38904 .8895 .38175 Mtetra
.8895 .38175 .89447 .38904 .90713 .3851 .90221 .37777 Mtetra
.90221 .37777 .90713 .3851 .91985 .38114 .91497 .37377 Mtetra
.91497 .37377 .91985 .38114 .93263 .37715 .92778 .36976 Mtetra
.34209 .54503 .3486 .55109 .35907 .54781 .35259 .54172 Mtetra
.35259 .54172 .35907 .54781 .36958 .54452 .36312 .53841 Mtetra
.36312 .53841 .36958 .54452 .38013 .54122 .3737 .53508 Mtetra
.3737 .53508 .38013 .54122 .39072 .5379 .38431 .53174 Mtetra
.663 .741 .908 r
.38431 .53174 .39072 .5379 .40135 .53458 .39497 .52839 Mtetra
.39497 .52839 .40135 .53458 .41203 .53124 .40568 .52503 Mtetra
.40568 .52503 .41203 .53124 .42275 .5279 .41642 .52166 Mtetra
.41642 .52166 .42275 .5279 .43351 .52455 .42721 .51829 Mtetra
.662 .741 .908 r
.42721 .51829 .43351 .52455 .44431 .52122 .43804 .51493 Mtetra
.661 .74 .909 r
.43804 .51493 .44431 .52122 .45516 .51791 .44891 .5116 Mtetra
.658 .739 .91 r
.44891 .5116 .45516 .51791 .46605 .51466 .45983 .50832 Mtetra
.654 .738 .911 r
.45983 .50832 .46605 .51466 .47698 .5115 .47079 .50514 Mtetra
.648 .737 .914 r
.47079 .50514 .47698 .5115 .48796 .50846 .4818 .50212 Mtetra
.638 .735 .918 r
.4818 .50212 .48796 .50846 .49898 .50562 .49284 .49934 Mtetra
.625 .733 .925 r
.49284 .49934 .49898 .50562 .51005 .50303 .50394 .4969 Mtetra
.605 .733 .935 r
.50394 .4969 .51005 .50303 .52117 .50073 .51509 .49487 Mtetra
.577 .733 .949 r
.51509 .49487 .52117 .50073 .53234 .49875 .52629 .49335 Mtetra
.538 .737 .967 r
.52629 .49335 .53234 .49875 .54357 .49707 .53755 .49237 Mtetra
.482 .742 .985 r
.53755 .49237 .54357 .49707 .55487 .49564 .54889 .49191 Mtetra
.4 .744 .993 r
.54889 .49191 .55487 .49564 .56622 .49433 .56029 .49184 Mtetra
.279 .728 .96 r
.56029 .49184 .56622 .49433 .57763 .49297 .57177 .49196 Mtetra
.124 .665 .842 r
.57177 .49196 .57763 .49297 .58911 .49134 .58332 .49197 Mtetra
.022 0 0 r
.58332 .49197 .58911 .49134 .60063 .48924 .59493 .49152 Mtetra
.112 0 0 r
.59493 .49152 .60063 .48924 .61219 .4865 .60659 .49027 Mtetra
.142 0 0 r
.60659 .49027 .61219 .4865 .62379 .483 .61829 .48793 Mtetra
.128 0 0 r
.61829 .48793 .62379 .483 .63541 .47875 .63001 .48435 Mtetra
.081 0 0 r
.63001 .48435 .63541 .47875 .64705 .4738 .64173 .47952 Mtetra
.004 0 0 r
.64173 .47952 .64705 .4738 .6587 .46833 .65345 .47357 Mtetra
0 0 0 r
.65345 .47357 .6587 .46833 .67038 .46253 .66517 .46679 Mtetra
.66517 .46679 .67038 .46253 .68209 .45661 .67689 .45951 Mtetra
.424 .834 .646 r
.67689 .45951 .68209 .45661 .69383 .45076 .68863 .45208 Mtetra
.581 .941 .813 r
.68863 .45208 .69383 .45076 .70562 .44512 .70041 .4448 Mtetra
.679 .971 .918 r
.70041 .4448 .70562 .44512 .71747 .43977 .71223 .4379 Mtetra
.717 .943 .957 r
.71223 .4379 .71747 .43977 .72937 .43475 .7241 .43151 Mtetra
.719 .895 .959 r
.7241 .43151 .72937 .43475 .74134 .43003 .73605 .42566 Mtetra
.709 .849 .949 r
.73605 .42566 .74134 .43003 .75337 .42556 .74807 .42031 Mtetra
.697 .813 .937 r
.74807 .42031 .75337 .42556 .76546 .42131 .76016 .4154 Mtetra
.686 .787 .927 r
.76016 .4154 .76546 .42131 .77761 .4172 .77232 .41082 Mtetra
.678 .769 .92 r
.77232 .41082 .77761 .4172 .78982 .41319 .78454 .40649 Mtetra
.672 .758 .915 r
.78454 .40649 .78982 .41319 .80209 .40924 .79684 .40233 Mtetra
.669 .751 .912 r
.79684 .40233 .80209 .40924 .81442 .40532 .80919 .39828 Mtetra
.666 .746 .91 r
.80919 .39828 .81442 .40532 .82679 .40141 .8216 .39428 Mtetra
.665 .744 .909 r
.8216 .39428 .82679 .40141 .83923 .3975 .83407 .3903 Mtetra
.664 .743 .908 r
.83407 .3903 .83923 .3975 .85171 .39358 .84659 .38634 Mtetra
.664 .742 .908 r
.84659 .38634 .85171 .39358 .86426 .38965 .85917 .38237 Mtetra
.85917 .38237 .86426 .38965 .87685 .38571 .87181 .37839 Mtetra
.664 .741 .908 r
.87181 .37839 .87685 .38571 .8895 .38175 .8845 .37439 Mtetra
.8845 .37439 .8895 .38175 .90221 .37777 .89724 .37038 Mtetra
.89724 .37038 .90221 .37777 .91497 .37377 .91004 .36635 Mtetra
.91004 .36635 .91497 .37377 .92778 .36976 .9229 .36231 Mtetra
.33554 .53892 .34209 .54503 .35259 .54172 .34605 .5356 Mtetra
.34605 .5356 .35259 .54172 .36312 .53841 .35661 .53226 Mtetra
.35661 .53226 .36312 .53841 .3737 .53508 .36722 .52891 Mtetra
.36722 .52891 .3737 .53508 .38431 .53174 .37786 .52554 Mtetra
.663 .741 .908 r
.37786 .52554 .38431 .53174 .39497 .52839 .38855 .52217 Mtetra
.38855 .52217 .39497 .52839 .40568 .52503 .39928 .51878 Mtetra
.39928 .51878 .40568 .52503 .41642 .52166 .41005 .51538 Mtetra
.41005 .51538 .41642 .52166 .42721 .51829 .42086 .51198 Mtetra
.662 .741 .908 r
.42086 .51198 .42721 .51829 .43804 .51493 .43172 .50859 Mtetra
.661 .74 .909 r
.43172 .50859 .43804 .51493 .44891 .5116 .44262 .50521 Mtetra
.659 .739 .909 r
.44262 .50521 .44891 .5116 .45983 .50832 .45357 .5019 Mtetra
.655 .737 .91 r
.45357 .5019 .45983 .50832 .47079 .50514 .46456 .49868 Mtetra
.648 .735 .913 r
.46456 .49868 .47079 .50514 .4818 .50212 .47559 .49563 Mtetra
.638 .732 .916 r
.47559 .49563 .4818 .50212 .49284 .49934 .48666 .49286 Mtetra
.622 .727 .922 r
.48666 .49286 .49284 .49934 .50394 .4969 .49779 .49047 Mtetra
.598 .722 .931 r
.49779 .49047 .50394 .4969 .51509 .49487 .50896 .48862 Mtetra
.564 .716 .943 r
.50896 .48862 .51509 .49487 .52629 .49335 .52019 .48745 Mtetra
.512 .708 .96 r
.52019 .48745 .52629 .49335 .53755 .49237 .53148 .48709 Mtetra
.434 .698 .976 r
.53148 .48709 .53755 .49237 .54889 .49191 .54285 .48757 Mtetra
.311 .674 .976 r
.54285 .48757 .54889 .49191 .56029 .49184 .5543 .48886 Mtetra
.121 .611 .91 r
.5543 .48886 .56029 .49184 .57177 .49196 .56583 .49076 Mtetra
0 .471 .709 r
.56583 .49076 .57177 .49196 .58332 .49197 .57746 .49292 Mtetra
.304 0 0 r
.57746 .49292 .58332 .49197 .59493 .49152 .58917 .49488 Mtetra
.385 0 0 r
.58917 .49488 .59493 .49152 .60659 .49027 .60096 .49608 Mtetra
.397 0 0 r
.60096 .49608 .60659 .49027 .61829 .48793 .61279 .49599 Mtetra
.375 0 .068 r
.61279 .49599 .61829 .48793 .63001 .48435 .62465 .49417 Mtetra
.335 0 .108 r
.62465 .49417 .63001 .48435 .64173 .47952 .6365 .4904 Mtetra
.282 0 .115 r
.6365 .4904 .64173 .47952 .65345 .47357 .64834 .48467 Mtetra
.216 0 .092 r
.64834 .48467 .65345 .47357 .66517 .46679 .66013 .47726 Mtetra
.132 0 .037 r
.66013 .47726 .66517 .46679 .67689 .45951 .6719 .46858 Mtetra
.02 0 0 r
.6719 .46858 .67689 .45951 .68863 .45208 .68365 .4592 Mtetra
0 0 0 r
.68365 .4592 .68863 .45208 .70041 .4448 .6954 .44965 Mtetra
.6954 .44965 .70041 .4448 .71223 .4379 .70717 .4404 Mtetra
.548 .906 .705 r
.70717 .4404 .71223 .4379 .7241 .43151 .71899 .43177 Mtetra
.686 .979 .88 r
.71899 .43177 .7241 .43151 .73605 .42566 .73088 .42396 Mtetra
.731 .954 .947 r
.73088 .42396 .73605 .42566 .74807 .42031 .74285 .41699 Mtetra
.729 .897 .955 r
.74285 .41699 .74807 .42031 .76016 .4154 .7549 .41082 Mtetra
.713 .846 .945 r
.7549 .41082 .76016 .4154 .77232 .41082 .76704 .40531 Mtetra
.697 .808 .934 r
.76704 .40531 .77232 .41082 .78454 .40649 .77927 .40033 Mtetra
.685 .782 .924 r
.77927 .40033 .78454 .40649 .79684 .40233 .79157 .39573 Mtetra
.677 .765 .918 r
.79157 .39573 .79684 .40233 .80919 .39828 .80394 .39138 Mtetra
.671 .755 .913 r
.80394 .39138 .80919 .39828 .8216 .39428 .81638 .3872 Mtetra
.668 .749 .911 r
.81638 .3872 .8216 .39428 .83407 .3903 .82887 .38311 Mtetra
.666 .745 .909 r
.82887 .38311 .83407 .3903 .84659 .38634 .84143 .37906 Mtetra
.665 .743 .909 r
.84143 .37906 .84659 .38634 .85917 .38237 .85405 .37504 Mtetra
.664 .742 .908 r
.85405 .37504 .85917 .38237 .87181 .37839 .86672 .37101 Mtetra
.86672 .37101 .87181 .37839 .8845 .37439 .87945 .36698 Mtetra
.664 .741 .908 r
.87945 .36698 .8845 .37439 .89724 .37038 .89224 .36293 Mtetra
.89224 .36293 .89724 .37038 .91004 .36635 .90508 .35887 Mtetra
.90508 .35887 .91004 .36635 .9229 .36231 .91798 .35479 Mtetra
.32893 .53277 .33554 .53892 .34605 .5356 .33948 .52942 Mtetra
.33948 .52942 .34605 .5356 .35661 .53226 .35006 .52606 Mtetra
.35006 .52606 .35661 .53226 .36722 .52891 .36069 .52268 Mtetra
.36069 .52268 .36722 .52891 .37786 .52554 .37136 .51929 Mtetra
.37136 .51929 .37786 .52554 .38855 .52217 .38207 .51589 Mtetra
.663 .741 .908 r
.38207 .51589 .38855 .52217 .39928 .51878 .39283 .51248 Mtetra
.39283 .51248 .39928 .51878 .41005 .51538 .40363 .50905 Mtetra
.40363 .50905 .41005 .51538 .42086 .51198 .41447 .50562 Mtetra
.41447 .50562 .42086 .51198 .43172 .50859 .42536 .50219 Mtetra
.661 .74 .908 r
.42536 .50219 .43172 .50859 .44262 .50521 .43629 .49878 Mtetra
.66 .739 .909 r
.43629 .49878 .44262 .50521 .45357 .5019 .44726 .49541 Mtetra
.656 .737 .91 r
.44726 .49541 .45357 .5019 .46456 .49868 .45828 .49213 Mtetra
.65 .734 .911 r
.45828 .49213 .46456 .49868 .47559 .49563 .46934 .48902 Mtetra
.64 .73 .914 r
.46934 .48902 .47559 .49563 .48666 .49286 .48044 .48617 Mtetra
.624 .723 .918 r
.48044 .48617 .48666 .49286 .49779 .49047 .49159 .48373 Mtetra
.599 .713 .924 r
.49159 .48373 .49779 .49047 .50896 .48862 .50279 .4819 Mtetra
.562 .7 .934 r
.50279 .4819 .50896 .48862 .52019 .48745 .51404 .48087 Mtetra
.505 .682 .946 r
.51404 .48087 .52019 .48745 .53148 .48709 .52536 .48088 Mtetra
.417 .656 .958 r
.52536 .48088 .53148 .48709 .54285 .48757 .53675 .48208 Mtetra
.279 .61 .956 r
.53675 .48208 .54285 .48757 .5543 .48886 .54824 .48454 Mtetra
.06 .52 .894 r
.54824 .48454 .5543 .48886 .56583 .49076 .55982 .48818 Mtetra
0 .35 .691 r
.55982 .48818 .56583 .49076 .57746 .49292 .57152 .49269 Mtetra
.453 0 0 r
.57152 .49269 .57746 .49292 .58917 .49488 .58333 .49756 Mtetra
.539 0 0 r
.58333 .49756 .58917 .49488 .60096 .49608 .59524 .50206 Mtetra
.54 .068 .082 r
.59524 .50206 .60096 .49608 .61279 .49599 .60723 .50539 Mtetra
.508 .089 .18 r
.60723 .50539 .61279 .49599 .62465 .49417 .61927 .50675 Mtetra
.462 .083 .232 r
.61927 .50675 .62465 .49417 .6365 .4904 .63131 .50552 Mtetra
.411 .06 .256 r
.63131 .50552 .6365 .4904 .64834 .48467 .64332 .50139 Mtetra
.356 .024 .259 r
.64332 .50139 .64834 .48467 .66013 .47726 .65526 .49439 Mtetra
.295 0 .243 r
.65526 .49439 .66013 .47726 .6719 .46858 .66713 .48495 Mtetra
.226 0 .206 r
.66713 .48495 .6719 .46858 .68365 .4592 .67892 .47374 Mtetra
.142 0 .143 r
.67892 .47374 .68365 .4592 .6954 .44965 .69066 .46158 Mtetra
.029 0 .037 r
.69066 .46158 .6954 .44965 .70717 .4404 .70239 .44927 Mtetra
0 0 0 r
.70239 .44927 .70717 .4404 .71899 .43177 .71413 .43747 Mtetra
.71413 .43747 .71899 .43177 .73088 .42396 .72593 .42665 Mtetra
.581 .915 .688 r
.72593 .42665 .73088 .42396 .74285 .41699 .7378 .41705 Mtetra
.717 .986 .882 r
.7378 .41705 .74285 .41699 .7549 .41082 .74978 .4087 Mtetra
.745 .946 .946 r
.74978 .4087 .7549 .41082 .76704 .40531 .76186 .40151 Mtetra
.731 .883 .95 r
.76186 .40151 .76704 .40531 .77927 .40033 .77404 .39529 Mtetra
.711 .832 .94 r
.77404 .39529 .77927 .40033 .79157 .39573 .78632 .38982 Mtetra
.694 .796 .929 r
.78632 .38982 .79157 .39573 .80394 .39138 .79868 .38489 Mtetra
.682 .773 .92 r
.79868 .38489 .80394 .39138 .81638 .3872 .81113 .38033 Mtetra
.674 .759 .915 r
.81113 .38033 .81638 .3872 .82887 .38311 .82365 .376 Mtetra
.669 .751 .912 r
.82365 .376 .82887 .38311 .84143 .37906 .83624 .37181 Mtetra
.667 .746 .91 r
.83624 .37181 .84143 .37906 .85405 .37504 .84889 .36769 Mtetra
.665 .744 .909 r
.84889 .36769 .85405 .37504 .86672 .37101 .8616 .3636 Mtetra
.664 .742 .908 r
.8616 .3636 .86672 .37101 .87945 .36698 .87437 .35952 Mtetra
.87437 .35952 .87945 .36698 .89224 .36293 .88719 .35543 Mtetra
.88719 .35543 .89224 .36293 .90508 .35887 .90008 .35133 Mtetra
.664 .741 .908 r
.90008 .35133 .90508 .35887 .91798 .35479 .91302 .34722 Mtetra
.32228 .52658 .32893 .53277 .33948 .52942 .33285 .5232 Mtetra
.33285 .5232 .33948 .52942 .35006 .52606 .34346 .51982 Mtetra
.34346 .51982 .35006 .52606 .36069 .52268 .35411 .51641 Mtetra
.35411 .51641 .36069 .52268 .37136 .51929 .36481 .513 Mtetra
.36481 .513 .37136 .51929 .38207 .51589 .37555 .50957 Mtetra
.663 .741 .908 r
.37555 .50957 .38207 .51589 .39283 .51248 .38633 .50613 Mtetra
.38633 .50613 .39283 .51248 .40363 .50905 .39716 .50268 Mtetra
.39716 .50268 .40363 .50905 .41447 .50562 .40803 .49922 Mtetra
.40803 .49922 .41447 .50562 .42536 .50219 .41895 .49575 Mtetra
.662 .74 .908 r
.41895 .49575 .42536 .50219 .43629 .49878 .4299 .4923 Mtetra
.661 .739 .908 r
.4299 .4923 .43629 .49878 .44726 .49541 .44091 .48887 Mtetra
.658 .738 .909 r
.44091 .48887 .44726 .49541 .45828 .49213 .45195 .48552 Mtetra
.652 .735 .91 r
.45195 .48552 .45828 .49213 .46934 .48902 .46304 .4823 Mtetra
.644 .73 .911 r
.46304 .4823 .46934 .48902 .48044 .48617 .47417 .47932 Mtetra
.629 .722 .914 r
.47417 .47932 .48044 .48617 .49159 .48373 .48535 .47674 Mtetra
.606 .709 .918 r
.48535 .47674 .49159 .48373 .50279 .4819 .49657 .47475 Mtetra
.57 .692 .923 r
.49657 .47475 .50279 .4819 .51404 .48087 .50785 .47362 Mtetra
.515 .666 .93 r
.50785 .47362 .51404 .48087 .52536 .48088 .51919 .47364 Mtetra
.432 .628 .936 r
.51919 .47364 .52536 .48088 .53675 .48208 .5306 .47512 Mtetra
.304 .57 .933 r
.5306 .47512 .53675 .48208 .54824 .48454 .54211 .47827 Mtetra
.106 .476 .895 r
.54211 .47827 .54824 .48454 .55982 .48818 .55373 .48318 Mtetra
0 .32 .765 r
.55373 .48318 .55982 .48818 .57152 .49269 .56547 .48971 Mtetra
.466 0 0 r
.56547 .48971 .57152 .49269 .58333 .49756 .57736 .49742 Mtetra
.624 .063 0 r
.57736 .49742 .58333 .49756 .59524 .50206 .58938 .50556 Mtetra
.649 .151 .052 r
.58938 .50556 .59524 .50206 .60723 .50539 .60153 .51313 Mtetra
.614 .177 .188 r
.60153 .51313 .60723 .50539 .61927 .50675 .61376 .51897 Mtetra
.558 .171 .264 r
.61376 .51897 .61927 .50675 .63131 .50552 .62603 .52198 Mtetra
.498 .148 .304 r
.62603 .52198 .63131 .50552 .64332 .50139 .63828 .52132 Mtetra
.438 .116 .321 r
.63828 .52132 .64332 .50139 .65526 .49439 .65045 .51659 Mtetra
.378 .077 .322 r
.65045 .51659 .65526 .49439 .66713 .48495 .6625 .5079 Mtetra
.318 .031 .31 r
.6625 .5079 .66713 .48495 .67892 .47374 .67442 .49589 Mtetra
.254 0 .282 r
.67442 .49589 .67892 .47374 .69066 .46158 .68622 .48154 Mtetra
.182 0 .236 r
.68622 .48154 .69066 .46158 .70239 .44927 .69793 .466 Mtetra
.091 0 .161 r
.69793 .466 .70239 .44927 .71413 .43747 .7096 .45038 Mtetra
0 0 .038 r
.7096 .45038 .71413 .43747 .72593 .42665 .72128 .43557 Mtetra
0 0 0 r
.72128 .43557 .72593 .42665 .7378 .41705 .73302 .42219 Mtetra
.73302 .42219 .7378 .41705 .74978 .4087 .74486 .41052 Mtetra
.668 .964 .76 r
.74486 .41052 .74978 .4087 .76186 .40151 .75683 .4006 Mtetra
.753 .981 .913 r
.75683 .4006 .76186 .40151 .77404 .39529 .76891 .39226 Mtetra
.75 .919 .948 r
.76891 .39226 .77404 .39529 .78632 .38982 .78113 .38523 Mtetra
.725 .856 .943 r
.78113 .38523 .78632 .38982 .79868 .38489 .79346 .37922 Mtetra
.703 .811 .932 r
.79346 .37922 .79868 .38489 .81113 .38033 .80589 .37394 Mtetra
.687 .782 .923 r
.80589 .37394 .81113 .38033 .82365 .376 .81842 .36915 Mtetra
.677 .764 .916 r
.81842 .36915 .82365 .376 .83624 .37181 .83102 .36467 Mtetra
.671 .753 .913 r
.83102 .36467 .83624 .37181 .84889 .36769 .8437 .36037 Mtetra
.667 .748 .91 r
.8437 .36037 .84889 .36769 .8616 .3636 .85644 .35617 Mtetra
.665 .744 .909 r
.85644 .35617 .8616 .3636 .87437 .35952 .86925 .35202 Mtetra
.664 .743 .908 r
.86925 .35202 .87437 .35952 .88719 .35543 .88211 .34788 Mtetra
.664 .742 .908 r
.88211 .34788 .88719 .35543 .90008 .35133 .89503 .34374 Mtetra
.89503 .34374 .90008 .35133 .91302 .34722 .90801 .33959 Mtetra
.664 .741 .908 r
.31558 .52034 .32228 .52658 .33285 .5232 .32617 .51694 Mtetra
.32617 .51694 .33285 .5232 .34346 .51982 .33681 .51353 Mtetra
.33681 .51353 .34346 .51982 .35411 .51641 .34749 .5101 Mtetra
.34749 .5101 .35411 .51641 .36481 .513 .35821 .50666 Mtetra
.35821 .50666 .36481 .513 .37555 .50957 .36898 .5032 Mtetra
.36898 .5032 .37555 .50957 .38633 .50613 .37979 .49974 Mtetra
.663 .741 .908 r
.37979 .49974 .38633 .50613 .39716 .50268 .39064 .49626 Mtetra
.39064 .49626 .39716 .50268 .40803 .49922 .40154 .49277 Mtetra
.40154 .49277 .40803 .49922 .41895 .49575 .41248 .48927 Mtetra
.41248 .48927 .41895 .49575 .4299 .4923 .42347 .48577 Mtetra
.662 .74 .908 r
.42347 .48577 .4299 .4923 .44091 .48887 .4345 .48229 Mtetra
.659 .738 .908 r
.4345 .48229 .44091 .48887 .45195 .48552 .44558 .47886 Mtetra
.655 .736 .909 r
.44558 .47886 .45195 .48552 .46304 .4823 .45669 .47553 Mtetra
.648 .731 .909 r
.45669 .47553 .46304 .4823 .47417 .47932 .46786 .47239 Mtetra
.636 .723 .91 r
.46786 .47239 .47417 .47932 .48535 .47674 .47906 .46958 Mtetra
.617 .71 .912 r
.47906 .46958 .48535 .47674 .49657 .47475 .49032 .46731 Mtetra
.586 .691 .914 r
.49032 .46731 .49657 .47475 .50785 .47362 .50162 .46584 Mtetra
.538 .661 .916 r
.50162 .46584 .50785 .47362 .51919 .47364 .51298 .46553 Mtetra
.466 .619 .916 r
.51298 .46553 .51919 .47364 .5306 .47512 .52441 .46676 Mtetra
.361 .557 .909 r
.52441 .46676 .5306 .47512 .54211 .47827 .53593 .46991 Mtetra
.207 .469 .885 r
.53593 .46991 .54211 .47827 .55373 .48318 .54756 .47528 Mtetra
0 .343 .822 r
.54756 .47528 .55373 .48318 .56547 .48971 .55932 .48295 Mtetra
0 .171 .679 r
.55932 .48295 .56547 .48971 .57736 .49742 .57125 .49271 Mtetra
.556 .021 0 r
.57125 .49271 .57736 .49742 .58938 .50556 .58335 .50397 Mtetra
.704 .165 0 r
.58335 .50397 .58938 .50556 .60153 .51313 .59562 .51573 Mtetra
.718 .227 .074 r
.59562 .51573 .60153 .51313 .61376 .51897 .60803 .52662 Mtetra
.663 .231 .211 r
.60803 .52662 .61376 .51897 .62603 .52198 .62054 .53513 Mtetra
.588 .207 .287 r
.62054 .53513 .62603 .52198 .63828 .52132 .63306 .53982 Mtetra
.511 .171 .327 r
.63306 .53982 .63828 .52132 .65045 .51659 .64552 .5396 Mtetra
.439 .131 .344 r
.64552 .5396 .65045 .51659 .6625 .5079 .65786 .534 Mtetra
.372 .087 .345 r
.65786 .534 .6625 .5079 .67442 .49589 .67001 .52326 Mtetra
.308 .04 .334 r
.67001 .52326 .67442 .49589 .68622 .48154 .68196 .50826 Mtetra
.245 0 .311 r
.68196 .50826 .68622 .48154 .69793 .466 .69373 .49036 Mtetra
.177 0 .273 r
.69373 .49036 .69793 .466 .7096 .45038 .70538 .47108 Mtetra
.096 0 .213 r
.70538 .47108 .7096 .45038 .72128 .43557 .71697 .45186 Mtetra
0 0 .115 r
.71697 .45186 .72128 .43557 .73302 .42219 .72857 .43383 Mtetra
0 0 0 r
.72857 .43383 .73302 .42219 .74486 .41052 .74024 .41774 Mtetra
.74024 .41774 .74486 .41052 .75683 .4006 .75203 .40392 Mtetra
.617 .911 .632 r
.75203 .40392 .75683 .4006 .76891 .39226 .76397 .39238 Mtetra
.752 .994 .862 r
.76397 .39238 .76891 .39226 .78113 .38523 .77607 .38286 Mtetra
.766 .947 .937 r
.77607 .38286 .78113 .38523 .79346 .37922 .78831 .37503 Mtetra
.739 .877 .944 r
.78831 .37503 .79346 .37922 .80589 .37394 .80069 .36847 Mtetra
.712 .824 .934 r
.80069 .36847 .80589 .37394 .81842 .36915 .81319 .36284 Mtetra
.693 .789 .925 r
.81319 .36284 .81842 .36915 .83102 .36467 .82579 .35782 Mtetra
.68 .768 .918 r
.82579 .35782 .83102 .36467 .8437 .36037 .83848 .35319 Mtetra
.673 .756 .913 r
.83848 .35319 .8437 .36037 .85644 .35617 .85125 .34878 Mtetra
.668 .749 .911 r
.85125 .34878 .85644 .35617 .86925 .35202 .86409 .34451 Mtetra
.666 .745 .909 r
.86409 .34451 .86925 .35202 .88211 .34788 .87699 .34029 Mtetra
.665 .743 .909 r
.87699 .34029 .88211 .34788 .89503 .34374 .88995 .33609 Mtetra
.664 .742 .908 r
.88995 .33609 .89503 .34374 .90801 .33959 .90297 .3319 Mtetra
.664 .741 .908 r
.30883 .51405 .31558 .52034 .32617 .51694 .31945 .51063 Mtetra
.31945 .51063 .32617 .51694 .33681 .51353 .33011 .50719 Mtetra
.33011 .50719 .33681 .51353 .34749 .5101 .34082 .50374 Mtetra
.34082 .50374 .34749 .5101 .35821 .50666 .35157 .50027 Mtetra
.35157 .50027 .35821 .50666 .36898 .5032 .36236 .49679 Mtetra
.36236 .49679 .36898 .5032 .37979 .49974 .3732 .4933 Mtetra
.3732 .4933 .37979 .49974 .39064 .49626 .38408 .48979 Mtetra
.663 .741 .908 r
.38408 .48979 .39064 .49626 .40154 .49277 .39501 .48627 Mtetra
.39501 .48627 .40154 .49277 .41248 .48927 .40598 .48274 Mtetra
.40598 .48274 .41248 .48927 .42347 .48577 .41699 .4792 Mtetra
.662 .74 .908 r
.41699 .4792 .42347 .48577 .4345 .48229 .42805 .47568 Mtetra
.661 .739 .908 r
.42805 .47568 .4345 .48229 .44558 .47886 .43915 .47217 Mtetra
.658 .737 .908 r
.43915 .47217 .44558 .47886 .45669 .47553 .4503 .46874 Mtetra
.653 .733 .908 r
.4503 .46874 .45669 .47553 .46786 .47239 .46149 .46544 Mtetra
.644 .726 .908 r
.46149 .46544 .46786 .47239 .47906 .46958 .47273 .46239 Mtetra
.629 .715 .908 r
.47273 .46239 .47906 .46958 .49032 .46731 .48401 .45976 Mtetra
.604 .696 .908 r
.48401 .45976 .49032 .46731 .50162 .46584 .49534 .45781 Mtetra
.566 .667 .906 r
.49534 .45781 .50162 .46584 .51298 .46553 .50673 .4569 Mtetra
.508 .625 .902 r
.50673 .4569 .51298 .46553 .52441 .46676 .51817 .45744 Mtetra
.425 .566 .891 r
.51817 .45744 .52441 .46676 .53593 .46991 .5297 .45991 Mtetra
.312 .485 .87 r
.5297 .45991 .53593 .46991 .54756 .47528 .54133 .46478 Mtetra
.163 .383 .831 r
.54133 .46478 .54756 .47528 .55932 .48295 .5531 .4724 Mtetra
0 .258 .766 r
.5531 .4724 .55932 .48295 .57125 .49271 .56503 .48284 Mtetra
0 .113 .662 r
.56503 .48284 .57125 .49271 .58335 .50397 .57715 .49584 Mtetra
0 0 .5 r
.57715 .49584 .58335 .50397 .59562 .51573 .58948 .51062 Mtetra
.687 .177 0 r
.58948 .51062 .59562 .51573 .60803 .52662 .60201 .5259 Mtetra
.759 .247 0 r
.60201 .5259 .60803 .52662 .62054 .53513 .6147 .53999 Mtetra
.71 .247 .149 r
.6147 .53999 .62054 .53513 .63306 .53982 .62748 .55099 Mtetra
.611 .209 .256 r
.62748 .55099 .63306 .53982 .64552 .5396 .64026 .55711 Mtetra
.509 .16 .31 r
.64026 .55711 .64552 .5396 .65786 .534 .65294 .55708 Mtetra
.418 .11 .333 r
.65294 .55708 .65786 .534 .67001 .52326 .66542 .55038 Mtetra
.339 .061 .338 r
.66542 .55038 .67001 .52326 .68196 .50826 .67765 .53738 Mtetra
.269 .013 .329 r
.67765 .53738 .68196 .50826 .69373 .49036 .68962 .51927 Mtetra
.203 0 .308 r
.68962 .51927 .69373 .49036 .70538 .47108 .70135 .49778 Mtetra
.136 0 .274 r
.70135 .49778 .70538 .47108 .71697 .45186 .71292 .47481 Mtetra
.06 0 .22 r
.71292 .47481 .71697 .45186 .72857 .43383 .72441 .45211 Mtetra
0 0 .134 r
.72441 .45211 .72857 .43383 .74024 .41774 .73592 .43104 Mtetra
0 0 0 r
.73592 .43104 .74024 .41774 .75203 .40392 .74752 .41242 Mtetra
.74752 .41242 .75203 .40392 .76397 .39238 .75927 .39663 Mtetra
.601 .877 .555 r
.75927 .39663 .76397 .39238 .77607 .38286 .77119 .38361 Mtetra
.756 .994 .818 r
.77119 .38361 .77607 .38286 .78831 .37503 .78329 .37305 Mtetra
.78 .963 .924 r
.78329 .37305 .78831 .37503 .80069 .36847 .79557 .3645 Mtetra
.752 .891 .942 r
.79557 .3645 .80069 .36847 .81319 .36284 .80801 .35747 Mtetra
.72 .833 .935 r
.80801 .35747 .81319 .36284 .82579 .35782 .82058 .35153 Mtetra
.697 .795 .925 r
.82058 .35153 .82579 .35782 .83848 .35319 .83326 .34631 Mtetra
.683 .771 .918 r
.83326 .34631 .83848 .35319 .85125 .34878 .84604 .34154 Mtetra
.674 .757 .913 r
.84604 .34154 .85125 .34878 .86409 .34451 .85889 .33704 Mtetra
.669 .749 .911 r
.85889 .33704 .86409 .34451 .87699 .34029 .87183 .33269 Mtetra
.666 .745 .909 r
.87183 .33269 .87699 .34029 .88995 .33609 .88482 .32841 Mtetra
.665 .743 .909 r
.88482 .32841 .88995 .33609 .90297 .3319 .89788 .32415 Mtetra
.664 .741 .908 r
.30203 .50772 .30883 .51405 .31945 .51063 .31267 .50427 Mtetra
.31267 .50427 .31945 .51063 .33011 .50719 .32336 .5008 Mtetra
.32336 .5008 .33011 .50719 .34082 .50374 .33409 .49733 Mtetra
.33409 .49733 .34082 .50374 .35157 .50027 .34487 .49383 Mtetra
.34487 .49383 .35157 .50027 .36236 .49679 .35569 .49033 Mtetra
.35569 .49033 .36236 .49679 .3732 .4933 .36656 .48681 Mtetra
.36656 .48681 .3732 .4933 .38408 .48979 .37746 .48327 Mtetra
.663 .741 .908 r
.37746 .48327 .38408 .48979 .39501 .48627 .38842 .47973 Mtetra
.38842 .47973 .39501 .48627 .40598 .48274 .39942 .47617 Mtetra
.39942 .47617 .40598 .48274 .41699 .4792 .41046 .4726 Mtetra
.41046 .4726 .41699 .4792 .42805 .47568 .42155 .46902 Mtetra
.662 .74 .908 r
.42155 .46902 .42805 .47568 .43915 .47217 .43268 .46546 Mtetra
.66 .738 .908 r
.43268 .46546 .43915 .47217 .4503 .46874 .44386 .46193 Mtetra
.657 .736 .908 r
.44386 .46193 .4503 .46874 .46149 .46544 .45508 .45849 Mtetra
.651 .73 .907 r
.45508 .45849 .46149 .46544 .47273 .46239 .46635 .45522 Mtetra
.64 .721 .906 r
.46635 .45522 .47273 .46239 .48401 .45976 .47767 .45225 Mtetra
.622 .705 .905 r
.47767 .45225 .48401 .45976 .49534 .45781 .48903 .44979 Mtetra
.593 .68 .902 r
.48903 .44979 .49534 .45781 .50673 .4569 .50043 .44815 Mtetra
.549 .643 .895 r
.50043 .44815 .50673 .4569 .51817 .45744 .5119 .44773 Mtetra
.486 .589 .882 r
.5119 .44773 .51817 .45744 .5297 .45991 .52344 .44904 Mtetra
.402 .517 .86 r
.52344 .44904 .5297 .45991 .54133 .46478 .53507 .45264 Mtetra
.296 .429 .827 r
.53507 .45264 .54133 .46478 .5531 .4724 .54682 .45904 Mtetra
.174 .331 .783 r
.54682 .45904 .5531 .4724 .56503 .48284 .55872 .46863 Mtetra
.04 .228 .729 r
.55872 .46863 .56503 .48284 .57715 .49584 .57082 .4815 Mtetra
0 .127 .67 r
.57082 .4815 .57715 .49584 .58948 .51062 .58314 .49727 Mtetra
0 .029 .601 r
.58314 .49727 .58948 .51062 .60201 .5259 .5957 .51502 Mtetra
0 0 .508 r
.5957 .51502 .60201 .5259 .6147 .53999 .60848 .53322 Mtetra
.634 .15 0 r
.60848 .53322 .6147 .53999 .62748 .55099 .62144 .54987 Mtetra
.718 .184 0 r
.62144 .54987 .62748 .55099 .64026 .55711 .63448 .56275 Mtetra
.625 .148 .1 r
.63448 .56275 .64026 .55711 .65294 .55708 .64749 .56982 Mtetra
.478 .087 .219 r
.64749 .56982 .65294 .55708 .66542 .55038 .66035 .56964 Mtetra
.354 .03 .271 r
.66035 .56964 .66542 .55038 .67765 .53738 .67296 .56168 Mtetra
.258 0 .288 r
.67296 .56168 .67765 .53738 .68962 .51927 .68525 .54651 Mtetra
.182 0 .286 r
.68525 .54651 .68962 .51927 .70135 .49778 .69722 .5256 Mtetra
.115 0 .269 r
.69722 .5256 .70135 .49778 .71292 .47481 .70891 .501 Mtetra
.05 0 .238 r
.70891 .501 .71292 .47481 .72441 .45211 .7204 .47494 Mtetra
0 0 .186 r
.7204 .47494 .72441 .45211 .73592 .43104 .73182 .4494 Mtetra
0 0 .103 r
.73182 .4494 .73592 .43104 .74752 .41242 .74326 .42589 Mtetra
0 0 0 r
.74326 .42589 .74752 .41242 .75927 .39663 .7548 .40531 Mtetra
.7548 .40531 .75927 .39663 .77119 .38361 .76652 .38802 Mtetra
.636 .886 .548 r
.76652 .38802 .77119 .38361 .78329 .37305 .77844 .3739 Mtetra
.775 .996 .803 r
.77844 .3739 .78329 .37305 .79557 .3645 .79057 .36257 Mtetra
.793 .967 .915 r
.79057 .36257 .79557 .3645 .80801 .35747 .8029 .35349 Mtetra
.76 .896 .938 r
.8029 .35349 .80801 .35747 .82058 .35153 .8154 .34612 Mtetra
.725 .837 .933 r
.8154 .34612 .82058 .35153 .83326 .34631 .82804 .33995 Mtetra
.7 .797 .925 r
.82804 .33995 .83326 .34631 .84604 .34154 .84081 .33458 Mtetra
.684 .772 .918 r
.84081 .33458 .84604 .34154 .85889 .33704 .85368 .32971 Mtetra
.675 .758 .913 r
.85368 .32971 .85889 .33704 .87183 .33269 .86664 .32513 Mtetra
.669 .75 .911 r
.86664 .32513 .87183 .33269 .88482 .32841 .87966 .32071 Mtetra
.666 .745 .909 r
.87966 .32071 .88482 .32841 .89788 .32415 .89276 .31637 Mtetra
.664 .741 .908 r
.29517 .50134 .30203 .50772 .31267 .50427 .30585 .49786 Mtetra
.30585 .49786 .31267 .50427 .32336 .5008 .31656 .49437 Mtetra
.31656 .49437 .32336 .5008 .33409 .49733 .32732 .49087 Mtetra
.32732 .49087 .33409 .49733 .34487 .49383 .33812 .48735 Mtetra
.33812 .48735 .34487 .49383 .35569 .49033 .34897 .48382 Mtetra
.34897 .48382 .35569 .49033 .36656 .48681 .35986 .48027 Mtetra
.35986 .48027 .36656 .48681 .37746 .48327 .3708 .47671 Mtetra
.3708 .47671 .37746 .48327 .38842 .47973 .38178 .47313 Mtetra
.663 .741 .908 r
.38178 .47313 .38842 .47973 .39942 .47617 .39281 .46954 Mtetra
.39281 .46954 .39942 .47617 .41046 .4726 .40388 .46594 Mtetra
.40388 .46594 .41046 .4726 .42155 .46902 .415 .46233 Mtetra
.415 .46233 .42155 .46902 .43268 .46546 .42616 .45872 Mtetra
.662 .74 .908 r
.42616 .45872 .43268 .46546 .44386 .46193 .43737 .45512 Mtetra
.66 .738 .907 r
.43737 .45512 .44386 .46193 .45508 .45849 .44862 .45157 Mtetra
.656 .734 .907 r
.44862 .45157 .45508 .45849 .46635 .45522 .45992 .44811 Mtetra
.649 .727 .906 r
.45992 .44811 .46635 .45522 .47767 .45225 .47127 .44485 Mtetra
.637 .715 .904 r
.47127 .44485 .47767 .45225 .48903 .44979 .48266 .44193 Mtetra
.617 .696 .9 r
.48266 .44193 .48903 .44979 .50043 .44815 .4941 .4396 Mtetra
.585 .665 .894 r
.4941 .4396 .50043 .44815 .5119 .44773 .50559 .43819 Mtetra
.539 .62 .881 r
.50559 .43819 .5119 .44773 .52344 .44904 .51714 .43815 Mtetra
.476 .558 .86 r
.51714 .43815 .52344 .44904 .53507 .45264 .52877 .44003 Mtetra
.398 .482 .829 r
.52877 .44003 .53507 .45264 .54682 .45904 .54051 .44444 Mtetra
.31 .396 .79 r
.54051 .44444 .54682 .45904 .55872 .46863 .55237 .45194 Mtetra
.22 .312 .746 r
.55237 .45194 .55872 .46863 .57082 .4815 .56442 .46292 Mtetra
.136 .235 .704 r
.56442 .46292 .57082 .4815 .58314 .49727 .57667 .47745 Mtetra
.06 .172 .669 r
.57667 .47745 .58314 .49727 .5957 .51502 .58918 .49507 Mtetra
0 .125 .645 r
.58918 .49507 .5957 .51502 .60848 .53322 .60194 .51473 Mtetra
0 .096 .635 r
.60194 .51473 .60848 .53322 .62144 .54987 .61494 .53472 Mtetra
0 .089 .643 r
.61494 .53472 .62144 .54987 .63448 .56275 .62812 .55282 Mtetra
0 .121 .667 r
.62812 .55282 .63448 .56275 .64749 .56982 .64138 .56662 Mtetra
.357 0 0 r
.64138 .56662 .64749 .56982 .66035 .56964 .65457 .57391 Mtetra
.274 0 0 r
.65457 .57391 .66035 .56964 .67296 .56168 .66758 .5732 Mtetra
.134 0 .033 r
.66758 .5732 .67296 .56168 .68525 .54651 .68027 .56404 Mtetra
.049 0 .13 r
.68027 .56404 .68525 .54651 .69722 .5256 .69261 .54714 Mtetra
0 0 .164 r
.69261 .54714 .69722 .5256 .70891 .501 .70457 .5242 Mtetra
0 0 .166 r
.70457 .5242 .70891 .501 .7204 .47494 .71623 .4975 Mtetra
0 0 .144 r
.71623 .4975 .7204 .47494 .73182 .4494 .72769 .46947 Mtetra
0 0 .096 r
.72769 .46947 .73182 .4494 .74326 .42589 .73907 .44222 Mtetra
0 0 .013 r
.73907 .44222 .74326 .42589 .7548 .40531 .75048 .41731 Mtetra
0 0 0 r
.75048 .41731 .7548 .40531 .76652 .38802 .76202 .39566 Mtetra
.76202 .39566 .76652 .38802 .77844 .3739 .77375 .37758 Mtetra
.713 .931 .605 r
.77375 .37758 .77844 .3739 .79057 .36257 .78571 .36291 Mtetra
.806 1 .819 r
.78571 .36291 .79057 .36257 .8029 .35349 .79789 .35121 Mtetra
.803 .96 .913 r
.79789 .35121 .8029 .35349 .8154 .34612 .81028 .34189 Mtetra
.764 .89 .934 r
.81028 .34189 .8154 .34612 .82804 .33995 .82286 .33436 Mtetra
.727 .833 .931 r
.82286 .33436 .82804 .33995 .84081 .33458 .83559 .32808 Mtetra
.701 .795 .923 r
.83559 .32808 .84081 .33458 .85368 .32971 .84845 .32262 Mtetra
.685 .771 .917 r
.84845 .32262 .85368 .32971 .86664 .32513 .86142 .31769 Mtetra
.675 .757 .913 r
.86142 .31769 .86664 .32513 .87966 .32071 .87447 .31305 Mtetra
.669 .749 .911 r
.87447 .31305 .87966 .32071 .89276 .31637 .8876 .30858 Mtetra
.664 .741 .908 r
.28827 .49491 .29517 .50134 .30585 .49786 .29897 .49141 Mtetra
.29897 .49141 .30585 .49786 .31656 .49437 .30971 .48789 Mtetra
.30971 .48789 .31656 .49437 .32732 .49087 .3205 .48436 Mtetra
.3205 .48436 .32732 .49087 .33812 .48735 .33133 .48082 Mtetra
.33133 .48082 .33812 .48735 .34897 .48382 .3422 .47726 Mtetra
.3422 .47726 .34897 .48382 .35986 .48027 .35312 .47368 Mtetra
.35312 .47368 .35986 .48027 .3708 .47671 .36408 .47009 Mtetra
.36408 .47009 .3708 .47671 .38178 .47313 .37509 .46649 Mtetra
.37509 .46649 .38178 .47313 .39281 .46954 .38615 .46287 Mtetra
.663 .741 .908 r
.38615 .46287 .39281 .46954 .40388 .46594 .39725 .45924 Mtetra
.39725 .45924 .40388 .46594 .415 .46233 .40839 .4556 Mtetra
.40839 .4556 .415 .46233 .42616 .45872 .41959 .45195 Mtetra
.663 .74 .908 r
.41959 .45195 .42616 .45872 .43737 .45512 .43083 .44829 Mtetra
.662 .739 .908 r
.43083 .44829 .43737 .45512 .44862 .45157 .44211 .44466 Mtetra
.659 .737 .907 r
.44211 .44466 .44862 .45157 .45992 .44811 .45344 .44107 Mtetra
.655 .733 .906 r
.45344 .44107 .45992 .44811 .47127 .44485 .46482 .43759 Mtetra
.648 .725 .905 r
.46482 .43759 .47127 .44485 .48266 .44193 .47624 .43432 Mtetra
.635 .711 .901 r
.47624 .43432 .48266 .44193 .4941 .4396 .48772 .43141 Mtetra
.614 .688 .896 r
.48772 .43141 .4941 .4396 .50559 .43819 .49924 .42913 Mtetra
.582 .653 .885 r
.49924 .42913 .50559 .43819 .51714 .43815 .51081 .42783 Mtetra
.537 .603 .867 r
.51081 .42783 .51714 .43815 .52877 .44003 .52245 .42797 Mtetra
.478 .538 .84 r
.52245 .42797 .52877 .44003 .54051 .44444 .53418 .43012 Mtetra
.41 .462 .803 r
.53418 .43012 .54051 .44444 .55237 .45194 .54601 .43489 Mtetra
.34 .384 .762 r
.54601 .43489 .55237 .45194 .56442 .46292 .55799 .44286 Mtetra
.277 .314 .72 r
.55799 .44286 .56442 .46292 .57667 .47745 .57016 .45439 Mtetra
.227 .258 .685 r
.57016 .45439 .57667 .47745 .58918 .49507 .58256 .46951 Mtetra
.192 .219 .661 r
.58256 .46951 .58918 .49507 .60194 .51473 .59522 .48771 Mtetra
.172 .199 .648 r
.59522 .48771 .60194 .51473 .61494 .53472 .60814 .50785 Mtetra
.17 .2 .65 r
.60814 .50785 .61494 .53472 .62812 .55282 .62131 .52813 Mtetra
.188 .227 .671 r
.62131 .52813 .62812 .55282 .64138 .56662 .63464 .54626 Mtetra
.236 .294 .72 r
.63464 .54626 .64138 .56662 .65457 .57391 .64803 .55978 Mtetra
.341 .438 .815 r
.64803 .55978 .65457 .57391 .66758 .5732 .66134 .5665 Mtetra
.555 .732 .958 r
.66134 .5665 .66758 .5732 .68027 .56404 .67443 .56497 Mtetra
.735 .992 .843 r
.67443 .56497 .68027 .56404 .69261 .54714 .68719 .55486 Mtetra
.59 .81 .41 r
.68719 .55486 .69261 .54714 .70457 .5242 .69955 .537 Mtetra
0 0 0 r
.69955 .537 .70457 .5242 .71623 .4975 .71153 .51319 Mtetra
.71153 .51319 .71623 .4975 .72769 .46947 .7232 .48581 Mtetra
.7232 .48581 .72769 .46947 .73907 .44222 .73467 .4573 Mtetra
.73467 .4573 .73907 .44222 .75048 .41731 .74607 .42978 Mtetra
.74607 .42978 .75048 .41731 .76202 .39566 .75752 .40476 Mtetra
.75752 .40476 .76202 .39566 .77375 .37758 .76912 .38311 Mtetra
.7 .879 .488 r
.76912 .38311 .77375 .37758 .78571 .36291 .78092 .36509 Mtetra
.803 .981 .701 r
.78092 .36509 .78571 .36291 .79789 .35121 .79296 .35052 Mtetra
.834 .994 .852 r
.79296 .35052 .79789 .35121 .81028 .34189 .80523 .33891 Mtetra
.806 .941 .916 r
.80523 .33891 .81028 .34189 .82286 .33436 .81772 .32965 Mtetra
.762 .876 .93 r
.81772 .32965 .82286 .33436 .83559 .32808 .83039 .32216 Mtetra
.725 .825 .927 r
.83039 .32216 .83559 .32808 .84845 .32262 .84322 .31589 Mtetra
.699 .79 .921 r
.84322 .31589 .84845 .32262 .86142 .31769 .85619 .31043 Mtetra
.684 .769 .916 r
.85619 .31043 .86142 .31769 .87447 .31305 .86925 .30547 Mtetra
.674 .756 .912 r
.86925 .30547 .87447 .31305 .8876 .30858 .88241 .30079 Mtetra
.664 .741 .908 r
.28131 .48843 .28827 .49491 .29897 .49141 .29204 .48491 Mtetra
.29204 .48491 .29897 .49141 .30971 .48789 .30281 .48136 Mtetra
.30281 .48136 .30971 .48789 .3205 .48436 .31362 .47781 Mtetra
.31362 .47781 .3205 .48436 .33133 .48082 .32448 .47423 Mtetra
.32448 .47423 .33133 .48082 .3422 .47726 .33538 .47065 Mtetra
.33538 .47065 .3422 .47726 .35312 .47368 .34633 .46705 Mtetra
.34633 .46705 .35312 .47368 .36408 .47009 .35732 .46343 Mtetra
.35732 .46343 .36408 .47009 .37509 .46649 .36835 .4598 Mtetra
.36835 .4598 .37509 .46649 .38615 .46287 .37944 .45615 Mtetra
.37944 .45615 .38615 .46287 .39725 .45924 .39057 .45249 Mtetra
.663 .741 .908 r
.39057 .45249 .39725 .45924 .40839 .4556 .40174 .44882 Mtetra
.40174 .44882 .40839 .4556 .41959 .45195 .41296 .44513 Mtetra
.41296 .44513 .41959 .45195 .43083 .44829 .42423 .44143 Mtetra
.663 .74 .908 r
.42423 .44143 .43083 .44829 .44211 .44466 .43555 .43774 Mtetra
.662 .739 .907 r
.43555 .43774 .44211 .44466 .45344 .44107 .44691 .43406 Mtetra
.659 .736 .907 r
.44691 .43406 .45344 .44107 .46482 .43759 .45832 .43043 Mtetra
.655 .732 .906 r
.45832 .43043 .46482 .43759 .47624 .43432 .46978 .42691 Mtetra
.648 .723 .903 r
.46978 .42691 .47624 .43432 .48772 .43141 .48128 .4236 Mtetra
.635 .708 .899 r
.48128 .4236 .48772 .43141 .49924 .42913 .49283 .42066 Mtetra
.615 .683 .891 r
.49283 .42066 .49924 .42913 .51081 .42783 .50444 .41834 Mtetra
.584 .645 .877 r
.50444 .41834 .51081 .42783 .52245 .42797 .5161 .417 Mtetra
.541 .593 .855 r
.5161 .417 .52245 .42797 .53418 .43012 .52783 .41708 Mtetra
.489 .528 .824 r
.52783 .41708 .53418 .43012 .54601 .43489 .53964 .41914 Mtetra
.431 .456 .785 r
.53964 .41914 .54601 .43489 .55799 .44286 .55158 .42376 Mtetra
.377 .387 .744 r
.55158 .42376 .55799 .44286 .57016 .45439 .56366 .43147 Mtetra
.333 .329 .705 r
.56366 .43147 .57016 .45439 .58256 .46951 .57594 .4426 Mtetra
.303 .286 .674 r
.57594 .4426 .58256 .46951 .59522 .48771 .58844 .45712 Mtetra
.287 .26 .653 r
.58844 .45712 .59522 .48771 .60814 .50785 .60121 .4745 Mtetra
.288 .251 .642 r
.60121 .4745 .60814 .50785 .62131 .52813 .61424 .49357 Mtetra
.304 .259 .642 r
.61424 .49357 .62131 .52813 .63464 .54626 .62749 .51257 Mtetra
.337 .286 .653 r
.62749 .51257 .63464 .54626 .64803 .55978 .6409 .52928 Mtetra
.393 .337 .675 r
.6409 .52928 .64803 .55978 .66134 .5665 .65435 .54137 Mtetra
.479 .419 .712 r
.65435 .54137 .66134 .5665 .67443 .56497 .6677 .54681 Mtetra
.605 .544 .76 r
.6677 .54681 .67443 .56497 .68719 .55486 .68082 .54432 Mtetra
.772 .719 .802 r
.68082 .54432 .68719 .55486 .69955 .537 .6936 .5337 Mtetra
.923 .891 .782 r
.6936 .5337 .69955 .537 .71153 .51319 .706 .51582 Mtetra
.949 .952 .653 r
.706 .51582 .71153 .51319 .7232 .48581 .71803 .49247 Mtetra
.873 .908 .499 r
.71803 .49247 .7232 .48581 .73467 .4573 .72976 .46594 Mtetra
.794 .854 .403 r
.72976 .46594 .73467 .4573 .74607 .42978 .74132 .43853 Mtetra
.755 .836 .379 r
.74132 .43853 .74607 .42978 .75752 .40476 .75282 .41221 Mtetra
.759 .858 .419 r
.75282 .41221 .75752 .40476 .76912 .38311 .76438 .38838 Mtetra
.796 .912 .519 r
.76438 .38838 .76912 .38311 .78092 .36509 .7761 .3678 Mtetra
.843 .972 .659 r
.7761 .3678 .78092 .36509 .79296 .35052 .78803 .35068 Mtetra
.864 .996 .794 r
.78803 .35068 .79296 .35052 .80523 .33891 .8002 .33681 Mtetra
.843 .968 .881 r
.8002 .33681 .80523 .33891 .81772 .32965 .81259 .32572 Mtetra
.798 .911 .918 r
.81259 .32572 .81772 .32965 .83039 .32216 .8252 .31682 Mtetra
.753 .855 .925 r
.8252 .31682 .83039 .32216 .84322 .31589 .83799 .30955 Mtetra
.719 .812 .923 r
.83799 .30955 .84322 .31589 .85619 .31043 .85094 .30341 Mtetra
.696 .783 .918 r
.85094 .30341 .85619 .31043 .86925 .30547 .86401 .298 Mtetra
.682 .765 .914 r
.86401 .298 .86925 .30547 .88241 .30079 .87718 .29305 Mtetra
.664 .741 .908 r
.27431 .48191 .28131 .48843 .29204 .48491 .28506 .47835 Mtetra
.28506 .47835 .29204 .48491 .30281 .48136 .29585 .47478 Mtetra
.29585 .47478 .30281 .48136 .31362 .47781 .30669 .4712 Mtetra
.30669 .4712 .31362 .47781 .32448 .47423 .31758 .4676 Mtetra
.31758 .4676 .32448 .47423 .33538 .47065 .3285 .46399 Mtetra
.3285 .46399 .33538 .47065 .34633 .46705 .33948 .46036 Mtetra
.33948 .46036 .34633 .46705 .35732 .46343 .3505 .45671 Mtetra
.3505 .45671 .35732 .46343 .36835 .4598 .36156 .45306 Mtetra
.36156 .45306 .36835 .4598 .37944 .45615 .37268 .44938 Mtetra
.37268 .44938 .37944 .45615 .39057 .45249 .38383 .44569 Mtetra
.38383 .44569 .39057 .45249 .40174 .44882 .39504 .44199 Mtetra
.663 .741 .908 r
.39504 .44199 .40174 .44882 .41296 .44513 .40629 .43827 Mtetra
.40629 .43827 .41296 .44513 .42423 .44143 .41759 .43454 Mtetra
.41759 .43454 .42423 .44143 .43555 .43774 .42893 .4308 Mtetra
.663 .74 .908 r
.42893 .4308 .43555 .43774 .44691 .43406 .44033 .42706 Mtetra
.662 .739 .907 r
.44033 .42706 .44691 .43406 .45832 .43043 .45177 .42333 Mtetra
.66 .736 .907 r
.45177 .42333 .45832 .43043 .46978 .42691 .46326 .41965 Mtetra
.656 .731 .905 r
.46326 .41965 .46978 .42691 .48128 .4236 .47479 .41607 Mtetra
.649 .722 .902 r
.47479 .41607 .48128 .4236 .49283 .42066 .48638 .4127 Mtetra
.637 .706 .897 r
.48638 .4127 .49283 .42066 .50444 .41834 .49801 .40967 Mtetra
.618 .681 .888 r
.49801 .40967 .50444 .41834 .5161 .417 .5097 .40723 Mtetra
.589 .643 .872 r
.5097 .40723 .5161 .417 .52783 .41708 .52145 .40569 Mtetra
.552 .592 .848 r
.52145 .40569 .52783 .41708 .53964 .41914 .53327 .40548 Mtetra
.506 .529 .815 r
.53327 .40548 .53964 .41914 .55158 .42376 .54517 .40709 Mtetra
.458 .463 .775 r
.54517 .40709 .55158 .42376 .56366 .43147 .5572 .41105 Mtetra
.415 .401 .735 r
.5572 .41105 .56366 .43147 .57594 .4426 .56937 .41782 Mtetra
.383 .351 .699 r
.56937 .41782 .57594 .4426 .58844 .45712 .58173 .42766 Mtetra
.363 .315 .67 r
.58173 .42766 .58844 .45712 .60121 .4745 .59431 .44051 Mtetra
.356 .295 .65 r
.59431 .44051 .60121 .4745 .61424 .49357 .60714 .45581 Mtetra
.363 .29 .639 r
.60714 .45581 .61424 .49357 .62749 .51257 .6202 .47246 Mtetra
.382 .298 .636 r
.6202 .47246 .62749 .51257 .6409 .52928 .63348 .48884 Mtetra
.414 .32 .64 r
.63348 .48884 .6409 .52928 .65435 .54137 .64688 .50296 Mtetra
.46 .357 .651 r
.64688 .50296 .65435 .54137 .6677 .54681 .66031 .51274 Mtetra
.522 .411 .668 r
.66031 .51274 .6677 .54681 .68082 .54432 .67364 .51644 Mtetra
.602 .484 .691 r
.67364 .51644 .68082 .54432 .6936 .5337 .68675 .51303 Mtetra
.701 .58 .715 r
.68675 .51303 .6936 .5337 .706 .51582 .69954 .5024 Mtetra
.811 .692 .733 r
.69954 .5024 .706 .51582 .71803 .49247 .71198 .48543 Mtetra
.909 .804 .731 r
.71198 .48543 .71803 .49247 .72976 .46594 .72409 .46376 Mtetra
.966 .887 .702 r
.72409 .46376 .72976 .46594 .74132 .43853 .73595 .43941 Mtetra
.972 .928 .66 r
.73595 .43941 .74132 .43853 .75282 .41221 .74766 .41444 Mtetra
.953 .946 .637 r
.74766 .41444 .75282 .41221 .76438 .38838 .75934 .39056 Mtetra
.933 .959 .652 r
.75934 .39056 .76438 .38838 .7761 .3678 .77109 .36898 Mtetra
.919 .975 .706 r
.77109 .36898 .7761 .3678 .78803 .35068 .783 .35033 Mtetra
.904 .982 .782 r
.783 .35033 .78803 .35068 .8002 .33681 .79511 .33477 Mtetra
.874 .965 .853 r
.79511 .33477 .8002 .33681 .81259 .32572 .80744 .32208 Mtetra
.829 .924 .897 r
.80744 .32208 .81259 .32572 .8252 .31682 .82 .31184 Mtetra
.781 .875 .916 r
.82 .31184 .8252 .31682 .83799 .30955 .83275 .30352 Mtetra
.74 .831 .92 r
.83275 .30352 .83799 .30955 .85094 .30341 .84567 .29661 Mtetra
.711 .797 .918 r
.84567 .29661 .85094 .30341 .86401 .298 .85874 .29067 Mtetra
.691 .774 .915 r
.85874 .29067 .86401 .298 .87718 .29305 .87193 .28537 Mtetra
.664 .741 .908 r
.26725 .47533 .27431 .48191 .28506 .47835 .27802 .47175 Mtetra
.27802 .47175 .28506 .47835 .29585 .47478 .28884 .46816 Mtetra
.28884 .46816 .29585 .47478 .30669 .4712 .29971 .46454 Mtetra
.29971 .46454 .30669 .4712 .31758 .4676 .31062 .46092 Mtetra
.31062 .46092 .31758 .4676 .3285 .46399 .32158 .45728 Mtetra
.32158 .45728 .3285 .46399 .33948 .46036 .33258 .45362 Mtetra
.33258 .45362 .33948 .46036 .3505 .45671 .34363 .44995 Mtetra
.34363 .44995 .3505 .45671 .36156 .45306 .35472 .44626 Mtetra
.35472 .44626 .36156 .45306 .37268 .44938 .36586 .44256 Mtetra
.36586 .44256 .37268 .44938 .38383 .44569 .37705 .43884 Mtetra
.37705 .43884 .38383 .44569 .39504 .44199 .38828 .43511 Mtetra
.38828 .43511 .39504 .44199 .40629 .43827 .39956 .43136 Mtetra
.663 .741 .908 r
.39956 .43136 .40629 .43827 .41759 .43454 .41089 .42759 Mtetra
.41089 .42759 .41759 .43454 .42893 .4308 .42227 .42382 Mtetra
.42227 .42382 .42893 .4308 .44033 .42706 .43369 .42003 Mtetra
.663 .74 .908 r
.43369 .42003 .44033 .42706 .45177 .42333 .44516 .41624 Mtetra
.662 .739 .907 r
.44516 .41624 .45177 .42333 .46326 .41965 .45669 .41246 Mtetra
.66 .736 .906 r
.45669 .41246 .46326 .41965 .47479 .41607 .46825 .40873 Mtetra
.656 .731 .905 r
.46825 .40873 .47479 .41607 .48638 .4127 .47987 .40508 Mtetra
.65 .723 .902 r
.47987 .40508 .48638 .4127 .49801 .40967 .49154 .40161 Mtetra
.64 .707 .896 r
.49154 .40161 .49801 .40967 .5097 .40723 .50326 .39845 Mtetra
.623 .683 .886 r
.50326 .39845 .5097 .40723 .52145 .40569 .51503 .3958 Mtetra
.598 .647 .869 r
.51503 .3958 .52145 .40569 .53327 .40548 .52686 .39395 Mtetra
.566 .598 .845 r
.52686 .39395 .53327 .40548 .54517 .40709 .53877 .39326 Mtetra
.527 .54 .812 r
.53877 .39326 .54517 .40709 .5572 .41105 .55076 .39414 Mtetra
.487 .479 .774 r
.55076 .39414 .5572 .41105 .56937 .41782 .56287 .39705 Mtetra
.452 .422 .735 r
.56287 .39705 .56937 .41782 .58173 .42766 .57511 .40235 Mtetra
.426 .377 .7 r
.57511 .40235 .58173 .42766 .59431 .44051 .58753 .41024 Mtetra
.412 .345 .672 r
.58753 .41024 .59431 .44051 .60714 .45581 .60016 .42061 Mtetra
.409 .327 .653 r
.60016 .42061 .60714 .45581 .6202 .47246 .613 .43295 Mtetra
.416 .322 .64 r
.613 .43295 .6202 .47246 .63348 .48884 .62606 .44627 Mtetra
.433 .328 .635 r
.62606 .44627 .63348 .48884 .64688 .50296 .63929 .45919 Mtetra
.46 .345 .635 r
.63929 .45919 .64688 .50296 .66031 .51274 .65264 .47 Mtetra
.497 .373 .641 r
.65264 .47 .66031 .51274 .67364 .51644 .66599 .47701 Mtetra
.544 .411 .651 r
.66599 .47701 .67364 .51644 .68675 .51303 .67926 .47883 Mtetra
.601 .462 .664 r
.67926 .47883 .68675 .51303 .69954 .5024 .69232 .47466 Mtetra
.668 .525 .681 r
.69232 .47466 .69954 .5024 .71198 .48543 .70512 .4645 Mtetra
.743 .6 .698 r
.70512 .4645 .71198 .48543 .72409 .46376 .71763 .44915 Mtetra
.819 .683 .714 r
.71763 .44915 .72409 .46376 .73595 .43941 .72986 .43 Mtetra
.885 .765 .725 r
.72986 .43 .73595 .43941 .74766 .41444 .7419 .40876 Mtetra
.928 .835 .732 r
.7419 .40876 .74766 .41444 .75934 .39056 .75382 .3871 Mtetra
.946 .886 .741 r
.75382 .3871 .75934 .39056 .77109 .36898 .76573 .36645 Mtetra
.942 .918 .762 r
.76573 .36645 .77109 .36898 .783 .35033 .77773 .34777 Mtetra
.922 .934 .797 r
.77773 .34777 .783 .35033 .79511 .33477 .78987 .33157 Mtetra
.889 .931 .84 r
.78987 .33157 .79511 .33477 .80744 .32208 .8022 .31795 Mtetra
.847 .909 .878 r
.8022 .31795 .80744 .32208 .82 .31184 .81473 .30673 Mtetra
.801 .876 .902 r
.81473 .30673 .82 .31184 .83275 .30352 .82746 .29752 Mtetra
.759 .839 .913 r
.82746 .29752 .83275 .30352 .84567 .29661 .84037 .28989 Mtetra
.725 .807 .915 r
.84037 .28989 .84567 .29661 .85874 .29067 .85344 .28341 Mtetra
.701 .782 .914 r
.85344 .28341 .85874 .29067 .87193 .28537 .86663 .27773 Mtetra
.664 .741 .908 r
.26013 .46871 .26725 .47533 .27802 .47175 .27093 .4651 Mtetra
.27093 .4651 .27802 .47175 .28884 .46816 .28178 .46148 Mtetra
.28178 .46148 .28884 .46816 .29971 .46454 .29268 .45784 Mtetra
.29268 .45784 .29971 .46454 .31062 .46092 .30361 .45418 Mtetra
.30361 .45418 .31062 .46092 .32158 .45728 .3146 .45051 Mtetra
.3146 .45051 .32158 .45728 .33258 .45362 .32563 .44683 Mtetra
.32563 .44683 .33258 .45362 .34363 .44995 .3367 .44313 Mtetra
.3367 .44313 .34363 .44995 .35472 .44626 .34783 .43941 Mtetra
.34783 .43941 .35472 .44626 .36586 .44256 .35899 .43568 Mtetra
.35899 .43568 .36586 .44256 .37705 .43884 .37021 .43193 Mtetra
.37021 .43193 .37705 .43884 .38828 .43511 .38147 .42817 Mtetra
.38147 .42817 .38828 .43511 .39956 .43136 .39278 .42439 Mtetra
.39278 .42439 .39956 .43136 .41089 .42759 .40414 .4206 Mtetra
.663 .741 .908 r
.40414 .4206 .41089 .42759 .42227 .42382 .41555 .41679 Mtetra
.41555 .41679 .42227 .42382 .43369 .42003 .427 .41297 Mtetra
.427 .41297 .43369 .42003 .44516 .41624 .43851 .40913 Mtetra
.663 .74 .908 r
.43851 .40913 .44516 .41624 .45669 .41246 .45006 .40529 Mtetra
.662 .739 .907 r
.45006 .40529 .45669 .41246 .46825 .40873 .46166 .40146 Mtetra
.66 .737 .906 r
.46166 .40146 .46825 .40873 .47987 .40508 .47331 .39766 Mtetra
.657 .732 .905 r
.47331 .39766 .47987 .40508 .49154 .40161 .48501 .39394 Mtetra
.652 .724 .901 r
.48501 .39394 .49154 .40161 .50326 .39845 .49676 .39035 Mtetra
.643 .71 .896 r
.49676 .39035 .50326 .39845 .51503 .3958 .50857 .38703 Mtetra
.629 .688 .886 r
.50857 .38703 .51503 .3958 .52686 .39395 .52042 .38413 Mtetra
.609 .655 .87 r
.52042 .38413 .52686 .39395 .53877 .39326 .53234 .38188 Mtetra
.582 .611 .847 r
.53234 .38188 .53877 .39326 .55076 .39414 .54433 .38059 Mtetra
.55 .558 .815 r
.54433 .38059 .55076 .39414 .56287 .39705 .55641 .38058 Mtetra
.517 .502 .779 r
.55641 .38058 .56287 .39705 .57511 .40235 .56859 .3822 Mtetra
.487 .45 .741 r
.56859 .3822 .57511 .40235 .58753 .41024 .5809 .38574 Mtetra
.465 .407 .708 r
.5809 .38574 .58753 .41024 .60016 .42061 .59336 .39132 Mtetra
.453 .377 .68 r
.59336 .39132 .60016 .42061 .613 .43295 .60601 .39881 Mtetra
.45 .358 .66 r
.60601 .39881 .613 .43295 .62606 .44627 .61884 .40778 Mtetra
.457 .352 .647 r
.61884 .40778 .62606 .44627 .63929 .45919 .63185 .41741 Mtetra
.471 .355 .64 r
.63185 .41741 .63929 .45919 .65264 .47 .64501 .42655 Mtetra
.493 .367 .637 r
.64501 .42655 .65264 .47 .66599 .47701 .65826 .43389 Mtetra
.522 .388 .64 r
.65826 .43389 .66599 .47701 .67926 .47883 .67152 .43809 Mtetra
.558 .418 .646 r
.67152 .43809 .67926 .47883 .69232 .47466 .6847 .43813 Mtetra
.601 .456 .656 r
.6847 .43813 .69232 .47466 .70512 .4645 .69773 .43345 Mtetra
.651 .503 .669 r
.69773 .43345 .70512 .4645 .71763 .44915 .71054 .4241 Mtetra
.705 .558 .685 r
.71054 .4241 .71763 .44915 .72986 .43 .72313 .41076 Mtetra
.761 .62 .703 r
.72313 .41076 .72986 .43 .7419 .40876 .73552 .39454 Mtetra
.814 .686 .723 r
.73552 .39454 .7419 .40876 .75382 .3871 .74776 .37677 Mtetra
.856 .749 .745 r
.74776 .37677 .75382 .3871 .76573 .36645 .75993 .35877 Mtetra
.88 .803 .769 r
.75993 .35877 .76573 .36645 .77773 .34777 .77211 .34161 Mtetra
.885 .842 .797 r
.77211 .34161 .77773 .34777 .78987 .33157 .78438 .32604 Mtetra
.871 .864 .829 r
.78438 .32604 .78987 .33157 .8022 .31795 .79678 .31244 Mtetra
.843 .866 .86 r
.79678 .31244 .8022 .31795 .81473 .30673 .80935 .30087 Mtetra
.807 .853 .885 r
.80935 .30087 .81473 .30673 .82746 .29752 .8221 .29117 Mtetra
.769 .831 .901 r
.8221 .29117 .82746 .29752 .84037 .28989 .83501 .28303 Mtetra
.736 .807 .908 r
.83501 .28303 .84037 .28989 .85344 .28341 .84809 .27611 Mtetra
.71 .786 .911 r
.84809 .27611 .85344 .28341 .86663 .27773 .8613 .27006 Mtetra
.664 .741 .908 r
.25296 .46203 .26013 .46871 .27093 .4651 .26379 .4584 Mtetra
.26379 .4584 .27093 .4651 .28178 .46148 .27467 .45475 Mtetra
.27467 .45475 .28178 .46148 .29268 .45784 .28559 .45108 Mtetra
.28559 .45108 .29268 .45784 .30361 .45418 .29655 .4474 Mtetra
.29655 .4474 .30361 .45418 .3146 .45051 .30756 .4437 Mtetra
.30756 .4437 .3146 .45051 .32563 .44683 .31862 .43998 Mtetra
.31862 .43998 .32563 .44683 .3367 .44313 .32973 .43626 Mtetra
.32973 .43626 .3367 .44313 .34783 .43941 .34088 .43251 Mtetra
.34088 .43251 .34783 .43941 .35899 .43568 .35207 .42875 Mtetra
.35207 .42875 .35899 .43568 .37021 .43193 .36332 .42497 Mtetra
.36332 .42497 .37021 .43193 .38147 .42817 .37461 .42118 Mtetra
.37461 .42118 .38147 .42817 .39278 .42439 .38595 .41737 Mtetra
.38595 .41737 .39278 .42439 .40414 .4206 .39734 .41355 Mtetra
.39734 .41355 .40414 .4206 .41555 .41679 .40878 .40971 Mtetra
.40878 .40971 .41555 .41679 .427 .41297 .42026 .40585 Mtetra
.663 .741 .908 r
.42026 .40585 .427 .41297 .43851 .40913 .4318 .40198 Mtetra
.4318 .40198 .43851 .40913 .45006 .40529 .44338 .3981 Mtetra
.663 .74 .908 r
.44338 .3981 .45006 .40529 .46166 .40146 .45502 .39421 Mtetra
.662 .739 .907 r
.45502 .39421 .46166 .40146 .47331 .39766 .4667 .39032 Mtetra
.661 .737 .906 r
.4667 .39032 .47331 .39766 .48501 .39394 .47843 .38646 Mtetra
.659 .733 .905 r
.47843 .38646 .48501 .39394 .49676 .39035 .49022 .38265 Mtetra
.654 .726 .902 r
.49022 .38265 .49676 .39035 .50857 .38703 .50205 .37895 Mtetra
.647 .715 .897 r
.50205 .37895 .50857 .38703 .52042 .38413 .51394 .37545 Mtetra
.636 .696 .888 r
.51394 .37545 .52042 .38413 .53234 .38188 .52588 .37228 Mtetra
.62 .667 .874 r
.52588 .37228 .53234 .38188 .54433 .38059 .53789 .36961 Mtetra
.599 .629 .852 r
.53789 .36961 .54433 .38059 .55641 .38058 .54996 .36767 Mtetra
.573 .582 .824 r
.54996 .36767 .55641 .38058 .56859 .3822 .56211 .36672 Mtetra
.546 .531 .79 r
.56211 .36672 .56859 .3822 .5809 .38574 .57436 .367 Mtetra
.521 .483 .755 r
.57436 .367 .5809 .38574 .59336 .39132 .58673 .36872 Mtetra
.501 .442 .722 r
.58673 .36872 .59336 .39132 .60601 .39881 .59923 .37195 Mtetra
.49 .411 .695 r
.59923 .37195 .60601 .39881 .61884 .40778 .61188 .37657 Mtetra
.486 .392 .674 r
.61188 .37657 .61884 .40778 .63185 .41741 .62469 .38222 Mtetra
.49 .383 .659 r
.62469 .38222 .63185 .41741 .64501 .42655 .63765 .38826 Mtetra
.501 .383 .65 r
.63765 .38826 .64501 .42655 .65826 .43389 .65072 .39382 Mtetra
.519 .391 .646 r
.65072 .39382 .65826 .43389 .67152 .43809 .66387 .39792 Mtetra
.542 .407 .647 r
.66387 .39792 .67152 .43809 .6847 .43813 .67704 .39961 Mtetra
.571 .43 .651 r
.67704 .39961 .6847 .43813 .69773 .43345 .69014 .39816 Mtetra
.604 .46 .659 r
.69014 .39816 .69773 .43345 .71054 .4241 .70314 .39321 Mtetra
.642 .497 .67 r
.70314 .39321 .71054 .4241 .72313 .41076 .71599 .38484 Mtetra
.683 .541 .685 r
.71599 .38484 .72313 .41076 .73552 .39454 .72869 .37358 Mtetra
.726 .591 .704 r
.72869 .37358 .73552 .39454 .74776 .37677 .74124 .36026 Mtetra
.766 .644 .727 r
.74124 .36026 .74776 .37677 .75993 .35877 .7537 .34586 Mtetra
.799 .697 .752 r
.7537 .34586 .75993 .35877 .77211 .34161 .76613 .33135 Mtetra
.82 .745 .781 r
.76613 .33135 .77211 .34161 .78438 .32604 .77859 .31751 Mtetra
.826 .783 .812 r
.77859 .31751 .78438 .32604 .79678 .31244 .79114 .30488 Mtetra
.816 .806 .841 r
.79114 .30488 .79678 .31244 .80935 .30087 .8038 .2937 Mtetra
.795 .813 .867 r
.8038 .2937 .80935 .30087 .8221 .29117 .81661 .28403 Mtetra
.767 .809 .886 r
.81661 .28403 .8221 .29117 .83501 .28303 .82957 .27573 Mtetra
.739 .797 .899 r
.82957 .27573 .83501 .28303 .84809 .27611 .84268 .26856 Mtetra
.715 .783 .905 r
.84268 .26856 .84809 .27611 .8613 .27006 .85592 .26227 Mtetra
.664 .741 .908 r
.24574 .45531 .25296 .46203 .26379 .4584 .25659 .45164 Mtetra
.25659 .45164 .26379 .4584 .27467 .45475 .2675 .44796 Mtetra
.2675 .44796 .27467 .45475 .28559 .45108 .27844 .44427 Mtetra
.27844 .44427 .28559 .45108 .29655 .4474 .28944 .44056 Mtetra
.28944 .44056 .29655 .4474 .30756 .4437 .30048 .43683 Mtetra
.30048 .43683 .30756 .4437 .31862 .43998 .31156 .43309 Mtetra
.31156 .43309 .31862 .43998 .32973 .43626 .32269 .42933 Mtetra
.32269 .42933 .32973 .43626 .34088 .43251 .33387 .42556 Mtetra
.33387 .42556 .34088 .43251 .35207 .42875 .3451 .42177 Mtetra
.3451 .42177 .35207 .42875 .36332 .42497 .35637 .41796 Mtetra
.35637 .41796 .36332 .42497 .37461 .42118 .3677 .41414 Mtetra
.3677 .41414 .37461 .42118 .38595 .41737 .37907 .4103 Mtetra
.37907 .4103 .38595 .41737 .39734 .41355 .39048 .40644 Mtetra
.39048 .40644 .39734 .41355 .40878 .40971 .40195 .40257 Mtetra
.40195 .40257 .40878 .40971 .42026 .40585 .41347 .39869 Mtetra
.41347 .39869 .42026 .40585 .4318 .40198 .42503 .39478 Mtetra
.663 .741 .908 r
.42503 .39478 .4318 .40198 .44338 .3981 .43665 .39087 Mtetra
.43665 .39087 .44338 .3981 .45502 .39421 .44832 .38693 Mtetra
.44832 .38693 .45502 .39421 .4667 .39032 .46003 .38299 Mtetra
.662 .74 .907 r
.46003 .38299 .4667 .39032 .47843 .38646 .4718 .37905 Mtetra
.661 .738 .907 r
.4718 .37905 .47843 .38646 .49022 .38265 .48362 .37513 Mtetra
.66 .735 .906 r
.48362 .37513 .49022 .38265 .50205 .37895 .49548 .37124 Mtetra
.656 .73 .903 r
.49548 .37124 .50205 .37895 .51394 .37545 .50741 .36743 Mtetra
.651 .72 .899 r
.50741 .36743 .51394 .37545 .52588 .37228 .51938 .36377 Mtetra
.643 .705 .892 r
.51938 .36377 .52588 .37228 .53789 .36961 .53141 .36034 Mtetra
.631 .682 .88 r
.53141 .36034 .53789 .36961 .54996 .36767 .5435 .35727 Mtetra
.615 .65 .862 r
.5435 .35727 .54996 .36767 .56211 .36672 .55566 .35472 Mtetra
.595 .61 .837 r
.55566 .35472 .56211 .36672 .57436 .367 .56789 .35287 Mtetra
.573 .566 .807 r
.56789 .35287 .57436 .367 .58673 .36872 .58021 .3519 Mtetra
.552 .522 .775 r
.58021 .3519 .58673 .36872 .59923 .37195 .59263 .35194 Mtetra
.535 .482 .744 r
.59263 .35194 .59923 .37195 .61188 .37657 .60516 .35303 Mtetra
.524 .451 .716 r
.60516 .35303 .61188 .37657 .62469 .38222 .61782 .35506 Mtetra
.519 .43 .694 r
.61782 .35506 .62469 .38222 .63765 .38826 .63061 .35777 Mtetra
.521 .418 .678 r
.63061 .35777 .63765 .38826 .65072 .39382 .64351 .36067 Mtetra
.529 .415 .668 r
.64351 .36067 .65072 .39382 .66387 .39792 .65652 .36317 Mtetra
.542 .419 .662 r
.65652 .36317 .66387 .39792 .67704 .39961 .66959 .36456 Mtetra
.56 .431 .661 r
.66959 .36456 .67704 .39961 .69014 .39816 .68268 .36421 Mtetra
.583 .449 .664 r
.68268 .36421 .69014 .39816 .70314 .39321 .69574 .36163 Mtetra
.61 .474 .671 r
.69574 .36163 .70314 .39321 .71599 .38484 .70874 .35659 Mtetra
.639 .504 .682 r
.70874 .35659 .71599 .38484 .72869 .37358 .72164 .3492 Mtetra
.671 .541 .697 r
.72164 .3492 .72869 .37358 .74124 .36026 .73445 .33982 Mtetra
.704 .582 .716 r
.73445 .33982 .74124 .36026 .7537 .34586 .74718 .32907 Mtetra
.734 .626 .739 r
.74718 .32907 .7537 .34586 .76613 .33135 .75986 .31761 Mtetra
.758 .671 .766 r
.75986 .31761 .76613 .33135 .77859 .31751 .77254 .30611 Mtetra
.774 .712 .795 r
.77254 .30611 .77859 .31751 .79114 .30488 .78526 .29511 Mtetra
.777 .745 .824 r
.78526 .29511 .79114 .30488 .8038 .2937 .79807 .28496 Mtetra
.77 .767 .85 r
.79807 .28496 .8038 .2937 .81661 .28403 .81098 .27583 Mtetra
.754 .777 .872 r
.81098 .27583 .81661 .28403 .82957 .27573 .82402 .26775 Mtetra
.734 .778 .888 r
.82402 .26775 .82957 .27573 .84268 .26856 .83718 .26061 Mtetra
.715 .773 .898 r
.83718 .26061 .84268 .26856 .85592 .26227 .85046 .25424 Mtetra
.664 .741 .908 r
.23846 .44853 .24574 .45531 .25659 .45164 .24934 .44484 Mtetra
.24934 .44484 .25659 .45164 .2675 .44796 .26027 .44113 Mtetra
.26027 .44113 .2675 .44796 .27844 .44427 .27124 .4374 Mtetra
.27124 .4374 .27844 .44427 .28944 .44056 .28226 .43366 Mtetra
.28226 .43366 .28944 .44056 .30048 .43683 .29333 .42991 Mtetra
.29333 .42991 .30048 .43683 .31156 .43309 .30445 .42614 Mtetra
.30445 .42614 .31156 .43309 .32269 .42933 .31561 .42235 Mtetra
.31561 .42235 .32269 .42933 .33387 .42556 .32681 .41855 Mtetra
.32681 .41855 .33387 .42556 .3451 .42177 .33807 .41473 Mtetra
.33807 .41473 .3451 .42177 .35637 .41796 .34937 .41089 Mtetra
.34937 .41089 .35637 .41796 .3677 .41414 .36072 .40704 Mtetra
.36072 .40704 .3677 .41414 .37907 .4103 .37213 .40317 Mtetra
.37213 .40317 .37907 .4103 .39048 .40644 .38357 .39929 Mtetra
.38357 .39929 .39048 .40644 .40195 .40257 .39507 .39538 Mtetra
.39507 .39538 .40195 .40257 .41347 .39869 .40662 .39147 Mtetra
.663 .741 .908 r
.40662 .39147 .41347 .39869 .42503 .39478 .41822 .38753 Mtetra
.41822 .38753 .42503 .39478 .43665 .39087 .42986 .38359 Mtetra
.42986 .38359 .43665 .39087 .44832 .38693 .44156 .37963 Mtetra
.44156 .37963 .44832 .38693 .46003 .38299 .45331 .37566 Mtetra
.45331 .37566 .46003 .38299 .4718 .37905 .46511 .37168 Mtetra
.662 .741 .909 r
.46511 .37168 .4718 .37905 .48362 .37513 .47696 .36771 Mtetra
.661 .74 .909 r
.47696 .36771 .48362 .37513 .49548 .37124 .48886 .36374 Mtetra
.66 .739 .908 r
.48886 .36374 .49548 .37124 .50741 .36743 .50082 .3598 Mtetra
.658 .735 .907 r
.50082 .3598 .50741 .36743 .51938 .36377 .51282 .3559 Mtetra
.654 .728 .903 r
.51282 .3559 .51938 .36377 .53141 .36034 .52489 .35209 Mtetra
.649 .717 .897 r
.52489 .35209 .53141 .36034 .5435 .35727 .537 .34842 Mtetra
.641 .699 .888 r
.537 .34842 .5435 .35727 .55566 .35472 .54918 .34498 Mtetra
.63 .674 .873 r
.54918 .34498 .55566 .35472 .56789 .35287 .56142 .34187 Mtetra
.616 .641 .853 r
.56142 .34187 .56789 .35287 .58021 .3519 .57373 .33923 Mtetra
.599 .603 .827 r
.57373 .33923 .58021 .3519 .59263 .35194 .58612 .33718 Mtetra
.582 .564 .799 r
.58612 .33718 .59263 .35194 .60516 .35303 .59859 .33579 Mtetra
.567 .527 .77 r
.59859 .33579 .60516 .35303 .61782 .35506 .61117 .3351 Mtetra
.556 .496 .744 r
.61117 .3351 .61782 .35506 .63061 .35777 .62385 .33501 Mtetra
.55 .474 .722 r
.62385 .33501 .63061 .35777 .64351 .36067 .63663 .33533 Mtetra
.55 .459 .705 r
.63663 .33533 .64351 .36067 .65652 .36317 .64951 .33575 Mtetra
.555 .453 .693 r
.64951 .33575 .65652 .36317 .66959 .36456 .66247 .33584 Mtetra
.565 .454 .686 r
.66247 .33584 .66959 .36456 .68268 .36421 .67549 .33515 Mtetra
.579 .462 .684 r
.67549 .33515 .68268 .36421 .69574 .36163 .68854 .33326 Mtetra
.596 .476 .686 r
.68854 .33326 .69574 .36163 .70874 .35659 .70159 .32988 Mtetra
.618 .497 .693 r
.70159 .32988 .70874 .35659 .72164 .3492 .71461 .32488 Mtetra
.641 .523 .703 r
.71461 .32488 .72164 .3492 .73445 .33982 .72758 .31834 Mtetra
.666 .554 .718 r
.72758 .31834 .73445 .33982 .74718 .32907 .74051 .31052 Mtetra
.69 .589 .737 r
.74051 .31052 .74718 .32907 .75986 .31761 .75341 .30183 Mtetra
.712 .627 .76 r
.75341 .30183 .75986 .31761 .77254 .30611 .7663 .2927 Mtetra
.729 .664 .786 r
.7663 .2927 .77254 .30611 .78526 .29511 .77921 .28357 Mtetra
.739 .699 .813 r
.77921 .28357 .78526 .29511 .79807 .28496 .79217 .27478 Mtetra
.741 .726 .838 r
.79217 .27478 .79807 .28496 .81098 .27583 .80521 .26656 Mtetra
.734 .745 .861 r
.80521 .26656 .81098 .27583 .82402 .26775 .81835 .25901 Mtetra
.723 .755 .878 r
.81835 .25901 .82402 .26775 .83718 .26061 .83159 .25214 Mtetra
.709 .758 .891 r
.83159 .25214 .83718 .26061 .85046 .25424 .84494 .24587 Mtetra
.664 .741 .908 r
.23112 .4417 .23846 .44853 .24934 .44484 .24203 .43798 Mtetra
.24203 .43798 .24934 .44484 .26027 .44113 .25299 .43424 Mtetra
.25299 .43424 .26027 .44113 .27124 .4374 .26399 .43049 Mtetra
.26399 .43049 .27124 .4374 .28226 .43366 .27504 .42672 Mtetra
.27504 .42672 .28226 .43366 .29333 .42991 .28613 .42293 Mtetra
.28613 .42293 .29333 .42991 .30445 .42614 .29727 .41913 Mtetra
.29727 .41913 .30445 .42614 .31561 .42235 .30846 .41532 Mtetra
.30846 .41532 .31561 .42235 .32681 .41855 .3197 .41148 Mtetra
.3197 .41148 .32681 .41855 .33807 .41473 .33099 .40763 Mtetra
.33099 .40763 .33807 .41473 .34937 .41089 .34232 .40377 Mtetra
.34232 .40377 .34937 .41089 .36072 .40704 .3537 .39988 Mtetra
.3537 .39988 .36072 .40704 .37213 .40317 .36513 .39599 Mtetra
.36513 .39599 .37213 .40317 .38357 .39929 .37661 .39207 Mtetra
.663 .741 .908 r
.37661 .39207 .38357 .39929 .39507 .39538 .38814 .38814 Mtetra
.38814 .38814 .39507 .39538 .40662 .39147 .39972 .3842 Mtetra
.39972 .3842 .40662 .39147 .41822 .38753 .41134 .38024 Mtetra
.663 .742 .909 r
.41134 .38024 .41822 .38753 .42986 .38359 .42302 .37628 Mtetra
.662 .742 .909 r
.42302 .37628 .42986 .38359 .44156 .37963 .43475 .37232 Mtetra
.662 .743 .91 r
.43475 .37232 .44156 .37963 .45331 .37566 .44653 .36836 Mtetra
.661 .744 .911 r
.44653 .36836 .45331 .37566 .46511 .37168 .45836 .36441 Mtetra
.66 .745 .913 r
.45836 .36441 .46511 .37168 .47696 .36771 .47025 .36045 Mtetra
.66 .746 .914 r
.47025 .36045 .47696 .36771 .48886 .36374 .48218 .35649 Mtetra
.66 .747 .915 r
.48218 .35649 .48886 .36374 .50082 .3598 .49417 .35252 Mtetra
.66 .748 .915 r
.49417 .35252 .50082 .3598 .51282 .3559 .50621 .34852 Mtetra
.66 .746 .913 r
.50621 .34852 .51282 .3559 .52489 .35209 .51831 .34451 Mtetra
.659 .741 .91 r
.51831 .34451 .52489 .35209 .537 .34842 .53046 .34051 Mtetra
.656 .731 .905 r
.53046 .34051 .537 .34842 .54918 .34498 .54267 .33657 Mtetra
.652 .717 .896 r
.54267 .33657 .54918 .34498 .56142 .34187 .55493 .33275 Mtetra
.644 .696 .884 r
.55493 .33275 .56142 .34187 .57373 .33923 .56726 .32914 Mtetra
.634 .67 .868 r
.56726 .32914 .57373 .33923 .58612 .33718 .57965 .32584 Mtetra
.621 .64 .848 r
.57965 .32584 .58612 .33718 .59859 .33579 .59211 .32292 Mtetra
.608 .607 .825 r
.59211 .32292 .59859 .33579 .61117 .3351 .60465 .32043 Mtetra
.596 .575 .8 r
.60465 .32043 .61117 .3351 .62385 .33501 .61727 .31837 Mtetra
.586 .546 .777 r
.61727 .31837 .62385 .33501 .63663 .33533 .62998 .31669 Mtetra
.58 .523 .756 r
.62998 .31669 .63663 .33533 .64951 .33575 .64278 .31524 Mtetra
.578 .507 .739 r
.64278 .31524 .64951 .33575 .66247 .33584 .65566 .31381 Mtetra
.581 .498 .727 r
.65566 .31381 .66247 .33584 .67549 .33515 .66862 .31215 Mtetra
.587 .497 .719 r
.66862 .31215 .67549 .33515 .68854 .33326 .68162 .30997 Mtetra
.598 .502 .716 r
.68162 .30997 .68854 .33326 .70159 .32988 .69467 .30701 Mtetra
.612 .513 .718 r
.69467 .30701 .70159 .32988 .71461 .32488 .70773 .30311 Mtetra
.628 .53 .724 r
.70773 .30311 .71461 .32488 .72758 .31834 .7208 .2982 Mtetra
.646 .552 .734 r
.7208 .2982 .72758 .31834 .74051 .31052 .73386 .29233 Mtetra
.664 .578 .749 r
.73386 .29233 .74051 .31052 .75341 .30183 .74691 .28568 Mtetra
.682 .608 .767 r
.74691 .28568 .75341 .30183 .7663 .2927 .75997 .2785 Mtetra
.697 .64 .788 r
.75997 .2785 .7663 .2927 .77921 .28357 .77305 .27108 Mtetra
.708 .671 .811 r
.77305 .27108 .77921 .28357 .79217 .27478 .78616 .26366 Mtetra
.714 .698 .834 r
.78616 .26366 .79217 .27478 .80521 .26656 .79933 .25646 Mtetra
.713 .72 .854 r
.79933 .25646 .80521 .26656 .81835 .25901 .81258 .24961 Mtetra
.708 .735 .872 r
.81258 .24961 .81835 .25901 .83159 .25214 .82591 .24317 Mtetra
.7 .744 .885 r
.82591 .24317 .83159 .25214 .84494 .24587 .83933 .23715 Mtetra
.664 .741 .908 r
.22373 .43482 .23112 .4417 .24203 .43798 .23467 .43107 Mtetra
.23467 .43107 .24203 .43798 .25299 .43424 .24565 .4273 Mtetra
.24565 .4273 .25299 .43424 .26399 .43049 .25668 .42352 Mtetra
.25668 .42352 .26399 .43049 .27504 .42672 .26775 .41972 Mtetra
.26775 .41972 .27504 .42672 .28613 .42293 .27888 .4159 Mtetra
.27888 .4159 .28613 .42293 .29727 .41913 .29005 .41207 Mtetra
.29005 .41207 .29727 .41913 .30846 .41532 .30127 .40823 Mtetra
.30127 .40823 .30846 .41532 .3197 .41148 .31253 .40436 Mtetra
.31253 .40436 .3197 .41148 .33099 .40763 .32384 .40048 Mtetra
.32384 .40048 .33099 .40763 .34232 .40377 .33521 .39659 Mtetra
.663 .741 .908 r
.33521 .39659 .34232 .40377 .3537 .39988 .34662 .39267 Mtetra
.34662 .39267 .3537 .39988 .36513 .39599 .35808 .38875 Mtetra
.35808 .38875 .36513 .39599 .37661 .39207 .36959 .38481 Mtetra
.36959 .38481 .37661 .39207 .38814 .38814 .38115 .38086 Mtetra
.662 .742 .909 r
.38115 .38086 .38814 .38814 .39972 .3842 .39276 .37692 Mtetra
.661 .742 .91 r
.39276 .37692 .39972 .3842 .41134 .38024 .40441 .37298 Mtetra
.66 .743 .912 r
.40441 .37298 .41134 .38024 .42302 .37628 .41612 .36907 Mtetra
.659 .745 .914 r
.41612 .36907 .42302 .37628 .43475 .37232 .42788 .36518 Mtetra
.657 .748 .917 r
.42788 .36518 .43475 .37232 .44653 .36836 .43969 .36133 Mtetra
.655 .752 .921 r
.43969 .36133 .44653 .36836 .45836 .36441 .45155 .3575 Mtetra
.655 .756 .924 r
.45155 .3575 .45836 .36441 .47025 .36045 .46347 .35367 Mtetra
.656 .761 .927 r
.46347 .35367 .47025 .36045 .48218 .35649 .47544 .34978 Mtetra
.658 .765 .929 r
.47544 .34978 .48218 .35649 .49417 .35252 .48746 .34581 Mtetra
.661 .767 .929 r
.48746 .34581 .49417 .35252 .50621 .34852 .49954 .34173 Mtetra
.665 .767 .926 r
.49954 .34173 .50621 .34852 .51831 .34451 .51168 .33754 Mtetra
.667 .763 .922 r
.51168 .33754 .51831 .34451 .53046 .34051 .52387 .33325 Mtetra
.668 .756 .916 r
.52387 .33325 .53046 .34051 .54267 .33657 .53611 .32893 Mtetra
.666 .745 .909 r
.53611 .32893 .54267 .33657 .55493 .33275 .54841 .32464 Mtetra
.662 .731 .901 r
.54841 .32464 .55493 .33275 .56726 .32914 .56076 .32045 Mtetra
.655 .714 .891 r
.56076 .32045 .56726 .32914 .57965 .32584 .57317 .31643 Mtetra
.647 .694 .88 r
.57317 .31643 .57965 .32584 .59211 .32292 .58564 .31263 Mtetra
.638 .671 .865 r
.58564 .31263 .59211 .32292 .60465 .32043 .59818 .30909 Mtetra
.629 .646 .848 r
.59818 .30909 .60465 .32043 .61727 .31837 .61079 .30582 Mtetra
.62 .621 .83 r
.61079 .30582 .61727 .31837 .62998 .31669 .62348 .30281 Mtetra
.612 .597 .811 r
.62348 .30281 .62998 .31669 .64278 .31524 .63624 .30001 Mtetra
.607 .576 .793 r
.63624 .30001 .64278 .31524 .65566 .31381 .64907 .29732 Mtetra
.605 .56 .778 r
.64907 .29732 .65566 .31381 .66862 .31215 .66198 .29464 Mtetra
.606 .551 .766 r
.66198 .29464 .66862 .31215 .68162 .30997 .67496 .29178 Mtetra
.61 .547 .759 r
.67496 .29178 .68162 .30997 .69467 .30701 .68799 .2886 Mtetra
.617 .55 .756 r
.68799 .2886 .69467 .30701 .70773 .30311 .70107 .28494 Mtetra
.627 .558 .757 r
.70107 .28494 .70773 .30311 .7208 .2982 .71418 .28071 Mtetra
.639 .571 .762 r
.71418 .28071 .7208 .2982 .73386 .29233 .72731 .27588 Mtetra
.652 .59 .772 r
.72731 .27588 .73386 .29233 .74691 .28568 .74047 .2705 Mtetra
.665 .612 .785 r
.74047 .2705 .74691 .28568 .75997 .2785 .75364 .26465 Mtetra
.677 .636 .801 r
.75364 .26465 .75997 .2785 .77305 .27108 .76685 .25851 Mtetra
.687 .661 .819 r
.76685 .25851 .77305 .27108 .78616 .26366 .78009 .25222 Mtetra
.693 .684 .837 r
.78009 .25222 .78616 .26366 .79933 .25646 .79338 .24594 Mtetra
.695 .705 .855 r
.79338 .24594 .79933 .25646 .81258 .24961 .80673 .23979 Mtetra
.694 .721 .87 r
.80673 .23979 .81258 .24961 .82591 .24317 .82015 .23384 Mtetra
.69 .732 .883 r
.82015 .23384 .82591 .24317 .83933 .23715 .83366 .22813 Mtetra
.664 .741 .908 r
.21628 .42788 .22373 .43482 .23467 .43107 .22724 .4241 Mtetra
.22724 .4241 .23467 .43107 .24565 .4273 .23825 .4203 Mtetra
.23825 .4203 .24565 .4273 .25668 .42352 .24931 .41649 Mtetra
.24931 .41649 .25668 .42352 .26775 .41972 .26041 .41266 Mtetra
.26041 .41266 .26775 .41972 .27888 .4159 .27156 .40882 Mtetra
.27156 .40882 .27888 .4159 .29005 .41207 .28276 .40496 Mtetra
.28276 .40496 .29005 .41207 .30127 .40823 .29401 .40108 Mtetra
.29401 .40108 .30127 .40823 .31253 .40436 .3053 .39719 Mtetra
.3053 .39719 .31253 .40436 .32384 .40048 .31665 .39328 Mtetra
.663 .741 .908 r
.31665 .39328 .32384 .40048 .33521 .39659 .32804 .38935 Mtetra
.32804 .38935 .33521 .39659 .34662 .39267 .33948 .38542 Mtetra
.33948 .38542 .34662 .39267 .35808 .38875 .35097 .38148 Mtetra
.662 .742 .909 r
.35097 .38148 .35808 .38875 .36959 .38481 .36251 .37754 Mtetra
.661 .742 .911 r
.36251 .37754 .36959 .38481 .38115 .38086 .3741 .37363 Mtetra
.658 .744 .913 r
.3741 .37363 .38115 .38086 .39276 .37692 .38573 .36977 Mtetra
.655 .746 .917 r
.38573 .36977 .39276 .37692 .40441 .37298 .39741 .36599 Mtetra
.651 .75 .922 r
.39741 .36599 .40441 .37298 .41612 .36907 .40915 .3623 Mtetra
.646 .757 .93 r
.40915 .3623 .41612 .36907 .42788 .36518 .42093 .35871 Mtetra
.642 .766 .938 r
.42093 .35871 .42788 .36518 .43969 .36133 .43276 .35519 Mtetra
.64 .777 .946 r
.43276 .35519 .43969 .36133 .45155 .3575 .44465 .35166 Mtetra
.641 .788 .953 r
.44465 .35166 .45155 .3575 .46347 .35367 .4566 .34805 Mtetra
.646 .798 .956 r
.4566 .34805 .46347 .35367 .47544 .34978 .46861 .34423 Mtetra
.656 .804 .954 r
.46861 .34423 .47544 .34978 .48746 .34581 .48068 .34016 Mtetra
.666 .805 .949 r
.48068 .34016 .48746 .34581 .49954 .34173 .49281 .33581 Mtetra
.675 .8 .941 r
.49281 .33581 .49954 .34173 .51168 .33754 .50499 .33122 Mtetra
.681 .789 .932 r
.50499 .33122 .51168 .33754 .52387 .33325 .51722 .32649 Mtetra
.681 .777 .923 r
.51722 .32649 .52387 .33325 .53611 .32893 .5295 .32171 Mtetra
.679 .763 .915 r
.5295 .32171 .53611 .32893 .54841 .32464 .54183 .31698 Mtetra
.674 .75 .908 r
.54183 .31698 .54841 .32464 .56076 .32045 .55422 .31238 Mtetra
.668 .737 .902 r
.55422 .31238 .56076 .32045 .57317 .31643 .56666 .30794 Mtetra
.662 .725 .896 r
.56666 .30794 .57317 .31643 .58564 .31263 .57916 .30367 Mtetra
.655 .711 .889 r
.57916 .30367 .58564 .31263 .59818 .30909 .59172 .29956 Mtetra
.649 .696 .88 r
.59172 .29956 .59818 .30909 .61079 .30582 .60434 .29563 Mtetra
.643 .679 .869 r
.60434 .29563 .61079 .30582 .62348 .30281 .61703 .29185 Mtetra
.637 .661 .856 r
.61703 .29185 .62348 .30281 .63624 .30001 .62979 .2882 Mtetra
.633 .643 .842 r
.62979 .2882 .63624 .30001 .64907 .29732 .64261 .28466 Mtetra
.629 .627 .829 r
.64261 .28466 .64907 .29732 .66198 .29464 .65551 .28117 Mtetra
.627 .613 .817 r
.65551 .28117 .66198 .29464 .67496 .29178 .66847 .27766 Mtetra
.628 .605 .808 r
.66847 .27766 .67496 .29178 .68799 .2886 .6815 .27404 Mtetra
.63 .6 .801 r
.6815 .27404 .68799 .2886 .70107 .28494 .69458 .27022 Mtetra
.635 .601 .798 r
.69458 .27022 .70107 .28494 .71418 .28071 .70771 .26612 Mtetra
.642 .607 .799 r
.70771 .26612 .71418 .28071 .72731 .27588 .72089 .26169 Mtetra
.65 .617 .804 r
.72089 .26169 .72731 .27588 .74047 .2705 .73411 .25693 Mtetra
.658 .631 .812 r
.73411 .25693 .74047 .2705 .75364 .26465 .74736 .25185 Mtetra
.666 .648 .822 r
.74736 .25185 .75364 .26465 .76685 .25851 .76066 .24651 Mtetra
.674 .666 .835 r
.76066 .24651 .76685 .25851 .78009 .25222 .774 .24101 Mtetra
.679 .684 .848 r
.774 .24101 .78009 .25222 .79338 .24594 .78739 .23542 Mtetra
.682 .701 .861 r
.78739 .23542 .79338 .24594 .80673 .23979 .80083 .22984 Mtetra
.682 .715 .873 r
.80083 .22984 .80673 .23979 .82015 .23384 .81434 .22432 Mtetra
.681 .725 .883 r
.81434 .22432 .82015 .23384 .83366 .22813 .82792 .21891 Mtetra
.664 .741 .908 r
.20877 .42089 .21628 .42788 .22724 .4241 .21976 .41708 Mtetra
.21976 .41708 .22724 .4241 .23825 .4203 .2308 .41325 Mtetra
.2308 .41325 .23825 .4203 .24931 .41649 .24188 .40941 Mtetra
.24188 .40941 .24931 .41649 .26041 .41266 .25302 .40555 Mtetra
.25302 .40555 .26041 .41266 .27156 .40882 .26419 .40168 Mtetra
.26419 .40168 .27156 .40882 .28276 .40496 .27542 .39779 Mtetra
.27542 .39779 .28276 .40496 .29401 .40108 .2867 .39388 Mtetra
.663 .741 .908 r
.2867 .39388 .29401 .40108 .3053 .39719 .29802 .38996 Mtetra
.29802 .38996 .3053 .39719 .31665 .39328 .30939 .38602 Mtetra
.30939 .38602 .31665 .39328 .32804 .38935 .32081 .38209 Mtetra
.662 .742 .909 r
.32081 .38209 .32804 .38935 .33948 .38542 .33228 .37816 Mtetra
.66 .742 .911 r
.33228 .37816 .33948 .38542 .35097 .38148 .3438 .37427 Mtetra
.657 .744 .914 r
.3438 .37427 .35097 .38148 .36251 .37754 .35536 .37045 Mtetra
.652 .747 .919 r
.35536 .37045 .36251 .37754 .3741 .37363 .36696 .36677 Mtetra
.644 .752 .928 r
.36696 .36677 .3741 .37363 .38573 .36977 .37861 .36327 Mtetra
.633 .761 .94 r
.37861 .36327 .38573 .36977 .39741 .36599 .39031 .36001 Mtetra
.619 .775 .955 r
.39031 .36001 .39741 .36599 .40915 .3623 .40205 .35697 Mtetra
.603 .793 .972 r
.40205 .35697 .40915 .3623 .42093 .35871 .41385 .35409 Mtetra
.589 .814 .986 r
.41385 .35409 .42093 .35871 .43276 .35519 .4257 .35121 Mtetra
.584 .837 .993 r
.4257 .35121 .43276 .35519 .44465 .35166 .43763 .34814 Mtetra
.595 .857 .993 r
.43763 .34814 .44465 .35166 .4566 .34805 .44962 .34466 Mtetra
.622 .871 .989 r
.44962 .34466 .4566 .34805 .46861 .34423 .46168 .34062 Mtetra
.656 .873 .98 r
.46168 .34062 .46861 .34423 .48068 .34016 .47381 .336 Mtetra
.685 .862 .966 r
.47381 .336 .48068 .34016 .49281 .33581 .48599 .33089 Mtetra
.7 .841 .95 r
.48599 .33089 .49281 .33581 .50499 .33122 .49823 .32548 Mtetra
.704 .815 .934 r
.49823 .32548 .50499 .33122 .51722 .32649 .5105 .31998 Mtetra
.7 .792 .921 r
.5105 .31998 .51722 .32649 .5295 .32171 .52283 .31459 Mtetra
.692 .772 .913 r
.52283 .31459 .5295 .32171 .54183 .31698 .5352 .3094 Mtetra
.683 .757 .907 r
.5352 .3094 .54183 .31698 .55422 .31238 .54762 .30447 Mtetra
.675 .746 .904 r
.54762 .30447 .55422 .31238 .56666 .30794 .5601 .29976 Mtetra
.668 .737 .902 r
.5601 .29976 .56666 .30794 .57916 .30367 .57263 .29525 Mtetra
.663 .73 .899 r
.57263 .29525 .57916 .30367 .59172 .29956 .58522 .29088 Mtetra
.659 .722 .896 r
.58522 .29088 .59172 .29956 .60434 .29563 .59787 .28661 Mtetra
.656 .713 .89 r
.59787 .28661 .60434 .29563 .61703 .29185 .61059 .28243 Mtetra
.652 .703 .884 r
.61059 .28243 .61703 .29185 .62979 .2882 .62336 .27832 Mtetra
.649 .692 .876 r
.62336 .27832 .62979 .2882 .64261 .28466 .6362 .27428 Mtetra
.647 .68 .867 r
.6362 .27428 .64261 .28466 .65551 .28117 .64911 .27027 Mtetra
.645 .669 .859 r
.64911 .27027 .65551 .28117 .66847 .27766 .66208 .26627 Mtetra
.644 .66 .851 r
.66208 .26627 .66847 .27766 .6815 .27404 .67511 .26225 Mtetra
.644 .653 .844 r
.67511 .26225 .6815 .27404 .69458 .27022 .6882 .25816 Mtetra
.645 .649 .839 r
.6882 .25816 .69458 .27022 .70771 .26612 .70136 .25395 Mtetra
.648 .649 .837 r
.70136 .25395 .70771 .26612 .72089 .26169 .71457 .24958 Mtetra
.652 .653 .838 r
.71457 .24958 .72089 .26169 .73411 .25693 .72783 .24503 Mtetra
.657 .66 .841 r
.72783 .24503 .73411 .25693 .74736 .25185 .74114 .24029 Mtetra
.662 .67 .847 r
.74114 .24029 .74736 .25185 .76066 .24651 .7545 .23538 Mtetra
.667 .681 .854 r
.7545 .23538 .76066 .24651 .774 .24101 .76791 .23033 Mtetra
.67 .693 .862 r
.76791 .23033 .774 .24101 .78739 .23542 .78138 .22518 Mtetra
.673 .705 .871 r
.78138 .22518 .78739 .23542 .80083 .22984 .7949 .21999 Mtetra
.674 .715 .88 r
.7949 .21999 .80083 .22984 .81434 .22432 .80849 .21479 Mtetra
.674 .724 .887 r
.80849 .21479 .81434 .22432 .82792 .21891 .82214 .20962 Mtetra
.664 .741 .908 r
.2012 .41384 .20877 .42089 .21976 .41708 .21222 .41 Mtetra
.21222 .41 .21976 .41708 .2308 .41325 .22329 .40615 Mtetra
.22329 .40615 .2308 .41325 .24188 .40941 .2344 .40227 Mtetra
.2344 .40227 .24188 .40941 .25302 .40555 .24556 .39839 Mtetra
.24556 .39839 .25302 .40555 .26419 .40168 .25677 .39448 Mtetra
.663 .741 .908 r
.25677 .39448 .26419 .40168 .27542 .39779 .26802 .39056 Mtetra
.26802 .39056 .27542 .39779 .2867 .39388 .27932 .38663 Mtetra
.27932 .38663 .2867 .39388 .29802 .38996 .29068 .38269 Mtetra
.662 .742 .909 r
.29068 .38269 .29802 .38996 .30939 .38602 .30208 .37876 Mtetra
.66 .742 .911 r
.30208 .37876 .30939 .38602 .32081 .38209 .31352 .37488 Mtetra
.656 .743 .914 r
.31352 .37488 .32081 .38209 .33228 .37816 .32501 .37108 Mtetra
.649 .746 .92 r
.32501 .37108 .33228 .37816 .3438 .37427 .33654 .36747 Mtetra
.637 .752 .931 r
.33654 .36747 .3438 .37427 .35536 .37045 .3481 .36414 Mtetra
.617 .762 .948 r
.3481 .36414 .35536 .37045 .36696 .36677 .3597 .3612 Mtetra
.585 .778 .972 r
.3597 .3612 .36696 .36677 .37861 .36327 .37134 .35875 Mtetra
.533 .797 .994 r
.37134 .35875 .37861 .36327 .39031 .36001 .38302 .35677 Mtetra
.456 .811 .997 r
.38302 .35677 .39031 .36001 .40205 .35697 .39475 .3551 Mtetra
.366 .806 .958 r
.39475 .3551 .40205 .35697 .41385 .35409 .40655 .35344 Mtetra
.307 .793 .894 r
.40655 .35344 .41385 .35409 .4257 .35121 .41843 .35136 Mtetra
.323 .809 .859 r
.41843 .35136 .4257 .35121 .43763 .34814 .43041 .34847 Mtetra
.42 .866 .879 r
.43041 .34847 .43763 .34814 .44962 .34466 .44248 .34446 Mtetra
.557 .927 .929 r
.44248 .34446 .44962 .34466 .46168 .34062 .45463 .33932 Mtetra
.671 .945 .96 r
.45463 .33932 .46168 .34062 .47381 .336 .46684 .33323 Mtetra
.729 .917 .957 r
.46684 .33323 .47381 .336 .48599 .33089 .4791 .3266 Mtetra
.743 .871 .939 r
.4791 .3266 .48599 .33089 .49823 .32548 .4914 .31984 Mtetra
.735 .827 .922 r
.4914 .31984 .49823 .32548 .5105 .31998 .50373 .31331 Mtetra
.719 .793 .91 r
.50373 .31331 .5105 .31998 .52283 .31459 .5161 .30722 Mtetra
.703 .769 .904 r
.5161 .30722 .52283 .31459 .5352 .3094 .52851 .30162 Mtetra
.688 .755 .902 r
.52851 .30162 .5352 .3094 .54762 .30447 .54097 .29645 Mtetra
.678 .746 .902 r
.54097 .29645 .54762 .30447 .5601 .29976 .55348 .29161 Mtetra
.671 .741 .903 r
.55348 .29161 .5601 .29976 .57263 .29525 .56605 .28699 Mtetra
.666 .737 .903 r
.56605 .28699 .57263 .29525 .58522 .29088 .57868 .28251 Mtetra
.663 .734 .902 r
.57868 .28251 .58522 .29088 .59787 .28661 .59137 .27809 Mtetra
.661 .73 .901 r
.59137 .27809 .59787 .28661 .61059 .28243 .60411 .27372 Mtetra
.659 .726 .898 r
.60411 .27372 .61059 .28243 .62336 .27832 .61692 .26938 Mtetra
.658 .72 .894 r
.61692 .26938 .62336 .27832 .6362 .27428 .62979 .26506 Mtetra
.656 .713 .89 r
.62979 .26506 .6362 .27428 .64911 .27027 .64272 .26076 Mtetra
.655 .706 .885 r
.64272 .26076 .64911 .27027 .66208 .26627 .65571 .25646 Mtetra
.654 .7 .88 r
.65571 .25646 .66208 .26627 .67511 .26225 .66877 .25216 Mtetra
.654 .694 .875 r
.66877 .25216 .67511 .26225 .6882 .25816 .68188 .24783 Mtetra
.654 .69 .871 r
.68188 .24783 .6882 .25816 .70136 .25395 .69506 .24345 Mtetra
.655 .687 .868 r
.69506 .24345 .70136 .25395 .71457 .24958 .7083 .239 Mtetra
.657 .687 .867 r
.7083 .239 .71457 .24958 .72783 .24503 .7216 .23446 Mtetra
.659 .689 .867 r
.7216 .23446 .72783 .24503 .74114 .24029 .73496 .22982 Mtetra
.661 .693 .869 r
.73496 .22982 .74114 .24029 .7545 .23538 .74837 .22508 Mtetra
.664 .699 .873 r
.74837 .22508 .7545 .23538 .76791 .23033 .76184 .22024 Mtetra
.666 .706 .877 r
.76184 .22024 .76791 .23033 .78138 .22518 .77537 .21532 Mtetra
.668 .713 .882 r
.77537 .21532 .78138 .22518 .7949 .21999 .78895 .21035 Mtetra
.669 .72 .887 r
.78895 .21035 .7949 .21999 .80849 .21479 .8026 .20535 Mtetra
.669 .726 .892 r
.8026 .20535 .80849 .21479 .82214 .20962 .81631 .20033 Mtetra
.664 .741 .908 r
.19358 .40674 .2012 .41384 .21222 .41 .20462 .40287 Mtetra
.20462 .40287 .21222 .41 .22329 .40615 .21571 .39899 Mtetra
.21571 .39899 .22329 .40615 .2344 .40227 .22685 .39508 Mtetra
.663 .741 .908 r
.22685 .39508 .2344 .40227 .24556 .39839 .23804 .39116 Mtetra
.23804 .39116 .24556 .39839 .25677 .39448 .24928 .38723 Mtetra
.24928 .38723 .25677 .39448 .26802 .39056 .26056 .38329 Mtetra
.662 .741 .909 r
.26056 .38329 .26802 .39056 .27932 .38663 .27189 .37936 Mtetra
.661 .742 .91 r
.27189 .37936 .27932 .38663 .29068 .38269 .28327 .37546 Mtetra
.657 .743 .913 r
.28327 .37546 .29068 .38269 .30208 .37876 .29468 .37166 Mtetra
.649 .745 .92 r
.29468 .37166 .30208 .37876 .31352 .37488 .30614 .36805 Mtetra
.634 .75 .932 r
.30614 .36805 .31352 .37488 .32501 .37108 .31762 .36479 Mtetra
.606 .76 .952 r
.31762 .36479 .32501 .37108 .33654 .36747 .32913 .3621 Mtetra
.552 .773 .981 r
.32913 .3621 .33654 .36747 .3481 .36414 .34065 .36016 Mtetra
.438 .777 .997 r
.34065 .36016 .3481 .36414 .3597 .3612 .35218 .35914 Mtetra
.214 .711 .915 r
.35218 .35914 .3597 .3612 .37134 .35875 .36375 .35898 Mtetra
.069 0 0 r
.36375 .35898 .37134 .35875 .38302 .35677 .37537 .35939 Mtetra
.24 0 0 r
.37537 .35939 .38302 .35677 .39475 .3551 .38707 .35978 Mtetra
.276 0 0 r
.38707 .35978 .39475 .3551 .40655 .35344 .39889 .35937 Mtetra
.217 0 0 r
.39889 .35937 .40655 .35344 .41843 .35136 .41085 .3574 Mtetra
.065 0 0 r
.41085 .3574 .41843 .35136 .43041 .34847 .42295 .35339 Mtetra
0 0 0 r
.42295 .35339 .43041 .34847 .44248 .34446 .43515 .34728 Mtetra
.542 .917 .767 r
.43515 .34728 .44248 .34446 .45463 .33932 .44744 .3395 Mtetra
.748 .985 .904 r
.44744 .3395 .45463 .33932 .46684 .33323 .45978 .33078 Mtetra
.798 .931 .921 r
.45978 .33078 .46684 .33323 .4791 .3266 .47214 .32191 Mtetra
.785 .862 .907 r
.47214 .32191 .4791 .3266 .4914 .31984 .48451 .31352 Mtetra
.757 .811 .896 r
.48451 .31352 .4914 .31984 .50373 .31331 .4969 .30597 Mtetra
.729 .778 .891 r
.4969 .30597 .50373 .31331 .5161 .30722 .50932 .29933 Mtetra
.706 .758 .892 r
.50932 .29933 .5161 .30722 .52851 .30162 .52177 .29349 Mtetra
.689 .747 .896 r
.52177 .29349 .52851 .30162 .54097 .29645 .53427 .28825 Mtetra
.677 .742 .9 r
.53427 .28825 .54097 .29645 .55348 .29161 .54682 .28339 Mtetra
.67 .74 .903 r
.54682 .28339 .55348 .29161 .56605 .28699 .55942 .27875 Mtetra
.666 .739 .905 r
.55942 .27875 .56605 .28699 .57868 .28251 .57209 .27422 Mtetra
.664 .738 .905 r
.57209 .27422 .57868 .28251 .59137 .27809 .58481 .26974 Mtetra
.663 .737 .905 r
.58481 .26974 .59137 .27809 .60411 .27372 .5976 .26527 Mtetra
.662 .735 .904 r
.5976 .26527 .60411 .27372 .61692 .26938 .61044 .26081 Mtetra
.661 .733 .903 r
.61044 .26081 .61692 .26938 .62979 .26506 .62334 .25635 Mtetra
.661 .73 .901 r
.62334 .25635 .62979 .26506 .64272 .26076 .6363 .25189 Mtetra
.66 .727 .898 r
.6363 .25189 .64272 .26076 .65571 .25646 .64933 .24742 Mtetra
.66 .723 .896 r
.64933 .24742 .65571 .25646 .66877 .25216 .66242 .24294 Mtetra
.659 .719 .893 r
.66242 .24294 .66877 .25216 .68188 .24783 .67557 .23845 Mtetra
.659 .716 .891 r
.67557 .23845 .68188 .24783 .69506 .24345 .68878 .23393 Mtetra
.659 .714 .888 r
.68878 .23393 .69506 .24345 .7083 .239 .70205 .22938 Mtetra
.66 .712 .887 r
.70205 .22938 .7083 .239 .7216 .23446 .71539 .22478 Mtetra
.661 .712 .886 r
.71539 .22478 .7216 .23446 .73496 .22982 .72878 .22013 Mtetra
.662 .713 .887 r
.72878 .22013 .73496 .22982 .74837 .22508 .74224 .21541 Mtetra
.663 .716 .888 r
.74224 .21541 .74837 .22508 .76184 .22024 .75576 .21064 Mtetra
.664 .719 .89 r
.75576 .21064 .76184 .22024 .77537 .21532 .76934 .20582 Mtetra
.665 .723 .892 r
.76934 .20582 .77537 .21532 .78895 .21035 .78298 .20094 Mtetra
.666 .726 .895 r
.78298 .20094 .78895 .21035 .8026 .20535 .79669 .19603 Mtetra
.666 .73 .897 r
.79669 .19603 .8026 .20535 .81631 .20033 .81045 .19109 Mtetra
.664 .741 .908 r
.18589 .39958 .19358 .40674 .20462 .40287 .19696 .39568 Mtetra
.19696 .39568 .20462 .40287 .21571 .39899 .20808 .39177 Mtetra
.663 .741 .908 r
.20808 .39177 .21571 .39899 .22685 .39508 .21925 .38784 Mtetra
.21925 .38784 .22685 .39508 .23804 .39116 .23046 .38389 Mtetra
.23046 .38389 .23804 .39116 .24928 .38723 .24173 .37995 Mtetra
.661 .742 .91 r
.24173 .37995 .24928 .38723 .26056 .38329 .25303 .37603 Mtetra
.658 .742 .912 r
.25303 .37603 .26056 .38329 .27189 .37936 .26438 .37219 Mtetra
.651 .744 .918 r
.26438 .37219 .27189 .37936 .28327 .37546 .27577 .36853 Mtetra
.636 .748 .929 r
.27577 .36853 .28327 .37546 .29468 .37166 .28718 .36524 Mtetra
.606 .755 .95 r
.28718 .36524 .29468 .37166 .30614 .36805 .29859 .36258 Mtetra
.538 .765 .981 r
.29859 .36258 .30614 .36805 .31762 .36479 .31001 .3609 Mtetra
.368 .747 .989 r
.31001 .3609 .31762 .36479 .32913 .3621 .3214 .36056 Mtetra
0 .558 .779 r
.3214 .36056 .32913 .3621 .34065 .36016 .33277 .36179 Mtetra
.384 0 0 r
.33277 .36179 .34065 .36016 .35218 .35914 .34415 .3645 Mtetra
.517 .015 0 r
.34415 .3645 .35218 .35914 .36375 .35898 .35558 .36815 Mtetra
.536 .091 .139 r
.35558 .36815 .36375 .35898 .37537 .35939 .36713 .3717 Mtetra
.506 .092 .189 r
.36713 .3717 .37537 .35939 .38707 .35978 .37885 .37381 Mtetra
.439 .038 .181 r
.37885 .37381 .38707 .35978 .39889 .35937 .39078 .37318 Mtetra
.316 0 .111 r
.39078 .37318 .39889 .35937 .41085 .3574 .40293 .36901 Mtetra
.084 0 0 r
.40293 .36901 .41085 .3574 .42295 .35339 .41526 .3613 Mtetra
0 0 0 r
.41526 .3613 .42295 .35339 .43515 .34728 .4277 .35081 Mtetra
.749 .986 .765 r
.4277 .35081 .43515 .34728 .44744 .3395 .44019 .33884 Mtetra
.862 .964 .865 r
.44019 .33884 .44744 .3395 .45978 .33078 .45267 .32673 Mtetra
.842 .878 .868 r
.45267 .32673 .45978 .33078 .47214 .32191 .46514 .31554 Mtetra
.799 .815 .864 r
.46514 .31554 .47214 .32191 .48451 .31352 .47758 .30582 Mtetra
.76 .775 .866 r
.47758 .30582 .48451 .31352 .4969 .30597 .49002 .29767 Mtetra
.727 .754 .874 r
.49002 .29767 .4969 .30597 .50932 .29933 .50248 .29086 Mtetra
.702 .743 .883 r
.50248 .29086 .50932 .29933 .52177 .29349 .51497 .28505 Mtetra
.685 .739 .892 r
.51497 .28505 .52177 .29349 .53427 .28825 .5275 .27988 Mtetra
.674 .739 .899 r
.5275 .27988 .53427 .28825 .54682 .28339 .54009 .27508 Mtetra
.668 .739 .903 r
.54009 .27508 .54682 .28339 .55942 .27875 .55274 .27046 Mtetra
.665 .74 .906 r
.55274 .27046 .55942 .27875 .57209 .27422 .56544 .26592 Mtetra
.664 .74 .907 r
.56544 .26592 .57209 .27422 .58481 .26974 .5782 .2614 Mtetra
.663 .74 .907 r
.5782 .2614 .58481 .26974 .5976 .26527 .59103 .25689 Mtetra
.663 .739 .907 r
.59103 .25689 .5976 .26527 .61044 .26081 .60391 .25236 Mtetra
.663 .738 .906 r
.60391 .25236 .61044 .26081 .62334 .25635 .61685 .24782 Mtetra
.663 .737 .905 r
.61685 .24782 .62334 .25635 .6363 .25189 .62985 .24327 Mtetra
.662 .736 .904 r
.62985 .24327 .6363 .25189 .64933 .24742 .64291 .2387 Mtetra
.662 .734 .903 r
.64291 .2387 .64933 .24742 .66242 .24294 .65604 .23412 Mtetra
.662 .732 .902 r
.65604 .23412 .66242 .24294 .67557 .23845 .66922 .22952 Mtetra
.662 .731 .901 r
.66922 .22952 .67557 .23845 .68878 .23393 .68247 .2249 Mtetra
.662 .729 .899 r
.68247 .2249 .68878 .23393 .70205 .22938 .69579 .22026 Mtetra
.662 .728 .898 r
.69579 .22026 .70205 .22938 .71539 .22478 .70916 .21559 Mtetra
.662 .727 .898 r
.70916 .21559 .71539 .22478 .72878 .22013 .7226 .21089 Mtetra
.662 .727 .897 r
.7226 .21089 .72878 .22013 .74224 .21541 .7361 .20615 Mtetra
.663 .728 .898 r
.7361 .20615 .74224 .21541 .75576 .21064 .74966 .20137 Mtetra
.663 .729 .898 r
.74966 .20137 .75576 .21064 .76934 .20582 .76329 .19655 Mtetra
.664 .73 .899 r
.76329 .19655 .76934 .20582 .78298 .20094 .77698 .1917 Mtetra
.664 .732 .9 r
.77698 .1917 .78298 .20094 .79669 .19603 .79073 .18681 Mtetra
.665 .734 .902 r
.79073 .18681 .79669 .19603 .81045 .19109 .80455 .18189 Mtetra
.663 .741 .908 r
.17814 .39237 .18589 .39958 .19696 .39568 .18924 .38844 Mtetra
.18924 .38844 .19696 .39568 .20808 .39177 .20039 .3845 Mtetra
.20039 .3845 .20808 .39177 .21925 .38784 .21158 .38055 Mtetra
.662 .741 .909 r
.21158 .38055 .21925 .38784 .23046 .38389 .22282 .37661 Mtetra
.66 .742 .911 r
.22282 .37661 .23046 .38389 .24173 .37995 .23411 .37272 Mtetra
.654 .743 .915 r
.23411 .37272 .24173 .37995 .25303 .37603 .24542 .36897 Mtetra
.642 .745 .924 r
.24542 .36897 .25303 .37603 .26438 .37219 .25677 .36554 Mtetra
.615 .751 .942 r
.25677 .36554 .26438 .37219 .27577 .36853 .26811 .3627 Mtetra
.551 .758 .974 r
.26811 .3627 .27577 .36853 .28718 .36524 .27944 .36092 Mtetra
.376 .737 .99 r
.27944 .36092 .28718 .36524 .29859 .36258 .29071 .36072 Mtetra
0 .499 .746 r
.29071 .36072 .29859 .36258 .31001 .3609 .30191 .36269 Mtetra
.506 0 0 r
.30191 .36269 .31001 .3609 .3214 .36056 .31303 .36715 Mtetra
.623 .161 .136 r
.31303 .36715 .3214 .36056 .33277 .36179 .32413 .37394 Mtetra
.636 .235 .267 r
.32413 .37394 .33277 .36179 .34415 .3645 .33526 .38216 Mtetra
.616 .248 .323 r
.33526 .38216 .34415 .3645 .35558 .36815 .34656 .39012 Mtetra
.575 .225 .339 r
.34656 .39012 .35558 .36815 .36713 .3717 .35812 .39567 Mtetra
.508 .167 .323 r
.35812 .39567 .36713 .3717 .37885 .37381 .37003 .39676 Mtetra
.397 .056 .266 r
.37003 .39676 .37885 .37381 .39078 .37318 .38228 .39218 Mtetra
.183 0 .124 r
.38228 .39218 .39078 .37318 .40293 .36901 .3948 .38201 Mtetra
0 0 0 r
.3948 .38201 .40293 .36901 .41526 .3613 .4075 .3676 Mtetra
.796 .966 .656 r
.4075 .3676 .41526 .3613 .4277 .35081 .42024 .35102 Mtetra
.921 .948 .797 r
.42024 .35102 .4277 .35081 .44019 .33884 .43295 .33442 Mtetra
.882 .854 .81 r
.43295 .33442 .44019 .33884 .45267 .32673 .44557 .3194 Mtetra
.83 .791 .815 r
.44557 .3194 .45267 .32673 .46514 .31554 .45812 .30677 Mtetra
.784 .755 .827 r
.45812 .30677 .46514 .31554 .47758 .30582 .47062 .2966 Mtetra
.746 .738 .845 r
.47062 .2966 .47758 .30582 .49002 .29767 .4831 .28854 Mtetra
.715 .732 .864 r
.4831 .28854 .49002 .29767 .50248 .29086 .49559 .282 Mtetra
.693 .732 .88 r
.49559 .282 .50248 .29086 .51497 .28505 .50811 .27644 Mtetra
.679 .735 .893 r
.50811 .27644 .51497 .28505 .5275 .27988 .52068 .27144 Mtetra
.671 .737 .9 r
.52068 .27144 .5275 .27988 .54009 .27508 .53331 .26672 Mtetra
.666 .739 .904 r
.53331 .26672 .54009 .27508 .55274 .27046 .546 .26213 Mtetra
.665 .74 .906 r
.546 .26213 .55274 .27046 .56544 .26592 .55874 .25757 Mtetra
.664 .741 .907 r
.55874 .25757 .56544 .26592 .5782 .2614 .57154 .25303 Mtetra
.57154 .25303 .5782 .2614 .59103 .25689 .5844 .24847 Mtetra
.663 .741 .907 r
.5844 .24847 .59103 .25689 .60391 .25236 .59732 .2439 Mtetra
.663 .74 .907 r
.59732 .2439 .60391 .25236 .61685 .24782 .6103 .23931 Mtetra
.6103 .23931 .61685 .24782 .62985 .24327 .62334 .23469 Mtetra
.663 .739 .907 r
.62334 .23469 .62985 .24327 .64291 .2387 .63645 .23006 Mtetra
.663 .739 .906 r
.63645 .23006 .64291 .2387 .65604 .23412 .64961 .22542 Mtetra
.663 .738 .906 r
.64961 .22542 .65604 .23412 .66922 .22952 .66284 .22075 Mtetra
.663 .737 .905 r
.66284 .22075 .66922 .22952 .68247 .2249 .67613 .21606 Mtetra
.663 .736 .905 r
.67613 .21606 .68247 .2249 .69579 .22026 .68948 .21135 Mtetra
.663 .736 .904 r
.68948 .21135 .69579 .22026 .70916 .21559 .7029 .20662 Mtetra
.663 .735 .904 r
.7029 .20662 .70916 .21559 .7226 .21089 .71638 .20186 Mtetra
.663 .735 .903 r
.71638 .20186 .7226 .21089 .7361 .20615 .72992 .19707 Mtetra
.72992 .19707 .7361 .20615 .74966 .20137 .74353 .19226 Mtetra
.74353 .19226 .74966 .20137 .76329 .19655 .7572 .18742 Mtetra
.663 .736 .903 r
.7572 .18742 .76329 .19655 .77698 .1917 .77094 .18254 Mtetra
.664 .736 .904 r
.77094 .18254 .77698 .1917 .79073 .18681 .78474 .17764 Mtetra
.664 .737 .904 r
.78474 .17764 .79073 .18681 .80455 .18189 .79861 .17271 Mtetra
.663 .741 .908 r
.17033 .3851 .17814 .39237 .18924 .38844 .18146 .38115 Mtetra
.18146 .38115 .18924 .38844 .20039 .3845 .19263 .37719 Mtetra
.661 .742 .909 r
.19263 .37719 .20039 .3845 .21158 .38055 .20385 .37326 Mtetra
.658 .742 .912 r
.20385 .37326 .21158 .38055 .22282 .37661 .2151 .36942 Mtetra
.649 .743 .918 r
.2151 .36942 .22282 .37661 .23411 .37272 .22639 .3658 Mtetra
.629 .747 .932 r
.22639 .3658 .23411 .37272 .24542 .36897 .23768 .36267 Mtetra
.581 .752 .959 r
.23768 .36267 .24542 .36897 .25677 .36554 .24894 .36046 Mtetra
.448 .745 .992 r
.24894 .36046 .25677 .36554 .26811 .3627 .26014 .35982 Mtetra
.035 .571 .852 r
.26014 .35982 .26811 .3627 .27944 .36092 .27122 .36157 Mtetra
.51 0 0 r
.27122 .36157 .27944 .36092 .29071 .36072 .28215 .36651 Mtetra
.667 .209 .156 r
.28215 .36651 .29071 .36072 .30191 .36269 .29292 .37513 Mtetra
.688 .3 .307 r
.29292 .37513 .30191 .36269 .31303 .36715 .30361 .38713 Mtetra
.675 .324 .372 r
.30361 .38713 .31303 .36715 .32413 .37394 .31433 .40114 Mtetra
.647 .316 .398 r
.31433 .40114 .32413 .37394 .33526 .38216 .32527 .41464 Mtetra
.603 .284 .402 r
.32527 .41464 .33526 .38216 .34656 .39012 .33661 .42439 Mtetra
.537 .223 .383 r
.33661 .42439 .34656 .39012 .35812 .39567 .34848 .42742 Mtetra
.422 .11 .329 r
.34848 .42742 .35812 .39567 .37003 .39676 .36087 .42203 Mtetra
.183 0 .185 r
.36087 .42203 .37003 .39676 .38228 .39218 .3737 .4085 Mtetra
0 0 0 r
.3737 .4085 .38228 .39218 .3948 .38201 .38677 .38893 Mtetra
.911 .965 .649 r
.38677 .38893 .3948 .38201 .4075 .3676 .39989 .3665 Mtetra
.946 .883 .739 r
.39989 .3665 .4075 .3676 .42024 .35102 .41293 .34431 Mtetra
.889 .794 .749 r
.41293 .34431 .42024 .35102 .43295 .33442 .4258 .32461 Mtetra
.837 .743 .76 r
.4258 .32461 .43295 .33442 .44557 .3194 .43851 .30848 Mtetra
.793 .717 .781 r
.43851 .30848 .44557 .3194 .45812 .30677 .4511 .29594 Mtetra
.756 .71 .808 r
.4511 .29594 .45812 .30677 .47062 .2966 .46362 .2864 Mtetra
.725 .712 .838 r
.46362 .2864 .47062 .2966 .4831 .28854 .47612 .27902 Mtetra
.7 .72 .864 r
.47612 .27902 .4831 .28854 .49559 .282 .48864 .27301 Mtetra
.683 .728 .884 r
.48864 .27301 .49559 .282 .50811 .27644 .5012 .26779 Mtetra
.673 .734 .896 r
.5012 .26779 .50811 .27644 .52068 .27144 .51381 .26297 Mtetra
.667 .737 .902 r
.51381 .26297 .52068 .27144 .53331 .26672 .52647 .25833 Mtetra
.665 .74 .906 r
.52647 .25833 .53331 .26672 .546 .26213 .5392 .25374 Mtetra
.664 .741 .907 r
.5392 .25374 .546 .26213 .55874 .25757 .55198 .24917 Mtetra
.664 .741 .908 r
.55198 .24917 .55874 .25757 .57154 .25303 .56482 .2446 Mtetra
.56482 .2446 .57154 .25303 .5844 .24847 .57772 .24 Mtetra
.57772 .24 .5844 .24847 .59732 .2439 .59068 .23538 Mtetra
.663 .741 .908 r
.59068 .23538 .59732 .2439 .6103 .23931 .6037 .23075 Mtetra
.6037 .23075 .6103 .23931 .62334 .23469 .61678 .22609 Mtetra
.61678 .22609 .62334 .23469 .63645 .23006 .62993 .22141 Mtetra
.663 .741 .907 r
.62993 .22141 .63645 .23006 .64961 .22542 .64313 .21671 Mtetra
.663 .74 .907 r
.64313 .21671 .64961 .22542 .66284 .22075 .6564 .21199 Mtetra
.6564 .21199 .66284 .22075 .67613 .21606 .66973 .20725 Mtetra
.66973 .20725 .67613 .21606 .68948 .21135 .68313 .20249 Mtetra
.663 .739 .906 r
.68313 .20249 .68948 .21135 .7029 .20662 .69659 .1977 Mtetra
.69659 .1977 .7029 .20662 .71638 .20186 .71011 .19289 Mtetra
.71011 .19289 .71638 .20186 .72992 .19707 .7237 .18806 Mtetra
.7237 .18806 .72992 .19707 .74353 .19226 .73735 .1832 Mtetra
.73735 .1832 .74353 .19226 .7572 .18742 .75107 .17832 Mtetra
.75107 .17832 .7572 .18742 .77094 .18254 .76485 .17341 Mtetra
.664 .739 .906 r
.76485 .17341 .77094 .18254 .78474 .17764 .7787 .16847 Mtetra
.7787 .16847 .78474 .17764 .79861 .17271 .79262 .16351 Mtetra
.662 .741 .909 r
.16246 .37778 .17033 .3851 .18146 .38115 .17361 .37382 Mtetra
.66 .742 .91 r
.17361 .37382 .18146 .38115 .19263 .37719 .1848 .36991 Mtetra
.655 .742 .914 r
.1848 .36991 .19263 .37719 .20385 .37326 .19603 .36612 Mtetra
.642 .744 .923 r
.19603 .36612 .20385 .37326 .2151 .36942 .20727 .36267 Mtetra
.612 .748 .942 r
.20727 .36267 .2151 .36942 .22639 .3658 .2185 .3599 Mtetra
.531 .75 .976 r
.2185 .3599 .22639 .3658 .23768 .36267 .22967 .35842 Mtetra
.27 .686 .968 r
.22967 .35842 .23768 .36267 .24894 .36046 .24071 .35912 Mtetra
.361 0 0 r
.24071 .35912 .24894 .36046 .26014 .35982 .25154 .36312 Mtetra
.67 .179 .076 r
.25154 .36312 .26014 .35982 .27122 .36157 .26213 .37148 Mtetra
.718 .32 .294 r
.26213 .37148 .27122 .36157 .28215 .36651 .27246 .38483 Mtetra
.714 .363 .381 r
.27246 .38483 .28215 .36651 .29292 .37513 .28263 .40273 Mtetra
.695 .368 .419 r
.28263 .40273 .29292 .37513 .30361 .38713 .29283 .42323 Mtetra
.665 .352 .434 r
.29283 .42323 .30361 .38713 .31433 .40114 .30331 .44283 Mtetra
.621 .316 .432 r
.30331 .44283 .31433 .40114 .32527 .41464 .31437 .45709 Mtetra
.551 .249 .41 r
.31437 .45709 .32527 .41464 .33661 .42439 .32619 .46198 Mtetra
.419 .119 .347 r
.32619 .46198 .33661 .42439 .34848 .42742 .33879 .45529 Mtetra
.095 0 .158 r
.33879 .45529 .34848 .42742 .36087 .42203 .352 .43763 Mtetra
.682 .822 .382 r
.352 .43763 .36087 .42203 .3737 .4085 .36557 .4121 Mtetra
.977 .905 .673 r
.36557 .4121 .3737 .4085 .38677 .38893 .37918 .38308 Mtetra
.923 .788 .694 r
.37918 .38308 .38677 .38893 .39989 .3665 .39263 .35477 Mtetra
.866 .719 .698 r
.39263 .35477 .39989 .3665 .41293 .34431 .40582 .33007 Mtetra
.822 .684 .712 r
.40582 .33007 .41293 .34431 .4258 .32461 .41875 .31025 Mtetra
.786 .671 .737 r
.41875 .31025 .4258 .32461 .43851 .30848 .43146 .29526 Mtetra
.756 .674 .771 r
.43146 .29526 .43851 .30848 .4511 .29594 .44404 .28423 Mtetra
.728 .686 .81 r
.44404 .28423 .4511 .29594 .46362 .2864 .45657 .27601 Mtetra
.704 .703 .846 r
.45657 .27601 .46362 .2864 .47612 .27902 .46909 .26957 Mtetra
.686 .718 .874 r
.46909 .26957 .47612 .27902 .48864 .27301 .48164 .26413 Mtetra
.674 .729 .891 r
.48164 .26413 .48864 .27301 .5012 .26779 .49423 .25921 Mtetra
.668 .735 .9 r
.49423 .25921 .5012 .26779 .51381 .26297 .50687 .25451 Mtetra
.665 .739 .905 r
.50687 .25451 .51381 .26297 .52647 .25833 .51958 .2499 Mtetra
.664 .74 .907 r
.51958 .2499 .52647 .25833 .5392 .25374 .53234 .24531 Mtetra
.664 .741 .907 r
.53234 .24531 .5392 .25374 .55198 .24917 .54516 .24071 Mtetra
.664 .741 .908 r
.54516 .24071 .55198 .24917 .56482 .2446 .55804 .23609 Mtetra
.55804 .23609 .56482 .2446 .57772 .24 .57098 .23146 Mtetra
.57098 .23146 .57772 .24 .59068 .23538 .58398 .2268 Mtetra
.58398 .2268 .59068 .23538 .6037 .23075 .59704 .22212 Mtetra
.59704 .22212 .6037 .23075 .61678 .22609 .61017 .21742 Mtetra
.61017 .21742 .61678 .22609 .62993 .22141 .62335 .2127 Mtetra
.663 .741 .908 r
.62335 .2127 .62993 .22141 .64313 .21671 .6366 .20796 Mtetra
.6366 .20796 .64313 .21671 .6564 .21199 .64991 .20319 Mtetra
.64991 .20319 .6564 .21199 .66973 .20725 .66329 .19841 Mtetra
.66329 .19841 .66973 .20725 .68313 .20249 .67672 .1936 Mtetra
.663 .741 .907 r
.67672 .1936 .68313 .20249 .69659 .1977 .69023 .18876 Mtetra
.663 .74 .907 r
.69023 .18876 .69659 .1977 .71011 .19289 .70379 .18391 Mtetra
.70379 .18391 .71011 .19289 .7237 .18806 .71743 .17903 Mtetra
.71743 .17903 .7237 .18806 .73735 .1832 .73112 .17412 Mtetra
.73112 .17412 .73735 .1832 .75107 .17832 .74489 .1692 Mtetra
.74489 .1692 .75107 .17832 .76485 .17341 .75872 .16424 Mtetra
.664 .74 .907 r
.75872 .16424 .76485 .17341 .7787 .16847 .77261 .15926 Mtetra
.77261 .15926 .7787 .16847 .79262 .16351 .78658 .15426 Mtetra
.659 .742 .911 r
.15452 .37045 .16246 .37778 .17361 .37382 .16568 .36655 Mtetra
.652 .743 .916 r
.16568 .36655 .17361 .37382 .1848 .36991 .17688 .36283 Mtetra
.635 .745 .927 r
.17688 .36283 .1848 .36991 .19603 .36612 .18808 .35954 Mtetra
.592 .748 .952 r
.18808 .35954 .19603 .36612 .20727 .36267 .19924 .35714 Mtetra
.466 .739 .987 r
.19924 .35714 .20727 .36267 .2185 .3599 .2103 .35642 Mtetra
.034 .558 .863 r
.2103 .35642 .2185 .3599 .22967 .35842 .22116 .35848 Mtetra
.577 .011 0 r
.22116 .35848 .22967 .35842 .24071 .35912 .23173 .36473 Mtetra
.725 .288 .213 r
.23173 .36473 .24071 .35912 .25154 .36312 .24193 .37649 Mtetra
.74 .373 .356 r
.24193 .37649 .25154 .36312 .26213 .37148 .25177 .39448 Mtetra
.73 .397 .415 r
.25177 .39448 .26213 .37148 .27246 .38483 .26136 .41809 Mtetra
.709 .394 .442 r
.26136 .41809 .27246 .38483 .28263 .40273 .27096 .4448 Mtetra
.68 .374 .45 r
.27096 .4448 .28263 .40273 .29283 .42323 .28095 .47012 Mtetra
.635 .334 .444 r
.28095 .47012 .29283 .42323 .30331 .44283 .2917 .48841 Mtetra
.558 .259 .416 r
.2917 .48841 .30331 .44283 .31437 .45709 .30347 .49464 Mtetra
.389 .089 .331 r
.30347 .49464 .31437 .45709 .32619 .46198 .3163 .48623 Mtetra
0 0 0 r
.3163 .48623 .32619 .46198 .33879 .45529 .32997 .46421 Mtetra
.967 .93 .616 r
.32997 .46421 .33879 .45529 .352 .43763 .34408 .43273 Mtetra
.938 .784 .664 r
.34408 .43273 .352 .43763 .36557 .4121 .35825 .39742 Mtetra
.873 .695 .658 r
.35825 .39742 .36557 .4121 .37918 .38308 .37217 .36343 Mtetra
.828 .65 .661 r
.37217 .36343 .37918 .38308 .39263 .35477 .38572 .33421 Mtetra
.796 .629 .675 r
.38572 .33421 .39263 .35477 .40582 .33007 .39888 .31115 Mtetra
.77 .626 .701 r
.39888 .31115 .40582 .33007 .41875 .31025 .41173 .29405 Mtetra
.747 .637 .738 r
.41173 .29405 .41875 .31025 .43146 .29526 .42439 .28174 Mtetra
.725 .659 .783 r
.42439 .28174 .43146 .29526 .44404 .28423 .43694 .27283 Mtetra
.705 .685 .828 r
.43694 .27283 .44404 .28423 .45657 .27601 .44946 .26603 Mtetra
.688 .708 .863 r
.44946 .26603 .45657 .27601 .46909 .26957 .462 .26042 Mtetra
.676 .724 .886 r
.462 .26042 .46909 .26957 .48164 .26413 .47457 .25542 Mtetra
.669 .733 .898 r
.47457 .25542 .48164 .26413 .49423 .25921 .4872 .25068 Mtetra
.666 .738 .904 r
.4872 .25068 .49423 .25921 .50687 .25451 .49988 .24604 Mtetra
.664 .74 .906 r
.49988 .24604 .50687 .25451 .51958 .2499 .51262 .24142 Mtetra
.664 .741 .907 r
.51262 .24142 .51958 .2499 .53234 .24531 .52542 .23681 Mtetra
.664 .741 .908 r
.52542 .23681 .53234 .24531 .54516 .24071 .53828 .23217 Mtetra
.53828 .23217 .54516 .24071 .55804 .23609 .5512 .22752 Mtetra
.5512 .22752 .55804 .23609 .57098 .23146 .56418 .22284 Mtetra
.56418 .22284 .57098 .23146 .58398 .2268 .57722 .21815 Mtetra
.57722 .21815 .58398 .2268 .59704 .22212 .59033 .21343 Mtetra
.59033 .21343 .59704 .22212 .61017 .21742 .60349 .20869 Mtetra
.60349 .20869 .61017 .21742 .62335 .2127 .61672 .20392 Mtetra
.61672 .20392 .62335 .2127 .6366 .20796 .63001 .19914 Mtetra
.63001 .19914 .6366 .20796 .64991 .20319 .64336 .19433 Mtetra
.64336 .19433 .64991 .20319 .66329 .19841 .65678 .1895 Mtetra
.65678 .1895 .66329 .19841 .67672 .1936 .67026 .18464 Mtetra
.67026 .18464 .67672 .1936 .69023 .18876 .68381 .17976 Mtetra
.68381 .17976 .69023 .18876 .70379 .18391 .69742 .17486 Mtetra
.69742 .17486 .70379 .18391 .71743 .17903 .7111 .16994 Mtetra
.7111 .16994 .71743 .17903 .73112 .17412 .72484 .16499 Mtetra
.72484 .16499 .73112 .17412 .74489 .1692 .73865 .16002 Mtetra
.73865 .16002 .74489 .1692 .75872 .16424 .75253 .15502 Mtetra
.75253 .15502 .75872 .16424 .77261 .15926 .76647 .15 Mtetra
.76647 .15 .77261 .15926 .78658 .15426 .78049 .14495 Mtetra
.65 .743 .917 r
.1465 .36317 .15452 .37045 .16568 .36655 .15766 .35951 Mtetra
.628 .745 .931 r
.15766 .35951 .16568 .36655 .17688 .36283 .16882 .35636 Mtetra
.573 .747 .959 r
.16882 .35636 .17688 .36283 .18808 .35954 .17991 .35429 Mtetra
.399 .72 .988 r
.17991 .35429 .18808 .35954 .19924 .35714 .19086 .3542 Mtetra
0 .411 .718 r
.19086 .3542 .19924 .35714 .2103 .35642 .20155 .35741 Mtetra
.664 .14 0 r
.20155 .35741 .2103 .35642 .22116 .35848 .21186 .36551 Mtetra
.75 .34 .274 r
.21186 .36551 .22116 .35848 .23173 .36473 .22169 .38002 Mtetra
.755 .401 .383 r
.22169 .38002 .23173 .36473 .24193 .37649 .23106 .40169 Mtetra
.743 .417 .43 r
.23106 .40169 .24193 .37649 .25177 .39448 .2401 .42974 Mtetra
.723 .412 .451 r
.2401 .42974 .25177 .39448 .26136 .41809 .24915 .46113 Mtetra
.695 .39 .456 r
.24915 .46113 .26136 .41809 .27096 .4448 .25867 .49056 Mtetra
.65 .347 .445 r
.25867 .49056 .27096 .4448 .28095 .47012 .26913 .51148 Mtetra
.563 .256 .405 r
.26913 .51148 .28095 .47012 .2917 .48841 .28089 .51815 Mtetra
.299 0 .249 r
.28089 .51815 .2917 .48841 .30347 .49464 .29395 .50783 Mtetra
.819 .915 .52 r
.29395 .50783 .30347 .49464 .3163 .48623 .30805 .48205 Mtetra
.94 .788 .664 r
.30805 .48205 .3163 .48623 .32997 .46421 .32268 .44585 Mtetra
.865 .672 .64 r
.32268 .44585 .32997 .46421 .34408 .43273 .33736 .4058 Mtetra
.82 .62 .632 r
.33736 .4058 .34408 .43273 .35825 .39742 .35172 .36774 Mtetra
.79 .594 .636 r
.35172 .36774 .35825 .39742 .37217 .36343 .36558 .3354 Mtetra
.767 .584 .65 r
.36558 .3354 .37217 .36343 .38572 .33421 .37896 .31021 Mtetra
.749 .588 .676 r
.37896 .31021 .38572 .33421 .39888 .31115 .39194 .29176 Mtetra
.733 .605 .714 r
.39194 .29176 .39888 .31115 .41173 .29405 .40466 .27868 Mtetra
.718 .633 .762 r
.40466 .27868 .41173 .29405 .42439 .28174 .41723 .26936 Mtetra
.702 .667 .813 r
.41723 .26936 .42439 .28174 .43694 .27283 .42976 .26235 Mtetra
.687 .698 .854 r
.42976 .26235 .43694 .27283 .44946 .26603 .44228 .25665 Mtetra
.676 .719 .881 r
.44228 .25665 .44946 .26603 .462 .26042 .45484 .25159 Mtetra
.669 .731 .896 r
.45484 .25159 .462 .26042 .47457 .25542 .46745 .24682 Mtetra
.666 .737 .903 r
.46745 .24682 .47457 .25542 .4872 .25068 .48011 .24216 Mtetra
.664 .74 .906 r
.48011 .24216 .4872 .25068 .49988 .24604 .49283 .23753 Mtetra
.664 .741 .907 r
.49283 .23753 .49988 .24604 .51262 .24142 .50561 .23289 Mtetra
.664 .741 .908 r
.50561 .23289 .51262 .24142 .52542 .23681 .51844 .22824 Mtetra
.51844 .22824 .52542 .23681 .53828 .23217 .53134 .22357 Mtetra
.53134 .22357 .53828 .23217 .5512 .22752 .5443 .21887 Mtetra
.5443 .21887 .5512 .22752 .56418 .22284 .55732 .21416 Mtetra
.55732 .21416 .56418 .22284 .57722 .21815 .57041 .20942 Mtetra
.57041 .20942 .57722 .21815 .59033 .21343 .58355 .20466 Mtetra
.58355 .20466 .59033 .21343 .60349 .20869 .59676 .19987 Mtetra
.59676 .19987 .60349 .20869 .61672 .20392 .61003 .19507 Mtetra
.61003 .19507 .61672 .20392 .63001 .19914 .62336 .19024 Mtetra
.62336 .19024 .63001 .19914 .64336 .19433 .63676 .18539 Mtetra
.63676 .18539 .64336 .19433 .65678 .1895 .65022 .18051 Mtetra
.65022 .18051 .65678 .1895 .67026 .18464 .66374 .17562 Mtetra
.66374 .17562 .67026 .18464 .68381 .17976 .67734 .17069 Mtetra
.67734 .17069 .68381 .17976 .69742 .17486 .69099 .16575 Mtetra
.69099 .16575 .69742 .17486 .7111 .16994 .70472 .16078 Mtetra
.70472 .16078 .7111 .16994 .72484 .16499 .7185 .15578 Mtetra
.7185 .15578 .72484 .16499 .73865 .16002 .73236 .15077 Mtetra
.73236 .15077 .73865 .16002 .75253 .15502 .74629 .14572 Mtetra
.74629 .14572 .75253 .15502 .76647 .15 .76028 .14066 Mtetra
.76028 .14066 .76647 .15 .78049 .14495 .77434 .13556 Mtetra
.624 .745 .934 r
.13837 .35614 .1465 .36317 .15766 .35951 .14949 .35309 Mtetra
.56 .745 .963 r
.14949 .35309 .15766 .35951 .16882 .35636 .16053 .35122 Mtetra
.353 .703 .984 r
.16053 .35122 .16882 .35636 .17991 .35429 .17138 .35153 Mtetra
.272 0 0 r
.17138 .35153 .17991 .35429 .19086 .3542 .18193 .35541 Mtetra
.696 .19 .031 r
.18193 .35541 .19086 .3542 .20155 .35741 .19203 .36458 Mtetra
.763 .362 .292 r
.19203 .36458 .20155 .35741 .21186 .36551 .20159 .38059 Mtetra
.767 .416 .39 r
.20159 .38059 .21186 .36551 .22169 .38002 .2106 .40417 Mtetra
.756 .43 .432 r
.2106 .40417 .22169 .38002 .23106 .40169 .21924 .43434 Mtetra
.739 .424 .45 r
.21924 .43434 .23106 .40169 .2401 .42974 .22788 .46775 Mtetra
.713 .403 .451 r
.22788 .46775 .2401 .42974 .24915 .46113 .23707 .49864 Mtetra
.67 .355 .433 r
.23707 .49864 .24915 .46113 .25867 .49056 .24736 .52007 Mtetra
.565 .231 .361 r
.24736 .52007 .25867 .49056 .26913 .51148 .25911 .52609 Mtetra
0 0 0 r
.25911 .52609 .26913 .51148 .28089 .51815 .27236 .5141 Mtetra
.928 .808 .707 r
.27236 .5141 .28089 .51815 .29395 .50783 .28677 .48604 Mtetra
.843 .65 .641 r
.28677 .48604 .29395 .50783 .30805 .48205 .30177 .44748 Mtetra
.801 .592 .619 r
.30177 .44748 .30805 .48205 .32268 .44585 .3168 .40541 Mtetra
.775 .564 .614 r
.3168 .40541 .32268 .44585 .33736 .4058 .33145 .36584 Mtetra
.755 .551 .619 r
.33145 .36584 .33736 .4058 .35172 .36774 .34553 .33254 Mtetra
.741 .549 .634 r
.34553 .33254 .35172 .36774 .36558 .3354 .35905 .30679 Mtetra
.729 .558 .66 r
.35905 .30679 .36558 .3354 .37896 .31021 .37211 .28807 Mtetra
.718 .58 .699 r
.37211 .28807 .37896 .31021 .39194 .29176 .38487 .27489 Mtetra
.708 .614 .749 r
.38487 .27489 .39194 .29176 .40466 .27868 .39746 .26552 Mtetra
.697 .654 .803 r
.39746 .26552 .40466 .27868 .41723 .26936 .40998 .2585 Mtetra
.685 .69 .849 r
.40998 .2585 .41723 .26936 .42976 .26235 .42249 .25279 Mtetra
.675 .715 .879 r
.42249 .25279 .42976 .26235 .44228 .25665 .43503 .24772 Mtetra
.669 .729 .895 r
.43503 .24772 .44228 .25665 .45484 .25159 .44762 .24294 Mtetra
.665 .736 .903 r
.44762 .24294 .45484 .25159 .46745 .24682 .46026 .23826 Mtetra
.664 .739 .906 r
.46026 .23826 .46745 .24682 .48011 .24216 .47296 .23361 Mtetra
.664 .741 .907 r
.47296 .23361 .48011 .24216 .49283 .23753 .48571 .22896 Mtetra
.664 .741 .908 r
.48571 .22896 .49283 .23753 .50561 .23289 .49853 .22429 Mtetra
.49853 .22429 .50561 .23289 .51844 .22824 .51141 .2196 Mtetra
.51141 .2196 .51844 .22824 .53134 .22357 .52435 .21488 Mtetra
.52435 .21488 .53134 .22357 .5443 .21887 .53735 .21015 Mtetra
.53735 .21015 .5443 .21887 .55732 .21416 .55041 .20539 Mtetra
.55041 .20539 .55732 .21416 .57041 .20942 .56353 .20061 Mtetra
.56353 .20061 .57041 .20942 .58355 .20466 .57672 .19581 Mtetra
.57672 .19581 .58355 .20466 .59676 .19987 .58996 .19098 Mtetra
.58996 .19098 .59676 .19987 .61003 .19507 .60328 .18614 Mtetra
.60328 .18614 .61003 .19507 .62336 .19024 .61665 .18126 Mtetra
.61665 .18126 .62336 .19024 .63676 .18539 .63009 .17637 Mtetra
.63009 .17637 .63676 .18539 .65022 .18051 .6436 .17145 Mtetra
.6436 .17145 .65022 .18051 .66374 .17562 .65717 .16651 Mtetra
.65717 .16651 .66374 .17562 .67734 .17069 .6708 .16154 Mtetra
.6708 .16154 .67734 .17069 .69099 .16575 .68451 .15655 Mtetra
.68451 .15655 .69099 .16575 .70472 .16078 .69828 .15154 Mtetra
.69828 .15154 .70472 .16078 .7185 .15578 .71211 .1465 Mtetra
.71211 .1465 .7185 .15578 .73236 .15077 .72601 .14144 Mtetra
.72601 .14144 .73236 .15077 .74629 .14572 .73999 .13635 Mtetra
.73999 .13635 .74629 .14572 .76028 .14066 .75403 .13123 Mtetra
.75403 .13123 .76028 .14066 .77434 .13556 .76814 .1261 Mtetra
.557 .743 .964 r
.1301 .34967 .13837 .35614 .14949 .35309 .1411 .34784 Mtetra
.349 .698 .983 r
.1411 .34784 .14949 .35309 .16053 .35122 .1519 .3482 Mtetra
.267 0 0 r
.1519 .3482 .16053 .35122 .17138 .35153 .16237 .35215 Mtetra
.698 .185 .011 r
.16237 .35215 .17138 .35153 .18193 .35541 .17236 .36134 Mtetra
.771 .362 .277 r
.17236 .36134 .18193 .35541 .19203 .36458 .18177 .37725 Mtetra
.778 .42 .377 r
.18177 .37725 .19203 .36458 .20159 .38059 .19062 .40048 Mtetra
.771 .437 .42 r
.19062 .40048 .20159 .38059 .2106 .40417 .19909 .42993 Mtetra
.758 .434 .436 r
.19909 .42993 .2106 .40417 .21924 .43434 .20759 .46214 Mtetra
.738 .413 .432 r
.20759 .46214 .21924 .43434 .22788 .46775 .21667 .49143 Mtetra
.701 .359 .395 r
.21667 .49143 .22788 .46775 .23707 .49864 .22691 .51106 Mtetra
.548 .124 .189 r
.22691 .51106 .23707 .49864 .24736 .52007 .23869 .51547 Mtetra
.849 .851 .844 r
.23869 .51547 .24736 .52007 .25911 .52609 .25202 .50247 Mtetra
.8 .622 .66 r
.25202 .50247 .25911 .52609 .27236 .5141 .26654 .47423 Mtetra
.771 .564 .619 r
.26654 .47423 .27236 .5141 .28677 .48604 .28166 .4363 Mtetra
.752 .538 .605 r
.28166 .4363 .28677 .48604 .30177 .44748 .2968 .39542 Mtetra
.738 .524 .604 r
.2968 .39542 .30177 .44748 .3168 .40541 .31153 .3573 Mtetra
.727 .519 .61 r
.31153 .3573 .3168 .40541 .33145 .36584 .32567 .32539 Mtetra
.718 .523 .626 r
.32567 .32539 .33145 .36584 .34553 .33254 .33922 .30082 Mtetra
.71 .537 .652 r
.33922 .30082 .34553 .33254 .35905 .30679 .35229 .28296 Mtetra
.704 .563 .692 r
.35229 .28296 .35905 .30679 .37211 .28807 .36505 .27035 Mtetra
.699 .601 .744 r
.36505 .27035 .37211 .28807 .38487 .27489 .37763 .26132 Mtetra
.691 .646 .8 r
.37763 .26132 .38487 .27489 .39746 .26552 .39013 .25449 Mtetra
.682 .686 .847 r
.39013 .25449 .39746 .26552 .40998 .2585 .40262 .24886 Mtetra
.673 .713 .878 r
.40262 .24886 .40998 .2585 .42249 .25279 .41514 .24381 Mtetra
.668 .729 .895 r
.41514 .24381 .42249 .25279 .43503 .24772 .42771 .23903 Mtetra
.665 .736 .903 r
.42771 .23903 .43503 .24772 .44762 .24294 .44033 .23434 Mtetra
.664 .739 .906 r
.44033 .23434 .44762 .24294 .46026 .23826 .453 .22968 Mtetra
.664 .741 .907 r
.453 .22968 .46026 .23826 .47296 .23361 .46574 .22501 Mtetra
.664 .741 .908 r
.46574 .22501 .47296 .23361 .48571 .22896 .47854 .22032 Mtetra
.47854 .22032 .48571 .22896 .49853 .22429 .49139 .21561 Mtetra
.49139 .21561 .49853 .22429 .51141 .2196 .50431 .21088 Mtetra
.50431 .21088 .51141 .2196 .52435 .21488 .51729 .20612 Mtetra
.51729 .20612 .52435 .21488 .53735 .21015 .53033 .20135 Mtetra
.53033 .20135 .53735 .21015 .55041 .20539 .54343 .19655 Mtetra
.54343 .19655 .55041 .20539 .56353 .20061 .55659 .19173 Mtetra
.55659 .19173 .56353 .20061 .57672 .19581 .56982 .18688 Mtetra
.56982 .18688 .57672 .19581 .58996 .19098 .58311 .18202 Mtetra
.58311 .18202 .58996 .19098 .60328 .18614 .59647 .17712 Mtetra
.59647 .17712 .60328 .18614 .61665 .18126 .60989 .17221 Mtetra
.60989 .17221 .61665 .18126 .63009 .17637 .62337 .16727 Mtetra
.62337 .16727 .63009 .17637 .6436 .17145 .63692 .16231 Mtetra
.63692 .16231 .6436 .17145 .65717 .16651 .65053 .15732 Mtetra
.65053 .15732 .65717 .16651 .6708 .16154 .66421 .15231 Mtetra
.66421 .15231 .6708 .16154 .68451 .15655 .67796 .14728 Mtetra
.67796 .14728 .68451 .15655 .69828 .15154 .69178 .14222 Mtetra
.69178 .14222 .69828 .15154 .71211 .1465 .70566 .13713 Mtetra
.70566 .13713 .71211 .1465 .72601 .14144 .71961 .13202 Mtetra
.71961 .13202 .72601 .14144 .73999 .13635 .73363 .12689 Mtetra
.73363 .12689 .73999 .13635 .75403 .13123 .74772 .12173 Mtetra
.74772 .12173 .75403 .13123 .76814 .1261 .76188 .11654 Mtetra
.388 .708 .985 r
.12164 .34412 .1301 .34967 .1411 .34784 .13242 .34419 Mtetra
0 .415 .748 r
.13242 .34419 .1411 .34784 .1519 .3482 .14288 .34756 Mtetra
.66 .118 0 r
.14288 .34756 .1519 .3482 .16237 .35215 .15288 .35572 Mtetra
.771 .337 .22 r
.15288 .35572 .16237 .35215 .17236 .36134 .16233 .36995 Mtetra
.788 .41 .34 r
.16233 .36995 .17236 .36134 .18177 .37725 .17124 .39066 Mtetra
.788 .435 .389 r
.17124 .39066 .18177 .37725 .19062 .40048 .17982 .41671 Mtetra
.782 .437 .403 r
.17982 .41671 .19062 .40048 .19909 .42993 .18844 .44482 Mtetra
.774 .419 .383 r
.18844 .44482 .19909 .42993 .20759 .46214 .19766 .46984 Mtetra
.753 .342 .272 r
.19766 .46984 .20759 .46214 .21667 .49143 .20801 .48584 Mtetra
.156 .591 .933 r
.20801 .48584 .21667 .49143 .22691 .51106 .21983 .48811 Mtetra
.713 .577 .701 r
.21983 .48811 .22691 .51106 .23869 .51547 .23311 .475 Mtetra
.726 .532 .628 r
.23311 .475 .23869 .51547 .25202 .50247 .2475 .44868 Mtetra
.722 .512 .605 r
.2475 .44868 .25202 .50247 .26654 .47423 .26246 .41416 Mtetra
.716 .502 .598 r
.26246 .41416 .26654 .47423 .28166 .4363 .27742 .37737 Mtetra
.71 .497 .599 r
.27742 .37737 .28166 .4363 .2968 .39542 .29199 .34326 Mtetra
.703 .498 .607 r
.29199 .34326 .2968 .39542 .31153 .3573 .30601 .31477 Mtetra
.698 .506 .624 r
.30601 .31477 .31153 .3573 .32567 .32539 .31947 .29279 Mtetra
.695 .524 .652 r
.31947 .29279 .32567 .32539 .33922 .30082 .33248 .27673 Mtetra
.693 .554 .693 r
.33248 .27673 .33922 .30082 .35229 .28296 .34519 .26524 Mtetra
.69 .597 .747 r
.34519 .26524 .35229 .28296 .36505 .27035 .35773 .25685 Mtetra
.685 .645 .804 r
.35773 .25685 .36505 .27035 .37763 .26132 .37021 .25034 Mtetra
.678 .687 .851 r
.37021 .25034 .37763 .26132 .39013 .25449 .38268 .24486 Mtetra
.672 .714 .88 r
.38268 .24486 .39013 .25449 .40262 .24886 .39518 .23988 Mtetra
.667 .729 .896 r
.39518 .23988 .40262 .24886 .41514 .24381 .40772 .23511 Mtetra
.665 .737 .903 r
.40772 .23511 .41514 .24381 .42771 .23903 .42032 .23041 Mtetra
.664 .74 .906 r
.42032 .23041 .42771 .23903 .44033 .23434 .43297 .22573 Mtetra
.664 .741 .907 r
.43297 .22573 .44033 .23434 .453 .22968 .44569 .22104 Mtetra
.664 .741 .908 r
.44569 .22104 .453 .22968 .46574 .22501 .45846 .21634 Mtetra
.45846 .21634 .46574 .22501 .47854 .22032 .4713 .21161 Mtetra
.4713 .21161 .47854 .22032 .49139 .21561 .48419 .20686 Mtetra
.48419 .20686 .49139 .21561 .50431 .21088 .49715 .20209 Mtetra
.49715 .20209 .50431 .21088 .51729 .20612 .51017 .19729 Mtetra
.51017 .19729 .51729 .20612 .53033 .20135 .52325 .19247 Mtetra
.52325 .19247 .53033 .20135 .54343 .19655 .53639 .18763 Mtetra
.53639 .18763 .54343 .19655 .55659 .19173 .5496 .18277 Mtetra
.5496 .18277 .55659 .19173 .56982 .18688 .56287 .17788 Mtetra
.56287 .17788 .56982 .18688 .58311 .18202 .5762 .17297 Mtetra
.5762 .17297 .58311 .18202 .59647 .17712 .5896 .16803 Mtetra
.5896 .16803 .59647 .17712 .60989 .17221 .60306 .16307 Mtetra
.60306 .16307 .60989 .17221 .62337 .16727 .61659 .15809 Mtetra
.61659 .15809 .62337 .16727 .63692 .16231 .63018 .15308 Mtetra
.63018 .15308 .63692 .16231 .65053 .15732 .64384 .14805 Mtetra
.64384 .14805 .65053 .15732 .66421 .15231 .65757 .143 Mtetra
.65757 .143 .66421 .15231 .67796 .14728 .67136 .13792 Mtetra
.67136 .13792 .67796 .14728 .69178 .14222 .68522 .13281 Mtetra
.68522 .13281 .69178 .14222 .70566 .13713 .69915 .12768 Mtetra
.69915 .12768 .70566 .13713 .71961 .13202 .71315 .12252 Mtetra
.71315 .12252 .71961 .13202 .73363 .12689 .72722 .11734 Mtetra
.72722 .11734 .73363 .12689 .74772 .12173 .74135 .11213 Mtetra
.74135 .11213 .74772 .12173 .76188 .11654 .75556 .1069 Mtetra
.06 .553 .889 r
.11295 .33959 .12164 .34412 .13242 .34419 .12347 .34189 Mtetra
.535 0 0 r
.12347 .34189 .13242 .34419 .14288 .34756 .13359 .34821 Mtetra
.747 .262 .088 r
.13359 .34821 .14288 .34756 .15288 .35572 .14323 .35956 Mtetra
.792 .374 .255 r
.14323 .35956 .15288 .35572 .16233 .36995 .15241 .37618 Mtetra
.804 .416 .318 r
.15241 .37618 .16233 .36995 .17124 .39066 .16132 .39696 Mtetra
.811 .425 .323 r
.16132 .39696 .17124 .39066 .17982 .41671 .17031 .41908 Mtetra
.819 .399 .245 r
.17031 .41908 .17982 .41671 .18844 .44482 .17986 .43824 Mtetra
.638 .108 0 r
.17986 .43824 .18844 .44482 .19766 .46984 .19041 .44968 Mtetra
.527 .488 .757 r
.19041 .44968 .19766 .46984 .20801 .48584 .20226 .44977 Mtetra
.657 .492 .65 r
.20226 .44977 .20801 .48584 .21983 .48811 .21537 .43742 Mtetra
.683 .486 .613 r
.21537 .43742 .21983 .48811 .23311 .475 .22944 .41457 Mtetra
.689 .481 .599 r
.22944 .41457 .23311 .475 .2475 .44868 .24399 .38533 Mtetra
.69 .478 .596 r
.24399 .38533 .2475 .44868 .26246 .41416 .25855 .3545 Mtetra
.688 .479 .599 r
.25855 .3545 .26246 .41416 .27742 .37737 .27277 .326 Mtetra
.685 .485 .609 r
.27277 .326 .27742 .37737 .29199 .34326 .28651 .30216 Mtetra
.683 .497 .629 r
.28651 .30216 .29199 .34326 .30601 .31477 .29978 .28363 Mtetra
.683 .52 .659 r
.29978 .28363 .30601 .31477 .31947 .29279 .31266 .26989 Mtetra
.683 .556 .704 r
.31266 .26989 .31947 .29279 .33248 .27673 .32529 .25982 Mtetra
.683 .602 .759 r
.32529 .25982 .33248 .27673 .34519 .26524 .33778 .25223 Mtetra
.68 .651 .814 r
.33778 .25223 .34519 .26524 .35773 .25685 .35022 .24613 Mtetra
.675 .691 .858 r
.35022 .24613 .35773 .25685 .37021 .25034 .36266 .24083 Mtetra
.67 .717 .884 r
.36266 .24083 .37021 .25034 .38268 .24486 .37513 .23592 Mtetra
.666 .731 .898 r
.37513 .23592 .38268 .24486 .39518 .23988 .38766 .23116 Mtetra
.665 .737 .904 r
.38766 .23116 .39518 .23988 .40772 .23511 .40023 .22646 Mtetra
.664 .74 .907 r
.40023 .22646 .40772 .23511 .42032 .23041 .41286 .22177 Mtetra
.664 .741 .907 r
.41286 .22177 .42032 .23041 .43297 .22573 .42556 .21706 Mtetra
.664 .741 .908 r
.42556 .21706 .43297 .22573 .44569 .22104 .43831 .21234 Mtetra
.43831 .21234 .44569 .22104 .45846 .21634 .45112 .20759 Mtetra
.45112 .20759 .45846 .21634 .4713 .21161 .46399 .20282 Mtetra
.46399 .20282 .4713 .21161 .48419 .20686 .47693 .19803 Mtetra
.47693 .19803 .48419 .20686 .49715 .20209 .48993 .19321 Mtetra
.48993 .19321 .49715 .20209 .51017 .19729 .50298 .18838 Mtetra
.50298 .18838 .51017 .19729 .52325 .19247 .5161 .18352 Mtetra
.5161 .18352 .52325 .19247 .53639 .18763 .52929 .17863 Mtetra
.52929 .17863 .53639 .18763 .5496 .18277 .54254 .17372 Mtetra
.54254 .17372 .5496 .18277 .56287 .17788 .55585 .16879 Mtetra
.55585 .16879 .56287 .17788 .5762 .17297 .56922 .16384 Mtetra
.56922 .16384 .5762 .17297 .5896 .16803 .58266 .15886 Mtetra
.58266 .15886 .5896 .16803 .60306 .16307 .59617 .15386 Mtetra
.59617 .15386 .60306 .16307 .61659 .15809 .60974 .14883 Mtetra
.60974 .14883 .61659 .15809 .63018 .15308 .62338 .14378 Mtetra
.62338 .14378 .63018 .15308 .64384 .14805 .63708 .1387 Mtetra
.63708 .1387 .64384 .14805 .65757 .143 .65086 .1336 Mtetra
.65086 .1336 .65757 .143 .67136 .13792 .6647 .12847 Mtetra
.6647 .12847 .67136 .13792 .68522 .13281 .6786 .12332 Mtetra
.6786 .12332 .68522 .13281 .69915 .12768 .69258 .11814 Mtetra
.69258 .11814 .69915 .12768 .71315 .12252 .70663 .11294 Mtetra
.70663 .11294 .71315 .12252 .72722 .11734 .72074 .10771 Mtetra
.72074 .10771 .72722 .11734 .74135 .11213 .73493 .10245 Mtetra
.73493 .10245 .74135 .11213 .75556 .1069 .74918 .09717 Mtetra
0 .351 .703 r
.1041 .33558 .11295 .33959 .12347 .34189 .11441 .33963 Mtetra
.628 .065 0 r
.11441 .33963 .12347 .34189 .13359 .34821 .12434 .34752 Mtetra
.759 .265 .054 r
.12434 .34752 .13359 .34821 .14323 .35956 .13393 .35934 Mtetra
.8 .34 .143 r
.13393 .35934 .14323 .35956 .15241 .37618 .14332 .37413 Mtetra
.815 .346 .102 r
.14332 .37413 .15241 .37618 .16132 .39696 .15281 .38965 Mtetra
.703 .193 0 r
.15281 .38965 .16132 .39696 .17031 .41908 .16279 .4026 Mtetra
.22 .346 .78 r
.16279 .4026 .17031 .41908 .17986 .43824 .17359 .40949 Mtetra
.558 .449 .686 r
.17359 .40949 .17986 .43824 .19041 .44968 .18544 .40776 Mtetra
.632 .461 .633 r
.18544 .40776 .19041 .44968 .20226 .44977 .19831 .39677 Mtetra
.657 .463 .61 r
.19831 .39677 .20226 .44977 .21537 .43742 .21193 .37808 Mtetra
.667 .464 .601 r
.21193 .37808 .21537 .43742 .22944 .41457 .22593 .35482 Mtetra
.67 .466 .599 r
.22593 .35482 .22944 .41457 .24399 .38533 .23994 .33052 Mtetra
.671 .471 .605 r
.23994 .33052 .24399 .38533 .25855 .3545 .2537 .30809 Mtetra
.672 .48 .618 r
.2537 .30809 .25855 .3545 .27277 .326 .26708 .2892 Mtetra
.673 .498 .641 r
.26708 .2892 .27277 .326 .28651 .30216 .28009 .27431 Mtetra
.675 .526 .676 r
.28009 .27431 .28651 .30216 .29978 .28363 .2928 .26299 Mtetra
.677 .567 .723 r
.2928 .26299 .29978 .28363 .31266 .26989 .30533 .25439 Mtetra
.678 .616 .779 r
.30533 .25439 .31266 .26989 .32529 .25982 .31776 .24761 Mtetra
.676 .663 .83 r
.31776 .24761 .32529 .25982 .33778 .25223 .33016 .24191 Mtetra
.672 .699 .867 r
.33016 .24191 .33778 .25223 .35022 .24613 .34257 .23679 Mtetra
.668 .721 .889 r
.34257 .23679 .35022 .24613 .36266 .24083 .35501 .23194 Mtetra
.665 .733 .9 r
.35501 .23194 .36266 .24083 .37513 .23592 .36751 .2272 Mtetra
.664 .738 .905 r
.36751 .2272 .37513 .23592 .38766 .23116 .38006 .2225 Mtetra
.664 .74 .907 r
.38006 .2225 .38766 .23116 .40023 .22646 .39267 .21779 Mtetra
.664 .741 .908 r
.39267 .21779 .40023 .22646 .41286 .22177 .40534 .21307 Mtetra
.40534 .21307 .41286 .22177 .42556 .21706 .41807 .20832 Mtetra
.41807 .20832 .42556 .21706 .43831 .21234 .43086 .20356 Mtetra
.43086 .20356 .43831 .21234 .45112 .20759 .44372 .19877 Mtetra
.44372 .19877 .45112 .20759 .46399 .20282 .45663 .19396 Mtetra
.45663 .19396 .46399 .20282 .47693 .19803 .4696 .18912 Mtetra
.4696 .18912 .47693 .19803 .48993 .19321 .48264 .18427 Mtetra
.48264 .18427 .48993 .19321 .50298 .18838 .49574 .17939 Mtetra
.49574 .17939 .50298 .18838 .5161 .18352 .5089 .17448 Mtetra
.5089 .17448 .5161 .18352 .52929 .17863 .52212 .16955 Mtetra
.52212 .16955 .52929 .17863 .54254 .17372 .53541 .1646 Mtetra
.53541 .1646 .54254 .17372 .55585 .16879 .54877 .15963 Mtetra
.54877 .15963 .55585 .16879 .56922 .16384 .56218 .15463 Mtetra
.56218 .15463 .56922 .16384 .58266 .15886 .57567 .1496 Mtetra
.57567 .1496 .58266 .15886 .59617 .15386 .58922 .14455 Mtetra
.58922 .14455 .59617 .15386 .60974 .14883 .60283 .13948 Mtetra
.60283 .13948 .60974 .14883 .62338 .14378 .61652 .13438 Mtetra
.61652 .13438 .62338 .14378 .63708 .1387 .63027 .12926 Mtetra
.63027 .12926 .63708 .1387 .65086 .1336 .64408 .12411 Mtetra
.64408 .12411 .65086 .1336 .6647 .12847 .65797 .11894 Mtetra
.65797 .11894 .6647 .12847 .6786 .12332 .67193 .11374 Mtetra
.67193 .11374 .6786 .12332 .69258 .11814 .68595 .10851 Mtetra
.68595 .10851 .69258 .11814 .70663 .11294 .70004 .10326 Mtetra
.70004 .10326 .70663 .11294 .72074 .10771 .71421 .09798 Mtetra
.71421 .09798 .72074 .10771 .73493 .10245 .72844 .09268 Mtetra
.72844 .09268 .73493 .10245 .74918 .09717 .74275 .08735 Mtetra
0 .335 .713 r
.09524 .33091 .1041 .33558 .11441 .33963 .1055 .33537 Mtetra
.519 0 0 r
.1055 .33537 .11441 .33963 .12434 .34752 .11553 .34253 Mtetra
.615 .059 0 r
.11553 .34253 .12434 .34752 .13393 .35934 .12544 .35163 Mtetra
.497 0 0 r
.12544 .35163 .13393 .35934 .14332 .37413 .13546 .36103 Mtetra
.048 .3 .789 r
.13546 .36103 .14332 .37413 .15281 .38965 .14587 .36843 Mtetra
.445 .424 .742 r
.14587 .36843 .15281 .38965 .16279 .4026 .15692 .37143 Mtetra
.573 .447 .671 r
.15692 .37143 .16279 .4026 .17359 .40949 .16875 .36839 Mtetra
.62 .453 .634 r
.16875 .36839 .17359 .40949 .18544 .40776 .18133 .35899 Mtetra
.642 .456 .616 r
.18133 .35899 .18544 .40776 .19831 .39677 .19447 .34438 Mtetra
.652 .459 .609 r
.19447 .34438 .19831 .39677 .21193 .37808 .20789 .32674 Mtetra
.657 .463 .611 r
.20789 .32674 .21193 .37808 .22593 .35482 .22133 .30849 Mtetra
.66 .472 .619 r
.22133 .30849 .22593 .35482 .23994 .33052 .23459 .29161 Mtetra
.663 .487 .636 r
.23459 .29161 .23994 .33052 .2537 .30809 .2476 .27722 Mtetra
.666 .51 .663 r
.2476 .27722 .2537 .30809 .26708 .2892 .26034 .2656 Mtetra
.67 .544 .702 r
.26034 .2656 .26708 .2892 .28009 .27431 .27288 .25644 Mtetra
.674 .588 .752 r
.27288 .25644 .28009 .27431 .2928 .26299 .2853 .24914 Mtetra
.675 .637 .804 r
.2853 .24914 .2928 .26299 .30533 .25439 .29766 .24307 Mtetra
.673 .679 .848 r
.29766 .24307 .30533 .25439 .31776 .24761 .31001 .23772 Mtetra
.669 .709 .878 r
.31001 .23772 .31776 .24761 .33016 .24191 .32239 .23275 Mtetra
.666 .726 .894 r
.32239 .23275 .33016 .24191 .34257 .23679 .33481 .22796 Mtetra
.665 .735 .902 r
.33481 .22796 .34257 .23679 .35501 .23194 .34729 .22323 Mtetra
.664 .739 .906 r
.34729 .22323 .35501 .23194 .36751 .2272 .35982 .21852 Mtetra
.664 .74 .907 r
.35982 .21852 .36751 .2272 .38006 .2225 .3724 .21379 Mtetra
.664 .741 .908 r
.3724 .21379 .38006 .2225 .39267 .21779 .38505 .20905 Mtetra
.38505 .20905 .39267 .21779 .40534 .21307 .39776 .20429 Mtetra
.39776 .20429 .40534 .21307 .41807 .20832 .41053 .19951 Mtetra
.41053 .19951 .41807 .20832 .43086 .20356 .42335 .1947 Mtetra
.42335 .1947 .43086 .20356 .44372 .19877 .43624 .18987 Mtetra
.43624 .18987 .44372 .19877 .45663 .19396 .4492 .18501 Mtetra
.4492 .18501 .45663 .19396 .4696 .18912 .46221 .18014 Mtetra
.46221 .18014 .4696 .18912 .48264 .18427 .47529 .17524 Mtetra
.47529 .17524 .48264 .18427 .49574 .17939 .48843 .17031 Mtetra
.48843 .17031 .49574 .17939 .5089 .17448 .50163 .16537 Mtetra
.50163 .16537 .5089 .17448 .52212 .16955 .51489 .16039 Mtetra
.51489 .16039 .52212 .16955 .53541 .1646 .52823 .1554 Mtetra
.52823 .1554 .53541 .1646 .54877 .15963 .54162 .15038 Mtetra
.54162 .15038 .54877 .15963 .56218 .15463 .55508 .14533 Mtetra
.55508 .14533 .56218 .15463 .57567 .1496 .56861 .14026 Mtetra
.56861 .14026 .57567 .1496 .58922 .14455 .5822 .13517 Mtetra
.5822 .13517 .58922 .14455 .60283 .13948 .59586 .13005 Mtetra
.59586 .13005 .60283 .13948 .61652 .13438 .60959 .12491 Mtetra
.60959 .12491 .61652 .13438 .63027 .12926 .62339 .11974 Mtetra
.62339 .11974 .63027 .12926 .64408 .12411 .63725 .11454 Mtetra
.63725 .11454 .64408 .12411 .65797 .11894 .65119 .10932 Mtetra
.65119 .10932 .65797 .11894 .67193 .11374 .66519 .10407 Mtetra
.66519 .10407 .67193 .11374 .68595 .10851 .67926 .0988 Mtetra
.67926 .0988 .68595 .10851 .70004 .10326 .6934 .0935 Mtetra
.6934 .0935 .70004 .10326 .71421 .09798 .70762 .08817 Mtetra
.70762 .08817 .71421 .09798 .72844 .09268 .7219 .08282 Mtetra
.7219 .08282 .72844 .09268 .74275 .08735 .73626 .07744 Mtetra
.08 .507 .9 r
.08655 .32428 .09524 .33091 .1055 .33537 .09699 .32749 Mtetra
.027 .433 .868 r
.09699 .32749 .1055 .33537 .11553 .34253 .10737 .33187 Mtetra
.178 .444 .873 r
.10737 .33187 .11553 .34253 .12544 .35163 .11786 .33632 Mtetra
.392 .466 .817 r
.11786 .33632 .12544 .35163 .13546 .36103 .12864 .33932 Mtetra
.523 .467 .736 r
.12864 .33932 .13546 .36103 .14587 .36843 .13988 .3394 Mtetra
.586 .464 .68 r
.13988 .3394 .14587 .36843 .15692 .37143 .15167 .33556 Mtetra
.618 .462 .649 r
.15167 .33556 .15692 .37143 .16875 .36839 .16398 .32766 Mtetra
.635 .463 .633 r
.16398 .32766 .16875 .36839 .18133 .35899 .17667 .3165 Mtetra
.644 .466 .628 r
.17667 .3165 .18133 .35899 .19447 .34438 .18958 .30349 Mtetra
.65 .473 .632 r
.18958 .30349 .19447 .34438 .20789 .32674 .2025 .29016 Mtetra
.655 .486 .643 r
.2025 .29016 .20789 .32674 .22133 .30849 .21532 .27775 Mtetra
.659 .505 .665 r
.21532 .27775 .22133 .30849 .23459 .29161 .22798 .26696 Mtetra
.664 .534 .697 r
.22798 .26696 .23459 .29161 .2476 .27722 .24048 .25794 Mtetra
.668 .573 .739 r
.24048 .25794 .2476 .27722 .26034 .2656 .25286 .25048 Mtetra
.672 .618 .787 r
.25286 .25048 .26034 .2656 .27288 .25644 .26518 .24419 Mtetra
.672 .662 .832 r
.26518 .24419 .27288 .25644 .2853 .24914 .27748 .23867 Mtetra
.67 .696 .866 r
.27748 .23867 .2853 .24914 .29766 .24307 .28979 .23359 Mtetra
.667 .719 .887 r
.28979 .23359 .29766 .24307 .31001 .23772 .30214 .22873 Mtetra
.665 .731 .899 r
.30214 .22873 .31001 .23772 .32239 .23275 .31453 .22398 Mtetra
.664 .737 .904 r
.31453 .22398 .32239 .23275 .33481 .22796 .32698 .21925 Mtetra
.664 .74 .906 r
.32698 .21925 .33481 .22796 .34729 .22323 .33949 .21452 Mtetra
.664 .741 .907 r
.33949 .21452 .34729 .22323 .35982 .21852 .35205 .20978 Mtetra
.664 .741 .908 r
.35205 .20978 .35982 .21852 .3724 .21379 .36468 .20503 Mtetra
.36468 .20503 .3724 .21379 .38505 .20905 .37736 .20024 Mtetra
.37736 .20024 .38505 .20905 .39776 .20429 .39011 .19544 Mtetra
.39011 .19544 .39776 .20429 .41053 .19951 .40291 .19061 Mtetra
.40291 .19061 .41053 .19951 .42335 .1947 .41578 .18576 Mtetra
.41578 .18576 .42335 .1947 .43624 .18987 .42871 .18089 Mtetra
.42871 .18089 .43624 .18987 .4492 .18501 .4417 .17599 Mtetra
.4417 .17599 .4492 .18501 .46221 .18014 .45475 .17107 Mtetra
.45475 .17107 .46221 .18014 .47529 .17524 .46787 .16613 Mtetra
.46787 .16613 .47529 .17524 .48843 .17031 .48105 .16116 Mtetra
.48105 .16116 .48843 .17031 .50163 .16537 .49429 .15617 Mtetra
.49429 .15617 .50163 .16537 .51489 .16039 .5076 .15115 Mtetra
.5076 .15115 .51489 .16039 .52823 .1554 .52097 .14611 Mtetra
.52097 .14611 .52823 .1554 .54162 .15038 .53441 .14104 Mtetra
.53441 .14104 .54162 .15038 .55508 .14533 .54792 .13595 Mtetra
.54792 .13595 .55508 .14533 .56861 .14026 .56149 .13084 Mtetra
.56149 .13084 .56861 .14026 .5822 .13517 .57513 .1257 Mtetra
.57513 .1257 .5822 .13517 .59586 .13005 .58883 .12053 Mtetra
.58883 .12053 .59586 .13005 .60959 .12491 .60261 .11534 Mtetra
.60261 .11534 .60959 .12491 .62339 .11974 .61645 .11012 Mtetra
.61645 .11012 .62339 .11974 .63725 .11454 .63036 .10488 Mtetra
.63036 .10488 .63725 .11454 .65119 .10932 .64434 .09961 Mtetra
.64434 .09961 .65119 .10932 .66519 .10407 .65839 .09431 Mtetra
.65839 .09431 .66519 .10407 .67926 .0988 .67251 .08899 Mtetra
.67251 .08899 .67926 .0988 .6934 .0935 .6867 .08364 Mtetra
.6867 .08364 .6934 .0935 .70762 .08817 .70096 .07827 Mtetra
.70096 .07827 .70762 .08817 .7219 .08282 .71529 .07286 Mtetra
.71529 .07286 .7219 .08282 .73626 .07744 .7297 .06743 Mtetra
.411 .613 .932 r
.07814 .31509 .08655 .32428 .09699 .32749 .0889 .31598 Mtetra
.452 .573 .885 r
.0889 .31598 .09699 .32749 .10737 .33187 .09974 .31682 Mtetra
.517 .538 .817 r
.09974 .31682 .10737 .33187 .11786 .33632 .1108 .31672 Mtetra
.568 .512 .752 r
.1108 .31672 .11786 .33632 .12864 .33932 .12218 .31482 Mtetra
.602 .496 .706 r
.12218 .31482 .12864 .33932 .13988 .3394 .13391 .31055 Mtetra
.622 .488 .678 r
.13391 .31055 .13988 .3394 .15167 .33556 .14599 .30389 Mtetra
.635 .486 .663 r
.14599 .30389 .15167 .33556 .16398 .32766 .15833 .29533 Mtetra
.643 .489 .66 r
.15833 .29533 .16398 .32766 .17667 .3165 .17081 .28572 Mtetra
.649 .498 .665 r
.17081 .28572 .17667 .3165 .18958 .30349 .18332 .27596 Mtetra
.654 .515 .681 r
.18332 .27596 .18958 .30349 .2025 .29016 .19579 .26678 Mtetra
.659 .539 .706 r
.19579 .26678 .2025 .29016 .21532 .27775 .20817 .25856 Mtetra
.665 .572 .741 r
.20817 .25856 .21532 .27775 .22798 .26696 .22048 .2514 Mtetra
.669 .611 .782 r
.22048 .2514 .22798 .26696 .24048 .25794 .23273 .24514 Mtetra
.67 .652 .823 r
.23273 .24514 .24048 .25794 .25286 .25048 .24496 .23956 Mtetra
.67 .687 .857 r
.24496 .23956 .25286 .25048 .26518 .24419 .25721 .23441 Mtetra
.668 .712 .881 r
.25721 .23441 .26518 .24419 .27748 .23867 .26948 .2295 Mtetra
.666 .727 .895 r
.26948 .2295 .27748 .23867 .28979 .23359 .2818 .22472 Mtetra
.664 .735 .902 r
.2818 .22472 .28979 .23359 .30214 .22873 .29417 .21998 Mtetra
.664 .739 .906 r
.29417 .21998 .30214 .22873 .31453 .22398 .30659 .21526 Mtetra
.664 .74 .907 r
.30659 .21526 .31453 .22398 .32698 .21925 .31908 .21052 Mtetra
.664 .741 .908 r
.31908 .21052 .32698 .21925 .33949 .21452 .33162 .20576 Mtetra
.33162 .20576 .33949 .21452 .35205 .20978 .34422 .20098 Mtetra
.34422 .20098 .35205 .20978 .36468 .20503 .35688 .19618 Mtetra
.35688 .19618 .36468 .20503 .37736 .20024 .3696 .19136 Mtetra
.3696 .19136 .37736 .20024 .39011 .19544 .38239 .18651 Mtetra
.38239 .18651 .39011 .19544 .40291 .19061 .39523 .18164 Mtetra
.39523 .18164 .40291 .19061 .41578 .18576 .40813 .17675 Mtetra
.40813 .17675 .41578 .18576 .42871 .18089 .4211 .17183 Mtetra
.4211 .17183 .42871 .18089 .4417 .17599 .43413 .16689 Mtetra
.43413 .16689 .4417 .17599 .45475 .17107 .44723 .16193 Mtetra
.44723 .16193 .45475 .17107 .46787 .16613 .46038 .15694 Mtetra
.46038 .15694 .46787 .16613 .48105 .16116 .4736 .15192 Mtetra
.4736 .15192 .48105 .16116 .49429 .15617 .48689 .14689 Mtetra
.48689 .14689 .49429 .15617 .5076 .15115 .50024 .14183 Mtetra
.50024 .14183 .5076 .15115 .52097 .14611 .51366 .13674 Mtetra
.51366 .13674 .52097 .14611 .53441 .14104 .52714 .13163 Mtetra
.52714 .13163 .53441 .14104 .54792 .13595 .54069 .12649 Mtetra
.54069 .12649 .54792 .13595 .56149 .13084 .5543 .12133 Mtetra
.5543 .12133 .56149 .13084 .57513 .1257 .56798 .11614 Mtetra
.56798 .11614 .57513 .1257 .58883 .12053 .58173 .11093 Mtetra
.58173 .11093 .58883 .12053 .60261 .11534 .59555 .10569 Mtetra
.59555 .10569 .60261 .11534 .61645 .11012 .60944 .10042 Mtetra
.60944 .10042 .61645 .11012 .63036 .10488 .6234 .09513 Mtetra
.6234 .09513 .63036 .10488 .64434 .09961 .63742 .08981 Mtetra
.63742 .08981 .64434 .09961 .65839 .09431 .65152 .08447 Mtetra
.65152 .08447 .65839 .09431 .67251 .08899 .66569 .0791 Mtetra
.66569 .0791 .67251 .08899 .6867 .08364 .67993 .0737 Mtetra
.67993 .0737 .6867 .08364 .70096 .07827 .69424 .06827 Mtetra
.69424 .06827 .70096 .07827 .71529 .07286 .70863 .06282 Mtetra
.70863 .06282 .71529 .07286 .7297 .06743 .72309 .05734 Mtetra
.559 .63 .879 r
.06994 .30393 .07814 .31509 .0889 .31598 .08104 .30241 Mtetra
.58 .594 .831 r
.08104 .30241 .0889 .31598 .09974 .31682 .09228 .30031 Mtetra
.602 .563 .783 r
.09228 .30031 .09974 .31682 .1108 .31672 .10373 .29718 Mtetra
.619 .542 .745 r
.10373 .29718 .1108 .31672 .12218 .31482 .11541 .29273 Mtetra
.632 .53 .72 r
.11541 .29273 .12218 .31482 .13391 .31055 .12732 .28697 Mtetra
.641 .526 .707 r
.12732 .28697 .13391 .31055 .14599 .30389 .13939 .28018 Mtetra
.647 .529 .705 r
.13939 .28018 .14599 .30389 .15833 .29533 .15156 .27283 Mtetra
.653 .54 .714 r
.15156 .27283 .15833 .29533 .17081 .28572 .16378 .26542 Mtetra
.658 .559 .731 r
.16378 .26542 .17081 .28572 .18332 .27596 .17598 .25835 Mtetra
.663 .585 .758 r
.17598 .25835 .18332 .27596 .19579 .26678 .18817 .2518 Mtetra
.667 .618 .79 r
.18817 .2518 .19579 .26678 .20817 .25856 .20033 .24582 Mtetra
.669 .652 .825 r
.20033 .24582 .20817 .25856 .22048 .2514 .21248 .24032 Mtetra
.669 .683 .855 r
.21248 .24032 .22048 .2514 .23273 .24514 .22465 .23518 Mtetra
.667 .707 .878 r
.22465 .23518 .23273 .24514 .24496 .23956 .23685 .23026 Mtetra
.666 .723 .892 r
.23685 .23026 .24496 .23956 .25721 .23441 .24909 .22546 Mtetra
.665 .733 .9 r
.24909 .22546 .25721 .23441 .26948 .2295 .26138 .22072 Mtetra
.664 .738 .905 r
.26138 .22072 .26948 .2295 .2818 .22472 .27372 .21599 Mtetra
.664 .74 .907 r
.27372 .21599 .2818 .22472 .29417 .21998 .28613 .21125 Mtetra
.664 .741 .907 r
.28613 .21125 .29417 .21998 .30659 .21526 .29858 .20649 Mtetra
.664 .741 .908 r
.29858 .20649 .30659 .21526 .31908 .21052 .3111 .20172 Mtetra
.3111 .20172 .31908 .21052 .33162 .20576 .32368 .19692 Mtetra
.32368 .19692 .33162 .20576 .34422 .20098 .33632 .1921 Mtetra
.33632 .1921 .34422 .20098 .35688 .19618 .34902 .18726 Mtetra
.34902 .18726 .35688 .19618 .3696 .19136 .36178 .18239 Mtetra
.36178 .18239 .3696 .19136 .38239 .18651 .3746 .1775 Mtetra
.3746 .1775 .38239 .18651 .39523 .18164 .38748 .17259 Mtetra
.38748 .17259 .39523 .18164 .40813 .17675 .40042 .16765 Mtetra
.40042 .16765 .40813 .17675 .4211 .17183 .41343 .16269 Mtetra
.41343 .16269 .4211 .17183 .43413 .16689 .4265 .15771 Mtetra
.4265 .15771 .43413 .16689 .44723 .16193 .43963 .1527 Mtetra
.43963 .1527 .44723 .16193 .46038 .15694 .45283 .14766 Mtetra
.45283 .14766 .46038 .15694 .4736 .15192 .46609 .14261 Mtetra
.46609 .14261 .4736 .15192 .48689 .14689 .47942 .13752 Mtetra
.47942 .13752 .48689 .14689 .50024 .14183 .49281 .13242 Mtetra
.49281 .13242 .50024 .14183 .51366 .13674 .50627 .12728 Mtetra
.50627 .12728 .51366 .13674 .52714 .13163 .5198 .12212 Mtetra
.5198 .12212 .52714 .13163 .54069 .12649 .53339 .11694 Mtetra
.53339 .11694 .54069 .12649 .5543 .12133 .54705 .11173 Mtetra
.54705 .11173 .5543 .12133 .56798 .11614 .56078 .1065 Mtetra
.56078 .1065 .56798 .11614 .58173 .11093 .57457 .10123 Mtetra
.57457 .10123 .58173 .11093 .59555 .10569 .58844 .09595 Mtetra
.58844 .09595 .59555 .10569 .60944 .10042 .60237 .09063 Mtetra
.60237 .09063 .60944 .10042 .6234 .09513 .61637 .08529 Mtetra
.61637 .08529 .6234 .09513 .63742 .08981 .63045 .07992 Mtetra
.63045 .07992 .63742 .08981 .65152 .08447 .64459 .07453 Mtetra
.64459 .07453 .65152 .08447 .66569 .0791 .65881 .06911 Mtetra
.65881 .06911 .66569 .0791 .67993 .0737 .6731 .06366 Mtetra
.6731 .06366 .67993 .0737 .69424 .06827 .68746 .05818 Mtetra
.68746 .05818 .69424 .06827 .70863 .06282 .7019 .05267 Mtetra
.7019 .05267 .70863 .06282 .72309 .05734 .71641 .04714 Mtetra
.618 .642 .852 r
.06178 .2921 .06994 .30393 .08104 .30241 .07313 .28883 Mtetra
.628 .617 .82 r
.07313 .28883 .08104 .30241 .09228 .30031 .08461 .28501 Mtetra
.637 .596 .792 r
.08461 .28501 .09228 .30031 .10373 .29718 .09625 .2805 Mtetra
.644 .584 .772 r
.09625 .2805 .10373 .29718 .11541 .29273 .10803 .27532 Mtetra
.65 .579 .762 r
.10803 .27532 .11541 .29273 .12732 .28697 .11992 .26962 Mtetra
.655 .583 .762 r
.11992 .26962 .12732 .28697 .13939 .28018 .13189 .26364 Mtetra
.659 .594 .771 r
.13189 .26364 .13939 .28018 .15156 .27283 .1439 .25764 Mtetra
.663 .613 .788 r
.1439 .25764 .15156 .27283 .16378 .26542 .15593 .25181 Mtetra
.666 .636 .811 r
.15593 .25181 .16378 .26542 .17598 .25835 .16798 .24624 Mtetra
.667 .663 .836 r
.16798 .24624 .17598 .25835 .18817 .2518 .18004 .24094 Mtetra
.668 .687 .859 r
.18004 .24094 .18817 .2518 .20033 .24582 .19213 .23589 Mtetra
.667 .708 .878 r
.19213 .23589 .20033 .24582 .21248 .24032 .20424 .23099 Mtetra
.666 .722 .891 r
.20424 .23099 .21248 .24032 .22465 .23518 .21641 .2262 Mtetra
.665 .732 .899 r
.21641 .2262 .22465 .23518 .23685 .23026 .22862 .22145 Mtetra
.664 .737 .904 r
.22862 .22145 .23685 .23026 .24909 .22546 .24088 .21672 Mtetra
.664 .739 .906 r
.24088 .21672 .24909 .22546 .26138 .22072 .2532 .21198 Mtetra
.664 .74 .907 r
.2532 .21198 .26138 .22072 .27372 .21599 .26558 .20723 Mtetra
.664 .741 .908 r
.26558 .20723 .27372 .21599 .28613 .21125 .27801 .20245 Mtetra
.27801 .20245 .28613 .21125 .29858 .20649 .29051 .19766 Mtetra
.29051 .19766 .29858 .20649 .3111 .20172 .30306 .19284 Mtetra
.30306 .19284 .3111 .20172 .32368 .19692 .31567 .188 Mtetra
.31567 .188 .32368 .19692 .33632 .1921 .32835 .18314 Mtetra
.32835 .18314 .33632 .1921 .34902 .18726 .34108 .17826 Mtetra
.34108 .17826 .34902 .18726 .36178 .18239 .35388 .17335 Mtetra
.35388 .17335 .36178 .18239 .3746 .1775 .36674 .16841 Mtetra
.36674 .16841 .3746 .1775 .38748 .17259 .37966 .16346 Mtetra
.37966 .16346 .38748 .17259 .40042 .16765 .39264 .15847 Mtetra
.39264 .15847 .40042 .16765 .41343 .16269 .40569 .15347 Mtetra
.40569 .15347 .41343 .16269 .4265 .15771 .4188 .14844 Mtetra
.4188 .14844 .4265 .15771 .43963 .1527 .43197 .14339 Mtetra
.43197 .14339 .43963 .1527 .45283 .14766 .44521 .13831 Mtetra
.44521 .13831 .45283 .14766 .46609 .14261 .45852 .1332 Mtetra
.45852 .1332 .46609 .14261 .47942 .13752 .47188 .12807 Mtetra
.47188 .12807 .47942 .13752 .49281 .13242 .48532 .12292 Mtetra
.48532 .12292 .49281 .13242 .50627 .12728 .49882 .11774 Mtetra
.49882 .11774 .50627 .12728 .5198 .12212 .51239 .11253 Mtetra
.51239 .11253 .5198 .12212 .53339 .11694 .52603 .1073 Mtetra
.52603 .1073 .53339 .11694 .54705 .11173 .53973 .10205 Mtetra
.53973 .10205 .54705 .11173 .56078 .1065 .5535 .09676 Mtetra
.5535 .09676 .56078 .1065 .57457 .10123 .56734 .09145 Mtetra
.56734 .09145 .57457 .10123 .58844 .09595 .58125 .08612 Mtetra
.58125 .08612 .58844 .09595 .60237 .09063 .59523 .08075 Mtetra
.59523 .08075 .60237 .09063 .61637 .08529 .60929 .07536 Mtetra
.60929 .07536 .61637 .08529 .63045 .07992 .62341 .06994 Mtetra
.62341 .06994 .63045 .07992 .64459 .07453 .6376 .0645 Mtetra
.6376 .0645 .64459 .07453 .65881 .06911 .65187 .05902 Mtetra
.65187 .05902 .65881 .06911 .6731 .06366 .66621 .05352 Mtetra
.66621 .05352 .6731 .06366 .68746 .05818 .68062 .04799 Mtetra
.68062 .04799 .68746 .05818 .7019 .05267 .6951 .04244 Mtetra
.6951 .04244 .7019 .05267 .71641 .04714 .70966 .03685 Mtetra
.645 .664 .854 r
.05348 .28077 .06178 .2921 .07313 .28883 .06497 .27659 Mtetra
.65 .649 .836 r
.06497 .27659 .07313 .28883 .08461 .28501 .07657 .27207 Mtetra
.654 .64 .823 r
.07657 .27207 .08461 .28501 .09625 .2805 .08826 .26723 Mtetra
.658 .637 .817 r
.08826 .26723 .09625 .2805 .10803 .27532 .10003 .26214 Mtetra
.661 .64 .818 r
.10003 .26214 .10803 .27532 .11992 .26962 .11187 .25691 Mtetra
.664 .649 .826 r
.11187 .25691 .11992 .26962 .13189 .26364 .12376 .25167 Mtetra
.665 .664 .838 r
.12376 .25167 .13189 .26364 .1439 .25764 .13568 .24651 Mtetra
.666 .681 .854 r
.13568 .24651 .1439 .25764 .15593 .25181 .14764 .24145 Mtetra
.667 .698 .869 r
.14764 .24145 .15593 .25181 .16798 .24624 .15963 .23652 Mtetra
.666 .712 .883 r
.15963 .23652 .16798 .24624 .18004 .24094 .17167 .23169 Mtetra
.665 .724 .893 r
.17167 .23169 .18004 .24094 .19213 .23589 .18375 .22691 Mtetra
.664 .732 .9 r
.18375 .22691 .19213 .23589 .20424 .23099 .19587 .22217 Mtetra
.664 .736 .904 r
.19587 .22217 .20424 .23099 .21641 .2262 .20806 .21744 Mtetra
.664 .739 .906 r
.20806 .21744 .21641 .2262 .22862 .22145 .22029 .21271 Mtetra
.664 .74 .907 r
.22029 .21271 .22862 .22145 .24088 .21672 .23259 .20796 Mtetra
.664 .741 .908 r
.23259 .20796 .24088 .21672 .2532 .21198 .24494 .20319 Mtetra
.24494 .20319 .2532 .21198 .26558 .20723 .25735 .1984 Mtetra
.25735 .1984 .26558 .20723 .27801 .20245 .26982 .19359 Mtetra
.26982 .19359 .27801 .20245 .29051 .19766 .28235 .18875 Mtetra
.28235 .18875 .29051 .19766 .30306 .19284 .29494 .18389 Mtetra
.29494 .18389 .30306 .19284 .31567 .188 .30759 .17901 Mtetra
.30759 .17901 .31567 .188 .32835 .18314 .32031 .1741 Mtetra
.32031 .1741 .32835 .18314 .34108 .17826 .33308 .16917 Mtetra
.33308 .16917 .34108 .17826 .35388 .17335 .34591 .16422 Mtetra
.34591 .16422 .35388 .17335 .36674 .16841 .35881 .15924 Mtetra
.35881 .15924 .36674 .16841 .37966 .16346 .37177 .15424 Mtetra
.37177 .15424 .37966 .16346 .39264 .15847 .38479 .14922 Mtetra
.38479 .14922 .39264 .15847 .40569 .15347 .39788 .14417 Mtetra
.39788 .14417 .40569 .15347 .4188 .14844 .41103 .13909 Mtetra
.41103 .13909 .4188 .14844 .43197 .14339 .42424 .13399 Mtetra
.42424 .13399 .43197 .14339 .44521 .13831 .43752 .12886 Mtetra
.43752 .12886 .44521 .13831 .45852 .1332 .45087 .12371 Mtetra
.45087 .12371 .45852 .1332 .47188 .12807 .46428 .11854 Mtetra
.46428 .11854 .47188 .12807 .48532 .12292 .47776 .11334 Mtetra
.47776 .11334 .48532 .12292 .49882 .11774 .4913 .10811 Mtetra
.4913 .10811 .49882 .11774 .51239 .11253 .50491 .10286 Mtetra
.50491 .10286 .51239 .11253 .52603 .1073 .51859 .09758 Mtetra
.51859 .09758 .52603 .1073 .53973 .10205 .53234 .09227 Mtetra
.53234 .09227 .53973 .10205 .5535 .09676 .54616 .08694 Mtetra
.54616 .08694 .5535 .09676 .56734 .09145 .56005 .08158 Mtetra
.56005 .08158 .56734 .09145 .58125 .08612 .574 .07619 Mtetra
.574 .07619 .58125 .08612 .59523 .08075 .58803 .07078 Mtetra
.58803 .07078 .59523 .08075 .60929 .07536 .60213 .06534 Mtetra
.60213 .06534 .60929 .07536 .62341 .06994 .6163 .05987 Mtetra
.6163 .05987 .62341 .06994 .6376 .0645 .63054 .05437 Mtetra
.63054 .05437 .6376 .0645 .65187 .05902 .64486 .04885 Mtetra
.64486 .04885 .65187 .05902 .66621 .05352 .65925 .04329 Mtetra
.65925 .04329 .66621 .05352 .68062 .04799 .67371 .03771 Mtetra
.67371 .03771 .68062 .04799 .6951 .04244 .68825 .0321 Mtetra
.68825 .0321 .6951 .04244 .70966 .03685 .70286 .02646 Mtetra
.658 .69 .869 r
.04496 .27046 .05348 .28077 .06497 .27659 .05652 .26594 Mtetra
.66 .685 .862 r
.05652 .26594 .06497 .27659 .07657 .27207 .06815 .26127 Mtetra
.662 .683 .86 r
.06815 .26127 .07657 .27207 .08826 .26723 .07985 .25649 Mtetra
.664 .686 .861 r
.07985 .25649 .08826 .26723 .10003 .26214 .09161 .25163 Mtetra
.665 .692 .866 r
.09161 .25163 .10003 .26214 .11187 .25691 .10341 .24677 Mtetra
.665 .701 .873 r
.10341 .24677 .11187 .25691 .12376 .25167 .11527 .24192 Mtetra
.666 .711 .881 r
.11527 .24192 .12376 .25167 .13568 .24651 .12717 .23712 Mtetra
.665 .72 .89 r
.12717 .23712 .13568 .24651 .14764 .24145 .13912 .23235 Mtetra
.665 .727 .896 r
.13912 .23235 .14764 .24145 .15963 .23652 .15111 .22761 Mtetra
.664 .733 .901 r
.15111 .22761 .15963 .23652 .17167 .23169 .16316 .22289 Mtetra
.664 .737 .904 r
.16316 .22289 .17167 .23169 .18375 .22691 .17526 .21817 Mtetra
.664 .739 .906 r
.17526 .21817 .18375 .22691 .19587 .22217 .18741 .21344 Mtetra
.664 .74 .907 r
.18741 .21344 .19587 .22217 .20806 .21744 .19963 .20869 Mtetra
.664 .741 .908 r
.19963 .20869 .20806 .21744 .22029 .21271 .2119 .20392 Mtetra
.2119 .20392 .22029 .21271 .23259 .20796 .22423 .19914 Mtetra
.22423 .19914 .23259 .20796 .24494 .20319 .23661 .19433 Mtetra
.23661 .19433 .24494 .20319 .25735 .1984 .24906 .1895 Mtetra
.24906 .1895 .25735 .1984 .26982 .19359 .26157 .18464 Mtetra
.26157 .18464 .26982 .19359 .28235 .18875 .27413 .17976 Mtetra
.27413 .17976 .28235 .18875 .29494 .18389 .28676 .17486 Mtetra
.28676 .17486 .29494 .18389 .30759 .17901 .29944 .16993 Mtetra
.29944 .16993 .30759 .17901 .32031 .1741 .31219 .16498 Mtetra
.31219 .16498 .32031 .1741 .33308 .16917 .325 .16001 Mtetra
.325 .16001 .33308 .16917 .34591 .16422 .33788 .15501 Mtetra
.33788 .15501 .34591 .16422 .35881 .15924 .35081 .14999 Mtetra
.35081 .14999 .35881 .15924 .37177 .15424 .36381 .14494 Mtetra
.36381 .14494 .37177 .15424 .38479 .14922 .37687 .13987 Mtetra
.37687 .13987 .38479 .14922 .39788 .14417 .39 .13478 Mtetra
.39 .13478 .39788 .14417 .41103 .13909 .40319 .12965 Mtetra
.40319 .12965 .41103 .13909 .42424 .13399 .41644 .12451 Mtetra
.41644 .12451 .42424 .13399 .43752 .12886 .42976 .11934 Mtetra
.42976 .11934 .43752 .12886 .45087 .12371 .44315 .11414 Mtetra
.44315 .11414 .45087 .12371 .46428 .11854 .4566 .10892 Mtetra
.4566 .10892 .46428 .11854 .47776 .11334 .47013 .10367 Mtetra
.47013 .10367 .47776 .11334 .4913 .10811 .48371 .09839 Mtetra
.48371 .09839 .4913 .10811 .50491 .10286 .49737 .09309 Mtetra
.49737 .09309 .50491 .10286 .51859 .09758 .51109 .08776 Mtetra
.51109 .08776 .51859 .09758 .53234 .09227 .52489 .0824 Mtetra
.52489 .0824 .53234 .09227 .54616 .08694 .53875 .07702 Mtetra
.53875 .07702 .54616 .08694 .56005 .08158 .55268 .07161 Mtetra
.55268 .07161 .56005 .08158 .574 .07619 .56669 .06618 Mtetra
.56669 .06618 .574 .07619 .58803 .07078 .58076 .06071 Mtetra
.58076 .06071 .58803 .07078 .60213 .06534 .59491 .05522 Mtetra
.59491 .05522 .60213 .06534 .6163 .05987 .60913 .0497 Mtetra
.60913 .0497 .6163 .05987 .63054 .05437 .62342 .04415 Mtetra
.62342 .04415 .63054 .05437 .64486 .04885 .63778 .03857 Mtetra
.63778 .03857 .64486 .04885 .65925 .04329 .65222 .03297 Mtetra
.65222 .03297 .65925 .04329 .67371 .03771 .66673 .02733 Mtetra
.66673 .02733 .67371 .03771 .68825 .0321 .68132 .02167 Mtetra
.68132 .02167 .68825 .0321 .70286 .02646 .69599 .01598 Mtetra
.662 .714 .886 r
.03622 .26105 .04496 .27046 .05652 .26594 .04781 .25646 Mtetra
.663 .713 .885 r
.04781 .25646 .05652 .26594 .06815 .26127 .05946 .25181 Mtetra
.664 .715 .886 r
.05946 .25181 .06815 .26127 .07985 .25649 .07117 .24713 Mtetra
.664 .718 .889 r
.07117 .24713 .07985 .25649 .09161 .25163 .08292 .24242 Mtetra
.665 .723 .892 r
.08292 .24242 .09161 .25163 .10341 .24677 .09473 .23771 Mtetra
.664 .727 .896 r
.09473 .23771 .10341 .24677 .11527 .24192 .10659 .23301 Mtetra
.664 .732 .9 r
.10659 .23301 .11527 .24192 .12717 .23712 .1185 .22831 Mtetra
.664 .735 .903 r
.1185 .22831 .12717 .23712 .13912 .23235 .13047 .2236 Mtetra
.664 .738 .905 r
.13047 .2236 .13912 .23235 .15111 .22761 .14249 .21889 Mtetra
.664 .739 .906 r
.14249 .21889 .15111 .22761 .16316 .22289 .15456 .21416 Mtetra
.664 .74 .907 r
.15456 .21416 .16316 .22289 .17526 .21817 .16669 .20942 Mtetra
.664 .741 .908 r
.16669 .20942 .17526 .21817 .18741 .21344 .17888 .20466 Mtetra
.17888 .20466 .18741 .21344 .19963 .20869 .19112 .19988 Mtetra
.19112 .19988 .19963 .20869 .2119 .20392 .20343 .19507 Mtetra
.20343 .19507 .2119 .20392 .22423 .19914 .21579 .19024 Mtetra
.21579 .19024 .22423 .19914 .23661 .19433 .22821 .18539 Mtetra
.22821 .18539 .23661 .19433 .24906 .1895 .24069 .18051 Mtetra
.24069 .18051 .24906 .1895 .26157 .18464 .25323 .17561 Mtetra
.25323 .17561 .26157 .18464 .27413 .17976 .26583 .17069 Mtetra
.26583 .17069 .27413 .17976 .28676 .17486 .2785 .16575 Mtetra
.2785 .16575 .28676 .17486 .29944 .16993 .29122 .16078 Mtetra
.29122 .16078 .29944 .16993 .31219 .16498 .30401 .15578 Mtetra
.30401 .15578 .31219 .16498 .325 .16001 .31685 .15076 Mtetra
.31685 .15076 .325 .16001 .33788 .15501 .32977 .14572 Mtetra
.32977 .14572 .33788 .15501 .35081 .14999 .34274 .14065 Mtetra
.34274 .14065 .35081 .14999 .36381 .14494 .35578 .13556 Mtetra
.35578 .13556 .36381 .14494 .37687 .13987 .36888 .13044 Mtetra
.36888 .13044 .37687 .13987 .39 .13478 .38204 .1253 Mtetra
.38204 .1253 .39 .13478 .40319 .12965 .39527 .12013 Mtetra
.39527 .12013 .40319 .12965 .41644 .12451 .40857 .11494 Mtetra
.40857 .11494 .41644 .12451 .42976 .11934 .42193 .10972 Mtetra
.42193 .10972 .42976 .11934 .44315 .11414 .43536 .10448 Mtetra
.43536 .10448 .44315 .11414 .4566 .10892 .44886 .0992 Mtetra
.44886 .0992 .4566 .10892 .47013 .10367 .46242 .09391 Mtetra
.46242 .09391 .47013 .10367 .48371 .09839 .47605 .08858 Mtetra
.47605 .08858 .48371 .09839 .49737 .09309 .48975 .08323 Mtetra
.48975 .08323 .49737 .09309 .51109 .08776 .50352 .07785 Mtetra
.50352 .07785 .51109 .08776 .52489 .0824 .51736 .07245 Mtetra
.51736 .07245 .52489 .0824 .53875 .07702 .53127 .06701 Mtetra
.53127 .06701 .53875 .07702 .55268 .07161 .54525 .06155 Mtetra
.54525 .06155 .55268 .07161 .56669 .06618 .5593 .05607 Mtetra
.5593 .05607 .56669 .06618 .58076 .06071 .57342 .05055 Mtetra
.57342 .05055 .58076 .06071 .59491 .05522 .58762 .04501 Mtetra
.58762 .04501 .59491 .05522 .60913 .0497 .60188 .03943 Mtetra
.60188 .03943 .60913 .0497 .62342 .04415 .61623 .03383 Mtetra
.61623 .03383 .62342 .04415 .63778 .03857 .63064 .0282 Mtetra
.63064 .0282 .63778 .03857 .65222 .03297 .64513 .02254 Mtetra
.64513 .02254 .65222 .03297 .66673 .02733 .65969 .01685 Mtetra
.65969 .01685 .66673 .02733 .68132 .02167 .67433 .01113 Mtetra
.67433 .01113 .68132 .02167 .69599 .01598 .68905 .00539 Mtetra
0 g
.68874 0 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.68874 0 m
.03716 .25514 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 0.522676 0.477324 0.97619 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.49505 0.5 0.49505 [
[ 0 0 -0.125 0 ]
[ 0 0 -0.125 0 ]
[ 0 1 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
0 0 m
1 0 L
s
0 0 m
0 1 L
s
0 1 m
1 1 L
s
1 0 m
1 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
1 .5 0 r
.015 w
.03175 .1355 Mdot
.03435 .12523 Mdot
.11137 .12765 Mdot
.14107 .18841 Mdot
.16218 .24538 Mdot
.17294 .21053 Mdot
.18267 .18577 Mdot
.18434 .1304 Mdot
.18553 .30956 Mdot
.20401 .239 Mdot
.21247 .27571 Mdot
.21687 .20845 Mdot
.22376 .2799 Mdot
.22832 .27485 Mdot
.29063 .20974 Mdot
.29686 .25079 Mdot
.30487 .22936 Mdot
.30683 .34623 Mdot
.32055 .20902 Mdot
.32574 .21979 Mdot
.34472 .28521 Mdot
.35998 .36393 Mdot
.36335 .24976 Mdot
.3794 .36608 Mdot
.42386 .66992 Mdot
.44391 .74519 Mdot
.45059 .34198 Mdot
.47208 .67586 Mdot
.47436 .71381 Mdot
.49778 .59825 Mdot
.50874 .91643 Mdot
.51516 .76219 Mdot
.53655 .61374 Mdot
.56563 .75219 Mdot
.59189 .65665 Mdot
.59581 .61604 Mdot
.59923 .6556 Mdot
.60292 .68499 Mdot
.62656 .67779 Mdot
.63555 .72451 Mdot
.63919 .652 Mdot
.64169 .6004 Mdot
.64246 .58611 Mdot
.64496 .54267 Mdot
.64608 .77288 Mdot
.65077 .64308 Mdot
.66065 .57816 Mdot
.67474 .59169 Mdot
.69296 .563 Mdot
.72815 .65902 Mdot
.73169 .58879 Mdot
.74669 .61318 Mdot
.74821 .65474 Mdot
.75963 .63781 Mdot
.79673 .57809 Mdot
.80925 .55852 Mdot
.81525 .58444 Mdot
.83417 .62985 Mdot
.83598 .55526 Mdot
.91595 .49319 Mdot
0 0 1 r
.005 w
.16128 .17044 m
.18734 .17269 L
.21339 .17909 L
.2345 .18734 L
.23945 .19126 L
.2655 .20415 L
.27874 .21339 L
.29156 .22295 L
.31204 .23945 L
.31761 .24532 L
.33549 .2655 L
.34367 .28341 L
.34499 .29156 L
.34367 .29798 L
.31761 .3104 L
.29156 .30711 L
.2655 .30014 L
.24507 .29156 L
.23945 .28747 L
.21339 .27402 L
.20155 .2655 L
.18734 .25472 L
.16884 .23945 L
.16128 .2313 L
.14618 .21339 L
.13806 .18734 L
.16128 .17044 L
s
.65633 .57701 m
.68239 .56842 L
.70844 .56313 L
.7345 .56168 L
.76055 .5752 L
.76359 .57817 L
.76859 .60422 L
.76055 .62333 L
.75627 .63028 L
.7345 .65485 L
.73298 .65633 L
.70844 .6775 L
.69922 .68239 L
.68239 .69294 L
.65633 .70579 L
.64983 .70844 L
.63028 .71539 L
.60422 .72268 L
.57817 .72651 L
.55211 .7214 L
.53145 .70844 L
.52926 .68239 L
.54239 .65633 L
.55211 .63983 L
.56625 .63028 L
.57817 .6193 L
.60119 .60422 L
.60422 .60227 L
.63028 .58726 L
.65315 .57817 L
.65633 .57701 L
s
0 g
.03 w
.24141 .24033 Mdot
.64872 .64417 Mdot
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.522676 0.522676 0.97619 0.97619 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.49505 0.5 0.49505 [
[ 0 0 -0.125 0 ]
[ 0 0 -0.125 0 ]
[ 0 1 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
0 0 m
1 0 L
s
0 0 m
0 1 L
s
0 1 m
1 1 L
s
1 0 m
1 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
1 .5 0 r
.015 w
.03175 .1355 Mdot
.03435 .12523 Mdot
.11137 .12765 Mdot
.14107 .18841 Mdot
.16218 .24538 Mdot
.17294 .21053 Mdot
.18267 .18577 Mdot
.18434 .1304 Mdot
.18553 .30956 Mdot
.20401 .239 Mdot
.21247 .27571 Mdot
.21687 .20845 Mdot
.22376 .2799 Mdot
.22832 .27485 Mdot
.29063 .20974 Mdot
.29686 .25079 Mdot
.30487 .22936 Mdot
.30683 .34623 Mdot
.32055 .20902 Mdot
.32574 .21979 Mdot
.34472 .28521 Mdot
.35998 .36393 Mdot
.36335 .24976 Mdot
.3794 .36608 Mdot
.42386 .66992 Mdot
.44391 .74519 Mdot
.45059 .34198 Mdot
.47208 .67586 Mdot
.47436 .71381 Mdot
.49778 .59825 Mdot
.50874 .91643 Mdot
.51516 .76219 Mdot
.53655 .61374 Mdot
.56563 .75219 Mdot
.59189 .65665 Mdot
.59581 .61604 Mdot
.59923 .6556 Mdot
.60292 .68499 Mdot
.62656 .67779 Mdot
.63555 .72451 Mdot
.63919 .652 Mdot
.64169 .6004 Mdot
.64246 .58611 Mdot
.64496 .54267 Mdot
.64608 .77288 Mdot
.65077 .64308 Mdot
.66065 .57816 Mdot
.67474 .59169 Mdot
.69296 .563 Mdot
.72815 .65902 Mdot
.73169 .58879 Mdot
.74669 .61318 Mdot
.74821 .65474 Mdot
.75963 .63781 Mdot
.79673 .57809 Mdot
.80925 .55852 Mdot
.81525 .58444 Mdot
.83417 .62985 Mdot
.83598 .55526 Mdot
.91595 .49319 Mdot
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{400, 400},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40006@0001T2000`400?l00000o`00003ooooooonA
ooooo`00oooooonAooooo`00oooooonAooooo`00oooooonAooooo`00oooooonAooooo`00oooooonA
ooooo`00oooooonAooooo`00oooooonAooooo`00oooooonAooooo`00oooooonAooooo`002Ooooonf
00000=7ooooo0009ooooo`0300000?oooooooooo0;;ooooo00<00000ooooooooool0coooool000Wo
oooo00<00000ooooooooool0/_ooool00`00003oooooooooo`3?ooooo`002Oooool00`00003ooooo
ooooo`2booooo`0300000?oooooooooo0<oooooo0009ooooo`0300000?oooooooooo0;;ooooo00<0
0000ooooooooool0coooool000Wooooo00@00000oooooooooooooooo[@000004ooooo`0300000?oo
oooooooo0<oooooo0009ooooo`0400000?ooooooooooooooojd000001?ooool00`00003ooooooooo
o`3?ooooo`002Oooool01000003ooooooooooooooon]000000Cooooo00<00000ooooooooool0cooo
ool000Wooooo00@00000oooooooooooooooo[@000004ooooo`0300000?oooooooooo0<oooooo0009
ooooo`0400000?ooooooooooooooojd000001?ooool00`00003oooooooooo`3?ooooo`002Oooool0
1000003ooooooooooooooon]000000Cooooo00<00000ooooooooool0coooool000Wooooo00@00000
oooooooooooooooo[@000004ooooo`0300000?oooooooooo0<oooooo0009ooooo`0400000?oooooo
ooooooooojd000001?ooool00`00003oooooooooo`3?ooooo`002Oooool01000003ooooooooooooo
oon]000000Cooooo00<00000ooooooooool0coooool000Wooooo00@00000oooooooooooooooo[@00
0004ooooo`0300000?oooooooooo0<oooooo0009ooooo`0400000?ooooooooooooooojd000001?oo
ool00`00003oooooooooo`3?ooooo`002Oooool01000003ooooooooooooooon]000000Cooooo00<0
0000ooooooooool0coooool000Wooooo00@00000oooooooooooooooo[@000004ooooo`0300000?oo
oooooooo08_ooooo0P000012ooooo`002Oooool01000003oooooooooooooool400000003o`000000
00006ATI00`06ATI00<00000o`0000000000U`000004ooooo`0300000?oooooooooo08Sooooo0`00
00000oooool00000ooooo`11ooooo`002Oooool01000003oooooooooooooool3000001@06ATIUP00
0004ooooo`0300000?oooooooooo08Kooooo0P000003ooooo`03ojVmj00000000000047ooooo0009
ooooo`0400000?ooooooooooooooo`8000006@0I6AVB000000Cooooo00<00000ooooooooool0Pooo
ool3000000;ooooo1?nY_NP00`00003ooooo00000010ooooo`002Oooool01@00003ooooooooooooo
oooo000001d06ATIS`000004ooooo`0300000?oooooooooo083ooooo0`000002ooooo`OoZKgX00<0
0000ooooo`000000@?ooool000Wooooo00D00000ooooooooooooooooo`00000;01TI6@/000002P0I
6AV<000000Cooooo00<00000ooooooooool0O_ooool2000000?ooooo2OnY_NP01000003oZKgXoooo
o`00000oooooo`002Oooool01000003oooooooooooooool901TI6@<000002`0c<c<4000000L06ATI
R`000004ooooo`0300000?oooooooooo07_ooooo0`000002ooooo`coZKgX00D00000ojVmj?oooooo
oooo0000000nooooo`002Oooool01000003oooooooooooooool801TI6@030000000c<c<0<c<c0100
<c<c0`0000000ol000006ATI01TI6@0401TI6@80000000?o0000000000000000P`000004ooooo`03
00000?oooooooooo07Wooooo0P000003ooooo`koZKgX00D00000ojVmj?nY_NSooooo0000000noooo
o`002Oooool01000003oooooooooooooool801TI6@030000000c<c<0<c<c00D0<c<c2`00000403<c
<`<000001P0I6AV5000000Cooooo00<00000ooooooooool0M_ooool3000000;ooooo4OnY_NP01P00
003oZKgXojVmj?nY_NSooooo000003gooooo0009ooooo`0400000?ooooooooooooooo`P06ATI00<0
000003<c<`0c<c<00`0c<c<2000000/0C4a<0`00000403<c<`8000001@0I6AV4000000Cooooo00<0
0000ooooooooool0M?ooool2000000;ooooo5?nY_NP00`00003oZKgXojVmj002ojVmj00300000?oo
oooooooo03_ooooo0009ooooo`0500000?ooooooooooooooool000001P0I6AT00`000000<c<c03<c
<`0303<c<`030000001<C4`0C4a<00<0C4a<2000000304a<C0@000000P0c<c<2000000D06ATIPP00
0004ooooo`0300000?oooooooooo077ooooo0`000002oooooaKoZKgX00<00000ojVmj?nY_NP00onY
_NP00`00003oooooooooo`0jooooo`002Oooool01@00003oooooooooooooool0000000H06ATI00<0
000003<c<`0c<c<00P0c<c<00`000000C4a<04a<C00204a<C003o`0000000000IVIV00L0IVIV00Co
000000000000000000000`1<C4`200000080<c<c00?o0000000000000000100I6AT00`00003o0000
0000001m000000Cooooo00<00000ooooooooool0K_ooool3000000;ooooo6OnY_NP00`00003oZKgX
ojVmj003ojVmj003ooooo`00003ooooo03[ooooo0009ooooo`0500000?ooooooooooooooo`000000
1P0I6AT00`000000<c<c03<c<`0203<c<`030000001<C4`0C4a<0080C4a<00<0000006IVIP1VIVH0
0P1VIVH5o`0000@0IVIV0`00000204a<C08000000`0c<c<2000000@06ATIOP000004ooooo`030000
0?oooooooooo06cooooo0P000003oooooacoZKgX00<00000ojVmj?nY_NP00onY_NP00`00003ooooo
ooooo`0iooooo`002Oooool01000003oooooooooooooool2000000D06ATI00D0000003<c<`0c<c<0
<c<c0000000404a<C0040000001VIVH0IVIV06IVIP;o00001@1oOgl7o`0000<0000000@0C4a<0000
0000000000000P0c<c<2000000<06ATIO@000004ooooo`0300000?oooooooooo06Wooooo0`000002
oooooaooZKgX00<00000ojVmj?nY_NP00onY_NP00oooool00000ooooo`0iooooo`002Oooool01000
003oooooooooooooool2000000D06ATI00D0000003<c<`0c<c<0<c<c0000000304a<C0050000001V
IVH0IVIV06IVI_l000001P1oOgl4000000@0Ogmo0_l000001P1VIVH00000000000000000C4a<o`00
0080000000<0<c<co`0000000000100I6AUj000000Cooooo00<00000ooooooooool0Ioooool20000
00?ooooo8OnY_NP00`00003oZKgXojVmj004ojVmj003ooooo`00003ooooo03Sooooo0009ooooo`04
00000?ooooooooooooooo`8000001@0I6AT01@000000<c<c03<c<`0c<c<0000000<0C4a<00D00000
06IVIP1VIVH0IVIVo`00000407moO`800000102IVIT400000080Ogmo0_l0000206IVIP050000001<
C4`0C4a<04a<C00000000P0c<c<00`0000006ATI01TI6@0301TI6GP000001?ooool00`00003ooooo
ooooo`1Tooooo`<000000_oooolTojVmj00300000?nY_NSoZKgX00CoZKgX00?ooooo00000?ooool0
>?ooool000Wooooo00@00000oooooooooooooooo0`00000501TI6@050000000c<c<0<c<c03<c<`00
00000P1<C4`01@000000IVIV06IVIP1VIVKo000000<0Ogmo00@0000009VIV@2IVIT0VIVI1ol00003
0000000407moOol0003o0000o`00008000000P1<C4`20000000303<c<`000000000000@06ATIM`00
0004ooooo`0300000?oooooooooo06;ooooo0P000003ooooobKoZKgX00<00000ojVmj?nY_NP01OnY
_NP00oooool00000ooooo`0gooooo`002Oooool01000003oooooooooooooool300000003o`00000I
6AT06ATI00806ATI00D0000003<c<`0c<c<0<c<c0000000304a<C0030000001VIVKo000000<0Ogmo
00D0000009VIV@2IVIT0VIVIo`0000070;>c/`?o00000`0000000`1oOgoo000006IVIP0200000080
C4a<00<0000003<c<`0c<c<00P00000301TI6GH000001?ooool00`00003oooooooooo`1Oooooo`<0
00000_oooolYojVmj00300000?nY_NSoZKgX00KoZKgX00?ooooo00000?ooool0=_ooool000Wooooo
00@00000oooooooooooooooo1000000501TI6@050000000c<c<0<c<c03<c<`0000000P1<C4`00`00
0000IVIVo`00000207moO`050000002IVIT0VIVI09VIVOl00000102c/k<6o`0000030;>c/ol0003o
000000;o000000@0Ogmoo`000?l0003o00000P0000000`1<C4`000000000000203<c<`8000000`0I
6AUd000000Cooooo00<00000ooooooooool0GOooool2000000?ooooo:onY_NP00`00003oZKgXojVm
j007ojVmj00300000?oooooooooo03Gooooo0009ooooo`0400000?ooooooooooooooo`D00000100I
6AT01@000000<c<c03<c<`0c<c<000000080C4a<00<0000006IVI_l000000P1oOgl01@000000VIVI
09VIV@2IVIWo00000080/k>c0_l000060<c<c0;o00000P2c/k<00ol0000000000000000207moO`;o
000000<0000004a<C01<C4`00P00000203<c<`030000000I6AT06ATI00806ATILP000004ooooo`03
00000?oooooooooo05[ooooo0`000002ooooobkoZKgX00<00000ojVmj?nY_NP02?nY_NP00`00003o
ooooooooo`0dooooo`002Oooool01000003oooooooooooooool6000000@06ATI00D0000003<c<`0c
<c<0<c<c0000000204a<C0030000001VIVKo00000080Ogmo00<0000009VIVOl000000P2c/k<00ol0
0000c<c<0<c<c0030<c<c0Co000000<0c<c<o`000?l000001?l0000010000000Ogmo07moOol00003
0000000404a<C?l00000<c<c03<c<`800000100I6AU`000000Cooooo00<00000ooooooooool0Eooo
ool3000000?ooooo<?nY_NP00`00003oZKgXojVmj008ojVmj003ooooo`00003ooooo03Cooooo0009
ooooo`0400000?ooooooooooooooo`H0000000?o000001TI6@0I6AT00P0I6AT01ol00000<c<c03<c
<`0c<c?o000004a<C00000000P1VIVH01Ol00000Ogmo0000002IVIWo00000080/k>c00Co00000<c<
c03<c<`0c<c<0_l000040>KViPKo000000D0/k>co`000?l00000000007moO`02o`00000406IVI_l0
0000C4a<000000<0<c<c00<0000001TI6@0I6AT00P0I6AU_000000Cooooo00<00000ooooooooool0
EOooool2000000?ooooo<onY_NP00`00003oZKgXojVmj009ojVmj00300000?oooooooooo03?ooooo
0009ooooo`0400000?ooooooooooooooo`P00000100I6AT01P000000<c<c03<c<`000000C4a<0000
0080IVIV00Go000007moO`000000VIVIo`0000020;>c/`05o`00003<c<`0c<c<0<c<c?l000002@3V
i^H6o`0000080000001oOgl0Ogmoo`00001VIVH0000004a<C000000303<c<`050000000I6AT06ATI
01TI6Ol00000KP000004ooooo`0300000?oooooooooo05;ooooo0`000003ooooocGoZKgX00<00000
ojVmj?nY_NP02OnY_NP00oooool00000ooooo`0cooooo`002Oooool01000003oooooooooooooool8
000000D06ATI00P0000003<c<`0c<c<0000004a<C0000000IVIVo`000080Ogmo00D0000009VIVOl0
0000/k>co`0000030<c<c003o`00003Vi^H0i^KV0080i^KV1?l000030>KViP05o`00003<c<co0000
0;>c/ol000000P0000001@1oOgoo000006IVIP000000C4a<008000000P0c<c<00`0000006ATI01TI
6@0201TI6Fd000001?ooool00`00003oooooooooo`1@ooooo`8000001?oooolgojVmj00300000?nY
_NSoZKgX00[oZKgX00<00000ooooooooool0<_ooool000Wooooo00@00000oooooooooooooooo2@00
000501TI6@080000000c<c<0<c<c0000001<C4`0000006IVI_l0000207moO`0500000?l00000/k>c
0;>c/ol000000P3<c<`00ol00000i^KV0>KViP02o`0000@0oooo00oo00000>KViP3Vi^H0i^KVo`00
003<c<co00000;>c/ol00000VIVI0000001oOgoo000006IVIP0000000P1<C4`010000000<c<c03<c
<`00000501TI6F/000001?ooool00`00003oooooooooo`1=ooooo`<000000oooooljojVmj0030000
0?nY_NSoZKgX00[oZKgX00?ooooo00000?ooool0<_ooool000Wooooo00@00000oooooooooooooooo
2@0000000ol000006ATI01TI6@0201TI6@06o`0000000000<c<c03<c<ol00000C4a<0P0000001Ol0
0000Ogmoo`00002IVIWo00000080/k>c00?o00000<c<c?l000000P3Vi^H00ol00000oooo0?ooo`04
0?ooo`;o00000P3Vi^H7o`00000300000?l0003o00000080000000D0C4a<o`0000000000<c<co`00
000401TI6@03o`0000000000000006P000001?ooool00`00003oooooooooo`1;ooooo`8000001?oo
oollojVmj00300000?nY_NSoZKgX00_oZKgX00?ooooo00000?ooool0<Oooool000Wooooo00@00000
oooooooooooooooo3000000401TI6@030000000c<c<0000000<0C4a<00D00000o`00001oOgl00000
09VIV@02o`0000060;>c/ol00000c<c<o`00003Vi^Ko0000203oool2o`000080i^KV00_o00000<c<
c?l00000/k>co`00002IVIT0000007moOol00000IVIV0000000204a<C0040000000c<c<000000000
00@06ATIJ@000004ooooo`0300000?oooooooooo04Sooooo0`000003ooooocooZKgX00<00000ojVm
j?nY_NP03?nY_NP00`00003oooooooooo`0`ooooo`002Oooool01000003oooooooooooooool=0000
00@06ATI00<0000003<c<`0000000`1<C4`01000003o0000o`000000000209VIV@07o`00002c/k?o
00000<c<c?l00000i^KVo`0000090?ooo`;o000000`0i^KVo`00003<c<co00000;>c/ol00000VIVI
0000001oOgoo000006IVIP00000204a<C0040000000c<c<0<c<c000000@06ATIJ0000004ooooo`03
00000?oooooooooo04Gooooo0`000002oooood?oZKgX00<00000ojVmj?nY_NP03?nY_NP00oooool0
0000ooooo`0`ooooo`002Oooool01000003oooooooooooooool=00000003o`00000I6AT06ATI0080
6ATI00Co000003<c<`00003o00000P1<C4`030000000IVIVo`000000003o000009VIVOl00000/k>c
o`00003<c<co00000>KViP;o00002@3oool03Ol00000i^KVo`00003<c<co00000;>c/ol00000VIVI
0000001oOgoo000006IVIP0000000P1<C4`01?l00000<c<c03<c<ol0000401TI6@03o`0000000000
000006@000001?ooool00`00003oooooooooo`13ooooo`8000000_oooom6ojVmj00300000?nY_NSo
ZKgX00goZKgX00?ooooo00000?ooool0;oooool000Wooooo00@00000oooooooooooooooo3`000003
01TI6@090000000c<c<0<c<c03<c<`000000C4a<o`00001VIVKo00000080Ogmo00D0000009VIVOl0
003o00000<c<c002o`000080i^KV0_l000070?ooo`03o`00003Vi^Ko00000080c<c<00Co00000;>c
/ol0000000000P1oOgl01Ol00000IVIV0000001<C4`0000000<0<c<c00<0000001TI6@0I6AT00P0I
6AUV000000Cooooo00<00000ooooooooool0@?ooool3000000;oooooB?nY_NP00`00003oZKgXojVm
j00=ojVmj003ooooo`00003ooooo02oooooo0009ooooo`0400000?oooooooooooooooa0000000`0I
6AT020000000<c<c03<c<`0c<c<0000004a<C0000000IVIV0_l000000`1oOgl0000009VIV@02o`00
0080c<c<0_l000020>KViP03o`00003oool0oooo00@0oooo00Ko00000>KViP3Vi^Ko00000<c<c?l0
00020;>c/`09o`0000000000Ogmo07moOol00000IVIV0000001<C4`0000000<0<c<c00<0000001TI
6@0I6AT00P0I6AUU000000Cooooo00<00000ooooooooool0?_ooool2000000?oooooB_nY_NP00`00
003oZKgXojVmj00>ojVmj003ooooo`00003ooooo02kooooo0009ooooo`0400000?oooooooooooooo
oa4000000`0I6AT200000080<c<c00<0000004a<C00000000P1VIVH01?l00000Ogmo0000002IVIT3
o`000080c<c<00?o00000>KViP3Vi^H00_l000050?ooo`0<o`00003Vi^H0i^KVo`00003<c<co0000
0;>c/ol00000VIVI0000001oOgoo00000P1VIVH00ol00000C4a<0000000303<c<`030000000I6AT0
6ATI00806ATII0000004ooooo`0300000?oooooooooo03_ooooo0`000002ooooodgoZKgX00<00000
ojVmj?nY_NP03OnY_NP2ojVmi`03ooooo`00003ooooo02gooooo0009ooooo`0400000?oooooooooo
oooooa800000100I6AT20000000603<c<ol00000000000000?l0000000000ol000000`00003o0000
o`000002o`0000030<c<c?l0003o00000080i^KV1_l000030>KViP08o`00003<c<co00000;>c/ol0
0000VIVIo`0000000002o`00000506IVIP000000C4a<o`00000000000P0c<c<00`0000006ATI01TI
6@0201TI6@03o`00000000000000060000001?ooool00`00003oooooooooo`0iooooo`8000000ooo
oom?ojVmj00300000?nY_NSoZKgX00SoZKgX1_nY_NL2ojVli`0300000?oooooooooo02cooooo0009
ooooo`0400000?oooooooooooooooa<000001@0I6AT20000000803<c<`000000000004a<C0000000
IVIVo`00001oOgl2000000Co000000<0c<c<o`000?l000002@3Vi^H01Ol00000c<c<o`00002c/k?o
00000080VIVI00D0000007moO`1oOgoo00000000000204a<C0040000000c<c<0<c<c000000D06ATI
HP000004ooooo`0300000?oooooooooo03Kooooo0`000003oooooe7oZKgX00<00000ojVmj?nY_NP0
1_nY_NP6ojVmi`GoZKcW00<00000ooooooooool0:oooool000Wooooo00@00000oooooooooooooooo
5000000601TI6@050000000c<c<0<c<c0000001<C4`00P0000001Ol00000Ogmo07moO`000000VIVI
00?o00000P3<c<`2o`0000H0i^KV00Oo00000<c<c03<c<`0c<c<o`00002c/k?o00000080VIVI00D0
000007moOol00000IVIV0000000204a<C0040000000c<c<0<c<c000000D06ATIH@000004ooooo`03
00000?oooooooooo03?ooooo0`000004oooooe?oZKgX00<00000ojVmj?nY_NP00onY_NP6ojVmi`Oo
ZKcW00?oZ[_V00000?ooool0;?ooool000Wooooo00@00000oooooooooooooooo500000000ol00000
00000000000401TI6@040000000c<c<0<c<c00000080C4a<00L00000o`000?l0003o000000000?l0
0000000000_o00000`3<c<`2o`000080/k>c00?o000009VIV@0000000P1oOgl00ol00000IVIVo`00
000204a<C004o`00000c<c<0<c<c000000D06ATI00?o0000000000000000G@000004ooooo`030000
0?oooooooooo037ooooo0P000004oooooeOoZKgX00<00000ojVmj?nY_NP01_nY_NL6ojVli`03ojVk
i_nZ^nKoZ[_V00;oZ[_V00<00000ooooooooool0:_ooool000Wooooo00@00000oooooooooooooooo
6000000301TI6@0;o`0000000000<c<c03<c<ol00000000004a<C?l00000000006IVI_l000000P1o
Ogl00`00003o0000o`0000020;>c/`?o00001@3<c<`00ol00000/k>c0;>c/`020;>c/`03o`00002I
VIT000000080Ogmo00Co000006IVIP1VIVH000000P1<C4`010000000<c<c03<c<`00000401TI6F00
00001?ooool00`00003oooooooooo`0^ooooo`<000000_oooomKojVmj00300000?nY_NOoZKgW00Co
ZKgW1_nY_>L2ojVjiP;oZK_V0_nZ^nH2ojZji@0300000?oooooooooo02Wooooo0009ooooo`040000
0?oooooooooooooooaT00000100I6AT200000080<c<c00<0000004a<C01<C4`00P000002o`000003
07moO`000000000000;o00000`2c/k<5o`0000D0/k>c00?o000009VIV@0000000P1oOgl01?l00000
IVIV06IVIP00000204a<C0050000000c<c<0<c<c03<c<`000000100I6AUO000000Cooooo00<00000
ooooooooool0;?ooool2000000?oooooFonY_NP2ojVmi`0400000?nY_NOoZKgWojVmi`KoZKcW0_nY
^^D2ojVjiP04ojZii?nZ^NGoZ[WUojZii@;oZ[[U00?oZkWT00000?ooool0:_ooool000Wooooo00@0
0000oooooooooooooooo6P00000501TI6@040000000c<c<0<c<c000000<0C4a<00<0000006IVI_l0
00000P1oOgl2000000?o00002@2c/k<01Ol00000VIVI09VIV@2IVIT000000080Ogmo00Co000006IV
IP1VIVH000000P1<C4`010000000<c<c03<c<`00000401TI6El000001?ooool00`00003ooooooooo
o`0Yooooo`<000000_oooomNojVmj0;oZKgW00<00000ojVmionY_>L00_nY_>L6ojVji@03ojVhhonZ
^NCoZ[WT00;oZ[WT00?oZ[WUoj^hhon[^N@00on[^N@00`00003oooooooooo`0Xooooo`002Oooool0
1000003ooooooooooooooolJ00000003o`0000000000000000<06ATI00Co00000000000c<c?o0000
0P0000000`1<C4co000000000003o`00000407moO`0000000000000000Oo000000<0/k>co`000?l0
00000`2IVIT010000000Ogmo07moOol0000206IVIP040000001<C4`0C4a<000000<0<c<c00<00000
01TI6@0I6AT00P0I6AT00`00003o00000000001K000000Cooooo00<00000ooooooooool09oooool2
000000?ooooo4?nY_NP00onY_NOoZKgXojVmj01<ojVmj0?oZKcW00<00000ojVlionY_>L01_nY^^D0
1?nY]n?oZKSSojVhhonY^><2ojZii004oj^fhOn[^>?oZkSSoj^hh`;oZkWT00?o[;WSooooo`000000
:Oooool000Wooooo00@00000oooooooooooooooo7P00000401TI6@8000000P0c<c<20000000404a<
C0000000000006IVIP?o000000@0Ogmo0000000000000000102IVIT00ol00000VIVI09VIV@0209VI
V@050000001oOgl0Ogmo07moOol000000P1VIVH010000000C4a<04a<C000000303<c<`030000000I
6AT06ATI00<06ATIG@000004ooooo`0300000?oooooooooo02Cooooo0`000003ooooo`?oZKgW0onY
_NP2ojVmi`;oZKgX00CoZKcWojVmionY_NOoZKgW0_nY_NP01?nY_>OoZKgWojVmionY_NL2ojVmj003
ojVlionY_NSoZKgX00;oZKgX0_nY_NL4ojVmj0;oZKgW>onY_NP6ojVli`0300000?nY^^GoZK[U00?o
ZK[U00?oZKKSojVghonY]n<00_nY]n<00onY^>?oZ[CPoj^fh@03oj^fh@03oj^hhon/]n7o[;WS00?o
[;WS00<00000ooooooooool09oooool000Wooooo00@00000oooooooooooooooo7`00000501TI6@80
00000P0c<c<00`000000C4a<04a<C00200000080IVIV00Co000007moO`1oOgl0Ogmo1000000209VI
V@<000000`1oOgl01Ol00000IVIV06IVIP1VIVH0000000<0C4a<00D0000003<c<`0c<c<0<c<c0000
000501TI6E`000001?ooool00`00003oooooooooo`0Rooooo`8000001?ooool2ojVli`;oZKgW00Go
ZK_VojVlionY_>OoZKcWojVmi`02ojVkiP?oZKcW00?oZKgWojZki_nZ^nH00onY_>L00onY_NOoZ[_V
ojZkiP03ojVli`03ojVmj?nY_>KoZKcV00?oZKgW00CoZKgXojVlionY_>OoZKcW0_nY_NL00onY_NSo
ZKgWojVmi`02ojVmj003ojVlionY_NSoZKgX033oZKgX1_nY_>L00onY^^KoZK[U00000003ojVji@04
ojVfh_nY]^?oZKKSojVfh`;oZKOS00CoZK;OojZdh?nZ]>3oZ[CP0_n[]^401?n/]=ko[;OQojbghOn/
]n42ojbih`;o[[WR00<00000ooooooooool09_ooool000Wooooo00@00000oooooooooooooooo7`00
00000ol00000000001TI6@0401TI6@80000000<0<c<c00000?l000000`0000000ol000000000o`00
0003o`0000<0Ogmo0P00000607moO`05o`00001VIVH0IVIV06IVIP0000000`1<C4`01@000000<c<c
03<c<`0c<c<0000000D06ATIG0000004ooooo`0300000?oooooooooo01oooooo0`0000000ooooooo
ZK_VojVkiP04ojVli`;oZ[[U0onY^nH00onY_>OoZ[WTojZii003ojVkiP03ojVlionZ^>CoZ[ST00?o
Z[_V00?oZKcWojZii?nZ^N@00onZ^nH00onY_>OoZ[[UojZji@03ojVliP03ojVmionZ^nKoZ[_V00;o
ZKcW00GoZ[WTojZli_nZ_>KoZ[cVojVmi`02ojZkiP?oZKcW00?oZKgXojZlionZ_>L01?nY_NP2ojVm
ibKoZKgX0_nY_NL3ojVli`?oZK_V0_nY^^H00`00003oZ;KSojRfh`03ojVfhP03ojVfhonY/MkoZK7N
00?oZK;O00?oZ[CPoj^ag?n/]=h00on/]=h00on/]n7o[[OOojjgg`02ojjihP03ok2kh_ooool00000
02Oooooo0009ooooo`0400000?ooooooooooooooob8000001P0I6AT00`000000<c<c03<c<`0203<c
<`80000000D0C4a<000000000000000006IVIP0;o`0000@0IVIV00D0000004a<C01<C4`0C4a<0000
000303<c<`030000000I6AT06ATI00<06ATIG0000004ooooo`0300000?oooooooooo01cooooo0`00
0002ooooo`;oZK[U0onY^nH00onY_>OoZ[SSojZhh`03ojZji@03ojVki_nZ]^;oZ[KR00?oZ[WT00?o
ZK_VojZeh?nZ^>@00onZ^>@00onZ^nKoZ[CPojZdh003ojZii004ojZki_n[]^7oZkKQojZji@;oZk;M
0onZ^><00onZ^nKoZkGPoj^eh003ojZii003ojZli_n[^>?oZkSS00?oZ[_V00?oZKcWojZkiOnZ^nD0
0onZ_>L00onY_NSoZ[cWojZli`03ojVmi`03ojVmj?nY_NOoZKgW00;oZKgX00?oZKgWojVmj?nY_NP0
7?nY_NP2ojVmi`03ojVkionY^nKoZK_V00?oZK_V00CoZ;OTojRfhonX]^<000000onX]^<00onY]^;o
Z;3MojVagP03ojVagP03ojVbgonZ[][oZk7L00;oZk7L0_n/]=h01?n^/mco[[OOojjggon^]ml4ok2k
hP0300000?oooooooooo02Gooooo0009ooooo`0400000?ooooooooooooooob@000001@0I6AT20000
00@0<c<c00@0000004a<C01<C4`0C4a<1000000:06IVIP800000101<C4`01@000000<c<c03<c<`0c
<c<0000000H06ATIF`000004ooooo`0300000?oooooooooo01[ooooo0P000003ooooo`;oZ[WT0onY
^^D00onY^nKoZ[KQojZfh@03ojZhh`03ojZjiOnZ/]koZ[KR00?oZ[KR00?oZ[WToj^_fonZ]N000_nZ
]N02ojZhi0;oZjkJ00?oZ[CPoj^Vd_n[Y]800on[[m/00on[]^7o[:WDojbYe003oj^bg@03ojZhhon/
[MWoZkGP00?oZkGP00?oZ[WTojbbgOn[^><00on[^><00onZ^nKoZkORoj^ghP03ojZki@04ojZlionZ
^^GoZ[[UojZli`;oZk[U0onZ_>L00onY_NOoZ[cWojZli`03ojVmi`03ojVmj?nY_NOoZKgX01WoZKgX
00?oZKcWojVkionY^nL00_nY^nL00onY^nKoZ;STojRgi003ojRgi003ojRfh`00003oZ:oM00?oZ:oM
0_nX/=d2ojVagP05ojV[f?nZ[][oZZkJojZ^f_n[/M`00_n][mT3ojjcg003ojjggona^=ko/KSN00;o
/;_R00?o/kkRooooo`0000009_ooool000Wooooo00@00000oooooooooooooooo9P00000501TI6@80
00000`0c<c<3000000@0C4a<0`00000506IVIP8000001@1<C4`00`000000<c<c03<c<`0203<c<`03
0000000I6AT06ATI00@06ATIF`000004ooooo`0300000?oooooooooo01Oooooo0`000003ooooo`;o
ZKOS0onZ^N@00onY^^GoZ[?OojZfh@03ojZfh@03ojZhhonZ[][oZ[;N00;oZ[;N0_nZ]^801OnZZMKo
ZjoKoj^_fon[[m_oZ[GP00;oZjKC0on[[]X4oj^VdP03oj^_fon/W/Wo[:WD00?o[:WD00?oZk;MojbS
cOn/[MT00_n/[MT2oj^eh004ojfYe?n//]go[;;Mojbbg@;oZkSS0_n//=/00on[]n;o[JoIojf_f@03
ojbfh@03ojZjiOn/]^3oZk[U00?oZk[U00?oZ[cWoj^jiOnZ_>L00onZ_>L00onY_NOoZ[cWojZli`02
ojVmi`;oZKgX0_nY_NLCojVmj0CoZKcW0_nY^nL01?nX^NGoZ;STojRhi?nX^>@2ojRgi004ojN`gP00
00000000ojN_gP;oZ:oM00?oYZOFojRXeonXZ=L01?nYZmP00onZ[][o[:[Eojf_f@03ojf_f@05ojjc
g?na]=[o/KCJok6hg_ne_=l01?nc_^800oooool00000ooooo`0Tooooo`002Oooool01000003ooooo
oooooooooolY000000@06ATI0`00000303<c<`0400000?l000000000000000<0C4a<1@00000704a<
C003o`00000c<c<0<c<c0080<c<c00<0000001TI6@0I6AT01@0I6AUJ000000Cooooo00<00000oooo
ooooool05_ooool00`00003o0000ooooo`02ooooo`03ojVgh_nY]n?oZKOS00;oZKOS00?oZ[WTojZa
gOnZ/ml00_nZ/ml2ojZfh@05ojZYe_nZ[][oZZkJojZ^f_nZ/]h00_nZX/l3ojZYeP03oj^_fonZW/[o
ZYk:00?oZjKC00?oZjkJoj^Lb?n[W<P00on[Y]83ojbNb@;o[:WD00Go[9K0ojbScOn/Xlgo[:?=ojb]
f@02ojfMa`?o[JWD00?o[;;MojjVd?n^Y]000on//=/4ojf_f@03ojbfhOn^[mSo[;KP00;o[;KP0_n[
^^D01?n/]n7oZk[Uoj^jiOn[^^D2ojZli`;oZk_U00?oZ[cWoj^kiOnZ_>L00onZ_>L00onY_NOoZ[gW
ojVmj00@ojVmj0GoZKcW0_nX^^D3ojRii@03ojRhi?nW/Ml000000080000000?oYk3N00000?nUY]H0
1?nVYmH2ojRXe`;oZJ_H00CoZZGBojbZeOn/Z]Go[:[E0_n][mT01?na[mKo/KCJok6df_na]=X3okFl
g`;o/kkR0_ne`^@00`00003oooooooooo`0Sooooo`002Oooool01000003oooooooooooooool[0000
00D06ATI0`00000403<c<`<000002P1<C4`2000000D0<c<c00<0000001TI6@0I6AT01@0I6AUJ0000
00Cooooo00<00000ooooooooool05_ooool00`00003oooooo`000002ojVfhP;oZKOR0_nY]n<01OnY
[mcoZ[7MojZagOnZ/MgoZ[?O00;oZJKC0onZZMH00onZ[][oZIc9ojVLb@03ojZRc`03ojZYe_nYUL;o
ZYk:00?oZYk:00?oZjKCojZB_On[W<P00on[W<P00on[Y];oZi:moj^B_@02ojbNb@04ojbYe?n/U/3o
[9K0ojbF`0;o[:?=1?n]WLL00on]ZMCo[Y[2ojjVd003ojjVd003ojb`fon_YLgo[jG=00;o[JoI00Go
/:G<ojj_f?n^[mSo[ZoHojbfh002ojn`f@?o[;OQ00KoZk[UojfhhOn]^>7o[KSQoj^kiOn]^N83oj^k
i@;oZ[cW00CoZkcVojZmionZ_NOoZ[gW0_nY_NP00onZ_NOoZKgXojVmj00:ojVmj0;oZKcW00CoZK_W
ojVji_nY^^KoZK[V0onX^^D01?nX^ND00000000000000002ojNag`05ojN`g_nUY]KoYJKF00000?nU
Y]H00onVYmH00onXZ=OoZ:7?ojZUdP03ojZUdP03ojbZeOn_ZM7o/JoF00?o/JoF00Co/KCJokJhf_nf
^=[o]KcO0_ni`N02okG2i003okO5iOooool0000002Cooooo0009ooooo`0400000?oooooooooooooo
obd000001P0I6AT3000000@0<c<c2P00000603<c<`030000000I6AT06ATI00H06ATIFP000004oooo
o`0300000?oooooooooo01Kooooo00@00000ojVfh_nY]^;oZKKR0_nX[m`3ojV^g0;oZJoL00?oZ[7M
ojVSdOnYXm400onYY]<00onZZMKoZ9S5ojVLb@03ojVLb@03ojZRconXSk_oZIG200;oZIG20_nZW/X0
1?nXRKCoZY:mojZB_OnZT[d2oj^Lb006ojV8/_n[T[goZi:moj^B_On/W/WoZh^c1?n/U/000on/Xlgo
[I6iojfA^@03ojfMa`?o[Y[20_n^Y]001?n`V;oo[jG=ojnUcOn_YLd4ok2Uc003ojj_f?nbYlgo[k3I
00?o[k3I00?o[;OQojnbf_n_/]X00_n]^>401On`]Mco[KWRojfih_n]^N;oZk_U00;o[;[T0on[_>H0
0onZ_NOoZ[cVojZliP03ojZmi`03ojVmj?nZ_NOoZ[gW00OoZKgX0_nY_>L3ojVki`03ojVji_nW]^?o
YkCR00<000000_nW/n42ojNag`03ojBWf?nUY]KoYJKF00;oYJKF00@00000ojJMcOnVWLgoYYg=0onX
XLl2ojZUdP04ojfRcOn_ZM7o[jWAojnYd@;o/JoF0_nf/]D00onf^=[o^kkLokW1h002okW1h0Co]lGU
00<00000ooooooooool08_ooool000Wooooo00@00000oooooooooooooooo<000000601TI6@040000
0?l00000000000000100<c<c00?o000001TI6@0I6AT01P0I6AUJ000000Cooooo00<00000oooooooo
ool05_ooool01000003oZKKRojR`g_nX/=h3ojR_g003ojV^g?nWXm;oZ:?A00;oZ:?A0onYXm400onY
Y]?oYiG3ojRHa@02ojRHa@;oZIc900CoYhZfojR?^onXSk_oZ8nk0_nYUL84ojR9]0;oZY:m1?nYR;82
oj^B_@?oZh^c0on/U/04ojfA^@03ojfMaon^S[Co[Xjd00;o[Y[21?n`V;l00on_YLgo/YVnok:I_P03
ok2Uc0?o/ZO=0_n_/=T2ok>Zd003ojnbf_nd[m?o]:oC00?o/;GL00?o[KWRojnggon/^^@00on/^^@0
1?n[_>Ko[;_UojbkiOnZ_>H2oj^liPKoZ[gW1?nY_NP5ojVli`03ojVkionX^>@00000008000000_nW
]>800onUZm_oY:SIojBXf@04ojBWf005ojFVe_nRVLcoY9_<ojBKc00000000onVWLd00onXXLooZYc8
ojfRc@03ojfRc@03ojnYdOneZloo][;E00;o][;E00Go_KWFok^ng?nk_]co^kkLokW1h002ok_7h`;o
]lGU0_ngb>L00`00003oooooooooo`0Qooooo`002Oooool01000003ooooooooooooooolb000000P0
6ATI1000000903<c<`<000002@0I6AUJ000000Cooooo00<00000ooooooooool05Oooool00`00003o
ooooooooo`03ojR`gP03ojR_g?nVY]KoYj?B00;oYj?B0onXXm400onYXm7oYYC3ojNE``02ojNE``;o
Z9S50onWR[H3ojR?^`03ojVE`_nWPjkoYh>^00?oZ8Vd00?oZY:mojR1Z_nYR;800onYR;800on[T[go
ZX:Yoj^;/`03oj^;/`03ojbF`?n/QZgo[8J]00;o[I6i00Go[XFXojj>]?n^S[Co[XjdojjJ`P02ok6=
/@?o/9Ro1?nbVKh00on`YLco]IfookFM_`02ok:Wc@04okNR`oncZ]3o/j[@ok>Zd0Co]:oC00?o/;GL
okBcf?n_]ml00_n_]ml2ojbji0;o[[[R00?o[;_Uojfli?n[_>H00on[_>H00onZ_NOoZkgWojZmi`03
ojZmi`03ojVmj?nY_>OoZKcW00CoZKcW0`0000001?nX^>CoYkKSojF^gOnU[]d3ojF[f`;oY:SI0_nT
YmP02OnQVLgoXYW<oj:Ic?nRVLcoY9_<00000?nTVlcoYYg=ojJGa@03ojZLb0?o[J;=0oneZll01Onf
/]Go_KWFokfie_nm^MKo^kkL00;o`LKO00?o^lOSokg<i_nmc>H00_ngb>L2okG9j@0300000?oooooo
oooo023ooooo0009ooooo`0400000?oooooooooooooooc@000002P0I6AT9000000`06ATIFP000004
ooooo`0300000?oooooooooo01Gooooo00H00000ooooooooooooooooojR`g_nUZMX3ojJVeP;oYj?B
0_nXXm401?nTULGoYYC3ojJD`onVU<<2ojNE``03ojRHaOnUQkCoYHNd00?oYhZf0_nXSk/3ojN3[P?o
Z8Vd0onXPJX3ojV8/P?oZX:Y0_n[Rk<01On/OjCo[8J]ojb6[On/QZgo[I6i00;o[XFX0on^S[@4ok6=
/@03ok2H_ondT;7o]92a00;o/YVn00Go]iBbokFM_oneWKoo]Ifook:Wc@03okNR``03ok>Zd?niZ<So
^JS800;o]:oC00Go^Zo?okBcf?nd/mSo];?Hojngg`03ok>hg@03ojjjh_na^n7o[KcT00;o[KcT0_n[
_>H2ojbmiP;oZkgW1?nZ_NL00onY_>OoZK_VojVjiP0300000004ojRiiOnV/n;oY[7PojJah0CoYJkM
00CoYJ_Koj2LdOnPV/koX9[>1?nQVLd2oj:Ic0;oY9_<00@00000ojJGaOnVUlGoYYO50onZW<P01On]
X/go/Z?9ok:SbOneZloo_K;@00?o_KWF00KoaLCIol76goo1a]oo`LKOolC?h_nmc>H2okc>j0;o]LWY
00?o/lSY00000?ooool08Oooool000Wooooo00@00000oooooooooooooooo=P00000L01TI6E/00000
1?ooool00`00003oooooooooo`0Eooooo`0400000?ooooooooooooooo`?oYJWJ0_nVY]H00onWXm;o
XiS:ojBEa@03ojBEa@;oYYC300?oYiG3ojB6]?nUQk@00_nUQk@3ojN:]P03ojR?^onVOj[oYh>^00;o
Yh>^0onXRK@3ojR1ZP;oZHRb00GoZGbRojZ2ZOnZPZWoZX:Yoj^;/`02ojaoY0?o[8J]1?n^QJP2ojj>
]0Co/Hfa0ondT;401?nbVKko]iBbokND/_ngU;82okFM_`?o]j;300Go_j>lokVXb?niZ<So^JS8okB_
d`03okZ_c`03okBcf?ni]]Ko^KKF00;o/kSM00Go]k_Mok6khOna^n7o/K_Qojfli003ojnmi003ojbm
i_n]_NKoZkgW00;oZkgW0_nZ_NL01OnZ_>L0000000000000003oZK[V00;oYkKS0onV/n82ojJah0;o
YJkM00CoXJ3Doj2LdOnPW=7oX9cA0_nPV/h3oj6Ic@03oj:Ic?nPS/7oXi;300;oXi;300<00000ojJG
aOnVUlD00_nZW<P01?n^VlCo/Z?9ok:SbOnbXlT3okfbd005okfie_o5a=WoaLCIolG4fOo1a]l00_o4
cn83okc>j0Co/lSY00<00000ooooooooool07oooool000Wooooo00@00000oooooooooooooooo=P00
00001?l00000000000000000000H01TI6E/000001?ooool00`00003oooooooooo`0Eooooo`030000
0?oooooooooo00;ooooo00?oYJWJoijTf_nPWM400_nPWM42oj>HbP?oY9G500CoYYC3oj67^?nTQ[Co
Y8Jd0onUQk@3ojN:]P?oYWnZ0onWPjh00onXRKCoYgbTojR1ZP02ojR1ZP03ojV8/_nYO:;oZGbR00?o
ZX:Y1?n/Oj@2ojb6[@Co[XFX00?o[Xjdok66Y_naQZH00onaSK43okB@/@Co]iBb00Co]Ifook^J]_nk
V[Ko]j;30onoXk`2okVXb004ol6/aOnj[loo^Zo?okZ_c`?o^KKF00Go_[cHokNkgOng^mgo]k_Mok6k
h@02ok>nhP;o[kgT00Co/;oUojfmi_n]_NKo[KgV0_n[_NL300000003ojZlionY^nKoZ;SU00CoYkKS
00CoY[?Roj>YfonRY=OoXZCG1?nQX=@2oj2Ld@03oj2Jc_nLS<;oWHc100;oWHc10onPS/43oj>B``03
00000?nYTkoo[Y_400?o[Y_400?o/Z?9okZYbOnjZLT00_nm/]000oo6_];oaLCIolG4f@02ol_@g@04
olC?h_o4e>Koa=CVokc>j0;o^LkZ0_ncb>T2ok36jP0300000?oooooooooo01kooooo0009ooooo`04
00000?oooooooooooooooch000004`0I6AUL000000Cooooo00<00000ooooooooool05Oooool00`00
003oooooooooo`03ooooo`;oWZCJ0onPWM42oj>HbP04ojBEaOnNR[koXHNhoj67^0?oY8Jd0onUQk@0
0onWR[KoY7fXojIoZP02ojIoZP;oYh>^00CoYWVQojMlY?nWO:CoYgbT0_nXPJX4ojUlXP;oZX:Y1?n/
Oj@00on/QZgo[WnQojj5Z003ojj5Z0?o/HJV0_naSK42okF9YP;o]92a00Co^XjXokND/_ngU;;o]iBb
0onkV[H4oknS_005okVXb?o1[<Go`Jc5ol6/aOnj[ll00_o1]Lh01Oni]]Ko_[cHokjlf?nn_=So]k_M
00;o^/7O00?o/kkRokC2i?nd`^@00on`_nD01?n]_NKo[KkV000000000002oj^mi`03ojZlionY^^Ko
ZK[V00;oZ;SU0_nW]^<01?nT[MkoXjWKoj>YfonSZM/2oj:Te`;oXJ3D00?oVXo7oi^=a?nKSL@00onL
S<83oif<`@;oX8k10_nST/<01?nUSK/00000ojVC_onYTkl2ojjKa005okJP`_njZLWo^ZW9okZYbOnm
/]000_o6_]83ol_@g@;oc][R00Coa=CVol;FjOo2e^Wo^LkZ0_nfc>/2ok36jP03ojk3j@00003ooooo
01oooooo0009ooooo`0400000?oooooooooooooood4000003@0I6AUO000000Cooooo00<00000oooo
ooooool05Oooool00`00003oooooooooo`04ooooo`;oWZCJ00CoX9gAoiBHe?nJT<SoVY380_nNR[h3
oj67^0;oY8Jd0_nUQk@01?nRO:WoY7fXojAmZ?nTOJP2ojIoZP03ojN3[_nVNJ7oYWVQ00?oYgbT0_nX
PJX4ojUlXP03ojZ2ZOn/NYko[7nT00?o[7nT00?o[8J]ojioXOn^Oj400on^QJP3ok66YP05ok6=/One
RJKo]HVVokF9Y_ndT;400_njSZP3okND/P04oknF[OnkV[Ko^iZfolFP/`?o_j>l0oo1[<D01Oo;]lOo
`KG>ol6ec_o1]Lkob<7C00;o_[cH0_o2a]d00onj`Moo^/OTokC2i003okC2i004ok2oi@0000000000
000000;o[;kW0on[_>H00onY^^KoYkKSojJbh@03ojJbh@;oY:gN00CoXjWKoibHconKTl_oVi?;0onJ
SlL3oi^=a0;oW8c20onMS<400onPS/7oX8NiojF=^`03ojF=^`0300000?nYTkoo[Y_400?o]Z320_nj
ZLT01Oo6]/_oa[kBom3>eoo@c]Oobm3M00;oc][R0_o=h>H01?o2e^Wo_MC[okgDjonfc>/2ok;8j`?o
[/?Y00<00000ooooooooool07Oooool000Wooooo00@00000ooooooooooooooooB@0000000ol00000
00000000001Q000000Cooooo00<00000ooooooooool05?ooool00`00003oooooooooo`05ooooo`;o
Sj7Q0onDV=@2oiZ@b0;oWXZn0_nQQkP00onTQ[CoWgb]oj9lZ@02oj9lZ@?oY7fX0_nVOjX3ojIiX@?o
YgbT00?oZ86ZojQhW_nYO:800onYO:800onZPZWo[7ZNojajWP03ojaoY0?o[WnQ0_n^QJP01?nbPIoo
/HJVok66Y_naQZH4okF9YP05okB@/OnjSZSo^XjXokZ>Z?ngU;800_noUZd01OnkV[KoaJ2colFP/oo5
X;?o_j>l00;obJ^l00Go`Jc5ol^gaoo;]lOobkO7ol6ecP02olS1d`04olc@gOo2a]go`/KMol;6g@?o
^/OT00Ko]<;T0000000000000000ok31i_n^`NP4ojbni`03oj^li_nY^NGoYkKS00;oYkKS0_nV/^40
0onQYMWoWYkDoijNe003oibHc`;oVi?;0onJSlL2oi^=a0?oW8c200?oWHc1oib3]onPQkT00_nPQkT3
ojF=^`03ojVC_`00003o]Z3200?o]Z3200?o^ZW9olJfboo6]//00oo@c]L01?oGgMcoc][RolgPi_o=
h>H2olOOjP05okgDjonhcnco^<o/ok;8jon_a>X01?n/`NT00`00003oooooooooo`0Looooo`002Ooo
ool01000003ooooooooooooooon]000000Cooooo00<00000ooooooooool05?ooool00`00003ooooo
ooooo`06ooooo`;oSj7Q0_nDV=@2oiZ@b0;oWXZn00CoXHNhoiYn]?nOO:goWgb]1?nRO:T2ojAmZ003
ojIoZ_nTMj3oYWVQ00?oYWVQ0_nWO:@3ojQhWP?oZGbR0on/NYh3ojaoY0?o[WnQ00Co[XFXok:1Wonb
PIoo/X6O0_naQZH01?ngQJ3o]HVVokF9Y_neRJH4okZ>Z0?o_iJ]1?o5X;<3olV[_006omJn`_o;]lOo
bkO7ol^gaooDb]3ob<7C0oo<d=d00oo2a]go`LoUol7?i@0300000004okS;j?nca>Oo/LGYok75j@;o
[/7X0_n/_^L2oj^liP;oZKWU00?oYkKSoj>[gOnQYMT00onQYMT2oijNe0;oW9S?0onKTl/2oiZ?a`03
oi^=a?nFOkSoVH2g00;oVH2g0_nLPkL3oj27^@?oYHfk0_n`U[`01000003o]Z32okJP`_o2Zl@3olJf
b`06om?8coo@c]OoemgLomOMg?oHj>3ocN3V0_o7gnX2ol3Jk003okS?k?nbb^_o[lCZ00;o[lCZ0_n/
`NT00on[_nT00000ooooo`0Mooooo`002Oooool01000003ooooooooooooooon]000000Cooooo00<0
0000ooooooooool05?ooool00`00003oooooooooo`07ooooo`;oJIc^00?oLi;RohB9dOn4RM400_nA
Pl02oiYn]0;oWgb]1?nRO:T2ojAmZ0;oY7NP1?nVNJ42ojMlY0?oZ7RN0onYO:83ojajWP;o[7nT00Co
[gbKojioXOn^Oj7o[WnQ1?nbPIl00onaQZKo]hFPokN5X003okF9YPCo^XjX0onoUZd4olFP/`03om:_
]_o9ZkcobJ^l00;oe[k200CobkO7omC:d?oDb]3oen3N0_o<d=d01Oo8g>P0000000000000003o_=?/
00;o^<_X0_ncb^/00onaaNWo[L?Zojboj002ojboj0;oZkcV00?oYkKTojFahOnU/N400onSZmd3oj6U
f@04oijNe?nFRlKoU8G1oiB5`@?oTh6m0_nDOkX3oiIo^0;oVH2g0onLPkL3oj27^@06ojF=^onZSKOo
/9Jlok2F_000003o]Z320oo2Zl@01_o6]/_odlS?om?8cooNgMCoemgLomSXh0;oe>cU00?oc>W[ol3J
k?o0f^`00_nidnd2ok;:j`03ojo4j_n/`NWo[<7Y00;oZkoY00?oZ[kX00000?ooool07?ooool000Wo
oooo00@00000oooooooooooooooo[@000004ooooo`0300000?oooooooooo01Cooooo00<00000oooo
ooooool02?ooool2ofVLkP04og>Bh_n4RM7oTH?0oi63`0;oVWjd0onOO:d3oj9lZ@03ojAmZ?nRMZ;o
Y7NP00;oY7NP0onVNJ400onWO:CoZ7JLojQhWP02ojQhWP;oZGbR00GoZgRJojajW_n/NYko[7ZNojao
Y003ojmlV`;o[WnQ1?nbPIl00onaQZKo]hFPokN5X002okF9YP;o_HbR0_njSZP2olBEYP03oknF[Oo;
XJcobj6/00;oaJ2c0_oB[kH01_o9Zkcoe[k2omJn`_oF_/;ohM[?omC:d0;oen3N0`000002okkNl006
okcCk?ndd>oo]=3_okC@koncb^_o[/K/0on]`nX00on/_nSoZK_VojVkiP03ojNfi0;oYK7Q00?oXj_M
oi^KdonHTl`00_nHTl`2oiJ;aP?oU8G10_nCPKd2oiAo^P?oUWnh0onIP;L2oib3]`;oX8Ni00CoY8Fc
ojZ=]onZSKOoZXfg0_n`U[`01P00003o`Z_4ol:[a?o2ZlCodKk7om?8c`;og]gD00?ohnkGomogf_oD
k>D00_o<jN/01?o3h>ko^M?]okWCkOncbn`3ojo5jP03ojc1jOn[_nWoZ[kX00;oZ[kX00?ooooo0000
0?ooool06oooool000Wooooo00@00000oooooooooooooooo[@000004ooooo`0300000?oooooooooo
01Cooooo00<00000ooooooooool02Oooool01?lDPNKo1VkNohB9dOn4RM42oi63`0;oVWjd0_nOO:d2
oj9lZ@03oiifY_nRMZ;oXWJR00?oY7NP0onVNJ42ojQfW0?oZ7RN00?oZGbRoj]hV_n[N9X00on/NYh4
ojmlV`03ojioXOncOi_o/X6O00?o/X6O1?ngQJ001?neRJKo_HbRokf<X_njSZP3olBEYP04oknF[Oo;
XJcobj6/olFP/`?odZnf0ooF_/82on7Jc`<0000000Coc>k[ok[Zm?njj_Co_]k`0_nceo<2okC@k`;o
[/W^0_n^a^`00on]`n[oZ[kXojZnj003ojVkiP04ojNfi?nRZmkoWZ?IoijSf@?oVi_C0onHTl`2oiJ;
aP;oU8G10onCPKd2oiAo^P?oUWnh0_nIP;L00onLPkOoWWnaojB5/`02ojB5/`?oZXfg00Go/9Jlok^P
_OnkX;d00000ol:[a002om6na`07on;Gc?oNgMCohnkGon?^eooOmm[oeoOQolcYj`02ol?PkP?o/l_/
0_n_aNX2ojc2j@;oZkoY0onZ_^P00`00003oooooooooo`0Jooooo`002Oooool01000003ooooooooo
oooooon]000000Cooooo00<00000ooooooooool05?ooool00`00003oooooooooo`0;ooooo`04o`I^
g_l]LMooTH?0oi63`0;oVWjd0_nOO:d00onRO:WoWWJVoiifYP02oj9fXP?oY7NP0_nVNJ401?nVMI_o
Z7JLojQfW?nXMY`2ojQhWPCoZgRJ0_n/NYh4ojmlV`03ojioXOncOi_o/X6O00?o/X6O1?ngQJ03okf<
XP05okZ>Z?o4UJKoa9FVolBEY_noUZd00_o;XJ`01_oM^;;odZnfom:_]_oB[kKohl^oomJn`P<00000
00Gog?KMokolion[lOGoZo7eok[Zm002ojoLm`06ok?Glon/c?3o[<c`ojc<l?n^bNkoZ/?/0on[`NX0
0onZ_^SoY[OUojJgi@03ojBbhP;oXZ_N0_nNXmT3oi^Kd`;oV9?<0_nFRlH3oiB5`@;oTh6m0_nDOkX2
oiIo^003oiAf[onHNJooV7V_00?oWWna0onTQK<2ojZ=]`?o^j2m00T00000om6naooA_/OodKk7on;G
c?o/klcohnkGomogf_oGmn400_o>l>X01?o3h>ko^]G^ok[Ek_ncbn`2ojo5j`;o[<;Y00?oZkoYojZn
j?nZ_^P00_nZ_^P00onY_NSooooo0000000Kooooo`002Oooool01000003ooooooooooooooon]0000
00Cooooo00<00000ooooooooool04oooool00`00003oooooooooo`0=ooooo`03o`1I/omTMm7oI7OA
00;oVWjd00?oWgb]oiIf[_nNMZH00_nNMZH3oj9fXP;oY7NP00?oYWVQojIeVonVMI/00onXMY`2ojQh
WPCoZgRJ00?o[7ZNok1jVOn_O9/00on_O9/00on^Oj7o/gnKok=oV`02ok:1W`03okZ4W?ngQJ3o]hFP
00;o]hFP0onmS:84olBEYP?obj6/0_oM^;802?oB[kH0000000000000003ojo;<okol`ooLm]go_ocW
0_n[lOD2ojOOnP03ojoLmonZc_;oZ/kb00;o[<c`0_nZa>d2oj[3k003oj_1j_nW^nOoY[OU00?oY[OU
00CoY;;RoifTf_nIV]?oVI[C0_nDT<`3oi66a@;oSWjn0_n<NKP3ohae]0;oSW>a0_n@M:l3oiAf[`;o
V7V_0onNOk43ojB5/`03ojZ=]ondU;Oo]9Bg00;o^j2m00?oc;;000000?oA_/L00_oRel`01Oo/klco
io_8omgnbooEo][oc_3Z00;o`n?_00Co^]G^ok?<k?ncc>co[lG[0_n/`NT3oj^oj@?oZ[kX0_nY_NP0
0`00003oooooooooo`0Iooooo`002Oooool01000003ooooooooooooooon]000000Cooooo00<00000
ooooooooool04oooool00`00003oooooooooo`0?ooooo`03ofAgdOn5MkcoQGNl00;oUWJ^0onNMZH3
oj9fXP;oY7NP0onVMI/3ojQfW003ojQhW_n[MiWoZgRJ00?oZgRJ00?o[7ZNok1jVOn_O9/00on_O9/3
ok=oV`;o/X6O0_njQ9`2okN5X004ol6=W_nmS:;o_HbRokf<XPCoa9FV00CodjJYol^Q[?oM^;;ogKRb
0P000002on?;_`03on_bc?noo<?oV=_n00;oV=_n00?oWmkmojG<m?nUc?@00_nWcO@01_nZc_;oZLC]
ojW4kOnYa>goZ/C]ojRnj@?oZ;gX0_nW^nL2ojJgi@04oj6/gonMY=[oWJCJoifTfP;oVI[C0_nDT<`3
oi66a@03ohin__n<NKSoS7Vh00?oS7Fd0_n>Lk43oi1d[`;oU7J_0onHNJl3oiio/@03ojB5/on[R[;o
]9Bg00;o]9Bg00Ko^j2molbb`?o<//3oc;;000000?oRel`2onc_c005onOkb?oEo][ocOGYolgejOo3
hnl00_nie^h01Oncc>co[/G[ojk5jon/`NWoZkoY00GoZ[kX1?nY_NP00`00003oooooooooo`0Hoooo
o`002Oooool01000003ooooooooooooooon]000000Cooooo00<00000ooooooooool04oooool00`00
003oooooooooo`0@ooooo`04ofAgdOn5MkcoUWJ^oiIf[PCoWWJV0_nRMZ82ojAgX0?oYWFK0onXMY`0
0onXN9koZgNIoj]hVP03oj]hVP03ojajW_n`NYWo/7ZI00?o[gbK0oncOi/01?nbPIoo^XBLokZ4W?nj
Q9`2okN5X0;o`HfN00?o_HbRolZHX_o:V:800_o4UJH2om>VZ@<0000000CogKRboo;R_OoSbkoojo;<
0_nEe_h2oiSKoP;oY<Wc00?oYLcdojO2kOnX`nd00_nX`nd2ojW4k@06ojRoj_nX_^WoZ;kYojRnjOnX
_NSoY[OU1?nT/^<2oj6/g`;oWJCJ0_nIV]<2oiB@c0?oTHK50_n>O[h2ohai^0?oS7Fd0_n>Lk42oi1d
[`?oU7J_0_nHNJl2oiio/@04oj>1[_n[R[;oZhZboj^:/P;o]9Bg00Woa:Bjolbb`?o<//3oc;;0on7=
a000003ok>o<onOkb?oEo]X00_o=mNT00oo2iO3o^MK^okWFkP02ok;;k003ojk5jon/`NWoZkoY00;o
ZkoY0_nZ_^P2ojVnj0GoZKgX00<00000ooooooooool05oooool000Wooooo00@00000oooooooooooo
oooo[@000004ooooo`0300000?oooooooooo01?ooooo00<00000ooooooooool04Oooool01?mo003o
QGNloiIf[_nFMZh3oiifYP;oXWJR00?oY7NPojAdWOnVMI/00_nVMI/3ojQfW0;oZgNI1?n[N9X3ok1j
V@;o[gbK00Go]GnIok=oVoncOi_o/gnKok:1W`03okZ4W005okN5X?o1SIko`HfNol6=W_nmS:800_o:
V:801?o4UJH00000000000000003omfh/P;ol^:m00CoU]3lojC4l?nTa?3oY<C`0_nSa_800onTbO?o
Yl7/ojO1k002ojO2k@03ojS3kOnX_n[oZ;oZ00?oZ;oZ00?oZ;kYojNjionW^^L00_nV]nD2ojBbh`03
oifVg?nHW=KoV9cF00;oTY3>0_n=QLH2ohQk_P?oQW>g0_n4K[42ohai^0?oS7Fd0_n>Lk42oi1d[`?o
U7J_0_nHNJl00onNOk7oXh6^oj>1[P03oj^:/P05okBD]oo4Y;[oa:BjolBT^_o<//000_oQcL@01P00
003ojoVdolgk/oo>om7oboOZol;Ul0;o^=G_0_nbbn`2ojk4j`;o[<7Y00?oZkoYojZnj?nZ_^P00_nY
_^P6ojVmj00300000?oooooooooo01Oooooo0009ooooo`0400000?ooooooooooooooojd000001?oo
ool00`00003oooooooooo`0Cooooo`0300000?oooooooooo017ooooo00CoO`00ohEg_?nFMZkoUWJ^
0onNMZH2oj9fXP;oY7BM0onVMI/3ojQfW0?oZgNI0on[N9X3ok1jV@;o[gbK00Co]GnIok=oVoncOi_o
/gnK1?njQ9`01OngQJ3o`HfNol6=W_o1SIko_HbR00<000000ooCYZT00oo/bK7ogKRboo;R_@02oo;R
_@04ojG1k_nTa?3oY<C`ojRojP?oYl3[00?oYl7/ojRnjOnX_^T00_nX_^T2ojRojP06ojRmj?nX_>So
Z;cXojRlj?nW^^OoY;CT0onQ[^43oifVg0;oV9cF0_nBT<h2ohf5aP;oR7^n0_n6LkL2ohA^/@;oQF^]
0on7JZ/2ohic/@?oT7B_0_nDMZl00onHNJooW7V[oj>1[P03oj>1[P;oZhZb1?o4Y;X01ooK_kkohLg4
oo7[`ooajl<00000olkodOo;mnX00_o0i?400onheNoo/LW/ok79k002ojk4j`05oj_0jOnZ_nSoZ[oX
ojZoj?nZ_^P02_nY_NP00`00003oooooooooo`0Fooooo`002Oooool01000003ooooooooooooooon]
000000Cooooo00<00000ooooooooool04oooool00`00003oooooooooo`0Booooo`03ogl00?nFMZko
UWJ^00?oWWJV00CoXWJRoiicX_nTM9goY7BM0onVMI/2ojQfW004ojYfVOn[MiWoZgNIoj]gV@;oZgRJ
00Go/7ZHok1jVOn`NYWo/7ZIojmlV`02okEoV@?o/gnK1?njQ9`2ol6=WP<000000_o:V:83om>VZ@;o
k<Va0_oYmjH00oobh[goYL7^ojRnj@02ojRnj@;oZ;oZ00?oYl3[ojVnjOnY_^T00onX_^T3ojVmj0;o
Z;gX00?oZ;cXojJhi_nV^>H00_nT]>@3oj6^h@04oifVg?nBU=;oRhO:oh^7bP;oTY3>0_n=QLH2ohQk
_P?oQW>g00CoQ6jaohE[[On5JjgoQF^]0_n7JZ/2ohY[Z@?oSfjY0_nELZT3oiaiZ`?oXh6^0_n[R[80
0oniUkCoa:BjolBT^P02om^o_P07oo;R_Ooajl?o/n5lokK^VP00003oaoK/ol3Tl@02okKBk`03ok79
k?n]`n[o[L?Z00?oZl3Y00?oZ[oXojZnj?nZ_^P02onY_NP00`00003oooooooooo`0Eooooo`002Ooo
ool01000003ooooooooooooooon6000000l06ATI60000004ooooo`0300000?oooooooooo01;ooooo
00<00000ooooooooool05?ooool2og5/_@?oTW:[0_nNLj83ojAdW@;oYWFK00?oZ7JLojYfVOnZMYT0
0on[MiT2oj]hVP05ok1jV?n`NYWo/7ZIok1jVOn_O9/00oneOiT2ok=oV`?o^XBL0`000002ol6=WP?o
bYRR00?ogk6Xom>VZOoCYZT00_o/bK400ooYmjKoY[o/ojRnj@03ojRnj@05ojVmj?nY_^SoZKkXojVn
j?nY_^T01_nY_NP01_nX_>OoYk[WojNjionW^^OoY[SVoj:bh`;oWZ[O0onIXMX3oi:DdP03oh^7b_n5
Nl7oQG_100;oP76h0ommJK42ohIc]`;oQ6ja0_n5Jjd2ohMZZ`?oRV^Y0_n?KZT2oiEbZ@?oW7V[0onS
PJh01?n[R[;o^INdokVG]?o4Y;X3om^o_P08oo;R_Oo;jHCo]^jJolKncOo7m^`00000okgPlOnfd^l2
ojo8k003ojg3j_n[`>WoZ[kX00CoZ[kX3?nY_NP00`00003oooooooooo`0Eooooo`002Oooool01000
003ooooooooooooooon2000001H06ATI5@000004ooooo`0300000?oooooooooo01;ooooo00<00000
ooooooooool05?ooool00ol<C<WoLFbmoi9bZ`02oi9bZ`;oWW>R0onTM9d2ojIeV`03ojQfW?nZMYWo
ZWJI00?oZgNI00?oZgRJok1jV?n`NYP00on`NYT4okEoV@03ok=oVonlQYX000000080000000?oaY2M
ol6=W_o1SIh00_o1SIh2olZHXP?ogk6X00?odjJYonc9/OoYmjH00_nY_NP2ojRnj@CoZKgX00?oZKkX
ojVmj?nY_NP01?nY_NP2ojVlj0;oZ;cW00?oYk[WojFgiOnR/^<00_nR/^<2oijZg`?oVJ7J0_nBU=82
oh^7bP04ohEk`On0LKSoP76hoh1a^0;oOFVa0_mlI:`2ohA^/@;oQF^]0_n7JZ/3ohY[Z@;oSfjY0onE
LZT2oiaiZ`?oXh6^0oniUk@3om^o_P;ol^:m00Go0000oj;RS?o4l^ooa?;_00000002ok??kP03ojo8
k?n/`^[o[<;Z00;oZl3Y0onZ_^P>ojVmj00300000?oooooooooo01Cooooo0009ooooo`0400000?oo
ooooooooooooogT0000000?o00000000000000007`0I6AT00ol0000000000000000?000000Cooooo
00<00000ooooooooool04_ooool00`00003oooooooooo`0Eooooo`04og5/_OnBLZ_oTW:[oi9bZ`?o
WW>R0_nTM9d2ojIeV`CoZWJI0_n[MiT00on[N9[o/7ZHok1jV003ok1jV@?o]GnI0`0000001?nlQY[o
^XBLokZ4W?o6T9d3ol6=WP;odIjQ00KobYRRomnaZ?oO/JSogk6Xoo[W[?o/bK4@ojVmj003ojVlj?nX
^nOoYkWV00;oYkWV0_nU]nD00onR/^?oVjONoiBLf002oiBLf0;oS8k@0_n4P<L2ogac_@;oQG_10_n0
LKP2ogeY/@;oO6B/0_mmHZP3ohE[[@;oQfZ[0_n:JjT3ohm^Z@;oUG:Y0onLNJ/00onSPJko[XZ_okVG
]002okVG]006om2_^OoK_kkol^:moo;R_Ol0003oX^:<0_o4l^l2okWKl@0500000?n^aN_o[/G[ojc2
j_n[_nT01?nZ_^P@ojVmj00300000?oooooooooo01?ooooo0009ooooo`0400000?oooooooooooooo
ogP00000900I6ATA000000Cooooo00<00000ooooooooool04_ooool00`00003oooooooooo`0Foooo
o`03og5/_OnBLZ_oTW:[00?oWW>R0_nTM9d2ojIeV`CoZWJI0_n[MiT3ok1jV0;o/7ZI00Ko]h2IokEo
V@0000000000okEoVOncOi/2okb6VP04okZ4W?o6T9goaY2MolJ@W@;o`HfN0_oAWZ401Oo:V:;ogk6X
omnaZ?oO/JSon^N/013oZKgX0_nY_>L2ojRki`03ojNii_nT]NGoXK3R00;oXK3R0_nKYmh3oiBLf0;o
S8k@00?oQ837ogac_OmlLkd00_mgJ;D2oh1a^0;oOFVa0_mlI:`2ogeRZ0?oP6:V0_n7JZ/3ohY[Z@;o
SfjY0_nELZT2oiaiZ`05ojAoZon^RZoo[XZ_ojj:[oniUk@00_o@[kT01?o]eK_ol^:mol;KJoo0o]`2
oko[lP;o^M_a00?o/L_]ojk5j`0000000_n[`NT2oj^oj@03ojZnj?nY_^SoZKkX013oZKgX00<00000
ooooooooool04oooool000Wooooo00@00000ooooooooooooooooM`00000W01TI6@l000001?ooool0
0`00003oooooooooo`0Booooo`0300000?oooooooooo01Kooooo00?oLFbmoi9bZonBLZ/00onNLj82
ojAdW@03ojIeVonXMYcoZWJI00?oZWJI0_n[MiT3ok1jV004ok1jV@0000000000000000?o]GnI0onl
QYX01OnjQ9coaY2MolJ@WOo6T9go`HfN00?odIjQ0ooO/JP2oo[W[13oZKgX00?oZKcWojRkionV^NH0
0_nV^NH2ojBei@04oj6`h_nIYMkoT9WHoi2If0?oQX[?0_mlN/H2ohB0a`03ogac_OmgJ;GoMfRe00?o
Lf2^0_mmJK400omlI:coOF:XogeRZ003oh1RYP;oQ6BU0on:JjT2ohm^Z@03oiEbZOnJMJSoY7n[00;o
Y7n[0on^RZl02?niUkCod:niom2_^Oo]eK_olo:So`000?o0nnWo_n_b0_nfe?001Onabngo[L?[ojg3
jon[`NT0000000CoZ[kX00?oZKkXojVmj?nY_NP04?nY_NP00`00003oooooooooo`0Booooo`002Ooo
ool01000003ooooooooooooooomd000000`06ATI4000000?01TI6@h000001?ooool00`00003ooooo
ooooo`0Booooo`0300000?oooooooooo01Oooooo0_nBLZ/3oiicXP;oY7BM0_nXMY`4ojYfV@03oj]g
VOn`NiWo/7ZH00<000000_ngP9T4okEoV@?o_8JJ00Go^XBLolJ@WOo6T9goaY2Mol6=WP03om6NX@?o
gk6X00?on^N/ojVmj?nY_NP03_nY_NP2ojRli`;oZ;_W00CoY[WVoj>diOnO[^;oWjkR0onIYMh2oi2I
f0?oQX[?00?oO7[6og=/_?mcK;`00_mlLkd2ogMX]@;oLf2^00CoLe^XogeY/OmlI:coO6B/0_mmHZP2
oh1RYP;oQ6BU0on:J:D2oi9^YP?oVWFX0onTOj/2ojj:[`;od:ni0_o]eK/01Oo2ff_o`?_Yok_Rlonk
h_?o]]C`00;o[lS/00Co[L?[oj_0jOn[`>T000000onZ_^PDojVmj00300000?oooooooooo01;ooooo
0009ooooo`0400000?ooooooooooooooofl0000000?o000001TI6@0I6AT02@0I6AT500000003o`00
000c<c<0<c<c00d0<c<c0P00000=01TI6@h000001?ooool00`00003oooooooooo`0Booooo`030000
0?oooooooooo01Oooooo0_lhF<L3oiicXP04ojAdWOnQMZ;oZ7JLojQfW0CoZWJI0`000002ok1jV004
ok1jVOngP9Wo]h2IokN0V@?o]GnI0onlQYX4olJ@W@06ol6=W_oAWZ7odIjQom6NXOo`b:Wogk6X0_oj
ij`@ojVmj003ojRlionW^nOoY[WV00;oY[WV0_nS]>D2oin^hP03oiVUg_n=UmWoPHO@00;oPHO@0_n6
R/l00omlN/KoLfblog=/_002ofeP/`;oMfRe0_mcH:h2og=KZ0;oO6B/0_mmHZP2oh1RYP;oQ6BU0on:
J:D2oi9^YP?oVWFX0onTOj/01on^RZoo`Yjcol:N/oo@[kWokMFkoo?bXol000000_nff?42ok;>k`04
ojo8k?n/`^[o[<;Zoj_0j@;oZ[kX00<00000ojZnj?nZ_^P05OnY_NP00`00003oooooooooo`0Aoooo
o`002Oooool01000003ooooooooooooooom^000000X06ATI0`00000G03<c<`8000002`0I6AT>0000
00Cooooo00<00000ooooooooool04Oooool00`00003oooooooooo`0Iooooo`04ocQHaon>LZooSW:_
ohib[`;oXGJR0onXMY`300000003oj]gVOn`NiWo/7ZH00;o/7ZH00Co/7ZIokN0VOngP9Wo]h2I0_ne
OiT01?o0RI[o_8JJokb6V_nlQYX4olJ@W@?odIjQ0_o`b:T00ooO/JSoZKgXojVmj00?ojVmj0;oZ;cW
0_nW^nL01?nV^NKoXkCUoij^honN[^<3oiJTg`;oSIOI0_n1Qm02ogEfaP03ofYV_?mlN/KoLfbl00;o
KF2c0_mYF:`2og=P[P;oLe^X00CoM5ZUogaT[?mmHZSoOF:X0_n0HZH3ohATY@;oRVRU0_nBKZH3oiYe
Z0?oY7n[0oo2W[<01_oR`kWokMFkoo?bXonjiOCo]]Saojo9k@?o[LC[00?o[<;ZojZojOnZ_nT00onZ
_^P00`00003oZKgXojVmj00EojVmj00300000?oooooooooo013ooooo0009ooooo`0400000?oooooo
ooooooooof`000002@0I6AT3000001`0<c<c00<0000001TI6@0I6AT0200I6AT>000000Cooooo00<0
0000ooooooooool04Oooool00`00003oooooooooo`0Jooooo`03ocQHaon>LZooSW:_00;oXGJR0`00
0003ojYfV@?o/7^I0_n`NYP4okN0V@;o]GnI00Co`8VJokb6V_nlQY[o_8JJ1?o6T9d3om6NX@;ol<RY
4_nY_NP00onX_>OoYk_WojJhiP02ojJhiP;oXkCU0_nN[^<3oiJTg`;oSIOI0_n1Qm000omeM/KoJVJl
ofYV_002og=/_0;oKF2c0_mYF:`2og=P[P03og=KZ?mdFZGoM5ZU00?oOF:X0_n0HZH2ohATY@?oRVRU
0_nBKZH3oiYeZ0;oY7n[0oo2W[<00ooR`kWon>fXo`000002ok;@k`;o[lW]00Go[LC[oj_0jOn[`>Wo
Z[oYojZnj004ojVmj00300000?nY_NSoZKgX01CoZKgX00<00000ooooooooool04?ooool000Wooooo
00@00000ooooooooooooooooJP00000701TI6@0400000?l000000000000000H0<c<c10000002o`00
00`00000200c<c<00`0000006ATI01TI6@0801TI6@d000001?ooool00`00003oooooooooo`0Aoooo
o`0300000?oooooooooo01[ooooo00?o>5S7ohib[`0000000P0000000onQMZ;oZ7JLojQfW003ojYf
V@?o/7^I0_n`NYP4okN0V@06okEoVOo0RI[o`8VJol29V_nlQY[ocINN0oo6T9d2omf/X`04om6NXOo`
b:Wol<RYoo38ZA7oZKgX0_nX_>P2ojNki`04ojJhi_nR]NKoWJkToif^i0?oUJGP0_n:UmX2ogf7dP;o
KWC80_meM/H00omZI[coHUVbof9I/P02ofeP/`;oJER/00?oJ5>Wog=P[_mcFjP00_mdFZD3ogQJX`;o
P6:V0_n4I:D3ohYXY@;oTVjV0onJMJP01?nTOj_o]8j_okB>[oo2W[<2on;3^@04ooS]Z?nbd>oo/]3_
ojg5j`?o[<;Z00?oZl3YojZnj?nZ_^P00_nZ_^P3ojVmj00300000?nY_NSoZKgX01GoZKgX00<00000
ooooooooool03oooool000Wooooo00@00000ooooooooooooooooI`00000901TI6@030000000c<c<0
<c<c00D0<c<c0`00000B04a<C0030000000c<c<0<c<c00D0<c<c00<0000001TI6@0I6AT0200I6AT=
000000Cooooo00<00000ooooooooool04Oooool00`00003oooooooooo`0Iooooo`<0000000CoSW:_
oj5fX_nQMZ;oXGJR0_nXMY`2ojYfV@06ojilW?n`NiWo/7^Iok1kVOn`NYSo^8>J1?ngP9T01OneOiWo
`8VJol29V_o0RI[o_8JJ00;ocINN0_o6T9d2omf/X`03om6NXOo`b:Wol<RY01;oZKgX00?oZ;cXojNk
ionU^NL00_nU^NL2oj:eiP;oWJkT0onEYN02ohZGfP;oOHOB00CoKWC8of1S__mPHkkoJVJl0_mRFK80
1?mLD:_oKF2cofUH[?mYF:`2ofQCY`;oLe^X00KoM5ZUogQJXomhFZ?oN5ZSogiMXon0HZH3ohATY@;o
RVRU0_nBKZH2oiYeZ009ojJ0ZondSZoo]8j_okB>[oo2W[?oh/>iooS]Z?o1eV7o[lW]00;o[LG[0_n/
`^X2ojZoj@03ojZnj?nY_^SoZKgX00GoZKgX00<00000ojVmj?nY_NP05OnY_NP00`00003ooooooooo
o`0>ooooo`002Oooool01000003ooooooooooooooomU000000P06ATI0`00000403<c<`@000005P1<
C4`2000000H0<c<c00<0000001TI6@0I6AT01`0I6AT=000000Cooooo00<00000ooooooooool04Ooo
ool00`00003oooooooooo`0Fooooo`<000000oooool01?n>LZooXGJRoj5fX_nQMZ82ojQfW003ojYf
VOn^O9co[WbL00?o/7^I00?o/7ZHokR3V_ngP9T00ongP9T01OneOiWo`8VJol29V_o0RI[o_8JJ00;o
cINN00CoaY2Momf/XooM[:?ogJbS0_ogkYd00oo`b:WoZKgXojVmj00?ojVmj0;oZ;cX0_nW^nL00onU
^NOoX[KVoif`i@02oif`i@?oU:OR00?oRI[MogZ9eomjRML00_mXM/d2ofidb004of1S__mEE;CoJVJl
of9I/P;oG52[00CoKF2cofUH[?mXDjOoJ5>W0_mcFjP2ogAJY@;oN5ZS0_mnGJ<3ohATY@;oRVRU0_nB
KZH00onJMJSoYX2[ojJ0Z`03okB>[`;oh/>i00Con>fXojo9kOn/`^[o[<;Z0_n[`>T2ojZoj@;oZ[kX
0_nY_^P6ojVmj00300000?nY_NSoZKgX01CoZKgX00<00000ooooooooool03_ooool000Wooooo00@0
0000ooooooooooooooooH`00000701TI6@<00000100c<c<3000000H0C4a<3@0000000ol000000000
0000000604a<C0030000000c<c<0<c<c00@0<c<c00<0000001TI6@0I6AT01P0I6AT=000000Cooooo
00<00000ooooooooool04Oooool00`00003oooooooooo`0Dooooo`8000001_ooool01?n>LZooXGJR
oj5fX_nQMZ82ojQfW0?o[WbL0on`NiT00on`NYSo^8>JokN0V@03okN0V@Co`8VJ00Co_8JJolfGW_o=
UikoaY2M0ooM[:<2ooO^WA;oZKgX00?oZ;cXojNkionU^NL00_nU^NL2oj:fiP03oif`iOnEZ^CoUJ[T
00;oRIkQ0_miS]`2ogZ9e`04ofQfcOmGH/?oEf;3of1S_P;oEEBd00CoHUVboea@ZomLD:_oG52[0_mY
F:`00omXDjOoJU:Sog=KZ002ogAJY@;oN5ZS0_mnGJ<3ohESX`;oSV^U0_nIM:L4ojJ0Z`;o]8j_00Ko
dJjfon;3^Oo;fVOo[LC[ojc2j_nZ_nT5ojZnj0[oZKgX00<00000ojVmj?nY_NP04?nY_NP3ooooo`03
00000?oooooooooo00kooooo0009ooooo`0400000?ooooooooooooooof40000000?o000001TI6@0I
6AT01@0I6AT00`000000<c<c03<c<`0403<c<`030000001<C4`0C4a<00D0C4a<00<00000o`00001V
IVH03`1VIVH00`000000C4a<04a<C00304a<C0030000000c<c<0<c<c00@0<c<c00<0000001TI6@0I
6AT01P0I6AT=000000Cooooo00<00000ooooooooool04?ooool00`00003oooooooooo`0Booooo`<0
00002Oooool3oj5fXP03ojQfW?nXOJKo[WbL00;o[WbL0on`NiT3okR3VP?o]h2I1?o0RIX3olfGWP03
olJ@WOoM[:?ogJbS00;omnjM4_nY_NP2ojRlj0;oYk_W00?oYKWWoj>gionS]nL00onM/^H2oiFZi0;o
RIkQ00?oNHkLofEke?mUNm@00_mXM/d01?mGH/?oAU2hof1S__mEE;@2of9I/P;oG52[0_mYF:`00omX
DjOoJU:SofYBX`02ogAJY@;oN5ZS0_mnGJ<3ohESX`;oSV^U0onIM:L3ojJ0Z`05okB>[ooA[[KodJjf
ooOS/on]a>/00_n[`>T2ojZoj@03ojZnj?nY_NSoZKgX00_oZKgX00<00000ojVmj?nY_NP03_nY_NP5
ooooo`0300000?oooooooooo00kooooo0009ooooo`0400000?ooooooooooooooof0000001`0I6AT2
000000@0<c<c0`00000404a<C0@000000`1VIVH8o`0000P0IVIV00<0000004a<C01<C4`00`1<C4`0
0`000000<c<c03<c<`0303<c<`030000000I6AT06ATI00H06ATI3@000004ooooo`0300000?oooooo
oooo013ooooo00<00000ooooooooool03oooool3000000cooooo0on6O<42ojQmYP?o[WbL0on`NiT3
okR3VP;o]h2I00?oaI2Nol29V_o0RIX00_o0RIX3olfGWP?ogJbS00?omnjMojVmj?nY_NP04OnY_NP0
0onX_>SoYk_XojNkj002ojJji`03oj>gionO]>OoWkCW00;oUjkV0_n<Y>D2ogbFh@;oIXCL00CoIG_D
odmUb_m?IL[oEf;30_m6D;P00omEE;CoCDV/of9I/P02oea@Z`03oe];Y_mYF:coJ5>W00;oJU:S0_m^
Dj800omdFZGoN5ZSogQJX`02ogiMX`;oQF>S0_n>JjD3oiUdY`?oYX2[0ooA[[H00oo;fVOoZl7Zoj_0
j@04ojZnj0koZKgX00<00000ojVmj?nY_NP02OnY_NP:ooooo`0300000?oooooooooo00gooooo0009
ooooo`0400000?oooooooooooooooeh00000200I6AT00`000000<c<c03<c<`0203<c<`800000101<
C4`3000000@0IVIV0ol0000807moO`Co00001@1VIVH00`000000C4a<04a<C00304a<C003o`00000c
<c<0<c<c0080<c<c00<0000001TI6@0I6AT01P0I6AT=000000Cooooo00<00000ooooooooool04?oo
ool00`00003oooooooooo`0<ooooo`<000004?ooool2ohIl`@;oZ7fV0on^O9`3ok1kV@?o^8>J0_ng
P9T00oo5T9ko`8VJol29VP02ol29VP?ocINN00?ol<VYomf/XooM[:<04_nY_NP3ojRlj003ojNkj?nV
^^SoY[[X00?oXkSW0_nO]>L2oiN^iP;oS:CU0_mlU^401omVQ=coBfgCod]]dom?IL[o>4nnoeMR`om6
D;P00_mEE;@00om=BJcoG52[oea@Z`02oe];YP;oJ5>W00CoJU:SofiCX_m^Dj;oKU>R0_mhFZ<2ogiM
X`;oQF>S0on>JjD2oiUdY`?oYX2[00Co_YVbom6^]_oghk?obmYW0_nZ_nT3ojZnj13oZKgX00<00000
ojVmj?nY_NP01OnY_NP=ooooo`0300000?oooooooooo00gooooo0009ooooo`0400000?oooooooooo
oooooe`0000000?o000001TI6@0I6AT0100I6AT00`00003o00000000000303<c<`0300000?l00000
C4a<0080C4a<0`00000306IVIPCo00003`1oOgl00ol00000IVIV06IVIP0306IVIP030000001<C4`0
C4a<0080C4a<00<0000003<c<`0c<c<00P0c<c<00`0000006ATI01TI6@0601TI6@03o`0000000000
000000X000001?ooool00`00003oooooooooo`0@ooooo`0300000?oooooooooo00Wooooo0`00000C
ooooo`;oQWc10onXOJH2ojilW0;o/7^I00Go^HRPokR3V_nhPi[o^8>JokN0V@03olF@WP;o`8VJ00?o
ejJTolfGW_o=Uih00oo`bJT00oogkYgoZKgXojVmj00AojVmj0CoZ;cX0_nV^^P00onS^>OoXKOXoiZb
j002oiZbj0;oT:[W00?oPYoVofb@i?m/T>@00_m?O=h02Om;KM?o;5C8odmUb_lhCkkoAU2hocY2[omE
E;CoCDV/odU2Y`02oea@Z`03oe];Y_mXDjOoJ5>W00;oJU:S0_m^Dj801?meF:;oN5ZSogiMXomnGJ<3
ohESX`;oSV^U0onIM:L01OnVP:_o_YVbokjI/_oA[[Komn>c00;oZ[oY0_nY_^PBojVmj00400000?nY
_NSoZKgXojVmj17ooooo00<00000ooooooooool03Oooool000Wooooo00@00000oooooooooooooooo
G000000601TI6@030000000c<c<0<c<c0080<c<c0P00000304a<C08000000`1VIVH3o`0000@0Ogmo
2ol0000407moO`03o`00001VIVH0IVIV00<0IVIV00<0000004a<C01<C4`00P1<C4`00`000000<c<c
03<c<`0203<c<`030000000I6AT06ATI00D06ATI3P000004ooooo`0300000?oooooooooo013ooooo
00<00000ooooooooool01_ooool3000001Oooooo0_n6O<42ojQmYP;o[WbL00?o/7^IokV8X?niR:00
0onhPiX01?ngP9WoaI2NolF@W_o5T9h2ol29VP;oejJT00CocINNoo39ZOo`bJWol<VY4_nY_NP5ojRl
j004ojNkj?nT^NSoY;WXojBij0;oXKOX00CoV[;XoiJ`jOn9ZN[oRJWZ0_mgW^X2ofb@i005odmlg_lY
H]CoBfgCobaDb?lhCkh00_m6D;P02?lj@ZooCDV/ode9[?m9@ZOoG52[oe];Y_mLBZ?oJ5>W0_mZDZ<2
ofiCXP;oMERR0omnGJ<2ohESX`;oSV^U0_nIM:L01_n[QZko_YVbokjI/_nnVK;oj<fkomoXO`;oZ[kX
00?oZKkXojVmj?nY_NP04_nY_NP00`00003oooooooooo`0Aooooo`0300000?oooooooooo00gooooo
0009ooooo`0400000?oooooooooooooooe/000001@0I6AT2000000<0<c<c0P00000304a<C0800000
0P1VIVH3o`0000<0Ogmo1?l0000;09VIV@;o00000`1oOgl00ol00000IVIV06IVIP0206IVIP030000
001<C4`0C4a<0080C4a<00<0000003<c<`0c<c<00P0c<c<00`0000006ATI01TI6@0501TI6@h00000
1?ooool00`00003oooooooooo`0@ooooo`0300000?oooooooooo00?ooooo0`00000Jooooo`;oQWc1
0_nXOJH2ojilW003ok1kVOniR:3o^HRP00?o^8>J00Go]h2IolF@W_o5T9koaI2Nol29VP03omNVY004
olfGW_o`bJWol<VYoo39ZA?oZKgX1?nX_>P2ojNkj003ojBij?nR^NSoX[WX00;oWKGY0_nF/>T2ohVY
jP;oMikZ00_oG8kXocAhh_ldN>;o:F;DobaDb?l:>[[o>4nnodI@^?lj@Zoo<CRYode9[002odU2Y`03
oe];Y_mLBZ?oG4ZS00;oJU:S0_m^Dj82ogEHXP?oOenT0_n5Hj<2ohi[Y@03oiUdYon[QZkoZhJ^00?o
_YVb00?oj<fkojZnj?nZ_^P04_nY_NP5ooooo`0300000?oooooooooo013ooooo00<00000oooooooo
ool03Oooool000Wooooo00@00000ooooooooooooooooF@00000501TI6@8000000`0c<c<2000000<0
C4a<0P00000206IVIP;o00000P1oOgl4o`0000<0VIVI2Ol0000509VIV@05o`00001oOgl0Ogmo07mo
Ool000000`1VIVH00`000000C4a<04a<C00204a<C003o`00000c<c<0<c<c0080<c<c00<0000001TI
6@0I6AT0100I6AT?000000Cooooo00<00000ooooooooool03oooool01000003oooooooooooooool3
000001kooooo00?oQWc1ojQmY_nXOJH00_n^O9`4okV8X0;o^8>J1?o5T9h01?o0RI[oejJTomNVY?oG
YZ@3oo39ZAKoZKgX00?oZ;cXojNlj?nW_>P00_nU^nP00onR^NSoXKSYoi^ej`02oi^ej`;oTK7/0_n3
Z^h2ofjPk`07odfAk_ldN>;o05OBo`1Gd_l0@/Co2SZjob8l]002ocY2[`03oc4hZOm9@ZOoBD:W00;o
Fd^V00?oG4ZSof5<X_mZDZ<00_m^Dj82ogEHXP?oOenT0_n;JJH00on>JjGoVGJYoj^6[P03oj^6[P04
okjI/_oXcK_ognQoojVnj17oZKgX2?ooool00`00003oooooooooo`0?ooooo`0300000?oooooooooo
00gooooo0009ooooo`0400000?oooooooooooooooeH0000000?o000001TI6@0I6AT0100I6AT00`00
0000<c<c03<c<`0203<c<`030000001<C4`0C4a<0080C4a<00<00000o`00001VIVH00_l0000207mo
O`;o0000102IVIT3o`0000T0/k>c00?o000009VIV@2IVIT00P2IVIT01Ol00000Ogmo07moO`1oOgoo
000000<0IVIV00<0000004a<C01<C4`00P1<C4`00`000000<c<c03<c<`0203<c<`030000000I6AT0
6ATI00@06ATI3`000004ooooo`0300000?oooooooooo00oooooo1000000Rooooo`;oZ7fV00?o[WbL
okJC/oniR:000oniR:02okR3VPCoaI2N00Ko`8VJomNVY?oGYZCoejJTom7ZQOo`bJTEojVmj0?oZ;cX
00?oYkcXojJlj?nT^^T00_nT^^T2oj6hj@03oi^ejonI]^coSk?_00;oSk?_0_n1[_82ofZWm@08odNL
m?lKNNGo05OBo`0[[Ol:>[[o022[o`l/Zolj@Zl2oc4hZ@04odU2Yom9@:CoFd^Voea:X`;oHDbR00Co
JU:SofiCX_m^Dj;oMERR0omoGj@2oh]YYP?oVGJY0on[QZh00onnVK;oj<fkomoXO`0>ojVmj0cooooo
00<00000ooooooooool03oooool00`00003oooooooooo`0=ooooo`002Oooool01000003ooooooooo
oooooomF000000H06ATI00<0000003<c<`0c<c<00P0c<c<010000000C4a<04a<C01<C4`200000080
IVIV00?o000007moO`1oOgl00_l0000309VIV@?o0000302c/k<00ol00000VIVI09VIV@0209VIV@05
o`00001oOgl0Ogmo07moOol000000`1VIVH00`000000C4a<04a<C00204a<C0050000000c<c<0<c<c
03<c<`0000001`0I6AT?000000Cooooo00<00000ooooooooool03oooool00`00003o0000ooooo`0T
ooooo`03obNGk_nfTk?o]Y>c00Co^HRP00?o^8>JolbOZ?o5T9h00oo5T9h4omNVY003om7ZQOnY_NSo
ZKgX01GoZKgX0onX_>P2ojJlj003ojBjjOnS^^WoXk[Y00;oWkW[0_nI]^`00on?/nooT;Oaoi2gl@02
oh>em@;oKk;i00OoCjcio`n5i?l?QNCo02^]o`Xj^_l08:_o3bb[00;o<CRY00?oBD:WodU0Y?m9@:@0
0_mLBZ<2of5<XP;oKU>R00CoMERRogmOY?moGjCoOenT0_n;JJH3oiUfZ@?oZhJ^00?ock6konS=^onY
_NP03?nY_NP?ooooo`0300000?oooooooooo00oooooo00<00000ooooooooool03?ooool000Wooooo
00@00000ooooooooooooooooE@00000601TI6@030000000c<c<0<c<c0080<c<c00D0000004a<C01<
C4`0C4a<0000000206IVIP;o00000P1oOgl01?l00000VIVI09VIV@2IVIT2o`0000@0/k>c1ol00005
0;>c/`03o`00002IVIT0VIVI0080VIVI00Co000007moO`1oOgoo00000`1VIVH01@000000C4a<04a<
C01<C4`0000000@0<c<c00<0000001TI6@0I6AT0100I6AT@000000Cooooo00<00000ooooooooool0
4Oooool00ol0003oooooooooo`0Rooooo`04obNGk_nfTk?o]Y>cokJC/`?o^HRP00?o^8>JolbOZ?o<
WjP00oo5T9h3omNVY003om7ZQOnY_NSoZKgX01OoZKgX00?oZ;cXojNlj?nW_>P00_nV^nT00onS^^Wo
Xk_Zoj>kjP02oinjk0;oVKS^00?oT;Oaoi>kl_nC^o800_n9_?L2og^mo0;oI[kn0_m7^_D2o`0PZ`05
o`l/Zola>:Wo;3:UodU2Yom9@:@00_mLBZ<2of5<XP04ofUAXom^Dj;oMERRogEHXP;oOenT0_n;JJH3
oiUfZ@?oZhJ^00?ock6koo;cYonY_NP02?nY_NPDooooo`0300000?oooooooooo00kooooo00<00000
ooooooooool03?ooool000Wooooo00@00000ooooooooooooooooE000000501TI6@8000000`0c<c<2
00000080C4a<00<00000o`00001VIVH00_l0000207moO`;o00000P2IVIT2o`000080/k>c1?l00007
0<c<c0;o0000102c/k<01Ol00000VIVI09VIV@2IVIWo00000080Ogmo00Go000006IVIP1VIVH0IVIV
0000000304a<C0050000000c<c<0<c<c03<c<`0000001`0I6AT00ol0000000000000000=000000Co
oooo00<00000ooooooooool04_ooool00ol0003oooooooooo`0Rooooo`03obNGk_nfTk?o]Y>c00?o
^HRP00?o^8>JolbOZ?o<WjP00_o5T9h2ong>]003omNVY?oAjXGoZKgX01OoZKgX0onX_NP2ojNlj0?o
YKcY00?oXk_Zoj>ljonO^n`00_nO^n`2oiZkk`03oi>kl_nI_o;oVKob00;oT/;g00CoRlGkoiS8n?nH
b?SoV<Sh0_nEcO/02?l08:_o3bb[oc4hZOla>:WoBD:WodU0Y?m=@ZCoG4ZS0_mQC:82ofUAX`;oMERR
0omoGj@2oh]YYP?oVGJY00?oZhJ^olna^oo?/K/01OnY_NPJooooo`0300000?oooooooooo00gooooo
00<00000ooooooooool03?ooool000Wooooo00@00000ooooooooooooooooD`00000501TI6@030000
000c<c<0<c<c0080<c<c00<0000004a<C01<C4`00P0000000`1VIVKo0000o`00000207moO`;o0000
00D0VIVIo`000?l0003o00000;>c/`03o`0000`0c<c<00?o00000;>c/`2c/k<00P2c/k<01Ol00000
VIVI09VIV@2IVIWo00000080Ogmo00Go000006IVIP1VIVH0IVIV0000000304a<C0050000000c<c<0
<c<c03<c<`0000001P0I6ATA000000Cooooo00<00000ooooooooool04oooool00ol0003ooooooooo
o`0Qooooo`03obNGk_nfTk?o]Y>c00;o^HRP00GofMWHolbOZ?o<WjSoc9nXolF@WP03ong>]003omNV
Y?ooooooZKgX01SoZKgX0onX_NP2ojNlj0?oYKcY0_nS_>/00onO^ncoXKg]oj6mk@02oifnk`03oiVo
l_nN`O7oW/7a00?oVlCd00[oV<Shoj77lonQao?oXL[eojK6l?l08:_o3bb[oc4hZOl/<ZGoBD2T0_m=
@Z@01_mLBZ?oHDbRofUAXomYDJ?oME^VogEHXP?oOenT0_n;JJH2oiUfZ@04ok>D]oo?/K_ock6koo;c
Y`?oZKgX7?ooool00`00003oooooooooo`0=ooooo`0300000?oooooooooo00cooooo0009ooooo`04
00000?oooooooooooooooe8000001@0I6AT00`000000<c<c03<c<`0203<c<`040000001<C4`0C4a<
00000080IVIV00Go000007moO`1oOgl0Ogmoo`00000209VIV@03o`00002c/k<0/k>c00;o00001P3<
c<`5o`0000D0c<c<00Co00000;>c/`2c/k?o00000`2IVIT01?l00000Ogmo07moOol0000306IVIP05
0000001<C4`0C4a<04a<C00000000`0c<c<00`0000006ATI01TI6@0401TI6A8000001?ooool00`00
003oooooooooo`0Dooooo`;o00008_ooool2okJC/`03okV8X?oIfMSofMWH00?oc9nX00CoaI2Nong>
]?o]c[CokLjd0ooooolIojVmj0?oZ;gX0_nW_>T00onU_>WoY[gZojJmjP02ojBmj`03oj6mkOnS_^co
Xkk/00;oXKo^00CoW/7aoj?2konS`^ooXl;_0_nRa?402?nQao?oY/C_ojK4konVa_3oZ<;/o`07VOl0
7jGo;3:U0_m9@:@2ode2Y0;oHDbR00?oJE6SogEKY_meFjH00omoGj@2oh]YYP06oiUfZOncU;Oo/iBg
ok>D]oo?/K_ol_>W8?ooool00`00003oooooooooo`0<ooooo`0300000?oooooooooo00cooooo0009
ooooo`0400000?ooooooooooooooodl0000000?o00000000000I6AT0100I6AT00`000000<c<c03<c
<`0203<c<`040000001<C4`0C4a<00000080IVIV00Ko000007moO`1oOgl0Ogmoo`00002IVIT2o`00
0080/k>c00?o00000<c<c03<c<`00P3<c<`4o`0000D0i^KV00?o00000<c<c03<c<`00P3<c<`01?l0
0000/k>c0;>c/ol0000309VIV@04o`00001oOgl0Ogmoo`000080IVIV00Go000004a<C01<C4`0C4a<
o`00000303<c<`030000000I6AT06ATI00@06ATI4`000004ooooo`0300000?oooooooooo01Kooooo
00?o0000ooooooooool08oooool2omWIf0;oc9nX0_ooool00oo]c[Coooooooooo`03oooooaWoZKgX
0onX_NP2ojNmj@?oY[gZ0_nU_N/01?nS_^coYKo/ojFok?nU_n`2ojC0k@03oj?2konV`NgoY/7]00;o
Y/?^00WoY/C_ojS2k?nX`^coZ<;/ojW0j_l07jGo;3:Uob/cY_m9@:@00_m=@Z@2of5<XP03ofUAXome
FjKoME^V00?oQFV[00?oRfVVoiYk/?ncU;L00oncU;L00oo/i<Soooooooooo`0Pooooo`0300000?oo
oooooooo00_ooooo00<00000ooooooooool03?ooool000Wooooo00@00000ooooooooooooooooC`00
000601TI6@030000000c<c<0<c<c0080<c<c00Co000004a<C01<C4co00000`1VIVH01_l00000Ogmo
07moOol00000VIVIo`0000<0/k>c00Co00000<c<c03<c<`0c<c<0_l000090>KViP03o`00003<c<`0
c<c<0080c<c<00Co00000;>c/`2c/k?o00000`2IVIT00ol00000Ogmoo`00000306IVIP040000001<
C4`0C4a<000000@0<c<c00<0000001TI6@0I6AT0100I6ATC000000Cooooo00<00000ooooooooool0
5oooool00ol0003oooooooooo`0Tooooo`03olbOZ?oooooooooo00Sooooo5onY_NP6ojRmj0;oYkgY
00?oY[gZojNmjOnW_NT00_nV_^/00onU_ncoYko[ojNoj`02ojK0k003ojK1kOnX`>_oZ<3[00;oZ<7/
00SoZ<;/ojW0j_nY`>[oZL3ZojVnjOl06:;o;3:UodU0Y0;oCD:T00CoETVWof5<X_mYDJ?oJE6S0_me
FjH2ohEYZ`;oVW^`1?ncU;L00oo/i<Soooooooooo`0Qooooo`0300000?oooooooooo00[ooooo00<0
0000ooooooooool03?ooool000Wooooo00@00000ooooooooooooooooCP00000601TI6@030000000c
<c<0<c<c0080<c<c00@0000004a<C01<C4`000000`1VIVH01_l00000Ogmo07moOol00000VIVIo`00
00<0/k>c00?o00000<c<c03<c<`00_l0000;0>KViP05o`00003<c<`0c<c<0<c<c?l000000P2c/k<0
1Ol00000VIVI09VIV@2IVIWo00000080Ogmo00Co000006IVIP1VIVH000000`1<C4`01@000000<c<c
03<c<`0c<c<0000000H06ATI50000004ooooo`0300000?oooooooooo01Sooooo00?o0000oooooooo
ool0;ooooolGojVmj003ojRmj?nY_NSoZKgX00;oZ;gX0onX_NT00onW_NWoZ;kYojNnjP02ojNnjP03
ojNojonX_^[oZ;kZ00;oZ;oZ00?oZ<3[ojVojOnY_nT00_nY_nX01onY`>[oZKkYojVnjOnY_^Wo01nU
ob`bYOl[<jH00_m=@Z@2oeI9Y`;oJE6S0_meFjH2ohEYZ`?oVW^`0_ncU;L00oo/i<Soooooooooo`0R
ooooo`0300000?oooooooooo00_ooooo00<00000ooooooooool02oooool000Wooooo00@00000oooo
ooooooooooooC@00000601TI6@030000000c<c<0<c<c0080<c<c00@0000004a<C01<C4`000000`1V
IVH01_l00000Ogmo07moOol00000VIVIo`0000<0/k>c00Co00000<c<c03<c<co0000303Vi^H00ol0
0000c<c<0<c<c0020<c<c004o`00002c/k<0/k>co`000080VIVI0_l000001@1oOgoo000006IVIP1V
IVH0000000<0C4a<00@0000003<c<`0c<c<0<c<c0P00000501TI6@03o`0000000000000001800000
1?ooool00`00003oooooooooo`0Iooooo`;o0000<?oooolJojVmj0;oZ;gX0onX_NT2ojRnj@04ojNn
j_nX_^WoZ;kYojRnjPCoZKkY00?oZKoYojVnjOnY_^T00onY_^T3ojVnj003o`0HX_l[<jKo<3Z[00;o
CD:T00?oETVWofAF[?mYDJ<00_meFjH3ohEYZ`;oVW^`00?o/iBgoncTb?o/i<P09Oooool00`00003o
ooooooooo`0:ooooo`0300000?oooooooooo00_ooooo0009ooooo`0400000?oooooooooooooood/0
000000?o000001TI6@0I6AT0100I6AT01_l00000<c<c03<c<`0c<c?o000000000080C4a<00<00000
06IVIP1VIVH00_l0000207moO`04o`00002IVIT0VIVIo`000080/k>c00Go00000<c<c03<c<`0c<c<
o`00000<0>KViP05o`00003<c<`0c<c<0<c<c?l000000P2c/k<01?l00000VIVI09VIVOl0000207mo
O`04o`00001VIVH0IVIVo`0000<0C4a<00Go000003<c<`0c<c<0<c<c0000000701TI6AD000001?oo
ool00`00003oooooooooo`0Kooooo`03o`000?oooooooooo02kooooo7?nY_NP00onX_NWoZKgXojVm
j003ojRnj@SoZKkY1OnY_^P2ojVmj006o`0HX_l05ZCo:c>Voc0jZom=@ZCoETVW0_mTEZ`3ogEKYP;o
QFV[0_nJNk02olFhcBOooooo00<00000ooooooooool02Oooool00`00003oooooooooo`0;ooooo`00
2Oooool01000003ooooooooooooooom<000000H06ATI00D0000003<c<`0c<c<0<c<c0000000304a<
C0040000001VIVH0IVIVo`000080Ogmo00Co000009VIV@2IVIWo00000P2c/k<01Ol00000c<c<0<c<
c03<c<co000000`0i^KV00Go00000<c<c03<c<`0c<c<o`0000030;>c/`03o`00002IVIWo000000<0
Ogmo00?o000006IVIP0000000`1<C4`01@000000<c<c03<c<`0c<c<0000000L06ATI5P000004oooo
o`0300000?oooooooooo01cooooo00?o0000ooooooooool0;_oooolOojVmj0;oZKkX00?oZKkYojVn
j?nY_^P00_nY_^P00onY_^WoZKkXojVnj003ojVnj0?oZKgX0_ooool01?l06:;o01JToc0jZol`>Z/2
oeI9Y`04ofAF[?mjJkKoNV^fogY[]P;oQFV[00CoVW^`olFhcOo5^<goaKS=:?ooool00`00003ooooo
ooooo`08ooooo`0300000?oooooooooo00_ooooo0009ooooo`0400000?oooooooooooooood/00000
1P0I6AT01@000000<c<c03<c<`0c<c<0000000<0C4a<00@0000006IVIP1VIVKo00000P1oOgl01?l0
0000VIVI09VIVOl000020;>c/`05o`00003<c<`0c<c<0<c<c?l00000303Vi^H01Ol00000c<c<0<c<
c03<c<co000000<0/k>c00?o000009VIVOl000000P1oOgl2o`00000306IVIP000000C4a<0080C4a<
00D0000003<c<`0c<c<0<c<co`00000701TI6AL000001?ooool00`00003oooooooooo`0Mooooo`03
o`000?oooooooooo02kooooo8OnY_NP00onY_^SoZKgXojVmj002ojVmj003ojVnj?nY_NSoZKgX00?o
ZKgX1Oooool2o`0FY003oc0jZollBkSoETVW00;oI5J/0_mjJkH2oiZ;`P?oaKS=:Oooool00`00003o
ooooooooo`08ooooo`0300000?oooooooooo00_ooooo0009ooooo`0400000?ooooooooooooooodP0
000000?o00000000000I6AT0100I6AT00ol00000000003<c<`0203<c<`050000001<C4`0C4a<04a<
C00000000P1VIVH01?l00000Ogmo07moOol0000209VIV@04o`00002c/k<0/k>co`0000<0c<c<00?o
00000>KViP3Vi^H02@3Vi^H2o`000080c<c<0_l000001P2c/k?o0000o`000?l00000VIVIo`000080
Ogmo00Co000006IVIP1VIVH000000`1<C4`01@000000<c<c03<c<`0c<c<0000000H06ATI00<00000
o`00000000005P000004ooooo`0300000?oooooooooo01kooooo0_l0000_ooooobOoZKgX2oooool0
0ol`>Z_o?4^hoca;^002ofAF[0?oNV^f0_nJRl800oo5^<goooooooooo`0Yooooo`0300000?oooooo
oooo00Oooooo00<00000ooooooooool02oooool000Wooooo00@00000ooooooooooooooooB@000006
01TI6@050000000c<c<0<c<c03<c<ol000000`1<C4`010000000IVIV06IVI_l0000207moO`05o`00
002IVIT0VIVI09VIVOl000000P2c/k<00ol00000c<c<0<c<c0020<c<c003o`00003Vi^H0i^KV00L0
i^KV00Go00000<c<c03<c<`0c<c<o`0000020;>c/`05o`00002IVIT0VIVI09VIVOl000000P1oOgl0
1Ol00000IVIV06IVIP1VIVH000000080C4a<00<0000003<c<`0c<c<00P0c<c<00`0000006ATI01TI
6@0401TI6AT000001?ooool00`00003oooooooooo`0Pooooo`03o`000?oooooooooo02gooooo8_nY
_NP@ooooo`04oc0jZollBkSoEg3@oeM`d0?oNV^f00?oVX_2okcmeoooool0;?ooool00`00003ooooo
ooooo`07ooooo`0300000?oooooooooo00[ooooo0009ooooo`0400000?ooooooooooooooodP00000
1P0I6AT00`000000<c<c03<c<`0203<c<`040000001<C4`0C4a<000000<0IVIV00Co000007moO`1o
Ogoo00000P2IVIT01Ol00000/k>c0;>c/`2c/k?o000000D0c<c<00?o00000>KViP3Vi^H0103Vi^H2
o`000080c<c<0_l000020;>c/`03o`00002IVIT0VIVI00;o00000P1oOgl00ol00000IVIV06IVIP02
00000080C4a<00<0000003<c<`0c<c<00P0c<c<00`0000006ATI01TI6@0401TI6AX000001?ooool0
0`00003oooooooooo`0Qooooo`03o`000?oooooooooo02kooooo7_nY_NPCooooo`;o?4^h0_mGL=00
0omjJkKoS[_eohjkm@0_ooooo`0300000?oooooooooo00Kooooo00<00000ooooooooool02_ooool0
00Wooooo00@00000ooooooooooooooooB000000601TI6@050000000c<c<0<c<c03<c<`0000000`1<
C4`010000000IVIV06IVI_l0000207moO`05o`00002IVIT0VIVI09VIVOl000000P2c/k<00ol00000
c<c<0<c<c0050<c<c0Ko00000`3<c<`01Ol00000/k>c0;>c/`2c/k?o00000080VIVI00Go000007mo
O`1oOgl0Ogmoo`00000206IVIP050000001<C4`0C4a<04a<C00000000`0c<c<2000000H06ATI00?o
000000000000000060000004ooooo`0300000?oooooooooo02;ooooo00?o0000ooooooooool0;_oo
oolIojVmj1Wooooo0omGL=000on>^oGoooooooooo`0^ooooo`0300000?oooooooooo00Kooooo00<0
0000ooooooooool02_ooool000Wooooo00@00000ooooooooooooooooA`00000601TI6@030000000c
<c<0<c<c0080<c<c00@0000004a<C01<C4`000000`1VIVH01?l00000Ogmo07moOol0000209VIV@05
o`00002c/k<0/k>c0;>c/ol000003@3<c<`3o`0000<0/k>c00Go000009VIV@2IVIWo000007moO`03
o`00000306IVIP00003o000000<0C4a<00Go000003<c<`0c<c<0<c<c0000000601TI6Ad000001?oo
ool00`00003oooooooooo`0Sooooo`03o`000?oooooooooo02kooooo5?nY_NQBooooo`0300000?oo
oooooooo00Gooooo00<00000ooooooooool02_ooool000Wooooo00@00000ooooooooooooooooA@00
00000ol000006ATI01TI6@0401TI6@03o`00000c<c<0<c<c00<0<c<c00@0000004a<C01<C4`00000
0`1VIVH01?l00000Ogmo07moOol0000209VIV@05o`00002c/k<0/k>c0;>c/ol00000303<c<`01?l0
0000/k>c0;>c/`2c/k<3o`00000509VIVOl0003o000007moOol000000`1VIVH010000000C4a<04a<
C01<C4`2000000<0<c<c00<0000001TI6@0I6AT0100I6ATN000000Cooooo00<00000ooooooooool0
9?ooool2o`0002oooooo4?nY_NQFooooo`0300000?oooooooooo00Cooooo00<00000ooooooooool0
2_ooool000Wooooo00@00000ooooooooooooooooAP00000601TI6@030000000c<c<0<c<c0080<c<c
00@0000004a<C01<C4`000000`1VIVH01Ol00000Ogmo07moO`1oOgoo000000<0VIVI00Co00000;>c
/`2c/k<0/k>c0ol000060<c<c0?o000000@0/k>co`000?l0003o00000`2IVIT01?l00000Ogmo07mo
Ool0000306IVIP030000001<C4`0C4a<008000000`0c<c<2000000D06ATI80000004ooooo`030000
0?oooooooooo02Kooooo00?o0000ooooooooool0;Oooool=ojVmj5Sooooo00<00000ooooooooool0
1?ooool00`00003oooooooooo`0:ooooo`002Oooool01000003ooooooooooooooom5000000H06ATI
00<0000003<c<`0c<c<00P0c<c<01@000000C4a<04a<C01<C4`0000000<0IVIV00Go000007moO`1o
Ogl0Ogmoo`00000309VIV@03o`00002c/k<0/k>c00@0/k>c1_l000030;>c/`04o`00002IVIT0VIVI
09VIV@?o000000@0Ogmoo`000?l00000IVIV0P0000001?l00000C4a<00000000000403<c<`03o`00
000I6AT06ATI00@06ATI8@000004ooooo`0300000?oooooooooo02Oooooo00?o0000ooooooooool0
;Oooool8ojVmj5gooooo00<00000ooooooooool00oooool00`00003oooooooooo`0:ooooo`002Ooo
ool01000003ooooooooooooooom5000000H06ATI00<0000003<c<`0c<c<00P0c<c<01@000000C4a<
04a<C01<C4`0000000<0IVIV00Go000007moO`1oOgl0Ogmoo`00000309VIV@03o`00002c/k<0/k>c
00X0/k>c0ol00000102IVIWo0000o`000?l0000307moO`04o`00001VIVH0IVIV000000<0C4a<00<0
000003<c<`0c<c<00P0c<c<2000000L06ATI8@000004ooooo`0300000?oooooooooo02Sooooo00?o
0000ooooooooool0;Oooool3ojVmj6;ooooo00<00000ooooooooool00oooool00`00003ooooooooo
o`09ooooo`002Oooool01000003ooooooooooooooom4000000L06ATI00<0000003<c<`0c<c<00P0c
<c<01@000000C4a<04a<C01<C4`0000000<0IVIV00?o000007moO`1oOgl00P1oOgl01?l00000VIVI
09VIV@2IVIT<o`0000<0VIVI00Co000007moO`1oOgl0Ogmo0ol000000`1VIVH000000000000204a<
C0800000100c<c<00`0000006ATI01TI6@0501TI6B<000001?ooool00`00003oooooooooo`0Yoooo
o`;o0000;Oooool00ol0003oooooooooo`1Sooooo`0300000?oooooooooo00;ooooo00<00000oooo
ooooool02Oooool000Wooooo00@00000ooooooooooooooooA000000601TI6@030000000c<c<0<c<c
00<0<c<c00D0000004a<C01<C4`0C4a<0000000306IVIP03o`00001oOgl0Ogmo0080Ogmo00?o0000
09VIV@2IVIT03P2IVIT2o`000080Ogmo0_l0000306IVIP050000001<C4`0C4a<04a<C00000001@0c
<c<00`0000006ATI01TI6@0501TI6B@000001?ooool00`00003oooooooooo`0[ooooo`03o`000?oo
oooooooo02[ooooo00?o0000ooooooooool0Hoooool00`00003oooooooooo`02ooooo`0300000?oo
oooooooo00Wooooo0009ooooo`0400000?oooooooooooooood<000001`0I6AT00`000000<c<c03<c
<`0203<c<`030000001<C4`0C4a<0080C4a<00D0000006IVIP1VIVH0IVIVo`00000507moO`?o0000
2@2IVIT4o`000080Ogmo0_l0000206IVIP<0000000@0C4a<00000000003o0000100c<c<2000000D0
6ATI0P0000000ol0000000000000000R000000Cooooo00<00000ooooooooool0;?ooool00ol0003o
ooooooooo`0Yooooo`03o`000?oooooooooo06Cooooo00D00000oooooooooooooooo0000000;oooo
o`002Oooool01000003ooooooooooooooom200000003o`00000I6AT06ATI00D06ATI00<0000003<c
<`0c<c<00P0c<c<00`000000C4a<04a<C00204a<C0030000001VIVH0IVIV0080IVIV00?o000007mo
O`1oOgl01@1oOgl9o`0000<0Ogmo0ol00000101VIVH0000000000000000304a<C0030000000c<c<0
<c<c00@0<c<c00<0000001TI6@0I6AT0100I6ATX000000Cooooo00<00000ooooooooool0;Oooool0
0ol0003oooooooooo`0Xooooo`03o`000?oooooooooo06Gooooo00@00000ooooooooool000002ooo
ool000Wooooo00@00000oooooooooooooooo@`00000701TI6@030000000c<c<0<c<c00<0<c<c00<0
000004a<C01<C4`00P1<C4`00`000000IVIV06IVIP0206IVIP?o00003@1oOgl3o`0000<0IVIV00<0
000004a<C01<C4`00P1<C4`2000000D0<c<c0P00000501TI6BX000001?ooool00`00003ooooooooo
o`0^ooooo`;o0000:?ooool00ol0003oooooooooo`1Vooooo`0300000?ooool0000000_ooooo0009
ooooo`0400000?oooooooooooooood800000200I6AT00`000000<c<c03<c<`0303<c<`03o`00001<
C4`0C4a<00<0C4a<00<0000006IVIP1VIVH0101VIVH=o`0000<0IVIV0P0000001?l00000C4a<04a<
C01<C4`2000000<0<c<c0P0000000ol00000000001TI6@0401TI6B`000001?ooool00`00003ooooo
ooooo`0`ooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool0I_ooool00`00003ooooo
0000000;ooooo`002Oooool01000003ooooooooooooooom2000000P06ATI00<0000003<c<`0c<c<0
0`0c<c<00`000000C4a<04a<C00304a<C003o`000000000000000140IVIV0`00000404a<C0800000
100c<c<00`0000006ATI01TI6@0601TI6Bd000001?ooool00`00003oooooooooo`0aooooo`03o`00
0?oooooooooo02Cooooo00?o0000ooooooooool0Ioooool00`00003ooooo0000000:ooooo`002Ooo
ool01000003ooooooooooooooom2000000P06ATI00<0000003<c<`0c<c<0100c<c<00`000000C4a<
04a<C00504a<C0@000002@1VIVH4000000<0C4a<1000000403<c<`800000200I6AT^000000Cooooo
00<00000ooooooooool0<_ooool00ol0003oooooooooo`0Sooooo`03o`000?oooooooooo06Sooooo
0P00000:ooooo`002Oooool01000003ooooooooooooooom2000000T06ATI00<0000003<c<`0c<c<0
100c<c<00`000000C4a<04a<C00804a<C0T000001@1<C4`00ol00000000003<c<`0603<c<`030000
000I6AT06ATI00L06ATI;`000004ooooo`0300000?oooooooooo03?ooooo0_l0000Sooooo`03o`00
0?oooooooooo06Oooooo0_l000000`00003oooooooooo`08ooooo`002Oooool01000003ooooooooo
oooooom2000000T06ATI00<0000003<c<`0c<c<01@0c<c<300000100C4a<1@00000603<c<`800000
00?o000001TI6@0I6AT01@0I6AT200000003o`0000000000000002d000001?ooool00`00003ooooo
ooooo`0eooooo`03o`000?oooooooooo023ooooo00?o0000ooooooooool0Hoooool4o`0000gooooo
0009ooooo`0400000?oooooooooooooood8000002@0I6AT00`000000<c<c03<c<`0803<c<`<00000
2P1<C4`3000000L0<c<c1000000701TI6CD000001?ooool00`00003oooooooooo`0fooooo`03o`00
0?oooooooooo01oooooo00?o0000ooooooooool0H?ooool3o`00017ooooo0009ooooo`0400000?oo
oooooooooooood<000002@0I6AT2000000/0<c<c2P00000703<c<`<000002P0I6ATf000000Cooooo
00<00000ooooooooool0=oooool00ol0003oooooooooo`0Nooooo`03o`000?oooooooooo05cooooo
1?l0000Dooooo`002Oooool01000003ooooooooooooooom3000000/06ATI0P00000F03<c<`<00000
00?o000001TI6@0I6AT0200I6AT200000003o`0000000000000003@000001?ooool00`00003ooooo
ooooo`0hooooo`;o00007_ooool00ol0003oooooooooo`1Hooooo`Co00006?ooool000Wooooo00@0
0000oooooooooooooooo@`00000=01TI6@<00000400c<c<3000000/06ATI?0000004ooooo`030000
0?oooooooooo03[ooooo00?o0000ooooooooool06oooool00ol0003oooooooooo`1Dooooo`Co0000
7?ooool000Wooooo00@00000ooooooooooooooooA000000?01TI6@<000001P0c<c<7000000d06ATI
?@000004ooooo`0300000?oooooooooo03_ooooo00?o0000ooooooooool06_ooool00ol0003ooooo
ooooo`1Aooooo`?o00008?ooool000Wooooo00@00000ooooooooooooooooA000000B01TI6@H00000
4P0I6ATo000000Cooooo00<00000ooooooooool0??ooool00ol0003oooooooooo`0Iooooo`03o`00
0?oooooooooo04gooooo1?l0000Sooooo`002Oooool01000003ooooooooooooooom5000002D06ATI
@`000004ooooo`0300000?oooooooooo03gooooo0_l0000Iooooo`03o`000?oooooooooo04Wooooo
1?l0000Wooooo`002Oooool01000003ooooooooooooooom500000003o`00000000006ATI01h06ATI
A`000004ooooo`0300000?oooooooooo03oooooo00?o0000ooooooooool05_ooool00ol0003ooooo
ooooo`15ooooo`Co0000:oooool000Wooooo00@00000ooooooooooooooooB@00000J01TI6DX00000
1?ooool00`00003oooooooooo`10ooooo`03o`000?oooooooooo01Cooooo00?o0000ooooooooool0
@oooool3o`0002oooooo0009ooooo`0400000?oooooooooooooood`000004`0I6AU>000000Cooooo
00<00000ooooooooool0@Oooool00ol0003oooooooooo`0Cooooo`03o`000?oooooooooo03oooooo
1?l0000booooo`002Oooool01000003ooooooooooooooomC000000D06ATIE@000004ooooo`030000
0?oooooooooo04;ooooo0_l0000Cooooo`03o`000?oooooooooo03_ooooo1?l0000fooooo`002Ooo
ool01000003ooooooooooooooon]000000Cooooo00<00000ooooooooool0A?ooool00ol0003ooooo
ooooo`0@ooooo`03o`000?oooooooooo03Oooooo1?l0000jooooo`002Oooool01000003ooooooooo
oooooon]000000Cooooo00<00000ooooooooool0AOooool00ol0003oooooooooo`0?ooooo`03o`00
0?oooooooooo03?ooooo1?l0000nooooo`002Oooool01000003ooooooooooooooon]000000Cooooo
00<00000ooooooooool0A_ooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo033ooooo
0ol00012ooooo`002Oooool01000003ooooooooooooooon]000000Cooooo00<00000ooooooooool0
Aoooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo02cooooo1?l00015ooooo`002Ooo
ool01000003ooooooooooooooon]000000Cooooo00<00000ooooooooool0B?ooool2o`0000gooooo
00?o0000ooooooooool0:?ooool4o`0004Wooooo0009ooooo`0400000?ooooooooooooooojd00000
1?ooool00`00003oooooooooo`1:ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool0
9?ooool4o`0004gooooo0009ooooo`0400000?ooooooooooooooojd000001?ooool00`00003ooooo
ooooo`1;ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool08Oooool3o`00057ooooo
0009ooooo`0400000?ooooooooooooooojd000001?ooool00`00003oooooooooo`1<ooooo`03o`00
0?oooooooooo00Sooooo00?o0000ooooooooool07Oooool4o`0005Cooooo0009ooooo`0400000?oo
ooooooooooooojd000001?ooool00`00003oooooooooo`1=ooooo`;o00002?ooool00ol0003ooooo
ooooo`0Iooooo`Co0000F?ooool000Wooooo00@00000oooooooooooooooo[@000004ooooo`030000
0?oooooooooo04oooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0Eooooo`Co0000
G?ooool000Wooooo00@00000oooooooooooooooo[@000004ooooo`0300000?oooooooooo053ooooo
00?o0000ooooooooool01?ooool00ol0003oooooooooo`0Booooo`?o0000H?ooool000Wooooo00@0
0000oooooooooooooooo[@000004ooooo`0300000?oooooooooo057ooooo00?o0000ooooooooool0
0oooool00ol0003oooooooooo`0>ooooo`Co0000Hoooool000Wooooo00@00000oooooooooooooooo
[@000004ooooo`0300000?oooooooooo05;ooooo0_l00003ooooo`03o`000?oooooooooo00[ooooo
1?l0001Wooooo`002Oooool01000003ooooooooooooooon]000000Cooooo00<00000ooooooooool0
E?ooool01?l0003oooooooooool00008ooooo`Co0000Joooool000Wooooo00@00000oooooooooooo
oooo[@000004ooooo`0300000?oooooooooo05Gooooo00?o0000ooooool000001Oooool3o`0006oo
oooo0009ooooo`0400000?ooooooooooooooojd000001?ooool00`00003oooooooooo`1Fooooo`;o
000000?oooooo`000?l000000_l0001booooo`002Oooool01000003ooooooooooooooon]000000Co
oooo00<00000ooooooooool0Eoooool2o`0007Kooooo0009ooooo`0400000?ooooooooooooooojd0
00001?ooool00`00003oooooooooo`3?ooooo`002Oooool01000003ooooooooooooooon]000000Co
oooo00<00000ooooooooool0coooool000Wooooo00@00000oooooooooooooooo[@000004ooooo`03
00000?oooooooooo0<oooooo0009ooooo`0400000?ooooooooooooooojd000001?ooool00`00003o
ooooooooo`3?ooooo`002Oooool01000003ooooooooooooooon]000000Cooooo00<00000oooooooo
ool0coooool000Wooooo00@00000oooooooooooooooo[@000004ooooo`0300000?oooooooooo0<oo
oooo0009ooooo`0400000?ooooooooooooooojd000001?ooool00`00003oooooooooo`3?ooooo`00
2Oooool01000003ooooooooooooooon]000000Cooooo00<00000ooooooooool0coooool000Wooooo
00@00000oooooooooooooooo[@000004ooooo`0300000?oooooooooo0<oooooo0009ooooo`040000
0?ooooooooooooooojd000001?ooool00`00003oooooooooo`3?ooooo`002Oooool01000003ooooo
oooooooooon]000000Cooooo00<00000ooooooooool0coooool000Wooooo00@00000oooooooooooo
oooo[@000004ooooo`0300000?oooooooooo0<oooooo0009ooooo`0400000?ooooooooooooooojd0
00001?ooool00`00003oooooooooo`3?ooooo`002Oooool00`00003oooooooooo`2booooo`030000
0?oooooooooo0<oooooo0009ooooo`0300000?oooooooooo0;;ooooo00<00000ooooooooool0cooo
ool000Wooooo00<00000ooooooooool0/_ooool00`00003oooooooooo`3?ooooo`002Ooooonf0000
0=7ooooo003ooooooi7ooooo003ooooooi7ooooo003ooooooi7ooooo003ooooooi7ooooo003ooooo
oi7ooooo003ooooooi7ooooo003ooooooi7ooooo003ooooooi7ooooo003ooooooi7ooooo003ooooo
oi7ooooo003ooooooi7ooooo003ooooooi7ooooo003ooooooi7ooooo003ooooooi7ooooo003ooooo
oi7ooooo003ooooooi7ooooo003ooooooi7ooooo0009oooookH000004Ooooonf000000[ooooo0009
ooooo`0300000?oooooooooo0;;ooooo00<00000ooooooooool03oooool00`00003oooooooooo`2b
ooooo`0300000?oooooooooo00Sooooo0009ooooo`0300000?oooooooooo0;;ooooo00<00000oooo
ooooool03oooool00`00003oooooooooo`2booooo`0300000?oooooooooo00Sooooo0009ooooo`03
00000?oooooooooo0;;ooooo00<00000ooooooooool03oooool00`00003oooooooooo`2booooo`03
00000?oooooooooo00Sooooo0009ooooo`0300000?oooooooooo0;;ooooo00<00000ooooooooool0
3oooool00`00003oooooooooo`2booooo`0300000?oooooooooo00Sooooo0009ooooo`0300000?oo
oooooooo0;;ooooo00<00000ooooooooool03oooool00`00003oooooooooo`2booooo`0300000?oo
oooooooo00Sooooo0009ooooo`0300000?oooooooooo0;;ooooo00<00000ooooooooool03oooool0
0`00003oooooooooo`2booooo`0300000?oooooooooo00Sooooo0009ooooo`0300000?oooooooooo
0;;ooooo00<00000ooooooooool03oooool00`00003oooooooooo`2booooo`0300000?oooooooooo
00Sooooo0009ooooo`0300000?oooooooooo0;;ooooo00<00000ooooooooool03oooool00`00003o
ooooooooo`2booooo`0300000?oooooooooo00Sooooo0009ooooo`0300000?oooooooooo0;;ooooo
00<00000ooooooooool03oooool00`00003oooooooooo`2booooo`0300000?oooooooooo00Sooooo
0009ooooo`0300000?oooooooooo0;;ooooo00<00000ooooooooool03oooool00`00003ooooooooo
o`2booooo`0300000?oooooooooo00Sooooo0009ooooo`0300000?oooooooooo0;;ooooo00<00000
ooooooooool03oooool00`00003oooooooooo`2booooo`0300000?oooooooooo00Sooooo0009oooo
o`0300000?oooooooooo0;;ooooo00<00000ooooooooool03oooool00`00003oooooooooo`2boooo
o`0300000?oooooooooo00Sooooo0009ooooo`0300000?oooooooooo0;;ooooo00<00000oooooooo
ool03oooool00`00003oooooooooo`2booooo`0300000?oooooooooo00Sooooo0009ooooo`030000
0?oooooooooo0;;ooooo00<00000ooooooooool03oooool00`00003oooooooooo`2booooo`030000
0?oooooooooo00Sooooo0009ooooo`0300000?oooooooooo0;;ooooo00<00000ooooooooool03ooo
ool00`00003oooooooooo`2booooo`0300000?oooooooooo00Sooooo0009ooooo`0300000?oooooo
oooo0;;ooooo00<00000ooooooooool03oooool00`00003oooooooooo`2booooo`0300000?oooooo
oooo00Sooooo0009ooooo`0300000?oooooooooo0;;ooooo00<00000ooooooooool03oooool00`00
003oooooooooo`2booooo`0300000?oooooooooo00Sooooo0009ooooo`0300000?oooooooooo0;;o
oooo00<00000ooooooooool03oooool00`00003oooooooooo`2booooo`0300000?oooooooooo00So
oooo0009ooooo`0300000?oooooooooo0;;ooooo00<00000ooooooooool03oooool00`00003ooooo
ooooo`2booooo`0300000?oooooooooo00Sooooo0009ooooo`0300000?oooooooooo0;;ooooo00<0
0000ooooooooool03oooool00`00003oooooooooo`2booooo`0300000?oooooooooo00Sooooo0009
ooooo`0300000?oooooooooo0;;ooooo00<00000ooooooooool03oooool00`00003oooooooooo`2b
ooooo`0300000?oooooooooo00Sooooo0009ooooo`0300000?oooooooooo0;;ooooo00<00000oooo
ooooool03oooool00`00003oooooooooo`2booooo`0300000?oooooooooo00Sooooo0009ooooo`03
00000?oooooooooo00?ooooo0P3oO`0;ooooo`80ogl0X?ooool00`00003oooooooooo`0?ooooo`03
00000?oooooooooo00?ooooo0P3oO`0;ooooo`80ogl0X?ooool00`00003oooooooooo`08ooooo`00
2Oooool00`00003oooooooooo`02ooooo`<0ogl02oooool20?mo00cooooo0P3oO`2Booooo`030000
0?oooooooooo00oooooo00<00000ooooooooool00_ooool30?mo00_ooooo0P3oO`0<ooooo`80ogl0
T_ooool00`00003oooooooooo`08ooooo`002Oooool00`00003oooooooooo`02ooooo`80ogl06_oo
ool20?mo09;ooooo00<00000ooooooooool03oooool00`00003oooooooooo`02ooooo`80ogl06_oo
ool20?mo09;ooooo00<00000ooooooooool02?ooool000Wooooo00<00000ooooooooool0/_ooool0
0`00003oooooooooo`0?ooooo`0300000?oooooooooo0;;ooooo00<00000ooooooooool02?ooool0
00Wooooo00<00000ooooooooool0/_ooool00`00003oooooooooo`0?ooooo`0300000?oooooooooo
0;;ooooo00<00000ooooooooool02?ooool000Wooooo00<00000ooooooooool0/_ooool00`00003o
ooooooooo`0?ooooo`0300000?oooooooooo0;;ooooo00<00000ooooooooool02?ooool000Wooooo
00<00000ooooooooool0/_ooool00`00003oooooooooo`0?ooooo`0300000?oooooooooo0;;ooooo
00<00000ooooooooool02?ooool000Wooooo00<00000ooooooooool0/_ooool00`00003ooooooooo
o`0?ooooo`0300000?oooooooooo0;;ooooo00<00000ooooooooool02?ooool000Wooooo00<00000
ooooooooool06Oooool80000oi7ooooo00<00000ooooooooool03oooool00`00003oooooooooo`2b
ooooo`0300000?oooooooooo00Sooooo0009ooooo`0300000?oooooooooo01Sooooo00<0003ooooo
ooooool01_ooool30000ohkooooo00<00000ooooooooool03oooool00`00003oooooooooo`2boooo
o`0300000?oooooooooo00Sooooo0009ooooo`0300000?oooooooooo01Oooooo00<0003ooooooooo
ool02_ooool30000oh_ooooo00<00000ooooooooool03oooool00`00003oooooooooo`2booooo`03
00000?oooooooooo00Sooooo0009ooooo`0300000?oooooooooo01Kooooo00<0003o0?mo0?ooool0
1?ooool20?mo00Sooooo00?o003oooooooooool0R?ooool00`00003oooooooooo`0?ooooo`030000
0?oooooooooo01Kooooo0P3oO`05ooooo`80ogl0Toooool00`00003oooooooooo`08ooooo`002Ooo
ool00`00003oooooooooo`0Fooooo`030000o`3oO`3ooooo00Cooooo0P3oO`09ooooo`80003oR?oo
ool00`00003oooooooooo`0?ooooo`0300000?oooooooooo01Kooooo0P3oO`05ooooo`80ogl0Tooo
ool00`00003oooooooooo`08ooooo`002Oooool00`00003oooooooooo`0Gooooo`030000oooooooo
oooo013ooooo0`000?n5ooooo`0300000?oooooooooo00oooooo00<00000ooooooooool0/_ooool0
0`00003oooooooooo`08ooooo`002Oooool00`00003oooooooooo`0Gooooo`030000oooooooooooo
01?ooooo00<0003oooooooooool0P_ooool00`00003oooooooooo`0?ooooo`0300000?oooooooooo
0;;ooooo00<00000ooooooooool02?ooool000Wooooo00<00000ooooooooool05oooool00`000?oo
ooooooooo`02ooooo`80ogl01_ooool20?mo00Sooooo00<0003oooooooooool00P3oO`03ooooo`80
ogl0N_ooool00`00003oooooooooo`0?ooooo`0300000?oooooooooo01cooooo0P3oO`06ooooo`80
ogl02oooool20?mo00?ooooo0P3oO`1jooooo`0300000?oooooooooo00Sooooo0009ooooo`030000
0?oooooooooo01Sooooo00@0003ooooooooooooooooo0P3oO`06ooooo`80ogl02Oooool30000o`04
0?mo0?ooooooooooooooo`80ogl0N_ooool00`00003oooooooooo`0?ooooo`0300000?oooooooooo
01cooooo0P3oO`06ooooo`80ogl02oooool20?mo00?ooooo0P3oO`1jooooo`0300000?oooooooooo
00Sooooo0009ooooo`0300000?oooooooooo01Sooooo00<0003oooooooooool05oooool20000o`?o
oooo0P3oO`1iooooo`0300000?oooooooooo00oooooo00<00000ooooooooool0=oooool20?mo07Wo
oooo00<00000ooooooooool02?ooool000Wooooo00<00000ooooooooool06Oooool00`000?oooooo
ooooo`0Gooooo`040?mo00000?ooooooooooo`80ogl0NOooool00`00003oooooooooo`0?ooooo`03
00000?oooooooooo03?ooooo0P3oO`02ooooo`80ogl0NOooool00`00003oooooooooo`08ooooo`00
2Oooool00`00003oooooooooo`0Jooooo`80003o3?ooool3000000Sooooo0P3oO`000`000?oooooo
ooooo`1jooooo`0300000?oooooooooo00oooooo00<00000ooooooooool0<oooool20?mo07gooooo
00<00000ooooooooool02?ooool000Wooooo00<00000ooooooooool07?ooool00`000?oooooooooo
o`02ooooo`80ogl01?ooool5000000[ooooo00<0003oooooooooool0NOooool00`00003ooooooooo
o`0?ooooo`0300000?oooooooooo027ooooo0P3oO`2?ooooo`0300000?oooooooooo00Sooooo0009
ooooo`0300000?oooooooooo01[ooooo0P3oO`000oooool0003oooooo`02ooooo`80ogl01?ooool5
000000[ooooo00<0003oooooooooool0NOooool00`00003oooooooooo`0?ooooo`0300000?oooooo
oooo01[ooooo0P3oO`05ooooo`80ogl0Soooool00`00003oooooooooo`08ooooo`002Oooool00`00
003oooooooooo`0Jooooo`80ogl00_ooool00`000?ooooooooooo`06ooooo`D000001_ooool20?mo
00?ooooo00<0003oooooooooool01?ooool20?mo07;ooooo00<00000ooooooooool03oooool00`00
003oooooooooo`0Jooooo`80ogl05_ooool20?mo00[ooooo0P3oO`1booooo`0300000?oooooooooo
00Sooooo0009ooooo`0300000?oooooooooo01oooooo0P000?l7ooooo`<000001oooool20?mo00Co
oooo00<0003oooooooooool00oooool20?mo07;ooooo00<00000ooooooooool03oooool00`00003o
ooooooooo`0booooo`80ogl02_ooool20?mo07;ooooo00<00000ooooooooool02?ooool000Wooooo
00<00000ooooooooool08Oooool00`000?ooooooooooo`0Eooooo`030000oooooooooooo07Kooooo
00<00000ooooooooool03oooool00`00003oooooooooo`2booooo`0300000?oooooooooo00Sooooo
0009ooooo`0300000?oooooooooo02;ooooo00<0003oooooooooool05Oooool00`000?oooooooooo
o`1eooooo`0300000?oooooooooo00oooooo00<00000ooooooooool0/_ooool00`00003ooooooooo
o`08ooooo`002Oooool00`00003oooooooooo`0Sooooo`030000oooooooooooo01Cooooo00<0003o
ooooooooool0MOooool00`00003oooooooooo`0?ooooo`0300000?oooooooooo0;;ooooo00<00000
ooooooooool02?ooool000Wooooo00<00000ooooooooool08oooool00`3oO`00003o0000o`020?mo
01?ooooo00<0003oooooooooool0M?ooool00`00003oooooooooo`0?ooooo`0300000?oooooooooo
02?ooooo0P3oO`000oooool0ogl00?mo002:ooooo`0300000?oooooooooo00Sooooo0009ooooo`03
00000?oooooooooo02?ooooo0`3oO`020000oa?ooooo00<0003oooooooooool0M?ooool00`00003o
ooooooooo`0?ooooo`0300000?oooooooooo02?ooooo1@3oO`2:ooooo`0300000?oooooooooo00So
oooo0009ooooo`0300000?oooooooooo02Gooooo0P3oO`000oooool0003oooooo`0Aooooo`030000
o`3oO`3ooooo07Cooooo00<00000ooooooooool03oooool00`00003oooooooooo`0Uooooo`80ogl0
5?ooool20?mo07Gooooo00<00000ooooooooool02?ooool000Wooooo00<00000ooooooooool0:Ooo
ool00ol00?l0003o0000o`0?ooooo`03o`00o`3oO`3ooooo07Cooooo00<00000ooooooooool03ooo
ool00`00003oooooooooo`0kooooo`80ogl0MOooool00`00003oooooooooo`08ooooo`002Oooool0
0`00003oooooooooo`0/ooooo`<0003o2oooool20000ogKooooo00<00000ooooooooool03oooool0
0`00003oooooooooo`2booooo`0300000?oooooooooo00Sooooo0009ooooo`0300000?oooooooooo
02oooooo0`000?l6ooooo`80003oN?ooool00`00003oooooooooo`0?ooooo`0300000?oooooooooo
0;;ooooo00<00000ooooooooool02?ooool000Wooooo00<00000ooooooooool07_ooool20?mo01;o
oooo1P000?mjooooo`0300000?oooooooooo00oooooo00<00000ooooooooool07_ooool20?mo09;o
oooo00<00000ooooooooool02?ooool000Wooooo00<00000ooooooooool07_ooool20?mo09;ooooo
00<00000ooooooooool03oooool00`00003oooooooooo`0Nooooo`80ogl0T_ooool00`00003ooooo
ooooo`08ooooo`002Oooool00`00003oooooooooo`2booooo`0300000?oooooooooo00oooooo00<0
0000ooooooooool0/_ooool00`00003oooooooooo`08ooooo`002Oooool00`00003oooooooooo`2b
ooooo`0300000?oooooooooo00oooooo00<00000ooooooooool0/_ooool00`00003oooooooooo`08
ooooo`002Oooool00`00003oooooooooo`2booooo`0300000?oooooooooo00oooooo00<00000oooo
ooooool0/_ooool00`00003oooooooooo`08ooooo`002Oooool00`00003oooooooooo`2booooo`03
00000?oooooooooo00oooooo00<00000ooooooooool0/_ooool00`00003oooooooooo`08ooooo`00
2Oooool00`00003oooooooooo`1>ooooo`80ogl0H_ooool00`00003oooooooooo`0?ooooo`030000
0?oooooooooo04kooooo0P3oO`1Rooooo`0300000?oooooooooo00Sooooo0009ooooo`0300000?oo
oooooooo03Cooooo0P3oO`0Hooooo`80ogl0H_ooool00`00003oooooooooo`0?ooooo`0300000?oo
oooooooo03Cooooo0P3oO`0Hooooo`80ogl0H_ooool00`00003oooooooooo`08ooooo`002Oooool0
0`00003oooooooooo`0dooooo`80ogl0O?ooool00`00003oooooooooo`0?ooooo`0300000?oooooo
oooo03Cooooo0P3oO`1looooo`0300000?oooooooooo00Sooooo0009ooooo`0300000?oooooooooo
0;;ooooo00<00000ooooooooool03oooool00`00003oooooooooo`2booooo`0300000?oooooooooo
00Sooooo0009ooooo`0300000?oooooooooo03gooooo0P3oO`02ooooo`80ogl0Koooool00`00003o
ooooooooo`0?ooooo`0300000?oooooooooo03gooooo0P3oO`02ooooo`80ogl0Koooool00`00003o
ooooooooo`08ooooo`002Oooool00`00003oooooooooo`0mooooo`80ogl00_ooool20?mo06oooooo
00<00000ooooooooool03oooool00`00003oooooooooo`0mooooo`80ogl00_ooool20?mo06oooooo
00<00000ooooooooool02?ooool000Wooooo00<00000ooooooooool0/_ooool00`00003ooooooooo
o`0?ooooo`0300000?oooooooooo0;;ooooo00<00000ooooooooool02?ooool000Wooooo00<00000
ooooooooool0/_ooool00`00003oooooooooo`0?ooooo`0300000?oooooooooo0;;ooooo00<00000
ooooooooool02?ooool000Wooooo00<00000ooooooooool0/_ooool00`00003oooooooooo`0?oooo
o`0300000?oooooooooo0;;ooooo00<00000ooooooooool02?ooool000Wooooo00<00000oooooooo
ool0/_ooool00`00003oooooooooo`0?ooooo`0300000?oooooooooo0;;ooooo00<00000oooooooo
ool02?ooool000Wooooo00<00000ooooooooool0/_ooool00`00003oooooooooo`0?ooooo`030000
0?oooooooooo0;;ooooo00<00000ooooooooool02?ooool000Wooooo00<00000ooooooooool0/_oo
ool00`00003oooooooooo`0?ooooo`0300000?oooooooooo0;;ooooo00<00000ooooooooool02?oo
ool000Wooooo00<00000ooooooooool0/_ooool00`00003oooooooooo`0?ooooo`0300000?oooooo
oooo0;;ooooo00<00000ooooooooool02?ooool000Wooooo00<00000ooooooooool0/_ooool00`00
003oooooooooo`0?ooooo`0300000?oooooooooo0;;ooooo00<00000ooooooooool02?ooool000Wo
oooo00<00000ooooooooool0/_ooool00`00003oooooooooo`0?ooooo`0300000?oooooooooo0;;o
oooo00<00000ooooooooool02?ooool000Wooooo00<00000ooooooooool0/_ooool00`00003ooooo
ooooo`0?ooooo`0300000?oooooooooo0;;ooooo00<00000ooooooooool02?ooool000Wooooo00<0
0000ooooooooool0/_ooool00`00003oooooooooo`0?ooooo`0300000?oooooooooo0;;ooooo00<0
0000ooooooooool02?ooool000Wooooo00<00000ooooooooool0/_ooool00`00003oooooooooo`0?
ooooo`0300000?oooooooooo0;;ooooo00<00000ooooooooool02?ooool000Wooooo00<00000oooo
ooooool0/_ooool00`00003oooooooooo`0?ooooo`0300000?oooooooooo0;;ooooo00<00000oooo
ooooool02?ooool000Wooooo00<00000ooooooooool0/_ooool00`00003oooooooooo`0?ooooo`03
00000?oooooooooo0;;ooooo00<00000ooooooooool02?ooool000Wooooo00<00000ooooooooool0
/_ooool00`00003oooooooooo`0?ooooo`0300000?oooooooooo0;;ooooo00<00000ooooooooool0
2?ooool000Wooooo00<00000ooooooooool0/_ooool00`00003oooooooooo`0?ooooo`0300000?oo
oooooooo0;;ooooo00<00000ooooooooool02?ooool000Wooooo00<00000ooooooooool0/_ooool0
0`00003oooooooooo`0?ooooo`0300000?oooooooooo0;;ooooo00<00000ooooooooool02?ooool0
00Wooooo00<00000ooooooooool0/_ooool00`00003oooooooooo`0?ooooo`0300000?oooooooooo
0;;ooooo00<00000ooooooooool02?ooool000Wooooo00<00000ooooooooool0/_ooool00`00003o
ooooooooo`0?ooooo`0300000?oooooooooo0;;ooooo00<00000ooooooooool02?ooool000Wooooo
00<00000ooooooooool0/_ooool00`00003oooooooooo`0?ooooo`0300000?oooooooooo0;;ooooo
00<00000ooooooooool02?ooool000Wooooo00<00000ooooooooool0/_ooool00`00003ooooooooo
o`0?ooooo`0300000?oooooooooo0;;ooooo00<00000ooooooooool02?ooool000Wooooo00<00000
ooooooooool0X_ooool20?mo00kooooo00<00000ooooooooool03oooool00`00003oooooooooo`2R
ooooo`80ogl03_ooool00`00003oooooooooo`08ooooo`002Oooool00`00003oooooooooo`2Roooo
o`80ogl03_ooool00`00003oooooooooo`0?ooooo`0300000?oooooooooo0:;ooooo0P3oO`0>oooo
o`0300000?oooooooooo00Sooooo0009ooooo`0300000?oooooooooo0;;ooooo00<00000oooooooo
ool03oooool00`00003oooooooooo`2booooo`0300000?oooooooooo00Sooooo0009ooooo`030000
0?oooooooooo0;;ooooo00<00000ooooooooool03oooool00`00003oooooooooo`2booooo`030000
0?oooooooooo00Sooooo0009ooooo`0300000?oooooooooo0;;ooooo00<00000ooooooooool03ooo
ool00`00003oooooooooo`2booooo`0300000?oooooooooo00Sooooo0009ooooo`0300000?oooooo
oooo0;;ooooo00<00000ooooooooool03oooool00`00003oooooooooo`2booooo`0300000?oooooo
oooo00Sooooo0009ooooo`0300000?oooooooooo0;;ooooo00<00000ooooooooool03oooool00`00
003oooooooooo`2booooo`0300000?oooooooooo00Sooooo0009ooooo`0300000?oooooooooo0;;o
oooo00<00000ooooooooool03oooool00`00003oooooooooo`2booooo`0300000?oooooooooo00So
oooo0009ooooo`0300000?oooooooooo0;;ooooo00<00000ooooooooool03oooool00`00003ooooo
ooooo`2booooo`0300000?oooooooooo00Sooooo0009ooooo`0300000?oooooooooo077ooooo0P3o
O`0oooooo`0300000?oooooooooo00oooooo00<00000ooooooooool0LOooool20?mo03oooooo00<0
0000ooooooooool02?ooool000Wooooo00<00000ooooooooool0LOooool20?mo03oooooo00<00000
ooooooooool03oooool00`00003oooooooooo`1aooooo`80ogl0?oooool00`00003oooooooooo`08
ooooo`002Oooool00`00003oooooooooo`2Cooooo`80ogl07Oooool00`00003oooooooooo`0?oooo
o`0300000?oooooooooo09?ooooo0P3oO`0Mooooo`0300000?oooooooooo00Sooooo0009ooooo`03
00000?oooooooooo08oooooo0P3oO`02ooooo`80ogl07Oooool00`00003oooooooooo`0?ooooo`03
00000?oooooooooo08oooooo0P3oO`02ooooo`80ogl07Oooool00`00003oooooooooo`08ooooo`00
2Oooool00`00003oooooooooo`1jooooo`030?mo00000?l0003o00L0003o2oooool20?mo027ooooo
00<00000ooooooooool03oooool00`00003oooooooooo`1jooooo`80ogl04oooool20?mo027ooooo
00<00000ooooooooool02?ooool000Wooooo00<00000ooooooooool0M_ooool50000o`030?mo0?oo
oooooooo00Kooooo0`000?l[ooooo`0300000?oooooooooo00oooooo00<00000ooooooooool0N_oo
ool20?mo03Kooooo00<00000ooooooooool02?ooool000Wooooo00<00000ooooooooool0M?ooool0
0ol00?l0003oooooo`0@ooooo`03o`00oooooooooooo00;ooooo0P3oO`0Tooooo`0300000?oooooo
oooo00oooooo00<00000ooooooooool0M?ooool20?mo01Kooooo0P3oO`0Tooooo`0300000?oooooo
oooo00Sooooo0009ooooo`0300000?oooooooooo077ooooo0P000?l00ol00?l0ogl00?mo000Aoooo
o`030000oooooooooooo00;ooooo0P3oO`0Tooooo`0300000?oooooooooo00oooooo00<00000oooo
ooooool0M?ooool20?mo01Kooooo0P3oO`0Tooooo`0300000?oooooooooo00Sooooo0009ooooo`03
00000?oooooooooo06kooooo0`000?l00`3oO`3oooooooooo`0=ooooo`80ogl01?ooool00`000?oo
ooooooooo`06ooooo`80ogl08?ooool00`00003oooooooooo`0?ooooo`0300000?oooooooooo073o
oooo0P3oO`0?ooooo`80ogl03Oooool20?mo023ooooo00<00000ooooooooool02?ooool000Wooooo
00<00000ooooooooool0K?ooool20000o`;ooooo0P3oO`04ooooo`80ogl02Oooool20?mo00Cooooo
00<0003oooooooooool01_ooool20?mo023ooooo00<00000ooooooooool03oooool00`00003ooooo
ooooo`1`ooooo`80ogl01?ooool20?mo00Wooooo0P3oO`0=ooooo`80ogl08?ooool00`00003ooooo
ooooo`08ooooo`002Oooool00`00003oooooooooo`1Fooooo`80ogl04oooool00`000?oooooooooo
o`02ooooo`80ogl01?ooool20?mo013ooooo00<0003oooooooooool09oooool00`00003ooooooooo
o`0?ooooo`0300000?oooooooooo05Kooooo0P3oO`0Hooooo`80ogl01?ooool20?mo03[ooooo00<0
0000ooooooooool02?ooool000Wooooo00<00000ooooooooool0E_ooool20?mo017ooooo0P000?l5
ooooo`80ogl05_ooool00`000?ooooooooooo`0Wooooo`0300000?oooooooooo00oooooo00<00000
ooooooooool0E_ooool20?mo01Sooooo0P3oO`10ooooo`0300000?oooooooooo00Sooooo0009oooo
o`0300000?oooooooooo06Sooooo00<0003oooooooooool07Oooool00`000?ooooooooooo`0Woooo
o`0300000?oooooooooo00oooooo00<00000ooooooooool0/_ooool00`00003oooooooooo`08oooo
o`002Oooool00`00003oooooooooo`1Mooooo`80ogl02?ooool00`000?l0ogl00?mo000Iooooo`80
ogl00oooool00`000?ooooooooooo`0Wooooo`0300000?oooooooooo00oooooo00<00000oooooooo
ool0GOooool20?mo00Wooooo0P3oO`0Iooooo`80ogl0;Oooool00`00003oooooooooo`08ooooo`00
2Oooool00`00003oooooooooo`1Mooooo`80ogl01_ooool20000o`03ooooo`3oO`00ogl001Wooooo
0P3oO`02ooooo`030000oooooooooooo02Sooooo00<00000ooooooooool03oooool00`00003ooooo
ooooo`1Mooooo`80ogl02Oooool20?mo01Wooooo0P3oO`0]ooooo`0300000?oooooooooo00Sooooo
0009ooooo`0300000?oooooooooo06Cooooo00<0003oooooooooool08?ooool00ol00?oooooooooo
o`0Xooooo`0300000?oooooooooo00oooooo00<00000ooooooooool0/_ooool00`00003ooooooooo
o`08ooooo`002Oooool00`00003oooooooooo`1Sooooo`030000oooooooooooo023ooooo00<0003o
ooooooooool02_ooool20?mo01gooooo00<00000ooooooooool03oooool00`00003oooooooooo`2C
ooooo`80ogl07Oooool00`00003oooooooooo`08ooooo`002Oooool00`00003oooooooooo`1Roooo
o`030000oooooooooooo00cooooo0`00000Booooo`030000o`3oO`3ooooo00[ooooo0P3oO`0Moooo
o`0300000?oooooooooo00oooooo00<00000ooooooooool0Q_ooool20?mo00_ooooo0P3oO`0Moooo
o`0300000?oooooooooo00Sooooo0009ooooo`0300000?oooooooooo067ooooo00<0003ooooooooo
ool03?ooool50000013ooooo00<0003o0?mo003oO`00:_ooool00`00003oooooooooo`0?ooooo`03
00000?oooooooooo07;ooooo0P3oO`0Booooo`80ogl0:_ooool00`00003oooooooooo`08ooooo`00
2Oooool00`00003oooooooooo`1Qooooo`030000oooooooooooo00cooooo1@00000?ooooo`030000
oooooooooooo02_ooooo00<00000ooooooooool03oooool00`00003oooooooooo`1booooo`80ogl0
?_ooool00`00003oooooooooo`08ooooo`002Oooool00`00003oooooooooo`1Pooooo`030000oooo
oooooooo00Kooooo0P3oO`05ooooo`D000003_ooool00`000?l0ogl00?mo000/ooooo`0300000?oo
oooooooo00oooooo00<00000ooooooooool0JOooool20?mo00Gooooo0P3oO`0Booooo`80ogl0;?oo
ool00`00003oooooooooo`08ooooo`002Oooool00`00003oooooooooo`1Oooooo`030000oooooooo
oooo00Gooooo103oO`05ooooo`040?mo000000000000000000cooooo00@0ogl00000o`000?oooooo
0P3oO`0/ooooo`0300000?oooooooooo00oooooo00<00000ooooooooool0Ioooool40?mo00Gooooo
0P3oO`0>ooooo`80ogl00_ooool20?mo02cooooo00<00000ooooooooool02?ooool000Wooooo00<0
0000ooooooooool0Goooool00`000?ooooooooooo`05ooooo`80ogl05oooool00`000?l0ogl0oooo
o`0_ooooo`0300000?oooooooooo00oooooo00<00000ooooooooool0Ioooool20?mo01Oooooo0P3o
O`0`ooooo`0300000?oooooooooo00Sooooo0009ooooo`0300000?oooooooooo04Wooooo0P3oO`0C
ooooo`030000oooooooooooo01kooooo00<0003oooooooooool0<?ooool00`00003oooooooooo`0?
ooooo`0300000?oooooooooo04Wooooo0P3oO`1Wooooo`0300000?oooooooooo00Sooooo0009oooo
o`0300000?oooooooooo04Wooooo0P3oO`07ooooo`80ogl02_ooool00`000?ooooooooooo`0=oooo
o`80ogl03_ooool00`000?ooooooooooo`0aooooo`0300000?oooooooooo00oooooo00<00000oooo
ooooool0BOooool20?mo00Oooooo0P3oO`0Jooooo`80ogl0@_ooool00`00003oooooooooo`08oooo
o`002Oooool00`00003oooooooooo`1Booooo`80ogl02Oooool00`000?ooooooooooo`0>ooooo`80
ogl02_ooool40000ocCooooo00<00000ooooooooool03oooool00`00003oooooooooo`1Booooo`80
ogl06_ooool20?mo04;ooooo00<00000ooooooooool02?ooool000Wooooo00<00000ooooooooool0
GOooool00`000?ooooooooooo`09ooooo`80ogl03_ooool00`000?ooooooooooo`0fooooo`030000
0?oooooooooo00oooooo00<00000ooooooooool0JOooool20?mo04Oooooo00<00000ooooooooool0
2?ooool000Wooooo00<00000ooooooooool0GOooool00`000?ooooooooooo`09ooooo`80ogl03?oo
ool20000ocWooooo00<00000ooooooooool03oooool00`00003oooooooooo`1Yooooo`80ogl0Aooo
ool00`00003oooooooooo`08ooooo`002Oooool00`00003oooooooooo`1Mooooo`030000oooooooo
oooo01Kooooo00<0003oooooooooool0>Oooool00`00003oooooooooo`0?ooooo`0300000?oooooo
oooo0;;ooooo00<00000ooooooooool02?ooool000Wooooo00<00000ooooooooool0GOooool00`00
0?ooooooooooo`0Eooooo`030000oooooooooooo03[ooooo00<00000ooooooooool03oooool00`00
003oooooooooo`2booooo`0300000?oooooooooo00Sooooo0009ooooo`0300000?oooooooooo05go
oooo0P000?lBooooo`<0003o00?o003oooooooooool0>oooool00`00003oooooooooo`0?ooooo`03
00000?oooooooooo0;;ooooo00<00000ooooooooool02?ooool000Wooooo00<00000ooooooooool0
D_ooool20?mo00_ooooo00<0003oooooooooool03?ooool30000od7ooooo00<00000ooooooooool0
3oooool00`00003oooooooooo`1Booooo`80ogl0G_ooool00`00003oooooooooo`08ooooo`002Ooo
ool00`00003oooooooooo`1Booooo`80ogl03?ooool00`000?ooooooooooo`08ooooo`<0003oA?oo
ool00`00003oooooooooo`0?ooooo`0300000?oooooooooo05;ooooo0P3oO`1Nooooo`0300000?oo
oooooooo00Sooooo0009ooooo`0300000?oooooooooo067ooooo2P000?l4ooooo`80ogl0@Oooool0
0`00003oooooooooo`0?ooooo`0300000?oooooooooo06oooooo0P3oO`11ooooo`0300000?oooooo
oooo00Sooooo0009ooooo`0300000?oooooooooo06oooooo0P3oO`11ooooo`0300000?oooooooooo
00oooooo00<00000ooooooooool0Koooool20?mo047ooooo00<00000ooooooooool02?ooool000Wo
oooo00<00000ooooooooool0/_ooool00`00003oooooooooo`0?ooooo`0300000?oooooooooo0;;o
oooo00<00000ooooooooool02?ooool000Wooooo00<00000ooooooooool0/_ooool00`00003ooooo
ooooo`0?ooooo`0300000?oooooooooo0;;ooooo00<00000ooooooooool02?ooool000Wooooo00<0
0000ooooooooool0COooool20?mo06?ooooo00<00000ooooooooool03oooool00`00003ooooooooo
o`1=ooooo`80ogl0Hoooool00`00003oooooooooo`08ooooo`002Oooool00`00003oooooooooo`1=
ooooo`80ogl05?ooool20?mo04gooooo00<00000ooooooooool03oooool00`00003oooooooooo`1=
ooooo`80ogl05?ooool20?mo04gooooo00<00000ooooooooool02?ooool000Wooooo00<00000oooo
ooooool0Hoooool20?mo04gooooo00<00000ooooooooool03oooool00`00003oooooooooo`1Soooo
o`80ogl0COooool00`00003oooooooooo`08ooooo`002Oooool00`00003oooooooooo`1Iooooo`80
ogl0Eoooool00`00003oooooooooo`0?ooooo`0300000?oooooooooo05Wooooo0P3oO`1Gooooo`03
00000?oooooooooo00Sooooo0009ooooo`0300000?oooooooooo05Wooooo0P3oO`1Gooooo`030000
0?oooooooooo00oooooo00<00000ooooooooool0FOooool20?mo05Oooooo00<00000ooooooooool0
2?ooool000Wooooo00<00000ooooooooool0LOooool20?mo03oooooo00<00000ooooooooool03ooo
ool00`00003oooooooooo`1aooooo`80ogl0?oooool00`00003oooooooooo`08ooooo`002Oooool0
0`00003oooooooooo`1aooooo`80ogl0?oooool00`00003oooooooooo`0?ooooo`0300000?oooooo
oooo077ooooo0P3oO`0oooooo`0300000?oooooooooo00Sooooo0009ooooo`0300000?oooooooooo
0;;ooooo00<00000ooooooooool03oooool00`00003oooooooooo`2booooo`0300000?oooooooooo
00Sooooo0009ooooo`0300000?oooooooooo0;;ooooo00<00000ooooooooool03oooool00`00003o
ooooooooo`2booooo`0300000?oooooooooo00Sooooo0009ooooo`0300000?oooooooooo0;;ooooo
00<00000ooooooooool03oooool00`00003oooooooooo`2booooo`0300000?oooooooooo00Sooooo
0009ooooo`0300000?oooooooooo0;;ooooo00<00000ooooooooool03oooool00`00003ooooooooo
o`2booooo`0300000?oooooooooo00Sooooo0009ooooo`0300000?oooooooooo0;;ooooo00<00000
ooooooooool03oooool00`00003oooooooooo`2booooo`0300000?oooooooooo00Sooooo0009oooo
o`0300000?oooooooooo0;;ooooo00<00000ooooooooool03oooool00`00003oooooooooo`2boooo
o`0300000?oooooooooo00Sooooo0009ooooo`0300000?oooooooooo0;;ooooo00<00000oooooooo
ool03oooool00`00003oooooooooo`2booooo`0300000?oooooooooo00Sooooo0009ooooo`030000
0?oooooooooo0;;ooooo00<00000ooooooooool03oooool00`00003oooooooooo`2booooo`030000
0?oooooooooo00Sooooo0009ooooo`0300000?oooooooooo0;;ooooo00<00000ooooooooool03ooo
ool00`00003oooooooooo`2booooo`0300000?oooooooooo00Sooooo0009ooooo`0300000?oooooo
oooo0;;ooooo00<00000ooooooooool03oooool00`00003oooooooooo`2booooo`0300000?oooooo
oooo00Sooooo0009ooooo`0300000?oooooooooo0;;ooooo00<00000ooooooooool03oooool00`00
003oooooooooo`2booooo`0300000?oooooooooo00Sooooo0009ooooo`0300000?oooooooooo0;;o
oooo00<00000ooooooooool03oooool00`00003oooooooooo`2booooo`0300000?oooooooooo00So
oooo0009ooooo`0300000?oooooooooo0;;ooooo00<00000ooooooooool03oooool00`00003ooooo
ooooo`2booooo`0300000?oooooooooo00Sooooo0009ooooo`0300000?oooooooooo0;;ooooo00<0
0000ooooooooool03oooool00`00003oooooooooo`2booooo`0300000?oooooooooo00Sooooo0009
ooooo`0300000?oooooooooo0;;ooooo00<00000ooooooooool03oooool00`00003oooooooooo`2b
ooooo`0300000?oooooooooo00Sooooo0009ooooo`0300000?oooooooooo0;;ooooo00<00000oooo
ooooool03oooool00`00003oooooooooo`2booooo`0300000?oooooooooo00Sooooo0009ooooo`03
00000?oooooooooo0;;ooooo00<00000ooooooooool03oooool00`00003oooooooooo`2booooo`03
00000?oooooooooo00Sooooo0009ooooo`0300000?oooooooooo0;;ooooo00<00000ooooooooool0
3oooool00`00003oooooooooo`2booooo`0300000?oooooooooo00Sooooo0009ooooo`0300000?oo
oooooooo0;;ooooo00<00000ooooooooool03oooool00`00003oooooooooo`2booooo`0300000?oo
oooooooo00Sooooo0009ooooo`0300000?oooooooooo0;;ooooo00<00000ooooooooool03oooool0
0`00003oooooooooo`2booooo`0300000?oooooooooo00Sooooo0009ooooo`0300000?oooooooooo
0;;ooooo00<00000ooooooooool03oooool00`00003oooooooooo`2booooo`0300000?oooooooooo
00Sooooo0009ooooo`0300000?oooooooooo0;;ooooo00<00000ooooooooool03oooool00`00003o
ooooooooo`2booooo`0300000?oooooooooo00Sooooo0009ooooo`0300000?oooooooooo0;;ooooo
00<00000ooooooooool03oooool00`00003oooooooooo`2booooo`0300000?oooooooooo00Sooooo
0009ooooo`0300000?oooooooooo0;;ooooo00<00000ooooooooool03oooool00`00003ooooooooo
o`2booooo`0300000?oooooooooo00Sooooo0009ooooo`0300000?oooooooooo05Sooooo0P3oO`1H
ooooo`0300000?oooooooooo00oooooo00<00000ooooooooool0F?ooool20?mo05Sooooo00<00000
ooooooooool02?ooool000Wooooo00<00000ooooooooool0F?ooool20?mo05Sooooo00<00000oooo
ooooool03oooool00`00003oooooooooo`1Hooooo`80ogl0F?ooool00`00003oooooooooo`08oooo
o`002Oooool00`00003oooooooooo`2booooo`0300000?oooooooooo00oooooo00<00000oooooooo
ool0/_ooool00`00003oooooooooo`08ooooo`002Oooool00`00003oooooooooo`2booooo`030000
0?oooooooooo00oooooo00<00000ooooooooool0/_ooool00`00003oooooooooo`08ooooo`002Ooo
ool00`00003oooooooooo`2booooo`0300000?oooooooooo00oooooo00<00000ooooooooool0/_oo
ool00`00003oooooooooo`08ooooo`002Oooool00`00003oooooooooo`2booooo`0300000?oooooo
oooo00oooooo00<00000ooooooooool0/_ooool00`00003oooooooooo`08ooooo`002Oooool00`00
003oooooooooo`2booooo`0300000?oooooooooo00oooooo00<00000ooooooooool0/_ooool00`00
003oooooooooo`08ooooo`002Oooool00`00003oooooooooo`2booooo`0300000?oooooooooo00oo
oooo00<00000ooooooooool0/_ooool00`00003oooooooooo`08ooooo`002Oooool00`00003ooooo
ooooo`2booooo`0300000?oooooooooo00oooooo00<00000ooooooooool0/_ooool00`00003ooooo
ooooo`08ooooo`002Oooool00`00003oooooooooo`2booooo`0300000?oooooooooo00oooooo00<0
0000ooooooooool0/_ooool00`00003oooooooooo`08ooooo`002Oooool00`00003oooooooooo`2b
ooooo`0300000?oooooooooo00oooooo00<00000ooooooooool0/_ooool00`00003oooooooooo`08
ooooo`002Oooool00`00003oooooooooo`2booooo`0300000?oooooooooo00oooooo00<00000oooo
ooooool0/_ooool00`00003oooooooooo`08ooooo`002Oooool00`00003oooooooooo`2booooo`03
00000?oooooooooo00oooooo00<00000ooooooooool0/_ooool00`00003oooooooooo`08ooooo`00
2Oooool00`00003oooooooooo`2booooo`0300000?oooooooooo00oooooo00<00000ooooooooool0
/_ooool00`00003oooooooooo`08ooooo`002Oooool00`00003oooooooooo`2booooo`0300000?oo
oooooooo00oooooo00<00000ooooooooool0/_ooool00`00003oooooooooo`08ooooo`002Ooooonf
0000017ooooo]P00000:ooooo`00oooooonAooooo`00oooooonAooooo`00oooooonAooooo`00oooo
oonAooooo`00oooooonAooooo`00oooooonAooooo`00oooooonAooooo`00oooooonAooooo`00oooo
oonAooooo`00\
\>"],
  ImageRangeCache->{{{0, 399}, {399, 0}} -> {-0.0500105, -0.0500105, \
0.00526322, 0.00526322}, {{9.5, 190.438}, {389.5, 208.5}} -> {-1.15081, \
-1.15117, 0.0115117, 0.0115117}, {{208.5, 389.438}, {389.5, 208.5}} -> \
{-1.09771, -0.0754011, 0.0052648, 0.0052648}, {{9.5, 190.438}, {190.438, \
9.5}} -> {-1.11761, -3.34306, 0.0111796, 0.0111796}, {{208.5, 389.438}, \
{190.438, 9.5}} -> {-3.34236, -3.34306, 0.0111796, 0.0111796}}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
Plot log-likelihood of data given the model as a function of EM \
iteration\
\>", "Subsubsection"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(PlotLogLikelihood[em, xd];\)\)], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.15873 0.564049 0.00536655 [
[.02381 -0.0125 -3 -9 ]
[.02381 -0.0125 3 0 ]
[.18254 -0.0125 -3 -9 ]
[.18254 -0.0125 3 0 ]
[.34127 -0.0125 -3 -9 ]
[.34127 -0.0125 3 0 ]
[.5 -0.0125 -3 -9 ]
[.5 -0.0125 3 0 ]
[.65873 -0.0125 -3 -9 ]
[.65873 -0.0125 3 0 ]
[.81746 -0.0125 -3 -9 ]
[.81746 -0.0125 3 0 ]
[.97619 -0.0125 -3 -9 ]
[.97619 -0.0125 3 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .02739 -24 -4.5 ]
[-0.0125 .02739 0 4.5 ]
[-0.0125 .13472 -18 -4.5 ]
[-0.0125 .13472 0 4.5 ]
[-0.0125 .24206 -18 -4.5 ]
[-0.0125 .24206 0 4.5 ]
[-0.0125 .34939 -18 -4.5 ]
[-0.0125 .34939 0 4.5 ]
[-0.0125 .45672 -18 -4.5 ]
[-0.0125 .45672 0 4.5 ]
[-0.0125 .56405 -6 -4.5 ]
[-0.0125 .56405 0 4.5 ]
[ 0 0 -0.125 0 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 .5 r
.25 Mabswid
[ ] 0 setdash
.18254 0 m
.18254 .61803 L
s
.34127 0 m
.34127 .61803 L
s
.5 0 m
.5 .61803 L
s
.65873 0 m
.65873 .61803 L
s
.81746 0 m
.81746 .61803 L
s
0 .02739 m
1 .02739 L
s
0 .13472 m
1 .13472 L
s
0 .24206 m
1 .24206 L
s
0 .34939 m
1 .34939 L
s
0 .45672 m
1 .45672 L
s
0 .56405 m
1 .56405 L
s
0 g
.02381 0 m
.02381 .00625 L
s
[(0)] .02381 -0.0125 0 1 Mshowa
.18254 0 m
.18254 .00625 L
s
[(1)] .18254 -0.0125 0 1 Mshowa
.34127 0 m
.34127 .00625 L
s
[(2)] .34127 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(3)] .5 -0.0125 0 1 Mshowa
.65873 0 m
.65873 .00625 L
s
[(4)] .65873 -0.0125 0 1 Mshowa
.81746 0 m
.81746 .00625 L
s
[(5)] .81746 -0.0125 0 1 Mshowa
.97619 0 m
.97619 .00625 L
s
[(6)] .97619 -0.0125 0 1 Mshowa
.125 Mabswid
.05556 0 m
.05556 .00375 L
s
.0873 0 m
.0873 .00375 L
s
.11905 0 m
.11905 .00375 L
s
.15079 0 m
.15079 .00375 L
s
.21429 0 m
.21429 .00375 L
s
.24603 0 m
.24603 .00375 L
s
.27778 0 m
.27778 .00375 L
s
.30952 0 m
.30952 .00375 L
s
.37302 0 m
.37302 .00375 L
s
.40476 0 m
.40476 .00375 L
s
.43651 0 m
.43651 .00375 L
s
.46825 0 m
.46825 .00375 L
s
.53175 0 m
.53175 .00375 L
s
.56349 0 m
.56349 .00375 L
s
.59524 0 m
.59524 .00375 L
s
.62698 0 m
.62698 .00375 L
s
.69048 0 m
.69048 .00375 L
s
.72222 0 m
.72222 .00375 L
s
.75397 0 m
.75397 .00375 L
s
.78571 0 m
.78571 .00375 L
s
.84921 0 m
.84921 .00375 L
s
.88095 0 m
.88095 .00375 L
s
.9127 0 m
.9127 .00375 L
s
.94444 0 m
.94444 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .02739 m
.00625 .02739 L
s
[(-100)] -0.0125 .02739 1 0 Mshowa
0 .13472 m
.00625 .13472 L
s
[(-80)] -0.0125 .13472 1 0 Mshowa
0 .24206 m
.00625 .24206 L
s
[(-60)] -0.0125 .24206 1 0 Mshowa
0 .34939 m
.00625 .34939 L
s
[(-40)] -0.0125 .34939 1 0 Mshowa
0 .45672 m
.00625 .45672 L
s
[(-20)] -0.0125 .45672 1 0 Mshowa
0 .56405 m
.00625 .56405 L
s
[(0)] -0.0125 .56405 1 0 Mshowa
.125 Mabswid
0 .05423 m
.00375 .05423 L
s
0 .08106 m
.00375 .08106 L
s
0 .10789 m
.00375 .10789 L
s
0 .16156 m
.00375 .16156 L
s
0 .18839 m
.00375 .18839 L
s
0 .21522 m
.00375 .21522 L
s
0 .26889 m
.00375 .26889 L
s
0 .29572 m
.00375 .29572 L
s
0 .32255 m
.00375 .32255 L
s
0 .37622 m
.00375 .37622 L
s
0 .40305 m
.00375 .40305 L
s
0 .42988 m
.00375 .42988 L
s
0 .48355 m
.00375 .48355 L
s
0 .51038 m
.00375 .51038 L
s
0 .53722 m
.00375 .53722 L
s
0 .00056 m
.00375 .00056 L
s
0 .59088 m
.00375 .59088 L
s
0 .61771 m
.00375 .61771 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
.02381 .61178 m
.02381 .61803 L
s
.18254 .61178 m
.18254 .61803 L
s
.34127 .61178 m
.34127 .61803 L
s
.5 .61178 m
.5 .61803 L
s
.65873 .61178 m
.65873 .61803 L
s
.81746 .61178 m
.81746 .61803 L
s
.97619 .61178 m
.97619 .61803 L
s
.125 Mabswid
.05556 .61428 m
.05556 .61803 L
s
.0873 .61428 m
.0873 .61803 L
s
.11905 .61428 m
.11905 .61803 L
s
.15079 .61428 m
.15079 .61803 L
s
.21429 .61428 m
.21429 .61803 L
s
.24603 .61428 m
.24603 .61803 L
s
.27778 .61428 m
.27778 .61803 L
s
.30952 .61428 m
.30952 .61803 L
s
.37302 .61428 m
.37302 .61803 L
s
.40476 .61428 m
.40476 .61803 L
s
.43651 .61428 m
.43651 .61803 L
s
.46825 .61428 m
.46825 .61803 L
s
.53175 .61428 m
.53175 .61803 L
s
.56349 .61428 m
.56349 .61803 L
s
.59524 .61428 m
.59524 .61803 L
s
.62698 .61428 m
.62698 .61803 L
s
.69048 .61428 m
.69048 .61803 L
s
.72222 .61428 m
.72222 .61803 L
s
.75397 .61428 m
.75397 .61803 L
s
.78571 .61428 m
.78571 .61803 L
s
.84921 .61428 m
.84921 .61803 L
s
.88095 .61428 m
.88095 .61803 L
s
.9127 .61428 m
.9127 .61803 L
s
.94444 .61428 m
.94444 .61803 L
s
.25 Mabswid
0 .61803 m
1 .61803 L
s
.99375 .02739 m
1 .02739 L
s
.99375 .13472 m
1 .13472 L
s
.99375 .24206 m
1 .24206 L
s
.99375 .34939 m
1 .34939 L
s
.99375 .45672 m
1 .45672 L
s
.99375 .56405 m
1 .56405 L
s
.125 Mabswid
.99625 .05423 m
1 .05423 L
s
.99625 .08106 m
1 .08106 L
s
.99625 .10789 m
1 .10789 L
s
.99625 .16156 m
1 .16156 L
s
.99625 .18839 m
1 .18839 L
s
.99625 .21522 m
1 .21522 L
s
.99625 .26889 m
1 .26889 L
s
.99625 .29572 m
1 .29572 L
s
.99625 .32255 m
1 .32255 L
s
.99625 .37622 m
1 .37622 L
s
.99625 .40305 m
1 .40305 L
s
.99625 .42988 m
1 .42988 L
s
.99625 .48355 m
1 .48355 L
s
.99625 .51038 m
1 .51038 L
s
.99625 .53722 m
1 .53722 L
s
.99625 .00056 m
1 .00056 L
s
.99625 .59088 m
1 .59088 L
s
.99625 .61771 m
1 .61771 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
.5 Mabswid
.02381 .01472 m
.18254 .35783 L
.34127 .39998 L
.5 .47744 L
.65873 .588 L
.81746 .60332 L
.97619 .60332 L
s
1 0 0 r
.02 w
.02381 .01472 Mdot
.18254 .35783 Mdot
.34127 .39998 Mdot
.5 .47744 Mdot
.65873 .588 Mdot
.81746 .60332 Mdot
.97619 .60332 Mdot
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/B000`400?l00000o`00003ooooooolQ
ooooo`00oooooolQooooo`00oooooolQooooo`008?ooool2o`0002Kooooo0ol0000Uooooo`Go0000
9_ooool3o`0002Oooooo0ol0000Uooooo`?o00009_ooool3o`0000Oooooo000Oooooo`04o`000?oo
ooooooooo`0002Kooooo00?o0000ooooooooool09Oooool01?l0003oooooooooool0000Uooooo`05
o`000?ooooooooooooooool000009oooool00ol0003oooooooooo`0Sooooo`05o`000?oooooooooo
ooooool000009?ooool01Ol0003ooooooooooooooooo000000Kooooo000Oooooo`04o`000?oooooo
ooooo`0002Kooooo00?o0000ooooooooool09_ooool00ol0003oooooooooo`0Yooooo`03o`000?oo
oooooooo02;ooooo1Ol0000Xooooo`03o`000?oooooooooo02;ooooo00Go0000oooooooooooooooo
o`000006ooooo`007oooool01?l0003oooooooooool0000Vooooo`03o`000?oooooooooo02Oooooo
00?o0000ooooooooool09_ooool2o`0002Gooooo00Co0000oooooooooooo0000:Oooool00ol0003o
ooooooooo`0Rooooo`Co00001oooool001oooooo00Co0000oooooooooooo00009_ooool00ol0003o
ooooooooo`0Tooooo`05o`000?ooooooooooooooool00000:Oooool00ol0003oooooooooo`0Soooo
o`03o`000?oooooo000002Gooooo1?l0000Uooooo`03o`000?oooooooooo00Sooooo000Oooooo`04
o`000?ooooooooooo`0002Gooooo0_l0000Vooooo`05o`000?ooooooooooooooool000009Oooool0
1Ol0003ooooooooooooooooo000002Kooooo0_l0000Uooooo`03o`000?oooooooooo02Oooooo00?o
0000ooooooooool01oooool0023ooooo0_l0000Wooooo`03o`000?oooooooooo02Gooooo0ol0000W
ooooo`?o0000:?ooool00ol0003oooooooooo`0Sooooo`Go00009_ooool2o`0000Oooooo003ooooo
ob7ooooo003oooooob7ooooo003oooooob7ooooo003oooooob7ooooo000Koooooooo00001Ol00001
ooooo`006oooool00ol0003oooooooooo`03ooooo`0300000?oooooooooo00Gooooo00?o0000oooo
ooooool01Oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Gooooo00?o0000oooo
ooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Kooooo00?o0000oooo
ooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000oooo
ooooool01_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000oooo
ooooool01Oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Gooooo00?o0000oooo
ooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Kooooo00?o0000oooo
ooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000oooo
ooooool01Oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Gooooo00?o0000oooo
ooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Kooooo00?o0000oooo
ooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00?ooooo0Ol00001oooo
o`006oooool00ol0003oooooooooo`02ooooo`<0o`009oooool00ol0003oooooooooo`0Vooooo`03
o`000?oooooooooo02Oooooo00?o0000ooooooooool09_ooool00ol0003oooooooooo`0Vooooo`03
o`000?oooooooooo02Kooooo00?o0000ooooooooool00oooool1o`00007ooooo000Kooooo`04o`00
0?ooooooooooooooo`D0o`009_ooool00`0007ooooooooooo`0Vooooo`030000Oooooooooooo02Oo
oooo00<0001oooooooooool09_ooool00`0007ooooooooooo`0Vooooo`030000Oooooooooooo02co
oooo0Ol00001ooooo`006oooool01?l0003oooooooooooooool50?l002Kooooo00<0001ooooooooo
ool09_ooool00`0007ooooooooooo`0Wooooo`030000Oooooooooooo02Kooooo00<0001ooooooooo
ool09_ooool00`0007ooooooooooo`0/ooooo`7o00000Oooool000Oooooo0ol00004ooooo`;o0000
1?ooool2o`0000Gooooo00Co0000oooooooooooooooo1@3o000Vooooo`030000Oooooooooooo02Ko
oooo00<0001oooooooooool09oooool00`0007ooooooooooo`0Vooooo`030000Oooooooooooo02Ko
oooo00<0001oooooooooool0;?ooool1o`00007ooooo0008ooooo`03o`000?oooooooooo00;ooooo
00Co0000oooooooooooo00000_ooool01?l0003oooooooooool00004ooooo`03o`000?oooooooooo
00;ooooo0`3o000Wooooo`030000Oooooooooooo02Kooooo00<0001oooooooooool09oooool00`00
07ooooooooooo`0Vooooo`030000Oooooooooooo02Kooooo00<0001oooooooooool0;?ooool1o`00
007ooooo0005o`0000?ooooo00?o0000ooooooooool00_ooool01?l0003oooooooooool00002oooo
o`04o`000?ooooooooooo`0000Cooooo0_l000050000O`03o`00000007l0001o0?P0001o0_l00001
ooooo`002?ooool00ol0003oooooooooo`02ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000
oooooooooooo00001?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo02Cooooo00<0
001oooooooooool09_ooool00`0007ooooooooooo`0Wooooo`030000Oooooooooooo02Kooooo00<0
001oooooooooool09_ooool00`0007ooooooooooo`0/ooooo`7o00000Oooool000Sooooo00?o0000
ooooooooool00_ooool01?l0003oooooooooool00002ooooo`04o`000?ooooooooooo`0000Cooooo
00?o0000ooooooooool01Oooool00ol0003oooooooooo`0Tooooo`030000Oooooooooooo02Kooooo
00<0001oooooooooool09oooool00`0007ooooooooooo`0Vooooo`030000Oooooooooooo02Kooooo
00<0001oooooooooool0;?ooool1o`00007ooooo0007ooooo`;o00001?ooool01?l0003ooooooooo
ool00002ooooo`04o`000?ooooooooooo`0000Cooooo00?o0000ooooooooool01_ooool00ol0003o
ooooooooo`0Sooooo`030000Oooooooooooo02Kooooo00<0001oooooooooool09oooool00`0007oo
ooooooooo`0Vooooo`030000Oooooooooooo02Kooooo00<0001oooooooooool0;?ooool1o`00007o
oooo0008ooooo`03o`000?oooooooooo00?ooooo0_l00004ooooo`;o00001Oooool00ol0003ooooo
ooooo`06ooooo`03o`000?oooooooooo02?ooooo00<0001oooooooooool09_ooool00`0007oooooo
ooooo`0Wooooo`030000Oooooooooooo02Kooooo00<0001oooooooooool09_ooool00`0007oooooo
ooooo`0/ooooo`7o00000Oooool001_ooooo00?o0000ooooooooool01_ooool00ol0003ooooooooo
o`0Sooooo`030000Oooooooooooo02Kooooo00<0001oooooooooool09oooool00`0007oooooooooo
o`0Vooooo`030000Oooooooooooo02Kooooo00<0001oooooooooool0;?ooool1o`00007ooooo000K
ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool08_ooool00`0007ooooooooooo`0V
ooooo`030000Oooooooooooo02Oooooo00<0001oooooooooool09_ooool00`0007ooooooooooo`0V
ooooo`030000Oooooooooooo02cooooo0Ol00001ooooo`006oooool2o`0000Sooooo00?o0000oooo
ooooool08_ooool00`0007ooooooooooo`0Vooooo`030000Oooooooooooo02Oooooo00<0001ooooo
ooooool09_ooool00`0007ooooooooooo`0Vooooo`030000Oooooooooooo02_ooooo0_l00001oooo
o`006oooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo027ooooo00<0001ooooooooo
ool09_ooool00`0007ooooooooooo`0Wooooo`030000Oooooooooooo02Kooooo00<0001ooooooooo
ool09_ooool00`0007ooooooooooo`0/ooooo`7o00000Oooool001_ooooo00?o0000ooooooooool0
2?ooool00ol0003oooooooooo`0Qooooo`030000Oooooooooooo02Kooooo00<0001oooooooooool0
9oooool00`0007ooooooooooo`0Vooooo`030000Oooooooooooo02Kooooo00<0001oooooooooool0
;?ooool1o`00007ooooo000Kooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool08?oo
ool00`0007ooooooooooo`0Vooooo`030000Oooooooooooo02Oooooo00<0001oooooooooool09_oo
ool00`0007ooooooooooo`0Vooooo`030000Oooooooooooo02cooooo0Ol00001ooooo`006oooool0
0ol0003oooooooooo`09ooooo`03o`000?oooooooooo023ooooo00<0001oooooooooool09_ooool0
0`0007ooooooooooo`0Wooooo`030000Oooooooooooo02Kooooo00<0001oooooooooool09_ooool0
0`0007ooooooooooo`0/ooooo`7o00000Oooool001_ooooo00?o0000ooooooooool02_ooool00ol0
003oooooooooo`0Oooooo`030000Oooooooooooo02Kooooo00<0001oooooooooool09oooool00`00
07ooooooooooo`0Vooooo`030000Oooooooooooo02Kooooo00<0001oooooooooool0;?ooool1o`00
007ooooo000Kooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool07oooool00`0007oo
ooooooooo`0Vooooo`030000Oooooooooooo02Oooooo00<0001oooooooooool09_ooool00`0007oo
ooooooooo`0Vooooo`030000Oooooooooooo02cooooo0Ol00001ooooo`006oooool2o`0000cooooo
00?o0000ooooooooool07_ooool00`0007ooooooooooo`0Vooooo`030000Oooooooooooo02Oooooo
00<0001oooooooooool09_ooool00`0007ooooooooooo`0Vooooo`030000Oooooooooooo02_ooooo
0_l00001ooooo`006oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo01kooooo00<0
001oooooooooool09_ooool00`0007ooooooooooo`0Wooooo`030000Oooooooooooo02Kooooo00<0
001oooooooooool09_ooool00`0007ooooooooooo`0/ooooo`7o00000Oooool001_ooooo00?o0000
ooooooooool03?ooool00ol0003oooooooooo`0Mooooo`030000Oooooooooooo02Kooooo00<0001o
ooooooooool09oooool00`0007ooooooooooo`0Vooooo`030000Oooooooooooo02Kooooo00<0001o
ooooooooool0;?ooool1o`00007ooooo000Kooooo`03o`000?oooooooooo00cooooo00?o0000oooo
ooooool07Oooool00`0007ooooooooooo`0Vooooo`030000Oooooooooooo02Oooooo00<0001ooooo
ooooool09_ooool00`0007ooooooooooo`0Vooooo`030000Oooooooooooo02cooooo0Ol00001oooo
o`006oooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo01gooooo00<0001ooooooooo
ool09_ooool00`0007ooooooooooo`0Wooooo`030000Oooooooooooo02Kooooo00<0001ooooooooo
ool09_ooool00`0007ooooooooooo`0/ooooo`7o00000Oooool001_ooooo00?o0000ooooooooool0
3Oooool00ol0003oooooooooo`0Looooo`030000Oooooooooooo02Kooooo00<0001oooooooooool0
9oooool00`0007ooooooooooo`0Vooooo`030000Oooooooooooo02Kooooo00<0001oooooooooool0
;?ooool1o`00007ooooo000Kooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool07?oo
ool00`0007ooooooooooo`0Vooooo`030000Oooooooooooo02Oooooo00<0001oooooooooool09_oo
ool00`0007ooooooooooo`0Vooooo`030000Oooooooooooo02cooooo0Ol00001ooooo`006oooool2
o`0000oooooo00?o0000ooooooooool06oooool00`0007ooooooooooo`0Vooooo`030000Oooooooo
oooo02Oooooo00<0001oooooooooool09_ooool00`0007ooooooooooo`0Vooooo`030000Oooooooo
oooo02_ooooo0_l00001ooooo`006oooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo
01_ooooo00<0001oooooooooool09_ooool00`0007ooooooooooo`0Wooooo`030000Oooooooooooo
02Kooooo00<0001oooooooooool09_ooool00`0007ooooooooooo`0/ooooo`7o00000Oooool001_o
oooo00?o0000ooooooooool03oooool00ol0003oooooooooo`0Jooooo`030000Oooooooooooo02Ko
oooo00<0001oooooooooool09oooool00`0007ooooooooooo`0Vooooo`030000Oooooooooooo02Ko
oooo00<0001oooooooooool0;?ooool1o`00007ooooo000Kooooo`03o`000?oooooooooo00oooooo
00?o0000ooooooooool06_ooool00`0007ooooooooooo`0Vooooo`030000Oooooooooooo02Oooooo
00<0001oooooooooool09_ooool00`0007ooooooooooo`0Vooooo`030000Oooooooooooo02cooooo
0Ol00001ooooo`003Oooool3o`0000Cooooo0_l00005ooooo`03o`000?oooooooooo013ooooo00?o
0000ooooooooool06Oooool00`0007ooooooooooo`0Vooooo`030000Oooooooooooo02Oooooo00<0
001oooooooooool09_ooool00`0007ooooooooooo`0Vooooo`030000Oooooooooooo02cooooo0Ol0
0001ooooo`003?ooool01Ol0003ooooooooooooooooo000000;ooooo00Co0000oooooooooooo0000
1?ooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo01Wooooo00<0001oooooooooool0
9_ooool00`0007ooooooooooo`0Wooooo`030000Oooooooooooo02Kooooo00<0001oooooooooool0
9_ooool00`0007ooooooooooo`0/ooooo`7o00000Oooool000Kooooo1Ol000000ooooooo0000oooo
o`02ooooo`04o`000?ooooooooooo`0000;ooooo00?o0000ooooooooool00_ooool00ol0003ooooo
ooooo`0Aooooo`03o`000?oooooooooo01Sooooo00<0001oooooooooool09_ooool00`0007oooooo
ooooo`0Wooooo`030000Oooooooooooo02Kooooo00<0001oooooooooool09_ooool00`0007oooooo
ooooo`0/ooooo`7o00000Oooool000gooooo0ol00003ooooo`04o`000?ooooooooooo`0000Cooooo
0_l0000B0000O`03o`00000007l0001o0>/0001o0_l00001ooooo`003?ooool01Ol0003ooooooooo
oooooooo000000;ooooo00Co0000oooooooooooo00001?ooool00ol0003oooooooooo`0Booooo`03
o`000?oooooooooo01Oooooo00<0001oooooooooool09_ooool00`0007ooooooooooo`0Wooooo`03
0000Oooooooooooo02Kooooo00<0001oooooooooool09_ooool00`0007ooooooooooo`0/ooooo`7o
00000Oooool000cooooo00Go0000ooooooooooooooooo`000002ooooo`04o`000?ooooooooooo`00
00Cooooo00?o0000ooooooooool04_ooool00ol0003oooooooooo`0Gooooo`030000Oooooooooooo
02Kooooo00<0001oooooooooool09oooool00`0007ooooooooooo`0Vooooo`030000Oooooooooooo
02Kooooo00<0001oooooooooool0;?ooool1o`00007ooooo000=ooooo`?o00001?ooool2o`0000Go
oooo00?o0000ooooooooool04_ooool00ol0003oooooooooo`0Gooooo`030000Oooooooooooo02Ko
oooo00<0001oooooooooool09oooool00`0007ooooooooooo`0Vooooo`030000Oooooooooooo02Ko
oooo00<0001oooooooooool0;?ooool1o`00007ooooo000Kooooo`03o`000?oooooooooo01?ooooo
00?o0000ooooooooool05_ooool00`0007ooooooooooo`0Vooooo`030000Oooooooooooo02Oooooo
00<0001oooooooooool09_ooool00`0007ooooooooooo`0Vooooo`030000Oooooooooooo02cooooo
0Ol00001ooooo`006oooool00ol0003oooooooooo`0Cooooo`03o`000?oooooooooo01Kooooo00<0
001oooooooooool09_ooool00`0007ooooooooooo`0Wooooo`030000Oooooooooooo02Kooooo00<0
001oooooooooool09_ooool00`0007ooooooooooo`0/ooooo`7o00000Oooool001_ooooo00?o0000
ooooooooool05?ooool00ol0003oooooooooo`0Eooooo`030000Oooooooooooo02Kooooo00<0001o
ooooooooool09oooool00`0007ooooooooooo`0Vooooo`030000Oooooooooooo02Kooooo00<0001o
ooooooooool0;?ooool1o`00007ooooo000Kooooo`;o00005Oooool00ol0003oooooooooo`0Eoooo
o`030000Oooooooooooo02Kooooo00<0001oooooooooool09oooool00`0007ooooooooooo`0Voooo
o`030000Oooooooooooo02Kooooo00<0001oooooooooool0:oooool2o`00007ooooo000Kooooo`03
o`000?oooooooooo01Gooooo00?o0000ooooooooool05?ooool00`0007ooooooooooo`0Vooooo`03
0000Oooooooooooo02Oooooo00<0001oooooooooool09_ooool00`0007ooooooooooo`0Vooooo`03
0000Oooooooooooo02cooooo0Ol00001ooooo`006oooool00ol0003oooooooooo`0Eooooo`03o`00
0?oooooooooo01Cooooo00<0001oooooooooool09_ooool00`0007ooooooooooo`0Wooooo`030000
Oooooooooooo02Kooooo00<0001oooooooooool09_ooool00`0007ooooooooooo`0/ooooo`7o0000
0Oooool001_ooooo00?o0000ooooooooool05_ooool00ol0003oooooooooo`0Cooooo`030000Oooo
oooooooo02Kooooo00<0001oooooooooool09oooool00`0007ooooooooooo`0Vooooo`030000Oooo
oooooooo02Kooooo00<0001oooooooooool0;?ooool1o`00007ooooo000Kooooo`03o`000?oooooo
oooo01Kooooo00?o0000ooooooooool04oooool00`0007ooooooooooo`0Vooooo`030000Oooooooo
oooo02Oooooo00<0001oooooooooool09_ooool00`0007ooooooooooo`0Vooooo`030000Oooooooo
oooo02cooooo0Ol00001ooooo`006oooool00ol0003oooooooooo`0Gooooo`03o`000?oooooooooo
01;ooooo00<0001oooooooooool09_ooool00`0007ooooooooooo`0Wooooo`030000Oooooooooooo
02Kooooo00<0001oooooooooool09_ooool00`0007ooooooooooo`0/ooooo`7o00000Oooool001_o
oooo00?o0000ooooooooool05oooool00ol0003oooooooooo`0Booooo`030000Oooooooooooo02Ko
oooo00<0001oooooooooool09oooool00`0007ooooooooooo`0Vooooo`030000Oooooooooooo02Ko
oooo00<0001oooooooooool0;?ooool1o`00007ooooo000Kooooo`;o00006Oooool00ol0003ooooo
ooooo`0Aooooo`030000Oooooooooooo02Kooooo00<0001oooooooooool09oooool00`0007oooooo
ooooo`0Vooooo`030000Oooooooooooo02Kooooo00<0001oooooooooool0:oooool2o`00007ooooo
000Kooooo`03o`000?oooooooooo01Sooooo00?o0000ooooooooool04Oooool00`0007oooooooooo
o`0Vooooo`030000Oooooooooooo02Oooooo00<0001oooooooooool09_ooool00`0007oooooooooo
o`0Vooooo`030000Oooooooooooo02cooooo0Ol00001ooooo`006oooool00ol0003oooooooooo`0H
ooooo`03o`000?oooooooooo017ooooo00<0001oooooooooool09_ooool00`0007ooooooooooo`0W
ooooo`030000Oooooooooooo02Kooooo00<0001oooooooooool09_ooool00`0007ooooooooooo`0/
ooooo`7o00000Oooool001_ooooo00?o0000ooooooooool06Oooool00ol0003oooooooooo`0@oooo
o`030000Oooooooooooo02Kooooo00<0001oooooooooool09oooool00`0007ooooooooooo`0Voooo
o`030000Oooooooooooo02Kooooo00<0001oooooooooool0;?ooool1o`00007ooooo000Kooooo`03
o`000?oooooooooo01Wooooo00?o0000ooooooooool04?ooool00`0007ooooooooooo`0Vooooo`03
0000Oooooooooooo02Oooooo00<0001oooooooooool09_ooool00`0007ooooooooooo`0Vooooo`03
0000Oooooooooooo02cooooo0Ol00001ooooo`006oooool00ol0003oooooooooo`0Jooooo`03o`00
0?oooooooooo00oooooo00<0001oooooooooool09_ooool00`0007ooooooooooo`0Wooooo`030000
Oooooooooooo02Kooooo00<0001oooooooooool09_ooool00`0007ooooooooooo`0/ooooo`7o0000
0Oooool001_ooooo00?o0000ooooooooool06_ooool00ol0003oooooooooo`0?ooooo`030000Oooo
oooooooo02Kooooo00<0001oooooooooool09oooool00`0007ooooooooooo`0Vooooo`030000Oooo
oooooooo02Kooooo00<0001oooooooooool0;?ooool1o`00007ooooo000Kooooo`;o00007?ooool0
0ol0003oooooooooo`0>ooooo`030000Oooooooooooo02Kooooo00<0001oooooooooool09oooool0
0`0007ooooooooooo`0Vooooo`030000Oooooooooooo02Kooooo00<0001oooooooooool0:oooool2
o`00007ooooo000Kooooo`03o`000?oooooooooo01_ooooo00?o0000ooooooooool03_ooool00`00
07ooooooooooo`0Vooooo`030000Oooooooooooo02Oooooo00<0001oooooooooool09_ooool00`00
07ooooooooooo`0Vooooo`030000Oooooooooooo02cooooo0Ol00001ooooo`006oooool00ol0003o
ooooooooo`0Looooo`03o`000?oooooooooo00gooooo00<0001oooooooooool09_ooool00`0007oo
ooooooooo`0Wooooo`030000Oooooooooooo02Kooooo00<0001oooooooooool09_ooool00`0007oo
ooooooooo`0/ooooo`7o00000Oooool001_ooooo00?o0000ooooooooool07?ooool00ol0003ooooo
ooooo`0=ooooo`030000Oooooooooooo02Kooooo00<0001oooooooooool09oooool00`0007oooooo
ooooo`0Vooooo`030000Oooooooooooo02Kooooo00<0001oooooooooool0;?ooool1o`00007ooooo
000=ooooo`?o00001?ooool2o`0000Gooooo00?o0000ooooooooool07Oooool00ol0003ooooooooo
o`0<ooooo`030000Oooooooooooo02Kooooo00<0001oooooooooool09oooool00`0007oooooooooo
o`0Vooooo`030000Oooooooooooo02Kooooo00<0001oooooooooool0;?ooool1o`00007ooooo000<
ooooo`05o`000?ooooooooooooooool000000_ooool01?l0003oooooooooool00004ooooo`03o`00
0?oooooooooo01gooooo00?o0000ooooooooool03?ooool00`0007ooooooooooo`0Vooooo`030000
Oooooooooooo02Oooooo00<0001oooooooooool09_ooool00`0007ooooooooooo`0Vooooo`030000
Oooooooooooo02cooooo0Ol00001ooooo`001_ooool5o`000003ooooool0003ooooo00;ooooo00Co
0000oooooooooooo00000_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo01gooooo
00?o0000ooooooooool03?ooool00`0007ooooooooooo`0Vooooo`030000Oooooooooooo02Oooooo
00<0001oooooooooool09_ooool00`0007ooooooooooo`0Vooooo`030000Oooooooooooo02cooooo
0Ol00001ooooo`003?ooool4o`0000?ooooo00Co0000oooooooooooo00001?ooool2o`0001l0001o
00?o00000000O`0007l0gP0007l2o`00007ooooo000<ooooo`03o`000?oooooooooo00Cooooo00Co
0000oooooooooooo00001?ooool00ol0003oooooooooo`0Nooooo`03o`000?oooooooooo00_ooooo
00<0001oooooooooool09_ooool00`0007ooooooooooo`0Wooooo`030000Oooooooooooo02Kooooo
00<0001oooooooooool09_ooool00`0007ooooooooooo`0/ooooo`7o00000Oooool000gooooo00?o
0000ooooooooool00oooool01?l0003oooooooooool00004ooooo`03o`000?oooooooooo01oooooo
00?o0000ooooooooool02_ooool00`0007ooooooooooo`0Vooooo`030000Oooooooooooo02Oooooo
00<0001oooooooooool09_ooool00`0007ooooooooooo`0Vooooo`030000Oooooooooooo02cooooo
0Ol00001ooooo`003_ooool2o`0000Cooooo0_l00005ooooo`03o`000?oooooooooo01oooooo00?o
0000ooooooooool02_ooool00`0007ooooooooooo`0Vooooo`030000Oooooooooooo02Oooooo00<0
001oooooooooool09_ooool00`0007ooooooooooo`0Vooooo`030000Oooooooooooo02cooooo0Ol0
0001ooooo`006oooool00ol0003oooooooooo`0Pooooo`03o`000?oooooooooo00Wooooo00<0001o
ooooooooool09_ooool00`0007ooooooooooo`0Wooooo`030000Oooooooooooo02Kooooo00<0001o
ooooooooool09_ooool00`0007ooooooooooo`0/ooooo`7o00000Oooool001_ooooo00?o0000oooo
ooooool08?ooool00ol0003oooooooooo`09ooooo`030000Oooooooooooo02Kooooo00<0001ooooo
ooooool09oooool00`0007ooooooooooo`0Vooooo`030000Oooooooooooo02Kooooo00<0001ooooo
ooooool0;?ooool1o`00007ooooo000Kooooo`03o`000?oooooooooo027ooooo00?o0000oooooooo
ool02?ooool00`0007ooooooooooo`0Vooooo`030000Oooooooooooo02Oooooo00<0001ooooooooo
ool09_ooool00`0007ooooooooooo`0Vooooo`030000Oooooooooooo02cooooo0Ol00001ooooo`00
6oooool2o`0002;ooooo00?o0000ooooooooool02?ooool00`0007ooooooooooo`0Vooooo`030000
Oooooooooooo02Oooooo00<0001oooooooooool09_ooool00`0007ooooooooooo`0Vooooo`030000
Oooooooooooo02_ooooo0_l00001ooooo`006oooool00ol0003oooooooooo`0Rooooo`03o`000?oo
oooooooo00Oooooo00<0001oooooooooool09_ooool00`0007ooooooooooo`0Wooooo`030000Oooo
oooooooo02Kooooo00<0001oooooooooool09_ooool00`0007ooooooooooo`0/ooooo`7o00000Ooo
ool001_ooooo00?o0000ooooooooool08_ooool00ol0003oooooooooo`07ooooo`030000Oooooooo
oooo02Kooooo00<0001oooooooooool09oooool00`0007ooooooooooo`0Vooooo`030000Oooooooo
oooo02Kooooo00<0001oooooooooool0;?ooool1o`00007ooooo000Kooooo`03o`000?oooooooooo
02?ooooo00?o0000ooooooooool01_ooool00`0007ooooooooooo`0Vooooo`030000Oooooooooooo
02Oooooo00<0001oooooooooool09_ooool00`0007ooooooooooo`0Vooooo`030000Oooooooooooo
02cooooo0Ol00001ooooo`006oooool00ol0003oooooooooo`0Sooooo`03o`000?oooooooooo00Ko
oooo00<0001oooooooooool09_ooool00`0007ooooooooooo`0Wooooo`030000Oooooooooooo02Ko
oooo00<0001oooooooooool09_ooool00`0007ooooooooooo`0/ooooo`7o00000Oooool001_ooooo
00?o0000ooooooooool08oooool00ol0003oooooooooo`06ooooo`030000Oooooooooooo02Kooooo
00<0001oooooooooool09oooool00`0007ooooooooooo`0Vooooo`030000Oooooooooooo02Kooooo
00<0001oooooooooool0;?ooool1o`00007ooooo000Kooooo`03o`000?oooooooooo02Cooooo00?o
0000ooooooooool01Oooool00`0007ooooooooooo`0Vooooo`030000Oooooooooooo02Oooooo00<0
001oooooooooool09_ooool00`0007ooooooooooo`0Vooooo`030000Oooooooooooo02cooooo0Ol0
0001ooooo`006oooool2o`0002Gooooo00?o0000ooooooooool01Oooool00`0007ooooooooooo`0V
ooooo`030000Oooooooooooo02Oooooo00<0001oooooooooool09_ooool00`0007ooooooooooo`0V
ooooo`030000Oooooooooooo02_ooooo0_l00001ooooo`006oooool00ol0003oooooooooo`0Uoooo
o`03o`000?oooooooooo00Cooooo00<0001oooooooooool09_ooool00`0007ooooooooooo`0Woooo
o`030000Oooooooooooo02Kooooo00<0001oooooooooool09_ooool00`0007ooooooooooo`0/oooo
o`7o00000Oooool001_ooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`04ooooo`03
0000Oooooooooooo02Kooooo00<0001oooooooooool09oooool00`0007ooooooooooo`0Vooooo`03
0000Oooooooooooo02Kooooo00<0001oooooooooool0;?ooool1o`00007ooooo000Kooooo`03o`00
0?oooooooooo02Kooooo00?o0000ooooooooool00oooool00`0007ooooooooooo`0Vooooo`030000
Oooooooooooo02Oooooo00<0001oooooooooool09_ooool00`0007ooooooooooo`0Vooooo`030000
Oooooooooooo02cooooo0Ol00001ooooo`006oooool00ol0003oooooooooo`0Vooooo`03o`000?oo
oooooooo00?ooooo00<0001oooooooooool09_ooool00`0007ooooooooooo`0Wooooo`030000Oooo
oooooooo02Kooooo00<0001oooooooooool09_ooool00`0007ooooooooooo`0/ooooo`7o00000Ooo
ool001_ooooo00?o0000ooooooooool09oooool00ol0003oooooooooo`02ooooo`030000Oooooooo
oooo02Kooooo00<0001oooooooooool09oooool00`0007ooooooooooo`0Vooooo`030000Oooooooo
oooo02Kooooo00<0001oooooooooool0;?ooool1o`00007ooooo000Kooooo`03o`000?oooooooooo
02Oooooo00?o0000ooooooooool00_ooool00`0007ooooooooooo`0Vooooo`030000Oooooooooooo
02Oooooo00<0001oooooooooool09_ooool00`0007ooooooooooo`0Vooooo`030000Oooooooooooo
02cooooo0Ol00001ooooo`006oooool2o`0002Wooooo00Go0000oooooooooooooooo0000O`0Xoooo
o`030000Oooooooooooo02Oooooo00<0001oooooooooool09_ooool00`0007ooooooooooo`0Voooo
o`030000Oooooooooooo02_ooooo0_l00001ooooo`006oooool00ol0003oooooooooo`0Xooooo`05
o`000?ooooooooooooooo`0007l0:?ooool00`0007ooooooooooo`0Wooooo`030000Oooooooooooo
02Kooooo00<0001oooooooooool09_ooool00`0007ooooooooooo`0/ooooo`7o00000Oooool001_o
oooo00?o0000ooooooooool0:Oooool01?l0003oooooooooo`0007lXooooo`030000Oooooooooooo
02Oooooo00<0001oooooooooool09_ooool00`0007ooooooooooo`0Vooooo`030000Oooooooooooo
02cooooo0Ol00001ooooo`006oooool00ol0003oooooooooo`0Yooooo`04o`000?oooooooooo0000
ObSooooo00<0001oooooooooool09oooool00`0007ooooooooooo`0Vooooo`030000Oooooooooooo
02Kooooo00<0001oooooooooool0;?ooool1o`00007ooooo000>ooooo`?o00000oooool2o`0000Go
oooo00?o0000ooooooooool0:Oooool01?l0003oooooooooo`0007lXooooo`030000Oooooooooooo
02Oooooo00<0001oooooooooool09_ooool00`0007ooooooooooo`0Vooooo`030000Oooooooooooo
02cooooo0Ol00001ooooo`003oooool01Ol0003ooooooooooooooooo000000;ooooo00?o0000oooo
ooooool00_ooool00ol0003oooooooooo`0Zooooo`03o`000?ooool0001o02Sooooo00<0001ooooo
ooooool09oooool00`0007ooooooooooo`0Vooooo`030000Oooooooooooo02Kooooo00<0001ooooo
ooooool0;?ooool1o`00007ooooo0006ooooo`Go000000?oooooo`000?l000000ol00002ooooo`04
o`000?ooooooooooo`0000Cooooo00?o0000ooooooooool0:_ooool00ol0003ooooo0000O`0Xoooo
o`030000Oooooooooooo02Oooooo00<0001oooooooooool09_ooool00`0007ooooooooooo`0Voooo
o`030000Oooooooooooo02cooooo0Ol00001ooooo`003?ooool01?l0003oooooooooool00003oooo
o`04o`000?ooooooooooo`0000Cooooo0_l0000/0000O`<0o`00d@0007l2o`00007ooooo000=oooo
o`03o`000?oooooo000000?ooooo00Co0000oooooooooooo00001?ooool00ol0003oooooooooo`0Z
ooooo`D0o`009_ooool00`0007ooooooooooo`0Wooooo`030000Oooooooooooo02Kooooo00<0001o
ooooooooool09_ooool00`0007ooooooooooo`0/ooooo`7o00000Oooool000kooooo0_l00003oooo
o`04o`000?ooooooooooo`0000Cooooo00?o0000ooooooooool0:_ooool50?l002Kooooo00<0001o
ooooooooool09oooool00`0007ooooooooooo`0Vooooo`030000Oooooooooooo02Kooooo00<0001o
ooooooooool0;?ooool1o`00007ooooo000?ooooo`03o`000?oooooooooo00;ooooo0_l00005oooo
o`03o`000?oooooooooo02[ooooo1@3o0004o`0002;ooooo00<0001oooooooooool09oooool00`00
07ooooooooooo`0Vooooo`030000Oooooooooooo02Kooooo00<0001oooooooooool0;?ooool1o`00
007ooooo000Kooooo`03o`000?oooooooooo02_ooooo0`3o0005ooooo`?o00007oooool00`0007oo
ooooooooo`0Wooooo`030000Oooooooooooo02Kooooo00<0001oooooooooool09_ooool00`0007oo
ooooooooo`0/ooooo`7o00000Oooool001_ooooo00?o0000ooooooooool0;?ooool00`0007oooooo
ooooo`07ooooo`Co00006oooool00`0007ooooooooooo`0Wooooo`030000Oooooooooooo02Kooooo
00<0001oooooooooool09_ooool00`0007ooooooooooo`0/ooooo`7o00000Oooool001_ooooo00?o
0000ooooooooool0;?ooool00`0007ooooooooooo`0;ooooo`Co00005oooool00`0007oooooooooo
o`0Wooooo`030000Oooooooooooo02Kooooo00<0001oooooooooool09_ooool00`0007oooooooooo
o`0/ooooo`7o00000Oooool001_ooooo0_l0000]ooooo`030000Oooooooooooo00oooooo1?l0000C
ooooo`030000Oooooooooooo02Oooooo00<0001oooooooooool09_ooool00`0007ooooooooooo`0V
ooooo`030000Oooooooooooo02_ooooo0_l00001ooooo`006oooool00ol0003oooooooooo`0/oooo
o`030000Oooooooooooo01?ooooo0ol0000@ooooo`030000Oooooooooooo02Oooooo00<0001ooooo
ooooool09_ooool00`0007ooooooooooo`0Vooooo`030000Oooooooooooo02cooooo0Ol00001oooo
o`006oooool00ol0003oooooooooo`0/ooooo`030000Oooooooooooo01Kooooo1?l0000<ooooo`03
0000Oooooooooooo02Oooooo00<0001oooooooooool09_ooool00`0007ooooooooooo`0Vooooo`03
0000Oooooooooooo02cooooo0Ol00001ooooo`006oooool00ol0003oooooooooo`0/ooooo`030000
Oooooooooooo01[ooooo1?l00008ooooo`030000Oooooooooooo02Oooooo00<0001oooooooooool0
9_ooool00`0007ooooooooooo`0Vooooo`030000Oooooooooooo02cooooo0Ol00001ooooo`006ooo
ool00ol0003oooooooooo`0/ooooo`030000Oooooooooooo01kooooo0ol00004ooooo`<0o`00:?oo
ool00`0007ooooooooooo`0Vooooo`030000Oooooooooooo02Kooooo00<0001oooooooooool0;?oo
ool1o`00007ooooo000Kooooo`03o`000?oooooooooo02cooooo00<0001oooooooooool08Oooool3
o`0000D0o`009oooool00`0007ooooooooooo`0Vooooo`030000Oooooooooooo02Kooooo00<0001o
ooooooooool0;?ooool1o`00007ooooo000Kooooo`03o`000?oooooooooo02cooooo00<0001ooooo
ooooool09?ooool50?l002Oooooo00<0001oooooooooool09_ooool00`0007ooooooooooo`0Voooo
o`030000Oooooooooooo02cooooo0Ol00001ooooo`006oooool2o`0002gooooo00<0001ooooooooo
ool09?ooool50?l00003o`000?oooooooooo02Cooooo00<0001oooooooooool09_ooool00`0007oo
ooooooooo`0Vooooo`030000Oooooooooooo02_ooooo0_l00001ooooo`006oooool00ol0003ooooo
ooooo`0/ooooo`030000Oooooooooooo02Gooooo0`3o0002ooooo`;o00009?ooool00`0007oooooo
ooooo`0Vooooo`030000Oooooooooooo02Kooooo00<0001oooooooooool0;?ooool1o`00007ooooo
000Kooooo`03o`000?oooooooooo02cooooo00<0001oooooooooool09_ooool00`0007oooooooooo
o`03ooooo`;o00008_ooool00`0007ooooooooooo`0Vooooo`030000Oooooooooooo02Kooooo00<0
001oooooooooool0;?ooool1o`00007ooooo000Kooooo`03o`000?oooooooooo02cooooo00<0001o
ooooooooool09_ooool00`0007ooooooooooo`05ooooo`;o00008?ooool00`0007ooooooooooo`0V
ooooo`030000Oooooooooooo02Kooooo00<0001oooooooooool0;?ooool1o`00007ooooo000Koooo
o`03o`000?oooooooooo02cooooo00<0001oooooooooool09_ooool00`0007ooooooooooo`07oooo
o`?o00007Oooool00`0007ooooooooooo`0Vooooo`030000Oooooooooooo02Kooooo00<0001ooooo
ooooool0;?ooool1o`00007ooooo000Kooooo`03o`000?oooooooooo02cooooo00<0001ooooooooo
ool09_ooool00`0007ooooooooooo`0:ooooo`;o00006oooool00`0007ooooooooooo`0Vooooo`03
0000Oooooooooooo02Kooooo00<0001oooooooooool0;?ooool1o`00007ooooo000Kooooo`03o`00
0?oooooooooo02cooooo00<0001oooooooooool09_ooool00`0007ooooooooooo`0<ooooo`;o0000
6Oooool00`0007ooooooooooo`0Vooooo`030000Oooooooooooo02Kooooo00<0001oooooooooool0
;?ooool1o`00007ooooo000Kooooo`;o0000;Oooool00`0007ooooooooooo`0Vooooo`030000Oooo
oooooooo00kooooo0_l0000Gooooo`030000Oooooooooooo02Kooooo00<0001oooooooooool09_oo
ool00`0007ooooooooooo`0[ooooo`;o00000Oooool001_ooooo00?o0000ooooooooool0;?ooool0
0`0007ooooooooooo`0Vooooo`030000Oooooooooooo013ooooo0_l0000Eooooo`030000Oooooooo
oooo02Kooooo00<0001oooooooooool09_ooool00`0007ooooooooooo`0/ooooo`7o00000Oooool0
01_ooooo00?o0000ooooooooool0;?ooool00`0007ooooooooooo`0Vooooo`030000Oooooooooooo
01;ooooo0_l0000Cooooo`030000Oooooooooooo02Kooooo00<0001oooooooooool09_ooool00`00
07ooooooooooo`0/ooooo`7o00000Oooool001_ooooo00?o0000ooooooooool0;?ooool00`0007oo
ooooooooo`0Vooooo`030000Oooooooooooo01Cooooo0_l0000Aooooo`030000Oooooooooooo02Ko
oooo00<0001oooooooooool09_ooool00`0007ooooooooooo`0/ooooo`7o00000Oooool000cooooo
1Ol00003ooooo`;o00001Oooool00ol0003oooooooooo`0/ooooo`030000Oooooooooooo02Kooooo
00<0001oooooooooool05_ooool2o`0000oooooo00<0001oooooooooool09_ooool00`0007oooooo
ooooo`0Vooooo`030000Oooooooooooo02cooooo0Ol00001ooooo`003Oooool01?l0003ooooooooo
ool00002ooooo`04o`000?ooooooooooo`0000Cooooo00?o0000ooooooooool0;?ooool00`0007oo
ooooooooo`0Vooooo`030000Oooooooooooo01Sooooo0_l0000=ooooo`030000Oooooooooooo02Ko
oooo00<0001oooooooooool09_ooool00`0007ooooooooooo`0/ooooo`7o00000Oooool000Kooooo
1Ol00003ooooo`03o`000?oooooooooo00;ooooo00Co0000oooooooooooo00001?ooool00ol0003o
ooooooooo`0/ooooo`030000Oooooooooooo02Kooooo00<0001oooooooooool06_ooool2o`0000_o
oooo00<0001oooooooooool09_ooool00`0007ooooooooooo`0Vooooo`030000Oooooooooooo02co
oooo0Ol00001ooooo`003oooool01Ol0003ooooooooooooooooo000000;ooooo00?o0000oooooooo
ool00_ooool2o`0007D0001o0ol000280000O`;o00000Oooool000cooooo00Go0000oooooooooooo
ooooo`000002ooooo`04o`000?ooooooooooo`0000Cooooo00?o0000ooooooooool0;?ooool00`00
07ooooooooooo`0Vooooo`030000Oooooooooooo01oooooo0_l00006ooooo`030000Oooooooooooo
02Kooooo00<0001oooooooooool09_ooool00`0007ooooooooooo`0/ooooo`7o00000Oooool000co
oooo00Go0000ooooooooooooooooo`000002ooooo`04o`000?ooooooooooo`0000Cooooo00?o0000
ooooooooool0;?ooool00`0007ooooooooooo`0Vooooo`030000Oooooooooooo027ooooo0_l00004
ooooo`030000Oooooooooooo02Kooooo00<0001oooooooooool09_ooool00`0007ooooooooooo`0/
ooooo`7o00000Oooool000gooooo0ol00004ooooo`;o00001Oooool00ol0003oooooooooo`0/oooo
o`030000Oooooooooooo02Kooooo00<0001oooooooooool08oooool2o`0000<0o`00:?ooool00`00
07ooooooooooo`0Vooooo`030000Oooooooooooo02cooooo0Ol00001ooooo`006oooool00ol0003o
ooooooooo`0/ooooo`030000Oooooooooooo02Kooooo00<0001oooooooooool09?ooool50?l002Oo
oooo00<0001oooooooooool09_ooool00`0007ooooooooooo`0/ooooo`7o00000Oooool001_ooooo
00?o0000ooooooooool0;?ooool00`0007ooooooooooo`0Vooooo`030000Oooooooooooo02Cooooo
1@3o000Wooooo`030000Oooooooooooo02Kooooo00<0001oooooooooool0;?ooool1o`00007ooooo
000Kooooo`;o0000;Oooool00`0007ooooooooooo`0Vooooo`030000Oooooooooooo02Cooooo1@3o
00000ol0003oooooooooo`0Tooooo`030000Oooooooooooo02Kooooo00<0001oooooooooool0:ooo
ool2o`00007ooooo000Kooooo`03o`000?oooooooooo02cooooo00<0001oooooooooool09_ooool0
0`0007ooooooooooo`0Uooooo`<0o`000_ooool2o`0002Cooooo00<0001oooooooooool09_ooool0
0`0007ooooooooooo`0/ooooo`7o00000Oooool001_ooooo00?o0000ooooooooool0;?ooool00`00
07ooooooooooo`0Vooooo`030000Oooooooooooo02Oooooo00<0001oooooooooool00_ooool00ol0
003oooooooooo`0Qooooo`030000Oooooooooooo02Kooooo00<0001oooooooooool0;?ooool1o`00
007ooooo000Kooooo`03o`000?oooooooooo02cooooo00<0001oooooooooool09_ooool00`0007oo
ooooooooo`0Wooooo`030000Oooooooooooo00?ooooo00?o0000ooooooooool08?ooool00`0007oo
ooooooooo`0Vooooo`030000Oooooooooooo02cooooo0Ol00001ooooo`006oooool00ol0003ooooo
ooooo`0/ooooo`030000Oooooooooooo02Kooooo00<0001oooooooooool09oooool00`0007oooooo
ooooo`04ooooo`;o00008?ooool00`0007ooooooooooo`0Vooooo`030000Oooooooooooo02cooooo
0Ol00001ooooo`006oooool00ol0003oooooooooo`0/ooooo`030000Oooooooooooo02Kooooo00<0
001oooooooooool09oooool00`0007ooooooooooo`06ooooo`03o`000?oooooooooo01gooooo00<0
001oooooooooool09_ooool00`0007ooooooooooo`0/ooooo`7o00000Oooool001_ooooo00?o0000
ooooooooool0;?ooool00`0007ooooooooooo`0Vooooo`030000Oooooooooooo02Oooooo00<0001o
ooooooooool01oooool2o`0001gooooo00<0001oooooooooool09_ooool00`0007ooooooooooo`0/
ooooo`7o00000Oooool001_ooooo0_l0000]ooooo`030000Oooooooooooo02Kooooo00<0001ooooo
ooooool09oooool00`0007ooooooooooo`09ooooo`03o`000?oooooooooo01[ooooo00<0001ooooo
ooooool09_ooool00`0007ooooooooooo`0[ooooo`;o00000Oooool001_ooooo00?o0000oooooooo
ool0;?ooool00`0007ooooooooooo`0Vooooo`030000Oooooooooooo02Oooooo00<0001ooooooooo
ool02_ooool00ol0003oooooooooo`0Iooooo`030000Oooooooooooo02Kooooo00<0001ooooooooo
ool0;?ooool1o`00007ooooo000Kooooo`03o`000?oooooooooo02cooooo00<0001oooooooooool0
9_ooool00`0007ooooooooooo`0Wooooo`030000Oooooooooooo00_ooooo0_l0000Iooooo`030000
Oooooooooooo02Kooooo00<0001oooooooooool0;?ooool1o`00007ooooo000Kooooo`03o`000?oo
oooooooo02cooooo00<0001oooooooooool09_ooool00`0007ooooooooooo`0Wooooo`030000Oooo
oooooooo00gooooo00?o0000ooooooooool05_ooool00`0007ooooooooooo`0Vooooo`030000Oooo
oooooooo02cooooo0Ol00001ooooo`006oooool00ol0003oooooooooo`0/ooooo`030000Oooooooo
oooo02Kooooo00<0001oooooooooool09oooool00`0007ooooooooooo`0>ooooo`;o00005_ooool0
0`0007ooooooooooo`0Vooooo`030000Oooooooooooo02cooooo0Ol00001ooooo`006oooool00ol0
003oooooooooo`0/ooooo`030000Oooooooooooo02Kooooo00<0001oooooooooool09oooool00`00
07ooooooooooo`0@ooooo`03o`000?oooooooooo01?ooooo00<0001oooooooooool09_ooool00`00
07ooooooooooo`0/ooooo`7o00000Oooool001_ooooo00?o0000ooooooooool0;?ooool00`0007oo
ooooooooo`0Vooooo`030000Oooooooooooo02Oooooo00<0001oooooooooool04Oooool2o`0001?o
oooo00<0001oooooooooool09_ooool00`0007ooooooooooo`0/ooooo`7o00000Oooool001_ooooo
0_l0000]ooooo`030000Oooooooooooo02Kooooo00<0001oooooooooool09oooool00`0007oooooo
ooooo`0Cooooo`03o`000?oooooooooo013ooooo00<0001oooooooooool09_ooool00`0007oooooo
ooooo`0[ooooo`;o00000Oooool001_ooooo00?o0000ooooooooool0;?ooool00`0007oooooooooo
o`0Vooooo`030000Oooooooooooo02Oooooo00<0001oooooooooool05?ooool00ol0003ooooooooo
o`0?ooooo`030000Oooooooooooo02Kooooo00<0001oooooooooool0;?ooool1o`00007ooooo000K
ooooo`03o`000?oooooooooo02cooooo00<0001oooooooooool09_ooool00`0007ooooooooooo`0W
ooooo`030000Oooooooooooo01Gooooo0_l0000?ooooo`030000Oooooooooooo02Kooooo00<0001o
ooooooooool0;?ooool1o`00007ooooo000Kooooo`03o`000?oooooooooo02cooooo00<0001ooooo
ooooool09_ooool00`0007ooooooooooo`0Wooooo`030000Oooooooooooo01Oooooo00?o0000oooo
ooooool03?ooool00`0007ooooooooooo`0Vooooo`030000Oooooooooooo02cooooo0Ol00001oooo
o`006oooool00ol0003oooooooooo`0/ooooo`030000Oooooooooooo02Kooooo00<0001ooooooooo
ool09oooool00`0007ooooooooooo`0Hooooo`;o00003?ooool00`0007ooooooooooo`0Vooooo`03
0000Oooooooooooo02cooooo0Ol00001ooooo`005?ooool2o`0000Gooooo00?o0000ooooooooool0
;?ooool00`0007ooooooooooo`0Vooooo`030000Oooooooooooo02Oooooo00<0001oooooooooool0
6_ooool00ol0003oooooooooo`09ooooo`030000Oooooooooooo02Kooooo00<0001oooooooooool0
;?ooool1o`00007ooooo000Cooooo`04o`000?ooooooooooo`0000Cooooo00?o0000ooooooooool0
;?ooool00`0007ooooooooooo`0Vooooo`030000Oooooooooooo02Oooooo00<0001oooooooooool0
6oooool00ol0003oooooooooo`08ooooo`030000Oooooooooooo02Kooooo00<0001oooooooooool0
;?ooool1o`00007ooooo000Cooooo`04o`000?ooooooooooo`0000Cooooo0_l0002O0000O`;o0000
G`0007l2o`00007ooooo000Cooooo`04o`000?ooooooooooo`0000Cooooo00?o0000ooooooooool0
;?ooool00`0007ooooooooooo`0Vooooo`030000Oooooooooooo02Oooooo00<0001oooooooooool0
7_ooool00ol0003oooooooooo`05ooooo`030000Oooooooooooo02Kooooo00<0001oooooooooool0
;?ooool1o`00007ooooo000Cooooo`04o`000?ooooooooooo`0000Cooooo00?o0000ooooooooool0
;?ooool00`0007ooooooooooo`0Vooooo`030000Oooooooooooo02Oooooo00<0001oooooooooool0
7oooool2o`0000Gooooo00<0001oooooooooool09_ooool00`0007ooooooooooo`0/ooooo`7o0000
0Oooool001?ooooo00Co0000oooooooooooo00001?ooool00ol0003oooooooooo`0/ooooo`030000
Oooooooooooo02Kooooo00<0001oooooooooool09oooool00`0007ooooooooooo`0Qooooo`03o`00
0?oooooooooo00;ooooo00<0001oooooooooool09_ooool00`0007ooooooooooo`0/ooooo`7o0000
0Oooool001Cooooo0_l00005ooooo`03o`000?oooooooooo02cooooo00<0001oooooooooool09_oo
ool00`0007ooooooooooo`0Wooooo`030000Oooooooooooo02;ooooo00Go0000oooooooooooooooo
0000O`0Xooooo`030000Oooooooooooo02cooooo0Ol00001ooooo`006oooool00ol0003ooooooooo
o`0/ooooo`030000Oooooooooooo02Kooooo00<0001oooooooooool09oooool00`0007oooooooooo
o`0Sooooo`;o00000`3o000Wooooo`030000Oooooooooooo02cooooo0Ol00001ooooo`006oooool0
0ol0003oooooooooo`0/ooooo`030000Oooooooooooo02Kooooo00<0001oooooooooool09oooool0
0`0007ooooooooooo`0Tooooo`D0o`009_ooool00`0007ooooooooooo`0/ooooo`7o00000Oooool0
01_ooooo0_l0000]ooooo`030000Oooooooooooo02Kooooo00<0001oooooooooool09oooool00`00
07ooooooooooo`0Tooooo`D0o`000ol0000Sooooo`030000Oooooooooooo02_ooooo0_l00001oooo
o`006oooool00ol0003oooooooooo`0/ooooo`030000Oooooooooooo02Kooooo00<0001ooooooooo
ool09oooool00`0007ooooooooooo`0Tooooo`D0o`000oooool:o`0001Wooooo00<0001ooooooooo
ool0;?ooool1o`00007ooooo000Kooooo`03o`000?oooooooooo02cooooo00<0001oooooooooool0
9_ooool00`0007ooooooooooo`0Wooooo`030000Oooooooooooo02Gooooo0`3o000>ooooo`_o0000
3Oooool30?l002Kooooo0`3o0004ooooo`7o00000Oooool001_ooooo00?o0000ooooooooool0;?oo
ool00`0007ooooooooooo`0Vooooo`030000Oooooooooooo02Oooooo00<0001oooooooooool09_oo
ool00`0007ooooooooooo`0Hooooo`[o00000_ooool50?l002Cooooo1@3o0003ooooo`7o00000Ooo
ool001_ooooo00?o0000ooooooooool0;?ooool00`0007ooooooooooo`0Vooooo`030000Oooooooo
oooo02Oooooo00<0001oooooooooool09_ooool00`0007ooooooooooo`0Rooooo`;o00001@3o000T
o`0000D0o`000oooool1o`00007ooooo000Kooooo`03o`000?oooooooooo02cooooo00<0001ooooo
ooooool09_ooool00`0007ooooooooooo`0Wooooo`030000Oooooooooooo02Kooooo00<0001ooooo
ooooool09?ooool50?l002Cooooo1@3o0003ooooo`7o00000Oooool001_ooooo00?o0000oooooooo
ool00oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000oooooooo
ool01_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000oooooooo
ool01Oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Gooooo00?o0000oooooooo
ool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Kooooo00?o0000oooooooo
ool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000oooooooo
ool01_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000oooooooo
ool01Oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Gooooo00?o0000oooooooo
ool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000oooooooo
ool01_ooool00ol0003oooooooooo`04ooooo`<0o`001_ooool00ol0003oooooooooo`05ooooo`03
o`000?oooooooooo00Kooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`04ooooo`<0
o`001?ooool1o`00007ooooo000Koooooooo00001Ol00001ooooo`00oooooolQooooo`00oooooolQ
ooooo`00\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.811156, -115.413, \
0.0242656, 0.71772}}]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Save EM data", "Subsection"],

Cell[BoxData[
    \(\(em2 = \ em;\)\)], "Input"]
}, Closed]],

Cell[CellGroupData[{

Cell["Animation", "Subsection"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(\(EMAllPlot[#, \ gdata, pr] &\)\  /@ \ em2;\)\)], "Input"],

Cell[CellGroupData[{

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
%%ImageSize: 400 400 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.47619 0.0238095 0.47619 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.0238095 0.477324 0.477324 MathSubStart
%% ContourGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.480769 0.5 0.480769 [
[ 0 0 -0.125 0 ]
[ 0 0 -0.125 0 ]
[ 0 1 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
0 0 m
1 0 L
s
0 0 m
0 1 L
s
0 1 m
1 1 L
s
1 0 m
1 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
.01923 .98077 m
.98077 .98077 L
.98077 .01923 L
.01923 .01923 L
F
.5 Mabswid
.1 g
.01923 .71418 m
.03846 .7279 L
.04268 .73077 L
.05769 .7406 L
.07295 .75 L
.07692 .75235 L
.09615 .76318 L
.10761 .76923 L
.11538 .77315 L
.13462 .78228 L
.14871 .78846 L
.15385 .7906 L
.17308 .79812 L
.19231 .80488 L
.20098 .80769 L
.21154 .81089 L
.23077 .81615 L
.25 .82069 L
.26923 .82451 L
.28374 .82692 L
.28846 .82761 L
.30769 .82999 L
.32692 .83166 L
.34615 .83262 L
.36538 .83286 L
.38462 .83239 L
.40385 .83118 L
.42308 .82923 L
.43989 .82692 L
.44231 .82653 L
.46154 .82304 L
.48077 .81875 L
.5 .81364 L
.51922 .80769 L
.51923 .80769 L
.53846 .80082 L
.55769 .79302 L
.56795 .78846 L
.57692 .78422 L
.59615 .77436 L
.60539 .76923 L
.61538 .76336 L
.63462 .75112 L
.63627 .75 L
.65385 .7375 L
.66266 .73077 L
.67308 .72237 L
.68568 .71154 L
.69231 .70552 L
.70602 .69231 L
.71154 .68667 L
.72414 .67308 L
.73077 .66547 L
.74037 .65385 L
.75 .64139 L
.75496 .63462 L
.76808 .61538 L
.76923 .6136 L
.77988 .59615 L
.78846 .58075 L
.79048 .57692 L
.79995 .55769 L
.80769 .54016 L
.80839 .53846 L
.81584 .51923 L
.82238 .5 L
.82692 .48481 L
.82803 .48077 L
.83283 .46154 L
.83681 .44231 L
.84 .42308 L
.84242 .40385 L
.84409 .38462 L
.84501 .36538 L
.84519 .34615 L
.84465 .32692 L
.84339 .30769 L
.84141 .28846 L
.83871 .26923 L
.83529 .25 L
.83115 .23077 L
.82692 .21391 L
.82628 .21154 L
.82065 .19231 L
.81427 .17308 L
.80769 .15529 L
.80713 .15385 L
.79918 .13462 L
.79043 .11538 L
.78846 .11128 L
.78084 .09615 L
.77039 .07692 L
.76923 .07489 L
.75902 .05769 L
.75 .04345 L
.74671 .03846 L
.7334 .01923 L
.01923 .01923 L
F
0 g
.01923 .71418 m
.03846 .7279 L
.04268 .73077 L
.05769 .7406 L
.07295 .75 L
.07692 .75235 L
.09615 .76318 L
.10761 .76923 L
.11538 .77315 L
.13462 .78228 L
.14871 .78846 L
.15385 .7906 L
.17308 .79812 L
.19231 .80488 L
.20098 .80769 L
.21154 .81089 L
.23077 .81615 L
.25 .82069 L
.26923 .82451 L
.28374 .82692 L
.28846 .82761 L
.30769 .82999 L
.32692 .83166 L
.34615 .83262 L
.36538 .83286 L
.38462 .83239 L
.40385 .83118 L
.42308 .82923 L
.43989 .82692 L
.44231 .82653 L
.46154 .82304 L
.48077 .81875 L
.5 .81364 L
.51922 .80769 L
.51923 .80769 L
.53846 .80082 L
.55769 .79302 L
.56795 .78846 L
.57692 .78422 L
.59615 .77436 L
.60539 .76923 L
.61538 .76336 L
.63462 .75112 L
.63627 .75 L
.65385 .7375 L
.66266 .73077 L
.67308 .72237 L
.68568 .71154 L
.69231 .70552 L
.70602 .69231 L
Mistroke
.71154 .68667 L
.72414 .67308 L
.73077 .66547 L
.74037 .65385 L
.75 .64139 L
.75496 .63462 L
.76808 .61538 L
.76923 .6136 L
.77988 .59615 L
.78846 .58075 L
.79048 .57692 L
.79995 .55769 L
.80769 .54016 L
.80839 .53846 L
.81584 .51923 L
.82238 .5 L
.82692 .48481 L
.82803 .48077 L
.83283 .46154 L
.83681 .44231 L
.84 .42308 L
.84242 .40385 L
.84409 .38462 L
.84501 .36538 L
.84519 .34615 L
.84465 .32692 L
.84339 .30769 L
.84141 .28846 L
.83871 .26923 L
.83529 .25 L
.83115 .23077 L
.82692 .21391 L
.82628 .21154 L
.82065 .19231 L
.81427 .17308 L
.80769 .15529 L
.80713 .15385 L
.79918 .13462 L
.79043 .11538 L
.78846 .11128 L
.78084 .09615 L
.77039 .07692 L
.76923 .07489 L
.75902 .05769 L
.75 .04345 L
.74671 .03846 L
.7334 .01923 L
Mfstroke
.2 g
.01923 .5976 m
.03846 .61493 L
.03899 .61538 L
.05769 .63073 L
.06271 .63462 L
.07692 .64513 L
.08947 .65385 L
.09615 .65828 L
.11538 .67025 L
.12021 .67308 L
.13462 .68111 L
.15385 .69094 L
.1567 .69231 L
.17308 .69976 L
.19231 .70763 L
.2028 .71154 L
.21154 .71458 L
.23077 .72061 L
.25 .72578 L
.26923 .73007 L
.27272 .73077 L
.28846 .7335 L
.30769 .73607 L
.32692 .7378 L
.34615 .73867 L
.36538 .73867 L
.38462 .73781 L
.40385 .73605 L
.42308 .73338 L
.43751 .73077 L
.44231 .72976 L
.46154 .72516 L
.48077 .71955 L
.5 .71285 L
.50345 .71154 L
.51923 .70501 L
.53846 .69594 L
.54547 .69231 L
.55769 .68552 L
.57692 .67364 L
.57777 .67308 L
.59615 .66009 L
.60425 .65385 L
.61538 .64466 L
.62666 .63462 L
.63462 .62702 L
.64597 .61538 L
.65385 .6067 L
.66278 .59615 L
.67308 .58299 L
.67751 .57692 L
.69044 .55769 L
.69231 .5547 L
.70178 .53846 L
.71154 .51958 L
.7117 .51923 L
.72031 .5 L
.72773 .48077 L
.73077 .47191 L
.73402 .46154 L
.73924 .44231 L
.74346 .42308 L
.7467 .40385 L
.74902 .38462 L
.75 .37518 L
.75042 .36538 L
.75092 .34615 L
.75055 .32692 L
.75 .31665 L
.74932 .30769 L
.74721 .28846 L
.74425 .26923 L
.74042 .25 L
.73572 .23077 L
.73077 .21357 L
.73013 .21154 L
.72364 .19231 L
.71622 .17308 L
.71154 .16203 L
.70785 .15385 L
.69849 .13462 L
.69231 .12294 L
.68809 .11538 L
.67661 .09615 L
.67308 .09059 L
.66397 .07692 L
.65385 .06272 L
.65009 .05769 L
.63487 .03846 L
.63462 .03815 L
.61817 .01923 L
.01923 .01923 L
F
0 g
.01923 .5976 m
.03846 .61493 L
.03899 .61538 L
.05769 .63073 L
.06271 .63462 L
.07692 .64513 L
.08947 .65385 L
.09615 .65828 L
.11538 .67025 L
.12021 .67308 L
.13462 .68111 L
.15385 .69094 L
.1567 .69231 L
.17308 .69976 L
.19231 .70763 L
.2028 .71154 L
.21154 .71458 L
.23077 .72061 L
.25 .72578 L
.26923 .73007 L
.27272 .73077 L
.28846 .7335 L
.30769 .73607 L
.32692 .7378 L
.34615 .73867 L
.36538 .73867 L
.38462 .73781 L
.40385 .73605 L
.42308 .73338 L
.43751 .73077 L
.44231 .72976 L
.46154 .72516 L
.48077 .71955 L
.5 .71285 L
.50345 .71154 L
.51923 .70501 L
.53846 .69594 L
.54547 .69231 L
.55769 .68552 L
.57692 .67364 L
.57777 .67308 L
.59615 .66009 L
.60425 .65385 L
.61538 .64466 L
.62666 .63462 L
.63462 .62702 L
.64597 .61538 L
.65385 .6067 L
.66278 .59615 L
.67308 .58299 L
Mistroke
.67751 .57692 L
.69044 .55769 L
.69231 .5547 L
.70178 .53846 L
.71154 .51958 L
.7117 .51923 L
.72031 .5 L
.72773 .48077 L
.73077 .47191 L
.73402 .46154 L
.73924 .44231 L
.74346 .42308 L
.7467 .40385 L
.74902 .38462 L
.75 .37518 L
.75042 .36538 L
.75092 .34615 L
.75055 .32692 L
.75 .31665 L
.74932 .30769 L
.74721 .28846 L
.74425 .26923 L
.74042 .25 L
.73572 .23077 L
.73077 .21357 L
.73013 .21154 L
.72364 .19231 L
.71622 .17308 L
.71154 .16203 L
.70785 .15385 L
.69849 .13462 L
.69231 .12294 L
.68809 .11538 L
.67661 .09615 L
.67308 .09059 L
.66397 .07692 L
.65385 .06272 L
.65009 .05769 L
.63487 .03846 L
.63462 .03815 L
.61817 .01923 L
Mfstroke
.3 g
.01923 .51535 m
.02251 .51923 L
.03846 .53698 L
.03986 .53846 L
.05769 .55622 L
.05926 .55769 L
.07692 .57344 L
.08108 .57692 L
.09615 .58891 L
.10591 .59615 L
.11538 .60283 L
.13462 .61534 L
.1347 .61538 L
.15385 .62654 L
.1692 .63462 L
.17308 .63654 L
.19231 .64538 L
.21154 .65313 L
.21344 .65385 L
.23077 .65983 L
.25 .6655 L
.26923 .67017 L
.28382 .67308 L
.28846 .67386 L
.30769 .67656 L
.32692 .67829 L
.34615 .67904 L
.36538 .67879 L
.38462 .67753 L
.40385 .67523 L
.41699 .67308 L
.42308 .67186 L
.44231 .66735 L
.46154 .66167 L
.48077 .65473 L
.48298 .65385 L
.5 .64642 L
.51923 .63663 L
.52284 .63462 L
.53846 .62517 L
.55286 .61538 L
.55769 .61184 L
.57692 .59631 L
.5771 .59615 L
.59615 .57813 L
.59732 .57692 L
.61448 .55769 L
.61538 .55659 L
.62918 .53846 L
.63462 .53053 L
.64179 .51923 L
.65262 .5 L
.65385 .49762 L
.66184 .48077 L
.66963 .46154 L
.67308 .45177 L
.67608 .44231 L
.6813 .42308 L
.68536 .40385 L
.6883 .38462 L
.69017 .36538 L
.69101 .34615 L
.69083 .32692 L
.68966 .30769 L
.68749 .28846 L
.68434 .26923 L
.68019 .25 L
.67504 .23077 L
.67308 .22428 L
.66886 .21154 L
.66163 .19231 L
.65385 .17423 L
.65331 .17308 L
.64386 .15385 L
.63462 .13703 L
.63321 .13462 L
.62128 .11538 L
.61538 .10659 L
.60799 .09615 L
.59615 .08061 L
.5932 .07692 L
.57692 .0579 L
.57674 .05769 L
.55837 .03846 L
.55769 .03779 L
.53846 .01982 L
.53779 .01923 L
.01923 .01923 L
F
0 g
.01923 .51535 m
.02251 .51923 L
.03846 .53698 L
.03986 .53846 L
.05769 .55622 L
.05926 .55769 L
.07692 .57344 L
.08108 .57692 L
.09615 .58891 L
.10591 .59615 L
.11538 .60283 L
.13462 .61534 L
.1347 .61538 L
.15385 .62654 L
.1692 .63462 L
.17308 .63654 L
.19231 .64538 L
.21154 .65313 L
.21344 .65385 L
.23077 .65983 L
.25 .6655 L
.26923 .67017 L
.28382 .67308 L
.28846 .67386 L
.30769 .67656 L
.32692 .67829 L
.34615 .67904 L
.36538 .67879 L
.38462 .67753 L
.40385 .67523 L
.41699 .67308 L
.42308 .67186 L
.44231 .66735 L
.46154 .66167 L
.48077 .65473 L
.48298 .65385 L
.5 .64642 L
.51923 .63663 L
.52284 .63462 L
.53846 .62517 L
.55286 .61538 L
.55769 .61184 L
.57692 .59631 L
.5771 .59615 L
.59615 .57813 L
.59732 .57692 L
.61448 .55769 L
.61538 .55659 L
.62918 .53846 L
.63462 .53053 L
Mistroke
.64179 .51923 L
.65262 .5 L
.65385 .49762 L
.66184 .48077 L
.66963 .46154 L
.67308 .45177 L
.67608 .44231 L
.6813 .42308 L
.68536 .40385 L
.6883 .38462 L
.69017 .36538 L
.69101 .34615 L
.69083 .32692 L
.68966 .30769 L
.68749 .28846 L
.68434 .26923 L
.68019 .25 L
.67504 .23077 L
.67308 .22428 L
.66886 .21154 L
.66163 .19231 L
.65385 .17423 L
.65331 .17308 L
.64386 .15385 L
.63462 .13703 L
.63321 .13462 L
.62128 .11538 L
.61538 .10659 L
.60799 .09615 L
.59615 .08061 L
.5932 .07692 L
.57692 .0579 L
.57674 .05769 L
.55837 .03846 L
.55769 .03779 L
.53846 .01982 L
.53779 .01923 L
Mfstroke
.4 g
.01923 .43899 m
.02128 .44231 L
.03409 .46154 L
.03846 .4676 L
.04856 .48077 L
.05769 .4918 L
.06491 .5 L
.07692 .51276 L
.08342 .51923 L
.09615 .53114 L
.10453 .53846 L
.11538 .54738 L
.12892 .55769 L
.13462 .56177 L
.15385 .57452 L
.15776 .57692 L
.17308 .58577 L
.19231 .59565 L
.19336 .59615 L
.21154 .60424 L
.23077 .6116 L
.24206 .61538 L
.25 .61779 L
.26923 .62283 L
.28846 .62675 L
.30769 .62956 L
.32692 .63127 L
.34615 .63186 L
.36538 .63132 L
.38462 .62962 L
.40385 .62671 L
.42308 .62255 L
.44231 .61706 L
.44737 .61538 L
.46154 .61012 L
.48077 .60163 L
.49149 .59615 L
.5 .59138 L
.51923 .57916 L
.52241 .57692 L
.53846 .56459 L
.54651 .55769 L
.55769 .54718 L
.56612 .53846 L
.57692 .5261 L
.58241 .51923 L
.59606 .5 L
.59615 .49985 L
.60751 .48077 L
.61538 .46521 L
.61707 .46154 L
.62496 .44231 L
.63132 .42308 L
.63462 .411 L
.63628 .40385 L
.63993 .38462 L
.64234 .36538 L
.64355 .34615 L
.6436 .32692 L
.64252 .30769 L
.64031 .28846 L
.63699 .26923 L
.63462 .25826 L
.63254 .25 L
.62694 .23077 L
.62017 .21154 L
.61538 .19965 L
.61218 .19231 L
.60292 .17308 L
.59615 .16051 L
.59231 .15385 L
.58026 .13462 L
.57692 .12969 L
.56662 .11538 L
.55769 .10396 L
.55122 .09615 L
.53846 .08184 L
.5338 .07692 L
.51923 .06252 L
.51402 .05769 L
.5 .04549 L
.49133 .03846 L
.48077 .03041 L
.46485 .01923 L
.01923 .01923 L
F
0 g
.01923 .43899 m
.02128 .44231 L
.03409 .46154 L
.03846 .4676 L
.04856 .48077 L
.05769 .4918 L
.06491 .5 L
.07692 .51276 L
.08342 .51923 L
.09615 .53114 L
.10453 .53846 L
.11538 .54738 L
.12892 .55769 L
.13462 .56177 L
.15385 .57452 L
.15776 .57692 L
.17308 .58577 L
.19231 .59565 L
.19336 .59615 L
.21154 .60424 L
.23077 .6116 L
.24206 .61538 L
.25 .61779 L
.26923 .62283 L
.28846 .62675 L
.30769 .62956 L
.32692 .63127 L
.34615 .63186 L
.36538 .63132 L
.38462 .62962 L
.40385 .62671 L
.42308 .62255 L
.44231 .61706 L
.44737 .61538 L
.46154 .61012 L
.48077 .60163 L
.49149 .59615 L
.5 .59138 L
.51923 .57916 L
.52241 .57692 L
.53846 .56459 L
.54651 .55769 L
.55769 .54718 L
.56612 .53846 L
.57692 .5261 L
.58241 .51923 L
.59606 .5 L
.59615 .49985 L
.60751 .48077 L
.61538 .46521 L
Mistroke
.61707 .46154 L
.62496 .44231 L
.63132 .42308 L
.63462 .411 L
.63628 .40385 L
.63993 .38462 L
.64234 .36538 L
.64355 .34615 L
.6436 .32692 L
.64252 .30769 L
.64031 .28846 L
.63699 .26923 L
.63462 .25826 L
.63254 .25 L
.62694 .23077 L
.62017 .21154 L
.61538 .19965 L
.61218 .19231 L
.60292 .17308 L
.59615 .16051 L
.59231 .15385 L
.58026 .13462 L
.57692 .12969 L
.56662 .11538 L
.55769 .10396 L
.55122 .09615 L
.53846 .08184 L
.5338 .07692 L
.51923 .06252 L
.51402 .05769 L
.5 .04549 L
.49133 .03846 L
.48077 .03041 L
.46485 .01923 L
Mfstroke
.5 g
.01923 .34456 m
.01974 .34615 L
.02647 .36538 L
.03458 .38462 L
.03846 .39281 L
.04414 .40385 L
.05527 .42308 L
.05769 .42693 L
.0681 .44231 L
.07692 .45414 L
.08284 .46154 L
.09615 .47688 L
.09978 .48077 L
.11538 .49633 L
.11935 .5 L
.13462 .51318 L
.14223 .51923 L
.15385 .52785 L
.16962 .53846 L
.17308 .54063 L
.19231 .55172 L
.20396 .55769 L
.21154 .56127 L
.23077 .56938 L
.25 .57614 L
.25248 .57692 L
.26923 .58158 L
.28846 .58575 L
.30769 .58866 L
.32692 .59032 L
.34615 .59071 L
.36538 .58981 L
.38462 .58758 L
.40385 .58395 L
.42308 .57884 L
.4291 .57692 L
.44231 .57211 L
.46154 .5636 L
.47283 .55769 L
.48077 .55307 L
.5 .54019 L
.50232 .53846 L
.51923 .52444 L
.52481 .51923 L
.53846 .50498 L
.54275 .5 L
.55734 .48077 L
.55769 .48026 L
.56928 .46154 L
.57692 .4468 L
.579 .44231 L
.5868 .42308 L
.59287 .40385 L
.59615 .39069 L
.59738 .38462 L
.60043 .36538 L
.60209 .34615 L
.60243 .32692 L
.60147 .30769 L
.59925 .28846 L
.59615 .27099 L
.59575 .26923 L
.59098 .25 L
.5849 .23077 L
.57747 .21154 L
.57692 .21025 L
.56862 .19231 L
.55827 .17308 L
.55769 .17208 L
.54629 .15385 L
.53846 .1426 L
.53251 .13462 L
.51923 .11831 L
.51668 .11538 L
.5 .09768 L
.49845 .09615 L
.48077 .07988 L
.47729 .07692 L
.46154 .06441 L
.45229 .05769 L
.44231 .05092 L
.42308 .0392 L
.42178 .03846 L
.40385 .02906 L
.38462 .0204 L
.38177 .01923 L
.01923 .01923 L
F
0 g
.01923 .34456 m
.01974 .34615 L
.02647 .36538 L
.03458 .38462 L
.03846 .39281 L
.04414 .40385 L
.05527 .42308 L
.05769 .42693 L
.0681 .44231 L
.07692 .45414 L
.08284 .46154 L
.09615 .47688 L
.09978 .48077 L
.11538 .49633 L
.11935 .5 L
.13462 .51318 L
.14223 .51923 L
.15385 .52785 L
.16962 .53846 L
.17308 .54063 L
.19231 .55172 L
.20396 .55769 L
.21154 .56127 L
.23077 .56938 L
.25 .57614 L
.25248 .57692 L
.26923 .58158 L
.28846 .58575 L
.30769 .58866 L
.32692 .59032 L
.34615 .59071 L
.36538 .58981 L
.38462 .58758 L
.40385 .58395 L
.42308 .57884 L
.4291 .57692 L
.44231 .57211 L
.46154 .5636 L
.47283 .55769 L
.48077 .55307 L
.5 .54019 L
.50232 .53846 L
.51923 .52444 L
.52481 .51923 L
.53846 .50498 L
.54275 .5 L
.55734 .48077 L
.55769 .48026 L
.56928 .46154 L
.57692 .4468 L
Mistroke
.579 .44231 L
.5868 .42308 L
.59287 .40385 L
.59615 .39069 L
.59738 .38462 L
.60043 .36538 L
.60209 .34615 L
.60243 .32692 L
.60147 .30769 L
.59925 .28846 L
.59615 .27099 L
.59575 .26923 L
.59098 .25 L
.5849 .23077 L
.57747 .21154 L
.57692 .21025 L
.56862 .19231 L
.55827 .17308 L
.55769 .17208 L
.54629 .15385 L
.53846 .1426 L
.53251 .13462 L
.51923 .11831 L
.51668 .11538 L
.5 .09768 L
.49845 .09615 L
.48077 .07988 L
.47729 .07692 L
.46154 .06441 L
.45229 .05769 L
.44231 .05092 L
.42308 .0392 L
.42178 .03846 L
.40385 .02906 L
.38462 .0204 L
.38177 .01923 L
Mfstroke
.4 g
.01923 .16916 m
.0249 .15385 L
.03366 .13462 L
.03846 .12557 L
.04447 .11538 L
.05769 .09618 L
.05771 .09615 L
.07392 .07692 L
.07692 .07376 L
.09399 .05769 L
.09615 .05586 L
.11538 .0413 L
.11963 .03846 L
.13462 .02939 L
.15385 .01968 L
.15483 .01923 L
.01923 .01923 L
F
0 g
.01923 .16916 m
.0249 .15385 L
.03366 .13462 L
.03846 .12557 L
.04447 .11538 L
.05769 .09618 L
.05771 .09615 L
.07392 .07692 L
.07692 .07376 L
.09399 .05769 L
.09615 .05586 L
.11538 .0413 L
.11963 .03846 L
.13462 .02939 L
.15385 .01968 L
.15483 .01923 L
s
.3 g
.01923 .07601 m
.03352 .05769 L
.03846 .05201 L
.05141 .03846 L
.05769 .03248 L
.07313 .01923 L
.01923 .01923 L
F
0 g
.01923 .07601 m
.03352 .05769 L
.03846 .05201 L
.05141 .03846 L
.05769 .03248 L
.07313 .01923 L
s
.6 g
.23077 .03723 m
.25 .03493 L
.26923 .03416 L
.28846 .03486 L
.30769 .037 L
.31708 .03846 L
.32692 .04056 L
.34615 .04557 L
.36538 .05207 L
.37926 .05769 L
.38462 .06011 L
.40385 .06979 L
.41617 .07692 L
.42308 .08127 L
.44231 .09474 L
.44416 .09615 L
.46154 .11052 L
.4669 .11538 L
.48077 .12907 L
.48593 .13462 L
.5 .15117 L
.5021 .15385 L
.51588 .17308 L
.51923 .17824 L
.52762 .19231 L
.53753 .21154 L
.53846 .21352 L
.54576 .23077 L
.55241 .25 L
.55756 .26923 L
.55769 .26976 L
.56124 .28846 L
.56347 .30769 L
.56425 .32692 L
.56354 .34615 L
.5613 .36538 L
.55769 .38363 L
.55743 .38462 L
.5518 .40385 L
.54424 .42308 L
.53846 .43503 L
.53447 .44231 L
.52209 .46154 L
.51923 .46541 L
.50647 .48077 L
.5 .48755 L
.48649 .5 L
.48077 .50467 L
.46154 .5182 L
.45988 .51923 L
.44231 .52892 L
.42308 .53731 L
.42006 .53846 L
.40385 .54369 L
.38462 .54826 L
.36538 .55117 L
.34615 .55252 L
.32692 .55239 L
.30769 .55081 L
.28846 .54779 L
.26923 .54335 L
.25297 .53846 L
.25 .53744 L
.23077 .53001 L
.21154 .52097 L
.20819 .51923 L
.19231 .51021 L
.17657 .5 L
.17308 .49754 L
.15385 .4827 L
.15155 .48077 L
.13462 .4653 L
.13085 .46154 L
.11538 .4447 L
.11336 .44231 L
.09847 .42308 L
.09615 .4198 L
.08577 .40385 L
.07692 .38832 L
.07499 .38462 L
.06596 .36538 L
.05856 .34615 L
.05769 .34366 L
.05268 .32692 L
.04829 .30769 L
.04536 .28846 L
.04387 .26923 L
.04385 .25 L
.04534 .23077 L
.0484 .21154 L
.05316 .19231 L
.05769 .17843 L
.05975 .17308 L
.06841 .15385 L
.07692 .13863 L
.07946 .13462 L
.0934 .11538 L
.09615 .11206 L
.11107 .09615 L
.11538 .09212 L
.13405 .07692 L
.13462 .07651 L
.15385 .06414 L
.16597 .05769 L
.17308 .05437 L
.19231 .04679 L
.21154 .04114 L
.22332 .03846 L
F
0 g
.23077 .03723 m
.25 .03493 L
.26923 .03416 L
.28846 .03486 L
.30769 .037 L
.31708 .03846 L
.32692 .04056 L
.34615 .04557 L
.36538 .05207 L
.37926 .05769 L
.38462 .06011 L
.40385 .06979 L
.41617 .07692 L
.42308 .08127 L
.44231 .09474 L
.44416 .09615 L
.46154 .11052 L
.4669 .11538 L
.48077 .12907 L
.48593 .13462 L
.5 .15117 L
.5021 .15385 L
.51588 .17308 L
.51923 .17824 L
.52762 .19231 L
.53753 .21154 L
.53846 .21352 L
.54576 .23077 L
.55241 .25 L
.55756 .26923 L
.55769 .26976 L
.56124 .28846 L
.56347 .30769 L
.56425 .32692 L
.56354 .34615 L
.5613 .36538 L
.55769 .38363 L
.55743 .38462 L
.5518 .40385 L
.54424 .42308 L
.53846 .43503 L
.53447 .44231 L
.52209 .46154 L
.51923 .46541 L
.50647 .48077 L
.5 .48755 L
.48649 .5 L
.48077 .50467 L
.46154 .5182 L
.45988 .51923 L
Mistroke
.44231 .52892 L
.42308 .53731 L
.42006 .53846 L
.40385 .54369 L
.38462 .54826 L
.36538 .55117 L
.34615 .55252 L
.32692 .55239 L
.30769 .55081 L
.28846 .54779 L
.26923 .54335 L
.25297 .53846 L
.25 .53744 L
.23077 .53001 L
.21154 .52097 L
.20819 .51923 L
.19231 .51021 L
.17657 .5 L
.17308 .49754 L
.15385 .4827 L
.15155 .48077 L
.13462 .4653 L
.13085 .46154 L
.11538 .4447 L
.11336 .44231 L
.09847 .42308 L
.09615 .4198 L
.08577 .40385 L
.07692 .38832 L
.07499 .38462 L
.06596 .36538 L
.05856 .34615 L
.05769 .34366 L
.05268 .32692 L
.04829 .30769 L
.04536 .28846 L
.04387 .26923 L
.04385 .25 L
.04534 .23077 L
.0484 .21154 L
.05316 .19231 L
.05769 .17843 L
.05975 .17308 L
.06841 .15385 L
.07692 .13863 L
.07946 .13462 L
.0934 .11538 L
.09615 .11206 L
.11107 .09615 L
.11538 .09212 L
Mistroke
.13405 .07692 L
.13462 .07651 L
.15385 .06414 L
.16597 .05769 L
.17308 .05437 L
.19231 .04679 L
.21154 .04114 L
.22332 .03846 L
.23077 .03723 L
Mfstroke
.7 g
.23077 .07568 m
.25 .07257 L
.26923 .07127 L
.28846 .07171 L
.30769 .07381 L
.32449 .07692 L
.32692 .07758 L
.34615 .08303 L
.36538 .09023 L
.37844 .09615 L
.38462 .09929 L
.40385 .11038 L
.41147 .11538 L
.42308 .12376 L
.43643 .13462 L
.44231 .13986 L
.45648 .15385 L
.46154 .15936 L
.473 .17308 L
.48077 .18352 L
.48672 .19231 L
.49808 .21154 L
.5 .21517 L
.50737 .23077 L
.51476 .25 L
.51923 .26466 L
.52037 .26923 L
.52428 .28846 L
.5265 .30769 L
.52702 .32692 L
.52581 .34615 L
.52276 .36538 L
.51923 .37994 L
.51773 .38462 L
.5105 .40385 L
.5007 .42308 L
.5 .42427 L
.48778 .44231 L
.48077 .4509 L
.47075 .46154 L
.46154 .46997 L
.44762 .48077 L
.44231 .48435 L
.42308 .4953 L
.41286 .5 L
.40385 .50351 L
.38462 .5094 L
.36538 .51325 L
.34615 .51524 L
.32692 .51546 L
.30769 .514 L
.28846 .51088 L
.26923 .50609 L
.25109 .5 L
.25 .49957 L
.23077 .49125 L
.21154 .48098 L
.21118 .48077 L
.19231 .46853 L
.18289 .46154 L
.17308 .45355 L
.16069 .44231 L
.15385 .43548 L
.14257 .42308 L
.13462 .41334 L
.12756 .40385 L
.11538 .38511 L
.11509 .38462 L
.10482 .36538 L
.09653 .34615 L
.09615 .34519 L
.09006 .32692 L
.08533 .30769 L
.0823 .28846 L
.08094 .26923 L
.0813 .25 L
.08344 .23077 L
.08748 .21154 L
.09361 .19231 L
.09615 .18586 L
.10211 .17308 L
.11342 .15385 L
.11538 .15098 L
.12829 .13462 L
.13462 .12782 L
.14809 .11538 L
.15385 .11078 L
.17308 .09785 L
.17601 .09615 L
.19231 .08802 L
.21154 .08075 L
.22498 .07692 L
F
0 g
.23077 .07568 m
.25 .07257 L
.26923 .07127 L
.28846 .07171 L
.30769 .07381 L
.32449 .07692 L
.32692 .07758 L
.34615 .08303 L
.36538 .09023 L
.37844 .09615 L
.38462 .09929 L
.40385 .11038 L
.41147 .11538 L
.42308 .12376 L
.43643 .13462 L
.44231 .13986 L
.45648 .15385 L
.46154 .15936 L
.473 .17308 L
.48077 .18352 L
.48672 .19231 L
.49808 .21154 L
.5 .21517 L
.50737 .23077 L
.51476 .25 L
.51923 .26466 L
.52037 .26923 L
.52428 .28846 L
.5265 .30769 L
.52702 .32692 L
.52581 .34615 L
.52276 .36538 L
.51923 .37994 L
.51773 .38462 L
.5105 .40385 L
.5007 .42308 L
.5 .42427 L
.48778 .44231 L
.48077 .4509 L
.47075 .46154 L
.46154 .46997 L
.44762 .48077 L
.44231 .48435 L
.42308 .4953 L
.41286 .5 L
.40385 .50351 L
.38462 .5094 L
.36538 .51325 L
.34615 .51524 L
.32692 .51546 L
Mistroke
.30769 .514 L
.28846 .51088 L
.26923 .50609 L
.25109 .5 L
.25 .49957 L
.23077 .49125 L
.21154 .48098 L
.21118 .48077 L
.19231 .46853 L
.18289 .46154 L
.17308 .45355 L
.16069 .44231 L
.15385 .43548 L
.14257 .42308 L
.13462 .41334 L
.12756 .40385 L
.11538 .38511 L
.11509 .38462 L
.10482 .36538 L
.09653 .34615 L
.09615 .34519 L
.09006 .32692 L
.08533 .30769 L
.0823 .28846 L
.08094 .26923 L
.0813 .25 L
.08344 .23077 L
.08748 .21154 L
.09361 .19231 L
.09615 .18586 L
.10211 .17308 L
.11342 .15385 L
.11538 .15098 L
.12829 .13462 L
.13462 .12782 L
.14809 .11538 L
.15385 .11078 L
.17308 .09785 L
.17601 .09615 L
.19231 .08802 L
.21154 .08075 L
.22498 .07692 L
.23077 .07568 L
Mfstroke
.8 g
.25 .11148 m
.26923 .10939 L
.28846 .10942 L
.30769 .11146 L
.3266 .11538 L
.32692 .1155 L
.34615 .12157 L
.36538 .1298 L
.37473 .13462 L
.38462 .1404 L
.40385 .15373 L
.404 .15385 L
.42308 .17037 L
.42582 .17308 L
.44231 .19149 L
.44296 .19231 L
.45665 .21154 L
.46154 .21958 L
.46754 .23077 L
.47601 .25 L
.48077 .26377 L
.48228 .26923 L
.48648 .28846 L
.48866 .30769 L
.48879 .32692 L
.4868 .34615 L
.48251 .36538 L
.48077 .37127 L
.47564 .38462 L
.46568 .40385 L
.46154 .41029 L
.45177 .42308 L
.44231 .43322 L
.43213 .44231 L
.42308 .44912 L
.40385 .46053 L
.40184 .46154 L
.38462 .46859 L
.36538 .47391 L
.34615 .47686 L
.32692 .47764 L
.30769 .47637 L
.28846 .47312 L
.26923 .46784 L
.25243 .46154 L
.25 .46046 L
.23077 .45082 L
.21691 .44231 L
.21154 .43861 L
.19231 .42334 L
.19201 .42308 L
.17308 .40414 L
.17281 .40385 L
.15755 .38462 L
.15385 .37924 L
.14536 .36538 L
.13575 .34615 L
.13462 .34359 L
.12843 .32692 L
.12323 .30769 L
.12007 .28846 L
.11894 .26923 L
.11988 .25 L
.12302 .23077 L
.12859 .21154 L
.13462 .19695 L
.13698 .19231 L
.14881 .17308 L
.15385 .16649 L
.16534 .15385 L
.17308 .14677 L
.18941 .13462 L
.19231 .13281 L
.21154 .12279 L
.23077 .11585 L
.23205 .11538 L
F
0 g
.25 .11148 m
.26923 .10939 L
.28846 .10942 L
.30769 .11146 L
.3266 .11538 L
.32692 .1155 L
.34615 .12157 L
.36538 .1298 L
.37473 .13462 L
.38462 .1404 L
.40385 .15373 L
.404 .15385 L
.42308 .17037 L
.42582 .17308 L
.44231 .19149 L
.44296 .19231 L
.45665 .21154 L
.46154 .21958 L
.46754 .23077 L
.47601 .25 L
.48077 .26377 L
.48228 .26923 L
.48648 .28846 L
.48866 .30769 L
.48879 .32692 L
.4868 .34615 L
.48251 .36538 L
.48077 .37127 L
.47564 .38462 L
.46568 .40385 L
.46154 .41029 L
.45177 .42308 L
.44231 .43322 L
.43213 .44231 L
.42308 .44912 L
.40385 .46053 L
.40184 .46154 L
.38462 .46859 L
.36538 .47391 L
.34615 .47686 L
.32692 .47764 L
.30769 .47637 L
.28846 .47312 L
.26923 .46784 L
.25243 .46154 L
.25 .46046 L
.23077 .45082 L
.21691 .44231 L
.21154 .43861 L
.19231 .42334 L
Mistroke
.19201 .42308 L
.17308 .40414 L
.17281 .40385 L
.15755 .38462 L
.15385 .37924 L
.14536 .36538 L
.13575 .34615 L
.13462 .34359 L
.12843 .32692 L
.12323 .30769 L
.12007 .28846 L
.11894 .26923 L
.11988 .25 L
.12302 .23077 L
.12859 .21154 L
.13462 .19695 L
.13698 .19231 L
.14881 .17308 L
.15385 .16649 L
.16534 .15385 L
.17308 .14677 L
.18941 .13462 L
.19231 .13281 L
.21154 .12279 L
.23077 .11585 L
.23205 .11538 L
.25 .11148 L
Mfstroke
.9 g
.26923 .15145 m
.28846 .15073 L
.30769 .15263 L
.3159 .15385 L
.32692 .1571 L
.34615 .16423 L
.36335 .17308 L
.36538 .17432 L
.38462 .18789 L
.38986 .19231 L
.40385 .20604 L
.40865 .21154 L
.42264 .23077 L
.42308 .23145 L
.43306 .25 L
.44045 .26923 L
.44231 .27392 L
.44513 .28846 L
.4472 .30769 L
.44663 .32692 L
.44321 .34615 L
.44231 .34984 L
.43656 .36538 L
.42581 .38462 L
.42308 .38845 L
.40923 .40385 L
.40385 .40854 L
.38462 .42137 L
.38149 .42308 L
.36538 .42961 L
.34615 .43434 L
.32692 .43612 L
.30769 .43522 L
.28846 .43175 L
.26923 .42566 L
.26278 .42308 L
.25 .41678 L
.23077 .40464 L
.22968 .40385 L
.21154 .38846 L
.2077 .38462 L
.19231 .36637 L
.19159 .36538 L
.17952 .34615 L
.17308 .33292 L
.17072 .32692 L
.16473 .30769 L
.1614 .28846 L
.16067 .26923 L
.16267 .25 L
.16768 .23077 L
.17308 .21746 L
.1763 .21154 L
.18972 .19231 L
.19231 .18939 L
.21091 .17308 L
.21154 .17264 L
.23077 .16176 L
.25 .15499 L
.25473 .15385 L
F
0 g
.26923 .15145 m
.28846 .15073 L
.30769 .15263 L
.3159 .15385 L
.32692 .1571 L
.34615 .16423 L
.36335 .17308 L
.36538 .17432 L
.38462 .18789 L
.38986 .19231 L
.40385 .20604 L
.40865 .21154 L
.42264 .23077 L
.42308 .23145 L
.43306 .25 L
.44045 .26923 L
.44231 .27392 L
.44513 .28846 L
.4472 .30769 L
.44663 .32692 L
.44321 .34615 L
.44231 .34984 L
.43656 .36538 L
.42581 .38462 L
.42308 .38845 L
.40923 .40385 L
.40385 .40854 L
.38462 .42137 L
.38149 .42308 L
.36538 .42961 L
.34615 .43434 L
.32692 .43612 L
.30769 .43522 L
.28846 .43175 L
.26923 .42566 L
.26278 .42308 L
.25 .41678 L
.23077 .40464 L
.22968 .40385 L
.21154 .38846 L
.2077 .38462 L
.19231 .36637 L
.19159 .36538 L
.17952 .34615 L
.17308 .33292 L
.17072 .32692 L
.16473 .30769 L
.1614 .28846 L
.16067 .26923 L
.16267 .25 L
Mistroke
.16768 .23077 L
.17308 .21746 L
.1763 .21154 L
.18972 .19231 L
.19231 .18939 L
.21091 .17308 L
.21154 .17264 L
.23077 .16176 L
.25 .15499 L
.25473 .15385 L
.26923 .15145 L
Mfstroke
1 g
.26923 .20537 m
.28846 .2026 L
.30769 .20408 L
.32692 .20966 L
.33174 .21154 L
.34615 .21961 L
.36053 .23077 L
.36538 .23552 L
.37714 .25 L
.38462 .26236 L
.38754 .26923 L
.39344 .28846 L
.39519 .30769 L
.39266 .32692 L
.38489 .34615 L
.38462 .34665 L
.36927 .36538 L
.36538 .36849 L
.34615 .37908 L
.32692 .38362 L
.30769 .38373 L
.28846 .37983 L
.26923 .37164 L
.25891 .36538 L
.25 .35833 L
.23791 .34615 L
.23077 .33699 L
.22481 .32692 L
.21681 .30769 L
.21311 .28846 L
.2135 .26923 L
.21844 .25 L
.22975 .23077 L
.23077 .22951 L
.25 .21333 L
.25203 .21154 L
F
0 g
.26923 .20537 m
.28846 .2026 L
.30769 .20408 L
.32692 .20966 L
.33174 .21154 L
.34615 .21961 L
.36053 .23077 L
.36538 .23552 L
.37714 .25 L
.38462 .26236 L
.38754 .26923 L
.39344 .28846 L
.39519 .30769 L
.39266 .32692 L
.38489 .34615 L
.38462 .34665 L
.36927 .36538 L
.36538 .36849 L
.34615 .37908 L
.32692 .38362 L
.30769 .38373 L
.28846 .37983 L
.26923 .37164 L
.25891 .36538 L
.25 .35833 L
.23791 .34615 L
.23077 .33699 L
.22481 .32692 L
.21681 .30769 L
.21311 .28846 L
.2135 .26923 L
.21844 .25 L
.22975 .23077 L
.23077 .22951 L
.25 .21333 L
.25203 .21154 L
.26923 .20537 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.522676 0.0238095 0.97619 0.477324 MathSubStart
%% SurfaceGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1.04977 -0.0679587 1.04977 [
[ 0 0 0 0 ]
[ 1 .81114 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.39787 .81114 L
s
.39787 .81114 m
.40529 .59895 L
s
.40529 .59895 m
.03716 .25514 L
s
.68874 0 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.68874 0 m
.03716 .25514 L
s
.40529 .59895 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.39787 .81114 L
s
.39787 .81114 m
.40529 .59895 L
s
0 0 m
1 0 L
1 .81114 L
0 .81114 L
closepath
clip
newpath
.658 .748 .916 r
.39899 .59894 .4051 .6044 .41534 .60143 .40925 .59598 Mtetra
.658 .748 .917 r
.40925 .59598 .41534 .60143 .42562 .59846 .41956 .59301 Mtetra
.657 .749 .918 r
.41956 .59301 .42562 .59846 .43595 .59548 .42991 .59004 Mtetra
.657 .75 .919 r
.42991 .59004 .43595 .59548 .44631 .59249 .44029 .58706 Mtetra
.657 .752 .92 r
.44029 .58706 .44631 .59249 .45671 .5895 .45072 .58408 Mtetra
.657 .753 .921 r
.45072 .58408 .45671 .5895 .46715 .58649 .46119 .58109 Mtetra
.656 .754 .922 r
.46119 .58109 .46715 .58649 .47764 .58348 .4717 .57809 Mtetra
.656 .755 .923 r
.4717 .57809 .47764 .58348 .48816 .58045 .48225 .57508 Mtetra
.656 .756 .924 r
.48225 .57508 .48816 .58045 .49873 .57741 .49285 .57205 Mtetra
.656 .758 .924 r
.49285 .57205 .49873 .57741 .50934 .57435 .50349 .569 Mtetra
.657 .759 .925 r
.50349 .569 .50934 .57435 .51999 .57127 .51416 .56593 Mtetra
.657 .76 .926 r
.51416 .56593 .51999 .57127 .53068 .56817 .52489 .56284 Mtetra
.657 .761 .926 r
.52489 .56284 .53068 .56817 .54142 .56505 .53565 .55972 Mtetra
.658 .762 .927 r
.53565 .55972 .54142 .56505 .5522 .5619 .54646 .55657 Mtetra
.659 .763 .927 r
.54646 .55657 .5522 .5619 .56302 .55873 .55731 .55339 Mtetra
.659 .764 .927 r
.55731 .55339 .56302 .55873 .57388 .55552 .5682 .55017 Mtetra
.66 .765 .927 r
.5682 .55017 .57388 .55552 .58479 .55229 .57914 .54692 Mtetra
.661 .765 .927 r
.57914 .54692 .58479 .55229 .59574 .54902 .59012 .54364 Mtetra
.662 .766 .927 r
.59012 .54364 .59574 .54902 .60673 .54572 .60114 .54031 Mtetra
.663 .766 .926 r
.60114 .54031 .60673 .54572 .61776 .54239 .61221 .53695 Mtetra
.664 .766 .926 r
.61221 .53695 .61776 .54239 .62884 .53903 .62332 .53355 Mtetra
.665 .766 .925 r
.62332 .53355 .62884 .53903 .63996 .53564 .63447 .53012 Mtetra
.665 .765 .925 r
.63447 .53012 .63996 .53564 .65112 .53222 .64566 .52666 Mtetra
.666 .765 .924 r
.64566 .52666 .65112 .53222 .66233 .52877 .6569 .52316 Mtetra
.667 .764 .923 r
.6569 .52316 .66233 .52877 .67358 .5253 .66819 .51963 Mtetra
.667 .763 .922 r
.66819 .51963 .67358 .5253 .68487 .5218 .67951 .51608 Mtetra
.668 .762 .921 r
.67951 .51608 .68487 .5218 .69621 .51828 .69088 .5125 Mtetra
.668 .761 .92 r
.69088 .5125 .69621 .51828 .7076 .51474 .7023 .50889 Mtetra
.668 .76 .919 r
.7023 .50889 .7076 .51474 .71902 .51118 .71376 .50527 Mtetra
.668 .759 .918 r
.71376 .50527 .71902 .51118 .7305 .5076 .72526 .50163 Mtetra
.668 .757 .917 r
.72526 .50163 .7305 .5076 .74201 .50401 .73681 .49798 Mtetra
.668 .756 .916 r
.73681 .49798 .74201 .50401 .75358 .50041 .74841 .49432 Mtetra
.668 .755 .915 r
.74841 .49432 .75358 .50041 .76519 .4968 .76005 .49065 Mtetra
.668 .754 .914 r
.76005 .49065 .76519 .4968 .77685 .49318 .77174 .48697 Mtetra
.668 .752 .914 r
.77174 .48697 .77685 .49318 .78855 .48955 .78347 .48328 Mtetra
.668 .751 .913 r
.78347 .48328 .78855 .48955 .8003 .48592 .79526 .47959 Mtetra
.667 .75 .912 r
.79526 .47959 .8003 .48592 .8121 .48227 .80709 .47589 Mtetra
.667 .749 .912 r
.80709 .47589 .8121 .48227 .82395 .47862 .81897 .47219 Mtetra
.667 .748 .911 r
.81897 .47219 .82395 .47862 .83585 .47497 .8309 .46848 Mtetra
.666 .747 .911 r
.8309 .46848 .83585 .47497 .84779 .47131 .84288 .46477 Mtetra
.666 .746 .91 r
.84288 .46477 .84779 .47131 .85979 .46764 .85491 .46106 Mtetra
.85491 .46106 .85979 .46764 .87183 .46396 .86699 .45734 Mtetra
.666 .745 .909 r
.86699 .45734 .87183 .46396 .88393 .46028 .87912 .45361 Mtetra
.665 .744 .909 r
.87912 .45361 .88393 .46028 .89607 .45659 .89131 .44988 Mtetra
.89131 .44988 .89607 .45659 .90827 .45289 .90354 .44614 Mtetra
.665 .743 .909 r
.90354 .44614 .90827 .45289 .92052 .44918 .91582 .4424 Mtetra
.91582 .4424 .92052 .44918 .93282 .44547 .92816 .43864 Mtetra
.664 .743 .908 r
.92816 .43864 .93282 .44547 .94517 .44174 .94055 .43488 Mtetra
.664 .742 .908 r
.94055 .43488 .94517 .44174 .95758 .43799 .95299 .4311 Mtetra
.95299 .4311 .95758 .43799 .97003 .43424 .96549 .42732 Mtetra
.657 .749 .918 r
.39283 .59349 .39899 .59894 .40925 .59598 .40312 .59054 Mtetra
.656 .75 .919 r
.40312 .59054 .40925 .59598 .41956 .59301 .41345 .58759 Mtetra
.656 .751 .92 r
.41345 .58759 .41956 .59301 .42991 .59004 .42382 .58464 Mtetra
.655 .753 .921 r
.42382 .58464 .42991 .59004 .44029 .58706 .43423 .58168 Mtetra
.655 .754 .923 r
.43423 .58168 .44029 .58706 .45072 .58408 .44469 .57872 Mtetra
.655 .755 .924 r
.44469 .57872 .45072 .58408 .46119 .58109 .45518 .57575 Mtetra
.654 .757 .925 r
.45518 .57575 .46119 .58109 .4717 .57809 .46572 .57278 Mtetra
.654 .759 .926 r
.46572 .57278 .4717 .57809 .48225 .57508 .4763 .56978 Mtetra
.654 .76 .927 r
.4763 .56978 .48225 .57508 .49285 .57205 .48692 .56677 Mtetra
.654 .762 .928 r
.48692 .56677 .49285 .57205 .50349 .569 .49759 .56375 Mtetra
.655 .763 .929 r
.49759 .56375 .50349 .569 .51416 .56593 .50829 .56069 Mtetra
.655 .765 .93 r
.50829 .56069 .51416 .56593 .52489 .56284 .51905 .55761 Mtetra
.656 .766 .931 r
.51905 .55761 .52489 .56284 .53565 .55972 .52984 .5545 Mtetra
.656 .767 .931 r
.52984 .5545 .53565 .55972 .54646 .55657 .54068 .55135 Mtetra
.657 .769 .932 r
.54068 .55135 .54646 .55657 .55731 .55339 .55156 .54817 Mtetra
.658 .77 .932 r
.55156 .54817 .55731 .55339 .5682 .55017 .56248 .54494 Mtetra
.659 .771 .932 r
.56248 .54494 .5682 .55017 .57914 .54692 .57345 .54168 Mtetra
.66 .771 .932 r
.57345 .54168 .57914 .54692 .59012 .54364 .58446 .53837 Mtetra
.661 .772 .931 r
.58446 .53837 .59012 .54364 .60114 .54031 .59552 .53502 Mtetra
.663 .772 .931 r
.59552 .53502 .60114 .54031 .61221 .53695 .60662 .53163 Mtetra
.664 .772 .93 r
.60662 .53163 .61221 .53695 .62332 .53355 .61776 .52819 Mtetra
.665 .772 .929 r
.61776 .52819 .62332 .53355 .63447 .53012 .62894 .52472 Mtetra
.666 .771 .928 r
.62894 .52472 .63447 .53012 .64566 .52666 .64017 .5212 Mtetra
.667 .77 .927 r
.64017 .5212 .64566 .52666 .6569 .52316 .65144 .51764 Mtetra
.668 .769 .926 r
.65144 .51764 .6569 .52316 .66819 .51963 .66276 .51406 Mtetra
.668 .768 .925 r
.66276 .51406 .66819 .51963 .67951 .51608 .67411 .51044 Mtetra
.669 .767 .924 r
.67411 .51044 .67951 .51608 .69088 .5125 .68552 .50679 Mtetra
.669 .766 .923 r
.68552 .50679 .69088 .5125 .7023 .50889 .69696 .50312 Mtetra
.67 .764 .921 r
.69696 .50312 .7023 .50889 .71376 .50527 .70845 .49943 Mtetra
.67 .763 .92 r
.70845 .49943 .71376 .50527 .72526 .50163 .71999 .49572 Mtetra
.67 .761 .919 r
.71999 .49572 .72526 .50163 .73681 .49798 .73157 .49199 Mtetra
.67 .76 .918 r
.73157 .49199 .73681 .49798 .74841 .49432 .7432 .48826 Mtetra
.67 .758 .917 r
.7432 .48826 .74841 .49432 .76005 .49065 .75487 .48452 Mtetra
.669 .756 .916 r
.75487 .48452 .76005 .49065 .77174 .48697 .7666 .48077 Mtetra
.669 .755 .915 r
.7666 .48077 .77174 .48697 .78347 .48328 .77836 .47701 Mtetra
.669 .753 .914 r
.77836 .47701 .78347 .48328 .79526 .47959 .79018 .47326 Mtetra
.668 .752 .913 r
.79018 .47326 .79526 .47959 .80709 .47589 .80205 .4695 Mtetra
.668 .751 .912 r
.80205 .4695 .80709 .47589 .81897 .47219 .81396 .46574 Mtetra
.668 .75 .912 r
.81396 .46574 .81897 .47219 .8309 .46848 .82593 .46197 Mtetra
.667 .748 .911 r
.82593 .46197 .8309 .46848 .84288 .46477 .83794 .45821 Mtetra
.667 .747 .911 r
.83794 .45821 .84288 .46477 .85491 .46106 .85 .45445 Mtetra
.666 .747 .91 r
.85 .45445 .85491 .46106 .86699 .45734 .86212 .45068 Mtetra
.666 .746 .91 r
.86212 .45068 .86699 .45734 .87912 .45361 .87428 .44691 Mtetra
.666 .745 .909 r
.87428 .44691 .87912 .45361 .89131 .44988 .8865 .44313 Mtetra
.665 .744 .909 r
.8865 .44313 .89131 .44988 .90354 .44614 .89877 .43935 Mtetra
.89877 .43935 .90354 .44614 .91582 .4424 .91109 .43557 Mtetra
.665 .743 .909 r
.91109 .43557 .91582 .4424 .92816 .43864 .92347 .43178 Mtetra
.92347 .43178 .92816 .43864 .94055 .43488 .93589 .42797 Mtetra
.664 .743 .908 r
.93589 .42797 .94055 .43488 .95299 .4311 .94837 .42416 Mtetra
.664 .742 .908 r
.94837 .42416 .95299 .4311 .96549 .42732 .9609 .42034 Mtetra
.655 .751 .92 r
.38662 .58806 .39283 .59349 .40312 .59054 .39694 .58513 Mtetra
.654 .752 .922 r
.39694 .58513 .40312 .59054 .41345 .58759 .40729 .58221 Mtetra
.654 .754 .923 r
.40729 .58221 .41345 .58759 .42382 .58464 .41769 .57929 Mtetra
.653 .755 .925 r
.41769 .57929 .42382 .58464 .43423 .58168 .42812 .57636 Mtetra
.652 .757 .926 r
.42812 .57636 .43423 .58168 .44469 .57872 .4386 .57343 Mtetra
.652 .759 .928 r
.4386 .57343 .44469 .57872 .45518 .57575 .44912 .57049 Mtetra
.652 .761 .929 r
.44912 .57049 .45518 .57575 .46572 .57278 .45969 .56755 Mtetra
.651 .763 .931 r
.45969 .56755 .46572 .57278 .4763 .56978 .4703 .56459 Mtetra
.651 .764 .932 r
.4703 .56459 .4763 .56978 .48692 .56677 .48095 .56161 Mtetra
.652 .766 .933 r
.48095 .56161 .48692 .56677 .49759 .56375 .49164 .55861 Mtetra
.652 .768 .934 r
.49164 .55861 .49759 .56375 .50829 .56069 .50238 .55558 Mtetra
.652 .77 .935 r
.50238 .55558 .50829 .56069 .51905 .55761 .51316 .55251 Mtetra
.653 .772 .936 r
.51316 .55251 .51905 .55761 .52984 .5545 .52398 .54942 Mtetra
.654 .774 .937 r
.52398 .54942 .52984 .5545 .54068 .55135 .53485 .54628 Mtetra
.655 .775 .937 r
.53485 .54628 .54068 .55135 .55156 .54817 .54576 .5431 Mtetra
.656 .776 .937 r
.54576 .5431 .55156 .54817 .56248 .54494 .55672 .53987 Mtetra
.658 .777 .937 r
.55672 .53987 .56248 .54494 .57345 .54168 .56772 .53659 Mtetra
.659 .778 .937 r
.56772 .53659 .57345 .54168 .58446 .53837 .57877 .53327 Mtetra
.661 .779 .936 r
.57877 .53327 .58446 .53837 .59552 .53502 .58985 .52989 Mtetra
.662 .779 .936 r
.58985 .52989 .59552 .53502 .60662 .53163 .60098 .52646 Mtetra
.664 .779 .935 r
.60098 .52646 .60662 .53163 .61776 .52819 .61216 .52298 Mtetra
.665 .779 .934 r
.61216 .52298 .61776 .52819 .62894 .52472 .62338 .51945 Mtetra
.666 .778 .933 r
.62338 .51945 .62894 .52472 .64017 .5212 .63464 .51587 Mtetra
.667 .777 .931 r
.63464 .51587 .64017 .5212 .65144 .51764 .64594 .51226 Mtetra
.669 .776 .93 r
.64594 .51226 .65144 .51764 .66276 .51406 .65729 .5086 Mtetra
.669 .775 .929 r
.65729 .5086 .66276 .51406 .67411 .51044 .66868 .50491 Mtetra
.67 .773 .927 r
.66868 .50491 .67411 .51044 .68552 .50679 .68011 .50118 Mtetra
.671 .771 .926 r
.68011 .50118 .68552 .50679 .69696 .50312 .69159 .49743 Mtetra
.671 .77 .924 r
.69159 .49743 .69696 .50312 .70845 .49943 .70312 .49366 Mtetra
.671 .768 .923 r
.70312 .49366 .70845 .49943 .71999 .49572 .71469 .48987 Mtetra
.672 .766 .921 r
.71469 .48987 .71999 .49572 .73157 .49199 .7263 .48606 Mtetra
.671 .764 .92 r
.7263 .48606 .73157 .49199 .7432 .48826 .73796 .48224 Mtetra
.671 .762 .918 r
.73796 .48224 .7432 .48826 .75487 .48452 .74967 .47842 Mtetra
.671 .76 .917 r
.74967 .47842 .75487 .48452 .7666 .48077 .76142 .47459 Mtetra
.671 .758 .916 r
.76142 .47459 .7666 .48077 .77836 .47701 .77322 .47076 Mtetra
.67 .756 .915 r
.77322 .47076 .77836 .47701 .79018 .47326 .78507 .46693 Mtetra
.67 .755 .914 r
.78507 .46693 .79018 .47326 .80205 .4695 .79697 .46311 Mtetra
.669 .753 .913 r
.79697 .46311 .80205 .4695 .81396 .46574 .80891 .45928 Mtetra
.669 .751 .912 r
.80891 .45928 .81396 .46574 .82593 .46197 .82091 .45546 Mtetra
.668 .75 .912 r
.82091 .45546 .82593 .46197 .83794 .45821 .83296 .45163 Mtetra
.668 .749 .911 r
.83296 .45163 .83794 .45821 .85 .45445 .84506 .44781 Mtetra
.667 .748 .911 r
.84506 .44781 .85 .45445 .86212 .45068 .85721 .44399 Mtetra
.667 .747 .91 r
.85721 .44399 .86212 .45068 .87428 .44691 .86941 .44017 Mtetra
.666 .746 .91 r
.86941 .44017 .87428 .44691 .8865 .44313 .88166 .43635 Mtetra
.666 .745 .909 r
.88166 .43635 .8865 .44313 .89877 .43935 .89397 .43252 Mtetra
.666 .744 .909 r
.89397 .43252 .89877 .43935 .91109 .43557 .90632 .4287 Mtetra
.665 .744 .909 r
.90632 .4287 .91109 .43557 .92347 .43178 .91874 .42486 Mtetra
.665 .743 .909 r
.91874 .42486 .92347 .43178 .93589 .42797 .9312 .42102 Mtetra
.9312 .42102 .93589 .42797 .94837 .42416 .94372 .41717 Mtetra
.664 .743 .908 r
.94372 .41717 .94837 .42416 .9609 .42034 .95629 .41331 Mtetra
.653 .753 .923 r
.38037 .58267 .38662 .58806 .39694 .58513 .3907 .57978 Mtetra
.652 .755 .925 r
.3907 .57978 .39694 .58513 .40729 .58221 .40108 .57689 Mtetra
.651 .756 .927 r
.40108 .57689 .40729 .58221 .41769 .57929 .4115 .574 Mtetra
.65 .758 .929 r
.4115 .574 .41769 .57929 .42812 .57636 .42197 .57112 Mtetra
.649 .76 .931 r
.42197 .57112 .42812 .57636 .4386 .57343 .43247 .56823 Mtetra
.649 .763 .932 r
.43247 .56823 .4386 .57343 .44912 .57049 .44302 .56534 Mtetra
.648 .765 .934 r
.44302 .56534 .44912 .57049 .45969 .56755 .45361 .56243 Mtetra
.648 .767 .936 r
.45361 .56243 .45969 .56755 .4703 .56459 .46424 .55952 Mtetra
.648 .77 .937 r
.46424 .55952 .4703 .56459 .48095 .56161 .47492 .55658 Mtetra
.648 .772 .939 r
.47492 .55658 .48095 .56161 .49164 .55861 .48564 .55361 Mtetra
.648 .774 .94 r
.48564 .55361 .49164 .55861 .50238 .55558 .49641 .55062 Mtetra
.649 .777 .941 r
.49641 .55062 .50238 .55558 .51316 .55251 .50722 .54758 Mtetra
.65 .779 .942 r
.50722 .54758 .51316 .55251 .52398 .54942 .51808 .54451 Mtetra
.651 .781 .943 r
.51808 .54451 .52398 .54942 .53485 .54628 .52898 .54138 Mtetra
.652 .783 .943 r
.52898 .54138 .53485 .54628 .54576 .5431 .53993 .53821 Mtetra
.654 .784 .943 r
.53993 .53821 .54576 .5431 .55672 .53987 .55091 .53498 Mtetra
.656 .785 .943 r
.55091 .53498 .55672 .53987 .56772 .53659 .56195 .53169 Mtetra
.658 .786 .943 r
.56195 .53169 .56772 .53659 .57877 .53327 .57303 .52834 Mtetra
.659 .787 .942 r
.57303 .52834 .57877 .53327 .58985 .52989 .58415 .52494 Mtetra
.661 .787 .941 r
.58415 .52494 .58985 .52989 .60098 .52646 .59531 .52147 Mtetra
.663 .787 .94 r
.59531 .52147 .60098 .52646 .61216 .52298 .60652 .51794 Mtetra
.665 .787 .939 r
.60652 .51794 .61216 .52298 .62338 .51945 .61777 .51435 Mtetra
.667 .786 .938 r
.61777 .51435 .62338 .51945 .63464 .51587 .62907 .51071 Mtetra
.668 .785 .936 r
.62907 .51071 .63464 .51587 .64594 .51226 .6404 .50702 Mtetra
.67 .784 .934 r
.6404 .50702 .64594 .51226 .65729 .5086 .65178 .50329 Mtetra
.671 .782 .933 r
.65178 .50329 .65729 .5086 .66868 .50491 .66321 .49951 Mtetra
.672 .78 .931 r
.66321 .49951 .66868 .50491 .68011 .50118 .67468 .4957 Mtetra
.673 .778 .929 r
.67468 .4957 .68011 .50118 .69159 .49743 .68619 .49185 Mtetra
.673 .776 .927 r
.68619 .49185 .69159 .49743 .70312 .49366 .69774 .48799 Mtetra
.673 .773 .925 r
.69774 .48799 .70312 .49366 .71469 .48987 .70935 .4841 Mtetra
.674 .771 .924 r
.70935 .4841 .71469 .48987 .7263 .48606 .72099 .4802 Mtetra
.674 .769 .922 r
.72099 .4802 .7263 .48606 .73796 .48224 .73268 .47629 Mtetra
.673 .766 .92 r
.73268 .47629 .73796 .48224 .74967 .47842 .74442 .47238 Mtetra
.673 .764 .919 r
.74442 .47238 .74967 .47842 .76142 .47459 .75621 .46846 Mtetra
.672 .762 .918 r
.75621 .46846 .76142 .47459 .77322 .47076 .76804 .46454 Mtetra
.672 .759 .916 r
.76804 .46454 .77322 .47076 .78507 .46693 .77992 .46063 Mtetra
.671 .757 .915 r
.77992 .46063 .78507 .46693 .79697 .46311 .79185 .45673 Mtetra
.671 .755 .914 r
.79185 .45673 .79697 .46311 .80891 .45928 .80383 .45282 Mtetra
.67 .754 .913 r
.80383 .45282 .80891 .45928 .82091 .45546 .81586 .44893 Mtetra
.669 .752 .912 r
.81586 .44893 .82091 .45546 .83296 .45163 .82794 .44504 Mtetra
.669 .75 .912 r
.82794 .44504 .83296 .45163 .84506 .44781 .84008 .44116 Mtetra
.668 .749 .911 r
.84008 .44116 .84506 .44781 .85721 .44399 .85226 .43728 Mtetra
.668 .748 .911 r
.85226 .43728 .85721 .44399 .86941 .44017 .8645 .4334 Mtetra
.667 .747 .91 r
.8645 .4334 .86941 .44017 .88166 .43635 .87678 .42953 Mtetra
.666 .746 .91 r
.87678 .42953 .88166 .43635 .89397 .43252 .88913 .42566 Mtetra
.666 .745 .909 r
.88913 .42566 .89397 .43252 .90632 .4287 .90152 .42178 Mtetra
.666 .744 .909 r
.90152 .42178 .90632 .4287 .91874 .42486 .91397 .4179 Mtetra
.665 .744 .909 r
.91397 .4179 .91874 .42486 .9312 .42102 .92647 .41402 Mtetra
.665 .743 .909 r
.92647 .41402 .9312 .42102 .94372 .41717 .93903 .41013 Mtetra
.665 .743 .908 r
.93903 .41013 .94372 .41717 .95629 .41331 .95164 .40624 Mtetra
.65 .755 .927 r
.37406 .57733 .38037 .58267 .3907 .57978 .38442 .57448 Mtetra
.648 .758 .929 r
.38442 .57448 .3907 .57978 .40108 .57689 .39483 .57164 Mtetra
.647 .76 .931 r
.39483 .57164 .40108 .57689 .4115 .574 .40527 .5688 Mtetra
.646 .762 .933 r
.40527 .5688 .4115 .574 .42197 .57112 .41576 .56597 Mtetra
.645 .765 .936 r
.41576 .56597 .42197 .57112 .43247 .56823 .42629 .56314 Mtetra
.644 .767 .938 r
.42629 .56314 .43247 .56823 .44302 .56534 .43686 .56031 Mtetra
.644 .77 .94 r
.43686 .56031 .44302 .56534 .45361 .56243 .44748 .55746 Mtetra
.643 .773 .942 r
.44748 .55746 .45361 .56243 .46424 .55952 .45814 .5546 Mtetra
.643 .776 .944 r
.45814 .5546 .46424 .55952 .47492 .55658 .46885 .55171 Mtetra
.643 .779 .946 r
.46885 .55171 .47492 .55658 .48564 .55361 .4796 .5488 Mtetra
.644 .781 .947 r
.4796 .5488 .48564 .55361 .49641 .55062 .4904 .54584 Mtetra
.645 .784 .948 r
.4904 .54584 .49641 .55062 .50722 .54758 .50124 .54285 Mtetra
.646 .787 .949 r
.50124 .54285 .50722 .54758 .51808 .54451 .51213 .5398 Mtetra
.647 .789 .95 r
.51213 .5398 .51808 .54451 .52898 .54138 .52306 .5367 Mtetra
.649 .791 .95 r
.52306 .5367 .52898 .54138 .53993 .53821 .53404 .53354 Mtetra
.651 .793 .951 r
.53404 .53354 .53993 .53821 .55091 .53498 .54506 .53031 Mtetra
.653 .795 .95 r
.54506 .53031 .55091 .53498 .56195 .53169 .55613 .52702 Mtetra
.655 .796 .95 r
.55613 .52702 .56195 .53169 .57303 .52834 .56724 .52365 Mtetra
.658 .797 .949 r
.56724 .52365 .57303 .52834 .58415 .52494 .5784 .52021 Mtetra
.66 .797 .948 r
.5784 .52021 .58415 .52494 .59531 .52147 .5896 .5167 Mtetra
.663 .797 .947 r
.5896 .5167 .59531 .52147 .60652 .51794 .60084 .51311 Mtetra
.665 .797 .945 r
.60084 .51311 .60652 .51794 .61777 .51435 .61213 .50946 Mtetra
.667 .796 .943 r
.61213 .50946 .61777 .51435 .62907 .51071 .62346 .50575 Mtetra
.669 .794 .941 r
.62346 .50575 .62907 .51071 .6404 .50702 .63483 .50198 Mtetra
.671 .793 .939 r
.63483 .50198 .6404 .50702 .65178 .50329 .64624 .49815 Mtetra
.673 .791 .937 r
.64624 .49815 .65178 .50329 .66321 .49951 .6577 .49427 Mtetra
.674 .788 .935 r
.6577 .49427 .66321 .49951 .67468 .4957 .6692 .49036 Mtetra
.675 .786 .933 r
.6692 .49036 .67468 .4957 .68619 .49185 .68075 .48641 Mtetra
.676 .783 .931 r
.68075 .48641 .68619 .49185 .69774 .48799 .69234 .48244 Mtetra
.676 .78 .929 r
.69234 .48244 .69774 .48799 .70935 .4841 .70397 .47844 Mtetra
.676 .777 .926 r
.70397 .47844 .70935 .4841 .72099 .4802 .71565 .47443 Mtetra
.676 .774 .924 r
.71565 .47443 .72099 .4802 .73268 .47629 .72737 .47041 Mtetra
.676 .771 .923 r
.72737 .47041 .73268 .47629 .74442 .47238 .73914 .46639 Mtetra
.675 .769 .921 r
.73914 .46639 .74442 .47238 .75621 .46846 .75096 .46238 Mtetra
.675 .766 .919 r
.75096 .46238 .75621 .46846 .76804 .46454 .76283 .45836 Mtetra
.674 .763 .918 r
.76283 .45836 .76804 .46454 .77992 .46063 .77474 .45436 Mtetra
.673 .761 .916 r
.77474 .45436 .77992 .46063 .79185 .45673 .7867 .45036 Mtetra
.672 .758 .915 r
.7867 .45036 .79185 .45673 .80383 .45282 .79872 .44638 Mtetra
.672 .756 .914 r
.79872 .44638 .80383 .45282 .81586 .44893 .81078 .4424 Mtetra
.671 .754 .913 r
.81078 .4424 .81586 .44893 .82794 .44504 .82289 .43844 Mtetra
.67 .752 .912 r
.82289 .43844 .82794 .44504 .84008 .44116 .83506 .43449 Mtetra
.669 .751 .912 r
.83506 .43449 .84008 .44116 .85226 .43728 .84728 .43054 Mtetra
.668 .749 .911 r
.84728 .43054 .85226 .43728 .8645 .4334 .85955 .42661 Mtetra
.668 .748 .91 r
.85955 .42661 .8645 .4334 .87678 .42953 .87187 .42268 Mtetra
.667 .747 .91 r
.87187 .42268 .87678 .42953 .88913 .42566 .88425 .41875 Mtetra
.667 .746 .91 r
.88425 .41875 .88913 .42566 .90152 .42178 .89668 .41483 Mtetra
.666 .745 .909 r
.89668 .41483 .90152 .42178 .91397 .4179 .90917 .4109 Mtetra
.666 .744 .909 r
.90917 .4109 .91397 .4179 .92647 .41402 .92171 .40698 Mtetra
.665 .744 .909 r
.92171 .40698 .92647 .41402 .93903 .41013 .9343 .40305 Mtetra
.665 .743 .909 r
.9343 .40305 .93903 .41013 .95164 .40624 .94695 .39911 Mtetra
.646 .758 .931 r
.3677 .57206 .37406 .57733 .38442 .57448 .37809 .56927 Mtetra
.644 .761 .934 r
.37809 .56927 .38442 .57448 .39483 .57164 .38851 .56649 Mtetra
.643 .763 .936 r
.38851 .56649 .39483 .57164 .40527 .5688 .39898 .56372 Mtetra
.641 .766 .939 r
.39898 .56372 .40527 .5688 .41576 .56597 .40949 .56095 Mtetra
.64 .769 .941 r
.40949 .56095 .41576 .56597 .42629 .56314 .42005 .55819 Mtetra
.639 .772 .944 r
.42005 .55819 .42629 .56314 .43686 .56031 .43065 .55543 Mtetra
.638 .776 .947 r
.43065 .55543 .43686 .56031 .44748 .55746 .44129 .55265 Mtetra
.637 .779 .949 r
.44129 .55265 .44748 .55746 .45814 .5546 .45198 .54986 Mtetra
.637 .783 .951 r
.45198 .54986 .45814 .5546 .46885 .55171 .46272 .54704 Mtetra
.637 .786 .953 r
.46272 .54704 .46885 .55171 .4796 .5488 .4735 .54419 Mtetra
.638 .79 .955 r
.4735 .54419 .4796 .5488 .4904 .54584 .48433 .5413 Mtetra
.639 .793 .956 r
.48433 .5413 .4904 .54584 .50124 .54285 .4952 .53835 Mtetra
.64 .796 .957 r
.4952 .53835 .50124 .54285 .51213 .5398 .50612 .53535 Mtetra
.642 .799 .958 r
.50612 .53535 .51213 .5398 .52306 .5367 .51709 .53228 Mtetra
.644 .802 .959 r
.51709 .53228 .52306 .5367 .53404 .53354 .5281 .52913 Mtetra
.646 .804 .959 r
.5281 .52913 .53404 .53354 .54506 .53031 .53916 .52591 Mtetra
.649 .806 .958 r
.53916 .52591 .54506 .53031 .55613 .52702 .55026 .52261 Mtetra
.652 .807 .958 r
.55026 .52261 .55613 .52702 .56724 .52365 .56141 .51922 Mtetra
.655 .808 .957 r
.56141 .51922 .56724 .52365 .5784 .52021 .57261 .51574 Mtetra
.659 .809 .955 r
.57261 .51574 .5784 .52021 .5896 .5167 .58384 .51218 Mtetra
.662 .809 .954 r
.58384 .51218 .5896 .5167 .60084 .51311 .59512 .50854 Mtetra
.665 .808 .952 r
.59512 .50854 .60084 .51311 .61213 .50946 .60644 .50482 Mtetra
.668 .807 .949 r
.60644 .50482 .61213 .50946 .62346 .50575 .61781 .50102 Mtetra
.67 .805 .947 r
.61781 .50102 .62346 .50575 .63483 .50198 .62922 .49715 Mtetra
.673 .803 .945 r
.62922 .49715 .63483 .50198 .64624 .49815 .64067 .49322 Mtetra
.675 .801 .942 r
.64067 .49322 .64624 .49815 .6577 .49427 .65216 .48923 Mtetra
.676 .798 .94 r
.65216 .48923 .6577 .49427 .6692 .49036 .66369 .4852 Mtetra
.678 .795 .937 r
.66369 .4852 .6692 .49036 .68075 .48641 .67527 .48113 Mtetra
.678 .791 .934 r
.67527 .48113 .68075 .48641 .69234 .48244 .6869 .47703 Mtetra
.679 .788 .932 r
.6869 .47703 .69234 .48244 .70397 .47844 .69856 .47291 Mtetra
.679 .784 .93 r
.69856 .47291 .70397 .47844 .71565 .47443 .71027 .46877 Mtetra
.679 .781 .927 r
.71027 .46877 .71565 .47443 .72737 .47041 .72203 .46463 Mtetra
.679 .777 .925 r
.72203 .46463 .72737 .47041 .73914 .46639 .73383 .46049 Mtetra
.678 .774 .923 r
.73383 .46049 .73914 .46639 .75096 .46238 .74568 .45636 Mtetra
.677 .771 .921 r
.74568 .45636 .75096 .46238 .76283 .45836 .75758 .45223 Mtetra
.676 .767 .919 r
.75758 .45223 .76283 .45836 .77474 .45436 .76952 .44812 Mtetra
.675 .764 .918 r
.76952 .44812 .77474 .45436 .7867 .45036 .78152 .44402 Mtetra
.674 .762 .916 r
.78152 .44402 .7867 .45036 .79872 .44638 .79356 .43994 Mtetra
.673 .759 .915 r
.79356 .43994 .79872 .44638 .81078 .4424 .80566 .43588 Mtetra
.672 .757 .914 r
.80566 .43588 .81078 .4424 .82289 .43844 .81781 .43183 Mtetra
.671 .755 .913 r
.81781 .43183 .82289 .43844 .83506 .43449 .83001 .4278 Mtetra
.67 .753 .912 r
.83001 .4278 .83506 .43449 .84728 .43054 .84226 .42379 Mtetra
.67 .751 .911 r
.84226 .42379 .84728 .43054 .85955 .42661 .85456 .41979 Mtetra
.669 .749 .911 r
.85456 .41979 .85955 .42661 .87187 .42268 .86692 .41579 Mtetra
.668 .748 .91 r
.86692 .41579 .87187 .42268 .88425 .41875 .87934 .41181 Mtetra
.667 .747 .91 r
.87934 .41181 .88425 .41875 .89668 .41483 .8918 .40783 Mtetra
.667 .746 .909 r
.8918 .40783 .89668 .41483 .90917 .4109 .90433 .40386 Mtetra
.666 .745 .909 r
.90433 .40386 .90917 .4109 .92171 .40698 .9169 .39989 Mtetra
.666 .744 .909 r
.9169 .39989 .92171 .40698 .9343 .40305 .92954 .39591 Mtetra
.665 .744 .909 r
.92954 .39591 .9343 .40305 .94695 .39911 .94222 .39193 Mtetra
.641 .762 .936 r
.36129 .56687 .3677 .57206 .37809 .56927 .3717 .56415 Mtetra
.639 .765 .939 r
.3717 .56415 .37809 .56927 .38851 .56649 .38215 .56145 Mtetra
.637 .768 .942 r
.38215 .56145 .38851 .56649 .39898 .56372 .39264 .55876 Mtetra
.635 .771 .945 r
.39264 .55876 .39898 .56372 .40949 .56095 .40318 .55608 Mtetra
.633 .775 .948 r
.40318 .55608 .40949 .56095 .42005 .55819 .41376 .55341 Mtetra
.632 .778 .951 r
.41376 .55341 .42005 .55819 .43065 .55543 .42438 .55073 Mtetra
.631 .782 .954 r
.42438 .55073 .43065 .55543 .44129 .55265 .43505 .54805 Mtetra
.63 .786 .957 r
.43505 .54805 .44129 .55265 .45198 .54986 .44577 .54534 Mtetra
.629 .791 .959 r
.44577 .54534 .45198 .54986 .46272 .54704 .45654 .54261 Mtetra
.629 .795 .962 r
.45654 .54261 .46272 .54704 .4735 .54419 .46735 .53984 Mtetra
.63 .799 .964 r
.46735 .53984 .4735 .54419 .48433 .5413 .47821 .53701 Mtetra
.631 .803 .965 r
.47821 .53701 .48433 .5413 .4952 .53835 .48911 .53413 Mtetra
.632 .807 .966 r
.48911 .53413 .4952 .53835 .50612 .53535 .50007 .53118 Mtetra
.635 .81 .967 r
.50007 .53118 .50612 .53535 .51709 .53228 .51107 .52814 Mtetra
.637 .813 .967 r
.51107 .52814 .51709 .53228 .5281 .52913 .52212 .52503 Mtetra
.64 .816 .967 r
.52212 .52503 .5281 .52913 .53916 .52591 .53321 .52181 Mtetra
.644 .818 .967 r
.53321 .52181 .53916 .52591 .55026 .52261 .54435 .51851 Mtetra
.648 .82 .966 r
.54435 .51851 .55026 .52261 .56141 .51922 .55554 .5151 Mtetra
.652 .821 .965 r
.55554 .5151 .56141 .51922 .57261 .51574 .56677 .51158 Mtetra
.656 .822 .963 r
.56677 .51158 .57261 .51574 .58384 .51218 .57804 .50797 Mtetra
.66 .822 .961 r
.57804 .50797 .58384 .51218 .59512 .50854 .58936 .50426 Mtetra
.664 .821 .959 r
.58936 .50426 .59512 .50854 .60644 .50482 .60072 .50045 Mtetra
.668 .819 .956 r
.60072 .50045 .60644 .50482 .61781 .50102 .61212 .49655 Mtetra
.672 .817 .953 r
.61212 .49655 .61781 .50102 .62922 .49715 .62356 .49257 Mtetra
.674 .815 .951 r
.62356 .49257 .62922 .49715 .64067 .49322 .63505 .48852 Mtetra
.677 .812 .948 r
.63505 .48852 .64067 .49322 .65216 .48923 .64658 .48441 Mtetra
.679 .809 .945 r
.64658 .48441 .65216 .48923 .66369 .4852 .65815 .48024 Mtetra
.681 .805 .941 r
.65815 .48024 .66369 .4852 .67527 .48113 .66976 .47603 Mtetra
.682 .801 .939 r
.66976 .47603 .67527 .48113 .6869 .47703 .68142 .47179 Mtetra
.682 .797 .936 r
.68142 .47179 .6869 .47703 .69856 .47291 .69312 .46752 Mtetra
.683 .793 .933 r
.69312 .46752 .69856 .47291 .71027 .46877 .70486 .46325 Mtetra
.682 .788 .93 r
.70486 .46325 .71027 .46877 .72203 .46463 .71665 .45897 Mtetra
.682 .784 .928 r
.71665 .45897 .72203 .46463 .73383 .46049 .72848 .45469 Mtetra
.681 .78 .925 r
.72848 .45469 .73383 .46049 .74568 .45636 .74036 .45042 Mtetra
.68 .776 .923 r
.74036 .45042 .74568 .45636 .75758 .45223 .75229 .44617 Mtetra
.679 .772 .921 r
.75229 .44617 .75758 .45223 .76952 .44812 .76427 .44193 Mtetra
.678 .769 .919 r
.76427 .44193 .76952 .44812 .78152 .44402 .7763 .43772 Mtetra
.677 .765 .918 r
.7763 .43772 .78152 .44402 .79356 .43994 .78838 .43353 Mtetra
.676 .762 .916 r
.78838 .43353 .79356 .43994 .80566 .43588 .8005 .42937 Mtetra
.674 .76 .915 r
.8005 .42937 .80566 .43588 .81781 .43183 .81269 .42523 Mtetra
.673 .757 .914 r
.81269 .42523 .81781 .43183 .83001 .4278 .82492 .42111 Mtetra
.672 .755 .913 r
.82492 .42111 .83001 .4278 .84226 .42379 .8372 .41702 Mtetra
.671 .753 .912 r
.8372 .41702 .84226 .42379 .85456 .41979 .84954 .41294 Mtetra
.67 .751 .911 r
.84954 .41294 .85456 .41979 .86692 .41579 .86194 .40888 Mtetra
.669 .749 .911 r
.86194 .40888 .86692 .41579 .87934 .41181 .87439 .40484 Mtetra
.668 .748 .91 r
.87439 .40484 .87934 .41181 .8918 .40783 .88689 .4008 Mtetra
.667 .747 .91 r
.88689 .4008 .8918 .40783 .90433 .40386 .89945 .39677 Mtetra
.667 .746 .909 r
.89945 .39677 .90433 .40386 .9169 .39989 .91207 .39275 Mtetra
.666 .745 .909 r
.91207 .39275 .9169 .39989 .92954 .39591 .92474 .38873 Mtetra
.666 .744 .909 r
.92474 .38873 .92954 .39591 .94222 .39193 .93746 .38471 Mtetra
.635 .765 .941 r
.35483 .56179 .36129 .56687 .3717 .56415 .36525 .55915 Mtetra
.633 .769 .945 r
.36525 .55915 .3717 .56415 .38215 .56145 .37573 .55654 Mtetra
.63 .772 .949 r
.37573 .55654 .38215 .56145 .39264 .55876 .38624 .55395 Mtetra
.627 .776 .952 r
.38624 .55395 .39264 .55876 .40318 .55608 .3968 .55138 Mtetra
.625 .781 .956 r
.3968 .55138 .40318 .55608 .41376 .55341 .4074 .54882 Mtetra
.623 .785 .959 r
.4074 .54882 .41376 .55341 .42438 .55073 .41806 .54625 Mtetra
.621 .79 .963 r
.41806 .54625 .42438 .55073 .43505 .54805 .42875 .54368 Mtetra
.619 .794 .966 r
.42875 .54368 .43505 .54805 .44577 .54534 .4395 .54108 Mtetra
.619 .799 .969 r
.4395 .54108 .44577 .54534 .45654 .54261 .45029 .53845 Mtetra
.618 .804 .971 r
.45029 .53845 .45654 .54261 .46735 .53984 .46114 .53577 Mtetra
.619 .809 .973 r
.46114 .53577 .46735 .53984 .47821 .53701 .47203 .53303 Mtetra
.62 .814 .975 r
.47203 .53303 .47821 .53701 .48911 .53413 .48297 .53022 Mtetra
.622 .818 .976 r
.48297 .53022 .48911 .53413 .50007 .53118 .49396 .52733 Mtetra
.625 .822 .976 r
.49396 .52733 .50007 .53118 .51107 .52814 .50499 .52435 Mtetra
.628 .826 .977 r
.50499 .52435 .51107 .52814 .52212 .52503 .51608 .52127 Mtetra
.632 .829 .976 r
.51608 .52127 .52212 .52503 .53321 .52181 .52721 .51807 Mtetra
.637 .832 .976 r
.52721 .51807 .53321 .52181 .54435 .51851 .53839 .51476 Mtetra
.642 .834 .974 r
.53839 .51476 .54435 .51851 .55554 .5151 .54961 .51132 Mtetra
.647 .836 .973 r
.54961 .51132 .55554 .5151 .56677 .51158 .56088 .50777 Mtetra
.653 .836 .971 r
.56088 .50777 .56677 .51158 .57804 .50797 .57219 .5041 Mtetra
.658 .836 .968 r
.57219 .5041 .57804 .50797 .58936 .50426 .58355 .50031 Mtetra
.663 .835 .966 r
.58355 .50031 .58936 .50426 .60072 .50045 .59495 .4964 Mtetra
.668 .834 .963 r
.59495 .4964 .60072 .50045 .61212 .49655 .60639 .49239 Mtetra
.672 .831 .96 r
.60639 .49239 .61212 .49655 .62356 .49257 .61787 .48829 Mtetra
.676 .828 .956 r
.61787 .48829 .62356 .49257 .63505 .48852 .62939 .4841 Mtetra
.68 .825 .953 r
.62939 .4841 .63505 .48852 .64658 .48441 .64096 .47984 Mtetra
.682 .821 .95 r
.64096 .47984 .64658 .48441 .65815 .48024 .65256 .47552 Mtetra
.684 .816 .946 r
.65256 .47552 .65815 .48024 .66976 .47603 .66421 .47115 Mtetra
.686 .812 .943 r
.66421 .47115 .66976 .47603 .68142 .47179 .6759 .46674 Mtetra
.686 .807 .939 r
.6759 .46674 .68142 .47179 .69312 .46752 .68764 .46231 Mtetra
.687 .802 .936 r
.68764 .46231 .69312 .46752 .70486 .46325 .69941 .45787 Mtetra
.687 .797 .933 r
.69941 .45787 .70486 .46325 .71665 .45897 .71123 .45343 Mtetra
.686 .792 .93 r
.71123 .45343 .71665 .45897 .72848 .45469 .7231 .44899 Mtetra
.685 .787 .927 r
.7231 .44899 .72848 .45469 .74036 .45042 .73501 .44457 Mtetra
.684 .782 .925 r
.73501 .44457 .74036 .45042 .75229 .44617 .74697 .44018 Mtetra
.683 .778 .923 r
.74697 .44018 .75229 .44617 .76427 .44193 .75898 .4358 Mtetra
.681 .774 .921 r
.75898 .4358 .76427 .44193 .7763 .43772 .77104 .43146 Mtetra
.68 .77 .919 r
.77104 .43146 .7763 .43772 .78838 .43353 .78315 .42715 Mtetra
.678 .766 .917 r
.78315 .42715 .78838 .43353 .8005 .42937 .79531 .42288 Mtetra
.677 .763 .916 r
.79531 .42288 .8005 .42937 .81269 .42523 .80753 .41863 Mtetra
.675 .76 .914 r
.80753 .41863 .81269 .42523 .82492 .42111 .81979 .41442 Mtetra
.674 .757 .913 r
.81979 .41442 .82492 .42111 .8372 .41702 .83211 .41024 Mtetra
.673 .755 .912 r
.83211 .41024 .8372 .41702 .84954 .41294 .84449 .40608 Mtetra
.671 .753 .912 r
.84449 .40608 .84954 .41294 .86194 .40888 .85692 .40195 Mtetra
.67 .751 .911 r
.85692 .40195 .86194 .40888 .87439 .40484 .8694 .39783 Mtetra
.669 .749 .91 r
.8694 .39783 .87439 .40484 .88689 .4008 .88194 .39373 Mtetra
.668 .748 .91 r
.88194 .39373 .88689 .4008 .89945 .39677 .89454 .38965 Mtetra
.667 .747 .909 r
.89454 .38965 .89945 .39677 .91207 .39275 .90719 .38557 Mtetra
.667 .746 .909 r
.90719 .38557 .91207 .39275 .92474 .38873 .9199 .3815 Mtetra
.666 .745 .909 r
.9199 .3815 .92474 .38873 .93746 .38471 .93266 .37743 Mtetra
.628 .769 .948 r
.3483 .55682 .35483 .56179 .36525 .55915 .35875 .55429 Mtetra
.624 .773 .952 r
.35875 .55429 .36525 .55915 .37573 .55654 .36924 .5518 Mtetra
.621 .778 .956 r
.36924 .5518 .37573 .55654 .38624 .55395 .37978 .54933 Mtetra
.617 .782 .96 r
.37978 .54933 .38624 .55395 .3968 .55138 .39036 .54689 Mtetra
.614 .787 .964 r
.39036 .54689 .3968 .55138 .4074 .54882 .40099 .54445 Mtetra
.611 .792 .968 r
.40099 .54445 .4074 .54882 .41806 .54625 .41167 .54202 Mtetra
.608 .797 .972 r
.41167 .54202 .41806 .54625 .42875 .54368 .42239 .53957 Mtetra
.606 .803 .975 r
.42239 .53957 .42875 .54368 .4395 .54108 .43317 .5371 Mtetra
.604 .808 .978 r
.43317 .5371 .4395 .54108 .45029 .53845 .44399 .53459 Mtetra
.604 .814 .981 r
.44399 .53459 .45029 .53845 .46114 .53577 .45486 .53203 Mtetra
.604 .819 .983 r
.45486 .53203 .46114 .53577 .47203 .53303 .46579 .5294 Mtetra
.605 .825 .984 r
.46579 .5294 .47203 .53303 .48297 .53022 .47676 .52668 Mtetra
.608 .83 .985 r
.47676 .52668 .48297 .53022 .49396 .52733 .48779 .52387 Mtetra
.611 .835 .985 r
.48779 .52387 .49396 .52733 .50499 .52435 .49886 .52094 Mtetra
.615 .839 .985 r
.49886 .52094 .50499 .52435 .51608 .52127 .50998 .5179 Mtetra
.62 .843 .985 r
.50998 .5179 .51608 .52127 .52721 .51807 .52115 .51472 Mtetra
.627 .847 .984 r
.52115 .51472 .52721 .51807 .53839 .51476 .53237 .51141 Mtetra
.633 .849 .982 r
.53237 .51141 .53839 .51476 .54961 .51132 .54363 .50795 Mtetra
.64 .851 .981 r
.54363 .50795 .54961 .51132 .56088 .50777 .55494 .50435 Mtetra
.647 .852 .978 r
.55494 .50435 .56088 .50777 .57219 .5041 .5663 .50061 Mtetra
.654 .852 .976 r
.5663 .50061 .57219 .5041 .58355 .50031 .57769 .49673 Mtetra
.661 .851 .973 r
.57769 .49673 .58355 .50031 .59495 .4964 .58913 .49271 Mtetra
.667 .849 .969 r
.58913 .49271 .59495 .4964 .60639 .49239 .60061 .48858 Mtetra
.673 .847 .966 r
.60061 .48858 .60639 .49239 .61787 .48829 .61214 .48433 Mtetra
.678 .843 .962 r
.61214 .48433 .61787 .48829 .62939 .4841 .6237 .47999 Mtetra
.682 .839 .959 r
.6237 .47999 .62939 .4841 .64096 .47984 .6353 .47556 Mtetra
.686 .834 .955 r
.6353 .47556 .64096 .47984 .65256 .47552 .64694 .47106 Mtetra
.688 .829 .951 r
.64694 .47106 .65256 .47552 .66421 .47115 .65863 .4665 Mtetra
.69 .824 .947 r
.65863 .4665 .66421 .47115 .6759 .46674 .67035 .46191 Mtetra
.691 .818 .943 r
.67035 .46191 .6759 .46674 .68764 .46231 .68212 .45729 Mtetra
.691 .812 .94 r
.68212 .45729 .68764 .46231 .69941 .45787 .69393 .45267 Mtetra
.691 .806 .936 r
.69393 .45267 .69941 .45787 .71123 .45343 .70578 .44804 Mtetra
.691 .8 .933 r
.70578 .44804 .71123 .45343 .7231 .44899 .71768 .44343 Mtetra
.69 .794 .93 r
.71768 .44343 .7231 .44899 .73501 .44457 .72963 .43883 Mtetra
.688 .789 .927 r
.72963 .43883 .73501 .44457 .74697 .44018 .74162 .43427 Mtetra
.687 .784 .924 r
.74162 .43427 .74697 .44018 .75898 .4358 .75366 .42975 Mtetra
.685 .779 .922 r
.75366 .42975 .75898 .4358 .77104 .43146 .76575 .42526 Mtetra
.683 .774 .92 r
.76575 .42526 .77104 .43146 .78315 .42715 .77789 .42081 Mtetra
.681 .77 .918 r
.77789 .42081 .78315 .42715 .79531 .42288 .79009 .41641 Mtetra
.679 .766 .917 r
.79009 .41641 .79531 .42288 .80753 .41863 .80233 .41205 Mtetra
.678 .763 .915 r
.80233 .41205 .80753 .41863 .81979 .41442 .81463 .40773 Mtetra
.676 .76 .914 r
.81463 .40773 .81979 .41442 .83211 .41024 .82698 .40345 Mtetra
.674 .757 .913 r
.82698 .40345 .83211 .41024 .84449 .40608 .83939 .3992 Mtetra
.673 .754 .912 r
.83939 .3992 .84449 .40608 .85692 .40195 .85186 .39499 Mtetra
.671 .752 .911 r
.85186 .39499 .85692 .40195 .8694 .39783 .86438 .3908 Mtetra
.67 .75 .911 r
.86438 .3908 .8694 .39783 .88194 .39373 .87695 .38663 Mtetra
.669 .749 .91 r
.87695 .38663 .88194 .39373 .89454 .38965 .88959 .38248 Mtetra
.668 .747 .91 r
.88959 .38248 .89454 .38965 .90719 .38557 .90228 .37835 Mtetra
.667 .746 .909 r
.90228 .37835 .90719 .38557 .9199 .3815 .91502 .37422 Mtetra
.667 .745 .909 r
.91502 .37422 .9199 .3815 .93266 .37743 .92783 .3701 Mtetra
.618 .774 .955 r
.34171 .55199 .3483 .55682 .35875 .55429 .35218 .54959 Mtetra
.614 .778 .96 r
.35218 .54959 .35875 .55429 .36924 .5518 .36269 .54724 Mtetra
.609 .783 .964 r
.36269 .54724 .36924 .5518 .37978 .54933 .37325 .54492 Mtetra
.604 .788 .969 r
.37325 .54492 .37978 .54933 .39036 .54689 .38386 .54262 Mtetra
.599 .794 .974 r
.38386 .54262 .39036 .54689 .40099 .54445 .39451 .54034 Mtetra
.595 .799 .978 r
.39451 .54034 .40099 .54445 .41167 .54202 .40521 .53806 Mtetra
.591 .805 .981 r
.40521 .53806 .41167 .54202 .42239 .53957 .41596 .53577 Mtetra
.588 .811 .985 r
.41596 .53577 .42239 .53957 .43317 .5371 .42677 .53345 Mtetra
.586 .818 .988 r
.42677 .53345 .43317 .5371 .44399 .53459 .43762 .53109 Mtetra
.584 .824 .99 r
.43762 .53109 .44399 .53459 .45486 .53203 .44853 .52866 Mtetra
.584 .83 .991 r
.44853 .52866 .45486 .53203 .46579 .5294 .45948 .52615 Mtetra
.585 .836 .992 r
.45948 .52615 .46579 .5294 .47676 .52668 .47049 .52354 Mtetra
.588 .842 .993 r
.47049 .52354 .47676 .52668 .48779 .52387 .48155 .52082 Mtetra
.592 .848 .993 r
.48155 .52082 .48779 .52387 .49886 .52094 .49266 .51797 Mtetra
.597 .853 .992 r
.49266 .51797 .49886 .52094 .50998 .5179 .50383 .51497 Mtetra
.604 .858 .992 r
.50383 .51497 .50998 .5179 .52115 .51472 .51504 .51181 Mtetra
.612 .862 .99 r
.51504 .51181 .52115 .51472 .53237 .51141 .5263 .5085 Mtetra
.621 .865 .989 r
.5263 .5085 .53237 .51141 .54363 .50795 .5376 .50502 Mtetra
.63 .867 .987 r
.5376 .50502 .54363 .50795 .55494 .50435 .54896 .50136 Mtetra
.639 .869 .984 r
.54896 .50136 .55494 .50435 .5663 .50061 .56035 .49754 Mtetra
.649 .869 .982 r
.56035 .49754 .5663 .50061 .57769 .49673 .57179 .49356 Mtetra
.658 .868 .979 r
.57179 .49356 .57769 .49673 .58913 .49271 .58327 .48943 Mtetra
.666 .866 .975 r
.58327 .48943 .58913 .49271 .60061 .48858 .59479 .48515 Mtetra
.673 .863 .972 r
.59479 .48515 .60061 .48858 .61214 .48433 .60636 .48074 Mtetra
.68 .86 .968 r
.60636 .48074 .61214 .48433 .6237 .47999 .61796 .47621 Mtetra
.685 .855 .964 r
.61796 .47621 .6237 .47999 .6353 .47556 .6296 .47159 Mtetra
.69 .849 .959 r
.6296 .47159 .6353 .47556 .64694 .47106 .64128 .46689 Mtetra
.693 .843 .955 r
.64128 .46689 .64694 .47106 .65863 .4665 .653 .46213 Mtetra
.695 .837 .951 r
.653 .46213 .65863 .4665 .67035 .46191 .66477 .45732 Mtetra
.696 .83 .947 r
.66477 .45732 .67035 .46191 .68212 .45729 .67657 .45249 Mtetra
.697 .823 .943 r
.67657 .45249 .68212 .45729 .69393 .45267 .68841 .44765 Mtetra
.697 .816 .939 r
.68841 .44765 .69393 .45267 .70578 .44804 .7003 .44281 Mtetra
.696 .809 .935 r
.7003 .44281 .70578 .44804 .71768 .44343 .71223 .438 Mtetra
.695 .803 .932 r
.71223 .438 .71768 .44343 .72963 .43883 .72421 .43321 Mtetra
.693 .796 .929 r
.72421 .43321 .72963 .43883 .74162 .43427 .73623 .42847 Mtetra
.691 .79 .926 r
.73623 .42847 .74162 .43427 .75366 .42975 .7483 .42376 Mtetra
.689 .785 .924 r
.7483 .42376 .75366 .42975 .76575 .42526 .76043 .41911 Mtetra
.687 .779 .921 r
.76043 .41911 .76575 .42526 .77789 .42081 .7726 .41452 Mtetra
.685 .775 .919 r
.7726 .41452 .77789 .42081 .79009 .41641 .78482 .40997 Mtetra
.683 .77 .917 r
.78482 .40997 .79009 .41641 .80233 .41205 .7971 .40548 Mtetra
.68 .766 .916 r
.7971 .40548 .80233 .41205 .81463 .40773 .80943 .40104 Mtetra
.678 .762 .915 r
.80943 .40104 .81463 .40773 .82698 .40345 .82182 .39665 Mtetra
.676 .759 .913 r
.82182 .39665 .82698 .40345 .83939 .3992 .83426 .39231 Mtetra
.675 .756 .912 r
.83426 .39231 .83939 .3992 .85186 .39499 .84676 .388 Mtetra
.673 .754 .912 r
.84676 .388 .85186 .39499 .86438 .3908 .85932 .38373 Mtetra
.672 .752 .911 r
.85932 .38373 .86438 .3908 .87695 .38663 .87193 .37949 Mtetra
.67 .75 .91 r
.87193 .37949 .87695 .38663 .88959 .38248 .8846 .37528 Mtetra
.669 .748 .91 r
.8846 .37528 .88959 .38248 .90228 .37835 .89732 .37108 Mtetra
.668 .747 .909 r
.89732 .37108 .90228 .37835 .91502 .37422 .91011 .3669 Mtetra
.667 .746 .909 r
.91011 .3669 .91502 .37422 .92783 .3701 .92295 .36273 Mtetra
.607 .778 .963 r
.33506 .54733 .34171 .55199 .35218 .54959 .34555 .54508 Mtetra
.6 .783 .968 r
.34555 .54508 .35218 .54959 .36269 .54724 .35608 .54289 Mtetra
.594 .789 .973 r
.35608 .54289 .36269 .54724 .37325 .54492 .36666 .54074 Mtetra
.587 .794 .978 r
.36666 .54074 .37325 .54492 .38386 .54262 .37729 .53862 Mtetra
.581 .8 .983 r
.37729 .53862 .38386 .54262 .39451 .54034 .38796 .53652 Mtetra
.574 .806 .987 r
.38796 .53652 .39451 .54034 .40521 .53806 .39869 .53443 Mtetra
.569 .812 .99 r
.39869 .53443 .40521 .53806 .41596 .53577 .40947 .53232 Mtetra
.564 .819 .993 r
.40947 .53232 .41596 .53577 .42677 .53345 .4203 .53017 Mtetra
.56 .825 .995 r
.4203 .53017 .42677 .53345 .43762 .53109 .43118 .52798 Mtetra
.558 .832 .997 r
.43118 .52798 .43762 .53109 .44853 .52866 .44212 .5257 Mtetra
.557 .839 .998 r
.44212 .5257 .44853 .52866 .45948 .52615 .45311 .52334 Mtetra
.558 .845 .998 r
.45311 .52334 .45948 .52615 .47049 .52354 .46415 .52085 Mtetra
.561 .852 .997 r
.46415 .52085 .47049 .52354 .48155 .52082 .47525 .51823 Mtetra
.566 .858 .997 r
.47525 .51823 .48155 .52082 .49266 .51797 .4864 .51546 Mtetra
.573 .864 .996 r
.4864 .51546 .49266 .51797 .50383 .51497 .49761 .51252 Mtetra
.582 .87 .995 r
.49761 .51252 .50383 .51497 .51504 .51181 .50886 .5094 Mtetra
.592 .875 .993 r
.50886 .5094 .51504 .51181 .5263 .5085 .52016 .50608 Mtetra
.604 .88 .992 r
.52016 .50608 .5263 .5085 .5376 .50502 .53151 .50257 Mtetra
.616 .883 .99 r
.53151 .50257 .5376 .50502 .54896 .50136 .54291 .49886 Mtetra
.628 .885 .988 r
.54291 .49886 .54896 .50136 .56035 .49754 .55435 .49495 Mtetra
.641 .886 .985 r
.55435 .49495 .56035 .49754 .57179 .49356 .56584 .49085 Mtetra
.652 .886 .982 r
.56584 .49085 .57179 .49356 .58327 .48943 .57736 .48657 Mtetra
.663 .884 .979 r
.57736 .48657 .58327 .48943 .59479 .48515 .58893 .48213 Mtetra
.673 .881 .976 r
.58893 .48213 .59479 .48515 .60636 .48074 .60053 .47753 Mtetra
.681 .877 .972 r
.60053 .47753 .60636 .48074 .61796 .47621 .61218 .4728 Mtetra
.688 .871 .968 r
.61218 .4728 .61796 .47621 .6296 .47159 .62386 .46796 Mtetra
.694 .865 .963 r
.62386 .46796 .6296 .47159 .64128 .46689 .63558 .46303 Mtetra
.698 .858 .959 r
.63558 .46303 .64128 .46689 .653 .46213 .64734 .45803 Mtetra
.701 .851 .954 r
.64734 .45803 .653 .46213 .66477 .45732 .65914 .45299 Mtetra
.703 .843 .95 r
.65914 .45299 .66477 .45732 .67657 .45249 .67098 .44792 Mtetra
.703 .835 .946 r
.67098 .44792 .67657 .45249 .68841 .44765 .68286 .44284 Mtetra
.703 .827 .941 r
.68286 .44284 .68841 .44765 .7003 .44281 .69478 .43777 Mtetra
.702 .819 .938 r
.69478 .43777 .7003 .44281 .71223 .438 .70674 .43273 Mtetra
.701 .812 .934 r
.70674 .43273 .71223 .438 .72421 .43321 .71875 .42772 Mtetra
.699 .804 .931 r
.71875 .42772 .72421 .43321 .73623 .42847 .73081 .42277 Mtetra
.696 .798 .928 r
.73081 .42277 .73623 .42847 .7483 .42376 .74291 .41787 Mtetra
.694 .791 .925 r
.74291 .41787 .7483 .42376 .76043 .41911 .75506 .41304 Mtetra
.691 .785 .922 r
.75506 .41304 .76043 .41911 .7726 .41452 .76727 .40827 Mtetra
.689 .779 .92 r
.76727 .40827 .7726 .41452 .78482 .40997 .77952 .40357 Mtetra
.686 .774 .918 r
.77952 .40357 .78482 .40997 .7971 .40548 .79183 .39894 Mtetra
.683 .77 .917 r
.79183 .39894 .7971 .40548 .80943 .40104 .8042 .39437 Mtetra
.681 .765 .915 r
.8042 .39437 .80943 .40104 .82182 .39665 .81662 .38986 Mtetra
.679 .762 .914 r
.81662 .38986 .82182 .39665 .83426 .39231 .82909 .3854 Mtetra
.677 .759 .913 r
.82909 .3854 .83426 .39231 .84676 .388 .84163 .381 Mtetra
.675 .756 .912 r
.84163 .381 .84676 .388 .85932 .38373 .85422 .37664 Mtetra
.673 .753 .911 r
.85422 .37664 .85932 .38373 .87193 .37949 .86686 .37232 Mtetra
.671 .751 .91 r
.86686 .37232 .87193 .37949 .8846 .37528 .87957 .36803 Mtetra
.67 .749 .91 r
.87957 .36803 .8846 .37528 .89732 .37108 .89233 .36377 Mtetra
.669 .748 .909 r
.89233 .36377 .89732 .37108 .91011 .3669 .90516 .35953 Mtetra
.668 .747 .909 r
.90516 .35953 .91011 .3669 .92295 .36273 .91804 .3553 Mtetra
.592 .783 .971 r
.32834 .54285 .33506 .54733 .34555 .54508 .33885 .54078 Mtetra
.583 .788 .977 r
.33885 .54078 .34555 .54508 .35608 .54289 .3494 .53877 Mtetra
.574 .794 .982 r
.3494 .53877 .35608 .54289 .36666 .54074 .36 .53682 Mtetra
.565 .799 .987 r
.36 .53682 .36666 .54074 .37729 .53862 .37064 .53491 Mtetra
.556 .805 .991 r
.37064 .53491 .37729 .53862 .38796 .53652 .38134 .53302 Mtetra
.547 .812 .995 r
.38134 .53302 .38796 .53652 .39869 .53443 .39209 .53113 Mtetra
.539 .818 .997 r
.39209 .53113 .39869 .53443 .40947 .53232 .40289 .52923 Mtetra
.531 .824 .999 r
.40289 .52923 .40947 .53232 .4203 .53017 .41375 .52729 Mtetra
.525 .83 1 r
.41375 .52729 .4203 .53017 .43118 .52798 .42467 .52529 Mtetra
.521 .837 .999 r
.42467 .52529 .43118 .52798 .44212 .5257 .43564 .5232 Mtetra
.52 .844 .998 r
.43564 .5232 .44212 .5257 .45311 .52334 .44666 .52099 Mtetra
.52 .85 .997 r
.44666 .52099 .45311 .52334 .46415 .52085 .45774 .51865 Mtetra
.524 .857 .995 r
.45774 .51865 .46415 .52085 .47525 .51823 .46888 .51615 Mtetra
.53 .865 .994 r
.46888 .51615 .47525 .51823 .4864 .51546 .48007 .51347 Mtetra
.539 .872 .992 r
.48007 .51347 .4864 .51546 .49761 .51252 .49132 .51059 Mtetra
.551 .879 .991 r
.49132 .51059 .49761 .51252 .50886 .5094 .50262 .5075 Mtetra
.565 .885 .99 r
.50262 .5075 .50886 .5094 .52016 .50608 .51397 .50419 Mtetra
.58 .891 .989 r
.51397 .50419 .52016 .50608 .53151 .50257 .52536 .50064 Mtetra
.596 .896 .988 r
.52536 .50064 .53151 .50257 .54291 .49886 .53681 .49686 Mtetra
.613 .9 .987 r
.53681 .49686 .54291 .49886 .55435 .49495 .54829 .49285 Mtetra
.629 .902 .985 r
.54829 .49285 .55435 .49495 .56584 .49085 .55983 .48862 Mtetra
.644 .903 .983 r
.55983 .48862 .56584 .49085 .57736 .48657 .5714 .48419 Mtetra
.659 .901 .981 r
.5714 .48419 .57736 .48657 .58893 .48213 .58301 .47955 Mtetra
.671 .899 .978 r
.58301 .47955 .58893 .48213 .60053 .47753 .59466 .47475 Mtetra
.682 .894 .974 r
.59466 .47475 .60053 .47753 .61218 .4728 .60635 .46979 Mtetra
.691 .889 .97 r
.60635 .46979 .61218 .4728 .62386 .46796 .61808 .4647 Mtetra
.698 .882 .966 r
.61808 .4647 .62386 .46796 .63558 .46303 .62984 .45952 Mtetra
.704 .874 .961 r
.62984 .45952 .63558 .46303 .64734 .45803 .64164 .45425 Mtetra
.707 .866 .957 r
.64164 .45425 .64734 .45803 .65914 .45299 .65347 .44894 Mtetra
.71 .857 .952 r
.65347 .44894 .65914 .45299 .67098 .44792 .66535 .44359 Mtetra
.71 .848 .948 r
.66535 .44359 .67098 .44792 .68286 .44284 .67726 .43825 Mtetra
.71 .839 .944 r
.67726 .43825 .68286 .44284 .69478 .43777 .68922 .43292 Mtetra
.709 .83 .939 r
.68922 .43292 .69478 .43777 .70674 .43273 .70121 .42762 Mtetra
.707 .821 .936 r
.70121 .42762 .70674 .43273 .71875 .42772 .71326 .42237 Mtetra
.705 .813 .932 r
.71326 .42237 .71875 .42772 .73081 .42277 .72534 .41719 Mtetra
.702 .805 .929 r
.72534 .41719 .73081 .42277 .74291 .41787 .73748 .41207 Mtetra
.699 .798 .926 r
.73748 .41207 .74291 .41787 .75506 .41304 .74966 .40704 Mtetra
.696 .791 .923 r
.74966 .40704 .75506 .41304 .76727 .40827 .7619 .40208 Mtetra
.693 .784 .921 r
.7619 .40208 .76727 .40827 .77952 .40357 .77419 .39721 Mtetra
.69 .779 .919 r
.77419 .39721 .77952 .40357 .79183 .39894 .78653 .39241 Mtetra
.687 .773 .917 r
.78653 .39241 .79183 .39894 .8042 .39437 .79892 .3877 Mtetra
.684 .769 .915 r
.79892 .3877 .8042 .39437 .81662 .38986 .81138 .38306 Mtetra
.681 .765 .914 r
.81138 .38306 .81662 .38986 .82909 .3854 .82388 .37849 Mtetra
.679 .761 .913 r
.82388 .37849 .82909 .3854 .84163 .381 .83645 .37398 Mtetra
.677 .758 .912 r
.83645 .37398 .84163 .381 .85422 .37664 .84908 .36952 Mtetra
.675 .755 .911 r
.84908 .36952 .85422 .37664 .86686 .37232 .86176 .36511 Mtetra
.673 .753 .911 r
.86176 .36511 .86686 .37232 .87957 .36803 .8745 .36075 Mtetra
.671 .75 .91 r
.8745 .36075 .87957 .36803 .89233 .36377 .88731 .35641 Mtetra
.67 .749 .91 r
.88731 .35641 .89233 .36377 .90516 .35953 .90017 .35211 Mtetra
.669 .747 .909 r
.90017 .35211 .90516 .35953 .91804 .3553 .91309 .34782 Mtetra
.573 .786 .98 r
.32155 .53856 .32834 .54285 .33885 .54078 .33207 .5367 Mtetra
.561 .792 .985 r
.33207 .5367 .33885 .54078 .3494 .53877 .34264 .53492 Mtetra
.549 .797 .991 r
.34264 .53492 .3494 .53877 .36 .53682 .35326 .53319 Mtetra
.536 .803 .995 r
.35326 .53319 .36 .53682 .37064 .53491 .36392 .53151 Mtetra
.523 .808 .998 r
.36392 .53151 .37064 .53491 .38134 .53302 .37464 .52986 Mtetra
.511 .814 1 r
.37464 .52986 .38134 .53302 .39209 .53113 .38542 .52822 Mtetra
.499 .819 1 r
.38542 .52822 .39209 .53113 .40289 .52923 .39624 .52655 Mtetra
.488 .824 .999 r
.39624 .52655 .40289 .52923 .41375 .52729 .40713 .52484 Mtetra
.479 .829 .997 r
.40713 .52484 .41375 .52729 .42467 .52529 .41807 .52306 Mtetra
.473 .835 .994 r
.41807 .52306 .42467 .52529 .43564 .5232 .42908 .52117 Mtetra
.47 .841 .99 r
.42908 .52117 .43564 .5232 .44666 .52099 .44014 .51916 Mtetra
.47 .847 .986 r
.44014 .51916 .44666 .52099 .45774 .51865 .45126 .51698 Mtetra
.474 .855 .983 r
.45126 .51698 .45774 .51865 .46888 .51615 .46243 .51461 Mtetra
.482 .863 .98 r
.46243 .51461 .46888 .51615 .48007 .51347 .47367 .51204 Mtetra
.494 .871 .978 r
.47367 .51204 .48007 .51347 .49132 .51059 .48496 .50923 Mtetra
.51 .88 .977 r
.48496 .50923 .49132 .51059 .50262 .5075 .4963 .50617 Mtetra
.528 .889 .977 r
.4963 .50617 .50262 .5075 .51397 .50419 .5077 .50285 Mtetra
.548 .897 .977 r
.5077 .50285 .51397 .50419 .52536 .50064 .51915 .49927 Mtetra
.57 .905 .978 r
.51915 .49927 .52536 .50064 .53681 .49686 .53064 .49541 Mtetra
.592 .911 .979 r
.53064 .49541 .53681 .49686 .54829 .49285 .54218 .49129 Mtetra
.613 .915 .979 r
.54218 .49129 .54829 .49285 .55983 .48862 .55376 .48691 Mtetra
.633 .918 .979 r
.55376 .48691 .55983 .48862 .5714 .48419 .56538 .48229 Mtetra
.652 .918 .978 r
.56538 .48229 .5714 .48419 .58301 .47955 .57704 .47745 Mtetra
.669 .916 .976 r
.57704 .47745 .58301 .47955 .59466 .47475 .58874 .47241 Mtetra
.683 .912 .974 r
.58874 .47241 .59466 .47475 .60635 .46979 .60047 .46719 Mtetra
.694 .906 .971 r
.60047 .46719 .60635 .46979 .61808 .4647 .61224 .46183 Mtetra
.703 .899 .967 r
.61224 .46183 .61808 .4647 .62984 .45952 .62405 .45635 Mtetra
.71 .89 .963 r
.62405 .45635 .62984 .45952 .64164 .45425 .63589 .45079 Mtetra
.714 .881 .958 r
.63589 .45079 .64164 .45425 .65347 .44894 .64776 .44517 Mtetra
.717 .871 .954 r
.64776 .44517 .65347 .44894 .66535 .44359 .65968 .43953 Mtetra
.718 .861 .949 r
.65968 .43953 .66535 .44359 .67726 .43825 .67163 .43388 Mtetra
.718 .851 .945 r
.67163 .43388 .67726 .43825 .68922 .43292 .68362 .42826 Mtetra
.717 .841 .941 r
.68362 .42826 .68922 .43292 .70121 .42762 .69565 .42268 Mtetra
.715 .831 .937 r
.69565 .42268 .70121 .42762 .71326 .42237 .70772 .41717 Mtetra
.712 .822 .933 r
.70772 .41717 .71326 .42237 .72534 .41719 .71984 .41172 Mtetra
.709 .813 .93 r
.71984 .41172 .72534 .41719 .73748 .41207 .73201 .40637 Mtetra
.705 .805 .927 r
.73201 .40637 .73748 .41207 .74966 .40704 .74422 .40111 Mtetra
.702 .797 .924 r
.74422 .40111 .74966 .40704 .7619 .40208 .75649 .39595 Mtetra
.698 .79 .921 r
.75649 .39595 .7619 .40208 .77419 .39721 .76881 .39088 Mtetra
.694 .783 .919 r
.76881 .39088 .77419 .39721 .78653 .39241 .78118 .38592 Mtetra
.691 .777 .917 r
.78118 .38592 .78653 .39241 .79892 .3877 .79361 .38104 Mtetra
.687 .772 .916 r
.79361 .38104 .79892 .3877 .81138 .38306 .8061 .37626 Mtetra
.684 .767 .914 r
.8061 .37626 .81138 .38306 .82388 .37849 .81864 .37156 Mtetra
.681 .763 .913 r
.81864 .37156 .82388 .37849 .83645 .37398 .83124 .36693 Mtetra
.679 .76 .912 r
.83124 .36693 .83645 .37398 .84908 .36952 .8439 .36237 Mtetra
.676 .757 .911 r
.8439 .36237 .84908 .36952 .86176 .36511 .85662 .35787 Mtetra
.674 .754 .911 r
.85662 .35787 .86176 .36511 .8745 .36075 .8694 .35342 Mtetra
.673 .752 .91 r
.8694 .35342 .8745 .36075 .88731 .35641 .88224 .34901 Mtetra
.671 .75 .91 r
.88224 .34901 .88731 .35641 .90017 .35211 .89514 .34464 Mtetra
.67 .748 .909 r
.89514 .34464 .90017 .35211 .91309 .34782 .9081 .34029 Mtetra
.548 .789 .988 r
.31469 .5345 .32155 .53856 .33207 .5367 .32522 .53288 Mtetra
.533 .794 .993 r
.32522 .53288 .33207 .5367 .34264 .53492 .33581 .53134 Mtetra
.516 .798 .997 r
.33581 .53134 .34264 .53492 .35326 .53319 .34644 .52987 Mtetra
.499 .803 .999 r
.34644 .52987 .35326 .53319 .36392 .53151 .35712 .52846 Mtetra
.481 .807 1 r
.35712 .52846 .36392 .53151 .37464 .52986 .36786 .52708 Mtetra
.463 .81 .998 r
.36786 .52708 .37464 .52986 .38542 .52822 .37866 .52571 Mtetra
.446 .813 .995 r
.37866 .52571 .38542 .52822 .39624 .52655 .38951 .52431 Mtetra
.431 .816 .989 r
.38951 .52431 .39624 .52655 .40713 .52484 .40042 .52286 Mtetra
.418 .819 .982 r
.40042 .52286 .40713 .52484 .41807 .52306 .4114 .52133 Mtetra
.409 .822 .974 r
.4114 .52133 .41807 .52306 .42908 .52117 .42243 .51967 Mtetra
.405 .826 .967 r
.42243 .51967 .42908 .52117 .44014 .51916 .43353 .51786 Mtetra
.405 .832 .959 r
.43353 .51786 .44014 .51916 .45126 .51698 .44469 .51586 Mtetra
.41 .839 .954 r
.44469 .51586 .45126 .51698 .46243 .51461 .45591 .51365 Mtetra
.421 .848 .95 r
.45591 .51365 .46243 .51461 .47367 .51204 .46719 .51119 Mtetra
.436 .859 .948 r
.46719 .51119 .47367 .51204 .48496 .50923 .47852 .50846 Mtetra
.457 .87 .948 r
.47852 .50846 .48496 .50923 .4963 .50617 .48992 .50544 Mtetra
.481 .883 .95 r
.48992 .50544 .4963 .50617 .5077 .50285 .50136 .50211 Mtetra
.507 .895 .953 r
.50136 .50211 .5077 .50285 .51915 .49927 .51286 .49848 Mtetra
.536 .906 .958 r
.51286 .49848 .51915 .49927 .53064 .49541 .5244 .49454 Mtetra
.564 .916 .962 r
.5244 .49454 .53064 .49541 .54218 .49129 .536 .49029 Mtetra
.593 .924 .965 r
.536 .49029 .54218 .49129 .55376 .48691 .54763 .48574 Mtetra
.619 .929 .968 r
.54763 .48574 .55376 .48691 .56538 .48229 .5593 .48092 Mtetra
.643 .931 .97 r
.5593 .48092 .56538 .48229 .57704 .47745 .57102 .47584 Mtetra
.664 .931 .971 r
.57102 .47584 .57704 .47745 .58874 .47241 .58276 .47053 Mtetra
.682 .928 .97 r
.58276 .47053 .58874 .47241 .60047 .46719 .59455 .46502 Mtetra
.697 .922 .968 r
.59455 .46502 .60047 .46719 .61224 .46183 .60636 .45936 Mtetra
.708 .915 .966 r
.60636 .45936 .61224 .46183 .62405 .45635 .61821 .45356 Mtetra
.716 .906 .962 r
.61821 .45356 .62405 .45635 .63589 .45079 .63009 .44766 Mtetra
.722 .896 .958 r
.63009 .44766 .63589 .45079 .64776 .44517 .64201 .44171 Mtetra
.726 .885 .954 r
.64201 .44171 .64776 .44517 .65968 .43953 .65396 .43573 Mtetra
.727 .874 .95 r
.65396 .43573 .65968 .43953 .67163 .43388 .66595 .42976 Mtetra
.727 .863 .945 r
.66595 .42976 .67163 .43388 .68362 .42826 .67798 .42381 Mtetra
.726 .852 .941 r
.67798 .42381 .68362 .42826 .69565 .42268 .69004 .41792 Mtetra
.723 .841 .937 r
.69004 .41792 .69565 .42268 .70772 .41717 .70215 .41211 Mtetra
.72 .831 .934 r
.70215 .41211 .70772 .41717 .71984 .41172 .7143 .40639 Mtetra
.716 .821 .93 r
.7143 .40639 .71984 .41172 .73201 .40637 .7265 .40077 Mtetra
.712 .812 .927 r
.7265 .40077 .73201 .40637 .74422 .40111 .73875 .39526 Mtetra
.708 .803 .924 r
.73875 .39526 .74422 .40111 .75649 .39595 .75104 .38987 Mtetra
.703 .795 .922 r
.75104 .38987 .75649 .39595 .76881 .39088 .76339 .3846 Mtetra
.699 .788 .92 r
.76339 .3846 .76881 .39088 .78118 .38592 .7758 .37944 Mtetra
.695 .782 .918 r
.7758 .37944 .78118 .38592 .79361 .38104 .78826 .3744 Mtetra
.691 .776 .916 r
.78826 .3744 .79361 .38104 .8061 .37626 .80078 .36946 Mtetra
.688 .77 .915 r
.80078 .36946 .8061 .37626 .81864 .37156 .81335 .36462 Mtetra
.684 .766 .913 r
.81335 .36462 .81864 .37156 .83124 .36693 .82599 .35987 Mtetra
.681 .762 .912 r
.82599 .35987 .83124 .36693 .8439 .36237 .83868 .3552 Mtetra
.678 .758 .911 r
.83868 .3552 .8439 .36237 .85662 .35787 .85144 .3506 Mtetra
.676 .755 .911 r
.85144 .3506 .85662 .35787 .8694 .35342 .86425 .34606 Mtetra
.674 .753 .91 r
.86425 .34606 .8694 .35342 .88224 .34901 .87713 .34157 Mtetra
.672 .751 .91 r
.87713 .34157 .88224 .34901 .89514 .34464 .89007 .33712 Mtetra
.671 .749 .909 r
.89007 .33712 .89514 .34464 .9081 .34029 .90307 .33271 Mtetra
.518 .789 .995 r
.30775 .53068 .31469 .5345 .32522 .53288 .3183 .52932 Mtetra
.497 .793 .998 r
.3183 .52932 .32522 .53288 .33581 .53134 .32889 .52806 Mtetra
.474 .795 .999 r
.32889 .52806 .33581 .53134 .34644 .52987 .33954 .52688 Mtetra
.45 .797 .998 r
.33954 .52688 .34644 .52987 .35712 .52846 .35024 .52577 Mtetra
.426 .797 .994 r
.35024 .52577 .35712 .52846 .36786 .52708 .36099 .5247 Mtetra
.401 .797 .986 r
.36099 .5247 .36786 .52708 .37866 .52571 .37181 .52363 Mtetra
.378 .796 .976 r
.37181 .52363 .37866 .52571 .38951 .52431 .38269 .52253 Mtetra
.358 .794 .964 r
.38269 .52253 .38951 .52431 .40042 .52286 .39363 .52137 Mtetra
.341 .793 .95 r
.39363 .52137 .40042 .52286 .4114 .52133 .40463 .52011 Mtetra
.329 .793 .936 r
.40463 .52011 .4114 .52133 .42243 .51967 .4157 .51871 Mtetra
.323 .795 .923 r
.4157 .51871 .42243 .51967 .43353 .51786 .42683 .51713 Mtetra
.324 .799 .913 r
.42683 .51713 .43353 .51786 .44469 .51586 .43803 .51533 Mtetra
.331 .807 .905 r
.43803 .51533 .44469 .51586 .45591 .51365 .44929 .51328 Mtetra
.345 .817 .901 r
.44929 .51328 .45591 .51365 .46719 .51119 .46062 .51094 Mtetra
.366 .831 .9 r
.46062 .51094 .46719 .51119 .47852 .50846 .472 .50829 Mtetra
.392 .846 .903 r
.472 .50829 .47852 .50846 .48992 .50544 .48345 .50531 Mtetra
.423 .864 .908 r
.48345 .50531 .48992 .50544 .50136 .50211 .49495 .50198 Mtetra
.458 .881 .916 r
.49495 .50198 .50136 .50211 .51286 .49848 .5065 .49829 Mtetra
.494 .899 .925 r
.5065 .49829 .51286 .49848 .5244 .49454 .5181 .49425 Mtetra
.531 .914 .935 r
.5181 .49425 .5244 .49454 .536 .49029 .52974 .48985 Mtetra
.567 .927 .943 r
.52974 .48985 .536 .49029 .54763 .48574 .54143 .48512 Mtetra
.601 .936 .951 r
.54143 .48512 .54763 .48574 .5593 .48092 .55316 .48006 Mtetra
.632 .942 .957 r
.55316 .48006 .5593 .48092 .57102 .47584 .56493 .47472 Mtetra
.659 .944 .961 r
.56493 .47472 .57102 .47584 .58276 .47053 .57673 .46912 Mtetra
.681 .942 .963 r
.57673 .46912 .58276 .47053 .59455 .46502 .58856 .46329 Mtetra
.699 .937 .963 r
.58856 .46329 .59455 .46502 .60636 .45936 .60043 .45728 Mtetra
.713 .93 .962 r
.60043 .45728 .60636 .45936 .61821 .45356 .61232 .45113 Mtetra
.724 .921 .959 r
.61232 .45113 .61821 .45356 .63009 .44766 .62425 .44487 Mtetra
.731 .911 .956 r
.62425 .44487 .63009 .44766 .64201 .44171 .63621 .43855 Mtetra
.735 .899 .953 r
.63621 .43855 .64201 .44171 .65396 .43573 .6482 .4322 Mtetra
.737 .887 .949 r
.6482 .4322 .65396 .43573 .66595 .42976 .66023 .42586 Mtetra
.736 .875 .945 r
.66023 .42586 .66595 .42976 .67798 .42381 .67229 .41956 Mtetra
.735 .863 .941 r
.67229 .41956 .67798 .42381 .69004 .41792 .68439 .41333 Mtetra
.732 .851 .937 r
.68439 .41333 .69004 .41792 .70215 .41211 .69653 .4072 Mtetra
.728 .84 .933 r
.69653 .4072 .70215 .41211 .7143 .40639 .70872 .40117 Mtetra
.724 .829 .93 r
.70872 .40117 .7143 .40639 .7265 .40077 .72095 .39526 Mtetra
.719 .819 .927 r
.72095 .39526 .7265 .40077 .73875 .39526 .73323 .38949 Mtetra
.714 .809 .924 r
.73323 .38949 .73875 .39526 .75104 .38987 .74556 .38385 Mtetra
.709 .801 .922 r
.74556 .38385 .75104 .38987 .76339 .3846 .75794 .37835 Mtetra
.704 .793 .919 r
.75794 .37835 .76339 .3846 .7758 .37944 .77037 .37299 Mtetra
.7 .786 .918 r
.77037 .37299 .7758 .37944 .78826 .3744 .78287 .36776 Mtetra
.695 .779 .916 r
.78287 .36776 .78826 .3744 .80078 .36946 .79542 .36266 Mtetra
.691 .773 .914 r
.79542 .36266 .80078 .36946 .81335 .36462 .80802 .35767 Mtetra
.687 .768 .913 r
.80802 .35767 .81335 .36462 .82599 .35987 .82069 .35279 Mtetra
.684 .764 .912 r
.82069 .35279 .82599 .35987 .83868 .3552 .83342 .348 Mtetra
.681 .76 .911 r
.83342 .348 .83868 .3552 .85144 .3506 .84621 .34329 Mtetra
.678 .757 .911 r
.84621 .34329 .85144 .3506 .86425 .34606 .85907 .33866 Mtetra
.675 .754 .91 r
.85907 .33866 .86425 .34606 .87713 .34157 .87198 .33408 Mtetra
.673 .752 .91 r
.87198 .33408 .87713 .34157 .89007 .33712 .88496 .32956 Mtetra
.672 .75 .909 r
.88496 .32956 .89007 .33712 .90307 .33271 .89799 .32508 Mtetra
.479 .786 .998 r
.30073 .5271 .30775 .53068 .3183 .52932 .31128 .52604 Mtetra
.451 .786 .998 r
.31128 .52604 .3183 .52932 .32889 .52806 .32189 .52509 Mtetra
.42 .785 .995 r
.32189 .52509 .32889 .52806 .33954 .52688 .33255 .52424 Mtetra
.388 .782 .988 r
.33255 .52424 .33954 .52688 .35024 .52577 .34326 .52346 Mtetra
.356 .777 .976 r
.34326 .52346 .35024 .52577 .36099 .5247 .35404 .52272 Mtetra
.323 .77 .96 r
.35404 .52272 .36099 .5247 .37181 .52363 .36487 .52199 Mtetra
.294 .763 .94 r
.36487 .52199 .37181 .52363 .38269 .52253 .37577 .52123 Mtetra
.268 .755 .918 r
.37577 .52123 .38269 .52253 .39363 .52137 .38674 .52038 Mtetra
.247 .748 .896 r
.38674 .52038 .39363 .52137 .40463 .52011 .39777 .51942 Mtetra
.234 .744 .875 r
.39777 .51942 .40463 .52011 .4157 .51871 .40887 .5183 Mtetra
.228 .744 .857 r
.40887 .5183 .4157 .51871 .42683 .51713 .42004 .51697 Mtetra
.23 .747 .844 r
.42004 .51697 .42683 .51713 .43803 .51533 .43128 .51539 Mtetra
.241 .756 .835 r
.43128 .51539 .43803 .51533 .44929 .51328 .44259 .51352 Mtetra
.259 .769 .831 r
.44259 .51352 .44929 .51328 .46062 .51094 .45396 .51131 Mtetra
.286 .787 .833 r
.45396 .51131 .46062 .51094 .472 .50829 .4654 .50875 Mtetra
.319 .808 .84 r
.4654 .50875 .472 .50829 .48345 .50531 .47689 .50581 Mtetra
.358 .831 .852 r
.47689 .50581 .48345 .50531 .49495 .50198 .48845 .50247 Mtetra
.402 .856 .866 r
.48845 .50247 .49495 .50198 .5065 .49829 .50006 .49871 Mtetra
.447 .881 .882 r
.50006 .49871 .5065 .49829 .5181 .49425 .51172 .49455 Mtetra
.494 .903 .898 r
.51172 .49455 .5181 .49425 .52974 .48985 .52342 .48999 Mtetra
.539 .923 .913 r
.52342 .48999 .52974 .48985 .54143 .48512 .53517 .48504 Mtetra
.581 .938 .927 r
.53517 .48504 .54143 .48512 .55316 .48006 .54696 .47973 Mtetra
.619 .948 .938 r
.54696 .47973 .55316 .48006 .56493 .47472 .55878 .4741 Mtetra
.652 .953 .946 r
.55878 .4741 .56493 .47472 .57673 .46912 .57063 .46817 Mtetra
.68 .954 .951 r
.57063 .46817 .57673 .46912 .58856 .46329 .58252 .46199 Mtetra
.702 .951 .954 r
.58252 .46199 .58856 .46329 .60043 .45728 .59444 .45561 Mtetra
.719 .944 .955 r
.59444 .45561 .60043 .45728 .61232 .45113 .60638 .44906 Mtetra
.731 .935 .955 r
.60638 .44906 .61232 .45113 .62425 .44487 .61836 .4424 Mtetra
.74 .924 .953 r
.61836 .4424 .62425 .44487 .63621 .43855 .63036 .43568 Mtetra
.745 .912 .95 r
.63036 .43568 .63621 .43855 .6482 .4322 .6424 .42893 Mtetra
.747 .9 .946 r
.6424 .42893 .6482 .4322 .66023 .42586 .65446 .42219 Mtetra
.747 .886 .943 r
.65446 .42219 .66023 .42586 .67229 .41956 .66656 .41551 Mtetra
.745 .873 .939 r
.66656 .41551 .67229 .41956 .68439 .41333 .6787 .40891 Mtetra
.742 .861 .936 r
.6787 .40891 .68439 .41333 .69653 .4072 .69088 .40242 Mtetra
.737 .848 .932 r
.69088 .40242 .69653 .4072 .70872 .40117 .70309 .39606 Mtetra
.732 .837 .929 r
.70309 .39606 .70872 .40117 .72095 .39526 .71536 .38985 Mtetra
.727 .826 .926 r
.71536 .38985 .72095 .39526 .73323 .38949 .72767 .38378 Mtetra
.721 .816 .923 r
.72767 .38378 .73323 .38949 .74556 .38385 .74003 .37788 Mtetra
.716 .806 .921 r
.74003 .37788 .74556 .38385 .75794 .37835 .75244 .37214 Mtetra
.71 .798 .919 r
.75244 .37214 .75794 .37835 .77037 .37299 .76491 .36656 Mtetra
.705 .79 .917 r
.76491 .36656 .77037 .37299 .78287 .36776 .77743 .36114 Mtetra
.7 .783 .916 r
.77743 .36114 .78287 .36776 .79542 .36266 .79001 .35585 Mtetra
.695 .776 .914 r
.79001 .35585 .79542 .36266 .80802 .35767 .80266 .3507 Mtetra
.691 .771 .913 r
.80266 .3507 .80802 .35767 .82069 .35279 .81536 .34568 Mtetra
.687 .766 .912 r
.81536 .34568 .82069 .35279 .83342 .348 .82812 .34076 Mtetra
.683 .762 .911 r
.82812 .34076 .83342 .348 .84621 .34329 .84095 .33594 Mtetra
.68 .758 .911 r
.84095 .33594 .84621 .34329 .85907 .33866 .85384 .33121 Mtetra
.677 .755 .91 r
.85384 .33121 .85907 .33866 .87198 .33408 .86679 .32655 Mtetra
.675 .753 .91 r
.86679 .32655 .87198 .33408 .88496 .32956 .8798 .32194 Mtetra
.673 .75 .909 r
.8798 .32194 .88496 .32956 .89799 .32508 .89288 .31739 Mtetra
.43 .777 .997 r
.29362 .52378 .30073 .5271 .31128 .52604 .30418 .52305 Mtetra
.393 .772 .991 r
.30418 .52305 .31128 .52604 .32189 .52509 .3148 .52245 Mtetra
.353 .765 .98 r
.3148 .52245 .32189 .52509 .33255 .52424 .32547 .52196 Mtetra
.312 .755 .964 r
.32547 .52196 .33255 .52424 .34326 .52346 .33619 .52154 Mtetra
.27 .742 .941 r
.33619 .52154 .34326 .52346 .35404 .52272 .34698 .52117 Mtetra
.23 .727 .913 r
.34698 .52117 .35404 .52272 .36487 .52199 .35784 .52081 Mtetra
.194 .711 .882 r
.35784 .52081 .36487 .52199 .37577 .52123 .36876 .5204 Mtetra
.164 .696 .85 r
.36876 .5204 .37577 .52123 .38674 .52038 .37975 .51991 Mtetra
.142 .684 .82 r
.37975 .51991 .38674 .52038 .39777 .51942 .39081 .51928 Mtetra
.129 .677 .793 r
.39081 .51928 .39777 .51942 .40887 .5183 .40195 .51846 Mtetra
.124 .674 .771 r
.40195 .51846 .40887 .5183 .42004 .51697 .41315 .5174 Mtetra
.13 .678 .756 r
.41315 .5174 .42004 .51697 .43128 .51539 .42443 .51605 Mtetra
.145 .689 .748 r
.42443 .51605 .43128 .51539 .44259 .51352 .43579 .51437 Mtetra
.169 .706 .747 r
.43579 .51437 .44259 .51352 .45396 .51131 .44721 .51231 Mtetra
.202 .729 .753 r
.44721 .51231 .45396 .51131 .4654 .50875 .4587 .50984 Mtetra
.243 .757 .766 r
.4587 .50984 .4654 .50875 .47689 .50581 .47025 .50693 Mtetra
.29 .788 .784 r
.47025 .50693 .47689 .50581 .48845 .50247 .48186 .50356 Mtetra
.343 .821 .805 r
.48186 .50356 .48845 .50247 .50006 .49871 .49353 .49973 Mtetra
.398 .854 .829 r
.49353 .49973 .50006 .49871 .51172 .49455 .50525 .49544 Mtetra
.454 .885 .853 r
.50525 .49544 .51172 .49455 .52342 .48999 .51702 .49069 Mtetra
.509 .912 .876 r
.51702 .49069 .52342 .48999 .53517 .48504 .52883 .48551 Mtetra
.56 .934 .897 r
.52883 .48551 .53517 .48504 .54696 .47973 .54068 .47992 Mtetra
.606 .95 .914 r
.54068 .47992 .54696 .47973 .55878 .4741 .55256 .47396 Mtetra
.646 .96 .928 r
.55256 .47396 .55878 .4741 .57063 .46817 .56447 .46767 Mtetra
.679 .963 .937 r
.56447 .46767 .57063 .46817 .58252 .46199 .57642 .4611 Mtetra
.706 .962 .943 r
.57642 .4611 .58252 .46199 .59444 .45561 .58839 .45431 Mtetra
.726 .956 .946 r
.58839 .45431 .59444 .45561 .60638 .44906 .60039 .44734 Mtetra
.74 .948 .948 r
.60039 .44734 .60638 .44906 .61836 .4424 .61241 .44025 Mtetra
.75 .937 .947 r
.61241 .44025 .61836 .4424 .63036 .43568 .62446 .43308 Mtetra
.755 .924 .945 r
.62446 .43308 .63036 .43568 .6424 .42893 .63654 .4259 Mtetra
.758 .911 .943 r
.63654 .4259 .6424 .42893 .65446 .42219 .64865 .41874 Mtetra
.758 .897 .94 r
.64865 .41874 .65446 .42219 .66656 .41551 .66079 .41164 Mtetra
.755 .883 .937 r
.66079 .41164 .66656 .41551 .6787 .40891 .67296 .40464 Mtetra
.752 .87 .933 r
.67296 .40464 .6787 .40891 .69088 .40242 .68517 .39778 Mtetra
.747 .856 .93 r
.68517 .39778 .69088 .40242 .70309 .39606 .69743 .39106 Mtetra
.741 .844 .927 r
.69743 .39106 .70309 .39606 .71536 .38985 .70972 .38451 Mtetra
.735 .832 .925 r
.70972 .38451 .71536 .38985 .72767 .38378 .72206 .37814 Mtetra
.729 .821 .922 r
.72206 .37814 .72767 .38378 .74003 .37788 .73446 .37196 Mtetra
.722 .811 .92 r
.73446 .37196 .74003 .37788 .75244 .37214 .7469 .36596 Mtetra
.716 .802 .918 r
.7469 .36596 .75244 .37214 .76491 .36656 .7594 .36015 Mtetra
.71 .794 .916 r
.7594 .36015 .76491 .36656 .77743 .36114 .77196 .35451 Mtetra
.704 .786 .915 r
.77196 .35451 .77743 .36114 .79001 .35585 .78457 .34904 Mtetra
.699 .779 .914 r
.78457 .34904 .79001 .35585 .80266 .3507 .79724 .34372 Mtetra
.694 .773 .913 r
.79724 .34372 .80266 .3507 .81536 .34568 .80998 .33854 Mtetra
.689 .768 .912 r
.80998 .33854 .81536 .34568 .82812 .34076 .82278 .33349 Mtetra
.685 .764 .911 r
.82278 .33349 .82812 .34076 .84095 .33594 .83564 .32856 Mtetra
.682 .76 .91 r
.83564 .32856 .84095 .33594 .85384 .33121 .84857 .32372 Mtetra
.679 .756 .91 r
.84857 .32372 .85384 .33121 .86679 .32655 .86156 .31896 Mtetra
.676 .754 .909 r
.86156 .31896 .86679 .32655 .8798 .32194 .87461 .31427 Mtetra
.674 .751 .909 r
.87461 .31427 .8798 .32194 .89288 .31739 .88773 .30964 Mtetra
.37 .76 .988 r
.28643 .52072 .29362 .52378 .30418 .52305 .297 .52035 Mtetra
.323 .748 .974 r
.297 .52035 .30418 .52305 .3148 .52245 .30761 .52013 Mtetra
.273 .732 .952 r
.30761 .52013 .3148 .52245 .32547 .52196 .31829 .52003 Mtetra
.221 .712 .922 r
.31829 .52003 .32547 .52196 .33619 .52154 .32903 .52001 Mtetra
.171 .689 .886 r
.32903 .52001 .33619 .52154 .34698 .52117 .33983 .52005 Mtetra
.125 .664 .845 r
.33983 .52005 .34698 .52117 .35784 .52081 .3507 .52008 Mtetra
.085 .641 .803 r
.3507 .52008 .35784 .52081 .36876 .5204 .36164 .52007 Mtetra
.055 .62 .762 r
.36164 .52007 .36876 .5204 .37975 .51991 .37266 .51995 Mtetra
.033 .604 .726 r
.37266 .51995 .37975 .51991 .39081 .51928 .38375 .51967 Mtetra
0 0 0 r
.38375 .51967 .39081 .51928 .40195 .51846 .39492 .51918 Mtetra
.39492 .51918 .40195 .51846 .41315 .5174 .40616 .51841 Mtetra
.40616 .51841 .41315 .5174 .42443 .51605 .41749 .5173 Mtetra
.41749 .5173 .42443 .51605 .43579 .51437 .42888 .51582 Mtetra
.42888 .51582 .43579 .51437 .44721 .51231 .44036 .5139 Mtetra
.44036 .5139 .44721 .51231 .4587 .50984 .4519 .51152 Mtetra
.4519 .51152 .4587 .50984 .47025 .50693 .46351 .50865 Mtetra
.225 .739 .711 r
.46351 .50865 .47025 .50693 .48186 .50356 .47518 .50525 Mtetra
.286 .781 .741 r
.47518 .50525 .48186 .50356 .49353 .49973 .48692 .50133 Mtetra
.351 .823 .773 r
.48692 .50133 .49353 .49973 .50525 .49544 .4987 .49688 Mtetra
.417 .863 .806 r
.4987 .49688 .50525 .49544 .51702 .49069 .51053 .49193 Mtetra
.481 .898 .837 r
.51053 .49193 .51702 .49069 .52883 .48551 .52241 .48648 Mtetra
.542 .928 .865 r
.52241 .48648 .52883 .48551 .54068 .47992 .53432 .48058 Mtetra
.596 .949 .888 r
.53432 .48058 .54068 .47992 .55256 .47396 .54627 .47427 Mtetra
.642 .963 .907 r
.54627 .47427 .55256 .47396 .56447 .46767 .55824 .46759 Mtetra
.68 .97 .921 r
.55824 .46759 .56447 .46767 .57642 .4611 .57025 .4606 Mtetra
.711 .971 .93 r
.57025 .4606 .57642 .4611 .58839 .45431 .58228 .45336 Mtetra
.734 .966 .936 r
.58228 .45336 .58839 .45431 .60039 .44734 .59433 .44593 Mtetra
.75 .958 .939 r
.59433 .44593 .60039 .44734 .61241 .44025 .6064 .43837 Mtetra
.761 .947 .94 r
.6064 .43837 .61241 .44025 .62446 .43308 .6185 .43074 Mtetra
.767 .934 .939 r
.6185 .43074 .62446 .43308 .63654 .4259 .63063 .42309 Mtetra
.77 .92 .937 r
.63063 .42309 .63654 .4259 .64865 .41874 .64278 .41547 Mtetra
.769 .906 .935 r
.64278 .41547 .64865 .41874 .66079 .41164 .65496 .40793 Mtetra
.767 .892 .933 r
.65496 .40793 .66079 .41164 .67296 .40464 .66717 .40051 Mtetra
.762 .877 .93 r
.66717 .40051 .67296 .40464 .68517 .39778 .67942 .39324 Mtetra
.757 .864 .927 r
.67942 .39324 .68517 .39778 .69743 .39106 .69171 .38614 Mtetra
.75 .85 .925 r
.69171 .38614 .69743 .39106 .70972 .38451 .70404 .37924 Mtetra
.744 .838 .923 r
.70404 .37924 .70972 .38451 .72206 .37814 .71641 .37255 Mtetra
.736 .827 .92 r
.71641 .37255 .72206 .37814 .73446 .37196 .72884 .36606 Mtetra
.729 .816 .919 r
.72884 .36606 .73446 .37196 .7469 .36596 .74131 .35979 Mtetra
.722 .806 .917 r
.74131 .35979 .7469 .36596 .7594 .36015 .75385 .35373 Mtetra
.715 .797 .915 r
.75385 .35373 .7594 .36015 .77196 .35451 .76643 .34787 Mtetra
.709 .789 .914 r
.76643 .34787 .77196 .35451 .78457 .34904 .77908 .3422 Mtetra
.703 .782 .913 r
.77908 .3422 .78457 .34904 .79724 .34372 .79179 .33671 Mtetra
.698 .776 .912 r
.79179 .33671 .79724 .34372 .80998 .33854 .80456 .33137 Mtetra
.693 .77 .911 r
.80456 .33137 .80998 .33854 .82278 .33349 .81739 .32619 Mtetra
.688 .765 .911 r
.81739 .32619 .82278 .33349 .83564 .32856 .83029 .32113 Mtetra
.684 .761 .91 r
.83029 .32113 .83564 .32856 .84857 .32372 .84325 .31618 Mtetra
.681 .758 .909 r
.84325 .31618 .84857 .32372 .86156 .31896 .85628 .31132 Mtetra
.678 .755 .909 r
.85628 .31132 .86156 .31896 .87461 .31427 .86937 .30655 Mtetra
.675 .752 .909 r
.86937 .30655 .87461 .31427 .88773 .30964 .88253 .30184 Mtetra
.299 .733 .968 r
.27914 .51793 .28643 .52072 .297 .52035 .28971 .51795 Mtetra
.24 .711 .942 r
.28971 .51795 .297 .52035 .30761 .52013 .30034 .51813 Mtetra
.179 .684 .906 r
.30034 .51813 .30761 .52013 .31829 .52003 .31102 .51845 Mtetra
.119 .653 .862 r
.31102 .51845 .31829 .52003 .32903 .52001 .32176 .51887 Mtetra
.063 .62 .812 r
.32176 .51887 .32903 .52001 .33983 .52005 .33258 .51934 Mtetra
.015 .587 .76 r
.33258 .51934 .33983 .52005 .3507 .52008 .34346 .5198 Mtetra
0 .557 .709 r
.34346 .5198 .3507 .52008 .36164 .52007 .35442 .5202 Mtetra
.053 0 0 r
.35442 .5202 .36164 .52007 .37266 .51995 .36546 .52049 Mtetra
.07 0 0 r
.36546 .52049 .37266 .51995 .38375 .51967 .37658 .52059 Mtetra
.076 0 0 r
.37658 .52059 .38375 .51967 .39492 .51918 .38778 .52043 Mtetra
.072 0 0 r
.38778 .52043 .39492 .51918 .40616 .51841 .39906 .51997 Mtetra
.056 0 0 r
.39906 .51997 .40616 .51841 .41749 .5173 .41043 .51912 Mtetra
.031 0 0 r
.41043 .51912 .41749 .5173 .42888 .51582 .42188 .51784 Mtetra
0 0 0 r
.42188 .51784 .42888 .51582 .44036 .5139 .4334 .51608 Mtetra
.4334 .51608 .44036 .5139 .4519 .51152 .445 .51378 Mtetra
.445 .51378 .4519 .51152 .46351 .50865 .45667 .51093 Mtetra
.45667 .51093 .46351 .50865 .47518 .50525 .46841 .50749 Mtetra
.236 .74 .678 r
.46841 .50749 .47518 .50525 .48692 .50133 .48021 .50347 Mtetra
.31 .791 .719 r
.48021 .50347 .48692 .50133 .4987 .49688 .49206 .49885 Mtetra
.385 .84 .76 r
.49206 .49885 .4987 .49688 .51053 .49193 .50396 .49366 Mtetra
.458 .884 .799 r
.50396 .49366 .51053 .49193 .52241 .48648 .5159 .48793 Mtetra
.527 .92 .834 r
.5159 .48793 .52241 .48648 .53432 .48058 .52789 .48169 Mtetra
.589 .947 .863 r
.52789 .48169 .53432 .48058 .54627 .47427 .5399 .47499 Mtetra
.641 .966 .887 r
.5399 .47499 .54627 .47427 .55824 .46759 .55194 .46789 Mtetra
.684 .975 .904 r
.55194 .46789 .55824 .46759 .57025 .4606 .56401 .46045 Mtetra
.718 .978 .917 r
.56401 .46045 .57025 .4606 .58228 .45336 .5761 .45273 Mtetra
.743 .974 .925 r
.5761 .45273 .58228 .45336 .59433 .44593 .5882 .44481 Mtetra
.761 .967 .929 r
.5882 .44481 .59433 .44593 .6064 .43837 .60033 .43675 Mtetra
.773 .956 .931 r
.60033 .43675 .6064 .43837 .6185 .43074 .61249 .42861 Mtetra
.779 .943 .932 r
.61249 .42861 .6185 .43074 .63063 .42309 .62466 .42046 Mtetra
.782 .928 .931 r
.62466 .42046 .63063 .42309 .64278 .41547 .63685 .41236 Mtetra
.781 .914 .929 r
.63685 .41236 .64278 .41547 .65496 .40793 .64908 .40435 Mtetra
.778 .899 .928 r
.64908 .40435 .65496 .40793 .66717 .40051 .66133 .39648 Mtetra
.773 .884 .926 r
.66133 .39648 .66717 .40051 .67942 .39324 .67362 .38879 Mtetra
.767 .87 .924 r
.67362 .38879 .67942 .39324 .69171 .38614 .68594 .38129 Mtetra
.76 .856 .922 r
.68594 .38129 .69171 .38614 .70404 .37924 .69831 .37402 Mtetra
.752 .843 .92 r
.69831 .37402 .70404 .37924 .71641 .37255 .71072 .36698 Mtetra
.744 .831 .918 r
.71072 .36698 .71641 .37255 .72884 .36606 .72317 .36019 Mtetra
.736 .82 .916 r
.72317 .36019 .72884 .36606 .74131 .35979 .73568 .35363 Mtetra
.729 .81 .915 r
.73568 .35363 .74131 .35979 .75385 .35373 .74825 .34731 Mtetra
.721 .801 .914 r
.74825 .34731 .75385 .35373 .76643 .34787 .76087 .34122 Mtetra
.714 .792 .913 r
.76087 .34122 .76643 .34787 .77908 .3422 .77355 .33534 Mtetra
.707 .785 .912 r
.77355 .33534 .77908 .3422 .79179 .33671 .78629 .32966 Mtetra
.701 .778 .911 r
.78629 .32966 .79179 .33671 .80456 .33137 .79909 .32417 Mtetra
.696 .772 .91 r
.79909 .32417 .80456 .33137 .81739 .32619 .81196 .31883 Mtetra
.691 .767 .91 r
.81196 .31883 .81739 .32619 .83029 .32113 .8249 .31365 Mtetra
.686 .763 .909 r
.8249 .31365 .83029 .32113 .84325 .31618 .8379 .30858 Mtetra
.683 .759 .909 r
.8379 .30858 .84325 .31618 .85628 .31132 .85096 .30363 Mtetra
.679 .756 .909 r
.85096 .30363 .85628 .31132 .86937 .30655 .86409 .29877 Mtetra
.676 .753 .909 r
.86409 .29877 .86937 .30655 .88253 .30184 .87729 .29398 Mtetra
.216 .694 .936 r
.27177 .51538 .27914 .51793 .28971 .51795 .28234 .51582 Mtetra
.147 .661 .895 r
.28234 .51582 .28971 .51795 .30034 .51813 .29296 .51644 Mtetra
.078 .622 .844 r
.29296 .51644 .30034 .51813 .31102 .51845 .30364 .51722 Mtetra
.013 .58 .785 r
.30364 .51722 .31102 .51845 .32176 .51887 .31439 .51809 Mtetra
0 .538 .724 r
.31439 .51809 .32176 .51887 .33258 .51934 .32522 .51902 Mtetra
.091 0 0 r
.32522 .51902 .33258 .51934 .34346 .5198 .33611 .51994 Mtetra
.127 0 0 r
.33611 .51994 .34346 .5198 .35442 .5202 .34709 .52078 Mtetra
.15 0 0 r
.34709 .52078 .35442 .5202 .36546 .52049 .35815 .52149 Mtetra
.162 0 0 r
.35815 .52149 .36546 .52049 .37658 .52059 .3693 .52198 Mtetra
.163 0 0 r
.3693 .52198 .37658 .52059 .38778 .52043 .38053 .52219 Mtetra
.153 0 0 r
.38053 .52219 .38778 .52043 .39906 .51997 .39185 .52204 Mtetra
.132 0 0 r
.39185 .52204 .39906 .51997 .41043 .51912 .40326 .52146 Mtetra
.101 0 0 r
.40326 .52146 .41043 .51912 .42188 .51784 .41476 .52039 Mtetra
.061 0 0 r
.41476 .52039 .42188 .51784 .4334 .51608 .42634 .51877 Mtetra
.01 0 0 r
.42634 .51877 .4334 .51608 .445 .51378 .438 .51656 Mtetra
0 0 0 r
.438 .51656 .445 .51378 .45667 .51093 .44973 .51373 Mtetra
.44973 .51373 .45667 .51093 .46841 .50749 .46154 .51023 Mtetra
.46154 .51023 .46841 .50749 .48021 .50347 .4734 .50608 Mtetra
.278 .763 .672 r
.4734 .50608 .48021 .50347 .49206 .49885 .48533 .50128 Mtetra
.362 .82 .72 r
.48533 .50128 .49206 .49885 .50396 .49366 .4973 .49583 Mtetra
.444 .871 .766 r
.4973 .49583 .50396 .49366 .5159 .48793 .50931 .48978 Mtetra
.52 .914 .807 r
.50931 .48978 .5159 .48793 .52789 .48169 .52137 .48318 Mtetra
.588 .946 .841 r
.52137 .48318 .52789 .48169 .5399 .47499 .53345 .47606 Mtetra
.646 .968 .869 r
.53345 .47606 .5399 .47499 .55194 .46789 .54556 .46851 Mtetra
.692 .98 .889 r
.54556 .46851 .55194 .46789 .56401 .46045 .55769 .46058 Mtetra
.728 .984 .904 r
.55769 .46058 .56401 .46045 .5761 .45273 .56984 .45236 Mtetra
.755 .981 .913 r
.56984 .45236 .5761 .45273 .5882 .44481 .58201 .44391 Mtetra
.774 .973 .919 r
.58201 .44391 .5882 .44481 .60033 .43675 .5942 .43532 Mtetra
.786 .962 .922 r
.5942 .43532 .60033 .43675 .61249 .42861 .6064 .42665 Mtetra
.792 .949 .923 r
.6064 .42665 .61249 .42861 .62466 .42046 .61863 .41798 Mtetra
.794 .934 .923 r
.61863 .41798 .62466 .42046 .63685 .41236 .63087 .40937 Mtetra
.793 .919 .923 r
.63087 .40937 .63685 .41236 .64908 .40435 .64314 .40087 Mtetra
.789 .904 .922 r
.64314 .40087 .64908 .40435 .66133 .39648 .65543 .39253 Mtetra
.784 .889 .92 r
.65543 .39253 .66133 .39648 .67362 .38879 .66776 .38439 Mtetra
.777 .874 .919 r
.66776 .38439 .67362 .38879 .68594 .38129 .68012 .37648 Mtetra
.769 .86 .917 r
.68012 .37648 .68594 .38129 .69831 .37402 .69252 .36882 Mtetra
.761 .847 .916 r
.69252 .36882 .69831 .37402 .71072 .36698 .70497 .36143 Mtetra
.752 .835 .915 r
.70497 .36143 .71072 .36698 .72317 .36019 .71746 .35431 Mtetra
.744 .824 .914 r
.71746 .35431 .72317 .36019 .73568 .35363 .73 .34745 Mtetra
.735 .813 .913 r
.73 .34745 .73568 .35363 .74825 .34731 .7426 .34087 Mtetra
.727 .803 .912 r
.7426 .34087 .74825 .34731 .76087 .34122 .75525 .33454 Mtetra
.719 .795 .911 r
.75525 .33454 .76087 .34122 .77355 .33534 .76797 .32845 Mtetra
.712 .787 .911 r
.76797 .32845 .77355 .33534 .78629 .32966 .78074 .32258 Mtetra
.705 .78 .91 r
.78074 .32258 .78629 .32966 .79909 .32417 .79358 .31691 Mtetra
.699 .774 .91 r
.79358 .31691 .79909 .32417 .81196 .31883 .80649 .31143 Mtetra
.693 .768 .909 r
.80649 .31143 .81196 .31883 .8249 .31365 .81946 .30611 Mtetra
.689 .764 .909 r
.81946 .30611 .8249 .31365 .8379 .30858 .83249 .30093 Mtetra
.684 .76 .909 r
.83249 .30093 .8379 .30858 .85096 .30363 .8456 .29588 Mtetra
.681 .756 .908 r
.8456 .29588 .85096 .30363 .86409 .29877 .85877 .29092 Mtetra
.678 .753 .908 r
.85877 .29092 .86409 .29877 .87729 .29398 .872 .28606 Mtetra
.126 .642 .89 r
.2643 .51307 .27177 .51538 .28234 .51582 .27486 .51396 Mtetra
.048 .597 .834 r
.27486 .51396 .28234 .51582 .29296 .51644 .28548 .51504 Mtetra
0 .548 .768 r
.28548 .51504 .29296 .51644 .30364 .51722 .29617 .51629 Mtetra
.091 0 0 r
.29617 .51629 .30364 .51722 .31439 .51809 .30692 .51765 Mtetra
.146 0 0 r
.30692 .51765 .31439 .51809 .32522 .51902 .31775 .51906 Mtetra
.187 0 0 r
.31775 .51906 .32522 .51902 .33611 .51994 .32866 .52046 Mtetra
.217 0 0 r
.32866 .52046 .33611 .51994 .34709 .52078 .33965 .52177 Mtetra
.234 0 0 r
.33965 .52177 .34709 .52078 .35815 .52149 .35073 .52292 Mtetra
.239 0 0 r
.35073 .52292 .35815 .52149 .3693 .52198 .3619 .52382 Mtetra
.234 0 0 r
.3619 .52382 .3693 .52198 .38053 .52219 .37317 .5244 Mtetra
.219 0 0 r
.37317 .5244 .38053 .52219 .39185 .52204 .38453 .52458 Mtetra
.194 0 0 r
.38453 .52458 .39185 .52204 .40326 .52146 .39598 .52427 Mtetra
.158 0 0 r
.39598 .52427 .40326 .52146 .41476 .52039 .40753 .52341 Mtetra
.113 0 0 r
.40753 .52341 .41476 .52039 .42634 .51877 .41917 .52193 Mtetra
.057 0 0 r
.41917 .52193 .42634 .51877 .438 .51656 .43089 .5198 Mtetra
0 0 0 r
.43089 .5198 .438 .51656 .44973 .51373 .44269 .51696 Mtetra
.44269 .51696 .44973 .51373 .46154 .51023 .45456 .5134 Mtetra
.45456 .5134 .46154 .51023 .4734 .50608 .4665 .50911 Mtetra
.4665 .50911 .4734 .50608 .48533 .50128 .47849 .50408 Mtetra
.35 .808 .69 r
.47849 .50408 .48533 .50128 .4973 .49583 .49054 .49836 Mtetra
.44 .865 .742 r
.49054 .49836 .4973 .49583 .50931 .48978 .50263 .49197 Mtetra
.522 .912 .787 r
.50263 .49197 .50931 .48978 .52137 .48318 .51476 .48497 Mtetra
.595 .948 .825 r
.51476 .48497 .52137 .48318 .53345 .47606 .52691 .47741 Mtetra
.656 .971 .855 r
.52691 .47741 .53345 .47606 .54556 .46851 .5391 .46937 Mtetra
.705 .984 .877 r
.5391 .46937 .54556 .46851 .55769 .46058 .5513 .46093 Mtetra
.742 .988 .892 r
.5513 .46093 .55769 .46058 .56984 .45236 .56352 .45217 Mtetra
.769 .985 .903 r
.56352 .45217 .56984 .45236 .58201 .44391 .57575 .44317 Mtetra
.788 .977 .909 r
.57575 .44317 .58201 .44391 .5942 .43532 .588 .43402 Mtetra
.799 .966 .913 r
.588 .43402 .5942 .43532 .6064 .42665 .60026 .4248 Mtetra
.805 .952 .914 r
.60026 .4248 .6064 .42665 .61863 .41798 .61253 .41559 Mtetra
.807 .938 .915 r
.61253 .41559 .61863 .41798 .63087 .40937 .62483 .40644 Mtetra
.805 .922 .915 r
.62483 .40644 .63087 .40937 .64314 .40087 .63714 .39743 Mtetra
.801 .907 .915 r
.63714 .39743 .64314 .40087 .65543 .39253 .64948 .38861 Mtetra
.795 .892 .914 r
.64948 .38861 .65543 .39253 .66776 .38439 .66185 .38001 Mtetra
.787 .877 .913 r
.66185 .38001 .66776 .38439 .68012 .37648 .67425 .37167 Mtetra
.778 .863 .912 r
.67425 .37167 .68012 .37648 .69252 .36882 .68668 .36362 Mtetra
.769 .85 .912 r
.68668 .36362 .69252 .36882 .70497 .36143 .69917 .35586 Mtetra
.76 .838 .911 r
.69917 .35586 .70497 .36143 .71746 .35431 .71169 .3484 Mtetra
.751 .826 .911 r
.71169 .3484 .71746 .35431 .73 .34745 .72427 .34125 Mtetra
.741 .815 .91 r
.72427 .34125 .73 .34745 .7426 .34087 .7369 .33439 Mtetra
.732 .806 .91 r
.7369 .33439 .7426 .34087 .75525 .33454 .74959 .32781 Mtetra
.724 .797 .909 r
.74959 .32781 .75525 .33454 .76797 .32845 .76234 .3215 Mtetra
.716 .789 .909 r
.76234 .3215 .76797 .32845 .78074 .32258 .77515 .31544 Mtetra
.709 .782 .909 r
.77515 .31544 .78074 .32258 .79358 .31691 .78802 .3096 Mtetra
.702 .775 .908 r
.78802 .3096 .79358 .31691 .80649 .31143 .80096 .30397 Mtetra
.696 .77 .908 r
.80096 .30397 .80649 .31143 .81946 .30611 .81397 .29852 Mtetra
.691 .765 .908 r
.81397 .29852 .81946 .30611 .83249 .30093 .82704 .29322 Mtetra
.686 .761 .908 r
.82704 .29322 .83249 .30093 .8456 .29588 .84019 .28806 Mtetra
.682 .757 .908 r
.84019 .28806 .8456 .29588 .85877 .29092 .8534 .28302 Mtetra
.679 .754 .908 r
.8534 .28302 .85877 .29092 .872 .28606 .86667 .27807 Mtetra
.031 .581 .832 r
.25673 .51097 .2643 .51307 .27486 .51396 .26729 .51232 Mtetra
0 .525 .762 r
.26729 .51232 .27486 .51396 .28548 .51504 .2779 .5139 Mtetra
.124 0 0 r
.2779 .5139 .28548 .51504 .29617 .51629 .28858 .51565 Mtetra
.186 0 0 r
.28858 .51565 .29617 .51629 .30692 .51765 .29934 .51751 Mtetra
.234 0 0 r
.29934 .51751 .30692 .51765 .31775 .51906 .31017 .51943 Mtetra
.27 0 0 r
.31017 .51943 .31775 .51906 .32866 .52046 .32109 .52132 Mtetra
.292 0 0 r
.32109 .52132 .32866 .52046 .33965 .52177 .33209 .52311 Mtetra
.302 0 0 r
.33209 .52311 .33965 .52177 .35073 .52292 .34319 .52472 Mtetra
.34319 .52472 .35073 .52292 .3619 .52382 .35439 .52604 Mtetra
.292 0 0 r
.35439 .52604 .3619 .52382 .37317 .5244 .36569 .527 Mtetra
.272 0 0 r
.36569 .527 .37317 .5244 .38453 .52458 .37709 .5275 Mtetra
.242 0 0 r
.37709 .5275 .38453 .52458 .39598 .52427 .38859 .52746 Mtetra
.202 0 0 r
.38859 .52746 .39598 .52427 .40753 .52341 .40019 .5268 Mtetra
.152 0 0 r
.40019 .5268 .40753 .52341 .41917 .52193 .41188 .52547 Mtetra
.091 0 0 r
.41188 .52547 .41917 .52193 .43089 .5198 .42366 .5234 Mtetra
.019 0 0 r
.42366 .5234 .43089 .5198 .44269 .51696 .43553 .52055 Mtetra
0 0 0 r
.43553 .52055 .44269 .51696 .45456 .5134 .44747 .5169 Mtetra
.44747 .5169 .45456 .5134 .4665 .50911 .45949 .51244 Mtetra
.45949 .51244 .4665 .50911 .47849 .50408 .47156 .50718 Mtetra
.352 .805 .674 r
.47156 .50718 .47849 .50408 .49054 .49836 .48368 .50115 Mtetra
.447 .866 .729 r
.48368 .50115 .49054 .49836 .50263 .49197 .49585 .49439 Mtetra
.535 .916 .777 r
.49585 .49439 .50263 .49197 .51476 .48497 .50806 .48697 Mtetra
.611 .953 .817 r
.50806 .48697 .51476 .48497 .52691 .47741 .52029 .47894 Mtetra
.674 .976 .847 r
.52029 .47894 .52691 .47741 .5391 .46937 .53255 .47039 Mtetra
.723 .989 .868 r
.53255 .47039 .5391 .46937 .5513 .46093 .54482 .46141 Mtetra
.759 .991 .884 r
.54482 .46141 .5513 .46093 .56352 .45217 .55711 .45209 Mtetra
.786 .987 .893 r
.55711 .45209 .56352 .45217 .57575 .44317 .56941 .44252 Mtetra
.803 .979 .9 r
.56941 .44252 .57575 .44317 .588 .43402 .58172 .43279 Mtetra
.814 .967 .903 r
.58172 .43279 .588 .43402 .60026 .4248 .59404 .423 Mtetra
.818 .953 .905 r
.59404 .423 .60026 .4248 .61253 .41559 .60637 .41322 Mtetra
.819 .939 .906 r
.60637 .41322 .61253 .41559 .62483 .40644 .61871 .40353 Mtetra
.817 .923 .907 r
.61871 .40353 .62483 .40644 .63714 .39743 .63108 .394 Mtetra
.812 .908 .907 r
.63108 .394 .63714 .39743 .64948 .38861 .64346 .38468 Mtetra
.805 .893 .907 r
.64346 .38468 .64948 .38861 .66185 .38001 .65587 .37561 Mtetra
.796 .879 .907 r
.65587 .37561 .66185 .38001 .67425 .37167 .66831 .36683 Mtetra
.787 .865 .907 r
.66831 .36683 .67425 .37167 .68668 .36362 .68079 .35837 Mtetra
.777 .852 .907 r
.68079 .35837 .68668 .36362 .69917 .35586 .69331 .35024 Mtetra
.767 .839 .907 r
.69331 .35024 .69917 .35586 .71169 .3484 .70587 .34245 Mtetra
.757 .828 .907 r
.70587 .34245 .71169 .3484 .72427 .34125 .71848 .33499 Mtetra
.747 .817 .907 r
.71848 .33499 .72427 .34125 .7369 .33439 .73115 .32785 Mtetra
.738 .807 .907 r
.73115 .32785 .7369 .33439 .74959 .32781 .74387 .32103 Mtetra
.729 .798 .907 r
.74387 .32103 .74959 .32781 .76234 .3215 .75666 .3145 Mtetra
.72 .79 .907 r
.75666 .3145 .76234 .3215 .77515 .31544 .7695 .30824 Mtetra
.712 .783 .907 r
.7695 .30824 .77515 .31544 .78802 .3096 .78242 .30223 Mtetra
.705 .776 .907 r
.78242 .30223 .78802 .3096 .80096 .30397 .79539 .29645 Mtetra
.699 .771 .907 r
.79539 .29645 .80096 .30397 .81397 .29852 .80844 .29086 Mtetra
.693 .766 .907 r
.80844 .29086 .81397 .29852 .82704 .29322 .82155 .28544 Mtetra
.688 .761 .907 r
.82155 .28544 .82704 .29322 .84019 .28806 .83473 .28018 Mtetra
.684 .758 .907 r
.83473 .28018 .84019 .28806 .8534 .28302 .84798 .27504 Mtetra
.68 .755 .907 r
.84798 .27504 .8534 .28302 .86667 .27807 .8613 .27001 Mtetra
0 .513 .766 r
.24907 .50904 .25673 .51097 .26729 .51232 .25961 .51089 Mtetra
.143 0 0 r
.25961 .51089 .26729 .51232 .2779 .5139 .27022 .51297 Mtetra
.213 0 0 r
.27022 .51297 .2779 .5139 .28858 .51565 .2809 .51523 Mtetra
.268 0 0 r
.2809 .51523 .28858 .51565 .29934 .51751 .29165 .51762 Mtetra
.309 0 0 r
.29165 .51762 .29934 .51751 .31017 .51943 .30248 .52005 Mtetra
.337 0 0 r
.30248 .52005 .31017 .51943 .32109 .52132 .31341 .52246 Mtetra
.353 0 0 r
.31341 .52246 .32109 .52132 .33209 .52311 .32443 .52474 Mtetra
.357 0 0 r
.32443 .52474 .33209 .52311 .34319 .52472 .33555 .5268 Mtetra
.352 0 0 r
.33555 .5268 .34319 .52472 .35439 .52604 .34677 .52855 Mtetra
.337 0 0 r
.34677 .52855 .35439 .52604 .36569 .527 .3581 .52989 Mtetra
.313 0 0 r
.3581 .52989 .36569 .527 .37709 .5275 .36954 .53071 Mtetra
.279 0 0 r
.36954 .53071 .37709 .5275 .38859 .52746 .38108 .53094 Mtetra
.234 0 0 r
.38108 .53094 .38859 .52746 .40019 .5268 .39273 .53048 Mtetra
.179 0 0 r
.39273 .53048 .40019 .5268 .41188 .52547 .40448 .52927 Mtetra
.112 0 0 r
.40448 .52927 .41188 .52547 .42366 .5234 .41633 .52725 Mtetra
.034 0 0 r
.41633 .52725 .42366 .5234 .43553 .52055 .42826 .52437 Mtetra
0 0 0 r
.42826 .52437 .43553 .52055 .44747 .5169 .44028 .52061 Mtetra
.44028 .52061 .44747 .5169 .45949 .51244 .45237 .51596 Mtetra
.45237 .51596 .45949 .51244 .47156 .50718 .46452 .51045 Mtetra
.367 .812 .672 r
.46452 .51045 .47156 .50718 .48368 .50115 .47673 .50409 Mtetra
.468 .876 .729 r
.47673 .50409 .48368 .50115 .49585 .49439 .48898 .49694 Mtetra
.559 .927 .778 r
.48898 .49694 .49585 .49439 .50806 .48697 .50127 .48907 Mtetra
.636 .962 .816 r
.50127 .48907 .50806 .48697 .52029 .47894 .51358 .48055 Mtetra
.698 .983 .844 r
.51358 .48055 .52029 .47894 .53255 .47039 .52592 .47147 Mtetra
.745 .993 .864 r
.52592 .47147 .53255 .47039 .54482 .46141 .53826 .46193 Mtetra
.779 .993 .877 r
.53826 .46193 .54482 .46141 .55711 .45209 .55062 .45202 Mtetra
.804 .988 .886 r
.55062 .45202 .55711 .45209 .56941 .44252 .56299 .44186 Mtetra
.819 .978 .891 r
.56299 .44186 .56941 .44252 .58172 .43279 .57537 .43155 Mtetra
.828 .966 .894 r
.57537 .43155 .58172 .43279 .59404 .423 .58775 .42117 Mtetra
.831 .952 .896 r
.58775 .42117 .59404 .423 .60637 .41322 .60014 .41081 Mtetra
.831 .937 .897 r
.60014 .41081 .60637 .41322 .61871 .40353 .61253 .40057 Mtetra
.827 .922 .898 r
.61253 .40057 .61871 .40353 .63108 .394 .62495 .39051 Mtetra
.822 .907 .899 r
.62495 .39051 .63108 .394 .64346 .38468 .63738 .38068 Mtetra
.814 .893 .899 r
.63738 .38068 .64346 .38468 .65587 .37561 .64984 .37114 Mtetra
.805 .879 .9 r
.64984 .37114 .65587 .37561 .66831 .36683 .66232 .36192 Mtetra
.795 .865 .9 r
.66232 .36192 .66831 .36683 .68079 .35837 .67484 .35305 Mtetra
.785 .852 .901 r
.67484 .35305 .68079 .35837 .69331 .35024 .68739 .34455 Mtetra
.774 .84 .902 r
.68739 .34455 .69331 .35024 .70587 .34245 .69999 .33641 Mtetra
.764 .828 .902 r
.69999 .33641 .70587 .34245 .71848 .33499 .71264 .32865 Mtetra
.753 .818 .903 r
.71264 .32865 .71848 .33499 .73115 .32785 .72535 .32124 Mtetra
.743 .808 .904 r
.72535 .32124 .73115 .32785 .74387 .32103 .73811 .31417 Mtetra
.733 .799 .904 r
.73811 .31417 .74387 .32103 .75666 .3145 .75093 .30742 Mtetra
.724 .791 .905 r
.75093 .30742 .75666 .3145 .7695 .30824 .76381 .30096 Mtetra
.716 .784 .905 r
.76381 .30096 .7695 .30824 .78242 .30223 .77676 .29478 Mtetra
.708 .777 .906 r
.77676 .29478 .78242 .30223 .79539 .29645 .78977 .28885 Mtetra
.702 .771 .906 r
.78977 .28885 .79539 .29645 .80844 .29086 .80285 .28312 Mtetra
.695 .766 .906 r
.80285 .28312 .80844 .29086 .82155 .28544 .816 .27759 Mtetra
.69 .762 .907 r
.816 .27759 .82155 .28544 .83473 .28018 .82922 .27222 Mtetra
.685 .758 .907 r
.82922 .27222 .83473 .28018 .84798 .27504 .84251 .26699 Mtetra
.681 .755 .907 r
.84251 .26699 .84798 .27504 .8613 .27001 .85587 .26187 Mtetra
0 .443 .698 r
.24131 .50725 .24907 .50904 .25961 .51089 .25185 .5096 Mtetra
.225 0 0 r
.25185 .5096 .25961 .51089 .27022 .51297 .26244 .5122 Mtetra
.289 0 0 r
.26244 .5122 .27022 .51297 .2809 .51523 .27311 .51499 Mtetra
.337 0 0 r
.27311 .51499 .2809 .51523 .29165 .51762 .28386 .51791 Mtetra
.371 0 0 r
.28386 .51791 .29165 .51762 .30248 .52005 .29469 .52087 Mtetra
.392 0 0 r
.29469 .52087 .30248 .52005 .31341 .52246 .30562 .52378 Mtetra
.402 0 0 r
.30562 .52378 .31341 .52246 .32443 .52474 .31665 .52656 Mtetra
.401 0 0 r
.31665 .52656 .32443 .52474 .33555 .5268 .32778 .52908 Mtetra
.391 0 0 r
.32778 .52908 .33555 .5268 .34677 .52855 .33903 .53126 Mtetra
.372 0 0 r
.33903 .53126 .34677 .52855 .3581 .52989 .35039 .53297 Mtetra
.344 0 0 r
.35039 .53297 .3581 .52989 .36954 .53071 .36187 .53411 Mtetra
.305 0 0 r
.36187 .53411 .36954 .53071 .38108 .53094 .37346 .53459 Mtetra
.256 0 0 r
.37346 .53459 .38108 .53094 .39273 .53048 .38516 .53432 Mtetra
.195 0 0 r
.38516 .53432 .39273 .53048 .40448 .52927 .39697 .53322 Mtetra
.122 0 0 r
.39697 .53322 .40448 .52927 .41633 .52725 .40888 .53122 Mtetra
.035 0 0 r
.40888 .53122 .41633 .52725 .42826 .52437 .42089 .52829 Mtetra
0 0 0 r
.42089 .52829 .42826 .52437 .44028 .52061 .43298 .52441 Mtetra
.43298 .52441 .44028 .52061 .45237 .51596 .44515 .51955 Mtetra
.44515 .51955 .45237 .51596 .46452 .51045 .45739 .51375 Mtetra
.398 .831 .685 r
.45739 .51375 .46452 .51045 .47673 .50409 .46968 .50705 Mtetra
.502 .895 .742 r
.46968 .50705 .47673 .50409 .48898 .49694 .48201 .49948 Mtetra
.593 .942 .788 r
.48201 .49948 .48898 .49694 .50127 .48907 .49438 .49114 Mtetra
.668 .973 .822 r
.49438 .49114 .50127 .48907 .51358 .48055 .50678 .48211 Mtetra
.727 .99 .847 r
.50678 .48211 .51358 .48055 .52592 .47147 .51919 .47248 Mtetra
.77 .996 .863 r
.51919 .47248 .52592 .47147 .53826 .46193 .53162 .46236 Mtetra
.801 .993 .873 r
.53162 .46236 .53826 .46193 .55062 .45202 .54405 .45187 Mtetra
.822 .986 .879 r
.54405 .45187 .55062 .45202 .56299 .44186 .55649 .44111 Mtetra
.835 .975 .883 r
.55649 .44111 .56299 .44186 .57537 .43155 .56893 .43019 Mtetra
.841 .961 .885 r
.56893 .43019 .57537 .43155 .58775 .42117 .58138 .41922 Mtetra
.843 .947 .887 r
.58138 .41922 .58775 .42117 .60014 .41081 .59383 .40829 Mtetra
.842 .933 .888 r
.59383 .40829 .60014 .41081 .61253 .40057 .60628 .39749 Mtetra
.837 .918 .889 r
.60628 .39749 .61253 .40057 .62495 .39051 .61875 .38689 Mtetra
.831 .904 .89 r
.61875 .38689 .62495 .39051 .63738 .38068 .63123 .37656 Mtetra
.822 .89 .891 r
.63123 .37656 .63738 .38068 .64984 .37114 .64373 .36655 Mtetra
.813 .876 .892 r
.64373 .36655 .64984 .37114 .66232 .36192 .65626 .35689 Mtetra
.803 .863 .894 r
.65626 .35689 .66232 .36192 .67484 .35305 .66882 .34762 Mtetra
.792 .851 .895 r
.66882 .34762 .67484 .35305 .68739 .34455 .68142 .33875 Mtetra
.781 .839 .897 r
.68142 .33875 .68739 .34455 .69999 .33641 .69406 .33028 Mtetra
.769 .828 .898 r
.69406 .33028 .69999 .33641 .71264 .32865 .70675 .32221 Mtetra
.758 .818 .899 r
.70675 .32221 .71264 .32865 .72535 .32124 .71949 .31452 Mtetra
.748 .808 .9 r
.71949 .31452 .72535 .32124 .73811 .31417 .73229 .30721 Mtetra
.738 .799 .901 r
.73229 .30721 .73811 .31417 .75093 .30742 .74514 .30024 Mtetra
.728 .791 .902 r
.74514 .30024 .75093 .30742 .76381 .30096 .75806 .2936 Mtetra
.719 .784 .903 r
.75806 .2936 .76381 .30096 .77676 .29478 .77105 .28725 Mtetra
.711 .777 .904 r
.77105 .28725 .77676 .29478 .78977 .28885 .7841 .28116 Mtetra
.704 .772 .905 r
.7841 .28116 .78977 .28885 .80285 .28312 .79722 .27531 Mtetra
.698 .767 .905 r
.79722 .27531 .80285 .28312 .816 .27759 .81041 .26966 Mtetra
.692 .762 .906 r
.81041 .26966 .816 .27759 .82922 .27222 .82367 .26419 Mtetra
.687 .758 .906 r
.82367 .26419 .82922 .27222 .84251 .26699 .837 .25886 Mtetra
.683 .755 .906 r
.837 .25886 .84251 .26699 .85587 .26187 .8504 .25366 Mtetra
.224 0 0 r
.23347 .50555 .24131 .50725 .25185 .5096 .24398 .5084 Mtetra
.296 0 0 r
.24398 .5084 .25185 .5096 .26244 .5122 .25456 .51152 Mtetra
.352 0 0 r
.25456 .51152 .26244 .5122 .27311 .51499 .26522 .51484 Mtetra
.393 0 0 r
.26522 .51484 .27311 .51499 .28386 .51791 .27596 .51829 Mtetra
.42 0 0 r
.27596 .51829 .28386 .51791 .29469 .52087 .28679 .52178 Mtetra
.435 0 0 r
.28679 .52178 .29469 .52087 .30562 .52378 .29772 .52521 Mtetra
.44 0 0 r
.29772 .52521 .30562 .52378 .31665 .52656 .30876 .52848 Mtetra
.435 0 0 r
.30876 .52848 .31665 .52656 .32778 .52908 .31991 .53146 Mtetra
.421 0 0 r
.31991 .53146 .32778 .52908 .33903 .53126 .33118 .53404 Mtetra
.398 0 0 r
.33118 .53404 .33903 .53126 .35039 .53297 .34258 .53612 Mtetra
.366 0 0 r
.34258 .53612 .35039 .53297 .36187 .53411 .35409 .53757 Mtetra
.323 0 0 r
.35409 .53757 .36187 .53411 .37346 .53459 .36573 .53829 Mtetra
.268 0 0 r
.36573 .53829 .37346 .53459 .38516 .53432 .37748 .53818 Mtetra
.201 0 0 r
.37748 .53818 .38516 .53432 .39697 .53322 .38935 .53717 Mtetra
.119 0 0 r
.38935 .53717 .39697 .53322 .40888 .53122 .40133 .53518 Mtetra
.023 0 0 r
.40133 .53518 .40888 .53122 .42089 .52829 .41341 .53218 Mtetra
0 0 0 r
.41341 .53218 .42089 .52829 .43298 .52441 .42558 .52814 Mtetra
.42558 .52814 .43298 .52441 .44515 .51955 .43783 .52306 Mtetra
.326 .784 .648 r
.43783 .52306 .44515 .51955 .45739 .51375 .45015 .51695 Mtetra
.443 .861 .712 r
.45015 .51695 .45739 .51375 .46968 .50705 .46252 .50987 Mtetra
.548 .92 .766 r
.46252 .50987 .46968 .50705 .48201 .49948 .47494 .50188 Mtetra
.636 .961 .806 r
.47494 .50188 .48201 .49948 .49438 .49114 .4874 .49306 Mtetra
.706 .985 .834 r
.4874 .49306 .49438 .49114 .50678 .48211 .49988 .4835 Mtetra
.759 .995 .853 r
.49988 .4835 .50678 .48211 .51919 .47248 .51238 .47331 Mtetra
.797 .996 .864 r
.51238 .47331 .51919 .47248 .53162 .46236 .52489 .46261 Mtetra
.823 .99 .87 r
.52489 .46261 .53162 .46236 .54405 .45187 .5374 .45151 Mtetra
.84 .98 .874 r
.5374 .45151 .54405 .45187 .55649 .44111 .54991 .44015 Mtetra
.849 .968 .876 r
.54991 .44015 .55649 .44111 .56893 .43019 .56242 .42863 Mtetra
.854 .954 .877 r
.56242 .42863 .56893 .43019 .58138 .41922 .57493 .41706 Mtetra
.854 .94 .878 r
.57493 .41706 .58138 .41922 .59383 .40829 .58744 .40556 Mtetra
.851 .926 .878 r
.58744 .40556 .59383 .40829 .60628 .39749 .59996 .39421 Mtetra
.846 .912 .88 r
.59996 .39421 .60628 .39749 .61875 .38689 .61248 .38308 Mtetra
.838 .898 .881 r
.61248 .38308 .61875 .38689 .63123 .37656 .62501 .37226 Mtetra
.83 .885 .883 r
.62501 .37226 .63123 .37656 .64373 .36655 .63756 .36179 Mtetra
.82 .872 .885 r
.63756 .36179 .64373 .36655 .65626 .35689 .65014 .3517 Mtetra
.809 .86 .887 r
.65014 .3517 .65626 .35689 .66882 .34762 .66274 .34203 Mtetra
.798 .848 .889 r
.66274 .34203 .66882 .34762 .68142 .33875 .67538 .3328 Mtetra
.786 .837 .891 r
.67538 .3328 .68142 .33875 .69406 .33028 .68806 .324 Mtetra
.775 .827 .893 r
.68806 .324 .69406 .33028 .70675 .32221 .70079 .31564 Mtetra
.763 .817 .895 r
.70079 .31564 .70675 .32221 .71949 .31452 .71357 .30769 Mtetra
.752 .807 .897 r
.71357 .30769 .71949 .31452 .73229 .30721 .72641 .30014 Mtetra
.742 .799 .898 r
.72641 .30014 .73229 .30721 .74514 .30024 .7393 .29296 Mtetra
.732 .791 .9 r
.7393 .29296 .74514 .30024 .75806 .2936 .75226 .28613 Mtetra
.722 .784 .901 r
.75226 .28613 .75806 .2936 .77105 .28725 .76528 .27962 Mtetra
.714 .777 .902 r
.76528 .27962 .77105 .28725 .7841 .28116 .77838 .27339 Mtetra
.706 .772 .903 r
.77838 .27339 .7841 .28116 .79722 .27531 .79154 .2674 Mtetra
.7 .767 .904 r
.79154 .2674 .79722 .27531 .81041 .26966 .80477 .26164 Mtetra
.694 .762 .905 r
.80477 .26164 .81041 .26966 .82367 .26419 .81807 .25607 Mtetra
.688 .759 .905 r
.81807 .25607 .82367 .26419 .837 .25886 .83144 .25065 Mtetra
.684 .755 .906 r
.83144 .25065 .837 .25886 .8504 .25366 .84488 .24537 Mtetra
.289 0 0 r
.22553 .50386 .23347 .50555 .24398 .5084 .23603 .50722 Mtetra
.354 0 0 r
.23603 .50722 .24398 .5084 .25456 .51152 .24659 .51086 Mtetra
.403 0 0 r
.24659 .51086 .25456 .51152 .26522 .51484 .25723 .51471 Mtetra
.438 0 0 r
.25723 .51471 .26522 .51484 .27596 .51829 .26797 .51869 Mtetra
.459 0 0 r
.26797 .51869 .27596 .51829 .28679 .52178 .27879 .5227 Mtetra
.47 0 0 r
.27879 .5227 .28679 .52178 .29772 .52521 .28973 .52664 Mtetra
.28973 .52664 .29772 .52521 .30876 .52848 .30077 .53038 Mtetra
.462 0 0 r
.30077 .53038 .30876 .52848 .31991 .53146 .31194 .5338 Mtetra
.444 0 0 r
.31194 .5338 .31991 .53146 .33118 .53404 .32323 .53678 Mtetra
.417 0 0 r
.32323 .53678 .33118 .53404 .34258 .53612 .33465 .5392 Mtetra
.38 0 0 r
.33465 .5392 .34258 .53612 .35409 .53757 .34621 .54094 Mtetra
.332 0 0 r
.34621 .54094 .35409 .53757 .36573 .53829 .35789 .54187 Mtetra
.271 0 0 r
.35789 .54187 .36573 .53829 .37748 .53818 .3697 .54191 Mtetra
.195 0 0 r
.3697 .54191 .37748 .53818 .38935 .53717 .38163 .54096 Mtetra
.103 0 0 r
.38163 .54096 .38935 .53717 .40133 .53518 .39368 .53896 Mtetra
0 0 0 r
.39368 .53896 .40133 .53518 .41341 .53218 .40583 .53586 Mtetra
.40583 .53586 .41341 .53218 .42558 .52814 .41808 .53164 Mtetra
.41808 .53164 .42558 .52814 .43783 .52306 .43041 .52631 Mtetra
.383 .825 .691 r
.43041 .52631 .43783 .52306 .45015 .51695 .44281 .51988 Mtetra
.502 .897 .752 r
.44281 .51988 .45015 .51695 .46252 .50987 .45527 .51242 Mtetra
.603 .948 .797 r
.45527 .51242 .46252 .50987 .47494 .50188 .46778 .50398 Mtetra
.685 .979 .829 r
.46778 .50398 .47494 .50188 .4874 .49306 .48033 .49466 Mtetra
.747 .994 .848 r
.48033 .49466 .4874 .49306 .49988 .4835 .49289 .48456 Mtetra
.791 .997 .86 r
.49289 .48456 .49988 .4835 .51238 .47331 .50548 .47381 Mtetra
.822 .992 .865 r
.50548 .47381 .51238 .47331 .52489 .46261 .51807 .46252 Mtetra
.843 .983 .867 r
.51807 .46252 .52489 .46261 .5374 .45151 .53066 .45083 Mtetra
.855 .971 .868 r
.53066 .45083 .5374 .45151 .54991 .44015 .54325 .43887 Mtetra
.862 .958 .868 r
.54325 .43887 .54991 .44015 .56242 .42863 .55583 .42676 Mtetra
.864 .944 .868 r
.55583 .42676 .56242 .42863 .57493 .41706 .56841 .41461 Mtetra
.863 .93 .868 r
.56841 .41461 .57493 .41706 .58744 .40556 .58098 .40255 Mtetra
.859 .917 .869 r
.58098 .40255 .58744 .40556 .59996 .39421 .59356 .39065 Mtetra
.852 .904 .87 r
.59356 .39065 .59996 .39421 .61248 .38308 .60614 .37902 Mtetra
.844 .891 .872 r
.60614 .37902 .61248 .38308 .62501 .37226 .61872 .36772 Mtetra
.835 .879 .874 r
.61872 .36772 .62501 .37226 .63756 .36179 .63132 .35679 Mtetra
.825 .867 .877 r
.63132 .35679 .63756 .36179 .65014 .3517 .64395 .3463 Mtetra
.814 .855 .879 r
.64395 .3463 .65014 .3517 .66274 .34203 .6566 .33625 Mtetra
.803 .844 .882 r
.6566 .33625 .66274 .34203 .67538 .3328 .66928 .32667 Mtetra
.791 .834 .885 r
.66928 .32667 .67538 .3328 .68806 .324 .682 .31756 Mtetra
.779 .824 .888 r
.682 .31756 .68806 .324 .70079 .31564 .69477 .30891 Mtetra
.767 .815 .89 r
.69477 .30891 .70079 .31564 .71357 .30769 .70759 .30071 Mtetra
.756 .806 .893 r
.70759 .30071 .71357 .30769 .72641 .30014 .72047 .29293 Mtetra
.745 .798 .895 r
.72047 .29293 .72641 .30014 .7393 .29296 .7334 .28556 Mtetra
.735 .79 .897 r
.7334 .28556 .7393 .29296 .75226 .28613 .7464 .27855 Mtetra
.725 .783 .899 r
.7464 .27855 .75226 .28613 .76528 .27962 .75947 .27188 Mtetra
.716 .777 .9 r
.75947 .27188 .76528 .27962 .77838 .27339 .7726 .26551 Mtetra
.708 .772 .901 r
.7726 .26551 .77838 .27339 .79154 .2674 .7858 .2594 Mtetra
.701 .767 .903 r
.7858 .2594 .79154 .2674 .80477 .26164 .79907 .25353 Mtetra
.695 .762 .904 r
.79907 .25353 .80477 .26164 .81807 .25607 .81241 .24786 Mtetra
.69 .759 .904 r
.81241 .24786 .81807 .25607 .83144 .25065 .82583 .24236 Mtetra
.685 .755 .905 r
.82583 .24236 .83144 .25065 .84488 .24537 .83932 .237 Mtetra
.342 0 0 r
.21751 .50213 .22553 .50386 .23603 .50722 .22798 .50599 Mtetra
.401 0 0 r
.22798 .50599 .23603 .50722 .24659 .51086 .23853 .51014 Mtetra
.444 0 0 r
.23853 .51014 .24659 .51086 .25723 .51471 .24916 .51451 Mtetra
.473 0 0 r
.24916 .51451 .25723 .51471 .26797 .51869 .25988 .51901 Mtetra
.49 0 0 r
.25988 .51901 .26797 .51869 .27879 .5227 .2707 .52352 Mtetra
.496 0 0 r
.2707 .52352 .27879 .5227 .28973 .52664 .28164 .52794 Mtetra
.493 0 0 r
.28164 .52794 .28973 .52664 .30077 .53038 .29269 .53213 Mtetra
.481 0 0 r
.29269 .53213 .30077 .53038 .31194 .5338 .30387 .53598 Mtetra
.46 0 0 r
.30387 .53598 .31194 .5338 .32323 .53678 .31518 .53933 Mtetra
.429 0 0 r
.31518 .53933 .32323 .53678 .33465 .5392 .32663 .54207 Mtetra
.387 0 0 r
.32663 .54207 .33465 .5392 .34621 .54094 .33822 .54406 Mtetra
.332 0 0 r
.33822 .54406 .34621 .54094 .35789 .54187 .34995 .54519 Mtetra
.263 0 0 r
.34995 .54519 .35789 .54187 .3697 .54191 .36182 .54534 Mtetra
.176 0 0 r
.36182 .54534 .3697 .54191 .38163 .54096 .37381 .54442 Mtetra
.072 0 0 r
.37381 .54442 .38163 .54096 .39368 .53896 .38592 .54238 Mtetra
0 0 0 r
.38592 .54238 .39368 .53896 .40583 .53586 .39815 .53916 Mtetra
.39815 .53916 .40583 .53586 .41808 .53164 .41048 .53475 Mtetra
.323 .79 .68 r
.41048 .53475 .41808 .53164 .43041 .52631 .42289 .52914 Mtetra
.455 .874 .748 r
.42289 .52914 .43041 .52631 .44281 .51988 .43538 .52238 Mtetra
.57 .934 .798 r
.43538 .52238 .44281 .51988 .45527 .51242 .44793 .51451 Mtetra
.663 .972 .832 r
.44793 .51451 .45527 .51242 .46778 .50398 .46053 .50561 Mtetra
.734 .991 .852 r
.46053 .50561 .46778 .50398 .48033 .49466 .47316 .49579 Mtetra
.785 .996 .862 r
.47316 .49579 .48033 .49466 .49289 .48456 .48582 .48516 Mtetra
.821 .993 .865 r
.48582 .48516 .49289 .48456 .50548 .47381 .49849 .47385 Mtetra
.844 .984 .865 r
.49849 .47385 .50548 .47381 .51807 .46252 .51116 .46198 Mtetra
.86 .971 .864 r
.51116 .46198 .51807 .46252 .53066 .45083 .52383 .44971 Mtetra
.868 .958 .862 r
.52383 .44971 .53066 .45083 .54325 .43887 .5365 .43716 Mtetra
.872 .945 .86 r
.5365 .43716 .54325 .43887 .55583 .42676 .54915 .42447 Mtetra
.872 .931 .859 r
.54915 .42447 .55583 .42676 .56841 .41461 .5618 .41177 Mtetra
.869 .918 .859 r
.5618 .41177 .56841 .41461 .58098 .40255 .57444 .39916 Mtetra
.864 .905 .86 r
.57444 .39916 .58098 .40255 .59356 .39065 .58708 .38675 Mtetra
.857 .893 .861 r
.58708 .38675 .59356 .39065 .60614 .37902 .59972 .37463 Mtetra
.849 .882 .863 r
.59972 .37463 .60614 .37902 .61872 .36772 .61236 .36287 Mtetra
.839 .87 .866 r
.61236 .36287 .61872 .36772 .63132 .35679 .62501 .35152 Mtetra
.829 .86 .869 r
.62501 .35152 .63132 .35679 .64395 .3463 .63769 .34063 Mtetra
.818 .849 .872 r
.63769 .34063 .64395 .3463 .6566 .33625 .65038 .33023 Mtetra
.806 .839 .875 r
.65038 .33023 .6566 .33625 .66928 .32667 .66311 .32032 Mtetra
.795 .83 .879 r
.66311 .32032 .66928 .32667 .682 .31756 .67588 .31092 Mtetra
.783 .821 .882 r
.67588 .31092 .682 .31756 .69477 .30891 .68869 .302 Mtetra
.771 .812 .886 r
.68869 .302 .69477 .30891 .70759 .30071 .70156 .29356 Mtetra
.759 .804 .889 r
.70156 .29356 .70759 .30071 .72047 .29293 .71447 .28558 Mtetra
.748 .796 .891 r
.71447 .28558 .72047 .29293 .7334 .28556 .72745 .27801 Mtetra
.737 .789 .894 r
.72745 .27801 .7334 .28556 .7464 .27855 .74049 .27084 Mtetra
.728 .782 .896 r
.74049 .27084 .7464 .27855 .75947 .27188 .75359 .26402 Mtetra
.718 .776 .898 r
.75359 .26402 .75947 .27188 .7726 .26551 .76677 .25752 Mtetra
.71 .771 .9 r
.76677 .25752 .7726 .26551 .7858 .2594 .78001 .25129 Mtetra
.703 .766 .901 r
.78001 .25129 .7858 .2594 .79907 .25353 .79332 .24532 Mtetra
.696 .762 .902 r
.79332 .24532 .79907 .25353 .81241 .24786 .80671 .23956 Mtetra
.691 .758 .903 r
.80671 .23956 .81241 .24786 .82583 .24236 .82017 .23397 Mtetra
.686 .755 .904 r
.82017 .23397 .82583 .24236 .83932 .237 .8337 .22854 Mtetra
.385 0 0 r
.20941 .50028 .21751 .50213 .22798 .50599 .21986 .50462 Mtetra
.438 0 0 r
.21986 .50462 .22798 .50599 .23853 .51014 .23039 .50927 Mtetra
.476 0 0 r
.23039 .50927 .23853 .51014 .24916 .51451 .241 .51414 Mtetra
.5 0 0 r
.241 .51414 .24916 .51451 .25988 .51901 .25171 .51912 Mtetra
.513 0 0 r
.25171 .51912 .25988 .51901 .2707 .52352 .26253 .52411 Mtetra
.516 0 0 r
.26253 .52411 .2707 .52352 .28164 .52794 .27346 .52899 Mtetra
.51 0 0 r
.27346 .52899 .28164 .52794 .29269 .53213 .28452 .53361 Mtetra
.494 0 0 r
.28452 .53361 .29269 .53213 .30387 .53598 .29571 .53784 Mtetra
.469 0 0 r
.29571 .53784 .30387 .53598 .31518 .53933 .30705 .54154 Mtetra
.434 0 0 r
.30705 .54154 .31518 .53933 .32663 .54207 .31853 .54457 Mtetra
.385 0 0 r
.31853 .54457 .32663 .54207 .33822 .54406 .33015 .54678 Mtetra
.323 0 0 r
.33015 .54678 .33822 .54406 .34995 .54519 .34193 .54806 Mtetra
.242 0 0 r
.34193 .54806 .34995 .54519 .36182 .54534 .35384 .54829 Mtetra
.142 0 0 r
.35384 .54829 .36182 .54534 .37381 .54442 .3659 .54738 Mtetra
.022 0 0 r
.3659 .54738 .37381 .54442 .38592 .54238 .37808 .54527 Mtetra
0 0 0 r
.37808 .54527 .38592 .54238 .39815 .53916 .39038 .54191 Mtetra
.263 .756 .68 r
.39038 .54191 .39815 .53916 .41048 .53475 .40279 .53727 Mtetra
.407 .851 .754 r
.40279 .53727 .41048 .53475 .42289 .52914 .41529 .53138 Mtetra
.535 .921 .809 r
.41529 .53138 .42289 .52914 .43538 .52238 .42786 .52426 Mtetra
.64 .966 .845 r
.42786 .52426 .43538 .52238 .44793 .51451 .4405 .51598 Mtetra
.72 .988 .864 r
.4405 .51598 .44793 .51451 .46053 .50561 .45319 .50663 Mtetra
.778 .995 .871 r
.45319 .50663 .46053 .50561 .47316 .49579 .46591 .49631 Mtetra
.818 .991 .871 r
.46591 .49631 .47316 .49579 .48582 .48516 .47865 .48515 Mtetra
.845 .981 .868 r
.47865 .48515 .48582 .48516 .49849 .47385 .49141 .47329 Mtetra
.862 .969 .863 r
.49141 .47329 .49849 .47385 .51116 .46198 .50417 .46086 Mtetra
.872 .955 .859 r
.50417 .46086 .51116 .46198 .52383 .44971 .51692 .44802 Mtetra
.877 .942 .855 r
.51692 .44802 .52383 .44971 .5365 .43716 .52966 .43491 Mtetra
.878 .928 .852 r
.52966 .43491 .5365 .43716 .54915 .42447 .5424 .42167 Mtetra
.877 .915 .85 r
.5424 .42167 .54915 .42447 .5618 .41177 .55512 .40843 Mtetra
.873 .903 .85 r
.55512 .40843 .5618 .41177 .57444 .39916 .56782 .39532 Mtetra
.867 .892 .85 r
.56782 .39532 .57444 .39916 .58708 .38675 .58052 .38242 Mtetra
.86 .881 .852 r
.58052 .38242 .58708 .38675 .59972 .37463 .59322 .36985 Mtetra
.852 .871 .854 r
.59322 .36985 .59972 .37463 .61236 .36287 .60592 .35766 Mtetra
.842 .861 .857 r
.60592 .35766 .61236 .36287 .62501 .35152 .61863 .34592 Mtetra
.832 .851 .861 r
.61863 .34592 .62501 .35152 .63769 .34063 .63135 .33467 Mtetra
.821 .842 .865 r
.63135 .33467 .63769 .34063 .65038 .33023 .6441 .32393 Mtetra
.809 .833 .869 r
.6441 .32393 .65038 .33023 .66311 .32032 .65688 .31372 Mtetra
.797 .825 .873 r
.65688 .31372 .66311 .32032 .67588 .31092 .66969 .30404 Mtetra
.785 .816 .877 r
.66969 .30404 .67588 .31092 .68869 .302 .68255 .29489 Mtetra
.773 .808 .881 r
.68255 .29489 .68869 .302 .70156 .29356 .69546 .28623 Mtetra
.762 .801 .885 r
.69546 .28623 .70156 .29356 .71447 .28558 .70842 .27805 Mtetra
.75 .794 .888 r
.70842 .27805 .71447 .28558 .72745 .27801 .72144 .27031 Mtetra
.74 .787 .891 r
.72144 .27031 .72745 .27801 .74049 .27084 .73452 .26298 Mtetra
.729 .781 .894 r
.73452 .26298 .74049 .27084 .75359 .26402 .74766 .25603 Mtetra
.72 .775 .896 r
.74766 .25603 .75359 .26402 .76677 .25752 .76088 .2494 Mtetra
.712 .77 .898 r
.76088 .2494 .76677 .25752 .78001 .25129 .77417 .24307 Mtetra
.704 .766 .9 r
.77417 .24307 .78001 .25129 .79332 .24532 .78752 .237 Mtetra
.697 .762 .901 r
.78752 .237 .79332 .24532 .80671 .23956 .80095 .23115 Mtetra
.692 .758 .903 r
.80095 .23115 .80671 .23956 .82017 .23397 .81445 .22549 Mtetra
.686 .755 .904 r
.81445 .22549 .82017 .23397 .8337 .22854 .82803 .21999 Mtetra
.417 0 0 r
.20123 .49823 .20941 .50028 .21986 .50462 .21167 .50303 Mtetra
.466 0 0 r
.21167 .50303 .21986 .50462 .23039 .50927 .22217 .50814 Mtetra
.499 0 0 r
.22217 .50814 .23039 .50927 .241 .51414 .23277 .51348 Mtetra
.52 0 0 r
.23277 .51348 .241 .51414 .25171 .51912 .24347 .51892 Mtetra
.53 0 0 r
.24347 .51892 .25171 .51912 .26253 .52411 .25428 .52436 Mtetra
.25428 .52436 .26253 .52411 .27346 .52899 .26521 .52965 Mtetra
.52 0 0 r
.26521 .52965 .27346 .52899 .28452 .53361 .27627 .53467 Mtetra
.501 0 0 r
.27627 .53467 .28452 .53361 .29571 .53784 .28748 .53925 Mtetra
.472 0 0 r
.28748 .53925 .29571 .53784 .30705 .54154 .29883 .54325 Mtetra
.43 0 0 r
.29883 .54325 .30705 .54154 .31853 .54457 .31034 .54652 Mtetra
.374 0 0 r
.31034 .54652 .31853 .54457 .33015 .54678 .32201 .54891 Mtetra
.301 0 0 r
.32201 .54891 .33015 .54678 .34193 .54806 .33383 .55031 Mtetra
.207 0 0 r
.33383 .55031 .34193 .54806 .35384 .54829 .34579 .55059 Mtetra
.09 0 0 r
.34579 .55059 .35384 .54829 .3659 .54738 .35791 .54966 Mtetra
0 0 0 r
.35791 .54966 .3659 .54738 .37808 .54527 .37016 .54744 Mtetra
.203 .721 .69 r
.37016 .54744 .37808 .54527 .39038 .54191 .38253 .54391 Mtetra
.359 .827 .771 r
.38253 .54391 .39038 .54191 .40279 .53727 .39502 .53903 Mtetra
.5 .907 .831 r
.39502 .53903 .40279 .53727 .41529 .53138 .4076 .53283 Mtetra
.617 .958 .867 r
.4076 .53283 .41529 .53138 .42786 .52426 .42026 .52535 Mtetra
.705 .984 .884 r
.42026 .52535 .42786 .52426 .4405 .51598 .43299 .51666 Mtetra
.769 .991 .887 r
.43299 .51666 .4405 .51598 .45319 .50663 .44577 .50685 Mtetra
.813 .987 .883 r
.44577 .50685 .45319 .50663 .46591 .49631 .45858 .49605 Mtetra
.842 .977 .875 r
.45858 .49605 .46591 .49631 .47865 .48515 .47141 .48438 Mtetra
.861 .963 .867 r
.47141 .48438 .47865 .48515 .49141 .47329 .48425 .47198 Mtetra
.873 .949 .859 r
.48425 .47198 .49141 .47329 .50417 .46086 .49709 .45902 Mtetra
.879 .935 .852 r
.49709 .45902 .50417 .46086 .51692 .44802 .50993 .44565 Mtetra
.882 .922 .846 r
.50993 .44565 .51692 .44802 .52966 .43491 .52275 .43201 Mtetra
.881 .91 .843 r
.52275 .43201 .52966 .43491 .5424 .42167 .53556 .41826 Mtetra
.879 .898 .841 r
.53556 .41826 .5424 .42167 .55512 .40843 .54835 .40453 Mtetra
.874 .887 .84 r
.54835 .40453 .55512 .40843 .56782 .39532 .56113 .39094 Mtetra
.868 .877 .841 r
.56113 .39094 .56782 .39532 .58052 .38242 .57389 .3776 Mtetra
.861 .868 .843 r
.57389 .3776 .58052 .38242 .59322 .36985 .58665 .3646 Mtetra
.853 .859 .845 r
.58665 .3646 .59322 .36985 .60592 .35766 .59941 .35203 Mtetra
.843 .85 .849 r
.59941 .35203 .60592 .35766 .61863 .34592 .61217 .33993 Mtetra
.833 .842 .853 r
.61217 .33993 .61863 .34592 .63135 .33467 .62495 .32835 Mtetra
.822 .834 .858 r
.62495 .32835 .63135 .33467 .6441 .32393 .63775 .31731 Mtetra
.811 .826 .862 r
.63775 .31731 .6441 .32393 .65688 .31372 .65058 .30684 Mtetra
.799 .819 .867 r
.65058 .30684 .65688 .31372 .66969 .30404 .66344 .29692 Mtetra
.787 .811 .872 r
.66344 .29692 .66969 .30404 .68255 .29489 .67634 .28754 Mtetra
.775 .804 .876 r
.67634 .28754 .68255 .29489 .69546 .28623 .68929 .27869 Mtetra
.763 .797 .881 r
.68929 .27869 .69546 .28623 .70842 .27805 .7023 .27033 Mtetra
.752 .791 .884 r
.7023 .27033 .70842 .27805 .72144 .27031 .71536 .26244 Mtetra
.741 .785 .888 r
.71536 .26244 .72144 .27031 .73452 .26298 .72849 .25498 Mtetra
.731 .779 .891 r
.72849 .25498 .73452 .26298 .74766 .25603 .74168 .2479 Mtetra
.722 .774 .894 r
.74168 .2479 .74766 .25603 .76088 .2494 .75494 .24116 Mtetra
.713 .769 .896 r
.75494 .24116 .76088 .2494 .77417 .24307 .76827 .23474 Mtetra
.705 .765 .898 r
.76827 .23474 .77417 .24307 .78752 .237 .78167 .22858 Mtetra
.698 .761 .9 r
.78167 .22858 .78752 .237 .80095 .23115 .79514 .22265 Mtetra
.692 .757 .902 r
.79514 .22265 .80095 .23115 .81445 .22549 .80869 .21691 Mtetra
.687 .755 .903 r
.80869 .21691 .81445 .22549 .82803 .21999 .82231 .21134 Mtetra
.44 0 0 r
.193 .4959 .20123 .49823 .21167 .50303 .20341 .50113 Mtetra
.485 0 0 r
.20341 .50113 .21167 .50303 .22217 .50814 .2139 .50667 Mtetra
.515 0 0 r
.2139 .50667 .22217 .50814 .23277 .51348 .22448 .51243 Mtetra
.533 0 0 r
.22448 .51243 .23277 .51348 .24347 .51892 .23516 .51829 Mtetra
.54 0 0 r
.23516 .51829 .24347 .51892 .25428 .52436 .24596 .52413 Mtetra
.537 0 0 r
.24596 .52413 .25428 .52436 .26521 .52965 .25689 .5298 Mtetra
.524 0 0 r
.25689 .5298 .26521 .52965 .27627 .53467 .26796 .53515 Mtetra
.501 0 0 r
.26796 .53515 .27627 .53467 .28748 .53925 .27918 .54004 Mtetra
.466 0 0 r
.27918 .54004 .28748 .53925 .29883 .54325 .29056 .54429 Mtetra
.417 0 0 r
.29056 .54429 .29883 .54325 .31034 .54652 .30209 .54776 Mtetra
.351 0 0 r
.30209 .54776 .31034 .54652 .32201 .54891 .31379 .55029 Mtetra
.263 0 0 r
.31379 .55029 .32201 .54891 .33383 .55031 .32566 .55176 Mtetra
.151 0 0 r
.32566 .55176 .33383 .55031 .34579 .55059 .33768 .55205 Mtetra
.013 0 0 r
.33768 .55205 .34579 .55059 .35791 .54966 .34985 .55106 Mtetra
.145 .685 .71 r
.34985 .55106 .35791 .54966 .37016 .54744 .36217 .54871 Mtetra
.309 .8 .796 r
.36217 .54871 .37016 .54744 .38253 .54391 .37462 .54498 Mtetra
.462 .889 .86 r
.37462 .54498 .38253 .54391 .39502 .53903 .38718 .53985 Mtetra
.59 .947 .896 r
.38718 .53985 .39502 .53903 .4076 .53283 .39984 .53333 Mtetra
.688 .975 .91 r
.39984 .53333 .4076 .53283 .42026 .52535 .41259 .52549 Mtetra
.757 .983 .908 r
.41259 .52549 .42026 .52535 .43299 .51666 .42541 .51639 Mtetra
.805 .979 .899 r
.42541 .51639 .43299 .51666 .44577 .50685 .43827 .50614 Mtetra
.837 .968 .886 r
.43827 .50614 .44577 .50685 .45858 .49605 .45117 .49486 Mtetra
.858 .954 .873 r
.45117 .49486 .45858 .49605 .47141 .48438 .46409 .48271 Mtetra
.871 .94 .861 r
.46409 .48271 .47141 .48438 .48425 .47198 .47702 .46982 Mtetra
.878 .925 .851 r
.47702 .46982 .48425 .47198 .49709 .45902 .48994 .45636 Mtetra
.882 .912 .843 r
.48994 .45636 .49709 .45902 .50993 .44565 .50286 .44249 Mtetra
.883 .9 .837 r
.50286 .44249 .50993 .44565 .52275 .43201 .51576 .42837 Mtetra
.881 .889 .833 r
.51576 .42837 .52275 .43201 .53556 .41826 .52864 .41414 Mtetra
.878 .879 .831 r
.52864 .41414 .53556 .41826 .54835 .40453 .54151 .39996 Mtetra
.873 .87 .831 r
.54151 .39996 .54835 .40453 .56113 .39094 .55435 .38595 Mtetra
.867 .861 .832 r
.55435 .38595 .56113 .39094 .57389 .3776 .56718 .37221 Mtetra
.86 .853 .834 r
.56718 .37221 .57389 .3776 .58665 .3646 .58 .35885 Mtetra
.852 .846 .837 r
.58 .35885 .58665 .3646 .59941 .35203 .59282 .34593 Mtetra
.843 .839 .841 r
.59282 .34593 .59941 .35203 .61217 .33993 .60564 .33352 Mtetra
.833 .832 .846 r
.60564 .33352 .61217 .33993 .62495 .32835 .61848 .32165 Mtetra
.822 .825 .851 r
.61848 .32165 .62495 .32835 .63775 .31731 .63133 .31035 Mtetra
.811 .818 .856 r
.63133 .31035 .63775 .31731 .65058 .30684 .6442 .29964 Mtetra
.8 .812 .861 r
.6442 .29964 .65058 .30684 .66344 .29692 .65711 .28951 Mtetra
.788 .806 .867 r
.65711 .28951 .66344 .29692 .67634 .28754 .67007 .27994 Mtetra
.776 .799 .872 r
.67007 .27994 .67634 .28754 .68929 .27869 .68306 .27092 Mtetra
.764 .793 .877 r
.68306 .27092 .68929 .27869 .7023 .27033 .69612 .26242 Mtetra
.753 .788 .881 r
.69612 .26242 .7023 .27033 .71536 .26244 .70922 .25439 Mtetra
.742 .782 .885 r
.70922 .25439 .71536 .26244 .72849 .25498 .72239 .2468 Mtetra
.732 .777 .889 r
.72239 .2468 .72849 .25498 .74168 .2479 .73563 .23962 Mtetra
.722 .772 .892 r
.73563 .23962 .74168 .2479 .75494 .24116 .74893 .23279 Mtetra
.714 .768 .895 r
.74893 .23279 .75494 .24116 .76827 .23474 .76231 .22627 Mtetra
.706 .764 .897 r
.76231 .22627 .76827 .23474 .78167 .22858 .77576 .22003 Mtetra
.699 .76 .899 r
.77576 .22003 .78167 .22858 .79514 .22265 .78927 .21403 Mtetra
.693 .757 .901 r
.78927 .21403 .79514 .22265 .80869 .21691 .80287 .20823 Mtetra
.688 .754 .902 r
.80287 .20823 .80869 .21691 .82231 .21134 .81653 .2026 Mtetra
.454 0 0 r
.18471 .4932 .193 .4959 .20341 .50113 .1951 .49881 Mtetra
.495 0 0 r
.1951 .49881 .20341 .50113 .2139 .50667 .20557 .50474 Mtetra
.523 0 0 r
.20557 .50474 .2139 .50667 .22448 .51243 .21613 .51088 Mtetra
.538 0 0 r
.21613 .51088 .22448 .51243 .23516 .51829 .2268 .51711 Mtetra
.543 0 0 r
.2268 .51711 .23516 .51829 .24596 .52413 .23759 .52329 Mtetra
.537 0 0 r
.23759 .52329 .24596 .52413 .25689 .5298 .24852 .52928 Mtetra
.52 0 0 r
.24852 .52928 .25689 .5298 .26796 .53515 .2596 .53493 Mtetra
.492 0 0 r
.2596 .53493 .26796 .53515 .27918 .54004 .27083 .54006 Mtetra
.45 0 0 r
.27083 .54006 .27918 .54004 .29056 .54429 .28223 .54451 Mtetra
.391 0 0 r
.28223 .54451 .29056 .54429 .30209 .54776 .29379 .54812 Mtetra
.311 0 0 r
.29379 .54812 .30209 .54776 .31379 .55029 .30553 .55075 Mtetra
.205 0 0 r
.30553 .55075 .31379 .55029 .32566 .55176 .31744 .55225 Mtetra
.071 0 0 r
.31744 .55225 .32566 .55176 .33768 .55205 .32951 .5525 Mtetra
.088 .647 .735 r
.32951 .5525 .33768 .55205 .34985 .55106 .34175 .55141 Mtetra
.259 .769 .827 r
.34175 .55141 .34985 .55106 .36217 .54871 .35413 .54891 Mtetra
.422 .865 .893 r
.35413 .54891 .36217 .54871 .37462 .54498 .36665 .54496 Mtetra
.56 .928 .929 r
.36665 .54496 .37462 .54498 .38718 .53985 .37929 .53955 Mtetra
.665 .96 .939 r
.37929 .53955 .38718 .53985 .39984 .53333 .39203 .53272 Mtetra
.741 .969 .932 r
.39203 .53272 .39984 .53333 .41259 .52549 .40486 .52451 Mtetra
.793 .965 .917 r
.40486 .52451 .41259 .52549 .42541 .51639 .41776 .51501 Mtetra
.827 .954 .899 r
.41776 .51501 .42541 .51639 .43827 .50614 .43071 .50434 Mtetra
.85 .94 .881 r
.43071 .50434 .43827 .50614 .45117 .49486 .44369 .49262 Mtetra
.865 .925 .865 r
.44369 .49262 .45117 .49486 .46409 .48271 .4567 .48001 Mtetra
.874 .912 .852 r
.4567 .48001 .46409 .48271 .47702 .46982 .46971 .46666 Mtetra
.879 .899 .841 r
.46971 .46666 .47702 .46982 .48994 .45636 .48272 .45275 Mtetra
.881 .887 .833 r
.48272 .45275 .48994 .45636 .50286 .44249 .49572 .43843 Mtetra
.88 .877 .827 r
.49572 .43843 .50286 .44249 .51576 .42837 .50869 .42388 Mtetra
.878 .867 .824 r
.50869 .42388 .51576 .42837 .52864 .41414 .52165 .40925 Mtetra
.875 .859 .822 r
.52165 .40925 .52864 .41414 .54151 .39996 .53459 .39467 Mtetra
.87 .852 .822 r
.53459 .39467 .54151 .39996 .55435 .38595 .5475 .38029 Mtetra
.865 .845 .823 r
.5475 .38029 .55435 .38595 .56718 .37221 .5604 .36621 Mtetra
.858 .838 .825 r
.5604 .36621 .56718 .37221 .58 .35885 .57328 .35253 Mtetra
.85 .832 .829 r
.57328 .35253 .58 .35885 .59282 .34593 .58616 .33932 Mtetra
.841 .826 .834 r
.58616 .33932 .59282 .34593 .60564 .33352 .59904 .32664 Mtetra
.832 .821 .839 r
.59904 .32664 .60564 .33352 .61848 .32165 .61193 .31453 Mtetra
.821 .816 .844 r
.61193 .31453 .61848 .32165 .63133 .31035 .62483 .30302 Mtetra
.811 .81 .85 r
.62483 .30302 .63133 .31035 .6442 .29964 .63776 .29211 Mtetra
.799 .805 .856 r
.63776 .29211 .6442 .29964 .65711 .28951 .65072 .2818 Mtetra
.788 .799 .862 r
.65072 .2818 .65711 .28951 .67007 .27994 .66372 .27208 Mtetra
.776 .794 .868 r
.66372 .27208 .67007 .27994 .68306 .27092 .67677 .26292 Mtetra
.765 .789 .873 r
.67677 .26292 .68306 .27092 .69612 .26242 .68987 .25429 Mtetra
.753 .784 .878 r
.68987 .25429 .69612 .26242 .70922 .25439 .70303 .24615 Mtetra
.743 .779 .882 r
.70303 .24615 .70922 .25439 .72239 .2468 .71624 .23846 Mtetra
.732 .774 .886 r
.71624 .23846 .72239 .2468 .73563 .23962 .72952 .23118 Mtetra
.723 .77 .89 r
.72952 .23118 .73563 .23962 .74893 .23279 .74288 .22427 Mtetra
.714 .766 .893 r
.74288 .22427 .74893 .23279 .76231 .22627 .7563 .21768 Mtetra
.706 .762 .896 r
.7563 .21768 .76231 .22627 .77576 .22003 .76979 .21137 Mtetra
.699 .759 .898 r
.76979 .21137 .77576 .22003 .78927 .21403 .78335 .2053 Mtetra
.693 .756 .9 r
.78335 .2053 .78927 .21403 .80287 .20823 .79699 .19944 Mtetra
.688 .753 .901 r
.79699 .19944 .80287 .20823 .81653 .2026 .81071 .19375 Mtetra
.459 0 0 r
.17637 .49005 .18471 .4932 .1951 .49881 .18674 .496 Mtetra
.497 0 0 r
.18674 .496 .1951 .49881 .20557 .50474 .19719 .50225 Mtetra
.522 0 0 r
.19719 .50225 .20557 .50474 .21613 .51088 .20774 .50871 Mtetra
.535 0 0 r
.20774 .50871 .21613 .51088 .2268 .51711 .2184 .51525 Mtetra
.537 0 0 r
.2184 .51525 .2268 .51711 .23759 .52329 .22919 .52173 Mtetra
.527 0 0 r
.22919 .52173 .23759 .52329 .24852 .52928 .24012 .52798 Mtetra
.506 0 0 r
.24012 .52798 .24852 .52928 .2596 .53493 .2512 .53385 Mtetra
.471 0 0 r
.2512 .53385 .2596 .53493 .27083 .54006 .26245 .53916 Mtetra
.419 0 0 r
.26245 .53916 .27083 .54006 .28223 .54451 .27387 .54376 Mtetra
.346 0 0 r
.27387 .54376 .28223 .54451 .29379 .54812 .28546 .54746 Mtetra
.247 0 0 r
.28546 .54746 .29379 .54812 .30553 .55075 .29723 .55012 Mtetra
.119 0 0 r
.29723 .55012 .30553 .55075 .31744 .55225 .30918 .5516 Mtetra
.036 .605 .763 r
.30918 .5516 .31744 .55225 .32951 .5525 .32131 .55177 Mtetra
.209 .729 .858 r
.32131 .55177 .32951 .5525 .34175 .55141 .3336 .55055 Mtetra
.378 .831 .926 r
.3336 .55055 .34175 .55141 .35413 .54891 .34605 .54786 Mtetra
.523 .899 .96 r
.34605 .54786 .35413 .54891 .36665 .54496 .35863 .54368 Mtetra
.636 .934 .967 r
.35863 .54368 .36665 .54496 .37929 .53955 .37135 .53799 Mtetra
.718 .946 .955 r
.37135 .53799 .37929 .53955 .39203 .53272 .38417 .53084 Mtetra
.774 .943 .934 r
.38417 .53084 .39203 .53272 .40486 .52451 .39708 .52228 Mtetra
.812 .933 .912 r
.39708 .52228 .40486 .52451 .41776 .51501 .41006 .5124 Mtetra
.837 .92 .89 r
.41006 .5124 .41776 .51501 .43071 .50434 .42309 .50133 Mtetra
.853 .907 .87 r
.42309 .50133 .43071 .50434 .44369 .49262 .43616 .48921 Mtetra
.864 .894 .854 r
.43616 .48921 .44369 .49262 .4567 .48001 .44925 .47618 Mtetra
.871 .882 .841 r
.44925 .47618 .4567 .48001 .46971 .46666 .46234 .46243 Mtetra
.874 .871 .83 r
.46234 .46243 .46971 .46666 .48272 .45275 .47543 .44811 Mtetra
.876 .861 .823 r
.47543 .44811 .48272 .45275 .49572 .43843 .4885 .43341 Mtetra
.875 .853 .817 r
.4885 .43341 .49572 .43843 .50869 .42388 .50156 .41848 Mtetra
.873 .846 .814 r
.50156 .41848 .50869 .42388 .52165 .40925 .51459 .4035 Mtetra
.87 .839 .812 r
.51459 .4035 .52165 .40925 .53459 .39467 .52759 .38859 Mtetra
.866 .833 .813 r
.52759 .38859 .53459 .39467 .5475 .38029 .54058 .37391 Mtetra
.86 .828 .814 r
.54058 .37391 .5475 .38029 .5604 .36621 .55354 .35954 Mtetra
.854 .823 .818 r
.55354 .35954 .5604 .36621 .57328 .35253 .56649 .3456 Mtetra
.846 .819 .822 r
.56649 .3456 .57328 .35253 .58616 .33932 .57943 .33216 Mtetra
.838 .814 .827 r
.57943 .33216 .58616 .33932 .59904 .32664 .59236 .31927 Mtetra
.829 .81 .832 r
.59236 .31927 .59904 .32664 .61193 .31453 .60531 .30697 Mtetra
.819 .806 .838 r
.60531 .30697 .61193 .31453 .62483 .30302 .61827 .29529 Mtetra
.809 .802 .845 r
.61827 .29529 .62483 .30302 .63776 .29211 .63125 .28422 Mtetra
.798 .797 .851 r
.63125 .28422 .63776 .29211 .65072 .2818 .64427 .27378 Mtetra
.787 .793 .857 r
.64427 .27378 .65072 .2818 .66372 .27208 .65732 .26393 Mtetra
.776 .789 .864 r
.65732 .26393 .66372 .27208 .67677 .26292 .67041 .25466 Mtetra
.764 .784 .869 r
.67041 .25466 .67677 .26292 .68987 .25429 .68356 .24593 Mtetra
.753 .78 .875 r
.68356 .24593 .68987 .25429 .70303 .24615 .69676 .2377 Mtetra
.743 .776 .88 r
.69676 .2377 .70303 .24615 .71624 .23846 .71003 .22994 Mtetra
.733 .772 .884 r
.71003 .22994 .71624 .23846 .72952 .23118 .72336 .22259 Mtetra
.723 .768 .888 r
.72336 .22259 .72952 .23118 .74288 .22427 .73676 .2156 Mtetra
.714 .764 .892 r
.73676 .2156 .74288 .22427 .7563 .21768 .75022 .20895 Mtetra
.706 .761 .894 r
.75022 .20895 .7563 .21768 .76979 .21137 .76376 .20258 Mtetra
.699 .758 .897 r
.76376 .20258 .76979 .21137 .78335 .2053 .77738 .19646 Mtetra
.693 .755 .899 r
.77738 .19646 .78335 .2053 .79699 .19944 .79106 .19055 Mtetra
.688 .753 .901 r
.79106 .19055 .79699 .19944 .81071 .19375 .80482 .18481 Mtetra
.453 0 0 r
.168 .48638 .17637 .49005 .18674 .496 .17835 .49259 Mtetra
.489 0 0 r
.17835 .49259 .18674 .496 .19719 .50225 .18879 .49912 Mtetra
.512 0 0 r
.18879 .49912 .19719 .50225 .20774 .50871 .19933 .50584 Mtetra
.522 0 0 r
.19933 .50584 .20774 .50871 .2184 .51525 .20998 .51262 Mtetra
.52 0 0 r
.20998 .51262 .2184 .51525 .22919 .52173 .22076 .51931 Mtetra
.506 0 0 r
.22076 .51931 .22919 .52173 .24012 .52798 .2317 .52576 Mtetra
.477 0 0 r
.2317 .52576 .24012 .52798 .2512 .53385 .24279 .53178 Mtetra
.433 0 0 r
.24279 .53178 .2512 .53385 .26245 .53916 .25405 .53722 Mtetra
.367 0 0 r
.25405 .53722 .26245 .53916 .27387 .54376 .26548 .54189 Mtetra
.277 0 0 r
.26548 .54189 .27387 .54376 .28546 .54746 .27711 .54562 Mtetra
.157 0 0 r
.27711 .54562 .28546 .54746 .29723 .55012 .28892 .54826 Mtetra
0 .559 .789 r
.28892 .54826 .29723 .55012 .30918 .5516 .30091 .54967 Mtetra
.161 .682 .883 r
.30091 .54967 .30918 .5516 .32131 .55177 .31308 .54973 Mtetra
.331 .785 .95 r
.31308 .54973 .32131 .55177 .3336 .55055 .32543 .54834 Mtetra
.481 .857 .984 r
.32543 .54834 .3336 .55055 .34605 .54786 .33794 .54545 Mtetra
.6 .897 .988 r
.33794 .54545 .34605 .54786 .35863 .54368 .35059 .54101 Mtetra
.687 .912 .973 r
.35059 .54101 .35863 .54368 .37135 .53799 .36337 .53504 Mtetra
.747 .913 .948 r
.36337 .53504 .37135 .53799 .38417 .53084 .37627 .52757 Mtetra
.789 .905 .922 r
.37627 .52757 .38417 .53084 .39708 .52228 .38926 .51867 Mtetra
.818 .895 .897 r
.38926 .51867 .39708 .52228 .41006 .5124 .40232 .50844 Mtetra
.837 .883 .875 r
.40232 .50844 .41006 .5124 .42309 .50133 .41543 .49701 Mtetra
.85 .871 .856 r
.41543 .49701 .42309 .50133 .43616 .48921 .42858 .48452 Mtetra
.859 .861 .841 r
.42858 .48452 .43616 .48921 .44925 .47618 .44174 .47114 Mtetra
.864 .851 .828 r
.44174 .47114 .44925 .47618 .46234 .46243 .45492 .45703 Mtetra
.867 .843 .819 r
.45492 .45703 .46234 .46243 .47543 .44811 .46808 .44237 Mtetra
.868 .836 .812 r
.46808 .44237 .47543 .44811 .4885 .43341 .48123 .42735 Mtetra
.868 .829 .807 r
.48123 .42735 .4885 .43341 .50156 .41848 .49436 .41212 Mtetra
.866 .824 .804 r
.49436 .41212 .50156 .41848 .51459 .4035 .50746 .39685 Mtetra
.863 .819 .804 r
.50746 .39685 .51459 .4035 .52759 .38859 .52053 .38169 Mtetra
.86 .815 .804 r
.52053 .38169 .52759 .38859 .54058 .37391 .53358 .36676 Mtetra
.855 .811 .807 r
.53358 .36676 .54058 .37391 .55354 .35954 .54661 .35218 Mtetra
.849 .808 .81 r
.54661 .35218 .55354 .35954 .56649 .3456 .55962 .33805 Mtetra
.842 .805 .815 r
.55962 .33805 .56649 .3456 .57943 .33216 .57262 .32443 Mtetra
.834 .802 .82 r
.57262 .32443 .57943 .33216 .59236 .31927 .58562 .31138 Mtetra
.826 .799 .826 r
.58562 .31138 .59236 .31927 .60531 .30697 .59862 .29895 Mtetra
.816 .796 .833 r
.59862 .29895 .60531 .30697 .61827 .29529 .61164 .28714 Mtetra
.807 .793 .839 r
.61164 .28714 .61827 .29529 .63125 .28422 .62467 .27597 Mtetra
.796 .79 .846 r
.62467 .27597 .63125 .28422 .64427 .27378 .63774 .26543 Mtetra
.785 .786 .853 r
.63774 .26543 .64427 .27378 .65732 .26393 .65084 .2555 Mtetra
.774 .783 .86 r
.65084 .2555 .65732 .26393 .67041 .25466 .66399 .24615 Mtetra
.763 .779 .866 r
.66399 .24615 .67041 .25466 .68356 .24593 .67719 .23735 Mtetra
.753 .776 .872 r
.67719 .23735 .68356 .24593 .69676 .2377 .69044 .22906 Mtetra
.742 .772 .877 r
.69044 .22906 .69676 .2377 .71003 .22994 .70376 .22123 Mtetra
.732 .769 .882 r
.70376 .22123 .71003 .22994 .72336 .22259 .71713 .21382 Mtetra
.723 .765 .886 r
.71713 .21382 .72336 .22259 .73676 .2156 .73058 .20679 Mtetra
.714 .762 .89 r
.73058 .20679 .73676 .2156 .75022 .20895 .7441 .20009 Mtetra
.706 .759 .893 r
.7441 .20009 .75022 .20895 .76376 .20258 .75768 .19367 Mtetra
.699 .756 .896 r
.75768 .19367 .76376 .20258 .77738 .19646 .77134 .1875 Mtetra
.693 .754 .898 r
.77134 .1875 .77738 .19646 .79106 .19055 .78508 .18154 Mtetra
.688 .752 .9 r
.78508 .18154 .79106 .19055 .80482 .18481 .79889 .17576 Mtetra
.436 0 0 r
.15961 .4821 .168 .48638 .17835 .49259 .16995 .48852 Mtetra
.469 0 0 r
.16995 .48852 .17835 .49259 .18879 .49912 .18037 .49525 Mtetra
.489 0 0 r
.18037 .49525 .18879 .49912 .19933 .50584 .1909 .50216 Mtetra
.496 0 0 r
.1909 .50216 .19933 .50584 .20998 .51262 .20155 .50911 Mtetra
.489 0 0 r
.20155 .50911 .20998 .51262 .22076 .51931 .21233 .51595 Mtetra
.468 0 0 r
.21233 .51595 .22076 .51931 .2317 .52576 .22327 .52251 Mtetra
.43 0 0 r
.22327 .52251 .2317 .52576 .24279 .53178 .23437 .52862 Mtetra
.372 0 0 r
.23437 .52862 .24279 .53178 .25405 .53722 .24564 .53411 Mtetra
.29 0 0 r
.24564 .53411 .25405 .53722 .26548 .54189 .2571 .53878 Mtetra
0 .399 .714 r
.2571 .53878 .26548 .54189 .27711 .54562 .26875 .54249 Mtetra
0 .512 .81 r
.26875 .54249 .27711 .54562 .28892 .54826 .2806 .54505 Mtetra
.119 .628 .898 r
.2806 .54505 .28892 .54826 .30091 .54967 .29263 .54634 Mtetra
.284 .728 .962 r
.29263 .54634 .30091 .54967 .31308 .54973 .30486 .54624 Mtetra
.434 .802 .995 r
.30486 .54624 .31308 .54973 .32543 .54834 .31726 .54466 Mtetra
.556 .847 .998 r
.31726 .54466 .32543 .54834 .33794 .54545 .32982 .54153 Mtetra
.647 .868 .982 r
.32982 .54153 .33794 .54545 .35059 .54101 .34254 .53684 Mtetra
.713 .873 .956 r
.34254 .53684 .35059 .54101 .36337 .53504 .35539 .53058 Mtetra
.76 .87 .928 r
.35539 .53058 .36337 .53504 .37627 .52757 .36835 .52281 Mtetra
.792 .863 .902 r
.36835 .52281 .37627 .52757 .38926 .51867 .38141 .5136 Mtetra
.815 .854 .878 r
.38141 .5136 .38926 .51867 .40232 .50844 .39454 .50305 Mtetra
.831 .845 .857 r
.39454 .50305 .40232 .50844 .41543 .49701 .40773 .4913 Mtetra
.842 .836 .84 r
.40773 .4913 .41543 .49701 .42858 .48452 .42095 .47849 Mtetra
.85 .829 .826 r
.42095 .47849 .42858 .48452 .44174 .47114 .43419 .46481 Mtetra
.855 .822 .815 r
.43419 .46481 .44174 .47114 .45492 .45703 .44744 .45041 Mtetra
.858 .816 .807 r
.44744 .45041 .45492 .45703 .46808 .44237 .46068 .43548 Mtetra
.859 .811 .801 r
.46068 .43548 .46808 .44237 .48123 .42735 .4739 .4202 Mtetra
.859 .807 .797 r
.4739 .4202 .48123 .42735 .49436 .41212 .4871 .40475 Mtetra
.858 .803 .796 r
.4871 .40475 .49436 .41212 .50746 .39685 .50027 .38927 Mtetra
.856 .8 .795 r
.50027 .38927 .50746 .39685 .52053 .38169 .51341 .37392 Mtetra
.852 .798 .797 r
.51341 .37392 .52053 .38169 .53358 .36676 .52652 .35883 Mtetra
.848 .795 .8 r
.52652 .35883 .53358 .36676 .54661 .35218 .53962 .34411 Mtetra
.843 .793 .803 r
.53962 .34411 .54661 .35218 .55962 .33805 .55269 .32985 Mtetra
.837 .792 .808 r
.55269 .32985 .55962 .33805 .57262 .32443 .56575 .31612 Mtetra
.829 .79 .814 r
.56575 .31612 .57262 .32443 .58562 .31138 .5788 .30298 Mtetra
.822 .788 .821 r
.5788 .30298 .58562 .31138 .59862 .29895 .59186 .29046 Mtetra
.813 .786 .828 r
.59186 .29046 .59862 .29895 .61164 .28714 .60494 .27858 Mtetra
.803 .784 .835 r
.60494 .27858 .61164 .28714 .62467 .27597 .61803 .26735 Mtetra
.793 .782 .842 r
.61803 .26735 .62467 .27597 .63774 .26543 .63115 .25675 Mtetra
.783 .78 .85 r
.63115 .25675 .63774 .26543 .65084 .2555 .6443 .24677 Mtetra
.772 .777 .857 r
.6443 .24677 .65084 .2555 .66399 .24615 .6575 .23738 Mtetra
.762 .774 .863 r
.6575 .23738 .66399 .24615 .67719 .23735 .67075 .22854 Mtetra
.751 .772 .87 r
.67075 .22854 .67719 .23735 .69044 .22906 .68406 .22021 Mtetra
.741 .769 .875 r
.68406 .22021 .69044 .22906 .70376 .22123 .69742 .21234 Mtetra
.731 .766 .88 r
.69742 .21234 .70376 .22123 .71713 .21382 .71085 .2049 Mtetra
.722 .763 .885 r
.71085 .2049 .71713 .21382 .73058 .20679 .72434 .19783 Mtetra
.714 .76 .889 r
.72434 .19783 .73058 .20679 .7441 .20009 .73791 .19109 Mtetra
.706 .757 .892 r
.73791 .19109 .7441 .20009 .75768 .19367 .75154 .18464 Mtetra
.699 .755 .895 r
.75154 .18464 .75768 .19367 .77134 .1875 .76525 .17843 Mtetra
.693 .753 .898 r
.76525 .17843 .77134 .1875 .78508 .18154 .77904 .17243 Mtetra
.688 .751 .9 r
.77904 .17243 .78508 .18154 .79889 .17576 .7929 .1666 Mtetra
.407 0 0 r
.15121 .47715 .15961 .4821 .16995 .48852 .16153 .48372 Mtetra
.437 0 0 r
.16153 .48372 .16995 .48852 .18037 .49525 .17195 .49057 Mtetra
.453 0 0 r
.17195 .49057 .18037 .49525 .1909 .50216 .18247 .4976 Mtetra
.454 0 0 r
.18247 .4976 .1909 .50216 .20155 .50911 .19312 .50464 Mtetra
.44 0 0 r
.19312 .50464 .20155 .50911 .21233 .51595 .2039 .51155 Mtetra
.41 0 0 r
.2039 .51155 .21233 .51595 .22327 .52251 .21484 .51815 Mtetra
.36 0 0 r
.21484 .51815 .22327 .52251 .23437 .52862 .22596 .52427 Mtetra
0 .282 .661 r
.22596 .52427 .23437 .52862 .24564 .53411 .23725 .52973 Mtetra
0 .368 .739 r
.23725 .52973 .24564 .53411 .2571 .53878 .24873 .53435 Mtetra
0 .468 .823 r
.24873 .53435 .2571 .53878 .26875 .54249 .26041 .53795 Mtetra
.086 .571 .902 r
.26041 .53795 .26875 .54249 .2806 .54505 .27229 .54039 Mtetra
.241 .665 .96 r
.27229 .54039 .2806 .54505 .29263 .54634 .28437 .54152 Mtetra
.385 .738 .991 r
.28437 .54152 .29263 .54634 .30486 .54624 .29664 .54122 Mtetra
.507 .787 .996 r
.29664 .54122 .30486 .54624 .31726 .54466 .30909 .53941 Mtetra
.602 .814 .981 r
.30909 .53941 .31726 .54466 .32982 .54153 .32171 .53604 Mtetra
.673 .826 .957 r
.32171 .53604 .32982 .54153 .34254 .53684 .33448 .53108 Mtetra
.724 .828 .93 r
.33448 .53108 .34254 .53684 .35539 .53058 .34739 .52454 Mtetra
.761 .826 .903 r
.34739 .52454 .35539 .53058 .36835 .52281 .36042 .51649 Mtetra
.788 .821 .878 r
.36042 .51649 .36835 .52281 .38141 .5136 .37355 .50699 Mtetra
.807 .815 .857 r
.37355 .50699 .38141 .5136 .39454 .50305 .38675 .49616 Mtetra
.821 .809 .839 r
.38675 .49616 .39454 .50305 .40773 .4913 .40001 .48414 Mtetra
.832 .803 .824 r
.40001 .48414 .40773 .4913 .42095 .47849 .4133 .47108 Mtetra
.839 .798 .812 r
.4133 .47108 .42095 .47849 .43419 .46481 .42661 .45715 Mtetra
.844 .794 .803 r
.42661 .45715 .43419 .46481 .44744 .45041 .43992 .44254 Mtetra
.847 .791 .796 r
.43992 .44254 .44744 .45041 .46068 .43548 .45323 .42741 Mtetra
.849 .788 .791 r
.45323 .42741 .46068 .43548 .4739 .4202 .46652 .41196 Mtetra
.85 .785 .788 r
.46652 .41196 .4739 .4202 .4871 .40475 .47978 .39635 Mtetra
.849 .783 .787 r
.47978 .39635 .4871 .40475 .50027 .38927 .49302 .38075 Mtetra
.847 .782 .788 r
.49302 .38075 .50027 .38927 .51341 .37392 .50623 .36529 Mtetra
.845 .781 .79 r
.50623 .36529 .51341 .37392 .52652 .35883 .5194 .35011 Mtetra
.841 .78 .793 r
.5194 .35011 .52652 .35883 .53962 .34411 .53256 .33531 Mtetra
.836 .779 .798 r
.53256 .33531 .53962 .34411 .55269 .32985 .54569 .32099 Mtetra
.831 .779 .803 r
.54569 .32099 .55269 .32985 .56575 .31612 .55881 .30722 Mtetra
.824 .778 .809 r
.55881 .30722 .56575 .31612 .5788 .30298 .57192 .29404 Mtetra
.817 .778 .816 r
.57192 .29404 .5788 .30298 .59186 .29046 .58504 .2815 Mtetra
.808 .777 .823 r
.58504 .2815 .59186 .29046 .60494 .27858 .59817 .2696 Mtetra
.8 .776 .831 r
.59817 .2696 .60494 .27858 .61803 .26735 .61131 .25835 Mtetra
.79 .775 .839 r
.61131 .25835 .61803 .26735 .63115 .25675 .62449 .24774 Mtetra
.78 .773 .846 r
.62449 .24774 .63115 .25675 .6443 .24677 .6377 .23775 Mtetra
.77 .771 .854 r
.6377 .23775 .6443 .24677 .6575 .23738 .65095 .22835 Mtetra
.76 .769 .861 r
.65095 .22835 .6575 .23738 .67075 .22854 .66425 .21949 Mtetra
.749 .767 .867 r
.66425 .21949 .67075 .22854 .68406 .22021 .67761 .21115 Mtetra
.739 .765 .873 r
.67761 .21115 .68406 .22021 .69742 .21234 .69102 .20327 Mtetra
.73 .763 .879 r
.69102 .20327 .69742 .21234 .71085 .2049 .7045 .1958 Mtetra
.721 .76 .884 r
.7045 .1958 .71085 .2049 .72434 .19783 .71805 .18871 Mtetra
.713 .758 .888 r
.71805 .18871 .72434 .19783 .73791 .19109 .73166 .18195 Mtetra
.705 .756 .891 r
.73166 .18195 .73791 .19109 .75154 .18464 .74535 .17547 Mtetra
.698 .754 .894 r
.74535 .17547 .75154 .18464 .76525 .17843 .75911 .16923 Mtetra
.692 .752 .897 r
.75911 .16923 .76525 .17843 .77904 .17243 .77294 .1632 Mtetra
.687 .75 .899 r
.77294 .1632 .77904 .17243 .7929 .1666 .78685 .15735 Mtetra
0 .185 .615 r
.1428 .47148 .15121 .47715 .16153 .48372 .15312 .47812 Mtetra
0 .163 .591 r
.15312 .47812 .16153 .48372 .17195 .49057 .16353 .48503 Mtetra
.4 0 0 r
.16353 .48503 .17195 .49057 .18247 .4976 .17405 .49208 Mtetra
.395 0 0 r
.17405 .49208 .18247 .4976 .19312 .50464 .1847 .49913 Mtetra
0 .181 .605 r
.1847 .49913 .19312 .50464 .2039 .51155 .19549 .50603 Mtetra
0 .219 .642 r
.19549 .50603 .2039 .51155 .21484 .51815 .20644 .51259 Mtetra
0 .273 .695 r
.20644 .51259 .21484 .51815 .22596 .52427 .21757 .51865 Mtetra
0 .345 .759 r
.21757 .51865 .22596 .52427 .23725 .52973 .22888 .52401 Mtetra
0 .428 .83 r
.22888 .52401 .23725 .52973 .24873 .53435 .24039 .5285 Mtetra
.064 .518 .896 r
.24039 .5285 .24873 .53435 .26041 .53795 .2521 .53195 Mtetra
.204 .602 .947 r
.2521 .53195 .26041 .53795 .27229 .54039 .26402 .5342 Mtetra
.339 .672 .976 r
.26402 .5342 .27229 .54039 .28437 .54152 .27613 .53512 Mtetra
.457 .723 .982 r
.27613 .53512 .28437 .54152 .29664 .54122 .28844 .53459 Mtetra
.553 .755 .971 r
.28844 .53459 .29664 .54122 .30909 .53941 .30094 .53254 Mtetra
.628 .773 .95 r
.30094 .53254 .30909 .53941 .32171 .53604 .31361 .52891 Mtetra
.684 .782 .925 r
.31361 .52891 .32171 .53604 .33448 .53108 .32644 .52368 Mtetra
.725 .785 .9 r
.32644 .52368 .33448 .53108 .34739 .52454 .33941 .51688 Mtetra
.756 .784 .876 r
.33941 .51688 .34739 .52454 .36042 .51649 .3525 .50857 Mtetra
.78 .782 .855 r
.3525 .50857 .36042 .51649 .37355 .50699 .36569 .49882 Mtetra
.797 .779 .836 r
.36569 .49882 .37355 .50699 .38675 .49616 .37895 .48776 Mtetra
.81 .776 .821 r
.37895 .48776 .38675 .49616 .40001 .48414 .39227 .47552 Mtetra
.82 .773 .809 r
.39227 .47552 .40001 .48414 .4133 .47108 .40562 .46227 Mtetra
.827 .771 .799 r
.40562 .46227 .4133 .47108 .42661 .45715 .419 .44817 Mtetra
.833 .769 .791 r
.419 .44817 .42661 .45715 .43992 .44254 .43238 .43341 Mtetra
.836 .767 .786 r
.43238 .43341 .43992 .44254 .45323 .42741 .44575 .41817 Mtetra
.839 .766 .782 r
.44575 .41817 .45323 .42741 .46652 .41196 .4591 .40262 Mtetra
.84 .765 .78 r
.4591 .40262 .46652 .41196 .47978 .39635 .47242 .38694 Mtetra
.47242 .38694 .47978 .39635 .49302 .38075 .48572 .37128 Mtetra
.838 .765 .781 r
.48572 .37128 .49302 .38075 .50623 .36529 .49899 .3558 Mtetra
.836 .765 .784 r
.49899 .3558 .50623 .36529 .5194 .35011 .51222 .3406 Mtetra
.833 .765 .787 r
.51222 .3406 .5194 .35011 .53256 .33531 .52544 .32581 Mtetra
.829 .766 .792 r
.52544 .32581 .53256 .33531 .54569 .32099 .53863 .3115 Mtetra
.824 .767 .798 r
.53863 .3115 .54569 .32099 .55881 .30722 .55181 .29775 Mtetra
.818 .767 .805 r
.55181 .29775 .55881 .30722 .57192 .29404 .56498 .2846 Mtetra
.811 .767 .812 r
.56498 .2846 .57192 .29404 .58504 .2815 .57815 .27208 Mtetra
.804 .768 .82 r
.57815 .27208 .58504 .2815 .59817 .2696 .59133 .26021 Mtetra
.795 .768 .828 r
.59133 .26021 .59817 .2696 .61131 .25835 .60454 .249 Mtetra
.786 .767 .836 r
.60454 .249 .61131 .25835 .62449 .24774 .61777 .23841 Mtetra
.777 .767 .844 r
.61777 .23841 .62449 .24774 .6377 .23775 .63103 .22845 Mtetra
.767 .766 .852 r
.63103 .22845 .6377 .23775 .65095 .22835 .64433 .21906 Mtetra
.757 .764 .859 r
.64433 .21906 .65095 .22835 .66425 .21949 .65769 .21022 Mtetra
.747 .763 .866 r
.65769 .21022 .66425 .21949 .67761 .21115 .6711 .20189 Mtetra
.738 .761 .872 r
.6711 .20189 .67761 .21115 .69102 .20327 .68456 .19401 Mtetra
.728 .76 .878 r
.68456 .19401 .69102 .20327 .7045 .1958 .69809 .18655 Mtetra
.72 .758 .883 r
.69809 .18655 .7045 .1958 .71805 .18871 .71169 .17945 Mtetra
.711 .756 .887 r
.71169 .17945 .71805 .18871 .73166 .18195 .72536 .17268 Mtetra
.704 .754 .891 r
.72536 .17268 .73166 .18195 .74535 .17547 .73909 .16618 Mtetra
.698 .752 .894 r
.73909 .16618 .74535 .17547 .75911 .16923 .7529 .15992 Mtetra
.692 .75 .897 r
.7529 .15992 .75911 .16923 .77294 .1632 .76679 .15387 Mtetra
.687 .749 .899 r
.76679 .15387 .77294 .1632 .78685 .15735 .78075 .14798 Mtetra
0 .216 .668 r
.13439 .46506 .1428 .47148 .15312 .47812 .14472 .47168 Mtetra
0 .199 .652 r
.14472 .47168 .15312 .47812 .16353 .48503 .15513 .47856 Mtetra
0 .195 .649 r
.15513 .47856 .16353 .48503 .17405 .49208 .16566 .48557 Mtetra
0 .206 .661 r
.16566 .48557 .17405 .49208 .1847 .49913 .17631 .49255 Mtetra
0 .232 .687 r
.17631 .49255 .1847 .49913 .19549 .50603 .18711 .49935 Mtetra
0 .274 .726 r
.18711 .49935 .19549 .50603 .20644 .51259 .19808 .5058 Mtetra
0 .33 .776 r
.19808 .5058 .20644 .51259 .21757 .51865 .20923 .51171 Mtetra
0 .398 .832 r
.20923 .51171 .21757 .51865 .22888 .52401 .22056 .5169 Mtetra
.053 .472 .886 r
.22056 .5169 .22888 .52401 .24039 .5285 .23209 .5212 Mtetra
.177 .545 .928 r
.23209 .5212 .24039 .5285 .2521 .53195 .24383 .52443 Mtetra
.3 .609 .954 r
.24383 .52443 .2521 .53195 .26402 .5342 .25578 .52645 Mtetra
.411 .659 .961 r
.25578 .52645 .26402 .5342 .27613 .53512 .26794 .52712 Mtetra
.505 .695 .954 r
.26794 .52712 .27613 .53512 .28844 .53459 .28029 .52634 Mtetra
.581 .719 .937 r
.28029 .52634 .28844 .53459 .30094 .53254 .29283 .52402 Mtetra
.641 .733 .916 r
.29283 .52402 .30094 .53254 .31361 .52891 .30555 .52012 Mtetra
.686 .741 .893 r
.30555 .52012 .31361 .52891 .32644 .52368 .31843 .51464 Mtetra
.722 .745 .871 r
.31843 .51464 .32644 .52368 .33941 .51688 .33145 .5076 Mtetra
.749 .747 .851 r
.33145 .5076 .33941 .51688 .3525 .50857 .34459 .49905 Mtetra
.769 .747 .833 r
.34459 .49905 .3525 .50857 .36569 .49882 .35783 .48909 Mtetra
.786 .747 .818 r
.35783 .48909 .36569 .49882 .37895 .48776 .37115 .47785 Mtetra
.798 .746 .805 r
.37115 .47785 .37895 .48776 .39227 .47552 .38452 .46545 Mtetra
.808 .746 .795 r
.38452 .46545 .39227 .47552 .40562 .46227 .39793 .45207 Mtetra
.815 .746 .787 r
.39793 .45207 .40562 .46227 .419 .44817 .41136 .43788 Mtetra
.821 .746 .78 r
.41136 .43788 .419 .44817 .43238 .43341 .4248 .42305 Mtetra
.825 .746 .776 r
.4248 .42305 .43238 .43341 .44575 .41817 .43823 .40776 Mtetra
.828 .746 .774 r
.43823 .40776 .44575 .41817 .4591 .40262 .45164 .3922 Mtetra
.829 .747 .773 r
.45164 .3922 .4591 .40262 .47242 .38694 .46502 .37653 Mtetra
.83 .748 .773 r
.46502 .37653 .47242 .38694 .48572 .37128 .47837 .36091 Mtetra
.829 .749 .775 r
.47837 .36091 .48572 .37128 .49899 .3558 .4917 .34547 Mtetra
.828 .751 .778 r
.4917 .34547 .49899 .3558 .51222 .3406 .50499 .33034 Mtetra
.825 .752 .783 r
.50499 .33034 .51222 .3406 .52544 .32581 .51826 .31561 Mtetra
.822 .754 .788 r
.51826 .31561 .52544 .32581 .53863 .3115 .53151 .30139 Mtetra
.817 .755 .794 r
.53151 .30139 .53863 .3115 .55181 .29775 .54474 .28772 Mtetra
.812 .757 .801 r
.54474 .28772 .55181 .29775 .56498 .2846 .55797 .27465 Mtetra
.805 .758 .809 r
.55797 .27465 .56498 .2846 .57815 .27208 .5712 .26222 Mtetra
.798 .759 .817 r
.5712 .26222 .57815 .27208 .59133 .26021 .58444 .25043 Mtetra
.79 .76 .825 r
.58444 .25043 .59133 .26021 .60454 .249 .59769 .23929 Mtetra
.782 .76 .834 r
.59769 .23929 .60454 .249 .61777 .23841 .61098 .22877 Mtetra
.773 .761 .842 r
.61098 .22877 .61777 .23841 .63103 .22845 .6243 .21886 Mtetra
.764 .76 .85 r
.6243 .21886 .63103 .22845 .64433 .21906 .63766 .20953 Mtetra
.754 .76 .857 r
.63766 .20953 .64433 .21906 .65769 .21022 .65106 .20073 Mtetra
.744 .759 .864 r
.65106 .20073 .65769 .21022 .6711 .20189 .66452 .19243 Mtetra
.735 .758 .871 r
.66452 .19243 .6711 .20189 .68456 .19401 .67804 .18458 Mtetra
.726 .757 .877 r
.67804 .18458 .68456 .19401 .69809 .18655 .69163 .17713 Mtetra
.718 .755 .882 r
.69163 .17713 .69809 .18655 .71169 .17945 .70527 .17004 Mtetra
.71 .754 .886 r
.70527 .17004 .71169 .17945 .72536 .17268 .71899 .16327 Mtetra
.703 .752 .89 r
.71899 .16327 .72536 .17268 .73909 .16618 .73278 .15677 Mtetra
.696 .751 .893 r
.73278 .15677 .73909 .16618 .7529 .15992 .74664 .1505 Mtetra
.691 .749 .896 r
.74664 .1505 .7529 .15992 .76679 .15387 .76058 .14442 Mtetra
.686 .748 .899 r
.76058 .14442 .76679 .15387 .78075 .14798 .77459 .13851 Mtetra
0 .252 .72 r
.12601 .45785 .13439 .46506 .14472 .47168 .13633 .46438 Mtetra
0 .239 .711 r
.13633 .46438 .14472 .47168 .15513 .47856 .14676 .47115 Mtetra
0 .24 .713 r
.14676 .47115 .15513 .47856 .16566 .48557 .15729 .47803 Mtetra
0 .255 .729 r
.15729 .47803 .16566 .48557 .17631 .49255 .16796 .48487 Mtetra
0 .283 .755 r
.16796 .48487 .17631 .49255 .18711 .49935 .17878 .49149 Mtetra
0 .325 .792 r
.17878 .49149 .18711 .49935 .19808 .5058 .18976 .49774 Mtetra
0 .377 .833 r
.18976 .49774 .19808 .5058 .20923 .51171 .20093 .50343 Mtetra
.053 .437 .873 r
.20093 .50343 .20923 .51171 .22056 .5169 .21229 .50839 Mtetra
.16 .497 .907 r
.21229 .50839 .22056 .5169 .23209 .5212 .22385 .51243 Mtetra
.268 .554 .929 r
.22385 .51243 .23209 .5212 .24383 .52443 .23562 .5154 Mtetra
.37 .602 .937 r
.23562 .5154 .24383 .52443 .25578 .52645 .2476 .51714 Mtetra
.46 .639 .933 r
.2476 .51714 .25578 .52645 .26794 .52712 .25979 .51752 Mtetra
.536 .666 .921 r
.25979 .51752 .26794 .52712 .28029 .52634 .27218 .51645 Mtetra
.597 .685 .903 r
.27218 .51645 .28029 .52634 .29283 .52402 .28476 .51386 Mtetra
.646 .698 .883 r
.28476 .51386 .29283 .52402 .30555 .52012 .29752 .5097 Mtetra
.685 .706 .863 r
.29752 .5097 .30555 .52012 .31843 .51464 .31045 .50397 Mtetra
.716 .711 .845 r
.31045 .50397 .31843 .51464 .33145 .5076 .32351 .4967 Mtetra
.74 .715 .828 r
.32351 .4967 .33145 .5076 .34459 .49905 .3367 .48796 Mtetra
.759 .717 .813 r
.3367 .48796 .34459 .49905 .35783 .48909 .34999 .47785 Mtetra
.774 .719 .801 r
.34999 .47785 .35783 .48909 .37115 .47785 .36335 .46647 Mtetra
.786 .721 .791 r
.36335 .46647 .37115 .47785 .38452 .46545 .37678 .45398 Mtetra
.796 .722 .782 r
.37678 .45398 .38452 .46545 .39793 .45207 .39024 .44054 Mtetra
.804 .723 .776 r
.39024 .44054 .39793 .45207 .41136 .43788 .40372 .42632 Mtetra
.81 .725 .771 r
.40372 .42632 .41136 .43788 .4248 .42305 .4172 .4115 Mtetra
.814 .726 .768 r
.4172 .4115 .4248 .42305 .43823 .40776 .43068 .39625 Mtetra
.817 .728 .767 r
.43068 .39625 .43823 .40776 .45164 .3922 .44414 .38076 Mtetra
.819 .73 .766 r
.44414 .38076 .45164 .3922 .46502 .37653 .45758 .36518 Mtetra
.82 .732 .768 r
.45758 .36518 .46502 .37653 .47837 .36091 .47098 .34966 Mtetra
.82 .735 .77 r
.47098 .34966 .47837 .36091 .4917 .34547 .48436 .33435 Mtetra
.819 .737 .774 r
.48436 .33435 .4917 .34547 .50499 .33034 .49771 .31935 Mtetra
.817 .74 .779 r
.49771 .31935 .50499 .33034 .51826 .31561 .51103 .30477 Mtetra
.814 .742 .785 r
.51103 .30477 .51826 .31561 .53151 .30139 .52433 .29068 Mtetra
.81 .745 .791 r
.52433 .29068 .53151 .30139 .54474 .28772 .53762 .27716 Mtetra
.805 .747 .799 r
.53762 .27716 .54474 .28772 .55797 .27465 .5509 .26423 Mtetra
.799 .749 .807 r
.5509 .26423 .55797 .27465 .5712 .26222 .56419 .25194 Mtetra
.793 .751 .815 r
.56419 .25194 .5712 .26222 .58444 .25043 .57748 .24027 Mtetra
.785 .753 .823 r
.57748 .24027 .58444 .25043 .59769 .23929 .59079 .22925 Mtetra
.777 .754 .832 r
.59079 .22925 .59769 .23929 .61098 .22877 .60413 .21884 Mtetra
.769 .755 .84 r
.60413 .21884 .61098 .22877 .6243 .21886 .6175 .20902 Mtetra
.76 .755 .849 r
.6175 .20902 .6243 .21886 .63766 .20953 .63091 .19977 Mtetra
.751 .755 .856 r
.63091 .19977 .63766 .20953 .65106 .20073 .64437 .19104 Mtetra
.741 .755 .863 r
.64437 .19104 .65106 .20073 .66452 .19243 .65789 .18279 Mtetra
.733 .754 .87 r
.65789 .18279 .66452 .19243 .67804 .18458 .67146 .17498 Mtetra
.724 .754 .876 r
.67146 .17498 .67804 .18458 .69163 .17713 .6851 .16756 Mtetra
.716 .753 .881 r
.6851 .16756 .69163 .17713 .70527 .17004 .6988 .16049 Mtetra
.708 .752 .886 r
.6988 .16049 .70527 .17004 .71899 .16327 .71257 .15373 Mtetra
.701 .75 .89 r
.71257 .15373 .71899 .16327 .73278 .15677 .72641 .14723 Mtetra
.695 .749 .893 r
.72641 .14723 .73278 .15677 .74664 .1505 .74032 .14095 Mtetra
.69 .748 .896 r
.74032 .14095 .74664 .1505 .76058 .14442 .75431 .13487 Mtetra
.685 .747 .898 r
.75431 .13487 .76058 .14442 .77459 .13851 .76837 .12894 Mtetra
0 .289 .766 r
.11764 .44984 .12601 .45785 .13633 .46438 .12798 .45621 Mtetra
0 .28 .761 r
.12798 .45621 .13633 .46438 .14676 .47115 .13842 .4628 Mtetra
0 .284 .767 r
.13842 .4628 .14676 .47115 .15729 .47803 .14897 .46947 Mtetra
0 .3 .782 r
.14897 .46947 .15729 .47803 .16796 .48487 .15966 .47607 Mtetra
0 .328 .805 r
.15966 .47607 .16796 .48487 .17878 .49149 .17049 .48245 Mtetra
0 .367 .834 r
.17049 .48245 .17878 .49149 .18976 .49774 .1815 .48843 Mtetra
.063 .412 .862 r
.1815 .48843 .18976 .49774 .20093 .50343 .19269 .49383 Mtetra
.152 .461 .887 r
.19269 .49383 .20093 .50343 .21229 .50839 .20408 .49848 Mtetra
.246 .509 .905 r
.20408 .49848 .21229 .50839 .22385 .51243 .21567 .50221 Mtetra
.337 .552 .913 r
.21567 .50221 .22385 .51243 .23562 .5154 .22747 .50486 Mtetra
.421 .588 .911 r
.22747 .50486 .23562 .5154 .2476 .51714 .23948 .50628 Mtetra
.494 .617 .902 r
.23948 .50628 .2476 .51714 .25979 .51752 .25171 .50636 Mtetra
.556 .639 .888 r
.25171 .50636 .25979 .51752 .27218 .51645 .26413 .50499 Mtetra
.606 .655 .872 r
.26413 .50499 .27218 .51645 .28476 .51386 .27675 .50211 Mtetra
.648 .667 .855 r
.27675 .50211 .28476 .51386 .29752 .5097 .28955 .49769 Mtetra
.682 .676 .838 r
.28955 .49769 .29752 .5097 .31045 .50397 .30251 .49174 Mtetra
.709 .682 .823 r
.30251 .49174 .31045 .50397 .32351 .4967 .31561 .48427 Mtetra
.731 .688 .809 r
.31561 .48427 .32351 .4967 .3367 .48796 .32884 .47538 Mtetra
.749 .692 .797 r
.32884 .47538 .3367 .48796 .34999 .47785 .34217 .46514 Mtetra
.763 .695 .787 r
.34217 .46514 .34999 .47785 .36335 .46647 .35557 .45369 Mtetra
.775 .698 .778 r
.35557 .45369 .36335 .46647 .37678 .45398 .36904 .44117 Mtetra
.785 .701 .772 r
.36904 .44117 .37678 .45398 .39024 .44054 .38254 .42774 Mtetra
.792 .704 .767 r
.38254 .42774 .39024 .44054 .40372 .42632 .39606 .41357 Mtetra
.799 .707 .763 r
.39606 .41357 .40372 .42632 .4172 .4115 .40959 .39883 Mtetra
.803 .709 .761 r
.40959 .39883 .4172 .4115 .43068 .39625 .42312 .3837 Mtetra
.807 .712 .761 r
.42312 .3837 .43068 .39625 .44414 .38076 .43662 .36835 Mtetra
.809 .715 .761 r
.43662 .36835 .44414 .38076 .45758 .36518 .4501 .35293 Mtetra
.811 .719 .763 r
.4501 .35293 .45758 .36518 .47098 .34966 .46356 .3376 Mtetra
.811 .722 .766 r
.46356 .3376 .47098 .34966 .48436 .33435 .47698 .32248 Mtetra
.811 .725 .771 r
.47698 .32248 .48436 .33435 .49771 .31935 .49038 .30769 Mtetra
.809 .729 .776 r
.49038 .30769 .49771 .31935 .51103 .30477 .50375 .29332 Mtetra
.806 .732 .782 r
.50375 .29332 .51103 .30477 .52433 .29068 .5171 .27944 Mtetra
.803 .735 .789 r
.5171 .27944 .52433 .29068 .53762 .27716 .53044 .26611 Mtetra
.798 .738 .797 r
.53044 .26611 .53762 .27716 .5509 .26423 .54378 .25338 Mtetra
.793 .741 .805 r
.54378 .25338 .5509 .26423 .56419 .25194 .55712 .24126 Mtetra
.787 .744 .813 r
.55712 .24126 .56419 .25194 .57748 .24027 .57046 .22977 Mtetra
.78 .746 .822 r
.57046 .22977 .57748 .24027 .59079 .22925 .58383 .2189 Mtetra
.772 .748 .831 r
.58383 .2189 .59079 .22925 .60413 .21884 .59722 .20862 Mtetra
.764 .749 .839 r
.59722 .20862 .60413 .21884 .6175 .20902 .61064 .19893 Mtetra
.756 .75 .848 r
.61064 .19893 .6175 .20902 .63091 .19977 .62411 .18978 Mtetra
.747 .751 .856 r
.62411 .18978 .63091 .19977 .64437 .19104 .63763 .18114 Mtetra
.738 .751 .863 r
.63763 .18114 .64437 .19104 .65789 .18279 .65119 .17297 Mtetra
.73 .751 .87 r
.65119 .17297 .65789 .18279 .67146 .17498 .66482 .16522 Mtetra
.721 .751 .876 r
.66482 .16522 .67146 .17498 .6851 .16756 .67851 .15784 Mtetra
.714 .75 .881 r
.67851 .15784 .6851 .16756 .6988 .16049 .69226 .15081 Mtetra
.706 .75 .886 r
.69226 .15081 .6988 .16049 .71257 .15373 .70608 .14406 Mtetra
.7 .749 .89 r
.70608 .14406 .71257 .15373 .72641 .14723 .71998 .13757 Mtetra
.694 .748 .893 r
.71998 .13757 .72641 .14723 .74032 .14095 .73394 .1313 Mtetra
.689 .747 .896 r
.73394 .1313 .74032 .14095 .75431 .13487 .74798 .12521 Mtetra
.684 .746 .898 r
.74798 .12521 .75431 .13487 .76837 .12894 .7621 .11926 Mtetra
0 .325 .803 r
.1093 .44104 .11764 .44984 .12798 .45621 .11966 .44718 Mtetra
0 .319 .801 r
.11966 .44718 .12798 .45621 .13842 .4628 .13012 .4535 Mtetra
0 .325 .807 r
.13012 .4535 .13842 .4628 .14897 .46947 .14069 .45989 Mtetra
0 .341 .819 r
.14069 .45989 .14897 .46947 .15966 .47607 .1514 .46619 Mtetra
.018 .366 .836 r
.1514 .46619 .15966 .47607 .17049 .48245 .16227 .47224 Mtetra
.081 .399 .855 r
.16227 .47224 .17049 .48245 .1815 .48843 .1733 .47788 Mtetra
.154 .436 .872 r
.1733 .47788 .1815 .48843 .19269 .49383 .18452 .48293 Mtetra
.233 .475 .884 r
.18452 .48293 .19269 .49383 .20408 .49848 .19593 .48722 Mtetra
.313 .512 .891 r
.19593 .48722 .20408 .49848 .21567 .50221 .20755 .49059 Mtetra
.388 .546 .89 r
.20755 .49059 .21567 .50221 .22747 .50486 .21939 .49288 Mtetra
.457 .574 .884 r
.21939 .49288 .22747 .50486 .23948 .50628 .23143 .49395 Mtetra
.517 .597 .873 r
.23143 .49395 .23948 .50628 .25171 .50636 .24369 .49369 Mtetra
.569 .616 .86 r
.24369 .49369 .25171 .50636 .26413 .50499 .25614 .49201 Mtetra
.612 .631 .845 r
.25614 .49201 .26413 .50499 .27675 .50211 .2688 .48885 Mtetra
.648 .642 .831 r
.2688 .48885 .27675 .50211 .28955 .49769 .28163 .48419 Mtetra
.677 .651 .817 r
.28163 .48419 .28955 .49769 .30251 .49174 .29462 .47802 Mtetra
.702 .658 .804 r
.29462 .47802 .30251 .49174 .31561 .48427 .30776 .4704 Mtetra
.722 .665 .793 r
.30776 .4704 .31561 .48427 .32884 .47538 .32102 .46139 Mtetra
.739 .67 .783 r
.32102 .46139 .32884 .47538 .34217 .46514 .33437 .45108 Mtetra
.753 .674 .775 r
.33437 .45108 .34217 .46514 .35557 .45369 .34781 .43962 Mtetra
.764 .679 .768 r
.34781 .43962 .35557 .45369 .36904 .44117 .36131 .42713 Mtetra
.774 .683 .763 r
.36131 .42713 .36904 .44117 .38254 .42774 .37485 .41377 Mtetra
.782 .687 .759 r
.37485 .41377 .38254 .42774 .39606 .41357 .38841 .39972 Mtetra
.788 .691 .757 r
.38841 .39972 .39606 .41357 .40959 .39883 .40197 .38514 Mtetra
.793 .694 .755 r
.40197 .38514 .40959 .39883 .42312 .3837 .41553 .3702 Mtetra
.797 .698 .756 r
.41553 .3702 .42312 .3837 .43662 .36835 .42907 .35506 Mtetra
.8 .702 .757 r
.42907 .35506 .43662 .36835 .4501 .35293 .4426 .33989 Mtetra
.802 .706 .76 r
.4426 .33989 .4501 .35293 .46356 .3376 .45609 .32481 Mtetra
.802 .71 .763 r
.45609 .32481 .46356 .3376 .47698 .32248 .46956 .30995 Mtetra
.802 .714 .768 r
.46956 .30995 .47698 .32248 .49038 .30769 .483 .29542 Mtetra
.801 .719 .774 r
.483 .29542 .49038 .30769 .50375 .29332 .49642 .28132 Mtetra
.799 .723 .78 r
.49642 .28132 .50375 .29332 .5171 .27944 .50982 .2677 Mtetra
.796 .727 .788 r
.50982 .2677 .5171 .27944 .53044 .26611 .52321 .25463 Mtetra
.792 .73 .795 r
.52321 .25463 .53044 .26611 .54378 .25338 .5366 .24213 Mtetra
.787 .734 .804 r
.5366 .24213 .54378 .25338 .55712 .24126 .54999 .23024 Mtetra
.781 .737 .813 r
.54999 .23024 .55712 .24126 .57046 .22977 .56339 .21895 Mtetra
.774 .74 .822 r
.56339 .21895 .57046 .22977 .58383 .2189 .5768 .20827 Mtetra
.767 .742 .83 r
.5768 .20827 .58383 .2189 .59722 .20862 .59025 .19816 Mtetra
.759 .744 .839 r
.59025 .19816 .59722 .20862 .61064 .19893 .60373 .18861 Mtetra
.751 .746 .848 r
.60373 .18861 .61064 .19893 .62411 .18978 .61725 .17959 Mtetra
.743 .747 .855 r
.61725 .17959 .62411 .18978 .63763 .18114 .63082 .17106 Mtetra
.735 .748 .863 r
.63082 .17106 .63763 .18114 .65119 .17297 .64444 .16298 Mtetra
.726 .748 .87 r
.64444 .16298 .65119 .17297 .66482 .16522 .65812 .1553 Mtetra
.719 .748 .876 r
.65812 .1553 .66482 .16522 .67851 .15784 .67186 .14799 Mtetra
.711 .748 .881 r
.67186 .14799 .67851 .15784 .69226 .15081 .68566 .14099 Mtetra
.704 .748 .886 r
.68566 .14099 .69226 .15081 .70608 .14406 .69954 .13428 Mtetra
.698 .747 .89 r
.69954 .13428 .70608 .14406 .71998 .13757 .71349 .12781 Mtetra
.692 .747 .893 r
.71349 .12781 .71998 .13757 .73394 .1313 .7275 .12154 Mtetra
.687 .746 .896 r
.7275 .12154 .73394 .1313 .74798 .12521 .7416 .11544 Mtetra
.683 .745 .898 r
.7416 .11544 .74798 .12521 .7621 .11926 .75576 .10948 Mtetra
0 .358 .831 r
.10098 .43148 .1093 .44104 .11966 .44718 .11137 .43731 Mtetra
.001 .355 .829 r
.11137 .43731 .11966 .44718 .13012 .4535 .12186 .4433 Mtetra
.022 .36 .832 r
.12186 .4433 .13012 .4535 .14069 .45989 .13246 .44934 Mtetra
.058 .374 .84 r
.13246 .44934 .14069 .45989 .1514 .46619 .1432 .45526 Mtetra
.106 .395 .85 r
.1432 .45526 .1514 .46619 .16227 .47224 .1541 .46093 Mtetra
.164 .422 .861 r
.1541 .46093 .16227 .47224 .1733 .47788 .16516 .46617 Mtetra
.229 .452 .869 r
.16516 .46617 .1733 .47788 .18452 .48293 .17641 .47081 Mtetra
.297 .483 .873 r
.17641 .47081 .18452 .48293 .19593 .48722 .18786 .47469 Mtetra
.364 .512 .872 r
.18786 .47469 .19593 .48722 .20755 .49059 .19951 .47765 Mtetra
.427 .539 .867 r
.19951 .47765 .20755 .49059 .21939 .49288 .21137 .47954 Mtetra
.484 .562 .859 r
.21137 .47954 .21939 .49288 .23143 .49395 .22345 .48024 Mtetra
.534 .581 .848 r
.22345 .48024 .23143 .49395 .24369 .49369 .23574 .47963 Mtetra
.578 .597 .836 r
.23574 .47963 .24369 .49369 .25614 .49201 .24822 .47763 Mtetra
.615 .61 .823 r
.24822 .47763 .25614 .49201 .2688 .48885 .2609 .47419 Mtetra
.647 .621 .811 r
.2609 .47419 .2688 .48885 .28163 .48419 .27376 .46929 Mtetra
.673 .631 .799 r
.27376 .46929 .28163 .48419 .29462 .47802 .28678 .46295 Mtetra
.695 .639 .788 r
.28678 .46295 .29462 .47802 .30776 .4704 .29994 .4552 Mtetra
.714 .645 .779 r
.29994 .4552 .30776 .4704 .32102 .46139 .31323 .44611 Mtetra
.73 .652 .771 r
.31323 .44611 .32102 .46139 .33437 .45108 .32661 .43579 Mtetra
.743 .657 .765 r
.32661 .43579 .33437 .45108 .34781 .43962 .34008 .42436 Mtetra
.755 .662 .759 r
.34008 .42436 .34781 .43962 .36131 .42713 .3536 .41196 Mtetra
.764 .667 .755 r
.3536 .41196 .36131 .42713 .37485 .41377 .36716 .39875 Mtetra
.772 .672 .753 r
.36716 .39875 .37485 .41377 .38841 .39972 .38075 .38488 Mtetra
.779 .677 .751 r
.38075 .38488 .38841 .39972 .40197 .38514 .39434 .37052 Mtetra
.784 .681 .751 r
.39434 .37052 .40197 .38514 .41553 .3702 .40793 .35584 Mtetra
.788 .686 .752 r
.40793 .35584 .41553 .3702 .42907 .35506 .42151 .34099 Mtetra
.791 .691 .754 r
.42151 .34099 .42907 .35506 .4426 .33989 .43506 .32612 Mtetra
.793 .695 .757 r
.43506 .32612 .4426 .33989 .45609 .32481 .4486 .31136 Mtetra
.794 .7 .761 r
.4486 .31136 .45609 .32481 .46956 .30995 .4621 .29682 Mtetra
.794 .705 .766 r
.4621 .29682 .46956 .30995 .483 .29542 .47559 .28262 Mtetra
.793 .71 .772 r
.47559 .28262 .483 .29542 .49642 .28132 .48905 .26883 Mtetra
.791 .714 .779 r
.48905 .26883 .49642 .28132 .50982 .2677 .5025 .25553 Mtetra
.788 .719 .787 r
.5025 .25553 .50982 .2677 .52321 .25463 .51593 .24275 Mtetra
.785 .723 .795 r
.51593 .24275 .52321 .25463 .5366 .24213 .52936 .23054 Mtetra
.78 .727 .804 r
.52936 .23054 .5366 .24213 .54999 .23024 .5428 .2189 Mtetra
.775 .731 .813 r
.5428 .2189 .54999 .23024 .56339 .21895 .55625 .20786 Mtetra
.768 .735 .822 r
.55625 .20786 .56339 .21895 .5768 .20827 .56972 .19738 Mtetra
.762 .738 .831 r
.56972 .19738 .5768 .20827 .59025 .19816 .58322 .18747 Mtetra
.754 .74 .839 r
.58322 .18747 .59025 .19816 .60373 .18861 .59675 .1781 Mtetra
.747 .742 .848 r
.59675 .1781 .60373 .18861 .61725 .17959 .61032 .16922 Mtetra
.739 .744 .856 r
.61032 .16922 .61725 .17959 .63082 .17106 .62394 .16082 Mtetra
.731 .745 .863 r
.62394 .16082 .63082 .17106 .64444 .16298 .63762 .15284 Mtetra
.723 .746 .87 r
.63762 .15284 .64444 .16298 .65812 .1553 .65135 .14525 Mtetra
.716 .746 .876 r
.65135 .14525 .65812 .1553 .67186 .14799 .66515 .138 Mtetra
.709 .746 .881 r
.66515 .138 .67186 .14799 .68566 .14099 .67901 .13106 Mtetra
.702 .746 .886 r
.67901 .13106 .68566 .14099 .69954 .13428 .69294 .12438 Mtetra
.696 .746 .89 r
.69294 .12438 .69954 .13428 .71349 .12781 .70693 .11793 Mtetra
.691 .745 .893 r
.70693 .11793 .71349 .12781 .7275 .12154 .72101 .11167 Mtetra
.686 .745 .896 r
.72101 .11167 .7275 .12154 .7416 .11544 .73515 .10557 Mtetra
.682 .744 .898 r
.73515 .10557 .7416 .11544 .75576 .10948 .74937 .0996 Mtetra
.07 .388 .849 r
.09269 .4212 .10098 .43148 .11137 .43731 .10312 .42665 Mtetra
.08 .385 .846 r
.10312 .42665 .11137 .43731 .12186 .4433 .11364 .43225 Mtetra
.102 .389 .847 r
.11364 .43225 .12186 .4433 .13246 .44934 .12428 .43786 Mtetra
.137 .401 .85 r
.12428 .43786 .13246 .44934 .1432 .45526 .13506 .44336 Mtetra
.181 .418 .854 r
.13506 .44336 .1432 .45526 .1541 .46093 .14599 .44857 Mtetra
.233 .44 .858 r
.14599 .44857 .1541 .46093 .16516 .46617 .15709 .45336 Mtetra
.289 .463 .859 r
.15709 .45336 .16516 .46617 .17641 .47081 .16837 .45754 Mtetra
.347 .487 .858 r
.16837 .45754 .17641 .47081 .18786 .47469 .17985 .46097 Mtetra
.403 .511 .854 r
.17985 .46097 .18786 .47469 .19951 .47765 .19154 .46349 Mtetra
.456 .532 .846 r
.19154 .46349 .19951 .47765 .21137 .47954 .20343 .46496 Mtetra
.504 .551 .837 r
.20343 .46496 .21137 .47954 .22345 .48024 .21554 .46526 Mtetra
.547 .568 .827 r
.21554 .46526 .22345 .48024 .23574 .47963 .22785 .46429 Mtetra
.584 .582 .816 r
.22785 .46429 .23574 .47963 .24822 .47763 .24037 .46197 Mtetra
.617 .594 .805 r
.24037 .46197 .24822 .47763 .2609 .47419 .25307 .45827 Mtetra
.645 .605 .794 r
.25307 .45827 .2609 .47419 .27376 .46929 .26595 .45316 Mtetra
.669 .614 .785 r
.26595 .45316 .27376 .46929 .28678 .46295 .27899 .44666 Mtetra
.689 .622 .776 r
.27899 .44666 .28678 .46295 .29994 .4552 .29217 .43881 Mtetra
.707 .63 .768 r
.29217 .43881 .29994 .4552 .31323 .44611 .30547 .4297 Mtetra
.722 .636 .762 r
.30547 .4297 .31323 .44611 .32661 .43579 .31888 .41941 Mtetra
.735 .642 .757 r
.31888 .41941 .32661 .43579 .34008 .42436 .33236 .40807 Mtetra
.746 .648 .752 r
.33236 .40807 .34008 .42436 .3536 .41196 .3459 .39582 Mtetra
.755 .654 .75 r
.3459 .39582 .3536 .41196 .36716 .39875 .35948 .38281 Mtetra
.763 .659 .748 r
.35948 .38281 .36716 .39875 .38075 .38488 .37309 .36919 Mtetra
.769 .665 .747 r
.37309 .36919 .38075 .38488 .39434 .37052 .3867 .35512 Mtetra
.775 .67 .748 r
.3867 .35512 .39434 .37052 .40793 .35584 .40032 .34075 Mtetra
.779 .675 .749 r
.40032 .34075 .40793 .35584 .42151 .34099 .41392 .32625 Mtetra
.782 .681 .752 r
.41392 .32625 .42151 .34099 .43506 .32612 .4275 .31173 Mtetra
.784 .686 .756 r
.4275 .31173 .43506 .32612 .4486 .31136 .44107 .29735 Mtetra
.786 .691 .76 r
.44107 .29735 .4486 .31136 .4621 .29682 .45461 .28319 Mtetra
.786 .697 .766 r
.45461 .28319 .4621 .29682 .47559 .28262 .46813 .26936 Mtetra
.785 .702 .772 r
.46813 .26936 .47559 .28262 .48905 .26883 .48163 .25594 Mtetra
.784 .707 .779 r
.48163 .25594 .48905 .26883 .5025 .25553 .49512 .24298 Mtetra
.781 .712 .787 r
.49512 .24298 .5025 .25553 .51593 .24275 .5086 .23054 Mtetra
.778 .717 .796 r
.5086 .23054 .51593 .24275 .52936 .23054 .52208 .21864 Mtetra
.774 .722 .804 r
.52208 .21864 .52936 .23054 .5428 .2189 .53556 .2073 Mtetra
.768 .726 .813 r
.53556 .2073 .5428 .2189 .55625 .20786 .54906 .19652 Mtetra
.763 .73 .822 r
.54906 .19652 .55625 .20786 .56972 .19738 .56258 .18628 Mtetra
.756 .733 .831 r
.56258 .18628 .56972 .19738 .58322 .18747 .57613 .17659 Mtetra
.749 .736 .84 r
.57613 .17659 .58322 .18747 .59675 .1781 .58971 .1674 Mtetra
.742 .739 .849 r
.58971 .1674 .59675 .1781 .61032 .16922 .60334 .15869 Mtetra
.734 .741 .856 r
.60334 .15869 .61032 .16922 .62394 .16082 .61701 .15042 Mtetra
.727 .742 .864 r
.61701 .15042 .62394 .16082 .63762 .15284 .63074 .14256 Mtetra
.72 .743 .87 r
.63074 .14256 .63762 .15284 .65135 .14525 .64453 .13506 Mtetra
.712 .744 .876 r
.64453 .13506 .65135 .14525 .66515 .138 .65838 .12789 Mtetra
.706 .744 .882 r
.65838 .12789 .66515 .138 .67901 .13106 .67229 .121 Mtetra
.7 .744 .886 r
.67229 .121 .67901 .13106 .69294 .12438 .68627 .11436 Mtetra
.694 .744 .89 r
.68627 .11436 .69294 .12438 .70693 .11793 .70032 .10794 Mtetra
.689 .744 .893 r
.70032 .10794 .70693 .11793 .72101 .11167 .71445 .10169 Mtetra
.685 .744 .896 r
.71445 .10169 .72101 .11167 .73515 .10557 .72865 .0956 Mtetra
.681 .744 .899 r
.72865 .0956 .73515 .10557 .74937 .0996 .74292 .08963 Mtetra
.139 .414 .859 r
.08443 .41023 .09269 .4212 .10312 .42665 .0949 .41525 Mtetra
.15 .411 .855 r
.0949 .41525 .10312 .42665 .11364 .43225 .10546 .4204 Mtetra
.172 .414 .853 r
.10546 .4204 .11364 .43225 .12428 .43786 .11614 .42555 Mtetra
.204 .423 .852 r
.11614 .42555 .12428 .43786 .13506 .44336 .12696 .43055 Mtetra
.244 .436 .851 r
.12696 .43055 .13506 .44336 .14599 .44857 .13793 .43527 Mtetra
.289 .453 .85 r
.13793 .43527 .14599 .44857 .15709 .45336 .14907 .43955 Mtetra
.337 .471 .848 r
.14907 .43955 .15709 .45336 .16837 .45754 .1604 .44324 Mtetra
.386 .49 .843 r
.1604 .44324 .16837 .45754 .17985 .46097 .17191 .44618 Mtetra
.434 .509 .837 r
.17191 .44618 .17985 .46097 .19154 .46349 .18363 .44823 Mtetra
.479 .527 .829 r
.18363 .44823 .19154 .46349 .20343 .46496 .19556 .44926 Mtetra
.52 .543 .819 r
.19556 .44926 .20343 .46496 .21554 .46526 .20769 .44916 Mtetra
.557 .557 .81 r
.20769 .44916 .21554 .46526 .22785 .46429 .22003 .44782 Mtetra
.589 .57 .8 r
.22003 .44782 .22785 .46429 .24037 .46197 .23257 .4452 Mtetra
.618 .581 .79 r
.23257 .4452 .24037 .46197 .25307 .45827 .24529 .44124 Mtetra
.643 .592 .781 r
.24529 .44124 .25307 .45827 .26595 .45316 .25819 .43594 Mtetra
.665 .601 .773 r
.25819 .43594 .26595 .45316 .27899 .44666 .27125 .42931 Mtetra
.684 .609 .766 r
.27125 .42931 .27899 .44666 .29217 .43881 .28444 .42141 Mtetra
.701 .617 .76 r
.28444 .42141 .29217 .43881 .30547 .4297 .29775 .41231 Mtetra
.715 .624 .754 r
.29775 .41231 .30547 .4297 .31888 .41941 .31117 .4021 Mtetra
.727 .63 .75 r
.31117 .4021 .31888 .41941 .33236 .40807 .32466 .3909 Mtetra
.738 .637 .747 r
.32466 .3909 .33236 .40807 .3459 .39582 .33821 .37885 Mtetra
.747 .643 .745 r
.33821 .37885 .3459 .39582 .35948 .38281 .35181 .36609 Mtetra
.755 .649 .744 r
.35181 .36609 .35948 .38281 .37309 .36919 .36542 .35277 Mtetra
.761 .655 .744 r
.36542 .35277 .37309 .36919 .3867 .35512 .37906 .33904 Mtetra
.766 .661 .746 r
.37906 .33904 .3867 .35512 .40032 .34075 .39269 .32505 Mtetra
.771 .666 .748 r
.39269 .32505 .40032 .34075 .41392 .32625 .40631 .31094 Mtetra
.774 .672 .751 r
.40631 .31094 .41392 .32625 .4275 .31173 .41992 .29684 Mtetra
.776 .678 .755 r
.41992 .29684 .4275 .31173 .44107 .29735 .43351 .28287 Mtetra
.778 .684 .76 r
.43351 .28287 .44107 .29735 .45461 .28319 .44708 .26913 Mtetra
.778 .69 .766 r
.44708 .26913 .45461 .28319 .46813 .26936 .46063 .25572 Mtetra
.778 .696 .773 r
.46063 .25572 .46813 .26936 .48163 .25594 .47417 .2427 Mtetra
.777 .701 .78 r
.47417 .2427 .48163 .25594 .49512 .24298 .4877 .23013 Mtetra
.774 .707 .788 r
.4877 .23013 .49512 .24298 .5086 .23054 .50122 .21805 Mtetra
.771 .712 .797 r
.50122 .21805 .5086 .23054 .52208 .21864 .51474 .20649 Mtetra
.767 .717 .806 r
.51474 .20649 .52208 .21864 .53556 .2073 .52827 .19547 Mtetra
.762 .722 .815 r
.52827 .19547 .53556 .2073 .54906 .19652 .54182 .18497 Mtetra
.757 .726 .824 r
.54182 .18497 .54906 .19652 .56258 .18628 .55539 .175 Mtetra
.751 .73 .833 r
.55539 .175 .56258 .18628 .57613 .17659 .56898 .16553 Mtetra
.744 .733 .842 r
.56898 .16553 .57613 .17659 .58971 .1674 .58262 .15655 Mtetra
.737 .736 .85 r
.58262 .15655 .58971 .1674 .60334 .15869 .5963 .14801 Mtetra
.73 .738 .858 r
.5963 .14801 .60334 .15869 .61701 .15042 .61002 .1399 Mtetra
.723 .74 .865 r
.61002 .1399 .61701 .15042 .63074 .14256 .6238 .13216 Mtetra
.716 .741 .871 r
.6238 .13216 .63074 .14256 .64453 .13506 .63764 .12476 Mtetra
.709 .742 .877 r
.63764 .12476 .64453 .13506 .65838 .12789 .65154 .11767 Mtetra
.703 .743 .882 r
.65154 .11767 .65838 .12789 .67229 .121 .66551 .11084 Mtetra
.697 .743 .887 r
.66551 .11084 .67229 .121 .68627 .11436 .67955 .10425 Mtetra
.692 .743 .891 r
.67955 .10425 .68627 .11436 .70032 .10794 .69365 .09785 Mtetra
.687 .743 .894 r
.69365 .09785 .70032 .10794 .71445 .10169 .70783 .09162 Mtetra
.683 .743 .897 r
.70783 .09162 .71445 .10169 .72865 .0956 .72208 .08553 Mtetra
.68 .743 .899 r
.72208 .08553 .72865 .0956 .74292 .08963 .73641 .07955 Mtetra
.201 .437 .864 r
.07619 .39865 .08443 .41023 .0949 .41525 .0867 .4032 Mtetra
.212 .433 .858 r
.0867 .4032 .0949 .41525 .10546 .4204 .09732 .40785 Mtetra
.233 .435 .854 r
.09732 .40785 .10546 .4204 .11614 .42555 .10805 .41247 Mtetra
.261 .441 .85 r
.10805 .41247 .11614 .42555 .12696 .43055 .11891 .41695 Mtetra
.296 .451 .846 r
.11891 .41695 .12696 .43055 .13793 .43527 .12993 .42113 Mtetra
.335 .463 .842 r
.12993 .42113 .13793 .43527 .14907 .43955 .14111 .42487 Mtetra
.377 .478 .836 r
.14111 .42487 .14907 .43955 .1604 .44324 .15248 .42803 Mtetra
.418 .493 .83 r
.15248 .42803 .1604 .44324 .17191 .44618 .16403 .43046 Mtetra
.459 .508 .822 r
.16403 .43046 .17191 .44618 .18363 .44823 .17579 .43202 Mtetra
.497 .523 .814 r
.17579 .43202 .18363 .44823 .19556 .44926 .18775 .4326 Mtetra
.532 .537 .805 r
.18775 .4326 .19556 .44926 .20769 .44916 .19991 .43209 Mtetra
.565 .549 .796 r
.19991 .43209 .20769 .44916 .22003 .44782 .21227 .4304 Mtetra
.594 .561 .787 r
.21227 .4304 .22003 .44782 .23257 .4452 .22483 .42747 Mtetra
.619 .572 .779 r
.22483 .42747 .23257 .4452 .24529 .44124 .23757 .42328 Mtetra
.642 .581 .771 r
.23757 .42328 .24529 .44124 .25819 .43594 .25048 .41781 Mtetra
.662 .59 .764 r
.25048 .41781 .25819 .43594 .27125 .42931 .26354 .41109 Mtetra
.679 .599 .758 r
.26354 .41109 .27125 .42931 .28444 .42141 .27674 .40316 Mtetra
.695 .606 .753 r
.27674 .40316 .28444 .42141 .29775 .41231 .29006 .39411 Mtetra
.708 .614 .749 r
.29006 .39411 .29775 .41231 .31117 .4021 .30348 .38402 Mtetra
.72 .621 .746 r
.30348 .38402 .31117 .4021 .32466 .3909 .31698 .37301 Mtetra
.73 .627 .744 r
.31698 .37301 .32466 .3909 .33821 .37885 .33053 .36121 Mtetra
.739 .634 .742 r
.33053 .36121 .33821 .37885 .35181 .36609 .34413 .34875 Mtetra
.747 .64 .742 r
.34413 .34875 .35181 .36609 .36542 .35277 .35776 .33578 Mtetra
.753 .646 .743 r
.35776 .33578 .36542 .35277 .37906 .33904 .3714 .32244 Mtetra
.759 .653 .745 r
.3714 .32244 .37906 .33904 .39269 .32505 .38504 .30886 Mtetra
.763 .659 .747 r
.38504 .30886 .39269 .32505 .40631 .31094 .39868 .29519 Mtetra
.766 .665 .751 r
.39868 .29519 .40631 .31094 .41992 .29684 .4123 .28154 Mtetra
.769 .672 .755 r
.4123 .28154 .41992 .29684 .43351 .28287 .42592 .26803 Mtetra
.77 .678 .761 r
.42592 .26803 .43351 .28287 .44708 .26913 .43951 .25475 Mtetra
.771 .684 .767 r
.43951 .25475 .44708 .26913 .46063 .25572 .45309 .24178 Mtetra
.771 .69 .774 r
.45309 .24178 .46063 .25572 .47417 .2427 .46666 .22919 Mtetra
.77 .696 .782 r
.46666 .22919 .47417 .2427 .4877 .23013 .48023 .21703 Mtetra
.767 .702 .79 r
.48023 .21703 .4877 .23013 .50122 .21805 .49379 .20534 Mtetra
.764 .708 .799 r
.49379 .20534 .50122 .21805 .51474 .20649 .50735 .19415 Mtetra
.761 .713 .808 r
.50735 .19415 .51474 .20649 .52827 .19547 .52092 .18345 Mtetra
.756 .718 .817 r
.52092 .18345 .52827 .19547 .54182 .18497 .53452 .17326 Mtetra
.751 .722 .826 r
.53452 .17326 .54182 .18497 .55539 .175 .54813 .16356 Mtetra
.745 .727 .835 r
.54813 .16356 .55539 .175 .56898 .16553 .56178 .15434 Mtetra
.739 .73 .843 r
.56178 .15434 .56898 .16553 .58262 .15655 .57547 .14557 Mtetra
.732 .733 .851 r
.57547 .14557 .58262 .15655 .5963 .14801 .58919 .13722 Mtetra
.726 .736 .859 r
.58919 .13722 .5963 .14801 .61002 .1399 .60297 .12925 Mtetra
.719 .738 .866 r
.60297 .12925 .61002 .1399 .6238 .13216 .61681 .12164 Mtetra
.712 .739 .873 r
.61681 .12164 .6238 .13216 .63764 .12476 .6307 .11435 Mtetra
.706 .74 .878 r
.6307 .11435 .63764 .12476 .65154 .11767 .64465 .10734 Mtetra
.7 .741 .883 r
.64465 .10734 .65154 .11767 .66551 .11084 .65867 .10058 Mtetra
.695 .742 .887 r
.65867 .10058 .66551 .11084 .67955 .10425 .67276 .09403 Mtetra
.69 .742 .891 r
.67276 .09403 .67955 .10425 .69365 .09785 .68692 .08767 Mtetra
.686 .742 .894 r
.68692 .08767 .69365 .09785 .70783 .09162 .70115 .08145 Mtetra
.682 .742 .897 r
.70115 .08145 .70783 .09162 .72208 .08553 .71546 .07536 Mtetra
.678 .742 .899 r
.71546 .07536 .72208 .08553 .73641 .07955 .72984 .06938 Mtetra
.255 .457 .865 r
.06797 .38653 .07619 .39865 .0867 .4032 .07853 .39056 Mtetra
.266 .453 .858 r
.07853 .39056 .0867 .4032 .09732 .40785 .0892 .39467 Mtetra
.285 .452 .852 r
.0892 .39467 .09732 .40785 .10805 .41247 .09999 .39875 Mtetra
.31 .456 .845 r
.09999 .39875 .10805 .41247 .11891 .41695 .1109 .40266 Mtetra
.34 .463 .839 r
.1109 .40266 .11891 .41695 .12993 .42113 .12197 .40627 Mtetra
.373 .473 .833 r
.12197 .40627 .12993 .42113 .14111 .42487 .1332 .40945 Mtetra
.409 .484 .826 r
.1332 .40945 .14111 .42487 .15248 .42803 .14461 .41206 Mtetra
.444 .496 .818 r
.14461 .41206 .15248 .42803 .16403 .43046 .1562 .41396 Mtetra
.479 .509 .81 r
.1562 .41396 .16403 .43046 .17579 .43202 .16799 .41502 Mtetra
.512 .521 .802 r
.16799 .41502 .17579 .43202 .18775 .4326 .17998 .41514 Mtetra
.543 .533 .794 r
.17998 .41514 .18775 .4326 .19991 .43209 .19217 .41422 Mtetra
.571 .544 .786 r
.19217 .41422 .19991 .43209 .21227 .4304 .20455 .41218 Mtetra
.597 .555 .778 r
.20455 .41218 .21227 .4304 .22483 .42747 .21713 .40897 Mtetra
.62 .564 .77 r
.21713 .40897 .22483 .42747 .23757 .42328 .22988 .40456 Mtetra
.641 .574 .764 r
.22988 .40456 .23757 .42328 .25048 .41781 .2428 .39895 Mtetra
.659 .582 .758 r
.2428 .39895 .25048 .41781 .26354 .41109 .25587 .39217 Mtetra
.675 .59 .753 r
.25587 .39217 .26354 .41109 .27674 .40316 .26907 .38425 Mtetra
.69 .598 .748 r
.26907 .38425 .27674 .40316 .29006 .39411 .28239 .37528 Mtetra
.703 .606 .745 r
.28239 .37528 .29006 .39411 .30348 .38402 .29581 .36535 Mtetra
.714 .613 .743 r
.29581 .36535 .30348 .38402 .31698 .37301 .3093 .35457 Mtetra
.724 .62 .741 r
.3093 .35457 .31698 .37301 .33053 .36121 .32286 .34306 Mtetra
.732 .626 .741 r
.32286 .34306 .33053 .36121 .34413 .34875 .33645 .33094 Mtetra
.74 .633 .741 r
.33645 .33094 .34413 .34875 .35776 .33578 .35008 .31835 Mtetra
.746 .64 .742 r
.35008 .31835 .35776 .33578 .3714 .32244 .36373 .30544 Mtetra
.751 .646 .745 r
.36373 .30544 .3714 .32244 .38504 .30886 .37737 .29231 Mtetra
.756 .653 .748 r
.37737 .29231 .38504 .30886 .39868 .29519 .39102 .27911 Mtetra
.759 .66 .752 r
.39102 .27911 .39868 .29519 .4123 .28154 .40466 .26595 Mtetra
.762 .666 .757 r
.40466 .26595 .4123 .28154 .42592 .26803 .41829 .25292 Mtetra
.763 .673 .763 r
.41829 .25292 .42592 .26803 .43951 .25475 .43191 .24012 Mtetra
.764 .679 .769 r
.43191 .24012 .43951 .25475 .45309 .24178 .44552 .22762 Mtetra
.764 .686 .776 r
.44552 .22762 .45309 .24178 .46666 .22919 .45912 .21548 Mtetra
.763 .692 .784 r
.45912 .21548 .46666 .22919 .48023 .21703 .47271 .20375 Mtetra
.761 .698 .793 r
.47271 .20375 .48023 .21703 .49379 .20534 .48631 .19247 Mtetra
.758 .704 .801 r
.48631 .19247 .49379 .20534 .50735 .19415 .49991 .18165 Mtetra
.754 .71 .81 r
.49991 .18165 .50735 .19415 .52092 .18345 .51353 .1713 Mtetra
.75 .715 .819 r
.51353 .1713 .52092 .18345 .53452 .17326 .52716 .16142 Mtetra
.745 .72 .828 r
.52716 .16142 .53452 .17326 .54813 .16356 .54082 .15201 Mtetra
.74 .724 .837 r
.54082 .15201 .54813 .16356 .56178 .15434 .55452 .14303 Mtetra
.734 .728 .846 r
.55452 .14303 .56178 .15434 .57547 .14557 .56825 .13448 Mtetra
.727 .731 .854 r
.56825 .13448 .57547 .14557 .58919 .13722 .58203 .12631 Mtetra
.721 .734 .861 r
.58203 .12631 .58919 .13722 .60297 .12925 .59586 .11851 Mtetra
.715 .736 .868 r
.59586 .11851 .60297 .12925 .61681 .12164 .60975 .11103 Mtetra
.709 .738 .874 r
.60975 .11103 .61681 .12164 .6307 .11435 .62369 .10385 Mtetra
.703 .739 .879 r
.62369 .10385 .6307 .11435 .64465 .10734 .6377 .09692 Mtetra
.697 .74 .884 r
.6377 .09692 .64465 .10734 .65867 .10058 .65177 .09022 Mtetra
.692 .741 .888 r
.65177 .09022 .65867 .10058 .67276 .09403 .66592 .08372 Mtetra
.688 .741 .892 r
.66592 .08372 .67276 .09403 .68692 .08767 .68013 .07739 Mtetra
.684 .742 .895 r
.68013 .07739 .68692 .08767 .70115 .08145 .69441 .07119 Mtetra
.68 .742 .898 r
.69441 .07119 .70115 .08145 .71546 .07536 .70877 .06511 Mtetra
.677 .742 .9 r
.70877 .06511 .71546 .07536 .72984 .06938 .72321 .05911 Mtetra
.302 .475 .864 r
.05975 .37395 .06797 .38653 .07853 .39056 .07038 .37743 Mtetra
.312 .47 .856 r
.07038 .37743 .07853 .39056 .0892 .39467 .08111 .38098 Mtetra
.329 .468 .848 r
.08111 .38098 .0892 .39467 .09999 .39875 .09195 .38447 Mtetra
.351 .47 .841 r
.09195 .38447 .09999 .39875 .1109 .40266 .10292 .38779 Mtetra
.377 .475 .833 r
.10292 .38779 .1109 .40266 .12197 .40627 .11404 .39082 Mtetra
.405 .482 .825 r
.11404 .39082 .12197 .40627 .1332 .40945 .12532 .39341 Mtetra
.435 .49 .818 r
.12532 .39341 .1332 .40945 .14461 .41206 .13677 .39546 Mtetra
.466 .5 .809 r
.13677 .39546 .14461 .41206 .1562 .41396 .14841 .39682 Mtetra
.496 .51 .801 r
.14841 .39682 .1562 .41396 .16799 .41502 .16024 .39739 Mtetra
.525 .521 .793 r
.16024 .39739 .16799 .41502 .17998 .41514 .17226 .39706 Mtetra
.552 .531 .785 r
.17226 .39706 .17998 .41514 .19217 .41422 .18447 .39574 Mtetra
.577 .541 .778 r
.18447 .39574 .19217 .41422 .20455 .41218 .19688 .39336 Mtetra
.6 .55 .77 r
.19688 .39336 .20455 .41218 .21713 .40897 .20946 .38988 Mtetra
.621 .559 .764 r
.20946 .38988 .21713 .40897 .22988 .40456 .22222 .38528 Mtetra
.64 .568 .758 r
.22222 .38528 .22988 .40456 .2428 .39895 .23515 .37955 Mtetra
.657 .576 .753 r
.23515 .37955 .2428 .39895 .25587 .39217 .24822 .37273 Mtetra
.672 .584 .749 r
.24822 .37273 .25587 .39217 .26907 .38425 .26142 .36486 Mtetra
.685 .592 .745 r
.26142 .36486 .26907 .38425 .28239 .37528 .27473 .35601 Mtetra
.697 .599 .743 r
.27473 .35601 .28239 .37528 .29581 .36535 .28814 .34627 Mtetra
.708 .607 .741 r
.28814 .34627 .29581 .36535 .3093 .35457 .30163 .33574 Mtetra
.718 .614 .74 r
.30163 .33574 .3093 .35457 .32286 .34306 .31518 .32455 Mtetra
.726 .621 .74 r
.31518 .32455 .32286 .34306 .33645 .33094 .32877 .3128 Mtetra
.733 .628 .741 r
.32877 .3128 .33645 .33094 .35008 .31835 .34239 .30064 Mtetra
.739 .635 .743 r
.34239 .30064 .35008 .31835 .36373 .30544 .35603 .28817 Mtetra
.745 .642 .746 r
.35603 .28817 .36373 .30544 .37737 .29231 .36969 .27553 Mtetra
.749 .648 .749 r
.36969 .27553 .37737 .29231 .39102 .27911 .38334 .26282 Mtetra
.752 .655 .754 r
.38334 .26282 .39102 .27911 .40466 .26595 .39699 .25016 Mtetra
.755 .662 .759 r
.39699 .25016 .40466 .26595 .41829 .25292 .41063 .23764 Mtetra
.756 .669 .765 r
.41063 .23764 .41829 .25292 .43191 .24012 .42427 .22533 Mtetra
.757 .676 .772 r
.42427 .22533 .43191 .24012 .44552 .22762 .4379 .21332 Mtetra
.757 .683 .779 r
.4379 .21332 .44552 .22762 .45912 .21548 .45152 .20165 Mtetra
.756 .689 .787 r
.45152 .20165 .45912 .21548 .47271 .20375 .46515 .19036 Mtetra
.754 .696 .796 r
.46515 .19036 .47271 .20375 .48631 .19247 .47878 .17949 Mtetra
.752 .702 .805 r
.47878 .17949 .48631 .19247 .49991 .18165 .49242 .16905 Mtetra
.748 .707 .813 r
.49242 .16905 .49991 .18165 .51353 .1713 .50607 .15905 Mtetra
.744 .713 .822 r
.50607 .15905 .51353 .1713 .52716 .16142 .51975 .14949 Mtetra
.739 .718 .831 r
.51975 .14949 .52716 .16142 .54082 .15201 .53346 .14036 Mtetra
.734 .722 .84 r
.53346 .14036 .54082 .15201 .55452 .14303 .5472 .13164 Mtetra
.728 .726 .848 r
.5472 .13164 .55452 .14303 .56825 .13448 .56098 .1233 Mtetra
.723 .729 .856 r
.56098 .1233 .56825 .13448 .58203 .12631 .57481 .11532 Mtetra
.717 .732 .863 r
.57481 .11532 .58203 .12631 .59586 .11851 .58869 .10768 Mtetra
.711 .735 .87 r
.58869 .10768 .59586 .11851 .60975 .11103 .60263 .10033 Mtetra
.705 .737 .876 r
.60263 .10033 .60975 .11103 .62369 .10385 .61662 .09325 Mtetra
.7 .738 .881 r
.61662 .09325 .62369 .10385 .6377 .09692 .63068 .08641 Mtetra
.695 .739 .885 r
.63068 .08641 .6377 .09692 .65177 .09022 .64481 .07978 Mtetra
.69 .74 .889 r
.64481 .07978 .65177 .09022 .66592 .08372 .65901 .07332 Mtetra
.686 .741 .893 r
.65901 .07332 .66592 .08372 .68013 .07739 .67327 .06702 Mtetra
.682 .741 .896 r
.67327 .06702 .68013 .07739 .69441 .07119 .68761 .06083 Mtetra
.679 .741 .898 r
.68761 .06083 .69441 .07119 .70877 .06511 .70203 .05475 Mtetra
.676 .742 .9 r
.70203 .05475 .70877 .06511 .72321 .05911 .71651 .04876 Mtetra
.344 .491 .863 r
.05153 .361 .05975 .37395 .07038 .37743 .06223 .36391 Mtetra
.353 .485 .854 r
.06223 .36391 .07038 .37743 .08111 .38098 .07302 .36686 Mtetra
.367 .482 .845 r
.07302 .36686 .08111 .38098 .09195 .38447 .08392 .36976 Mtetra
.386 .483 .836 r
.08392 .36976 .09195 .38447 .10292 .38779 .09495 .37247 Mtetra
.408 .485 .828 r
.09495 .37247 .10292 .38779 .11404 .39082 .10613 .3749 Mtetra
.432 .49 .819 r
.10613 .3749 .11404 .39082 .12532 .39341 .11746 .37691 Mtetra
.458 .497 .811 r
.11746 .37691 .12532 .39341 .13677 .39546 .12896 .37839 Mtetra
.485 .505 .803 r
.12896 .37839 .13677 .39546 .14841 .39682 .14064 .37921 Mtetra
.511 .513 .794 r
.14064 .37921 .14841 .39682 .16024 .39739 .15251 .37929 Mtetra
.536 .522 .787 r
.15251 .37929 .16024 .39739 .17226 .39706 .16456 .37851 Mtetra
.56 .53 .779 r
.16456 .37851 .17226 .39706 .18447 .39574 .1768 .3768 Mtetra
.582 .539 .772 r
.1768 .3768 .18447 .39574 .19688 .39336 .18922 .37411 Mtetra
.603 .548 .766 r
.18922 .37411 .19688 .39336 .20946 .38988 .20182 .37038 Mtetra
.622 .556 .76 r
.20182 .37038 .20946 .38988 .22222 .38528 .21458 .3656 Mtetra
.639 .564 .755 r
.21458 .3656 .22222 .38528 .23515 .37955 .22751 .35979 Mtetra
.655 .572 .75 r
.22751 .35979 .23515 .37955 .24822 .37273 .24058 .35295 Mtetra
.669 .58 .747 r
.24058 .35295 .24822 .37273 .26142 .36486 .25377 .34515 Mtetra
.682 .588 .744 r
.25377 .34515 .26142 .36486 .27473 .35601 .26708 .33645 Mtetra
.693 .595 .742 r
.26708 .33645 .27473 .35601 .28814 .34627 .28047 .32693 Mtetra
.703 .602 .741 r
.28047 .32693 .28814 .34627 .30163 .33574 .29395 .31669 Mtetra
.712 .61 .741 r
.29395 .31669 .30163 .33574 .31518 .32455 .30748 .30584 Mtetra
.72 .617 .741 r
.30748 .30584 .31518 .32455 .32877 .3128 .32107 .29449 Mtetra
.727 .624 .743 r
.32107 .29449 .32877 .3128 .34239 .30064 .33468 .28276 Mtetra
.733 .631 .745 r
.33468 .28276 .34239 .30064 .35603 .28817 .34832 .27077 Mtetra
.738 .638 .748 r
.34832 .27077 .35603 .28817 .36969 .27553 .36197 .25862 Mtetra
.743 .645 .752 r
.36197 .25862 .36969 .27553 .38334 .26282 .37562 .24643 Mtetra
.746 .652 .757 r
.37562 .24643 .38334 .26282 .39699 .25016 .38928 .23428 Mtetra
.748 .659 .762 r
.38928 .23428 .39699 .25016 .41063 .23764 .40293 .22227 Mtetra
.75 .666 .769 r
.40293 .22227 .41063 .23764 .42427 .22533 .41658 .21047 Mtetra
.751 .673 .776 r
.41658 .21047 .42427 .22533 .4379 .21332 .43023 .19895 Mtetra
.751 .68 .783 r
.43023 .19895 .4379 .21332 .45152 .20165 .44388 .18774 Mtetra
.75 .687 .791 r
.44388 .18774 .45152 .20165 .46515 .19036 .45753 .1769 Mtetra
.748 .694 .8 r
.45753 .1769 .46515 .19036 .47878 .17949 .4712 .16645 Mtetra
.745 .7 .808 r
.4712 .16645 .47878 .17949 .49242 .16905 .48487 .15639 Mtetra
.742 .706 .817 r
.48487 .15639 .49242 .16905 .50607 .15905 .49856 .14674 Mtetra
.738 .711 .826 r
.49856 .14674 .50607 .15905 .51975 .14949 .51228 .1375 Mtetra
.734 .716 .835 r
.51228 .1375 .51975 .14949 .53346 .14036 .52603 .12865 Mtetra
.729 .721 .843 r
.52603 .12865 .53346 .14036 .5472 .13164 .53982 .12017 Mtetra
.723 .725 .851 r
.53982 .12017 .5472 .13164 .56098 .1233 .55365 .11205 Mtetra
.718 .728 .859 r
.55365 .11205 .56098 .1233 .57481 .11532 .56753 .10426 Mtetra
.712 .731 .865 r
.56753 .10426 .57481 .11532 .58869 .10768 .58146 .09677 Mtetra
.707 .734 .872 r
.58146 .09677 .58869 .10768 .60263 .10033 .59545 .08956 Mtetra
.701 .736 .877 r
.59545 .08956 .60263 .10033 .61662 .09325 .6095 .08258 Mtetra
.696 .737 .882 r
.6095 .08258 .61662 .09325 .63068 .08641 .62361 .07582 Mtetra
.692 .738 .887 r
.62361 .07582 .63068 .08641 .64481 .07978 .63779 .06925 Mtetra
.687 .739 .891 r
.63779 .06925 .64481 .07978 .65901 .07332 .65204 .06284 Mtetra
.684 .74 .894 r
.65204 .06284 .65901 .07332 .67327 .06702 .66636 .05656 Mtetra
.68 .741 .896 r
.66636 .05656 .67327 .06702 .68761 .06083 .68075 .05039 Mtetra
.677 .741 .899 r
.68075 .05039 .68761 .06083 .70203 .05475 .69522 .04431 Mtetra
.675 .741 .901 r
.69522 .04431 .70203 .05475 .71651 .04876 .70976 .0383 Mtetra
.38 .506 .86 r
.04331 .34775 .05153 .361 .06223 .36391 .05407 .35008 Mtetra
.387 .5 .851 r
.05407 .35008 .06223 .36391 .07302 .36686 .06493 .35244 Mtetra
.4 .496 .842 r
.06493 .35244 .07302 .36686 .08392 .36976 .07589 .35472 Mtetra
.416 .495 .833 r
.07589 .35472 .08392 .36976 .09495 .37247 .08699 .35683 Mtetra
.435 .496 .824 r
.08699 .35683 .09495 .37247 .10613 .3749 .09822 .35865 Mtetra
.456 .499 .815 r
.09822 .35865 .10613 .3749 .11746 .37691 .10961 .36007 Mtetra
.478 .504 .806 r
.10961 .36007 .11746 .37691 .12896 .37839 .12116 .36099 Mtetra
.501 .51 .798 r
.12116 .36099 .12896 .37839 .14064 .37921 .13289 .36129 Mtetra
.524 .517 .79 r
.13289 .36129 .14064 .37921 .15251 .37929 .14479 .36088 Mtetra
.546 .524 .782 r
.14479 .36088 .15251 .37929 .16456 .37851 .15687 .35967 Mtetra
.567 .532 .775 r
.15687 .35967 .16456 .37851 .1768 .3768 .16913 .35759 Mtetra
.587 .539 .769 r
.16913 .35759 .1768 .3768 .18922 .37411 .18157 .35459 Mtetra
.606 .547 .763 r
.18157 .35459 .18922 .37411 .20182 .37038 .19417 .35064 Mtetra
.623 .555 .757 r
.19417 .35064 .20182 .37038 .21458 .3656 .20695 .34572 Mtetra
.639 .563 .753 r
.20695 .34572 .21458 .3656 .22751 .35979 .21987 .33983 Mtetra
.653 .57 .749 r
.21987 .33983 .22751 .35979 .24058 .35295 .23293 .33301 Mtetra
.666 .578 .746 r
.23293 .33301 .24058 .35295 .25377 .34515 .24612 .3253 Mtetra
.678 .585 .744 r
.24612 .3253 .25377 .34515 .26708 .33645 .25941 .31676 Mtetra
.689 .592 .742 r
.25941 .31676 .26708 .33645 .28047 .32693 .27279 .30748 Mtetra
.699 .6 .742 r
.27279 .30748 .28047 .32693 .29395 .31669 .28625 .29755 Mtetra
.707 .607 .742 r
.28625 .29755 .29395 .31669 .30748 .30584 .29977 .28706 Mtetra
.715 .614 .743 r
.29977 .28706 .30748 .30584 .32107 .29449 .31334 .27613 Mtetra
.722 .621 .745 r
.31334 .27613 .32107 .29449 .33468 .28276 .32695 .26485 Mtetra
.728 .629 .748 r
.32695 .26485 .33468 .28276 .34832 .27077 .34057 .25334 Mtetra
.733 .636 .751 r
.34057 .25334 .34832 .27077 .36197 .25862 .35422 .24169 Mtetra
.737 .643 .756 r
.35422 .24169 .36197 .25862 .37562 .24643 .36787 .23002 Mtetra
.74 .65 .761 r
.36787 .23002 .37562 .24643 .38928 .23428 .38153 .21839 Mtetra
.742 .658 .766 r
.38153 .21839 .38928 .23428 .40293 .22227 .39519 .2069 Mtetra
.744 .665 .773 r
.39519 .2069 .40293 .22227 .41658 .21047 .40886 .19561 Mtetra
.744 .672 .78 r
.40886 .19561 .41658 .21047 .43023 .19895 .42252 .18457 Mtetra
.744 .679 .788 r
.42252 .18457 .43023 .19895 .44388 .18774 .43619 .17384 Mtetra
.743 .686 .796 r
.43619 .17384 .44388 .18774 .45753 .1769 .44987 .16343 Mtetra
.742 .693 .804 r
.44987 .16343 .45753 .1769 .4712 .16645 .46356 .15339 Mtetra
.739 .699 .813 r
.46356 .15339 .4712 .16645 .48487 .15639 .47727 .14371 Mtetra
.736 .705 .822 r
.47727 .14371 .48487 .15639 .49856 .14674 .491 .13441 Mtetra
.732 .71 .83 r
.491 .13441 .49856 .14674 .51228 .1375 .50476 .12547 Mtetra
.728 .715 .839 r
.50476 .12547 .51228 .1375 .52603 .12865 .51855 .1169 Mtetra
.723 .72 .847 r
.51855 .1169 .52603 .12865 .53982 .12017 .53238 .10867 Mtetra
.718 .724 .854 r
.53238 .10867 .53982 .12017 .55365 .11205 .54626 .10076 Mtetra
.713 .727 .861 r
.54626 .10076 .55365 .11205 .56753 .10426 .56019 .09315 Mtetra
.708 .73 .868 r
.56019 .09315 .56753 .10426 .58146 .09677 .57417 .08581 Mtetra
.703 .733 .874 r
.57417 .08581 .58146 .09677 .59545 .08956 .5882 .07871 Mtetra
.698 .735 .879 r
.5882 .07871 .59545 .08956 .6095 .08258 .6023 .07184 Mtetra
.693 .737 .884 r
.6023 .07184 .6095 .08258 .62361 .07582 .61647 .06516 Mtetra
.689 .738 .888 r
.61647 .06516 .62361 .07582 .63779 .06925 .6307 .05864 Mtetra
.685 .739 .892 r
.6307 .05864 .63779 .06925 .65204 .06284 .645 .05227 Mtetra
.682 .74 .895 r
.645 .05227 .65204 .06284 .66636 .05656 .65937 .04602 Mtetra
.679 .74 .897 r
.65937 .04602 .66636 .05656 .68075 .05039 .67382 .03986 Mtetra
.676 .741 .899 r
.67382 .03986 .68075 .05039 .69522 .04431 .68834 .03378 Mtetra
.674 .741 .901 r
.68834 .03378 .69522 .04431 .70976 .0383 .70294 .02776 Mtetra
.412 .521 .859 r
.03505 .3343 .04331 .34775 .05407 .35008 .04589 .33605 Mtetra
.418 .514 .849 r
.04589 .33605 .05407 .35008 .06493 .35244 .05682 .3378 Mtetra
.428 .509 .839 r
.05682 .3378 .06493 .35244 .07589 .35472 .06785 .33948 Mtetra
.442 .507 .83 r
.06785 .33948 .07589 .35472 .08699 .35683 .07901 .34098 Mtetra
.458 .507 .821 r
.07901 .34098 .08699 .35683 .09822 .35865 .09031 .3422 Mtetra
.476 .508 .812 r
.09031 .3422 .09822 .35865 .10961 .36007 .10175 .34305 Mtetra
.496 .512 .803 r
.10175 .34305 .10961 .36007 .12116 .36099 .11335 .34341 Mtetra
.515 .516 .795 r
.11335 .34341 .12116 .36099 .13289 .36129 .12512 .34319 Mtetra
.535 .522 .787 r
.12512 .34319 .13289 .36129 .14479 .36088 .13706 .34231 Mtetra
.555 .528 .78 r
.13706 .34231 .14479 .36088 .15687 .35967 .14917 .34069 Mtetra
.574 .534 .773 r
.14917 .34069 .15687 .35967 .16913 .35759 .16145 .33827 Mtetra
.591 .541 .767 r
.16145 .33827 .16913 .35759 .18157 .35459 .1739 .33499 Mtetra
.608 .548 .762 r
.1739 .33499 .18157 .35459 .19417 .35064 .18652 .33083 Mtetra
.624 .555 .757 r
.18652 .33083 .19417 .35064 .20695 .34572 .1993 .32578 Mtetra
.639 .562 .753 r
.1993 .32578 .20695 .34572 .21987 .33983 .21222 .31985 Mtetra
.652 .57 .749 r
.21222 .31985 .21987 .33983 .23293 .33301 .22527 .31306 Mtetra
.664 .577 .747 r
.22527 .31306 .23293 .33301 .24612 .3253 .23844 .30546 Mtetra
.676 .584 .745 r
.23844 .30546 .24612 .3253 .25941 .31676 .25172 .29711 Mtetra
.686 .591 .744 r
.25172 .29711 .25941 .31676 .27279 .30748 .26508 .28808 Mtetra
.695 .598 .744 r
.26508 .28808 .27279 .30748 .28625 .29755 .27853 .27847 Mtetra
.703 .606 .745 r
.27853 .27847 .28625 .29755 .29977 .28706 .29203 .26835 Mtetra
.71 .613 .746 r
.29203 .26835 .29977 .28706 .31334 .27613 .30558 .25783 Mtetra
.717 .62 .748 r
.30558 .25783 .31334 .27613 .32695 .26485 .31917 .24701 Mtetra
.722 .627 .752 r
.31917 .24701 .32695 .26485 .34057 .25334 .33279 .23599 Mtetra
.727 .635 .755 r
.33279 .23599 .34057 .25334 .35422 .24169 .34643 .22485 Mtetra
.731 .642 .76 r
.34643 .22485 .35422 .24169 .36787 .23002 .36008 .21369 Mtetra
.734 .65 .765 r
.36008 .21369 .36787 .23002 .38153 .21839 .37374 .20258 Mtetra
.736 .657 .771 r
.37374 .20258 .38153 .21839 .39519 .2069 .38741 .1916 Mtetra
.738 .664 .778 r
.38741 .1916 .39519 .2069 .40886 .19561 .40108 .1808 Mtetra
.738 .672 .785 r
.40108 .1808 .40886 .19561 .42252 .18457 .41476 .17025 Mtetra
.738 .679 .793 r
.41476 .17025 .42252 .18457 .43619 .17384 .42845 .15997 Mtetra
.737 .686 .801 r
.42845 .15997 .43619 .17384 .44987 .16343 .44215 .15 Mtetra
.736 .692 .809 r
.44215 .15 .44987 .16343 .46356 .15339 .45587 .14035 Mtetra
.733 .699 .818 r
.45587 .14035 .46356 .15339 .47727 .14371 .46961 .13104 Mtetra
.73 .705 .826 r
.46961 .13104 .47727 .14371 .491 .13441 .48338 .12207 Mtetra
.727 .71 .835 r
.48338 .12207 .491 .13441 .50476 .12547 .49718 .11344 Mtetra
.723 .715 .843 r
.49718 .11344 .50476 .12547 .51855 .1169 .51101 .10513 Mtetra
.718 .72 .85 r
.51101 .10513 .51855 .1169 .53238 .10867 .52489 .09713 Mtetra
.713 .724 .858 r
.52489 .09713 .53238 .10867 .54626 .10076 .53881 .08942 Mtetra
.709 .727 .865 r
.53881 .08942 .54626 .10076 .56019 .09315 .55278 .08198 Mtetra
.704 .73 .871 r
.55278 .08198 .56019 .09315 .57417 .08581 .56681 .07479 Mtetra
.699 .732 .876 r
.56681 .07479 .57417 .08581 .5882 .07871 .5809 .06781 Mtetra
.695 .734 .881 r
.5809 .06781 .5882 .07871 .6023 .07184 .59505 .06103 Mtetra
.69 .736 .886 r
.59505 .06103 .6023 .07184 .61647 .06516 .60927 .05443 Mtetra
.686 .737 .89 r
.60927 .05443 .61647 .06516 .6307 .05864 .62355 .04796 Mtetra
.683 .738 .893 r
.62355 .04796 .6307 .05864 .645 .05227 .6379 .04162 Mtetra
.68 .739 .896 r
.6379 .04162 .645 .05227 .65937 .04602 .65233 .03539 Mtetra
.677 .74 .898 r
.65233 .03539 .65937 .04602 .67382 .03986 .66683 .02924 Mtetra
.675 .74 .9 r
.66683 .02924 .67382 .03986 .68834 .03378 .6814 .02316 Mtetra
.672 .741 .902 r
.6814 .02316 .68834 .03378 .70294 .02776 .69606 .01712 Mtetra
.44 .535 .857 r
.02677 .32073 .03505 .3343 .04589 .33605 .03767 .32189 Mtetra
.445 .527 .848 r
.03767 .32189 .04589 .33605 .05682 .3378 .04868 .32305 Mtetra
.454 .522 .838 r
.04868 .32305 .05682 .3378 .06785 .33948 .05978 .32413 Mtetra
.465 .519 .829 r
.05978 .32413 .06785 .33948 .07901 .34098 .07101 .32503 Mtetra
.479 .518 .819 r
.07101 .32503 .07901 .34098 .09031 .3422 .08237 .32567 Mtetra
.495 .518 .81 r
.08237 .32567 .09031 .3422 .10175 .34305 .09387 .32595 Mtetra
.511 .52 .802 r
.09387 .32595 .10175 .34305 .11335 .34341 .10552 .32578 Mtetra
.528 .523 .794 r
.10552 .32578 .11335 .34341 .12512 .34319 .11733 .32507 Mtetra
.546 .528 .786 r
.11733 .32507 .12512 .34319 .13706 .34231 .1293 .32374 Mtetra
.563 .533 .779 r
.1293 .32374 .13706 .34231 .14917 .34069 .14144 .32172 Mtetra
.58 .538 .773 r
.14144 .32172 .14917 .34069 .16145 .33827 .15375 .31897 Mtetra
.596 .544 .767 r
.15375 .31897 .16145 .33827 .1739 .33499 .16622 .31543 Mtetra
.611 .551 .762 r
.16622 .31543 .1739 .33499 .18652 .33083 .17884 .31109 Mtetra
.625 .557 .758 r
.17884 .31109 .18652 .33083 .1993 .32578 .19162 .30593 Mtetra
.639 .564 .754 r
.19162 .30593 .1993 .32578 .21222 .31985 .20453 .29997 Mtetra
.651 .571 .751 r
.20453 .29997 .21222 .31985 .22527 .31306 .21757 .29324 Mtetra
.663 .578 .749 r
.21757 .29324 .22527 .31306 .23844 .30546 .23073 .28576 Mtetra
.673 .585 .748 r
.23073 .28576 .23844 .30546 .25172 .29711 .24399 .27761 Mtetra
.683 .592 .747 r
.24399 .27761 .25172 .29711 .26508 .28808 .25734 .26885 Mtetra
.691 .599 .748 r
.25734 .26885 .26508 .28808 .27853 .27847 .27076 .25956 Mtetra
.699 .606 .749 r
.27076 .25956 .27853 .27847 .29203 .26835 .28425 .24982 Mtetra
.706 .613 .75 r
.28425 .24982 .29203 .26835 .30558 .25783 .29778 .23972 Mtetra
.712 .62 .753 r
.29778 .23972 .30558 .25783 .31917 .24701 .31136 .22935 Mtetra
.718 .628 .756 r
.31136 .22935 .31917 .24701 .33279 .23599 .32496 .21881 Mtetra
.722 .635 .76 r
.32496 .21881 .33279 .23599 .34643 .22485 .33859 .20817 Mtetra
.726 .642 .765 r
.33859 .20817 .34643 .22485 .36008 .21369 .35223 .19751 Mtetra
.729 .65 .771 r
.35223 .19751 .36008 .21369 .37374 .20258 .36589 .18691 Mtetra
.731 .657 .777 r
.36589 .18691 .37374 .20258 .38741 .1916 .37957 .17642 Mtetra
.732 .665 .784 r
.37957 .17642 .38741 .1916 .40108 .1808 .39325 .16611 Mtetra
.733 .672 .791 r
.39325 .16611 .40108 .1808 .41476 .17025 .40694 .15602 Mtetra
.733 .679 .799 r
.40694 .15602 .41476 .17025 .42845 .15997 .42065 .14619 Mtetra
.732 .686 .807 r
.42065 .14619 .42845 .15997 .44215 .15 .43438 .13663 Mtetra
.73 .693 .815 r
.43438 .13663 .44215 .15 .45587 .14035 .44813 .12737 Mtetra
.728 .699 .823 r
.44813 .12737 .45587 .14035 .46961 .13104 .4619 .11841 Mtetra
.725 .705 .831 r
.4619 .11841 .46961 .13104 .48338 .12207 .4757 .10976 Mtetra
.721 .71 .839 r
.4757 .10976 .48338 .12207 .49718 .11344 .48953 .10142 Mtetra
.717 .715 .847 r
.48953 .10142 .49718 .11344 .51101 .10513 .50341 .09336 Mtetra
.713 .72 .854 r
.50341 .09336 .51101 .10513 .52489 .09713 .51733 .08559 Mtetra
.709 .723 .861 r
.51733 .08559 .52489 .09713 .53881 .08942 .53129 .07807 Mtetra
.704 .727 .868 r
.53129 .07807 .53881 .08942 .55278 .08198 .54532 .07079 Mtetra
.7 .73 .874 r
.54532 .07079 .55278 .08198 .56681 .07479 .55939 .06373 Mtetra
.696 .732 .879 r
.55939 .06373 .56681 .07479 .5809 .06781 .57353 .05686 Mtetra
.691 .734 .883 r
.57353 .05686 .5809 .06781 .59505 .06103 .58773 .05017 Mtetra
.688 .736 .888 r
.58773 .05017 .59505 .06103 .60927 .05443 .602 .04363 Mtetra
.684 .737 .891 r
.602 .04363 .60927 .05443 .62355 .04796 .61633 .03721 Mtetra
.681 .738 .894 r
.61633 .03721 .62355 .04796 .6379 .04162 .63074 .0309 Mtetra
.678 .739 .897 r
.63074 .0309 .6379 .04162 .65233 .03539 .64522 .02468 Mtetra
.675 .74 .899 r
.64522 .02468 .65233 .03539 .66683 .02924 .65977 .01854 Mtetra
.673 .74 .901 r
.65977 .01854 .66683 .02924 .6814 .02316 .6744 .01244 Mtetra
.671 .74 .902 r
.6744 .01244 .6814 .02316 .69606 .01712 .68911 .0064 Mtetra
0 g
.68874 0 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.68874 0 m
.03716 .25514 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 0.522676 0.477324 0.97619 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.49505 0.5 0.49505 [
[ 0 0 -0.125 0 ]
[ 0 0 -0.125 0 ]
[ 0 1 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
0 0 m
1 0 L
s
0 0 m
0 1 L
s
0 1 m
1 1 L
s
1 0 m
1 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
1 .5 0 r
.015 w
.03175 .1355 Mdot
.03435 .12523 Mdot
.11137 .12765 Mdot
.14107 .18841 Mdot
.16218 .24538 Mdot
.17294 .21053 Mdot
.18267 .18577 Mdot
.18434 .1304 Mdot
.18553 .30956 Mdot
.20401 .239 Mdot
.21247 .27571 Mdot
.21687 .20845 Mdot
.22376 .2799 Mdot
.22832 .27485 Mdot
.29063 .20974 Mdot
.29686 .25079 Mdot
.30487 .22936 Mdot
.30683 .34623 Mdot
.32055 .20902 Mdot
.32574 .21979 Mdot
.34472 .28521 Mdot
.35998 .36393 Mdot
.36335 .24976 Mdot
.3794 .36608 Mdot
.42386 .66992 Mdot
.44391 .74519 Mdot
.45059 .34198 Mdot
.47208 .67586 Mdot
.47436 .71381 Mdot
.49778 .59825 Mdot
.50874 .91643 Mdot
.51516 .76219 Mdot
.53655 .61374 Mdot
.56563 .75219 Mdot
.59189 .65665 Mdot
.59581 .61604 Mdot
.59923 .6556 Mdot
.60292 .68499 Mdot
.62656 .67779 Mdot
.63555 .72451 Mdot
.63919 .652 Mdot
.64169 .6004 Mdot
.64246 .58611 Mdot
.64496 .54267 Mdot
.64608 .77288 Mdot
.65077 .64308 Mdot
.66065 .57816 Mdot
.67474 .59169 Mdot
.69296 .563 Mdot
.72815 .65902 Mdot
.73169 .58879 Mdot
.74669 .61318 Mdot
.74821 .65474 Mdot
.75963 .63781 Mdot
.79673 .57809 Mdot
.80925 .55852 Mdot
.81525 .58444 Mdot
.83417 .62985 Mdot
.83598 .55526 Mdot
.91595 .49319 Mdot
0 0 1 r
.005 w
.00495 .28842 m
.00628 .29156 L
.01857 .31761 L
.03101 .33781 L
.03525 .34367 L
.05706 .36884 L
.05795 .36972 L
.08312 .39115 L
.08963 .39578 L
.10917 .40763 L
.13523 .41964 L
.14074 .42183 L
.16128 .42794 L
.18734 .43294 L
.21339 .43485 L
.23945 .43375 L
.2655 .42959 L
.29156 .42219 L
.29261 .42183 L
.31761 .41124 L
.34367 .39603 L
.34405 .39578 L
.36972 .37551 L
.37582 .36972 L
.39578 .34724 L
.39849 .34367 L
.41525 .31761 L
.42183 .30485 L
.4275 .29156 L
.436 .2655 L
.44117 .23945 L
.44325 .21339 L
.44232 .18734 L
.43834 .16128 L
.43114 .13523 L
.42183 .11212 L
.42037 .10917 L
.40546 .08312 L
.39578 .06961 L
.38528 .05706 L
.36972 .04137 L
.35758 .03101 L
.34367 .02092 L
.31761 .00569 L
.3162 .00495 L
s
.00495 .12854 m
.01344 .10917 L
.02832 .08312 L
.03101 .07912 L
.04848 .05706 L
.05706 .04802 L
.07619 .03101 L
.08312 .02579 L
.10917 .00934 L
.11742 .00495 L
s
.29156 .15739 m
.31761 .14824 L
.34367 .14249 L
.36972 .13986 L
.39578 .14025 L
.42183 .14366 L
.44789 .15025 L
.47394 .16034 L
.47599 .16128 L
.5 .17443 L
.51844 .18734 L
.52606 .19355 L
.54662 .21339 L
.55211 .21962 L
.56712 .23945 L
.57817 .25755 L
.58227 .2655 L
.59322 .29156 L
.60058 .31761 L
.60422 .3392 L
.60471 .34367 L
.6058 .36972 L
.60422 .39297 L
.60387 .39578 L
.59886 .42183 L
.59054 .44789 L
.57848 .47394 L
.57817 .47453 L
.562 .5 L
.55211 .51255 L
.53968 .52606 L
.52606 .53862 L
.50853 .55211 L
.5 .55773 L
.47394 .57183 L
.45901 .57817 L
.44789 .5819 L
.42183 .5885 L
.39578 .59192 L
.36972 .59231 L
.34367 .58968 L
.31761 .58392 L
.29972 .57817 L
.29156 .57477 L
.2655 .56178 L
.25025 .55211 L
.23945 .54409 L
.21914 .52606 L
.21339 .52008 L
.19681 .5 L
Mistroke
.18734 .48608 L
.18031 .47394 L
.16827 .44789 L
.16128 .42714 L
.15996 .42183 L
.15493 .39578 L
.153 .36972 L
.15409 .34367 L
.15823 .31761 L
.16128 .3045 L
.16559 .29156 L
.17653 .2655 L
.18734 .24609 L
.19169 .23945 L
.21221 .21339 L
.21339 .21211 L
.23945 .1881 L
.24041 .18734 L
.2655 .17038 L
.28271 .16128 L
.29156 .15739 L
Mfstroke
0 g
.03 w
.21687 .20845 Mdot
.3794 .36608 Mdot
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.522676 0.522676 0.97619 0.97619 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.49505 0.5 0.49505 [
[ 0 0 -0.125 0 ]
[ 0 0 -0.125 0 ]
[ 0 1 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
0 0 m
1 0 L
s
0 0 m
0 1 L
s
0 1 m
1 1 L
s
1 0 m
1 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
1 .5 0 r
.015 w
.03175 .1355 Mdot
.03435 .12523 Mdot
.11137 .12765 Mdot
.14107 .18841 Mdot
.16218 .24538 Mdot
.17294 .21053 Mdot
.18267 .18577 Mdot
.18434 .1304 Mdot
.18553 .30956 Mdot
.20401 .239 Mdot
.21247 .27571 Mdot
.21687 .20845 Mdot
.22376 .2799 Mdot
.22832 .27485 Mdot
.29063 .20974 Mdot
.29686 .25079 Mdot
.30487 .22936 Mdot
.30683 .34623 Mdot
.32055 .20902 Mdot
.32574 .21979 Mdot
.34472 .28521 Mdot
.35998 .36393 Mdot
.36335 .24976 Mdot
.3794 .36608 Mdot
.42386 .66992 Mdot
.44391 .74519 Mdot
.45059 .34198 Mdot
.47208 .67586 Mdot
.47436 .71381 Mdot
.49778 .59825 Mdot
.50874 .91643 Mdot
.51516 .76219 Mdot
.53655 .61374 Mdot
.56563 .75219 Mdot
.59189 .65665 Mdot
.59581 .61604 Mdot
.59923 .6556 Mdot
.60292 .68499 Mdot
.62656 .67779 Mdot
.63555 .72451 Mdot
.63919 .652 Mdot
.64169 .6004 Mdot
.64246 .58611 Mdot
.64496 .54267 Mdot
.64608 .77288 Mdot
.65077 .64308 Mdot
.66065 .57816 Mdot
.67474 .59169 Mdot
.69296 .563 Mdot
.72815 .65902 Mdot
.73169 .58879 Mdot
.74669 .61318 Mdot
.74821 .65474 Mdot
.75963 .63781 Mdot
.79673 .57809 Mdot
.80925 .55852 Mdot
.81525 .58444 Mdot
.83417 .62985 Mdot
.83598 .55526 Mdot
.91595 .49319 Mdot
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{400, 400},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40006@0001T2000`400?l00000o`00003ooooooonA
ooooo`00oooooonAooooo`00oooooonAooooo`00oooooonAooooo`00oooooonAooooo`00oooooonA
ooooo`00oooooonAooooo`00oooooonAooooo`00oooooonAooooo`00oooooonAooooo`002Ooooonf
00000=7ooooo0009ooooo`0300000?oooooooooo0;;ooooo00<00000ooooooooool0coooool000Wo
oooo00<00000ooooooooool0/_ooool00`00003oooooooooo`3?ooooo`002Oooool00`00003ooooo
ooooo`2booooo`0300000?oooooooooo0<oooooo0009ooooo`0300000?oooooooooo00[ooooo00?o
0000ooooooooool02_ooool200000003o`000?oooooooooo02Kooooo0_l00002000000_ooooo0P00
000;ooooo`03o`000000003ooooo00cooooo00<00000ooooooooool04_ooool00`00003ooooooooo
o`0]ooooo`0300000?oooooooooo0<oooooo0009ooooo`0400000?ooooooooooooooo`P0C4a<00?o
000006IVIP1VIVH02@1VIVH2000002l0Ogmo0P00000;06IVIP030000001<C4`0C4a<00X0C4a<00<0
000003<c<`0c<c<02`0c<c<00`0000006ATI01TI6@0A01TI6B`000001?ooool00`00003ooooooooo
o`3?ooooo`002Oooool01000003oooooooooooooool604a<C0;o00002`1VIVH00`000000Ogmo07mo
O`0B07moO`/00000501oOgl00`000000IVIV06IVIP0906IVIP8000002`1<C4`00`000000<c<c03<c
<`0;03<c<`030000000I6AT06ATI01406ATI:`000004ooooo`0300000?oooooooooo0<oooooo0009
ooooo`0400000?ooooooooooooooo`D0C4a<00?o000006IVIP1VIVH02P1VIVH00`000000Ogmo07mo
O`0>07moO`D000002`2IVIT00`00003o000000000004000000h0Ogmo00<00000o`00000000002P1V
IVH00`000000C4a<04a<C00904a<C0030000000c<c<0<c<c00/0<c<c00<0000001TI6@0I6AT04@0I
6ATZ000000Cooooo00<00000ooooooooool0coooool000Wooooo00@00000oooooooooooooooo1@1<
C4`00ol00000IVIV06IVIP0806IVIP0300000?l00000Ogmo00h0Ogmo0P00000G09VIV@<000003P1o
Ogl00`000000IVIV06IVIP0806IVIP03o`00001<C4`0C4a<00P0C4a<00<0000003<c<`0c<c<02`0c
<c<00`0000006ATI01TI6@0B01TI6@03o`0000000000000002H000001?ooool00`00003ooooooooo
o`3?ooooo`002Oooool01000003oooooooooooooool404a<C003o`00001VIVH0IVIV00P0IVIV00<0
000007moO`1oOgl02`1oOgl4000001`0VIVI00<0000007moO`1oOgl0301oOgl00`000000IVIV06IV
IP0806IVIP030000001<C4`0C4a<00P0C4a<00<0000003<c<`0c<c<02`0c<c<00`0000006ATI01TI
6@0A01TI6BT000001?ooool00`00003oooooooooo`3?ooooo`002Oooool01000003ooooooooooooo
ool304a<C003o`00001VIVH0IVIV00P0IVIV00<0000007moO`1oOgl02P1oOgl200000240VIVI0`00
000<07moO`030000001VIVH0IVIV00P0IVIV00<0000004a<C01<C4`0201<C4`00`000000<c<c0000
000;03<c<`030000000I6AT06ATI01406ATI:0000004ooooo`0300000?oooooooooo0<oooooo0009
ooooo`0400000?ooooooooooooooo`80C4a<00?o000006IVIP1VIVH01`1VIVH00`00003o000007mo
O`0:07moO`0300000?l00000VIVI02D0VIVI00?o00000000000000002P1oOgl2000000T0IVIV00<0
0000o`00001<C4`0201<C4`00`000000<c<c03<c<`0;03<c<`030000000I6AT06ATI01006ATI:000
0004ooooo`0300000?oooooooooo0<oooooo0009ooooo`0400000?ooooooooooooooo`80C4a<00?o
000006IVIP1VIVH01P1VIVH00`000000Ogmo07moO`0907moO`800000:`2IVIT00`000000Ogmo07mo
O`0907moO`030000001VIVH0IVIV00P0IVIV00<0000004a<C01<C4`01`1<C4`00`000000<c<c03<c
<`0:03<c<`030000000I6AT06ATI01006ATI:0000004ooooo`0300000?oooooooooo0<oooooo0009
ooooo`0600000?ooooooooooooooo`1<C4co0000201VIVH00`000000Ogmo07moO`0807moO`800000
4@2IVIT?000000h0VIVI0P00000:07moO`030000001VIVH0IVIV00P0IVIV00<0000004a<C01<C4`0
1`1<C4`00`000000<c<c03<c<`0:03<c<`030000000I6AT06ATI01006ATI9`000004ooooo`030000
0?oooooooooo0<oooooo0009ooooo`0500000?ooooooooooooooool00000201VIVH00ol00000Ogmo
07moO`0807moO`030000002IVIT0VIVI00d0VIVI00@00000o`000?l0000000003`2c/k<3000000d0
VIVI0P00000907moO`030000001VIVH0IVIV00P0IVIV00<0000004a<C01<C4`01`1<C4`00`000000
<c<c03<c<`0:03<c<`030000000I6AT06ATI01006ATI9P000004ooooo`0300000?oooooooooo0<oo
oooo0009ooooo`0400000?ooooooooooooooo`T0IVIV00<0000007moO`1oOgl01`1oOgl00`000000
VIVI09VIV@0;09VIV@<000005P2c/k<4000000/0VIVI0P00000807moO`03o`00001VIVH0IVIV00L0
IVIV00?o000004a<C01<C4`0201<C4`00ol00000<c<c03<c<`0903<c<`030000000I6AT06ATI0100
6ATI9P000004ooooo`0300000?oooooooooo0<oooooo0009ooooo`0400000?ooooooooooooooo`P0
IVIV00<0000007moO`1oOgl01`1oOgl00`000000VIVI09VIV@0909VIV@<000007@2c/k<2000000/0
VIVI00<0000007moO`1oOgl01P1oOgl00`000000IVIV06IVIP0706IVIP030000001<C4`0C4a<00L0
C4a<00<0000003<c<`0c<c<02P0c<c<00`0000006ATI01TI6@0@01TI6BD000001?ooool00`00003o
ooooooooo`3?ooooo`002Oooool01000003oooooooooooooool706IVIP800000201oOgl00`000000
VIVI09VIV@0909VIV@030000002c/k<0/k>c0200/k>c00<0000009VIV@2IVIT02@2IVIT00ol00000
Ogmo07moO`0607moO`030000001VIVH0IVIV00L0IVIV00<0000004a<C01<C4`01`1<C4`00`000000
<c<c03<c<`0:03<c<`030000000I6AT06ATI00l06ATI9@000004ooooo`0300000?oooooooooo08_o
oooo0_l00012ooooo`002Oooool01000003oooooooooooooool706IVIP030000001oOgl0Ogmo00H0
Ogmo00?o000009VIV@2IVIT01`2IVIT00`00003o00000000000T0;>c/`03o`0000000000000000P0
VIVI0P00000807moO`030000001VIVH0IVIV00L0IVIV00<0000004a<C01<C4`01`1<C4`00`000000
<c<c03<c<`0903<c<`03o`00000I6AT06ATI01006ATI90000004ooooo`0300000?oooooooooo08So
oooo0ol000000ooooooo0000ooooo`11ooooo`002Oooool01000003oooooooooooooool606IVIP03
0000001oOgl0Ogmo00H0Ogmo00<0000009VIV@2IVIT01`2IVIT00`000000/k>c0;>c/`0X0;>c/`03
0000002IVIT0VIVI00L0VIVI0P00000707moO`030000001VIVH0IVIV00L0IVIV00?o000004a<C01<
C4`01`1<C4`00ol00000<c<c03<c<`0803<c<`030000000I6AT06ATI01406ATI8`000004ooooo`03
00000?oooooooooo08Kooooo0_l00003ooooo`03oj^mi_l0003o0000047ooooo0009ooooo`040000
0?ooooooooooooooo`D0IVIV00<0000007moO`1oOgl01P1oOgl00`000000VIVI09VIV@0709VIV@03
0000002c/k<0/k>c00d0/k>c3`00000>0;>c/`03o`00002IVIT0VIVI00P0VIVI00?o000007moO`1o
Ogl01@1oOgl00`000000IVIV06IVIP0706IVIP030000001<C4`0C4a<00H0C4a<00<0000003<c<`0c
<c<02@0c<c<00`0000006ATI01TI6@0A01TI6B8000001?ooool00`00003oooooooooo`23ooooo`?o
00000_ooool01on/_NKoZkgVoj^mi_n[_NKo0000ooooool00000@?ooool000Wooooo00@00000oooo
oooooooooooo101VIVH00`000000Ogmo07moO`0607moO`03o`00002IVIT0VIVI00H0VIVI00<00000
o`00002c/k<02`2c/k<4000000l0c<c<0`00000<0;>c/`800000202IVIT2000000L0Ogmo00<00000
06IVIP1VIVH01`1VIVH00`000000C4a<04a<C00604a<C0030000000c<c<0<c<c00T0<c<c00<00000
01TI6@0I6AT0400I6AT00ol0000000000000000O000000Cooooo00<00000ooooooooool0P?ooool3
o`0000?ooooo1?n/_NH2oj^miP03o`000?oooooo0000043ooooo0009ooooo`0400000?oooooooooo
ooooo`@0IVIV00<0000007moO`1oOgl01@1oOgl00`000000VIVI09VIV@0609VIV@030000002c/k<0
/k>c00T0/k>c0`00000F0<c<c0<000002`2c/k<00`000000VIVI09VIV@0709VIV@030000001oOgl0
Ogmo00D0Ogmo00?o000006IVIP1VIVH01P1VIVH00`000000C4a<04a<C00704a<C0030000000c<c<0
<c<c00T0<c<c00?o000001TI6@0I6AT03`0I6ATR000000Cooooo00<00000ooooooooool0O_ooool2
o`0000Gooooo1on/_NH01?l0003o[;gVooooool0000oooooo`002Oooool01000003ooooooooooooo
ool306IVIP030000001oOgl0Ogmo00D0Ogmo00<0000009VIV@2IVIT01P2IVIT00`000000/k>c0;>c
/`090;>c/`030000003<c<`0c<c<01X0c<c<00<000000;>c/`2c/k<02@2c/k<2000000P0VIVI00?o
000007moO`1oOgl01@1oOgl00`000000IVIV06IVIP0606IVIP030000001<C4`0C4a<00L0C4a<00<0
000003<c<`0c<c<0200c<c<00`0000006ATI01TI6@0@01TI6B4000001?ooool00`00003ooooooooo
o`1kooooo`?o00001Oooool01On]_NGo[;gVojbmi_n/_NKo[KgU00Co[;gV00Go0000ojbmi_oooooo
ooooo`00000nooooo`002Oooool01000003oooooooooooooool206IVIP03o`00001oOgl0Ogmo00D0
Ogmo00<0000009VIV@2IVIT01P2IVIT00ol00000/k>c0;>c/`080;>c/`03o`0000000000c<c<01d0
c<c<0`00000:0;>c/`03o`00002IVIT0VIVI00H0VIVI00<0000007moO`1oOgl01@1oOgl00`000000
IVIV06IVIP0506IVIP0300000?l00000C4a<00P0C4a<00<0000003<c<`0c<c<0200c<c<00`000000
6ATI01TI6@0@01TI6B0000001?ooool00`00003oooooooooo`1iooooo`;o00001Oooool00on^_>Co
[KgUojfmi@02ojfmi@04ojbmi_n]_NGo[KgUojfmi@;o[;gV00Ko[KgVo`000?n/_NKo[;gVooooool0
000nooooo`002Oooool01000003oooooooooooooool206IVIP030000001oOgl0Ogmo00D0Ogmo00?o
000009VIV@2IVIT01P2IVIT00`000000/k>c0;>c/`070;>c/`030000003<c<`0c<c<0240c<c<00<0
00000;>c/`2c/k<0202c/k<00`000000VIVI09VIV@0509VIV@030000001oOgl0Ogmo00D0Ogmo00<0
000006IVIP1VIVH01P1VIVH00`000000C4a<04a<C00704a<C003o`00000c<c<0<c<c00P0<c<c00<0
000001TI6@0I6AT0400I6ATP000000Cooooo00<00000ooooooooool0M_ooool3o`0000Gooooo00Co
[kcTojjli?n^_>Co[[cT0_n]_ND2ojjmi@?o[KgU0on]_NH01_l0003o[;gVojbmi_n/_NKoooooo`00
03gooooo0009ooooo`0400000?ooooooooooooooo`80IVIV00<0000007moO`1oOgl01@1oOgl00`00
0000VIVI09VIV@0509VIV@030000002c/k<0/k>c00L0/k>c00<000000<c<c03<c<`08`3<c<`20000
00T0/k>c00<0000009VIV@2IVIT01@2IVIT00`000000Ogmo07moO`0507moO`030000001VIVH0IVIV
00H0IVIV00<0000004a<C01<C4`01P1<C4`00`000000<c<c03<c<`0903<c<`030000000I6AT06ATI
00l06ATI80000004ooooo`0300000?oooooooooo07Cooooo0_l00005ooooo`03ok2lhon__>Co[kcT
00;o[kcT0on^_>@4ojjmi@?o[KgU0_n]_NH00ol0003o[;gVojbmiP02ojbmiP03o`000?oooooooooo
03_ooooo0009ooooo`0600000?ooooooooooooooo`1VIVH000001`1oOgl00`000000VIVI09VIV@05
09VIV@030000002c/k<0/k>c00L0/k>c00<000000<c<c03<c<`04@3<c<`400000140c<c<00<00000
0;>c/`2c/k<01`2c/k<00`000000VIVI09VIV@0509VIV@03o`00001oOgl0Ogmo00D0Ogmo00<00000
06IVIP1VIVH01@1VIVH00`000000C4a<04a<C00704a<C0030000000c<c<0<c<c00P0<c<c00<00000
01TI6@0I6AT0400I6ATO000000Cooooo00<00000ooooooooool0LOooool3o`0000Cooooo0_n`^n83
ok2lh`;o[kcT00?o[kcSojjli?n^_>@00_n^_>@4ojjmi@06ojfmiOn^_NGo[KgVojfmi_l0003o[KgV
0_n/_NH00on]_NKoooooo`00000looooo`002Oooool01P00003oooooooooooooool0IVIV000000H0
Ogmo00<0000009VIV@2IVIT01P2IVIT00ol00000/k>c0;>c/`060;>c/`03o`00003<c<`0c<c<00/0
c<c<00<00000o`0000000000100000040>KViP0400000?l000000000000000h0c<c<0P0000080;>c
/`03o`00002IVIT0VIVI00D0VIVI00<0000007moO`1oOgl01@1oOgl00`000000IVIV06IVIP0506IV
IP030000001<C4`0C4a<00H0C4a<00<0000003<c<`0c<c<02@0c<c<00`0000006ATI01TI6@0?01TI
6Al000001?ooool00`00003oooooooooo`1^ooooo`?o00001Oooool00onb^n7o/;_Rok2khP02ok2k
hP03ok2lhon`_>;o/;cR00?o[kcS0_n^_>@2ojnmi0;o[[gU00Oo[kgTojjmiOn^_NGo[[gUojfmi_l0
003o[KgU00Co[KgV00?oooooo`000?ooool0>_ooool000Wooooo00H00000oooooooooooooooo06IV
IP00000607moO`030000002IVIT0VIVI00H0VIVI00<000000;>c/`2c/k<01@2c/k<00`000000c<c<
0<c<c0090<c<c0<000003`3Vi^H3000000d0c<c<00<000000;>c/`2c/k<01P2c/k<00`000000VIVI
09VIV@0409VIV@030000001oOgl0Ogmo00D0Ogmo00<0000006IVIP1VIVH01P1VIVH00ol00000C4a<
04a<C00504a<C0030000000c<c<0<c<c00X0<c<c00?o000001TI6@0I6AT03P0I6ATO000000Cooooo
00<00000ooooooooool0K?ooool2o`0000Oooooo0onb^n42ok2khP03ok6khOn`_>;o/;cR00;o/;cR
00?o[kcSok2lhon__N@01on__N@3ojjmi@03ojfmiOl0003o[KgU00?o[KgV00?oooooo`000?ooool0
>_ooool000Wooooo00D00000oooooooooooooooo0000000607moO`030000002IVIT0VIVI00H0VIVI
00<000000;>c/`2c/k<01@2c/k<00`000000c<c<0<c<c0080<c<c08000005@3Vi^H4000000X0c<c<
00<000000;>c/`2c/k<01P2c/k<00`000000VIVI09VIV@0409VIV@030000001oOgl0Ogmo00D0Ogmo
00<0000006IVIP1VIVH01@1VIVH00`000000C4a<04a<C00604a<C0030000000c<c<0<c<c00T0<c<c
00<0000001TI6@0I6AT03`0I6ATN000000Cooooo00<00000ooooooooool0JOooool3o`0000Oooooo
0_nc^]l3ok:kh@Co/K_Q0_n`_>801?na_>;o/;cSok2lhon`_><7ojnmi0Co[[gU00?o0000ojjmiOn]
_NH00on]_NH00ooooooo0000ooooo`0iooooo`002Oooool01@00003oooooooooooooool0000000H0
Ogmo00<0000009VIV@2IVIT01@2IVIT00`000000/k>c0;>c/`050;>c/`03o`00003<c<`0c<c<00P0
c<c<00<000000>KViP3Vi^H06@3Vi^H00ol00000c<c<0<c<c0080<c<c0030000002c/k<0/k>c00H0
/k>c00<0000009VIV@2IVIT0102IVIT00ol00000Ogmo07moO`0507moO`030000001VIVH0IVIV00D0
IVIV00<0000004a<C01<C4`01P1<C4`00`000000<c<c03<c<`0903<c<`030000000I6AT06ATI00h0
6ATI7P000004ooooo`0300000?oooooooooo06Oooooo0_l00008ooooo`03okBjg_nc^]oo/k[O00;o
/k[O00?o/[_Qok:kh?nb^n000_na^n400onb_>7o/KcRok6lhP02ok6lhP03ok2lhona_>?o/KcS00Oo
[kgT0_n^_ND01?n__NGo0000ojjmiOn^_ND3ojfmiP;ooooo00?o0000ooooooooool0=oooool000Wo
oooo00@00000oooooooooooooooo1`1oOgl00ol00000VIVI09VIV@0509VIV@030000002c/k<0/k>c
00D0/k>c00<000000<c<c03<c<`01`3<c<`00`000000i^KV0>KViP0J0>KViP8000002@3<c<`00`00
0000/k>c0;>c/`060;>c/`030000002IVIT0VIVI00D0VIVI00<0000007moO`1oOgl0101oOgl00`00
0000IVIV06IVIP0506IVIP030000001<C4`0C4a<00H0C4a<00?o000003<c<`0c<c<02@0c<c<00`00
00006ATI01TI6@0>01TI6Ah000001?ooool00`00003oooooooooo`1Tooooo`?o00002?ooool4okBj
gP;o/k[O00Go];[Nok:kh?nb^n3o/[_Pok>kg`03ok:lh@;o/KcR00?o/[cQok6lhona_><00_na_><0
0on__NCo/;gSok2mh`02ojnmi005ok2mi?n__NGo[kgUojnmiOl000000on^_ND3ojfmiP03ooooool0
003ooooo03Sooooo0009ooooo`0400000?ooooooooooooooo`L0Ogmo00<0000009VIV@2IVIT0102I
VIT00`000000/k>c0;>c/`050;>c/`030000003<c<`0c<c<00L0c<c<00<000000>KViP3Vi^H07@3V
i^H2000000P0c<c<00<000000;>c/`2c/k<01P2c/k<00`000000VIVI09VIV@0409VIV@030000001o
Ogl0Ogmo00D0Ogmo00<0000006IVIP1VIVH01@1VIVH00`000000C4a<04a<C00504a<C0030000000c
<c<0<c<c00T0<c<c00<0000001TI6@0I6AT03P0I6ATN000000Cooooo00<00000ooooooooool0H_oo
ool2o`0000[ooooo0_ne^M`2okBjgP03okFjgOnd^]ko];[N00;o];[N00Go/[_Pok>kgonc^moo/k_O
ok:lh@02ok>lh0?o/[cQ0_na_><2ok6mhP03ok2mhona_N?o/KgS00?o/;gT0_n__ND00ol0003o[[gU
ojjmi@02ojjmi@05ojfmi_n^_^Ko[[kVooooool00000>?ooool000Wooooo00@00000oooooooooooo
oooo1P1oOgl00`000000VIVI09VIV@0509VIV@030000002c/k<0/k>c00D0/k>c00<000000<c<c03<
c<`01P3<c<`00`000000i^KV0>KViP0P0>KViP03o`00003<c<`0c<c<00H0c<c<00<000000;>c/`2c
/k<01@2c/k<00`000000VIVI09VIV@0509VIV@030000001oOgl0Ogmo00@0Ogmo00<0000006IVIP1V
IVH01@1VIVH00`000000C4a<04a<C00604a<C0030000000c<c<0<c<c00T0<c<c00<0000001TI6@0I
6AT03P0I6ATM000000Cooooo00<00000ooooooooool0Goooool3o`0000[ooooo00Go][SJokFig?ne
^Mco]KWLokJif`03okFjg@;o];[N00Go]K[Nok>kgonc^moo/k_OokBkg`04ok>lh003ok:lhOnc_>7o
/KgR00;o/KgR00?o/[gRok6mhona_N<00_na_N<3ok2mi003ojnmi?l0003o[kgT00;o[[gU0_n^_^D3
ojjniP03ooooool0003ooooo03Kooooo0009ooooo`0400000?ooooooooooooooo`H0Ogmo00<00000
09VIV@2IVIT0102IVIT00ol00000/k>c0;>c/`050;>c/`030000003<c<`0c<c<00H0c<c<00?o0000
0>KViP3Vi^H08P3Vi^H00`000000c<c<0<c<c0060<c<c0030000002c/k<0/k>c00D0/k>c00<00000
09VIV@2IVIT0102IVIT00`000000Ogmo07moO`0507moO`030000001VIVH0IVIV00D0IVIV00<00000
04a<C01<C4`01P1<C4`00`000000<c<c03<c<`0803<c<`030000000I6AT06ATI00h06ATI7@000004
ooooo`0300000?oooooooooo05gooooo0_l0000:ooooo`03okNgf?nf^=[o][SJ00;o][SJ00Go]KWL
okJifonf^M_o][WKokFjg@02okJjg0?o]K[N00Co/k_OokBkgond^moo];_O0_nc_>001Ond_>3o/kcQ
ok>lhOnc_>7o/KgR00?o/[gR0ona_N<4ok2mi003o`000?n__^Co[[kU00;o[[kU00?o[kkUojjni_n^
_^H00_n^_^H00ol0003oooooooooo`0eooooo`002Oooool01000003oooooooooooooool607moO`03
0000002IVIT0VIVI00@0VIVI00<000000;>c/`2c/k<0102c/k<00ol00000c<c<0<c<c0070<c<c003
0000003Vi^H0i^KV02<0i^KV00<000000<c<c03<c<`01P3<c<`00`000000/k>c0;>c/`040;>c/`03
0000002IVIT0VIVI00@0VIVI00<0000007moO`1oOgl01@1oOgl00`000000IVIV06IVIP0506IVIP03
o`00001<C4`0C4a<00H0C4a<00<0000003<c<`0c<c<0200c<c<00`0000006ATI01TI6@0>01TI6Ad0
00001?ooool00`00003oooooooooo`1Jooooo`?o00002_ooool01?nh]MKo]kOHokNgf?ng]mP2okJh
fP05okNhfOnf^M_o][WKokJifong^MX01?nf^]`00one^]ko][_MokJkg@03okBkg`Co];cP00?o/kcQ
ok>mhOnc_N400onb_N84ok6mh`;o/;gT00Go/KkTo`000?n__^Co[kkTojjni@03ojnni@;o[[kV00?o
[[kUooooool00000=_ooool000Wooooo00@00000oooooooooooooooo1@1oOgl00`000000VIVI09VI
V@0409VIV@030000002c/k<0/k>c00D0/k>c00<000000<c<c03<c<`01P3<c<`00`000000i^KV0>KV
iP0<0>KViP_o00003P3Vi^H00ol00000c<c<0<c<c0060<c<c0030000002c/k<0/k>c00@0/k>c00<0
000009VIV@2IVIT0102IVIT00`000000Ogmo07moO`0507moO`030000001VIVH0IVIV00@0IVIV00<0
000004a<C01<C4`01`1<C4`00`000000<c<c03<c<`0803<c<`030000000I6AT06ATI00h06ATI7000
0004ooooo`0300000?oooooooooo05Oooooo0ol0000<ooooo`?o^;GF0_ng]mP01Oni]mOo]kSIokNh
fOng^=Wo][WK00?o]kWJ0_nf^]`00ong^]_o][_MokJkg@02okJkg@03okBkgonf_=ko][cN00;o];cP
00?o]KcOok>mhOnc_N400_nc_N400onb_N;o/kgRok>mhP02ok6mh`06ok:nhona_^Co/KkTok6ni?l0
003o[kkT0_n`_^@3ojnni@Co[[kU00?oooooo`000?ooool0=?ooool000Wooooo00@00000oooooooo
oooooooo1@1oOgl00`000000VIVI09VIV@0409VIV@030000002c/k<0/k>c00@0/k>c00<000000<c<
c03<c<`01P3<c<`00`000000i^KV0>KViP0;0>KViP;o00002`3oool3o`0000`0i^KV00<000000<c<
c03<c<`01P3<c<`00`000000/k>c0;>c/`040;>c/`03o`00002IVIT0VIVI00@0VIVI00?o000007mo
O`1oOgl0101oOgl00`000000IVIV06IVIP0506IVIP030000001<C4`0C4a<00H0C4a<00<0000003<c
<`0c<c<0200c<c<00`0000006ATI01TI6@0>01TI6A`000001?ooool00`00003oooooooooo`1Eoooo
o`;o00003_ooool4okReeP05okNgf?ni]mOo^KOGokVgeong^=T00_ni^=P3okNifP04okVifOng^]_o
]k[KokNjf`;o][_M00Go]k_LokJlg_nf_=ko][cNokNlgP03okFlg`;o/kgQ0_nd_N000onc_N;o/kkQ
ok>nh@03ok:nh`;o/KkT00?o0000ok6nhon`_^@00_n`_^@3ojnni@?o[[kU00?oooooo`000?ooool0
=?ooool000Wooooo00@00000oooooooooooooooo1@1oOgl00`000000VIVI09VIV@0409VIV@030000
002c/k<0/k>c00@0/k>c00<000000<c<c03<c<`01@3<c<`00ol00000i^KV0>KViP0;0>KViP03o`00
003oool0oooo00h0oooo00?o00000>KViP3Vi^H02@3Vi^H00`000000c<c<0<c<c0060<c<c0030000
002c/k<0/k>c00@0/k>c00<0000009VIV@2IVIT0102IVIT00`000000Ogmo07moO`0407moO`030000
001VIVH0IVIV00D0IVIV00<0000004a<C01<C4`01P1<C4`00`000000<c<c03<c<`0803<c<`03o`00
000I6AT06ATI00l06ATI00?o000000000000000060000004ooooo`0300000?oooooooooo05;ooooo
0ol0000?ooooo`;o^KCD0_nh]MH01Onj]MGo^KOGokVgeoni]mOo^[OF00Co^KSH00Ko]kWJokVifOni
^MWo^KWIokNjfoni^]/4okNkg006okJlg_ng_=ko]kcNokNlg_ne_=oo][gO0ond_N000one_N3o/kkQ
ok>nh@02ok>nh@06ok:nhonc_^;o/KkSok6nhol0003o/[kS1?n`_^@2ojnni@Co[[kU00?oooooo`00
0?ooool0<oooool000Wooooo00@00000oooooooooooooooo1@1oOgl00`000000VIVI09VIV@0409VI
V@030000002c/k<0/k>c00@0/k>c00<000000<c<c03<c<`01@3<c<`00`000000i^KV0>KViP0:0>KV
iP03o`00003oool0oooo0100oooo00?o00000>KViP3Vi^H02@3Vi^H00`000000c<c<0<c<c0060<c<
c0030000002c/k<0/k>c00<0/k>c00<0000009VIV@2IVIT0102IVIT00`000000Ogmo07moO`0507mo
O`030000001VIVH0IVIV00@0IVIV00<0000004a<C01<C4`01`1<C4`00`000000<c<c03<c<`0703<c
<`030000000I6AT06ATI00l06ATI6`000004ooooo`0300000?oooooooooo053ooooo0_l0000@oooo
o`05okZbd_ni]=Co^KCDokVde?nj]=<00onj]MD01?ni]mOo^[OFokZge_nj]mH2okVhf005okZheoni
^MWo^KWIokVifOnj^MT00oni^]/2okNkg005okRkg?ng_=ko]kcNokNlg_nh_=d00onf_Ml01?nd_N3o
]KgPokFmh?ne_N02ok>nh@06okBnhOnc_^;o/kkRok>nh_na_^?o00000_nb_^<2ok2ni004ok6oi?n_
_^Go[kkUojnni@;o[[kU0_n__^D00ol0003oooooooooo`0booooo`002Oooool01000003ooooooooo
ooooool407moO`030000002IVIT0VIVI00@0VIVI00<000000;>c/`2c/k<0102c/k<00`000000c<c<
0<c<c0050<c<c0030000003Vi^H0i^KV00X0i^KV00?o00000?ooo`3oool04P3oool00ol00000i^KV
0>KViP080>KViP030000003<c<`0c<c<00H0c<c<00<000000;>c/`2c/k<0102c/k<00`000000VIVI
09VIV@0409VIV@030000001oOgl0Ogmo00@0Ogmo00<0000006IVIP1VIVH01@1VIVH00`000000C4a<
04a<C00604a<C0030000000c<c<0<c<c00P0<c<c00<0000001TI6@0I6AT03P0I6ATK000000Cooooo
00<00000ooooooooool0COooool3o`00013ooooo1?nj/]801Oni]=Co^[CCokZddonj]=?o^[GE00;o
^kGD0onj]mH4okZhe`05okVifOnj^MWo^[WIokZifOni^]/00_nj^mX3okRkg005okNlg_nh_=go^;cM
okRlgOnf_Ml00_ng_Mh3okFmh0Co];kQ0onc_^800ol0003o/[kSok:oh`04ok6oi003ojnniOn`_nGo
[kkU00;o[kkU00?o[koUooooool00000<oooool000Wooooo00@00000oooooooooooooooo101oOgl0
0`000000VIVI09VIV@0409VIV@030000002c/k<0/k>c00@0/k>c00<000000<c<c03<c<`01@3<c<`0
0`000000i^KV0>KViP090>KViP03o`00003oool0oooo01@0oooo00?o00000>KViP3Vi^H0203Vi^H0
0ol0000000000<c<c0060<c<c0030000002c/k<0/k>c00@0/k>c00<0000009VIV@2IVIT0102IVIT0
0`000000Ogmo07moO`0407moO`030000001VIVH0IVIV00@0IVIV00<0000004a<C01<C4`01P1<C4`0
0ol00000<c<c03<c<`0803<c<`030000000I6AT06ATI00h06ATI6`000004ooooo`0300000?oooooo
oooo04_ooooo0_l0000Booooo`;o^[7@0_nj/]801Onk/]7o^[CCokZddonj]=?o_;CB00Co^kGD00?o
^[OFok^geOnk]mD00onj^=L3okZif@03ok^jf?nj^m[o^[_J00;o^[_J00?o^;_LokVlfoni_=/00_nh
_=d00oni_Mgo]kgNokNmgP02okNmgP03okFmh?nf_^3o][kP00;o];kQ00Go]KkQok>nh_nc_^;o/kkR
o`000003ok:oh`?o/KoT0on`_nD01_n__^Go[koUojnoiOn__nGoooooo`0003;ooooo0009ooooo`04
00000?ooooooooooooooo`@0Ogmo00<0000009VIV@2IVIT0102IVIT00`000000/k>c0;>c/`040;>c
/`030000003<c<`0c<c<00D0c<c<00<000000>KViP3Vi^H02@3Vi^H00ol00000oooo0?ooo`0E0?oo
o`03o`00003Vi^H0i^KV00P0i^KV00<000000<c<c03<c<`01@3<c<`00`000000/k>c0;>c/`040;>c
/`030000002IVIT0VIVI00@0VIVI00<0000007moO`1oOgl0101oOgl00`000000IVIV06IVIP0406IV
IP030000001<C4`0C4a<00H0C4a<00<0000003<c<`0c<c<0200c<c<00`0000006ATI01TI6@0>01TI
6A/000001?ooool00`00003oooooooooo`18ooooo`?o00004_ooool01Onk[lko^[7@okZad?nj/M3o
^[;B00?o^k;A00Co^[CCokbdd_nl]=;o_;CB0_nk]M@00onl]]?o^kOEok^ge@02ok^ge@04okZheonk
^=Oo^kSGokZif@?o^k[H0_nj^mX01Onk^mWo^KcKokVlfoni_=_o^[cK00?o^KgM0_ng_Mh2okRngP03
okJnh?ng_^3o]kkP00?o]KkQ00Ko/kkRokBoh_l0003o];oRok:ohonc_n<4ok6oi0Co/;oU00Co[koU
ojnoi_oooooo0000<_ooool000Wooooo00@00000oooooooooooooooo101oOgl00`000000VIVI09VI
V@0409VIV@030000002c/k<0/k>c00@0/k>c00<000000<c<c03<c<`01@3<c<`00`000000i^KV0>KV
iP080>KViP03o`00003oool0oooo01L0oooo00?o00000>KViP3Vi^H0203Vi^H00`000000c<c<0<c<
c0050<c<c0030000002c/k<0/k>c00@0/k>c00<0000009VIV@2IVIT0102IVIT00`000000Ogmo07mo
O`0407moO`030000001VIVH0IVIV00@0IVIV00<0000004a<C01<C4`01P1<C4`00`000000<c<c03<c
<`0803<c<`030000000I6AT06ATI00h06ATI6P000004ooooo`0300000?oooooooooo04Gooooo0ol0
000Dooooo`?o^jo>00?o^[7@okbaconl/Ll00onk/]401Onm/]3o_;CBokbdd_nl]=;o^kGD00?o_;KC
0_nk]mD01Onm]mCo^kSGok^heonk^=Oo_KWF00?o^k[H1?nk^mT01_ni_=_o^[cKokZlfonj_=_o^KgM
okZmg@?o^;kN00?o^KkNokNnh?ng_^000_ng_^001_ne_^7o][oQokJohOnd_n;o0000okBohP?o/koS
1?na_n@3ok2oi@?o[koV00?oooooo`000?ooool0<?ooool000Wooooo00@00000oooooooooooooooo
101oOgl00`000000VIVI09VIV@0409VIV@030000002c/k<0/k>c00@0/k>c00<000000<c<c03<c<`0
1@3<c<`00`000000i^KV0>KViP070>KViP03o`00003oool0oooo01T0oooo00?o00000>KViP3Vi^H0
1`3Vi^H00`000000c<c<0<c<c0050<c<c0030000002c/k<0/k>c00@0/k>c00<0000009VIV@2IVIT0
102IVIT00`000000Ogmo07moO`0407moO`030000001VIVH0IVIV00@0IVIV00<0000004a<C01<C4`0
1P1<C4`00`000000<c<c03<c<`0803<c<`030000000I6AT06ATI00h06ATI6P000004ooooo`030000
0?oooooooooo04?ooooo0_l0000Eooooo`;o^jg<0onk[lh4okbac`05ok^bdOnm/]3o_K;@okfbd?nl
]=800_nm]=43okbfd`Co_KOD00Go^kSGokfie_nm^MKo_KWFok^jf002okfje`;o^k_I00Go_;cIokZl
fonj_=_o^[cKok^mf`03okZmg@04okRng_ni_]ko^KkNokVngP;o]kkP00Ko^;oPokJohOnf_n7o][oQ
okBoh_l00002okBohPCo/koS00?o/KoTok;0i?n`_nD00on`_nD2ojnoiP;ooooo00?o0000oooooooo
ool0;_ooool000Wooooo00@00000oooooooooooooooo101oOgl00`000000VIVI09VIV@0409VIV@03
0000002c/k<0/k>c00@0/k>c00<000000<c<c03<c<`01@3<c<`00`000000i^KV0>KViP070>KViP03
o`00003oool0oooo01T0oooo00?o00000>KViP3Vi^H01`3Vi^H00`000000c<c<0<c<c0050<c<c003
0000002c/k<0/k>c00@0/k>c00<0000009VIV@2IVIT0102IVIT00`000000Ogmo07moO`0407moO`03
0000001VIVH0IVIV00@0IVIV00<0000004a<C01<C4`01P1<C4`00`000000<c<c03<c<`0803<c<`03
0000000I6AT06ATI00h06ATI6P000004ooooo`0300000?oooooooooo043ooooo0ol0000Eooooo`03
ok^/b_nk[Lco^jg<00;o^jg<00?o^jo>okb_cOnl[ld00_nl/Ll01Onm/Lgo_K;@okfbd?nm/]3o_[?>
00Co_KCA00?o_;KCokjfd_nn]]800_nm]m@01Onn^=?o_KWFokfie_nm^MKo_[[E00?o_K[G00Go_[_G
okblfOnl_=Wo_;cIokZlf`03ok^mf`03okZmgOnk_]co^kkL00?o^KkN1?nh_n03okJoh@03o`000?nd
_n;o]L3R00?o/koS00Co/l3Sok;0i?nb`>Co//3T0_n`_nD01_na_nGo[koVojnoi_n__nKoooooo`00
033ooooo0009ooooo`0400000?ooooooooooooooo`@0Ogmo00<0000009VIV@2IVIT0102IVIT00`00
0000/k>c0;>c/`040;>c/`030000003<c<`0c<c<00D0c<c<00<000000>KViP3Vi^H01`3Vi^H00ol0
0000oooo0?ooo`0J0?ooo`03o`00003Vi^H0i^KV00L0i^KV00<000000<c<c03<c<`01@3<c<`00`00
0000/k>c0;>c/`040;>c/`030000002IVIT0VIVI00<0VIVI00<0000007moO`1oOgl0101oOgl00`00
0000IVIV06IVIP0506IVIP030000001<C4`0C4a<00D0C4a<00<0000003<c<`0c<c<0200c<c<00`00
00006ATI01TI6@0>01TI6AX000001?ooool00`00003oooooooooo`0nooooo`;o00005oooool3ok^/
bP;o^jg<00Go_:g;okb_cOnl[lgo_:o=okbac`03okfac@04okfbd?nn/lko_[?>okjccP;o_KCA00Go
_kC@okjfd_nn]];o_[KBokngd@03okjhd`05okfie_nn^]Go_[[EokjjeOnm^]L00onn^mL00onl_=Wo
_KgIok^mf`02ok^mf`03okfnfonk_]co^kkL00;o^kkL00?o^KkNokVog_ni_mh00_nh_n02okS0h003
okJohOng`>7o000000?o]L3R00Co/koSok?0honc`>?o/l3S0_nb`>@4ok6oi@?o[koV00?oooooo`00
0?ooool0;_ooool000Wooooo00@00000oooooooooooooooo101oOgl00`000000VIVI09VIV@0409VI
V@030000002c/k<0/k>c00@0/k>c00<000000<c<c03<c<`0103<c<`00`000000i^KV0>KViP070>KV
iP03o`00003oool0oooo01`0oooo00?o00000>KViP3Vi^H01P3Vi^H00`000000c<c<0<c<c0050<c<
c003o`00002c/k<0/k>c00@0/k>c00?o000009VIV@2IVIT0102IVIT00`000000Ogmo07moO`0407mo
O`030000001VIVH0IVIV00@0IVIV00<0000004a<C01<C4`01P1<C4`00`000000<c<c03<c<`0803<c
<`030000000I6AT06ATI00h06ATI6@000004ooooo`0300000?oooooooooo03_ooooo0ol0000Hoooo
o`Co^jc:00Co^jg<okb]bonl[L_o_:g;0_nl[ld01?nn[l_o_K7=okfacOnm/Ld4okjccP05okfddOno
]=3o_kC@okndd?nn]]800ono]m400onn^=?o`;SCokjje@02okjje@05ol2jeOnn^mOo_[_Gokjkeono
_=L00onm_MT01?nk_M_o_KkKokfnfonm_]/2ok^ng0;o_;oL00?o^KoNok[0g_nh`>000_nh`>001_ni
`N3o]l3QokO0hOl0003o]l3QokG0hP;o]L7R0_nc`><01?nd`NCo//3Tok;0i?nb`>@2ok6oi@;o/L3U
00Go[koVok30i_n``>Koooooo`00000^ooooo`002Oooool01000003oooooooooooooool407moO`03
0000002IVIT0VIVI00@0VIVI00<000000;>c/`2c/k<0102c/k<00`000000c<c<0<c<c0040<c<c003
0000003Vi^H0i^KV00L0i^KV00?o00000?ooo`3oool0703oool00ol00000i^KV0>KViP070>KViP03
o`00003<c<`0c<c<00@0c<c<00<000000;>c/`2c/k<0102c/k<00`000000VIVI09VIV@0409VIV@03
0000001oOgl0Ogmo00@0Ogmo00<0000006IVIP1VIVH0101VIVH00`000000C4a<04a<C00604a<C003
0000000c<c<0<c<c00P0<c<c00<0000001TI6@0I6AT03P0I6ATI000000Cooooo00<00000oooooooo
ool0>Oooool2o`0001[ooooo0_nkZ/P3ok^/bPCo_:g;00Go_:o=okj_bonn[l_o_Zo;okfac@02okna
c0?o_[?>0ono]=001Oo1]Loo_kOAokngdOno]m7o`KOA00?o`;SC00Go_[[Eol2jeOo0^]Go`;[Eokjk
e`03oknle`03okfmfOno_MWo_kgI00?o_KkK0onl_m`01Onl`=co^/3Nok[0g_nj`=ko^<3P00?o^L7P
00?o]l3Qo`000?ng`N400one`N84okC1i003ok;0i?nb`NCo//7T00?o/L3U1?n``>H00ol0003ooooo
ooooo`0/ooooo`002Oooool01000003oooooooooooooool407moO`030000002IVIT0VIVI00@0VIVI
00<000000;>c/`2c/k<0102c/k<00`000000c<c<0<c<c0040<c<c0030000003Vi^H0i^KV00L0i^KV
00?o00000?ooo`3oool0703oool00ol00000i^KV0>KViP070>KViP030000003<c<`0c<c<00@0c<c<
00<000000;>c/`2c/k<0102c/k<00`000000VIVI09VIV@0409VIV@030000001oOgl0Ogmo00@0Ogmo
00<0000006IVIP1VIVH0101VIVH00`000000C4a<04a<C00604a<C0030000000c<c<0<c<c00P0<c<c
00<0000001TI6@0I6AT03P0I6ATI000000Cooooo00<00000ooooooooool0=_ooool3o`0001[ooooo
00?o^jS6ok^Zb?nkZ/P00_nkZ/P00onk[<[o_:c8okb/b002okb]b`05okj]bOnn[l_o_Zo;okj_bono
[lX01?no/L`01?nn/lko`;?>ol2cc_no]=03ol6ec`04okngdOo1]m7o`KOAol6gd@;o`;SC00Go`KWB
ol2jeOo0^]Go`;[Eol6ke003oknle`Co_kgI00Co_KkKokjof_nn_m[o_;oL0onl`=`00onj`=ko^l7N
ok_1gP03okW1h005okO1hOl0003o]l7QokO1hOne`N800_nf`N<3okC1i0?o//7T00Co//7Uok70iOna
`>Go/L3U0on``>H00ooooooo0000ooooo`0/ooooo`002Oooool01000003oooooooooooooool407mo
O`030000002IVIT0VIVI00@0VIVI00<000000;>c/`2c/k<0102c/k<00`000000c<c<0<c<c0040<c<
c0030000003Vi^H0i^KV00L0i^KV00?o00000?ooo`3oool07@3oool00ol00000i^KV0>KViP060>KV
iP030000003<c<`0c<c<00D0c<c<00<000000;>c/`2c/k<0102c/k<00`000000VIVI09VIV@0409VI
V@030000001oOgl0Ogmo00<0Ogmo00<0000006IVIP1VIVH01@1VIVH00`000000C4a<04a<C00504a<
C0030000000c<c<0<c<c00P0<c<c00<0000001TI6@0I6AT03P0I6ATI000000Cooooo00<00000oooo
ooooool0<oooool3o`0001cooooo0onkZ<H2ok^Zb005okbYaonl[<So_:c8okb/b?nl[L/00onn[LT0
1?nn[l_o_jo:okn_b_no[lX2oknac005ol6bboo0/lko`;?>ol2cc_o2]<d00oo1]Ll01Oo2]/ko`KOA
ol6gdOo1]m7o`;SC00?o`KWB00Go`;[Eol6ke?o1^mCo`K_Doknle`02ol6meP;o_kgI0_o0_]T00onn
_m[o_l3Koko0f`03okc0g0Co^l7N0oni`N001Ol0003o]l7QokS2h_nh`^;o]/7S00;o]/;S0ond`N@0
1_nb`NCo//7Uok;1iOnb`NGo/L3Uok71i@Co/<3V00?o0000ooooooooool0:oooool000Wooooo00@0
0000oooooooooooooooo101oOgl00`000000VIVI09VIV@0409VIV@030000002c/k<0/k>c00@0/k>c
00<000000<c<c03<c<`0103<c<`00`000000i^KV0>KViP070>KViP03o`00003oool0oooo01d0oooo
00?o00000>KViP3Vi^H01`3Vi^H00`000000c<c<0<c<c0040<c<c0030000002c/k<0/k>c00@0/k>c
00<0000009VIV@2IVIT0102IVIT00`000000Ogmo07moO`0307moO`030000001VIVH0IVIV00D0IVIV
00<0000004a<C01<C4`01@1<C4`00`000000<c<c03<c<`0803<c<`030000000I6AT06ATI00h06ATI
6@000004ooooo`0300000?oooooooooo037ooooo0_l0000Nooooo`Co^jS600Co^j[8okbYaonlZLOo
_:W70_nl[<P01?nn[<Oo_Zg9okj]bOnn[LT4okn_bP05oknac?o1//_o`K;;ol6bboo0/lh00oo2]<d0
1_o1]Loo`[K>ol:fc_o2]/ko`KOAol>hd0?o`KWB00Go`k[Bol6ke?o1^mCo`K_Dol>le003ol6meP?o
`;kI00?o`KoIoko0fono`=/00_no`=/00onl`=co_L7Lokg1g002ok_1gP;o_<;N00Co^L7Pok[2h?nh
`^;o00000_nh`^84okK2h`?o]<7T0onb`ND3ok71i@Co/<3V00?o0000ooooooooool0:_ooool000Wo
oooo00@00000oooooooooooooooo101oOgl00`000000VIVI09VIV@0409VIV@030000002c/k<0/k>c
00@0/k>c00<000000<c<c03<c<`0103<c<`00`000000i^KV0>KViP070>KViP03o`00003oool0oooo
01d0oooo00?o00000>KViP3Vi^H01`3Vi^H00`000000c<c<0<c<c0040<c<c0030000002c/k<0/k>c
00@0/k>c00<0000009VIV@2IVIT0102IVIT00`000000Ogmo07moO`0307moO`030000001VIVH0IVIV
00D0IVIV00<0000004a<C01<C4`01@1<C4`00`000000<c<c03<c<`0803<c<`030000000I6AT06ATI
00h06ATI6@000004ooooo`0300000?oooooooooo02kooooo0ol0000Oooooo`;o^ZK50onkZ<H4okbY
a`05okb/b?nn[<Oo_Zc7okj/aonn[LT00_o0[/P3okn_bP04ol6`bOo1//_o`K;;ol6bb`?o`[C=00Go
`kG<ol:fc_o2]/ko`[K>olBgcP03ol>hd005ol6id_o3^];o`k[Bol>jd_o1^m@00oo3_=@01?o1_MKo
`[kFol:ne_o0_]T3ol6of@;o_l3K0_o0`M/00onm`Mco_/;Mokc2gP02okc2gP05okc2gonj`^3o^/;P
ok[2h?l000000onh`^84okK2h`03okC1i?nd`^Co//7U00?o//7U00?o/L7Uok71i_na`NH00on``>H0
0ooooooo0000ooooo`0Zooooo`002Oooool01000003oooooooooooooool407moO`030000002IVIT0
VIVI00@0VIVI00<000000;>c/`2c/k<0102c/k<00`000000c<c<0<c<c0040<c<c0030000003Vi^H0
i^KV00L0i^KV00?o00000?ooo`3oool07@3oool00ol00000i^KV0>KViP070>KViP030000003<c<`0
c<c<00@0c<c<00<000000;>c/`2c/k<0102c/k<00`000000VIVI09VIV@0409VIV@030000001oOgl0
Ogmo00<0Ogmo00<0000006IVIP1VIVH01@1VIVH00`000000C4a<04a<C00504a<C0030000000c<c<0
<c<c00P0<c<c00<0000001TI6@0I6AT03P0I6ATI000000Cooooo00<00000ooooooooool0;?ooool2
o`00023ooooo00?o^JC3okZVaOnjY/D00_njY/D00onkZ<Ko_:S5okbXa@03okbYa`?o_Zc700?o`:c6
ol2^b?o0[/P00_o0[/P01Ono[l[o`K39ol6`bOo1/<Wo`K;;00;o`[;;00Go`[C=ol>ec?o3]Lco`kG<
ol:fcP03olBgcP;o`kS@00Coa;W@ol>jd_o3^];o`k[B0oo3_=@01Oo4_MCo`[kFol:ne_o2_]Ko`koF
00?o`KoI0oo0`M/01Oo1`]_o_/;Mokk2gOnn`]go_<;N00?o_<;O00Ko^/;Pok[3hOl0003o^/?QokS2
h_nh`n83okK2h`04okK3hond`^Co]<;TokC2i0;o//7U0_nb`^D2ok71iPCo/<3V00?o0000oooooooo
ool0:Oooool000Wooooo00@00000oooooooooooooooo1@1oOgl00`000000VIVI09VIV@0409VIV@03
0000002c/k<0/k>c00<0/k>c00<000000<c<c03<c<`01@3<c<`00`000000i^KV0>KViP060>KViP03
o`00003oool0oooo01h0oooo00?o00000>KViP3Vi^H01P3Vi^H00`000000c<c<0<c<c0040<c<c003
0000002c/k<0/k>c00@0/k>c00<0000009VIV@2IVIT0102IVIT00`000000Ogmo07moO`0407moO`03
0000001VIVH0IVIV00@0IVIV00<0000004a<C01<C4`01P1<C4`00`000000<c<c03<c<`0803<c<`03
0000000I6AT06ATI00h06ATI60000004ooooo`0300000?oooooooooo02Wooooo0ol0000Qooooo`?o
^JC30_njY/D00onkY/?o_:S5okbXa@02okbXa@04okbYaonnZ/Go_Z[5okj/a`?o`:c60_o0[/P01Oo1
[/Oo`K39ol6`bOo1/<Wo`k7800?o`[;;1?o3]L`4olBgcP05ol>hd?o4^M3oa;W@olBid?o3^]800_o4
_=801Oo3_=Coa;gDolBme?o4_MCo`[kF00?o`koF00Co`KoIol;1fOo2`MWo`<7K0oo1`]/01_nn`]go
_l?Moko3gOno`mgo_<;Ookg3g`;o^/?Q00?o0000ok_4hOnh`n800_nh`n801?nf`^?o]/?SokK3honf
`n<3okC2i0?o//;U0ona`NH2ok30iP;o/<7V00?o0000ooooooooool0:?ooool000Wooooo00@00000
oooooooooooooooo1@1oOgl00`000000VIVI09VIV@0409VIV@030000002c/k<0/k>c00<0/k>c00<0
00000<c<c03<c<`01@3<c<`00`000000i^KV0>KViP060>KViP03o`00003oool0oooo01h0oooo00?o
00000>KViP3Vi^H01P3Vi^H00`000000c<c<0<c<c0040<c<c0030000002c/k<0/k>c00@0/k>c00<0
000009VIV@2IVIT0102IVIT00`000000Ogmo07moO`0407moO`030000001VIVH0IVIV00@0IVIV00<0
000004a<C01<C4`01P1<C4`00`000000<c<c03<c<`0803<c<`030000000I6AT06ATI00h06ATI6000
0004ooooo`0300000?oooooooooo02Oooooo0_l0000Sooooo`Co^JC300Co^ZK5ok^V`onkY/?o^jK3
0_nlZ<D01?nmZ<Co_Z[5okjZaOnnZ/D4ol2/aP05ol2^b?o1[/Oo`Jk7ol6^aoo1/<T00oo3/LP00oo2
//_oa;?:olBcbP03ol>ec004olFfc?o4]lkoa;O>olJhc@?oa;W@00Goa[_@olBld_o4_=;oa;cBolJm
dP03olBme0?o`koF00Goa<7Gol;1fOo2`MWo`/7Iol?2f@03ol72f`?o_l?M00Ko_lCMokg3gonm`moo
_L?Ook[3hOl00002ok_4h@03okS3h_ni`n;o^L?R00;o]/?S00Co]/?TokC2i?nd`^Co]<;T1?nb`^D3
ok71iP;o/<7V00?o[l7Wooooool00000:Oooool000Wooooo00@00000oooooooooooooooo1@1oOgl0
0`000000VIVI09VIV@0409VIV@030000002c/k<0/k>c00<0/k>c00<000000<c<c03<c<`01@3<c<`0
0`000000i^KV0>KViP060>KViP03o`00003oool0oooo01h0oooo00?o00000>KViP3Vi^H01P3Vi^H0
0`000000c<c<0<c<c0040<c<c0030000002c/k<0/k>c00@0/k>c00<0000009VIV@2IVIT0102IVIT0
0`000000Ogmo07moO`0407moO`030000001VIVH0IVIV00@0IVIV00<0000004a<C01<C4`01P1<C4`0
0`000000<c<c03<c<`0803<c<`03o`00000I6AT06ATI00h06ATI60000004ooooo`0300000?oooooo
oooo02Cooooo0ol0000Tooooo`;o^:;20oniY<<4ok^V``05okbXaOnmZ<Co_JS4okfXa?nnZ/D00_no
Z/@3ol2/aP04ol6]aOo1[/Oo`Jk7ol6^a`Co`k781?o4/lX01?o3]LcoaKK<olFfc?o4]lh3olJhc@05
olBid?o6^m3oa[_@olJkd?o4_=800oo6_M801?o4_MCoaKoDolFoe?o3_mH3olC1e`05ol;1fOo3`]Wo
`l;Iol?2fOo1`]/00_o1`m/01Ono`mgo_lCMoko4gOnoa=go_L?O00;o_LCO00Ko0000ok_4hOnka>7o
^lCQokW3h_nia><4okK3i003okC2i?nd`nGo]<?U00;o//;U0_nb`^H2ok71iPCo[l7W00?o0000oooo
ooooool09oooool000Wooooo00@00000oooooooooooooooo1P1oOgl00`000000VIVI09VIV@0309VI
V@030000002c/k<0/k>c00@0/k>c00<000000<c<c03<c<`01@3<c<`00`000000i^KV0>KViP060>KV
iP03o`00003oool0oooo01`0oooo00?o00000>KViP3Vi^H01`3Vi^H00`000000c<c<0<c<c0040<c<
c0030000002c/k<0/k>c00@0/k>c00<0000009VIV@2IVIT0102IVIT00`000000Ogmo07moO`0407mo
O`030000001VIVH0IVIV00@0IVIV00<0000004a<C01<C4`01P1<C4`00`000000<c<c03<c<`0803<c
<`030000000I6AT06ATI00h06ATI60000004ooooo`0300000?oooooooooo02;ooooo0_l0000Uoooo
o`03okNP`OnhX/;o^:;200;o^:;200?o^JC3ok^T`_nkY<800onkY/<4okfXa0Co_j[400Go`:c6ol6]
aOo1[LGo`Jg5ol6^a`02ol>_aP;o`k780_o5//P2olBcbP05olJdbOo5]/coaKK<olFfc?o7]l/00oo6
^<d01?o7^/goa[_@olJkd?o6^m03olJmdP05olNnd_o5_mCoaKoDolFoe?o6`M@00oo4`ML00oo5`]Oo
`l;Iol?2f@02olC4fP03ol73foo2a=co`/CL00;o_lCM00Go`<GNokg4gonma=oo_LCOo`000002ok_4
h@04ok_5h_nia>?o^LCSokW4h`;o]/?T0_nfa>@3okC3i@?o//;V0ona`NH4ojo1i`03o`000?oooooo
oooo02Kooooo0009ooooo`0400000?ooooooooooooooo`H0Ogmo00<0000009VIV@2IVIT00`2IVIT0
0`000000/k>c0;>c/`040;>c/`030000003<c<`0c<c<00D0c<c<00<000000>KViP3Vi^H01`3Vi^H0
0ol00000oooo0?ooo`0K0?ooo`03o`00003Vi^H0i^KV00L0i^KV00<000000<c<c03<c<`0103<c<`0
0`000000/k>c0;>c/`040;>c/`030000002IVIT0VIVI00@0VIVI00<0000007moO`1oOgl0101oOgl0
0`000000IVIV06IVIP0406IVIP030000001<C4`0C4a<00H0C4a<00<0000003<c<`0c<c<0200c<c<0
0`0000006ATI01TI6@0>01TI6AP000001?ooool00`00003oooooooooo`0Oooooo`?o00009_ooool3
okNP`@;o^:;200?o^Z;1ok^T`_nkY<800_nkY<800onkY/?o_JK2okfV`P02okfXa0;o_jS30_noZ/@0
0oo1Zl?o`Jg5ol6]a@02ol6]a@?o`jo600Go`k78olFbb?o5//SoaK;8olBcbP03olJdb@05olFfc?o7
]l_oakO;olNgboo6^<d00oo7^/d01?o6^m3oakc@olNld?o6_M83olNndP05olFoe?o6`MCoa/7DolK1
e?o4`ML00_o5`]L3olC4fP05olG5f_o2a=co`/CLol;4g?o3a]`00oo0aMh01?nma=oo_LGPo`000?nk
a>43ok_5hP06okW4honiaN?o^LGSokW5honfa>Co]/CU0ond`nD4ok;2iP03ok71i_na`^Oo/L;W00?o
[l7W00?oooooo`000?ooool09_ooool000Wooooo00@00000oooooooooooooooo1P1oOgl00`000000
VIVI09VIV@0309VIV@030000002c/k<0/k>c00@0/k>c00<000000<c<c03<c<`01@3<c<`00ol00000
i^KV0>KViP070>KViP03o`00003oool0oooo01/0oooo00?o00000>KViP3Vi^H01`3Vi^H00`000000
c<c<0<c<c0040<c<c0030000002c/k<0/k>c00@0/k>c00<0000009VIV@2IVIT0102IVIT00`000000
Ogmo07moO`0407moO`030000001VIVH0IVIV00@0IVIV00<0000004a<C01<C4`01P1<C4`00`000000
<c<c03<c<`0803<c<`030000000I6AT06ATI00h06ATI60000004ooooo`0300000?oooooooooo01co
oooo0ol0000Wooooo`03okJN`?ngX<7o]j3100;o]j3100Co^:;2okZR`OnjX/7o^Z;10_nkY<801Onl
Y<7o_JK2okfV`_nmY/;o_JS400?o_jS300Co_j[4ol6[`oo1Zl?o`J_30_o1[LD2ol>]a0;o`jo600Go
aK36olFbb?o5//SoaK;8olJca`03olJdb@?oakO;00Gob;W;olNjcOo7^/goak[=olVkc@03olNld0?o
akkB0_o8`=82olK1e0;ob<;E00CoaL;GolK4f?o6a=Soa<CJ0oo5aMX01Oo2a=co`lKLol?6g?o3a]co
`<GN00;o`<KO00Go_LGPo`000?nna^7o_/KQok_5hP02ok_6hP;o^LGS00Co^<GTokK4iOnfa>Go]/CU
0ond`nD2ok;2iP;o//?V00?o/L;Wok32ion_`NL00on_`NL00ol0003oooooooooo`0Uooooo`002Ooo
ool01000003oooooooooooooool707moO`030000002IVIT0VIVI00<0VIVI00<000000;>c/`2c/k<0
102c/k<00`000000c<c<0<c<c0040<c<c0030000003Vi^H0i^KV00P0i^KV00?o00000?ooo`3oool0
6P3oool00ol00000i^KV0>KViP070>KViP030000003<c<`0c<c<00@0c<c<00<000000;>c/`2c/k<0
102c/k<00`000000VIVI09VIV@0409VIV@030000001oOgl0Ogmo00@0Ogmo00<0000006IVIP1VIVH0
101VIVH00`000000C4a<04a<C00604a<C0030000000c<c<0<c<c00P0<c<c00<0000001TI6@0I6AT0
3P0I6ATH000000Cooooo00<00000ooooooooool06_ooool2o`0002Sooooo00Co]9bookJN`?nfW/3o
]Yk00ongX<44okZR`@04ok^T`_nlY<7o_:C1okbT`@;o_JK200Co_ZK1oknX`onoZ<?o_jS31?o1Zl<0
1Oo1[LGo`jg4ol>]a?o3[LCo`jo600?oaK3600GoaK;8olJcaoo6/lOoa[?7olJdb@02olNfb@05olNg
boo8^L_ob;W;olRiboo7^/d00oo9^ld01?o7_=3obKk@olVnd?o7_]83olS0dP?ob<;E00GobLCFolK4
f?o6a=Soa/CHolO5f003olG5fP?o`lKL00So`lOMol36goo0a]oo`<KOokk6hOl0003o_/KQokk7h@?o
^lKR1?nhaN@3okK4i@03okC3iOnda>Ko]<CV00?o//?V0on``^L3ojo1i`03ooooool0003ooooo02Go
oooo0009ooooo`0500000?ooooooooooooooool000001P1oOgl00`000000VIVI09VIV@0309VIV@03
0000002c/k<0/k>c00@0/k>c00<000000<c<c03<c<`01@3<c<`00`000000i^KV0>KViP070>KViP03
o`00003oool0oooo01T0oooo00?o00000>KViP3Vi^H01`3Vi^H00`000000c<c<0<c<c0050<c<c003
0000002c/k<0/k>c00@0/k>c00<0000009VIV@2IVIT0102IVIT00`000000Ogmo07moO`0407moO`03
0000001VIVH0IVIV00@0IVIV00<0000004a<C01<C4`01P1<C4`00`000000<c<c03<c<`0803<c<`03
0000000I6AT06ATI00h06ATI60000004ooooo`0300000?oooooooooo01Oooooo0ol0000Yooooo`;o
]9bo1?nfW/000ongX<7o^:30okRP`003okZR`@Co_:C100Go_JK2okjV`OnnY/7o_ZK1oknX``02ol6Y
`P?o`J_300Co`jc3ol>]a?o3[LCo`jg40oo5/<H01Oo7//Goa[?7olJcaoo6/lOob;C700?oakK900Co
bKS9olRiboo8^L_ob;W;0oo9^ld01?o;_LkobKk@olVnd?o9_]02ol_0d004olS0d_o:`]?ob/;ColS2
e@?obLCF00Goa/CHolO5f?o7aMSoalGHolG5fP02olG6f`06ol?6g?o3amgo`lOMol?7gOo0a]oo`<OO
0_l00003okk7h@03ok_6h_nka^?o^lKS00;o^<GT0_nha^@00onfa>Go]/GUokC4iP03okC4iP?o//?V
0on``^L3ojo1i`03ooooool0003ooooo02Cooooo0009ooooo`0500000?ooooooooooooooo`000000
1P1oOgl00ol00000VIVI09VIV@0409VIV@030000002c/k<0/k>c00@0/k>c00?o00000<c<c03<c<`0
1@3<c<`00`000000i^KV0>KViP070>KViP03o`00003oool0oooo01P0oooo00?o00000>KViP3Vi^H0
1`3Vi^H00`000000c<c<0<c<c0050<c<c0030000002c/k<0/k>c00@0/k>c00<0000009VIV@2IVIT0
102IVIT00`000000Ogmo07moO`0407moO`030000001VIVH0IVIV00@0IVIV00<0000004a<C01<C4`0
1P1<C4`00`000000<c<c03<c<`0803<c<`030000000I6AT06ATI00h06ATI60000004ooooo`030000
0?oooooooooo01Kooooo0_l0000Zooooo`Co]9bo0_nfW/000ongW[oo^:30okRP`002okRP`003okZR
`OnkX/3o^j;000;o_:C100?o_ZG0okjV`OnnY/400_nnY/44ol6Y`P05ol6[`oo3[<?o`jc3ol>/`oo3
[L@00_o5[l@01Oo5/<Koak;5olNbaOo7//Goa[?700?ob;C700GoakK9olVhbOo9^<WobKS9olRib`02
olZjb`05olVkcOo;_Lkobkg>ol^mc_o9_]000oo;`=03ol[2d`04ol_4doo9a=KobLCFolW4eP?oalGH
0_o8amT00oo5a]_oa/SLolK8g002ol?7g@?o000000Co`<SPo`000?nnan7o_/OQ0_nmb>800onka^?o
^lOTok_7i002okS6i004okS6iOnfaNGo]/GUokK5i@;o]<CV0_nca>H00onb`nKo/L?Wok73i`02ok32
i`Co[l7W00?o0000ooooooooool08oooool000Wooooo00D00000oooooooooooooooo0000000607mo
O`030000002IVIT0VIVI00@0VIVI00<000000;>c/`2c/k<0102c/k<00`000000c<c<0<c<c0050<c<
c0030000003Vi^H0i^KV00P0i^KV00?o00000?ooo`3oool05P3oool00ol00000i^KV0>KViP080>KV
iP030000003<c<`0c<c<00D0c<c<00<000000;>c/`2c/k<0102c/k<00`000000VIVI09VIV@0409VI
V@030000001oOgl0Ogmo00@0Ogmo00<0000006IVIP1VIVH0101VIVH00`000000C4a<04a<C00604a<
C0030000000c<c<0<c<c00P0<c<c00<0000001TI6@0I6AT03P0I6ATH000000Cooooo00<00000oooo
ooooool05_ooool00ol0003oooooo`00000Xooooo`;o/Y^o0ondW;l01?nfW/3o]ijookNN_ongW[l2
okRP`005okZQ_onkX/3o^j;0ok^R`?nlY<400onnYL02okjV`@;o`:O10_o1ZL800oo3Z/7o`jc3ol>/
``02ol>/``?oaJo41?o7//D4olRda`CobKS90oo:^//01?o<_<cobkg>ol^mc_o;_Lh3ol_0d0;oc<;A
00Gob/;Col_4doo;a=?oblCColW4eP02ol[6eP04olO5f?o8amWob<OIolS9fP;oa/SL0ol000000oo3
b=ko`lWOol38h002ol38h004o`000?nmb>;o_LSRokg8h`?o^lOT1?nha^D00onfaNGo]LGVokG5iP02
ok?4iP;o/lCW0_na`nL3ok32i`;o[l7W0_n^`NL00ol0003oooooooooo`0Rooooo`002Oooool01P00
003oooooooooooooool0IVIV000000H0Ogmo00<0000009VIV@2IVIT0102IVIT00`000000/k>c0;>c
/`040;>c/`030000003<c<`0c<c<00D0c<c<00<000000>KViP3Vi^H0203Vi^H2o`0001D0oooo00?o
00000>KViP3Vi^H0203Vi^H00`000000c<c<0<c<c0050<c<c0030000002c/k<0/k>c00D0/k>c00<0
000009VIV@2IVIT0102IVIT00`000000Ogmo07moO`0407moO`030000001VIVH0IVIV00@0IVIV00<0
000004a<C01<C4`01P1<C4`00`000000<c<c03<c<`0803<c<`030000000I6AT06ATI00h06ATI6000
0004ooooo`0300000?oooooooooo01Kooooo00Co0000oooooooooooo00009_ooool3ok:K_`?o]9bo
1?ngW[l01?nhX<3o^Z6ookZQ_onjXKl2ok^R`0Co_ZG000Go_ZK1ol2W`Oo0Yl7o`:O1ol6Y`P03ol>Z
`@;o`jc30_o5[L82olF_a005olN`a?o7//Goak;5olNbaOo8/lD00_o8]<L2olZfa`;obKS90_o;^/T0
1Oo:^/_oc;c<olblc?o<_<cobkg>00;oc;o>00Cobl3@olc2dOo<`]7oc<;A0oo;a=<2olc6e005ol[6
e_o;b=OoblSGolS7fOo8bMX00ol00002olK9g@05ol?8g_o3bMoo`lWOol?9goo0b>000_o0bN401Ol0
003o_LSSokg8honmb>?o^lOT00;o^/OT0_nha^D2okO6i@?o]LGV0onca>L3ok73i`03ok32ion_`^Oo
[l;W00;o[/7W00?o[/7Xo`000?ooool08oooool000Wooooo00H00000oooooooooooooooo06IVIP00
000607moO`030000002IVIT0VIVI00@0VIVI00<000000;>c/`2c/k<0102c/k<00`000000c<c<0<c<
c0060<c<c0030000003Vi^H0i^KV00T0i^KV0_l0000B0?ooo`03o`00003Vi^H0i^KV00T0i^KV00<0
00000<c<c03<c<`01@3<c<`00ol00000/k>c0;>c/`050;>c/`030000002IVIT0VIVI00@0VIVI00<0
000007moO`1oOgl0101oOgl00`000000IVIV06IVIP0406IVIP030000001<C4`0C4a<00H0C4a<00<0
000003<c<`0c<c<0200c<c<00`0000006ATI01TI6@0>01TI6AP000001?ooool00`00003ooooooooo
o`0Fooooo`05o`000?ooooooooooooooool000009?ooool00on`VKoo/Y^ook:K_`02ok:K_`03okBL
_oneW;ko]Ibn00?o]ijo1?njXKl00onkX/3o_:>ookbS_`03okjU`0Co`:O11?o3Z/401Oo3[<?oaJg2
olF]`_o5[L;oaJo400?oak3400Coak;5olRcaOo8/lGob;C70oo:]/L01?o9^<Wobk[9ol^jbOo;^/T3
olblc004oljoc?o<_lkoc;o>olbocP;oc/;?00Coc<;Aolg4dOo=a=7oblCC0oo<a]@2ol_8e`?o0000
0_o8bMX00oo9bm_oa/WMolK;gP02olK;gP04ol?9goo3bn3o`l_Pol39h@;o`<[R00Go0000okg8honm
bNCo_LWTok[7i002ok[8i@;o]lKU00Co]lKVokG5i_neaNKo]LGV1?nca>L3ok73i`03ojo2ion_`^So
[/7X00?o[/7X00?o0000ooooooooool08Oooool000Wooooo00H00000oooooooooooooooo06IVIP00
000607moO`030000002IVIT0VIVI00@0VIVI00<000000;>c/`2c/k<0102c/k<00`000000c<c<0<c<
c0060<c<c0030000003Vi^H0i^KV00/0i^KV0_l0000>0?ooo`;o0000303Vi^H00`000000c<c<0<c<
c0050<c<c0030000002c/k<0/k>c00D0/k>c00<0000009VIV@2IVIT0102IVIT00`000000Ogmo07mo
O`0407moO`030000001VIVH0IVIV00@0IVIV00<0000004a<C01<C4`01P1<C4`00`000000<c<c03<c
<`0803<c<`030000000I6AT06ATI00h06ATI60000004ooooo`0300000?oooooooooo01Gooooo00?o
0000ooooooooool00oooool00ol0003oooooooooo`0Oooooo`04ojjG_on`VKoo/9Vook2I_`;o/Y^o
00?o/i^nokFL__neW;h00_neW;h00ongW[oo^9jnokRN_P03okZQ_`Co_:>o00?o_ZG0oknU_onoYKl0
0oo0Yl401?o2Z<3o`j[1ol>Z`Oo3Z/43olF]`P05olN_`_o7/<Coak34olN`a?o9//@00oo8/lD01Oo;
]LGob[K7olZfaoo:]/Ooc;W700?obk[900?ocKc9olblc?o>_l`00_o>_l`01?o<_lkoc/;?olk2coo>
`/l3olg4d@?oc<KD0ol00003ol_:f003olS9f_o9bm_obL_K00?oa/_N00Goa/cOol?;h?o3bn3o`l_P
ol?<h@02ol3:hP04o`000?nobn?o_LWTokc9i0?o^/SU1?nga^H00oneaNKo]<GWokC5i`02ok?4i`;o
//CW00?o/L?Wok33j?n_`^P00_n_`^P4ojk1j003o`000?oooooooooo023ooooo0009ooooo`060000
0?ooooooooooooooo`1VIVH000001`1oOgl00`000000VIVI09VIV@0409VIV@030000002c/k<0/k>c
00@0/k>c00<000000<c<c03<c<`01P3<c<`00`000000i^KV0>KViP0<0>KViP03o`00003oool0oooo
00X0oooo00?o00000>KViP3Vi^H02`3Vi^H00`000000c<c<0<c<c0060<c<c0030000002c/k<0/k>c
00@0/k>c00<0000009VIV@2IVIT0102IVIT00`000000Ogmo07moO`0507moO`030000001VIVH0IVIV
00@0IVIV00<0000004a<C01<C4`01P1<C4`00`000000<c<c03<c<`0803<c<`030000000I6AT06ATI
00h06ATI60000004ooooo`0300000?oooooooooo01Gooooo00?o0000ooooooooool01?ooool00ol0
003oooooooooo`0Looooo`Co[YNo0_n`VKl01?nbVkoo/i^nok>K__ncVkh2okFL_P03okNM__nhW[ko
^9jn00;o^9jn00?o^Z6ook^Q__nkXKh00_nlXkl00onnY;ko_jFooknU_`02oknU_`05ol2W`Oo2Z<3o
`ZS0ol:X`?o3Z/400_o4[<401Oo5[L;oajo2olN_`_o7[l;oak3400?obK;400Gob;?5ol^eaOo;]LGo
bkG5olZfa`03olbia`04ol^jbOo=_<WocKc9olnnbP?oc[o<0oo>`/l2olo4c`03olg4dOo>a];o0000
00;o00000_o=b=D3ol_:f0;oc<cI00CobL_KolW<g?o9c=coa/_N0oo6c=l00oo3bn3o`lcQol?<h@03
oko;h`05o`000?nlbNCo_<WTokc9i?njb>D00_nib>H2okO6iP;o]/KV0ondaNL2ok;4i`04ok74ion`
`nSo/<?Xok33j0?o[l;X0_n^`NP00on]`NSo0000ooooo`0Qooooo`002Oooool01000003ooooooooo
ooooool206IVIP030000001oOgl0Ogmo00@0Ogmo00<0000009VIV@2IVIT0102IVIT00`000000/k>c
0;>c/`050;>c/`030000003<c<`0c<c<00H0c<c<00<000000>KViP3Vi^H0303Vi^H<o`0000h0i^KV
00<000000<c<c03<c<`01@3<c<`00`000000/k>c0;>c/`050;>c/`03o`00002IVIT0VIVI00@0VIVI
00?o000007moO`1oOgl0101oOgl00`000000IVIV06IVIP0506IVIP030000001<C4`0C4a<00D0C4a<
00<0000003<c<`0c<c<02@0c<c<00`0000006ATI01TI6@0>01TI6AP000001?ooool00`00003ooooo
ooooo`0Eooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool06_ooool2ojbE_`?o[YNo
00?o/9Vook6I__ncVkh00oncVkh01?neW;ko]ifnokNM__ngWKh2okRN_P05okZO__nkXKko^j6nok^Q
__nlXkl00onnY;h2oknU_`03ol6W_oo2Z<3o`ZS000;o`ZS00oo4[<44olN_`PCobK;41?o;]LD3olbi
a`04oljkb?o=_<WocKc9olflb@;ockk:00Coc[o<olo1cOo?`Lgoc/;?0_o?a<l3o`000004olk6d_o@
bM?od<WColg8e@;oc/_F00?obl[Holc<fOo<c=T00_o<c]/00oo9c=cobLkMolW>g@02olK<g`;oa/gP
00Co`lcQol?=h_o3cN;o_l_S0_nobn@01Ol0003o_<WTokc:iOnlb^Go^LSV00?o^<SV00Go]/KVokK6
ionfa^Oo]<GWok?5i`04ok74i`05ok33j?n``^So/<;Xojo2j?n^`NP01?n]`NP00ol0003ooooooooo
o`0Oooooo`002Oooool01000003oooooooooooooool206IVIP03o`00001oOgl0Ogmo00D0Ogmo00<0
000009VIV@2IVIT0102IVIT00`000000/k>c0;>c/`050;>c/`03o`00003<c<`0c<c<00H0c<c<0P00
000U0>KViP030000003<c<`0c<c<00H0c<c<00<000000;>c/`2c/k<01@2c/k<00`000000VIVI09VI
V@0409VIV@030000001oOgl0Ogmo00@0Ogmo00<0000006IVIP1VIVH01@1VIVH00`000000C4a<04a<
C00504a<C0030000000c<c<0<c<c00P0<c<c00<0000001TI6@0I6AT03`0I6ATH000000Cooooo00<0
0000ooooooooool05Oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo01Oooooo00Co
ZI>oojbE_on/UKoo[9Fo0on^Ukl3ok6I_P?o/i^n1?ngWKh00onhW[ko^YnnokZO_P03ok^Q_PCo_ZBn
00Co_jFool6W_oo1Ykoo`JNo0_o2Z<02olBZ`0;oa:c100GoaZg1olN_`_o7[l;oajo2olV``P03olVb
a003ol^da?o;]LGobkG500;ocKS600Goc;W7oljkb?o>^lSoc[_8olflb@03olnnbP?ocl7=0ol00002
om77d004olk6d_o@bM?od<WCom3;e@?oc/_F00?oclgHolc<fOo<c]/00_o<c]/3olW>g@;obLoO00Co
a/gPolG>hOo5c^7o`lgR0_o2cN<2oko;i003okk<iOl0003o_<[U00;o^l[V0_nhb>H2okS8i`03okK6
ionea^Oo/lGW00;o/lGW0_naa>L2ok74j003ok32j?n_`^So[/7X00;o[/7X0_n]`NP2ojg0j003o`00
0?oooooooooo01kooooo0009ooooo`0400000?ooooooooooooooo`<0IVIV00<0000007moO`1oOgl0
101oOgl00`000000VIVI09VIV@0409VIV@030000002c/k<0/k>c00D0/k>c00<000000<c<c03<c<`0
203<c<`00`000000i^KV0>KViP0Q0>KViP030000003<c<`0c<c<00L0c<c<00<000000;>c/`2c/k<0
1@2c/k<00`000000VIVI09VIV@0409VIV@030000001oOgl0Ogmo00@0Ogmo00?o000006IVIP1VIVH0
1@1VIVH00`000000C4a<04a<C00504a<C0030000000c<c<0<c<c00P0<c<c00<0000001TI6@0I6AT0
3`0I6ATH000000Cooooo00<00000ooooooooool05Oooool00ol0003oooooooooo`07ooooo`03o`00
0?oooooooooo01?ooooo00?oYY;0ojVC_onYTkl00_nYTkl3ojbE_`03ojjG_on_Ukko/IVn00?o/IVn
00?o/i^nokBK_OndVkd00ongWKh4okZO_P;o^j6n00Co_J:nokjT__nnY;ko_ZBn1?o1Ykl01Oo2Z<3o
a:[0olBZ`?o4Z/3oa:c100?oaZg100Goajo2olV``_o9/<;obK32olVba002ol^da004ol^eaOo=^<Ko
cKS6olfhaP?oc[_800Cod;g8olnnb_o?_/[ockk:0_oA`L/2o`000003om74c_oBaloodLO@00;odLO@
00?od/WBom39doo@bmD00_o@bmD00oo>bmKoclgHolo=f002olo?f@04olc>foo<cmcoc<oLolW>g@;o
bLoO00Cob=3PolG>hOo5c^7oaLkQ0oo2cN<01oo1c^Co_/cUokk<iOl0003o_LcUok_:i_njb^H00onh
b>L01Ongb>Oo]LKWokG6ionea^Oo/lGW00;o//GX0_naa>P01?n``nSo[l;Xojo2j?n_`^P3ojk1j0?o
[L3X00?o0000ooooooooool07_ooool000Wooooo00@00000oooooooooooooooo0`1VIVH00`000000
Ogmo07moO`0507moO`030000002IVIT0VIVI00@0VIVI00<000000;>c/`2c/k<01@2c/k<00`000000
c<c<0<c<c0080<c<c0030000003Vi^H0i^KV01l0i^KV00<000000<c<c03<c<`01`3<c<`00`000000
/k>c0;>c/`050;>c/`030000002IVIT0VIVI00@0VIVI00<0000007moO`1oOgl01@1oOgl00`000000
IVIV06IVIP0406IVIP030000001<C4`0C4a<00H0C4a<00<0000003<c<`0c<c<0200c<c<00`000000
6ATI01TI6@0>01TI6AT000001?ooool00`00003oooooooooo`0Eooooo`03o`000?oooooooooo00So
oooo00?o0000ooooooooool04?ooool01?nST<7oYY;0ojJB`?nVT/03ojVC_`;o[9Fo00Co[IFnojnG
__n_Ukko[iNn0_naVKh00onbVKgo]9^mokBK_@02okBK_@03okNM__nhWKgo^Ynn00?o^Ynn00Go^j6n
okfR__nmX[ko_J:nokjT_P02ol2U_P?o`JNo00Co`jRoolBZ`?o4Z/3oa:[01?o6[L43olV``P05ol^c
`_o;]<CobkC4ol^da?o=]/@00oo=^<H00oo?^/Koc[_8om2mb002om2mb004olnnb_l0003o0000o`00
00?odLC>0_oBall01?oAam3od/WBom;9d_oCc=<3om3;e@05om7>e_o?cMSocloIolo?fOo?dM/00oo<
cm`00oo<dMgobLoOolS@h002olS@h004olG>hOo5cn;oaLoRol;=h`;o`LkT00Co`<kUokg<iOnmc>Go
00000onjb^H01Onhb>Oo]lSWokO8iongb>Oo]LKW00;o]<KX0_nbaNP4ok33j0?o[l;X00?o[/7Xojg1
j?n]`>P00on]`>P00ol0003oooooooooo`0Mooooo`002Oooool01000003oooooooooooooool406IV
IP030000001oOgl0Ogmo00D0Ogmo00<0000009VIV@2IVIT0102IVIT00`000000/k>c0;>c/`050;>c
/`030000003<c<`0c<c<00P0c<c<0P00000N0>KViP03o`00003<c<`0c<c<00L0c<c<00?o00000;>c
/`2c/k<01@2c/k<00`000000VIVI09VIV@0509VIV@030000001oOgl0Ogmo00@0Ogmo00<0000006IV
IP1VIVH01@1VIVH00`000000C4a<04a<C00604a<C0030000000c<c<0<c<c00P0<c<c00<0000001TI
6@0I6AT03P0I6ATI000000Cooooo00<00000ooooooooool05?ooool00ol0003oooooooooo`0:oooo
o`03o`000?oooooooooo00gooooo00?oWhk2oj>@`OnST<400onVT/03ojVC_`Co[IFn0_n_Ukh01?na
VKko/YVmok:I_OnbVKd2okBK_@04okJL_OnhWKgo^9fmokRM_@;o^Ynn00?o^j2mokfR__nmX[h00_nm
X[h4ol2U_P05ol6W_oo3Z;oo`jRool>X_oo4Z/000_o6[<02olJ]`@;ob:o100GobK32ol^c`_o;/l;o
bk?2ol^da003olffa005olfha_o?^/Kock[6om6maoo@_LP00ol000001OoA`L_od/C<om;4c?oBa<co
dLC>00;od/O?0_oDb]001OoBbM;odlcCom?<dooCc=?od<_E00;odLkF00?od]3Holo?fOo?dM/00_o?
dM/01?o<cmcoc=7MolcAgOo<dml2olS@h0;ob=;Q00CoaLoRolC@hoo4d>?o`LkT0oo0c^D01?nmc>Go
_<cVo`000?njb^H2okW:i`;o]lSW0_nfb>P00onda^So/lKXok?6j002ok;5j0Co/<?X00?o[l;Xojk2
j?n^`^P00_n]`NP2ojg0j0;o[<3X00?o0000ooooooooool07?ooool000Wooooo00@00000oooooooo
oooooooo101VIVH00`000000Ogmo07moO`0507moO`030000002IVIT0VIVI00@0VIVI00<000000;>c
/`2c/k<01P2c/k<00`000000c<c<0<c<c0090<c<c0030000003Vi^H0i^KV01T0i^KV0P00000:0<c<
c0030000002c/k<0/k>c00D0/k>c00<0000009VIV@2IVIT01@2IVIT00`000000Ogmo07moO`0407mo
O`030000001VIVH0IVIV00D0IVIV00?o000004a<C01<C4`01P1<C4`00`000000<c<c03<c<`0803<c
<`030000000I6AT06ATI00h06ATI6@000004ooooo`0300000?oooooooooo01Cooooo00?o0000oooo
ooooool02oooool00ol0003oooooooooo`09ooooo`04oib=`onOS/;oWhk2oin>`P?oXi310onVT/03
ojVC_`?o[IFn00?o[iNnok2G_OnbVKd00onbVKd00ondVkgo]YbmokJL_@03okRM_@04okZO__nkX;go
^j2mok^P_@;o_J:n0_nnXkd2ol2U_P03ol:W__o3Z;oo`jRo00;o`jRo0oo6[<001?o6[L7ob:o1olR_
`Oo8[l44ol^c`P?ocKK400?ockW5olnja_o?^/H00ol000001?o@_LSod/79om;1bOoDa<X3om;4c003
omC7cOoBalooe<[@00;oe<[@0ooCc=<2omC?e003om7>e_oBd=Sod]3H00?ocm7K0_o?dm`00oo<dMgo
c=?OolcCg`03olSBh@;oam;S00?oa=3Sol?AiOo3dND00_o0c^D2oko>iP04okc<i_nkc>Oo0000okW:
i`;o^<[X0_nfb>P2okG8j003ok?6j?nba^So/LCX00;o/LCX0_n``nP2ojo3j0;o[/;X0on]`NP3ojc0
j003o`000?oooooooooo01cooooo0009ooooo`0400000?ooooooooooooooo`D0IVIV00<0000007mo
O`1oOgl01@1oOgl00`000000VIVI09VIV@0409VIV@030000002c/k<0/k>c00H0/k>c00<000000<c<
c03<c<`02@3<c<`2000001P0i^KV00<000000<c<c03<c<`02P3<c<`00`000000/k>c0;>c/`050;>c
/`030000002IVIT0VIVI00@0VIVI00<0000007moO`1oOgl01@1oOgl00`000000IVIV06IVIP0506IV
IP030000001<C4`0C4a<00H0C4a<00<0000003<c<`0c<c<0200c<c<00`0000006ATI01TI6@0>01TI
6AT000001?ooool00`00003oooooooooo`0Dooooo`03o`000?oooooooooo00cooooo00?o0000oooo
ooooool01_ooool01?nHRlCoW8g3oib=`onLSL<3oin>`P;oXi310_nVT/001?nVTKooZI>oojVC_onY
Tkl3ojfE_P?o/9Nm0onbVKd4okJL_@;o^9fm1?nkX;d01OnmX[ko_Z>mokjS_OnnXkgo`:Fn00?o`ZNn
0_o3Z;l2olFZ_`;oaZc000Gob:k0olR_`Oo8[l7ob:o1ol^a`@03ol^c`P03olfe`oo=]/CockW500?o
00000ooA_LL3om;1b@;oe<C:00Cod/C<omC7cOoDalgoe/[>0ooDb]001?oEcM7odlcComC?e?oDcm@2
omCBeP04om;@f?oBdmWod]?IoloAf`?ocm?L00GocmGNolcCgoo;e>7obmCQolSBh@02olOBh`;oa]?T
00?o`m7Uol;Ai_o2dNH00_noc^H2okk>i`04ok_<iol0003o^/cXokS:j0;o]lWX0_neb>P01OndanSo
//KXok;6j?nba^So/LCX00;o/<CX0_n_`nP01?n_`^So[/;Xojk2j?n^`^P3ojg1j0?o[<3X00?o0000
ooooooooool06oooool000Wooooo00@00000oooooooooooooooo1@1VIVH00`000000Ogmo07moO`06
07moO`030000002IVIT0VIVI00@0VIVI00<000000;>c/`2c/k<01P2c/k<00`000000c<c<0<c<c00:
0<c<c0030000003Vi^H0i^KV01@0i^KV00?o00000<c<c03<c<`02P3<c<`00`000000/k>c0;>c/`05
0;>c/`030000002IVIT0VIVI00D0VIVI00<0000007moO`1oOgl0101oOgl00`000000IVIV06IVIP05
06IVIP030000001<C4`0C4a<00H0C4a<00<0000003<c<`0c<c<0200c<c<00`0000006ATI01TI6@0?
01TI6AT000001?ooool00`00003oooooooooo`0Dooooo`04o`000?m`R=_oLHKIog66f@cooooo00Go
0000oooooooooooooooooi28a`02oiB9a@;oV8_40onLSL<3oin>`P03oj>@`OnSSl3oYY6o00?oYY6o
0onYTkl2ojfE_PCo/9Nm00?o/YVmok>J_OncV[d00onfW;d00onhWKgo^IjmokVN_@03ok^P_@Co_Z>m
1?o2Ykh01Oo3Z;ooaJZoolFZ_oo5Z[ooaZc000?ob:k000Kob:o1ol^a`Oo;/L7obk71ol^c`_o=]L<3
o`0000;ockW50ooA_LL2om?0b004om;1bOoDa<[oe<C:omC4bP?oe<O=0_oFb/h01OoDb]3oeLgAomG=
dOoFd=?oe<oD00?oe=;F0ooBdmT2om;Ef`05oloCg?o?eMkocmGNolkFgoo;e>400_o:eN801?o7d^?o
a]?TolKCi?o6dn@3ol;AiP03ol3Aionnc^Oo_/kW00;o_<kX00?o^/cXo`000?ngbNP00_ngbNP4okC7
j005ok;6j?nbaNSo//GXok34j?n``nT01?n_`^P01On^`^So[L7Xojg1j?n]`NSo[<3X00?o[;oX00?o
ooooo`000?ooool06oooool000Wooooo00@00000oooooooooooooooo1P1VIVH00ol00000000007mo
O`0507moO`03o`00002IVIT0VIVI00D0VIVI00<000000;>c/`2c/k<01P2c/k<2000000/0c<c<00@0
0000o`00000000000000403Vi^H2000000/0c<c<0P0000070;>c/`0300000?l00000VIVI00D0VIVI
00<0000007moO`1oOgl01@1oOgl00`000000IVIV06IVIP0506IVIP030000001<C4`0C4a<00H0C4a<
00<0000003<c<`0c<c<0200c<c<00`0000006ATI01TI6@0?01TI6AT000001?ooool00`00003ooooo
ooooo`0Dooooo`04o`000?m`R=_oL8SKog66f@;oM8GF0_mgQ=@2ogZ4d@;oOXC?0_n2QLd2ohN5b`;o
RhO90on@R<L3oiB9a@;oV8_40onLSL<00onOS/;oWhk1oj>?`002oj>?`0?oYY6o0_nYTkl01?nZTkko
[IFnojfE__n]UKh2ok2G_@04ok6H_OncV[go/iZmok>J_@?o]Ybm1?niW[d00onkX;go_J:mokfR_@03
okjS_@04ol2U__o2Ykko`ZNnol:W_PCoaJZo1?o8[/03ol^a`@?o000000?ocKG3olnha?o?^LD00_o?
^LD00ooA_<KodKg7om?0b002om?0b0?oe<C:0_oFal`00ooDalgoe/[>omK:cP02omO>d003omG=dOoF
d=?oe]3C00;oem?E00Coe=;FomGDf?oEe=Sod]?I0_oBeM/2om;Gg@05oloEg_o>e]ooc]KOolgHhOo:
eN800oo9e^@01?o6dnCoa=?UolCCiOo2dNH2ol3Ai`?o_<kX00Go^lkXokW<j?nic>So0000okO9j002
okK9j@;o]<OX0_ncanT00onbaNSo/LGYok75j@02ok33j@;o[l;X00Co[/;Xojg1j?n]`NSo[L7X0on/
`>P3ojboj003o`000?oooooooooo01[ooooo0009ooooo`0400000?ooooooooooooooo`L0IVIV00<0
000007moO`1oOgl01@1oOgl00`000000VIVI09VIV@0509VIV@030000002c/k<0/k>c00L0/k>c00<0
00000<c<c03<c<`0303<c<`3000000X0i^KV0`00000<0<c<c0030000002c/k<0/k>c00L0/k>c00<0
000009VIV@2IVIT01@2IVIT00`000000Ogmo07moO`0507moO`030000001VIVH0IVIV00D0IVIV00<0
000004a<C01<C4`01P1<C4`00`000000<c<c03<c<`0803<c<`030000000I6AT06ATI00l06ATI6@00
0004ooooo`0300000?oooooooooo01Cooooo00?o0000og28fom`R=/00_maQ]T2ogB5eP;oMhCD0_mj
Q=42ogj4c`;oPXG=0_n7QL/2oh^7b@?oT8S70_nDRLD2oiR;a0;oW8g300?oVhc3oin>`OnOS/400onS
Sl03ojJA_`?oZY>n0on]UKh00on`Ukgo/IRmok6H_@04ok>J_@03okJL_OngWKgo]ifm00;o^Ijm00?o
^j2mokfR_OnmX[d00_nmX[d01OnnXkgo`:Fnol2U__o0YKko`ZNn00;oa:Vn0_o5Z[l2olN/_`;ob:k0
00Cob[31o`000?l0003o00000_o=]<801Oo=]L?ockS4olnha?o?^<CockW500;odKc600Kodl37om?0
b?oC`<Sodl38omG3bOoDa<X3omK7c003omO;cOoFb/koelk@00;oelk@0ooFd=<2omOCe@?oeMCH00Co
eMOJom;EfooBemgod]OM0_oAfMl01?o>e]oocMSQolgHhOo<fN<2olWFi0;oamKU00Coa=?Uol?Ci_o3
dnKo`=7W0_nodNP02?nlc^So^lkXok_>j?nkc^So^LcXo`000?nhbnWo]/WY0_ndb>T2ok?7j@;o//KY
00?o/LGYok34jOn_`nT00_n_`nT00on^`^So[/;Yojk2j@03ojg1j0?o[<3X00Co[;oXoj^oj?oooooo
00006oooool000Wooooo00D00000ooooooooooooooooo`00000706IVIP030000001oOgl0Ogmo00D0
Ogmo00<0000009VIV@2IVIT01@2IVIT00`000000/k>c0;>c/`070;>c/`030000003<c<`0c<c<00h0
c<c<2P00000>0<c<c0030000002c/k<0/k>c00L0/k>c00<0000009VIV@2IVIT01@2IVIT00ol00000
Ogmo07moO`0507moO`030000001VIVH0IVIV00D0IVIV00<0000004a<C01<C4`01P1<C4`00`000000
<c<c03<c<`0903<c<`030000000I6AT06ATI00h06ATI6P000004ooooo`0300000?oooooooooo01?o
oooo00?o0000ooooooooool00_mYQM/00om[PmWoKH;Foff2eP02ogN4e0;oNXCA0_mnQ<l3oh:5c@;o
QhG;0_n;QlT2oi28a`04oiB9aOnBR<GoUh[4oiN:a0?oVhc30onOS/43oj>?`003ojJA_onWTKooYi6o
00?oZY>n0_n]UKh4ok6H_@;o/iZm00Go]I^mokNM_OngWKgo]ifmokVN_@03ok^P_@;o_J:m00?o_j>m
ol2U__o0YKh00_o0YKh3olBY_P04olFZ_oo7[;ooajboolN/_`?o000000?ob[31ol^a`Oo=]<800_o=
]<83olnha004om6laOoA_<KodKc6om6laP;odl3700?odl38omG3bOoE`lT00_oGal/01?oFalcoel_=
omO;cOoIc/l3omO>d004omSAd_oFd=?oem?EomOCe@;oemKG00GoeMCHomGGf_oEem[oe=WLom;Gg@03
om7Ig`05om3JhOo=f>7oc=WSolcIhoo:fND00_o7e^D2olKGiP04ol?Ci_o1dnSo`M?XokoAj0;o_M3X
0_nkc^P2ok[=j@04okS;jOl0003o]/[YokC8j@;o/lSY0_nba^T01OnaaNWo/<CYok34jOn`a>Wo[l?Y
00;o[/?Y00?o[/;Yojg1jOn/`NP00on/`NP3ojc0j0;oZkoX00?o0000ooooooooool06Oooool000Wo
oooo00D00000oooooooooooooooo0000000706IVIP030000001oOgl0Ogmo00H0Ogmo00<0000009VI
V@2IVIT01@2IVIT00ol00000/k>c0;>c/`070;>c/`03o`0000000000c<c<02@0c<c<00?o00000;>c
/`2c/k<01`2c/k<00`000000VIVI09VIV@0609VIV@030000001oOgl0Ogmo00D0Ogmo00<0000006IV
IP1VIVH01@1VIVH00`000000C4a<04a<C00604a<C0030000000c<c<0<c<c00T0<c<c00<0000001TI
6@0I6AT03P0I6ATJ000000Cooooo00<00000ooooooooool04oooool01?l0003oooooooooooooool2
ofV5f`04of^3fOm]P]KoKH;Fog61e0;oMH7B0_miP/l3ogj3c@;oPhC;0_n8QLT2ohj7a`?oTXS50_nG
R/@3oi^<``;oWhk10_nSSl001?nST<3oYi6oojNA_onWTKl3ojZC_P03ojfE__n^U[ko[YJn00?o/IRm
00Co/iZmokFK_OneVkgo]I^m0_ngWKd4ok^P_@04okfR_OnoXkgo_j>moknS_@;o`:Fn0_o2Ykh2olBY
_P;oajbo0_l000001?o9[l3ob[31olZ``Oo:/<43olfd`P;ockS300GockS4om6laOoA_<GodKc5om6l
aP02om?0a`;oe/?800CoeL?9omO7booGal_oelO;0ooGbld2omW>c`05omO>d?oHdM;of=7BomWDe?oG
dmD00_oGe]L2omOIf@03omGGf_oDfMcoe=WL00;oe=cN00GodMWOom3JhOo@f^7ocmcSolcIh`02ol[I
i@03olSJi_o6enKoa]OV00;oa=KX00Co`M?Xol3CjOo0dnWo_M3X0_nld>T2ok[=j@;o^<gY00Go]/[Y
o`000?nebNWo/lSYok;7j@04ok75j@05ok34jOn_a>Wo[lCYojk3jOn^`^T00on]`NT2ojc1j0?o[<3X
1?n[_nP00ol0003oooooooooo`0Hooooo`002Oooool01@00003oooooooooooooool0000000P0IVIV
00<0000007moO`1oOgl01@1oOgl00ol00000VIVI09VIV@0609VIV@030000002c/k<0/k>c00P0/k>c
00<000000<c<c03<c<`0803<c<`2000000X0/k>c00<0000009VIV@2IVIT01P2IVIT00`000000Ogmo
07moO`0407moO`03o`00001VIVH0IVIV00H0IVIV00<0000004a<C01<C4`01P1<C4`00`000000<c<c
03<c<`0903<c<`030000000I6AT06ATI00h06ATI6P000004ooooo`0300000?oooooooooo01?ooooo
00Co0000oooooooooooooooo0_mQPM`2of=of@;oKH;F00?oLH7DogF1d_mePM800_miP/l3ogj3c@;o
PhC;0_n8QLT2ohj7a`;oTXS50onGR/@2oi^<``;oWhk11?nST<03ojNA_`03ojZC__n[U;oo[YJn00;o
[YJn0onaV;d4okFK_@03okNM_OniW[go^Ijm00?o^j2m1?noXkd01Oo0YKko`ZNnol:W__o2Ykkoa:Vn
00?o00000_o7[;l2olV_`004olZ``Oo</l7oc;?1olfd`P?ockS300KodK_4om6laOoA_<GodKc5omBo
a_oC`<L3omK3b0?oelO;0_oIbl`00ooGblgofLk?omW>c`02om[Bd@05omSAd_oIe=CofMCDom[He_oG
e]L00ooGfMT01?oGg=_oe=WLomCLg_oDg=h2om?Mh005om3JhOo?g>?ocmcSolgLi?o:fND00_o8f^H0
1_o6f^Soa=KXolCFj?o4e^So`]KYol3Cj@;o_];Y00?o_=3Yok[?j_njcnX00_nhcNT2okO<jP03okG9
jOl0003o//OY00;o//OY0_naaNT00on`aNWo[lCYojo4j@02ojo3j@;o[/;Y0on]`NT3ojc0j0KoZkoX
00?o0000ooooooooool05oooool000Wooooo00H00000oooooooooooooooo04a<C000000806IVIP03
0000001oOgl0Ogmo00D0Ogmo00<0000009VIV@2IVIT01P2IVIT00`000000/k>c0;>c/`080;>c/`<0
00007@3<c<`2000000/0/k>c00<0000009VIV@2IVIT01P2IVIT00`000000Ogmo07moO`0507moO`03
0000001VIVH0IVIV00H0IVIV00<0000004a<C01<C4`01P1<C4`00`000000<c<c03<c<`0903<c<`03
0000000I6AT06ATI00h06ATI6P000004ooooo`0300000?oooooooooo01?ooooo00?o0000oooooooo
ool00_ooool2of61g003of=ofOmVO]OoIWkG00;oJWkE0_mePM82ogV2c`;oOX?=0_n3Q</2ohR5b@;o
SXO70onBR<D01?nGR/CoUXW4oi^<`onKS<<3oin>`@?oXi300_nWTKl01?nWT[ooZiBooj^D_on[U;l3
ojjF_P03ok6H_OnbVKko/YVn00?o]I^m1?niW[d00onkX;go_J:mokfR_@03oknS_@;o`ZNn0ol00003
olJ[_`04olN/_oo9[l3obJo0olV_`0?oc;?100CockO2olnh`oo?^<?ockS30_oA^l@01?oA_<Goe;o6
omBoa_oF`lL3omK3b003omS7b_oGal_ofL_<00;ofL_<00Cof/o>omW>cooJd]7of];A0_oKe]<00ooI
e=Cof]SFom[HeP02om[Kf005omOIfOoGg=_oemcKomKNgOoDg=h00_oCgN02om7OhP05oloLhoo=g>Co
cMcTol_Mi_o8f^H00oo6f^P01Oo4e^So`]KYol;FjOo0eN[o_];Y00;o_=7Z00?o^/oZokS>j_nhc^X0
0_ngc>X2okG;jP03o`000?ndbN[o//OY00;o/LKY00?o/<GYojo4jOn_a>T00_n_`nT01On^`nWo[L;Y
ojg2jOn]`^Wo[L7Y00;o[<7Y0on/`>P5oj^oj003o`000?oooooooooo01Oooooo0009ooooo`060000
0?ooooooooooooooo`1<C4`00000201VIVH00`000000Ogmo07moO`0607moO`030000002IVIT0VIVI
00H0VIVI00<000000;>c/`2c/k<02P2c/k<00`000000c<c<0<c<c00I0<c<c003o`00002c/k<0/k>c
00X0/k>c00<0000009VIV@2IVIT01P2IVIT00`000000Ogmo07moO`0507moO`030000001VIVH0IVIV
00H0IVIV00<0000004a<C01<C4`01`1<C4`00`000000<c<c03<c<`0803<c<`030000000I6AT06ATI
00l06ATI6P000004ooooo`0300000?oooooooooo01?ooooo00?o0000ooooooooool00_ooool2oeQm
g0;oHgoI0_mVO]L00omZO]GoKgkBofmndP02ogAod0;oNX7>0_n0P/`2ohJ4bP;oRhK80onAR<H2oiJ9
a0?oVhc30onOS/400onST<3oXi31ojNB_`02ojNB_`?oZiBo0_n^U[h00on_Ukko/YVnok:I_P02ok:I
_P03okFK_OnfW;ko^Ijm00?o^Ijm1?nmX[d01?noXkgo0000o`000?l00002ol:W_P04olBZ_oo6Zkoo
aZ^oolR^`0?obJo00_o<//42olbc`@;ockO200CockS3om6ka?oA^lCodK_40ooD_lH2omK3a`03omK3
b?oHal[of<O:00;of/c<00GofL_<om[?c_oJclkog=?@om[Bd@03om_Fd`04omcJeOoJf=Kof]_Hom[K
f0;of]kJ00GoemcKomKNgOoFg]goeN7Oom?Mh002om7OhP;od>3T00CocMcTol_Mi_o9gNSobMgX0_o6
f^P2olCIj@05ol;FjOo0eN[o`=GZokkDjonldNX00_njd>/00onhc^[o]lg[okO=j`02okG;jP05okC:
j_ncb>[o0000ok?8j_naa^T00_n`aNT2ojo4j@Co[/?Y00Go[L;Yojg1jOn]`NWo[<7Yojc0j@09oj^o
j003o`000?oooooooooo01Kooooo0009ooooo`0400000?ooooooooooooooo`80C4a<00?o000006IV
IP1VIVH01P1VIVH2000000L0Ogmo0P00000709VIV@8000002`2c/k<00ol0000000000000000G0<c<
c08000002`2c/k<00ol00000VIVI09VIV@0609VIV@030000001oOgl0Ogmo00H0Ogmo00<0000006IV
IP1VIVH01@1VIVH00ol00000000004a<C00704a<C0030000000c<c<0<c<c00T0<c<c00<0000001TI
6@0I6AT03`0I6ATJ000000Cooooo00<00000ooooooooool04oooool00ol0003oooooooooo`03oooo
o`;oF7gL00?oFWcJoeekf?mMNmP00_mZO]D2ofmndP;oM7o@00?oNX7>oh22c?n0P/`00on6Q<X2oh^6
b0?oTHS60_nFRL@3oi^<``03oin>`OnOS/;oXi3100;oXi310onWT[l2oj^D_`Co[iNn0_nbVKh01?nc
Vkko]YbnokJL__nfW;h2okVN_@03okZP__nmX[go_J:m00?o00000oo1Y[h01?o2Ykkoa:ZoolBZ_oo6
Zkl3olR^`005olV_`?o<//7oc;;1olbb`Oo</l400oo?]l83om6ka0;oe;o500Coe;o6omK3aooF`lOo
e/?70ooHalX2om[<c0?of/o>00Cog=?@omgHd_oMf=;ofmKC0_oLf]D00ooLg]Oof]_Hom[NfP02om[N
fP03omWQg?oFg]goeN7O00;oe>;R0_oBhn@01Oo@h>Coc^7VolkQi_o;hNSobMgX00;oamcY0_o4fNT2
ol;HjP05ol3Ej_nne>_o_]C[okcCjonjd>/00_nhcn/00ongcN_o]Lc[okC:jP03okC:jP04ok?8j_l0
003o/LOZok35j@;o/<GZ0_n_a>T2ojk3j@;o[L;Y00?o[L7Yojc1jOn/`NT00_n/`>T7oj^oj0;oZ[kX
00?o0000ooooooooool05Oooool000Wooooo00@00000oooooooooooooooo0`1<C4`00`000000IVIV
06IVIP0706IVIP030000001oOgl0Ogmo00H0Ogmo00<0000009VIV@2IVIT01P2IVIT2000000`0/k>c
0`00000@0<c<c0@000002`2c/k<2000000T0VIVI00<0000007moO`1oOgl01P1oOgl00`000000IVIV
06IVIP0506IVIP030000001<C4`0C4a<00L0C4a<00<0000003<c<`0c<c<0200c<c<00ol000006ATI
01TI6@0@01TI6AX000001?ooool00`00003oooooooooo`0Booooo`03o`000?oooooooooo00Gooooo
0_mHOM`01?mJO=[oGG_Hof9ke_mRNmH2ofmndP;oM7o@0_mjPLh2oh22c0;oQXC:0_n;Q/P3oi68aP;o
UXW40_nKS<<00onJS<CoWhk2oin>`P03oj>@`@?oYi:o00?oZiBoojbE_on/UKl00on_Ukh00onbVKko
/i^nok>K_P03okJL_P03okVN_OnjX;ko000000;o000000?o_J:moknT__noY;h00_o1Y[h01?o3Z;oo
a:ZoolBZ_oo4Z[l4olR^`0Coc;;10oo?]l82om6ja004om6ka?oD_lGoe;o5omBoa@?oe/?70_oHb<T0
0ooHal[of/c<om[<c002omc@c@03om[?c_oLdm3og=?@00;ogMSB00CogMcDomcJeOoLg]Oog=kG0_oL
hMX01_oJg][ofN7LomWQg?oHi=ooe^GQomCRhP;od^?T0_o@i>H01Oo>hNKobn7Xol_Qj?o9h>WoamcY
00;oa=cZ0_o2f>X2ol3Gj`06okkDjonldn_o_=?[ok[Bk?nhcn_o]lk[0onec>/2okC:jP;o/lW[00Go
/LOZo`000?n`a^[o/<GZojo4j@03ojk3j@Co[L;Y00?o[<7Yojc0jOn[`>P00_n[`>P6oj^oj0;oZ[kX
00?o0000ooooooooool05Oooool000Wooooo00@00000oooooooooooooooo101<C4`00`000000IVIV
06IVIP0706IVIP03o`00001oOgl0Ogmo00H0Ogmo00<0000009VIV@2IVIT01`2IVIT00`000000/k>c
0;>c/`0<0;>c/a0000003P2c/k<00`000000VIVI09VIV@0809VIV@030000001oOgl0Ogmo00H0Ogmo
00<0000006IVIP1VIVH01@1VIVH00`000000C4a<04a<C00704a<C0030000000c<c<0<c<c00T0<c<c
00<0000001TI6@0I6AT03`0I6ATK000000Cooooo00<00000ooooooooool04_ooool00ol0003ooooo
ooooo`05ooooo`;oCGWM0_m?N=/01?mMNmSoHW_Fof9ke_mXO=<2ofimd@;oMGo?0_n0P/`3ohJ4bP;o
RhK800CoTHS6ohn7aonDRLGoU8W50onJS<@3oin>`P?oXi3100?oYi:oojRC`?n/UKl00_n/UKl3ojnG
_PCo/i^n00Co]Ybno`000?l0003o00000_njX;h01OnmX[go_jBnoknT__noY;ko`JJn00?o`jRo0_o4
Z[l01Oo7[L3ob:k0olR^`?o8[/3obk7100?oc;;100?oc[K2olng`_oA^/@00_oA^/@3omBoa@;oel?7
00Koe/?7omS8bOoHb<Wof<S9om_<booJc<`2omc@c@;ogMG@00?og=?@omgHd_oMf=800_oMg=@01?oN
h=Oog=kGomcQf_oLhMX2om_Tg006omWQg?oHi=ooe^GQomKUhOoDin?od^?T0_o@i>H2olkTj005ol_Q
j?o9h>WobN3YolKOjoo4g>X00_o2fn`2ol3Gj`;o_]K/00?o_=?[ok[Bk?njd^`00ongc^/00onec>_o
]<_[okC;j`02ok?9j`;o/LS[00?o0000ojo5j_n_aNX00_n_a>T00on^`nWo[L;Yojg2j@02ojg2j@05
ojc1jOn/`>Wo[<3Yojc0jOn[`>P01_n[_nP4ojZnj003o`000?oooooooooo01Cooooo0009ooooo`04
00000?ooooooooooooooo`D0C4a<00<0000006IVIP1VIVH01P1VIVH00`000000Ogmo07moO`0707mo
O`030000002IVIT0VIVI00L0VIVI0P00000Y0;>c/`03o`00002IVIT0VIVI00L0VIVI0P00000807mo
O`030000001VIVH0IVIV00H0IVIV00<0000004a<C01<C4`01`1<C4`00`000000<c<c03<c<`0903<c
<`030000000I6AT06ATI00l06ATI6`000004ooooo`0300000?oooooooooo01;ooooo00?o0000oooo
ooooool01_ooool2odeig@03odmhfomDMmWoE7OI00;oHW_F00CoJ7cCofimdOm^OM7oMGo?0_mlPLd3
oh:3b`;oRHG90_n?QlL3oiB9a@?oVXc40_nOS/82oj>@`@04oj>A`_nXTl3oZ9?0ojRC`0?o[9Fo00Co
[iNnok2I_on`VKoo/i^n0ol00002okRN_P?o^Z2n1?noY;h4ol>X_`05olBZ_oo7[L3oajg0olN]`?o8
[/000oo;/L400oo<//7oc[K2oljf`P04om6ja0;oe;o50ooG`lL01ooIb<Wof<S9omS8bOoHb<Woflc;
omcAcOoLd<d00ooMeM000ooNf];ogMSBomgLe002omgLe003omkPeooMi=Wog>7J00;ofnCL0_oJimh0
1_oHjN7oe^GQomCWhooDin?od^SVom3TiP;oc^CX0_o;i>T01Oo9h>Woa]o[olCNk?o4g^co`]_/00;o
_mW/0_nne^`2okcDk004ok[Bk?nhd>co^=3/okO>j`;o]Lg/00?o]<_[ok;9jonbbN/00_nab>/2ok36
jP03o`000?n_a>[o[/?Y00;o[/?Y0on]`^T2ojc1j@Co[<3Y1On[_nP6ojZnj003o`000?oooooooooo
01?ooooo0009ooooo`0400000?ooooooooooooooo`H0C4a<00<0000006IVIP1VIVH01P1VIVH00`00
0000Ogmo07moO`0707moO`030000002IVIT0VIVI00P0VIVI0P00000U0;>c/`8000002@2IVIT00`00
0000Ogmo07moO`0707moO`030000001VIVH0IVIV00L0IVIV00<0000004a<C01<C4`01`1<C4`00`00
0000<c<c03<c<`0903<c<`030000000I6AT06ATI00l06ATI00?o000000000000000060000004oooo
o`0300000?oooooooooo01;ooooo00?o0000ooooooooool01oooool01?m1M=goCgSKodmhfomDMmT2
oeUhe`;oH7WE0_m^OM400omeOlooO87=ogb1c@03oh:3b`;oRHG90_n?QlL3oiB9a@;oVXc400?oWhk2
oij?`onSTL800onSTL82ojRC`0;o[9Fo00?o[9O0ok2I_on`VKl00_l000000oncVkko]IfookRN_P03
okRN_P03okZP__nlXkoo_:>o00?o_jBn00Co`JNool>X_oo3Z;ooaJc00oo7[L001Oo9/<7obk71ol^a
`Oo;/L7ocKG200?oc[K20ooA^/@2omBoa@Coel?70_oIb<T01OoHb<Woflc;om_<booLdLgog]K?00?o
gMG@00Cog][BomoNe?oOg]CogMcD0_oNh=L00ooMi=WogNOLom_Tg002om[WgP;of>WQ00?oe^_SomCW
hooBj>H00_o?j>P2olgXjP05ol_TjOo8hn_ob>?[olGRkOo4g^`00_o1gNd00onofNco_MS]okgHk@02
okcDk0;o^]?]00Co^=3/okK?k?nfcnco]Lg/0_ncbn`00onbbN_o/LS[ok78j`02ok36jP;o[lGZ00?o
0000ojo4j_n^`nT00_n]`nT00on]`^Wo[<7Yojc1j@02ojc1j@;o[<3Y0_n[_nT3oj^oj0;oZ[oX1OnZ
_^P00ol0003oooooooooo`0Cooooo`002Oooool01000003oooooooooooooool704a<C003o`00001V
IVH0IVIV00H0IVIV00<0000007moO`1oOgl01`1oOgl00`000000VIVI09VIV@0909VIV@<000008@2c
/k<00`000000VIVI09VIV@0809VIV@030000001oOgl0Ogmo00L0Ogmo00<0000006IVIP1VIVH01`1V
IVH00`000000C4a<04a<C00704a<C0030000000c<c<0<c<c00T0<c<c00<0000001TI6@0I6AT0400I
6ATK000000Cooooo00<00000ooooooooool04_ooool00ol0003oooooooooo`08ooooo`04od5dgOm4
Lm_oE7OIoeAgf@;oFGSG00?oH7WEofMkdomWNm<00_m_OM42ogb1c@;oPX?;0_n9QLT2ohn7a`;oU8W5
00?oTh[7oiV<aOnIS<D00onNSl<3oj>A`P04ojRC`?nXU<;o[9O0ojbG`0?o000000?o/9VookFM_one
WKl00_neWKl2okRN_P03okZQ_onlXkoo_:>o00;o_:>o00Co_jBnol6W_oo1Ykoo`jRo0oo5[<001Oo7
[L3obK31olV``Oo9/<7obk7100?ocKG200Coc[K2om6ja?oA^/CodK[40ooD_lD3omO3a`;ofLS90_oK
cL/00ooKc<_og=7=omcAc@02omkFc`04omgEd?oNf];ogmkDomoNe0;ogn?G00Gog^3GomgTfOoMimco
gNOLom_ZgP02omW]h006omSYhOoFjn?oe^_Som?/iOoAk>SocnSX0_o=j>X2olWWk005olSSjoo5h^go
aN;]ol?Pk_o1gNd00_nofnh00onmf>go^mK]ok_Fk@02ok[Ck@;o^=7]00Co]/o/okG=k?necNco/l_/
0_nbb^/00onab>_o/<O[ok37j`02ojo5jP05ojk5j_n^`n[o0000ojk3j_n]`nT00_n]`^T3ojc1j@;o
Zl3Y0_n[_nT4oj^oj003ojZoj?nZ_^SoZ[kX00GoZ[kX00?o0000ooooooooool04_ooool000Wooooo
00@00000oooooooooooooooo201<C4`00`000000IVIV06IVIP0606IVIP03o`0000000000Ogmo00L0
Ogmo00<00000o`00000000002`2IVIT2000001/0/k>c1000000:09VIV@03o`00001oOgl0Ogmo00L0
Ogmo00<0000006IVIP1VIVH01`1VIVH00`000000C4a<04a<C00704a<C0030000000c<c<0<c<c00T0
<c<c00<0000001TI6@0I6AT0400I6ATL000000Cooooo00<00000ooooooooool04_ooool00ol0003o
ooooooooo`08ooooo`;o<foM00CoA7?KodQcf_m?M=SoCgCH0_mPNMD2ofMkd`03ofmmdOmgOlooMgo?
00;oOX;=0_n6QL/2ohf7b0?oTh[70onIS<D3oij?``03oj>A`_nTT/?oZ9C200?o00000_n/Ul000on`
VKoo/I_0ok6K`003okFM_`04okRN__njXKoo^Z6ookZQ_`;o_:>o00Co_ZG0ol6W_oo1Ykoo`JNo1?o5
[<04olV``@CocKG20ooA^/@2om>naP04omBoaOoG`lOoel?7omO3a`;ofLS90ooKcL/01?oMd/gog=7=
omkFcooNe/l2omoKdP04on3Qe?oOg]Cogn?GomoSe`;ognOI00?og^_KomgWg?oKj]h00_oIkN02omO^
h`06omK[hooCk>GodNcXom7/j?o>k>[ocNSZ0_o9in`2olOVk@05olGRkOo3h>ko`=k^ol3Nk_nofnh0
0_nlfNh00onke^go^MC^okWDkP02okSAk@;o]/o]00Co]Lg/ok?<k?ncc>co//[[0_nab>/00on`an_o
[lK[ojo6j`02ojk5jP05ojk3j_l0003o[L?Zojg3j_n]`^T01?n/`NT3oj_0j@CoZkoX0_nZ_nP7ojZn
j003o`000?oooooooooo01;ooooo0009ooooo`0400000?ooooooooooooooo`P0C4a<00<0000006IV
IP1VIVH01`1VIVH00`000000Ogmo07moO`0907moO`030000002IVIT0VIVI00X0VIVI0P00000G0;>c
/`8000003@2IVIT00`000000Ogmo07moO`0707moO`03o`00001VIVH0IVIV00P0IVIV00<0000004a<
C01<C4`01`1<C4`00`000000<c<c03<c<`0903<c<`030000000I6AT06ATI01006ATI70000004oooo
o`0300000?oooooooooo01;ooooo00?o0000ooooooooool02Oooool01OlcKmgo=VkKocI^fom8Lm[o
CgCH00;oEgKF0_mWNm<2ofmmd@;oMgo?0_mnP/d2ohJ5b`;oSHO80onCR/L2oiV<a@;oWXo300CoWY35
o`000?l0003o00000onXU<800on/Ul3o[IW2ok6K`002ok6K`0?o]Ifo1?njXKl01?nlXkoo_ZG0okjU
`?nnYL02ol6W_`05ol>Z`Oo5[<3oaJc0olF/`?o8[l800oo9/<400oo<]<?ocKG2olfe`P02om2ia004
om6ja?oC_/Kodkk6om>naP?oel?70_oIb<T3om_=b`;ogM;=00?ogmS@omkFcooOfm800_oOfm800ooP
hMCohNGGomoSe`03omoWf@04omk[fooLk]kof_3PomW]h0;oenkS0_oDknD00ooAl>OodNcXolk/jP02
ol_[k0;oanW]00GoanK]olCTk_o4i>ko`N;_ol3NkP02okgLk`04okcIk_njenko^]O^okWDkP;o]m;^
0_nfcnd2okC>k@04ok?<k?nbb^co//[/ok78j`;o/<O[00?o[lK[ojk5j_n^a>X00_n^a>X01?n]`n[o
0000ojg2jOn]`^T3ojc1j@?oZl3Y00CoZkoYoj^oj?n[_nSoZkoX0_nZ_nP9ojZnj003o`000?oooooo
oooo017ooooo0009ooooo`0400000?ooooooooooooooo`T0C4a<00<0000006IVIP1VIVH01`1VIVH0
0`000000Ogmo07moO`0907moO`800000302IVIT6000000d0/k>c1000000>09VIV@030000001oOgl0
Ogmo00P0Ogmo00<0000006IVIP1VIVH01`1VIVH00`000000C4a<04a<C00704a<C0030000000c<c<0
<c<c00X0<c<c00<0000001TI6@0I6AT0400I6ATL000000Cooooo00<00000ooooooooool04Oooool0
0ol0003oooooooooo`0;ooooo`05ob=YfolfK]_o>foJoc]_f_m?M=P00_mGM]H00omONMGoJ7_CofQk
d`02ogMoc`;oOX;=0on6QL/2ohf7b0;oTh[700?oVHc5oiR>aol000000_l00003ojBB``;oZ9C200Co
ZIO3ojfI`_n]VL;o[IW20onaVl000oneWKoo]io1okNO`@03okZQ_`Co_ZG000Go`JNool>Z`Oo3Z/7o
`j[1olF/`003olR_`P04olV``Oo<]<?oc;C3olfe`P?od;W41?oC_/H00ooFa<Soel?7omW8b@02omW8
b@03om_>c?oKcL_ogM;=00;ogM;=00CogmS@on3Md_oPgM;ogm_B0_oPhM@01OoQiMOoh>[Ion3ZfOoO
imWog^_K00;og>kN00Kof_3PomObhooDlnGoe??UomC_iOoAl>L2olk`jP04ol__k?o;jncoanW]olOY
k@;oa>O_00Goa>C^ol7Rkonngo3o_]o`okgLk`02ok_Ik`04ok[Gk_nhe>oo^=C_okOBkP;o]M3^0_nd
c^d2ok;<k@04ok;:k?n`b>co/<S/ok37j`;o[lK[0_n^aNX01On^a>[o[L?Zojg3j_n]`^Wo000000Co
[<7Y0on[`>T2oj^oj@03oj^oj?nZ_nSoZ[oX00_oZ[kX00?o0000ooooooooool04?ooool000Wooooo
00D00000ooooooooooooooooo`00000904a<C003o`00001VIVH0IVIV00L0IVIV0P00000;07moO`03
0000002IVIT0VIVI00l0VIVI3@00000A09VIV@030000001oOgl0Ogmo00P0Ogmo00<0000006IVIP1V
IVH01`1VIVH00`000000C4a<04a<C00804a<C0030000000c<c<0<c<c00T0<c<c00<0000001TI6@0I
6AT0400I6ATM000000Cooooo00<00000ooooooooool04Oooool00ol0003oooooooooo`0<ooooo`03
ob=YfolVJM[o>foJ00;o@W3I0_mGM]H01?mONMGoJ7_Cog5ndOmaO]42ogZ2c`?oPhG=0_n;R</01OnB
RlWo0000o`000?l0003oV8k700?oWY350_nTT/<00onXU<;oZIO3ojVG``03ojfI`P;o/I_000?o/ig2
okNO`OngWl400_ngWl400onjXKoo_:C1okbT`@03okjU`0?o`j[100?oaZk3olR_`_o8[l800_o8[l83
olbd``04olniaOo@^LCod;W4om2ia0?odkk60_oFa<P2omW9bP03omW8bOoKc/coflk<00;og]C>00?o
gM;=omoHd?oOf=000_oPgM800ooQhmGoh>7Don7Ue`02on3Zf@;ognkK00CogO7Nomc^g_oJl>3oeo;S
0_oDlnD2om7ci`03olkcjOo>l>[obno/00;ob>g^00CoaN__olCWkoo4inoo`^G`0_noh_401?nngo3o
_=c`okcLl?nkfNl2okWGk`04okSDkonfd^ko]];^okG@kP;o/lk]0_nbc>d2ok7:k005ok38k?n_an_o
[lO[ojo6jon^aN/00on]a>X01On]`n[o[<;Yojc2jOn/`NWo000000;o[<7Y0on[`>T01On[_nWoZkoX
oj^oj?n[_nSoZ[oX00_oZ[kX00?oZKkXo`000?ooool04Oooool000Wooooo00D00000oooooooooooo
oooo0000000:04a<C08000002@1VIVH00`000000Ogmo07moO`0907moO`800000:P2IVIT200000003
o`00001oOgl0Ogmo00P0Ogmo00<0000006IVIP1VIVH01`1VIVH00`000000C4a<04a<C00804a<C003
0000000c<c<0<c<c00X0<c<c00<0000001TI6@0I6AT0400I6ATM000000Cooooo00<00000oooooooo
ool04Oooool00ol0003oooooooooo`0<ooooo`;o4F?I00?o9VWJobaYf_m2L=T00_m;LmP2oeEfe`03
ofQkdomaO]7oLGkA00;oNX;?0_n3QLd3o`0000;oTX_90onHS/L2oij@a@03ojBB`onTU<GoZIO300?o
ZIO30_n]VL84ok>M`P;o]io100?o^:;3okbT`OnlY<400_nlY<401?nnYL3o`JW2ol6Y`_o3Z/43olJ^
``;ob:o20_o:]<@01Oo<]<?ockW5olniaOo?^LGod;W400?odkk600?oe/C9omK4b?oIbLX00_oIbLX0
0ooKclgoflk<omkDcP02omkDcP04omoJdOoOf=3oh=gBon3MdP;ohN?E00?ohNSGon3]f_oPj]T00_oO
k]/2omgagP04om[dh?oGm^;odoOTomCci@;odO?W00Koc_?Yol[bk?o:l^coao7^olS]k_o5jnl2ol;Y
l@03ol;Ul?noh_7o_n;a00;o_=oa00Co_=c`okWJl?nif_3o^MO_0_nge>l01?nfd^ko]=3^okC@k_nc
c^d2ok;<k@;o/L[/0_n`b>`00on_an_o[/K[ojk6j`02ojk5j`04ojg4j_n]`n[o[L?Zojc2j@;o[<7Y
00?o0000ojc1jOn[`>T00on[`>T2oj^oj@03oj^oj?nZ_nSoZ[oX00_oZ[kX00?oZKkXojVmj?l00000
4Oooool000Wooooo00H00000oooooooooooooooo03<c<`00000;04a<C0030000001VIVH0IVIV00L0
IVIV00<0000007moO`1oOgl02P1oOgl2000002L0VIVI00<0000007moO`1oOgl02@1oOgl00`00003o
000006IVIP0806IVIP03o`00001<C4`0C4a<00T0C4a<00<0000003<c<`0c<c<02P0c<c<00`000000
6ATI01TI6@0@01TI6Ad000001?ooool00`00003oooooooooo`0Aooooo`03o`000?oooooooooo00go
oooo00?o4F?IoaARf?lDH]P00_ldK=X2od]cf003oeEfeomPN]KoH7[F00;oLGkA0ol000000on3QLgo
RhS;oh^8b`02oi:;b@;oV8k700?oV8o9oijBaonNT/L00onTU<D3ojVG``03ojfI`_n_VlCo[i_400?o
/ig200Co]io1okRR`onhX/?o^:;30_nlY<401?nnZ<?o`JW2ol6Y`_o1ZL84olJ^``04olR_`_o:]<Co
b[C4olZda0?ockW500Cod[k7om>na_oC_/Kodkk60_oFa<T3omW9bP;oflo=0ooNe<h2omoJd@04on7P
dooPgM;ohN?Eon7Se@;ohNSG00Soh>gJomoag?oOlMcog?GNomgag_oJm>3oeoKRom?gi0;od?OW0_o<
mnT01?o9m^cob_;/olOak_o4ko02ol7/l@04ol;YlOnoi_;o_>?bokcSlP;o_=oa0_njg?401?nif_3o
]mO`okGDl?nee?02okCBk`04okC@k_nbcNko//g^ok;<k@;o/<[]0_n`b>`2ojo7k003ojk6jon^aN_o
[LCZ00;o[LCZ00?o[L?Zojc2j_n/`^X00on/`NT01Ol0003oZl3Yoj_0jOn[`>WoZkoY00?oZkoX00?o
Z[oXojZnj?nZ_^P02OnZ_^P01OnY_^SoZKgXojVmj?nY_NSo0000013ooooo0009ooooo`0400000?oo
ooooooooooooo`80<c<c00<0000004a<C01<C4`02@1<C4`00ol00000IVIV06IVIP0706IVIP<00000
2`1oOgl300000280VIVI0P00000;07moO`030000001VIVH0IVIV00P0IVIV00<0000004a<C01<C4`0
2@1<C4`00`000000<c<c03<c<`0:03<c<`030000000I6AT06ATI01006ATI7P000004ooooo`030000
0?oooooooooo017ooooo00?o0000ooooooooool03_ooool01?l0FmCo56;HoaYSf?ldK=X2oci_f@;o
EGKG0ol00002ogF2dP;oOhG@0_n8RLh2oi2<b`?oV8o90onNT/L3ojBDa@03ojVG`onZVLGo[i_400;o
[i_40oncWL84okRR``04okbT`OnnZ<?o_ZS3okjX``;o`JW200Go`jg4olJ^`oo6[/?oaZk3olRca@03
olZda003olfia_o?^LGod[k700;od[k700Kodkk6omK4bOoFa<Woe/C9omS:booIbLX3om_?c@04omkF
cooNe<kogm[AomoJd@;ohN3C0_oRi]H00ooQk=SohNSGon3]fP02omoag0;og?GN00GofOOPomGih_oA
n^CocO[Vom3gi`02olcgj@07olWfk?o5m>ko`_;`ol;bl?noko;o`NcaokkYl`02okcVl`06okcSl_nj
go?o^]ocok[Olonjg?7o]mWa0_nee_401Onee?3o/m7`ok?Al?nccnoo/Lg^00?o/L_]00?o/<[]ojo8
k?n_b>`00_n_an`01On^a^_o[/G[ojk5jon^aN_o[LCZ00;o[L?Z00?o[<;Zojc1jOn/`NT00_n[`NT0
0on[`>Wo0000oj_0j@02oj^oj@;oZkoX0_nZ_nP:ojZnj003ojVnj?nY_NSoZKgX00;oZKgX00?o0000
ooooooooool03_ooool000Wooooo00@00000oooooooooooooooo0`0c<c<00`000000C4a<04a<C009
04a<C0030000001VIVH0IVIV00T0IVIV00?o000007moO`1oOgl02`1oOgl01000003o000000000000
000J09VIV@80000000?o00000000001oOgl02`1oOgl00`000000IVIV06IVIP0806IVIP030000001<
C4`0C4a<00T0C4a<00?o000003<c<`0c<c<02P0c<c<00`0000006ATI01TI6@0@01TI6Al000001?oo
ool00`00003oooooooooo`0Aooooo`03o`000?oooooooooo00oooooo00Go05_Do`1Je?lJHmSo8fKI
oci_f@02o`0000;oH7[F0_m[O]@2ogF2dP;oOhG@0_n8RLh2oi2<b`?oV8o90_nNT/L2ojBDa@04ojBG
aonZVLGoZYW5ojZIa@?o[i_400?o/ig2okBQa?ndXL@00onhX/<4okjX``05ol6Y`_o3[LCo`jg4ol>]
a?o6[/<00oo8/lD01?o:]<CocKW6olfia_o@_/T3om:na`;oeLC:00?oe/C9omS:booHb//00_oKd<h0
0ooKclgog]K?omkFc`02on3LdP04on7SeOoQh=?oh^KFon;VeP;ohNcH00?oh?7Jomkeg?oOlM`00_oL
mMh01?oImn3oeOWRom7ji?o=n^H2olWjj006olKijoo2mngo`_O]okoel?o2l_3o_nob0_nmk?<01?nk
jOCo_>KcokWRm?nih_@2ok[Ol`04okOLl_nefO;o]MWbokGFl@;o/m?`00?o/m7`ok;?konbcnl00_na
cNh01?nabngo/<W]ok39kOn_b>`2ojk7k003ojk6jon]a>_o[LC[00?o[L?[00Go[L?Zojc2j_n/`^[o
[<7Yoj_1j@04oj_0j@04o`000?n[_nWoZkoYoj^oj@;oZ[oX2OnZ_^P3ojVnj005ojVmj?oooooooooo
ooooool000004?ooool000Wooooo00@00000oooooooooooooooo100c<c<00`000000C4a<04a<C009
04a<C0030000001VIVH0IVIV00P0IVIV0P00000@07moO`<00000502IVIT3000000h0Ogmo00<00000
o`00001VIVH02P1VIVH00`000000C4a<04a<C00904a<C0030000000c<c<0<c<c00X0<c<c00<00000
01TI6@0I6AT0400I6AT00ol0000000000000000L000000Cooooo00<00000ooooooooool04?ooool0
0ol0003oooooooooo`0@ooooo`;o05?=0ol000001?l^Jm[oBG?IoeIhfOmFN=T2of9me`;oMH;B0_mo
QM03ohR9cP;oT8c;0_nHSlT00onNT/OoWYC:ojBGa`03ojBGa`;oZYW50_n_Vl@00on`WlKo]:74okBQ
a002okBQa003okRR`onjY/Go^ZK500?o_ZS30oo3[L@01Oo6//Oob;?5olRcaOo8/lGobkS800?ocKW6
0_o@_/T01?oB_/OoeLC:omG4b_oEa<X3omS:b`;ofm3>00CogMOAomkFcooPg=;oh=cB0_oQhmD01OoQ
jMOoh^KFon7/f?oQk=Soh?7J00;og_GL00Wof_SNomOjgooBo>7od_cQolglh_o9o>Coa?cWol7kjOo6
nN/00_o2mnd01_nomO3o_O;bok__m?nkkoCo_Nccok_Ym0;o^>Ge00Co^N;dokONm?nefo?o]M_c0_ne
fO82ok?ElP04ok?Cl?nbd?3o/]3`ok;?k`;o/<c^0_n`bnh01?n`bNgo[lS/ojo8k?n^an`2ojg5j`03
ojg4jon/`n_o[<?Z00?o[<?Z00?o[<;Zojc1jOn/`NT00_n[`NT01On[`>WoZkoYoj^ojOl0003oZ[oY
00?oZ[oX2onZ_^P00onY_^Soooooooooo`03ooooo`03o`000?oooooooooo00kooooo0009ooooo`04
00000?ooooooooooooooo`D0<c<c00<0000004a<C01<C4`02@1<C4`00`000000IVIV06IVIP0906IV
IP8000004@1oOgl3000000d0VIVI1000000@07moO`030000001VIVH0IVIV00X0IVIV00<0000004a<
C01<C4`02@1<C4`00`000000<c<c03<c<`0:03<c<`030000000I6AT06ATI01406ATI7`000004oooo
o`0300000?oooooooooo013ooooo00?o0000ooooooooool03oooool3o`0000;o057=0_l>GmL2oc]`
f`;oEWSI00?oHWgGofn2e_m_P]H00_mjQ]@3ohF;d@;oSXk?0_nFTL`3oijDbP?oY9O700?oZYW5oj^M
b?n`WlH00on`WlH2okBQa003okJUaonjY/Go^ZK500;o^ZK500Co_ZS3ol2/a_o0[<Ko`jg40oo6//L0
1Oo8/lGobkS8ol^hb?o;^<SocKW600?od;k90ooEa<X2omS;c@03omS:booKd<kofm3>00;ogMOA00?o
gmkDon3Ld_oQhmD00_oQhmD02?oQjMOohNoJon7_f_oOm=_og?SMomkeg?oJn=koeo[O0_oBo>401?o=
o>;obOcTolClioo1nnT2okkik006ok_gkonim?;o^OCbokSam?nkkoCo^N_e0_ngioH01OnhiOGo]^7e
okCMm?ndgOCo]M_c00;o/mOc0_nceO82ok;Bl@04ok;@l?n`c^oo/<k_ok3<kP;o[l[^0_n_bNd01?n_
b>co[/K/ojk6k?n]aN/2ojg4j`;o[<?[0_n/`nX01?n/`^[o[<7Yojc1jOn[`NT3oj_0j@?oZkoY00?o
0000ojZojOnZ_nP02OnZ_^P:ooooo`03o`000?oooooooooo00gooooo0009ooooo`0400000?oooooo
ooooooooo`H0<c<c00<0000004a<C01<C4`02@1<C4`00`000000IVIV06IVIP0:06IVIP8000004P1o
Ogl=000001<0Ogmo00<0000006IVIP1VIVH02P1VIVH00`000000C4a<04a<C00904a<C0030000000c
<c<0<c<c00X0<c<c00<0000001TI6@0I6AT04@0I6ATP000000Cooooo00<00000ooooooooool04?oo
ool00ol0003oooooooooo`0<ooooo`?o00001?ooool01?l0DLgo05?>o`iOeolKIMT2oc]`f`03odUf
fomROMOoHWgG00;oKh;F0_mjQ]@3ohF;d@;oSXk?0_nFTL`3oijDbP03ojBGaonUV/_oZig800;oZig8
0on`WlH4okJUa`;o^ZK500Co_J_8ol2/a_o0[<Ko`:c61?o6//L01?o9^<[obkS8ol^hb?o;^<P3om2n
b@;odlG<00KoeLC:omS;cOoHblgof<_=om[Bd?oKd<h3omgGd@05omoNe?oQi]OohNKGon7SeOoQjML0
0_oQkmX01_oOm=_og?SMomchgOoGnmgod_gNolgng`;oaokP00?o`_gRok[kiongn^X00_nfn>h2okCf
l@03okWdl_nhlOCo]^kf00;o]N[g00Go]nOfokGSm_ndgoKo]=ofokCMm002ok?Im003ok?Glonbe?;o
/]Cb00;o/];a0_n`co001?n`c^oo[lc^ojo<k_n_b^h2ojk8k@;o[/O/00Co[/K/ojg5jon]aN_o[LC[
0_n/`n/3ojc2jPGoZl7Y00SoZl3Yoj^ojOn[_nWoZkoYojZojOnZ_nSo0000ojZoj0KoZ[kX3Oooool0
0ol0003oooooooooo`0=ooooo`002Oooool01000003oooooooooooooool703<c<`030000001<C4`0
C4a<00T0C4a<00?o000006IVIP1VIVH02`1VIVH00ol00000Ogmo07moO`0]07moO`0300000?l00000
IVIV00X0IVIV0P00000;04a<C0030000000c<c<0<c<c00/0<c<c00?o000001TI6@0I6AT04@0I6ATP
000000Cooooo00<00000ooooooooool04?ooool00ol0003oooooooooo`09ooooo`?o00002?ooool0
1?l0@;So05?>o`1GdOlKIMT2oc]`f`03odUffomHO=_oF7cK00;oKh;F0_mjQ]@2ohF;d@;oSXk?0_nF
TL`2oijDbP04oifHc_nUV/_oYI[;ojFJb`?oZig800?o/9o6ok6SbOnaXlT00onfYLL01OnjY/Go_J_8
okf[b?nmZlSo`:c600;o`k790oo6//L2olVhbP04ol^hb?o>_/_oc[k;om2nb@?odlG<0_oFc<l00ooH
blgof];@om[Bd002omgId`04omgGdOoOg]CogmkDon7Ve`;oh>cI00?ogo;Kon7_f_oOm=/00_oLn=d0
0ooGnmgod_gNolgng`02olOnh005ol;mh_nan^?o[oWWojkhjonfn>h00_ndm_401_ncloCo/^ofok;/
monbk?Oo]N[gok?Vm`;o/^7g00Co]=ofok;KmOnbfoGo/mWd0_nae_<00onbe?;o/=7aok3Al@02ok3?
l0;o[lg_00Co[lc^ojk9k_n^bNko[/S]1?n]a^`01On]aN_o[<C[ojc4jon/`n_o[<;Z00?oZl7Z00?o
Zl7Yoj_0jOn[`>T00_n[`>T2oj^oj@CoZ[oY00Co0000ojZnj?nZ_^SoZ[kX4Oooool00ol0003ooooo
ooooo`0=ooooo`002Oooool01000003oooooooooooooool803<c<`030000001<C4`0C4a<00T0C4a<
0P00000<06IVIP<00000:P1oOgl2000000`0IVIV00<0000004a<C01<C4`02P1<C4`00`000000<c<c
03<c<`0<03<c<`030000000I6AT06ATI01406ATI80000004ooooo`0300000?oooooooooo013ooooo
00?o0000ooooooooool01_ooool3o`0000gooooo00Co03ffo`1GdOlYK=co:FcL0_ljLmh00omHO=_o
Ih;JofN2fP02ogB8f0;oPHgF0_n<TM<2oiFDd0CoWIS>0onUV//00on[WLSo[:7<ok6Sb@03ok6Sb@03
okJUaonhZ/_o^:[;00?o_J_81?o3/LT01?o6//OobKS:olVhb_o9^<X3oljnb`;odLG?00KodlG<omK<
cooFc<ooe/c?omWDdooJd]02omgId`;og^7G00?ogmkDon7VeooPk=T00_oPk=T00ooOl]_og?SLomSk
g@02om;mg@0:olcngOnno]go__kMokWmg_ndnn3o/O[Sojoiion^n>_o[OK_ojkdl`;o[_7f0_n^kOP0
1Onbk?Oo/NOhok3Sn?n`hoSo/^7g00;o/Mgf00Co/]_eok7Gm?naeoCo/MKc0_n`d_800on`dO7o[lk`
ojo>l002ojo=k`;o[/_^00?o[/W^ojg7kOn]and00on]a^`3ojc4j`;o[<?[0_n/`^X00on[`N[oZl7Y
oj_1j@02oj_0j@?oZkoY0onZ_nT3ojZnj003o`000?oooooooooo017ooooo00?o0000ooooooooool0
3Oooool000Wooooo00@00000oooooooooooooooo2@0c<c<00`000000C4a<04a<C00:04a<C0800000
3@1VIVH4000002@0Ogmo0P00000=06IVIP030000001<C4`0C4a<00X0C4a<00<0000003<c<`0c<c<0
300c<c<00`0000006ATI01TI6@0A01TI6B4000001?ooool00`00003oooooooooo`0@ooooo`03o`00
0?oooooooooo00?ooooo0ol0000Aooooo`;o04c80_lYK=`00oljLmkoC7_Oodakg`02ofN2fP;oM8SH
0_n1SMH2ohbAd`;oUIC@0onMV<h2ojFJb`04ojFNcon/XLco[:7<ojbQc0;o/J?900?o/jS=okRZbonh
Z//00_nhZ//00onmZlSo_k7<oknac002ol>ab@04olJhcOo9^<[obKS:olVhbP;oc;k>00Coc[k;om75
cooAaLoodLG?0ooFc<l2omWDd`03om_LeooMfM?og^7G00;og^7G00OognWJomk`g?oNl=coh>cIomob
fooLn=cof?_M00;od_gM00[oc?kMok;kf?n/nMSoYoSJojGgg_nTmn?oY?KXojGekOnVlo;oZ?7f0onY
k_P01_n^kOSo[^WiojkTnOn^i?Wo/>?hok3Nm`;o[m[f00Co/=WeojoEm?n_eOCo/=Cc0_n_d?800on_
co7o[/g`ojk=l002ojk<k`;o[/_^00?o[LS^ojg7kOn]and00_n]a^`2ojg5k004ojc4jon/`n_o[<?[
ojc3j`;oZl;Z0_n[`NX00on[`NWoZl3Yoj_0j@02oj_0j@04oj^ojOnZ_nWoZ[oYojZoj@Gooooo00?o
0000ooooooooool04?ooool00ol0003oooooooooo`0=ooooo`002Oooool01000003ooooooooooooo
ool:03<c<`03o`0000000000C4a<00/0C4a<00?o00000000001VIVH03P1VIVH01?l0000000000000
0000000M07moO`<000003P1VIVH00`000000C4a<04a<C00:04a<C0030000000c<c<0<c<c00`0<c<c
00<0000001TI6@0I6AT04@0I6ATR000000Cooooo00<00000ooooooooool03oooool01?l0003ooooo
ooooooooool3o`0001Gooooo00?o04c8o`1Cc_l0Dlh00_ljLmh00om<NmooGH?Ooef3g`02ogB8f0;o
PHgF0on<TM<2oiFDd003oifHc_nMW=;oYIk?00?oYIk?0_n/XL`01?naXlWo/jS=ok>XcOncZ<d2okRZ
b`05ok^`cono/Lco_k7<oknac?o3/LT00oo6^<d01?o9^<[oc;k>olbnc_o<_/h3om75c`;oe<gB00Go
e/c?omWDdooIe=?ofMCCom_Le`02omgTfP04omkQeooOjM[og_3Lomk`g0;og?KM00gof?_Nom;ngOo:
omco`_kJok[mf?nbnmSoV?;CoiKbeonFl]coV?;Soi_cjOnNl_3oXO7d00;oY>kh0_nYk_P01On[j_Wo
ZnKjoj_Vn_n^i?Wo[^3h00;o[]cg00Co[m[fojkFmOn^e_Go[mGd0_n^d_<01?n_d?;o[/k`ojk>l?n^
cO02ojg:k`;o[LW^00?o[LS^ojg6kOn]a^d00_n]a^`2ojc4k0;o[<C[00Go[<?[oj_2j_n[`^[oZl;Z
oj_1jP04oj_0j@GoZ[oY2?ooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo00gooooo
0009ooooo`0400000?ooooooooooooooo``0<c<c00<0000004a<C01<C4`02`1<C4`00`000000IVIV
06IVIP0@06IVIP<000005`1oOgl200000003o`00001VIVH0IVIV00d0IVIV00<00000o`00001<C4`0
2`1<C4`00`00003o000003<c<`0<03<c<`03o`00000I6AT06ATI01806ATI00?o0000000000000000
7`000004ooooo`0300000?oooooooooo00oooooo1?l0000Iooooo`06o`0YUol0Dlko05gEo`1MeOlW
Kmoo>gWR0_mMPml2off9g@;oNhoK0_n8U=T2oi>HeP?oWIcB0onUW/l00on/XLco[JKAojfVd@03ok>X
c@05okRZbonk/<oo^k3?ok^`cono/L`00_o2]m03olJhc@;obKoA00Coc;k>olo6d_o?a];odLG?0ooD
cM82omOFe`04omWDdooKg=OofmcGomgTfP;ogNcM00OofoCOomk`g?oLm]gog?KMomSkg_oBo]gob_oL
00;oZoWB00SoW??AoiSbdon6jmGoR^gMoho_iOnDl>goVNocoik]m`;oX^_j00?oY^_jojSVnonXi_/0
0_nYh_X01?n/hOWo[=chojcLn?n^g?L2ojgGmP04ojkFmOn^do?o[]?cojkBl`;o[Loa00Co[/k`ojg;
kon]bnoo[L[_0_n]b>h2ojg7k@03ojg6kOn/aNco[<G/00;o[<C/1?n[`n/00on[`^[oZl7Zoj_1jP02
oj_1jP?oZl3Y00?oZ[oYooooooooool02_ooool00ol0003oooooooooo`0?ooooo`03o`000?oooooo
oooo00gooooo0009ooooo`0400000?ooooooooooooooo`d0<c<c00<0000004a<C01<C4`02`1<C4`2
000001<0IVIV0`00000=07moO`L00000401VIVH2000000d0C4a<00<0000003<c<`0c<c<03@0c<c<0
0`0000006ATI01TI6@0B01TI6B8000001?ooool00`00003oooooooooo`0?ooooo`;o00007Oooool0
1Ol0=:Wo05gEoa1Yg?l@JMco>gWR00;oD8?T0_m]RMd2og^?f`;oR9CI0_nCV=H3oifLdP03ojFNconU
Y=Co[JKA00?o[JKA00?o/jS=okF^d_ne[]800onk/<l4ol:gd004olJhcOo9_m7obKoAolc7eP?oclKB
0_oBcmH00ooDcM;oemKGomOFe`02omWNf`03om_LeooMi=[ogNcM00;ogNcM00KofoCOomOjgooAoMko
dOgNolSng?ndo=D2oj_idP07ohGYbOmeh/coNnGFoh;Yh?n9k>WoTNgaoiO/m`02oicZnP03oj;[n_nT
io_oY^;k00;oY^;k00GoZN;joj[MnOnZgOWo[=chojcHm`02ojcDm@;o[M?d00Co[]?cojg?l_n]co;o
[Loa0_n]c?001?n]bnoo[<W^ojc9k_n]b>h2ojc6k@?o[<G/0_n/a>/00on[`n_oZl;[oj_2jP03oj_2
jP03oj_1j_n[`NWoZl7Y00?oZl3Y3oooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo
00cooooo0009ooooo`0400000?ooooooooooooooo`h0<c<c00?o000004a<C01<C4`0301<C4`20000
01@0IVIV3@00000F06IVIP030000001<C4`0C4a<00`0C4a<00<0000003<c<`0c<c<03@0c<c<00`00
00006ATI01TI6@0B01TI6B<000001?ooool00`00003oooooooooo`0Aooooo`03o`000?oooooooooo
01cooooo00Go03^_oa1Yg?lVM^?o9WKSoe23i002of>;h`;oM9;R0_n4V=l3oi6Mg0;oW:7H0onUY=@2
ojfVd@03ojj]e_ne[];o]JkB00;o]JkB00?o^k3?okfgdonm]m<00_o2]m02olBoe@05olVodOo<amKo
c<OFolc7e_o?a]800_oBcmH2omCHf`05omOFeooIg]_ofMkKomWNfooJj=h00_oIl>400ooMk=gofoCO
omOjg`02om7mgP04olSng?nGlLWoUo79oho]a`;oJ]c>00GoM>;JogkWiOn7jNooT>[foiOYnP02oicV
o003oj7Vo?nTh_coY]kk00;oY]kk00CoZ=kjojWInOnYfOWoZ]Wh0_n[eOH01?n/e?Go[=7cojcAlon/
d?<4ojc=l@04ojg<l?n/bNoo[<W_ojc9kP;o[<O]00?o[<K]oj_5k?n[aN`00_n[a>`00on/a>_oZl;[
oj_2j`02oj_2j`;oZl;Z00?oZl7Zoj_1jOn[`NT05?ooool00ol0003oooooooooo`0>ooooo`03o`00
0?oooooooooo00cooooo0009ooooo`0500000?ooooooooooooooo`0000003P0c<c<2000000h0C4a<
0`00000b06IVIP0300000?l00000C4a<00d0C4a<00<0000003<c<`0c<c<03@0c<c<00`0000006ATI
01TI6@0B01TI6B@000001?ooool00`00003oooooooooo`0Booooo`03o`000?oooooooooo01cooooo
00?o04Jio`1PeOlVM^<00_lnP^L2of>;h`;oM9;R0_n4V=l3oi6Mg0;oW:7H00?oYJCDojFZf_nUZ]X0
0on^[MH2okF^dP05okNff?nm]m?o_KOCokfgdono_mT00oo4_mD01_o7b=[oc<OFolc7e_o<amKoc]3K
om;?eP?oe=SK0_oFh]l01?oIg]_of^SNomW`hOoIl>42omKghP04om3lh_o7o]ko^ogJojoje0;oMn2j
00CoFM;5ofKKgOmehN[oPNGc0_n<iOX01OnAio[oV>GloigRoOnMh_goX>;l00;oXmkk0_nVg_/2ojOJ
n@04ojWInOnYeOOoZMGgoj_EmP;oZm7d00Co[=7coj_>l_n[c_;o[<ga0_n[bo000on/b^ooZlS^oj_8
kP02ojc7kP04ojc7kOn[aNgoZlG]oj_5k0CoZl?[00?oZl;[oj_1j_n[`NX00on[`NXHooooo`03o`00
0?oooooooooo00gooooo00?o0000ooooooooool03?ooool000Wooooo00H00000oooooooooooooooo
01TI6@00000?03<c<`8000003`1<C4`2000002h0IVIV0P00000?04a<C0030000000c<c<0<c<c00d0
<c<c00<0000001TI6@0I6AT04`0I6ATT000000Cooooo00<00000ooooooooool04oooool00ol0003o
ooooooooo`0Looooo`03o`16^Ol0H=Go3FoO00;o?X;W0_mFSNT01_m[U^WoQ9SOohBHgon4V=ooTIgL
ohjSh`?oVjOO0onUZ]X00on^[MKo[kCLojndg003okNff005okfgdono_mWo_koIoknofOo4_mD00oo7
b=X00oo<amKoc]3Kolk@f`02om3Jh003omCHfooFh]ooe^;O00;oe^_S00WodoCVomW`hOoFmn;oe_OR
om3lh_o7o]koV_;<ohc[a?mMcj`00_mKe=X00om/gNSoNn;cohOSnP02oi3Ro@05oiCToOnJhOgoW]gm
oikMoOnQgO`00_nSfO/2ojGJnP;oYmKh00CoZ=KgojSBm_nXd_KoZM;e0_nZc_<3oj_>lP?oZl_`0_n[
b>l00on[b>koZlK]oj_6k@03oj_5k@;oZlC/0on[`n/2oj_2j`03oj_1j_oooooooooo01[ooooo00?o
0000ooooooooool03Oooool00ol0003oooooooooo`0<ooooo`002Oooool01000003ooooooooooooo
ool201TI6@030000000c<c<0<c<c00h0<c<c00<0000004a<C01<C4`03P1<C4`2000002T0IVIV0`00
000@04a<C0030000000c<c<0<c<c00d0<c<c00<0000001TI6@0I6AT04`0I6ATU000000Cooooo00<0
0000ooooooooool05?ooool2o`0001kooooo00Co05C6o`e_golXOnSo:7oX0_mFSNT00om[U^WoOYgV
ogjMiP03ohjSh`?oVjOO00?oYJ[JojFbh_n_]=`00on_]=`00ong]]So^;kNoknof@02oknof@04ol78
h?o7b=[oalSJolO8fP;obM;P00?oc]3Kom3Jh?o@f^000_oAiND00ooFh]ooe^_SomK[h`02om?diP05
olkji_o4oN?o^?cMojWhe?mag;H00_mMe>H01Om_fo;oO]kjohWOoOn9gogoSN7m00;oU=kn00CoUmon
oicLoOnLg?goW]gm0_nRfO/01OnSfO_oYMKiojGFnOnUe_WoYmKh00;oYm;f00CoZ=;fojW?m?nYcoCo
Z/kc0_nZc?42oj[;l@04oj_;l?n[b>ooZlS_oj_8k`;oZlK^00?oZlK]oj_4k?n[a>`00on[a>`5oj_2
jaoooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0<ooooo`002Oooool01000003o
ooooooooooooool301TI6@8000003`0c<c<200000100C4a<0P0000000ol00000IVIV06IVIP0R06IV
IP800000401<C4`00`00003o00000000000?03<c<`03o`00000I6AT06ATI01<06ATI9P000004oooo
o`0300000?oooooooooo01Kooooo00?o0000ooooooooool07Oooool01?l0IMCo:7oXobQoj?m4SNd2
oejJk`;oOYgV0_n>Xn<2oi^Wg`04oiR_ionU/^;oYK;RojFbhP;o[kCL00Go[kgTokRng_nh_]ko^;kN
oknof@03ol78h006olO8f_o9d^3obM;PolWBh?o:g>Kod=[P0ooAiND01Oo?k^WoboOZol_gj_oCm>Ko
c_[V00;oXoOH00KoP>G0ofSFm?mif__oNM[kog_Ln_n7gOh2oi3Ko`04oi;Mo_nHf_goV=[moi[Ko@;o
W]Ol00?oX=Skoj?DnOnSe?T00_nTeOT2ojGAm`03ojKBmonWc_CoYlkd00;oZ<od00CoZLodojW<l_nY
c?;oZ/ca0onZbO02oj[7kP;oZ/K^00GoZlK^oj_4kOn[a>goZlC/oj[3k003oj_3j`03oj_2jooooooo
oooo02;ooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0<ooooo`002Oooool01000
003oooooooooooooool501TI6@030000000c<c<0<c<c00h0<c<c0P00000A04a<C0<000007`1VIVH0
0`00003o000004a<C00@04a<C0030000000c<c<0<c<c00l0<c<c00<0000001TI6@0I6AT0500I6ATV
000000Cooooo00<00000ooooooooool05oooool00ol0003oooooooooo`0Mooooo`04oe`00?l=N>;o
;H_]obf;k@;oGY[_0_meXnh3ohVZj`;oV:oW00?oYK;RojBkj_nT^nX00on__N@01Onh_]ko^LSVokW8
i_nib>Ko`LSP00?o`]?W00?obM;Pol[Li_o:g>H00_o9in`01_oAiNGocnkYol_gj_o;mn[o`O_XokCk
hP;oXoOH0_n5f?l01?n5fOooS]SoohkHoon?f_l2oiKGoP04oiOIo_nLeOcoW=GloigFo0;oX=?j0_nQ
e?T01OnSe?WoY=7gojCAmonTdOOoYM7g00;oY/ke00CoYlkdojS<l_nXc?;oZ<cb1?nYbO001?nZbO3o
Z/O_oj[7konZanh4oj[5k@03oj_4kOnZ`ncoZ/?/00;oZ/?/00?oZl?[ooooooooool09Oooool00ol0
003oooooooooo`0:ooooo`03o`000?oooooooooo00cooooo0009ooooo`0400000?oooooooooooooo
o`H06ATI00<0000003<c<`0c<c<03`0c<c<200000180C4a<1`00000A06IVIPL000004P1<C4`00`00
0000<c<c03<c<`0?03<c<`030000000I6AT06ATI01@06ATI9`000004ooooo`0300000?oooooooooo
01Sooooo00?o0000ooooooooool07_ooool01Ol0B:Wo;H_]obf;kOl]RngoC9_d00;oJJSf0_n1/O@3
oiBhk`?oY;_Z00Go[kgTojo8k?n_b>co[lS/okW8iP02okWCkP;o`]?W0_o2g^d00oo:g>KobNO/olWW
k002olKak`03okghk_n`nNSo/?WX00;oR>_?00CoQMKoohkDoon>e?ooS]Ko0_nEe?d00onEe_goV]?k
oi[Cn`02oi_Do004oicEo?nOd_WoWm;ioj3CnPCoXm3g0_nUcOD00onVc_GoYl_cojO;l`02ojO;l`04
ojS<l_nXbO7oZ<WaojW9l0CoZLO_00CoZ/O_oj[5kOnZaNgoZ/G]1OnZ`n`[ooooo`03o`000?oooooo
oooo00_ooooo00?o0000ooooooooool02oooool000Wooooo00@00000oooooooooooooooo1`0I6AT0
0ol00000<c<c03<c<`0@03<c<`030000001<C4`0C4a<01H0C4a<4@00000H04a<C0030000000c<c<0
<c<c00l0<c<c00<0000001TI6@0I6AT05@0I6ATW000000Cooooo00<00000ooooooooool06Oooool2
o`00023ooooo00Co05jmoa24iOl@Q>Go=9[b0_mYZ?H2oh6am003oiBhkon=`OSoSL7h00?oX<Gc0_n_
b>`2ojcCm005okWCk_nfgoCo]]odokKOm?o2g^d00_nojO82okObm007olKakonmn>ko/?WXok3ij?mX
fL7oT=7nohoCoP02oiKAo003oiGBoOnJd?_oV]3k00;oV]7k00GoV]?koik@nOnNd?WoW]3ioioAn@02
oj7>m`03oj;?monTc?GoY<ce00;oY<ge00CoYLgeojK;lonVbo?oYl_c0_nWb?43ojS9l@?oZLO_1?nY
aNh01?nZaNgoZ/C/oj[4k?nZ`n``ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool0
2oooool000Wooooo00@00000oooooooooooooooo1`0I6AT200000180<c<c0P00000l04a<C0030000
0?l0000000000140<c<c00<0000001TI6@0I6AT05@0I6ATX000000Cooooo00<00000ooooooooool0
6oooool00ol0003oooooooooo`0Pooooo`;o07OB0_mF[?T3ogBin`;oSL7h00GoX<Gcoi[@nonJd?_o
V]3kojcCm002ojGNn`;o]]od00Ko[nWioj;_monRkoOoX^ogokObm?nZmO02oiObi@04oiS<n_nGc__o
UlkkoiK?o0?oVlgi00?oV/kjoi[@nonNcOP00_nNcOP00onNcoWoXLcfoj7<mP02oj7=m`04oj7>monS
boCoXl_dojC<m@;oYLWc00?oY/[cojK8lOnVb?400onWb?42ojS6k`;oZ<O_00CoZLO_ojW5k_nYaNko
ZLG^1?nYa>d00onZa>coooooooooo`0aooooo`03o`000?oooooooooo00Wooooo00?o0000oooooooo
ool02oooool000Wooooo00@00000oooooooooooooooo2@0I6AT00`000000<c<c03<c<`0A03<c<`80
0000>01<C4`2000001<0<c<c00<0000001TI6@0I6AT05@0I6AT00ol0000000000000000V000000Co
oooo00<00000ooooooooool07?ooool00ol0003oooooooooo`0Rooooo`03o`23colmZ_Go?J[e00;o
H[cm0_n1bOh2oi[@n`;oS]So00?oYMkkoiWUo?nIiO`00_n5i_D2oj;_m`03oho]kOmfhmcoV/Wh00;o
VL_i00CoV<cjoic:monLb_OoVlch0_nNb_H2oik;m`03oik<n?nQb_GoXL[e00;oXL_f00CoXLcfoj?:
m?nSb_CoXl_d0_nUb?82ojG9lP04ojG9lonVao7oY/OaojK8l@CoYlK_00CoZ<K_ojS5k_nXaNkoZ<G^
0_nY`nd3ojW4kCSooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`0;ooooo`002Ooo
ool01000003oooooooooooooool:01TI6@8000004`0c<c<3000003<0C4a<0P00000C03<c<`800000
5`0I6ATZ000000Cooooo00<00000ooooooooool07Oooool00ol0003oooooooooo`0Uooooo`?oB;[f
00?oKlgnoeC8lomDb?<00_mkfo/01OmPe>go@/CCod;4dolU[kGoWLOe00;oVlSf00CoV/Whoig8mOnM
b?GoWLWf0_nOao@2oio8m@03oik:m_nQb?CoXLSd00;oXLWd00CoXL[eoj?8lonSb??oXlWc1?nTao80
0onUb?;oY/K`ojK6l003ojK7l@?oYlK_0_nXa>h3ojS5kP;oZ<?]00?oZL?]ooooooooool0>_ooool0
0ol0003oooooooooo`08ooooo`03o`000?oooooooooo00_ooooo0009ooooo`0400000?oooooooooo
ooooo``06ATI0P00000D03<c<`04o`00000000000000000002`0C4a<0`00000D03<c<`030000000I
6AT06ATI01H06ATI:`000004ooooo`0300000?oooooooooo01kooooo0_l0000^ooooo`03oik6m?nP
a?;oX<Cb00;oWlGc00?oW/Odoj75l_nQaO800_nPa_<00onOaoCoX/Kboj;6lP02oj77l`04oj78m?nS
a_;oXlKboj?7lP;oY<Ga0_nTa_400onTao;oYLG`ojG5l002ojG6l004ojK6l?nVaNooY/G_ojO5k`Co
YlC^00?oZ<C^ojS3kOnX`nd00onX`ndoooooo`03o`000?oooooooooo00Oooooo00?o0000oooooooo
ool02oooool000Wooooo00@00000oooooooooooooooo3P0I6AT2000001H0<c<c0`00000X04a<C003
0000000c<c<0<c<c01@0<c<c00?o000001TI6@0I6AT05P0I6AT/000000Cooooo00<00000oooooooo
ool08?ooool00ol0003oooooooooo`0/ooooo`03oj34l_nR`o3oX/?`00;oX/Ca00?oXLGboj?4lOnS
a?400_nRaO401?nRa_;oXlC`oj?4l?nSaO42ojC4l0;oY<G`00?oY<GaojG4konUa>l00_nUaNl00onU
aO3oY/C^ojK4kP02ojK4k`04ojK5konW`nkoYl?^ojO4kP;oZ<;]0onX`ne4ooooo`03o`000?oooooo
oooo00Oooooo00?o0000ooooooooool02_ooool000Wooooo00@00000oooooooooooooooo400I6AT0
0`000000<c<c03<c<`0F03<c<`<000008P1<C4`3000001H0<c<c00<0000001TI6@0I6AT05P0I6AT]
000000Cooooo00<00000ooooooooool08Oooool00ol0003oooooooooo`0/ooooo`03oj;3l?nT`noo
Y<?_00;oXl?`00?oXlCaojC3konT`nl00_nTa?001?nSa?3oYL?_ojG3konTa?02ojK3kP;oYL?_00?o
YLC_ojK3k_nV`nh00_nV`nh00onVa>koYl?]ojO3k@02ojO3k@04ojO3k_nX`^goZ<;]ojS2kDWooooo
00?o0000ooooooooool01_ooool00ol0003oooooooooo`0:ooooo`002Oooool01000003ooooooooo
oooooolA01TI6@03o`00000c<c<0<c<c01P0<c<c0`00000L04a<C0<00000600c<c<00`0000006ATI
01TI6@0G01TI6Bd000001?ooool00`00003oooooooooo`0Rooooo`03o`000?oooooooooo02gooooo
00GoY<?_ojG2k_nU`^koY<;_ojC3k`02ojG2kP03ojG3k_nV`^goY/;]00;oY/;^00?oY/?^ojK2kOnV
`^d00_nV`^d00onV`nkoYl;]ojO2k@02ojO2k@04ojO3kOnW`^coYl;/ojS2k4gooooo00?o0000oooo
ooooool01_ooool00ol0003oooooooooo`0:ooooo`002Oooool01000003ooooooooooooooolB01TI
6@8000006`0c<c<00ol00000000000000005000000d0C4a<1`00000H03<c<`0300000?l000000000
01T06ATI;P000004ooooo`0300000?oooooooooo02?ooooo00?o0000ooooooooool0;Oooool01?nU
`^koY/7]ojK1kOnU`^d2ojK1k0;oY/7]00GoY/;]ojO1k?nW`NcoY/7]ojK2k@04ojO1k003ojO2kOnW
`NcoYl7/00;oYl7/00?oYl;/ooooooooool0C_ooool00ol0003oooooooooo`05ooooo`03o`000?oo
oooooooo00[ooooo0009ooooo`0400000?oooooooooooooooa@06ATI0P00000Q03<c<`d000007P0c
<c<00`0000006ATI01TI6@0I01TI6Bl000001?ooool00`00003oooooooooo`0Tooooo`;o0000;_oo
ool01?nV`NgoYl3/ojO0k?nV`N`2ojO0k0?oYl7/0_nW`>/3ojO1k0;oZ<3[0_nW`NaEooooo`03o`00
0?oooooooooo00Cooooo00?o0000ooooooooool02_ooool000Wooooo00@00000oooooooooooooooo
5P0I6AT2000004P0<c<c0P00000K01TI6C0000001?ooool00`00003oooooooooo`0Vooooo`03o`00
0?oooooooooo02cooooo00CoYl3/ojO0jonW`>_oYl3/0_nW_n/3ojO0j`;oZ;o[0onX`>]Hooooo`03
o`000?oooooooooo00Cooooo00?o0000ooooooooool02_ooool000Wooooo00@00000oooooooooooo
oooo600I6AT2000004@0<c<c0P00000L01TI6@03o`0000000000000002h000001?ooool00`00003o
ooooooooo`0Wooooo`03o`000?oooooooooo02gooooo0_nX_n/00onW_n_oZ;oZojRojP03ojRojego
oooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0:ooooo`002Oooool01000003ooooo
oooooooooolJ01TI6@030000000c<c<0<c<c03l0<c<c0P00000M01TI6C8000001?ooool00`00003o
ooooooooo`0Xooooo`03o`000?oooooooooo02gooooo0onX_nYRooooo`03o`000?oooooooooo00?o
oooo00?o0000ooooooooool02Oooool000Wooooo00@00000oooooooooooooooo6`0I6AT3000003d0
<c<c00<0000001TI6@0I6AT0700I6ATc000000Cooooo00<00000ooooooooool0:Oooool2o`0002go
oooo00?o0000ooooooooool0Hoooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Wo
oooo0009ooooo`0400000?oooooooooooooooah06ATI0`00000h03<c<`8000007P0I6ATd000000Co
oooo00<00000ooooooooool0:oooool00ol0003oooooooooo`0Zooooo`03o`000?oooooooooo06?o
oooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`09ooooo`002Oooool01@00003ooooo
ooooooooool0000002006ATI00Co00000000000000000000<00c<c<01000003o000000000000000O
01TI6@03o`00000000000000038000001?ooool00`00003oooooooooo`0/ooooo`03o`000?oooooo
oooo02Wooooo00?o0000ooooooooool0I?ooool01Ol0003ooooooooooooooooo000000_ooooo0009
ooooo`0400000?ooooooooooooooo`8000008`0I6AT4000002T0<c<c0`00000R01TI6CH000001?oo
ool00`00003oooooooooo`0]ooooo`03o`000?oooooooooo02Sooooo00?o0000ooooooooool0IOoo
ool01?l0003oooooooooool0000;ooooo`002Oooool01000003oooooooooooooool3000002H06ATI
0`00000R03<c<`@000008`0I6ATh000000Cooooo00<00000ooooooooool0;_ooool2o`0002Sooooo
00?o0000ooooooooool0I_ooool00ol0003oooooo`00000;ooooo`002Oooool01000003ooooooooo
ooooool300000003o`0000000000000002H06ATI1000000J03<c<`0400000?l000000000000002D0
6ATI>P000004ooooo`0300000?oooooooooo033ooooo00?o0000ooooooooool09Oooool00ol0003o
ooooooooo`1Vooooo`03o`000?oooooo000000_ooooo0009ooooo`0400000?ooooooooooooooo`L0
0000:@0I6AT:000000H0<c<c2P00000X01TI6C/000001?ooool00`00003oooooooooo`0aooooo`03
o`000?oooooooooo02Cooooo00?o0000ooooooooool0Ioooool00ol0003oooooo`00000:ooooo`00
2Oooool01000003oooooooooooooool8000003806ATI1P00000a01TI6C`000001?ooool00`00003o
ooooooooo`0booooo`03o`000?oooooooooo02?ooooo00?o0000ooooooooool0J?ooool2o`0000[o
oooo0009ooooo`0400000?ooooooooooooooo`T00000I`0I6ATm000000Cooooo00<00000oooooooo
ool0<oooool2o`0002?ooooo00?o0000ooooooooool0Ioooool3o`0000[ooooo0009ooooo`040000
0?ooooooooooooooo`T0000000?o0000000000000000HP0I6ATo000000Cooooo00<00000oooooooo
ool0=Oooool00ol0003oooooooooo`0Pooooo`03o`000?oooooooooo06?ooooo1?l0000=ooooo`00
2Oooool01000003oooooooooooooool>000005h06ATI@@000004ooooo`0300000?oooooooooo03Ko
oooo00?o0000ooooooooool07oooool00ol0003oooooooooo`1Pooooo`?o00004Oooool000Wooooo
00@00000oooooooooooooooo4000001K01TI6D8000001?ooool00`00003oooooooooo`0gooooo`03
o`000?oooooooooo01kooooo00?o0000ooooooooool0G?ooool4o`0001Cooooo0009ooooo`040000
0?oooooooooooooooa00000000?o000001TI6@0I6AT0EP0I6AT00`00003o000000000011000000Co
oooo00<00000ooooooooool0>?ooool2o`0001kooooo00?o0000ooooooooool0F?ooool4o`0001So
oooo0009ooooo`0400000?oooooooooooooooa<00000E00I6AU6000000Cooooo00<00000oooooooo
ool0>_ooool00ol0003oooooooooo`0Kooooo`03o`000?oooooooooo05Cooooo1?l0000Looooo`00
2Oooool01000003ooooooooooooooolD000005406ATIB0000004ooooo`0300000?oooooooooo03_o
oooo00?o0000ooooooooool06_ooool00ol0003oooooooooo`1Aooooo`?o00008?ooool000Wooooo
00@00000oooooooooooooooo5`00001=01TI6DT000001?ooool00`00003oooooooooo`0looooo`03
o`000?oooooooooo01Wooooo00?o0000ooooooooool0COooool4o`0002?ooooo0009ooooo`040000
0?oooooooooooooooaL0000000Co00000000000000000000A@0I6AT300000003o`00000000000000
04L000001?ooool00`00003oooooooooo`0mooooo`;o00006Oooool00ol0003oooooooooo`19oooo
o`Co00009oooool000Wooooo00@00000oooooooooooooooo7@00001101TI6Dl000001?ooool00`00
003oooooooooo`0oooooo`03o`000?oooooooooo01Kooooo00?o0000ooooooooool0AOooool4o`00
02_ooooo0009ooooo`0400000?oooooooooooooooal00000?@0I6AUA000000Cooooo00<00000oooo
ooooool0@?ooool00ol0003oooooooooo`0Dooooo`03o`000?oooooooooo04?ooooo0ol0000_oooo
o`002Oooool01000003ooooooooooooooolO00000003o`0000000000000003H06ATIE@000004oooo
o`0300000?oooooooooo047ooooo00?o0000ooooooooool04oooool00ol0003oooooooooo`0ooooo
o`Co0000<_ooool000Wooooo00@00000oooooooooooooooo9@00000`01TI6EP000001?ooool00`00
003oooooooooo`12ooooo`;o00004oooool00ol0003oooooooooo`0kooooo`Co0000=_ooool000Wo
oooo00@00000oooooooooooooooo;000000V01TI6E/000001?ooool00`00003oooooooooo`14oooo
o`03o`000?oooooooooo013ooooo00?o0000ooooooooool0=oooool4o`0003[ooooo0009ooooo`04
00000?ooooooooooooooobl000007@0I6AUQ000000Cooooo00<00000ooooooooool0AOooool00ol0
003oooooooooo`0?ooooo`03o`000?oooooooooo03?ooooo1?l0000nooooo`002Oooool01000003o
ooooooooooooool_00000003o`0000000000000000P000002P0I6AT800000003o`00000000000000
05h000001?ooool00`00003oooooooooo`16ooooo`03o`000?oooooooooo00kooooo00?o0000oooo
ooooool0<?ooool3o`0004;ooooo0009ooooo`0400000?ooooooooooooooojd000001?ooool00`00
003oooooooooo`17ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool0;?ooool4o`00
04Gooooo0009ooooo`0400000?ooooooooooooooojd000001?ooool00`00003oooooooooo`18oooo
o`;o00003Oooool00ol0003oooooooooo`0Xooooo`Co0000BOooool000Wooooo00@00000oooooooo
oooooooo[@000004ooooo`0300000?oooooooooo04[ooooo00?o0000ooooooooool02_ooool00ol0
003oooooooooo`0Tooooo`Co0000COooool000Wooooo00@00000oooooooooooooooo[@000004oooo
o`0300000?oooooooooo04_ooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`0Qoooo
o`?o0000DOooool000Wooooo00@00000oooooooooooooooo[@000004ooooo`0300000?oooooooooo
04cooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`0Mooooo`Co0000E?ooool000Wo
oooo00@00000oooooooooooooooo[@000004ooooo`0300000?oooooooooo04gooooo0_l00008oooo
o`03o`000?oooooooooo01Wooooo1?l0001Hooooo`002Oooool01000003ooooooooooooooon]0000
00Cooooo00<00000ooooooooool0Coooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo
01Gooooo1?l0001Looooo`002Oooool01000003ooooooooooooooon]000000Cooooo00<00000oooo
ooooool0D?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo01;ooooo0ol0001Poooo
o`002Oooool01000003ooooooooooooooon]000000Cooooo00<00000ooooooooool0DOooool00ol0
003oooooooooo`03ooooo`03o`000?oooooooooo00kooooo1?l0001Sooooo`002Oooool01000003o
oooooooooooooon]000000Cooooo00<00000ooooooooool0D_ooool2o`0000?ooooo00?o0000oooo
ooooool02_ooool4o`0006Oooooo0009ooooo`0400000?ooooooooooooooojd000001?ooool00`00
003oooooooooo`1Dooooo`04o`000?ooooooooooo`0000Sooooo1?l0001[ooooo`002Oooool01000
003ooooooooooooooon]000000Cooooo00<00000ooooooooool0EOooool00ol0003oooooo`000005
ooooo`?o0000Koooool000Wooooo00@00000oooooooooooooooo[@000004ooooo`0300000?oooooo
oooo05Kooooo0_l000000ooooooo0000o`000002o`0007;ooooo0009ooooo`0400000?oooooooooo
ooooojd000001?ooool00`00003oooooooooo`1Gooooo`;o0000M_ooool000Wooooo00@00000oooo
oooooooooooo[@000004ooooo`0300000?oooooooooo0<oooooo0009ooooo`0400000?oooooooooo
ooooojd000001?ooool00`00003oooooooooo`3?ooooo`002Oooool01000003ooooooooooooooon]
000000Cooooo00<00000ooooooooool0coooool000Wooooo00@00000oooooooooooooooo[@000004
ooooo`0300000?oooooooooo0<oooooo0009ooooo`0400000?ooooooooooooooojd000001?ooool0
0`00003oooooooooo`3?ooooo`002Oooool01000003ooooooooooooooon]000000Cooooo00<00000
ooooooooool0coooool000Wooooo00@00000oooooooooooooooo[@000004ooooo`0300000?oooooo
oooo0<oooooo0009ooooo`0400000?ooooooooooooooojd000001?ooool00`00003oooooooooo`3?
ooooo`002Oooool01000003ooooooooooooooon]000000Cooooo00<00000ooooooooool0coooool0
00Wooooo00@00000oooooooooooooooo[@000004ooooo`0300000?oooooooooo0<oooooo0009oooo
o`0400000?ooooooooooooooojd000001?ooool00`00003oooooooooo`3?ooooo`002Oooool01000
003ooooooooooooooon]000000Cooooo00<00000ooooooooool0coooool000Wooooo00@00000oooo
oooooooooooo[@000004ooooo`0300000?oooooooooo0<oooooo0009ooooo`0300000?oooooooooo
0;;ooooo00<00000ooooooooool0coooool000Wooooo00<00000ooooooooool0/_ooool00`00003o
ooooooooo`3?ooooo`002Oooool00`00003oooooooooo`2booooo`0300000?oooooooooo0<oooooo
0009oooookH00000dOooool00?ooooooTOooool00?ooooooTOooool00?ooooooTOooool00?oooooo
TOooool00?ooooooTOooool00?ooooooTOooool00?ooooooTOooool00?ooooooTOooool00?oooooo
TOooool00?ooooooTOooool00?ooooooTOooool00?ooooooTOooool00?ooooooTOooool00?oooooo
TOooool00?ooooooTOooool00?ooooooTOooool00?ooooooTOooool000Wooooo]_l0000AoooookKo
00002_ooool000Wooooo00?o0000ooooooooool04_ooool00ol00?ooooooooooo`0Qooooo`?o003o
NOooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo0;;ooooo00?o0000ooooooooool0
2?ooool000Wooooo00?o0000ooooooooool04?ooool2o`00obOooooo00?o003oooooooooool0M_oo
ool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo0;;ooooo00?o0000ooooooooool02?oo
ool000Wooooo00?o0000ooooooooool03_ooool2o`00ob[ooooo00?o003oooooooooool0MOooool0
0ol0003oooooooooo`0?ooooo`03o`000?oooooooooo0;;ooooo00?o0000ooooooooool02?ooool0
00Wooooo00?o0000ooooooooool03Oooool00ol00?ooooooooooo`0[ooooo`;o003oMOooool00ol0
003oooooooooo`0?ooooo`03o`000?oooooooooo0;;ooooo00?o0000ooooooooool02?ooool000Wo
oooo00?o0000ooooooooool03?ooool00ol00?ooooooooooo`0^ooooo`03o`00oooooooooooo07;o
oooo00?o0000ooooooooool03oooool00ol0003oooooooooo`2booooo`03o`000?oooooooooo00So
oooo0009ooooo`03o`000?oooooooooo00[ooooo0_l00?lbooooo`03o`00oooooooooooo077ooooo
00?o0000ooooooooool03oooool00ol0003oooooooooo`2booooo`03o`000?oooooooooo00Sooooo
0009ooooo`03o`000?oooooooooo00Wooooo00?o003oooooooooool0<oooool00ol00?oooooooooo
o`1`ooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool0/_ooool00ol0003ooooooooo
o`08ooooo`002Oooool00ol0003oooooooooo`08ooooo`03o`00oooooooooooo03Gooooo0_l00?m`
ooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool0/_ooool00ol0003oooooooooo`08
ooooo`002Oooool00ol0003oooooooooo`07ooooo`03o`00oooooooooooo03Sooooo00?o003ooooo
ooooool0KOooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo0;;ooooo00?o0000oooo
ooooool02?ooool000Wooooo00?o0000ooooooooool01_ooool00ol00?ooooooooooo`0jooooo`03
o`00oooooooooooo06cooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`2booooo`03
o`000?oooooooooo00Sooooo0009ooooo`03o`000?oooooooooo00Kooooo00?o003oooooooooool0
>_ooool00ol00?ooooooooooo`1/ooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool0
/_ooool00ol0003oooooooooo`08ooooo`002Oooool00ol0003oooooooooo`05ooooo`03o`00oooo
oooooooo03cooooo00?o003oooooooooool0Joooool00ol0003oooooooooo`0?ooooo`03o`000?oo
oooooooo0;;ooooo00?o0000ooooooooool02?ooool000Wooooo00?o0000ooooooooool01?ooool0
0ol00?ooooooooooo`0nooooo`03o`00oooooooooooo06[ooooo00?o0000ooooooooool03oooool0
0ol0003oooooooooo`2booooo`03o`000?oooooooooo00Sooooo0009ooooo`03o`000?oooooooooo
00?ooooo00?o003oooooooooool0?oooool00ol00?ooooooooooo`1Zooooo`03o`000?oooooooooo
00oooooo00?o0000ooooooooool0/_ooool00ol0003oooooooooo`08ooooo`002Oooool00ol0003o
ooooooooo`02ooooo`03o`00oooooooooooo047ooooo00?o003oooooooooool0JOooool00ol0003o
ooooooooo`0?ooooo`03o`000?oooooooooo0;;ooooo00?o0000ooooooooool02?ooool000Wooooo
00?o0000ooooooooool00_ooool00ol00?ooooooooooo`11ooooo`03o`00oooooooooooo06Wooooo
00?o0000ooooooooool03oooool00ol0003oooooooooo`2booooo`03o`000?oooooooooo00Sooooo
0009ooooo`05o`000?ooooooooooooooool00?l0AOooool00ol00?ooooooooooo`1Xooooo`03o`00
0?oooooooooo00oooooo00?o0000ooooooooool0/_ooool00ol0003oooooooooo`08ooooo`002Ooo
ool01Ol0003ooooooooooooooooo003o04Kooooo00?o003oooooooooool0Ioooool00ol0003ooooo
ooooo`0?ooooo`03o`000?oooooooooo0;;ooooo00?o0000ooooooooool02?ooool000Wooooo00Go
0000ooooooooooooooooo`00o`16ooooo`03o`00oooooooooooo06Oooooo00?o0000ooooooooool0
3oooool00ol0003oooooooooo`2booooo`03o`000?oooooooooo00Sooooo0009ooooo`04o`000?oo
ooooooooo`00odSooooo00?o003oooooooooool0I_ooool00ol0003oooooooooo`0?ooooo`03o`00
0?oooooooooo0;;ooooo00?o0000ooooooooool02?ooool000Wooooo00Co0000oooooooooooo003o
B?ooool00ol00?ooooooooooo`1Vooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool0
/_ooool00ol0003oooooooooo`08ooooo`002Oooool00ol0003oooooo`00o`1:ooooo`03o`00oooo
oooooooo06Gooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`2booooo`03o`000?oo
oooooooo00Sooooo0009ooooo`03o`000?l00?oooooo00?ooooo0_ooO`0;ooooo`;oogl0>?ooool0
0ol00?ooooooooooo`1Uooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool00oooool2
oomo00_ooooo0_ooO`2Pooooo`03o`000?oooooooooo00Sooooo0009ooooo`03o`000?oooooooooo
00;ooooo0oooO`0;ooooo`;oogl03?ooool2oomo02[ooooo00?o003oooooooooool0IOooool00ol0
003oooooooooo`0?ooooo`03o`000?oooooooooo00;ooooo0oooO`0;ooooo`;oogl03?ooool2oomo
09;ooooo00?o0000ooooooooool02?ooool000Wooooo00?o0000ooooooooool00_ooool2oomo01[o
oooo0_ooO`0Nooooo`H0003o1oooool00ol00?ooooooooooo`1Tooooo`03o`000?oooooooooo00oo
oooo00?o0000ooooooooool00_ooool2oomo01[ooooo0_ooO`2Booooo`03o`000?oooooooooo00So
oooo0009ooooo`03o`000?oooooooooo03Wooooo1@000?l6ooooo`T0003oIOooool00ol0003ooooo
ooooo`0?ooooo`03o`000?oooooooooo0;;ooooo00?o0000ooooooooool02?ooool000Wooooo00?o
0000ooooooooool0=_ooool30000oa;ooooo00?o003oooooo`000?l00P000?mRooooo`03o`000?oo
oooooooo00oooooo00?o0000ooooooooool0/_ooool00ol0003oooooooooo`08ooooo`002Oooool0
0ol0003oooooooooo`0cooooo`<0003o5_ooool01?l00?ooooooooooooooool30000oeoooooo00?o
0000ooooooooool03oooool00ol0003oooooooooo`2booooo`03o`000?oooooooooo00Sooooo0009
ooooo`03o`000?oooooooooo02oooooo10000?lIooooo`03o`00oooooooooooo00Cooooo0P000?mM
ooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool0/_ooool00ol0003oooooooooo`08
ooooo`002Oooool00ol0003oooooooooo`0^ooooo`030000oooooooooooo01_ooooo00?o003ooooo
ooooool01_ooool00`000?ooooooooooo`1Jooooo`03o`000?oooooooooo00oooooo00?o0000oooo
ooooool0/_ooool00ol0003oooooooooo`08ooooo`002Oooool00ol0003oooooooooo`0/ooooo`80
003o7_ooool00ol00?ooooooooooo`07ooooo`030000oooooooooooo05Wooooo00?o0000oooooooo
ool03oooool00ol0003oooooooooo`2booooo`03o`000?oooooooooo00Sooooo0009ooooo`03o`00
0?oooooooooo02_ooooo00<0003oooooooooool07oooool00ol00?ooooooooooo`07ooooo`80003o
FOooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo0;;ooooo00?o0000ooooooooool0
2?ooool000Wooooo00?o0000ooooooooool0:_ooool00`000?ooooooooooo`0Pooooo`03o`00oooo
oooooooo00Wooooo0P000?mGooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool0/_oo
ool00ol0003oooooooooo`08ooooo`002Oooool00ol0003oooooooooo`0Fooooo`;oogl01Oooool2
oomo00Wooooo00?o003o0000ooooool08_ooool00ol00?ooooooooooo`0;ooooo`03o`00oooooooo
oooo05Cooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`0Fooooo`;oogl01Oooool2
oomo09?ooooo00?o0000ooooooooool02?ooool000Wooooo00?o0000ooooooooool05_ooool2oomo
00Gooooo0_ooO`09ooooo`030000oooooooooooo02;ooooo00?o003oooooooooool03?ooool00`00
0?ooooooooooo`1Cooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool05_ooool2oomo
00Gooooo0_ooO`2Cooooo`03o`000?oooooooooo00Sooooo0009ooooo`03o`000?oooooooooo02?o
oooo0ol000000oooool0003oooooo`0Tooooo`03o`00oooooooooooo00gooooo00<0003ooooooooo
ool0D_ooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo0;;ooooo00?o0000oooooooo
ool02?ooool000Wooooo00?o0000ooooooooool08_ooool5o`0002Kooooo00?o003oooooooooool0
3_ooool00`000?ooooooooooo`1Aooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool0
/_ooool00ol0003oooooooooo`08ooooo`002Oooool00ol0003oooooooooo`0Looooo`;oogl01?oo
ool5o`0000[ooooo0_ooO`03ooooo`;oogl05Oooool00ol00?ooooooooooo`0?ooooo`030000oooo
oooooooo053ooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`0Looooo`;oogl01_oo
ool2oomo00_ooooo0_ooO`03ooooo`;oogl0N_ooool00ol0003oooooooooo`08ooooo`002Oooool0
0ol0003oooooooooo`0Looooo`;oogl01?ooool5o`0000[ooooo0_ooO`03ooooo`;oogl05Oooool0
0ol00?ooooooooooo`0@ooooo`03o`00oooooooooooo04oooooo00?o0000ooooooooool03oooool0
0ol0003oooooooooo`0Looooo`;oogl01_ooool2oomo00_ooooo0_ooO`03ooooo`;oogl0N_ooool0
0ol0003oooooooooo`08ooooo`002Oooool00ol0003oooooooooo`0Sooooo`?o00004Oooool2oomo
01Cooooo00?o003oooooooooool04Oooool00`000?ooooooooooo`1>ooooo`03o`000?oooooooooo
00oooooo00?o0000ooooooooool0=oooool2oomo07Wooooo00?o0000ooooooooool02?ooool000Wo
oooo00?o0000ooooooooool08_ooool00`000?ooooooooooo`0>ooooo`;oogl00_ooool2oomo01Co
oooo00?o003oooooooooool04_ooool00`000?ooooooooooo`1=ooooo`03o`000?oooooooooo00oo
oooo00?o0000ooooooooool0<oooool2oomo00;ooooo0_ooO`1iooooo`03o`000?oooooooooo00So
oooo0009ooooo`03o`000?oooooooooo027ooooo00<0003oooooooooool03oooool2oomo01Sooooo
00?o003oooooooooool04oooool00`000?ooooooooooo`1<ooooo`03o`000?oooooooooo00oooooo
00?o0000ooooooooool0<oooool2oomo07gooooo00?o0000ooooooooool02?ooool000Wooooo00?o
0000ooooooooool08?ooool00`000?ooogl0oomo000Zooooo`03o`00oooooooooooo01Cooooo00<0
003oooooooooool0Boooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo027ooooo0_oo
O`2?ooooo`03o`000?oooooooooo00Sooooo0009ooooo`03o`000?oooooooooo01[ooooo0_ooO`04
ooooo`030000ooooO`3oogl002[ooooo00?o003oooooooooool05?ooool00`000?ooooooooooo`1;
ooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool06_ooool2oomo00Gooooo0_ooO`2?
ooooo`03o`000?oooooooooo00Sooooo0009ooooo`03o`000?oooooooooo01[ooooo0_ooO`03oooo
o`030000oooooooooooo013ooooo0_ooO`0:ooooo`;oogl03Oooool00ol00?ooooooooooo`0Eoooo
o`030000oooooooooooo04[ooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`0Joooo
o`;oogl05_ooool2oomo00[ooooo0_ooO`1booooo`03o`000?oooooooooo00Sooooo0009ooooo`03
o`000?oooooooooo01oooooo00<0003oooooooooool04?ooool2oomo00[ooooo0_ooO`0<ooooo`03
o`00oooooooooooo01Kooooo00<0003oooooooooool0B_ooool00ol0003oooooooooo`0?ooooo`03
o`000?oooooooooo03;ooooo0_ooO`0:ooooo`;oogl0L_ooool00ol0003oooooooooo`08ooooo`00
2Oooool00ol0003oooooooooo`0Nooooo`030000oooooooooooo02_ooooo00?o003oooooooooool0
5oooool00ol00?ooooooooooo`19ooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool0
/_ooool00ol0003oooooooooo`08ooooo`002Oooool00ol0003oooooooooo`0Mooooo`030000oooo
oooooooo02cooooo00?o003oooooooooool05oooool00`000?ooooooooooo`19ooooo`03o`000?oo
oooooooo00oooooo00?o0000ooooooooool0/_ooool00ol0003oooooooooo`08ooooo`002Oooool0
0ol0003oooooooooo`0Mooooo`030000oooooooooooo02cooooo00?o003oooooooooool05oooool0
0`000?ooooooooooo`19ooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool0/_ooool0
0ol0003oooooooooo`08ooooo`002Oooool00ol0003oooooooooo`0Looooo`030000oooooooooooo
00Cooooo0_ooO`000oooooooogl0oomo000Sooooo`03o`00oooooooooooo01Wooooo00<0003ooooo
ooooool0B?ooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo02?ooooo0_ooO`000ooo
ooooogl0oomo002:ooooo`03o`000?oooooooooo00Sooooo0009ooooo`03o`000?oooooooooo01co
oooo00<0003oooooooooool01?ooool5oomo02?ooooo00?o003oooooooooool06Oooool00`000?oo
ooooooooo`18ooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool08oooool5oomo08[o
oooo00?o0000ooooooooool02?ooool000Wooooo00?o0000o`00ooooool07?ooool00`000?oooooo
ooooo`06ooooo`;oogl05?ooool2oomo00kooooo00?o003oooooooooool06Oooool00`000?oooooo
ooooo`18ooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool09Oooool2oomo01Cooooo
0_ooO`1eooooo`03o`000?oooooooooo00Sooooo0009ooooo`03o`000?l00?oooooo01_ooooo00<0
003oooooooooool07Oooool2oomo00gooooo00?o003oooooooooool06oooool00`000?oooooooooo
o`17ooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool0>oooool2oomo07Gooooo00?o
0000ooooooooool02?ooool000Wooooo00?o0000o`00ooooool06oooool00`000?ooooooooooo`0/
ooooo`03o`00oooooooooooo01_ooooo00<0003oooooooooool0Aoooool00ol0003oooooooooo`0?
ooooo`03o`000?oooooooooo0;;ooooo00?o0000ooooooooool02?ooool000Wooooo00?o0000oooo
ool00?l06_ooool00`000?ooooooooooo`0/ooooo`03o`00oooooooooooo01gooooo00<0003ooooo
ooooool0A_ooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo0;;ooooo00?o0000oooo
ooooool02?ooool000Wooooo00?o0000ooooool00?l06_ooool010000?ooooooooooooooool2oomo
02Wooooo00?o003oooooooooool07Oooool00`000?ooooooooooo`16ooooo`03o`000?oooooooooo
00oooooo00?o0000ooooooooool07_ooool2oomo09;ooooo00?o0000ooooooooool02?ooool000Wo
oooo00?o0000ooooool00?l06_ooool010000?ooooooooooooooool2oomo02Sooooo00?o003ooooo
ooooool07_ooool00`000?ooooooooooo`16ooooo`03o`000?oooooooooo00oooooo00?o0000oooo
ooooool07_ooool2oomo09;ooooo00?o0000ooooooooool02?ooool000Wooooo00Co0000oooooooo
oooo003o6Oooool00`000?ooooooooooo`0[ooooo`03o`00oooooooooooo01oooooo00<0003ooooo
ooooool0AOooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo0;;ooooo00?o0000oooo
ooooool02?ooool000Wooooo00Go0000ooooooooooooooooo`00o`0Hooooo`030000oooooooooooo
02_ooooo00?o003oooooooooool07oooool00`000?ooooooooooo`15ooooo`03o`000?oooooooooo
00oooooo00?o0000ooooooooool0/_ooool00ol0003oooooooooo`08ooooo`002Oooool00ol0003o
ooooooooo`02ooooo`03o`00oooooooooooo01Gooooo00<0003oooooooooool0:_ooool00ol00?oo
ooooooooo`0Pooooo`030000oooooooooooo04Gooooo00?o0000ooooooooool03oooool00ol0003o
ooooooooo`2booooo`03o`000?oooooooooo00Sooooo0009ooooo`03o`000?oooooooooo00?ooooo
00?o003oooooooooool04oooool00`000?ooooooooooo`0Zooooo`03o`00oooooooooooo027ooooo
00?o003oooooooooool0AOooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo0;;ooooo
00?o0000ooooooooool02?ooool000Wooooo00?o0000ooooooooool00oooool00ol00?oooooooooo
o`0Cooooo`030000oooooooooooo02Wooooo00?o003oooooooooool01_ooool2oomo01[ooooo00<0
003oooooooooool0AOooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo04kooooo0_oo
O`1Rooooo`03o`000?oooooooooo00Sooooo0009ooooo`03o`000?oooooooooo00?ooooo00?o003o
ooooooooool04oooool00`000?ooooooooooo`0Hooooo`;oogl03oooool00ol00?ooooooooooo`06
ooooo`;oogl06_ooool00`000?ooooooooooo`15ooooo`03o`000?oooooooooo00oooooo00?o0000
ooooooooool0=?ooool2oomo01Sooooo0_ooO`1Rooooo`03o`000?oooooooooo00Sooooo0009oooo
o`03o`000?oooooooooo00Cooooo00?o003oooooooooool04_ooool00`000?ooooooooooo`0Hoooo
o`;oogl03_ooool00ol00?ooooooooooo`0Sooooo`030000oooooooooooo04Gooooo00?o0000oooo
ooooool03oooool00ol0003oooooooooo`0dooooo`;oogl0O?ooool00ol0003oooooooooo`08oooo
o`002Oooool00ol0003oooooooooo`05ooooo`03o`00oooooooooooo017ooooo00<0003ooooooooo
ool09?ooool3o`000003o`00oooooooooooo02Gooooo00<0003oooooooooool0A?ooool00ol0003o
ooooooooo`0?ooooo`03o`000?oooooooooo0;;ooooo00?o0000ooooooooool02?ooool000Wooooo
00?o0000ooooooooool01_ooool00ol00?ooooooooooo`0@ooooo`030000oooooooooooo027ooooo
0_ooO`05o`0002Oooooo00<0003oooooooooool0A?ooool00ol0003oooooooooo`0?ooooo`03o`00
0?oooooooooo03gooooo0_ooO`02ooooo`;oogl0Koooool00ol0003oooooooooo`08ooooo`002Ooo
ool00ol0003oooooooooo`07ooooo`;o003o4?ooool00`000?ooooooooooo`0Qooooo`;oogl01Ol0
000Wooooo`030000oooooooooooo04Cooooo00?o0000ooooooooool03oooool00ol0003ooooooooo
o`0mooooo`;oogl00_ooool2oomo06oooooo00?o0000ooooooooool02?ooool000Wooooo00?o0000
ooooooooool02Oooool00ol00?ooooooooooo`0=ooooo`030000oooooooooooo02?ooooo1Ol0000W
ooooo`030000oooooooooooo04Cooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`2b
ooooo`03o`000?oooooooooo00Sooooo0009ooooo`03o`000?oooooooooo00[ooooo00?o003ooooo
ooooool03?ooool00`000?ooooooooooo`0Rooooo`03o`00oooooooo000000;o0000:?ooool00`00
0?ooooooooooo`14ooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool0/_ooool00ol0
003oooooooooo`08ooooo`002Oooool00ol0003oooooooooo`0;ooooo`03o`00oooooooooooo00_o
oooo00<0003oooooooooool08Oooool00ol00?ooooooooooo`0Zooooo`030000oooooooooooo04Go
oooo00?o0000ooooooooool03oooool00ol0003oooooooooo`2booooo`03o`000?oooooooooo00So
oooo0009ooooo`03o`000?oooooooooo00cooooo00?o003oooooooooool02_ooool00`000?oooooo
ooooo`0Pooooo`03o`00oooooooooooo02_ooooo00?o003oooooooooool0AOooool00ol0003ooooo
ooooo`0?ooooo`03o`000?oooooooooo0;;ooooo00?o0000ooooooooool02?ooool000Wooooo00?o
0000ooooooooool03Oooool2o`00o`[ooooo00<0003oooooooooool07_ooool2o`00obkooooo00<0
003oooooooooool0AOooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo0;;ooooo00?o
0000ooooooooool02?ooool000Wooooo00?o0000ooooooooool03oooool2o`00o`Sooooo00<0003o
ooooooooool07?ooool2o`00oc3ooooo00<0003oooooooooool0AOooool00ol0003oooooooooo`0?
ooooo`03o`000?oooooooooo0;;ooooo00?o0000ooooooooool02?ooool000Wooooo00?o0000oooo
ooooool04Oooool2o`00o`Kooooo00<0003oooooooooool06_ooool2o`00oc;ooooo00<0003ooooo
ooooool0AOooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo0;;ooooo00?o0000oooo
ooooool02?ooool000Wooooo00?o0000ooooooooool04oooool3o`00o`Cooooo00<0003ooooooooo
ool05_ooool3o`00oc?ooooo00<0003oooooooooool0A_ooool00ol0003oooooooooo`0?ooooo`03
o`000?oooooooooo0;;ooooo00?o0000ooooooooool02?ooool000Wooooo00?o0000ooooooooool0
5_ooool3o`00o`03ooooo`000?oooooo01Gooooo0_l00?lfooooo`030000oooooooooooo04Kooooo
00?o0000ooooooooool03oooool00ol0003oooooooooo`2booooo`03o`000?oooooooooo00Sooooo
0009ooooo`03o`000?oooooooooo01Wooooo0_l00?lCooooo`?o003o>?ooool00`000?oooooooooo
o`16ooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool0/_ooool00ol0003ooooooooo
o`08ooooo`002Oooool00ol0003oooooooooo`0Jooooo`030000ool00?oo003o00Ko003o2?ooool3
o`00oc_ooooo00<0003oooooooooool0A_ooool00ol0003oooooooooo`0?ooooo`03o`000?oooooo
oooo0;;ooooo00?o0000ooooooooool02?ooool000Wooooo00?o0000ooooooooool06oooool00`00
0?ooooooooooo`05ooooo`So003o?Oooool00`000?ooooooooooo`17ooooo`03o`000?oooooooooo
00oooooo00?o0000ooooooooool0/_ooool00ol0003oooooooooo`08ooooo`002Oooool00ol0003o
ooooooooo`0Kooooo`030000oooooooooooo04[ooooo00<0003oooooooooool0Aoooool00ol0003o
ooooooooo`0?ooooo`03o`000?oooooooooo0;;ooooo00?o0000ooooooooool02?ooool000Wooooo
00?o0000ooooooooool07?ooool00`000?ooooooooooo`19ooooo`030000oooooooooooo04Oooooo
00?o0000ooooooooool03oooool00ol0003oooooooooo`2booooo`03o`000?oooooooooo00Sooooo
0009ooooo`03o`000?oooooooooo01cooooo00<0003oooooooooool0BOooool00`000?oooooooooo
o`17ooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool0/_ooool00ol0003ooooooooo
o`08ooooo`002Oooool00ol0003oooooooooo`0Mooooo`030000oooooooooooo04Oooooo00<0003o
ooooooooool0B?ooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo0;;ooooo00?o0000
ooooooooool02?ooool000Wooooo00?o0000ooooooooool07Oooool00`000?ooooooooooo`17oooo
o`030000oooooooooooo04Sooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`2boooo
o`03o`000?oooooooooo00Sooooo0009ooooo`03o`000?oooooooooo01gooooo00<0003ooooooooo
ool0Aoooool00`000?ooooooooooo`18ooooo`03o`000?oooooooooo00oooooo00?o0000oooooooo
ool0/_ooool00ol0003oooooooooo`08ooooo`002Oooool00ol0003oooooooooo`0Nooooo`030000
oooooooooooo04Gooooo00<0003oooooooooool0BOooool00ol0003oooooooooo`0?ooooo`03o`00
0?oooooooooo0;;ooooo00?o0000ooooooooool02?ooool000Wooooo00?o0000ooooooooool07_oo
ool00`000?ooooooooooo`15ooooo`030000oooooooooooo04Wooooo00?o0000ooooooooool03ooo
ool00ol0003oooooooooo`2booooo`03o`000?oooooooooo00Sooooo0009ooooo`03o`000?oooooo
oooo01oooooo00<0003oooooooooool0@oooool00`000?ooooooooooo`1:ooooo`03o`000?oooooo
oooo00oooooo00?o0000ooooooooool0/_ooool00ol0003oooooooooo`08ooooo`002Oooool00ol0
003oooooooooo`0Oooooo`030000oooooooooooo04;ooooo00<0003oooooooooool0>oooool2oomo
00kooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`2Rooooo`;oogl03_ooool00ol0
003oooooooooo`08ooooo`002Oooool00ol0003oooooooooo`0Pooooo`030000oooooooooooo047o
oooo00<0003oooooooooool0>oooool2oomo00kooooo00?o0000ooooooooool03oooool00ol0003o
ooooooooo`2Rooooo`;oogl03_ooool00ol0003oooooooooo`08ooooo`002Oooool00ol0003ooooo
ooooo`0Qooooo`030000oooooooooooo03oooooo00<0003oooooooooool0C?ooool00ol0003ooooo
ooooo`0?ooooo`03o`000?oooooooooo0;;ooooo00?o0000ooooooooool02?ooool000Wooooo00?o
0000ooooooooool08_ooool00`000?ooooooooooo`0mooooo`030000oooooooooooo04gooooo00?o
0000ooooooooool03oooool00ol0003oooooooooo`2booooo`03o`000?oooooooooo00Sooooo0009
ooooo`03o`000?oooooooooo02?ooooo00<0003oooooooooool0>oooool00`000?ooooooooooo`1>
ooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool0/_ooool00ol0003oooooooooo`08
ooooo`002Oooool00ol0003oooooooooo`0Tooooo`030000oooooooooooo03Wooooo00<0003ooooo
ooooool0Coooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo0;;ooooo00?o0000oooo
ooooool02?ooool000Wooooo00?o0000ooooooooool09Oooool00ol00?ooooooooooo`0gooooo`03
0000oooooooooooo053ooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`2booooo`03
o`000?oooooooooo00Sooooo0009ooooo`03o`000?oooooooooo02Kooooo00<0003oooooooooool0
=Oooool00`000?ooooooooooo`1Aooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool0
/_ooool00ol0003oooooooooo`08ooooo`002Oooool00ol0003oooooooooo`0Wooooo`030000oooo
oooooooo03?ooooo00<0003oooooooooool0D_ooool00ol0003oooooooooo`0?ooooo`03o`000?oo
oooooooo0;;ooooo00?o0000ooooooooool02?ooool000Wooooo00?o0000ooooooooool0:?ooool0
0`000?ooooooooooo`0`ooooo`80003o5?ooool2oomo03oooooo00?o0000ooooooooool03oooool0
0ol0003oooooooooo`1aooooo`;oogl0?oooool00ol0003oooooooooo`08ooooo`002Oooool00ol0
003oooooooooo`0Yooooo`030000oooooooooooo02kooooo00<0003oooooooooool05?ooool2oomo
03oooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`1aooooo`;oogl0?oooool00ol0
003oooooooooo`08ooooo`002Oooool00ol0003oooooooooo`0Zooooo`80003o;?ooool20000ocWo
oooo0_ooO`0Mooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool0Toooool2oomo01go
oooo00?o0000ooooooooool02?ooool000Wooooo00?o0000ooooooooool0;?ooool00`000?oooooo
ooooo`0Wooooo`80003o=oooool2oomo00;ooooo0_ooO`0Mooooo`03o`000?oooooooooo00oooooo
00?o0000ooooooooool0Soooool2oomo00;ooooo0_ooO`0Mooooo`03o`000?oooooooooo00Sooooo
0009ooooo`03o`000?oooooooooo02gooooo0P000?lVooooo`030000oooooooooooo02;ooooo0_oo
O`0Cooooo`;oogl08Oooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo07[ooooo0_oo
O`0Cooooo`;oogl08Oooool00ol0003oooooooooo`08ooooo`002Oooool00ol0003oooooooooo`0_
ooooo`<0003o8_ooool00`000?ooooooooooo`0Sooooo`;oogl0=_ooool00ol0003oooooooooo`0?
ooooo`03o`000?oooooooooo07[ooooo0_ooO`0fooooo`03o`000?oooooooooo00Sooooo0009oooo
o`03o`000?oooooooooo03;ooooo00<0003oooooooooool07Oooool20000ob3ooooo0_ooO`0Foooo
o`;oogl09?ooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo07Cooooo0_ooO`0Foooo
o`;oogl09?ooool00ol0003oooooooooo`08ooooo`002Oooool00ol0003oooooooooo`0cooooo`03
o`00o`000?l0003o01Oooooo1@000?lRooooo`;oogl05_ooool2oomo02Cooooo00?o0000oooooooo
ool03oooool00ol0003oooooooooo`1dooooo`;oogl05_ooool2oomo02Cooooo00?o0000oooooooo
ool02?ooool000Wooooo00?o0000ooooooooool0=_ooool40000oa3ooooo0`000?lSooooo`;oogl0
3oooool2oomo00gooooo0_ooO`0Pooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool0
L?ooool2oomo00oooooo0_ooO`0=ooooo`;oogl08?ooool00ol0003oooooooooo`08ooooo`002Ooo
ool00ol0003oooooooooo`0joooooa00003o9_ooool2oomo00Cooooo0_ooO`09ooooo`;oogl03Ooo
ool2oomo023ooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`1`ooooo`;oogl01?oo
ool2oomo00Wooooo0_ooO`0=ooooo`;oogl08?ooool00ol0003oooooooooo`08ooooo`002Oooool0
0ol0003oooooooooo`1Fooooo`;oogl06?ooool2oomo00Cooooo0_ooO`0jooooo`03o`000?oooooo
oooo00oooooo00?o0000ooooooooool0E_ooool2oomo01Sooooo0_ooO`04ooooo`;oogl0>_ooool0
0ol0003oooooooooo`08ooooo`002Oooool00ol0003oooooooooo`1Fooooo`;oogl06?ooool2oomo
043ooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`1Fooooo`;oogl06?ooool2oomo
043ooooo00?o0000ooooooooool02?ooool000Wooooo00?o0000ooooooooool0/_ooool00ol0003o
ooooooooo`0?ooooo`03o`000?oooooooooo0;;ooooo00?o0000ooooooooool02?ooool000Wooooo
00?o0000ooooooooool0GOooool2oomo00Wooooo0_ooO`0Iooooo`;oogl0;Oooool00ol0003ooooo
ooooo`0?ooooo`03o`000?oooooooooo05gooooo0_ooO`09ooooo`;oogl06Oooool2oomo02gooooo
00?o0000ooooooooool02?ooool000Wooooo00?o0000ooooooooool0GOooool2oomo00Wooooo0_oo
O`0Iooooo`;oogl0;Oooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo05gooooo0_oo
O`09ooooo`;oogl06Oooool2oomo02gooooo00?o0000ooooooooool02?ooool000Wooooo00?o0000
ooooooooool0/_ooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo0;;ooooo00?o0000
ooooooooool02?ooool000Wooooo00?o0000ooooooooool0Toooool2oomo01gooooo00?o0000oooo
ooooool03oooool00ol0003oooooooooo`2Cooooo`;oogl07Oooool00ol0003oooooooooo`08oooo
o`002Oooool00ol0003oooooooooo`26ooooo`;oogl02oooool2oomo01gooooo00?o0000oooooooo
ool03oooool00ol0003oooooooooo`26ooooo`;oogl02oooool2oomo01gooooo00?o0000oooooooo
ool02?ooool000Wooooo00?o0000ooooooooool0L_ooool2oomo01;ooooo0_ooO`0Zooooo`03o`00
0?oooooooooo00oooooo00?o0000ooooooooool0L_ooool2oomo01;ooooo0_ooO`0Zooooo`03o`00
0?oooooooooo00Sooooo0009ooooo`03o`000?oooooooooo07;ooooo0_ooO`0nooooo`03o`000?oo
oooooooo00oooooo00?o0000ooooooooool0L_ooool2oomo03kooooo00?o0000ooooooooool02?oo
ool000Wooooo00?o0000ooooooooool0JOooool2oomo00Gooooo0_ooO`0Booooo`;oogl0;?ooool0
0ol0003oooooooooo`0?ooooo`03o`000?oooooooooo06Wooooo0_ooO`05ooooo`;oogl04_ooool2
oomo02cooooo00?o0000ooooooooool02?ooool000Wooooo00?o0000ooooooooool0Ioooool4oomo
00Gooooo0_ooO`0>ooooo`;oogl00_ooool2oomo02cooooo00?o0000ooooooooool03oooool00ol0
003oooooooooo`1Wooooo`Coogl01Oooool2oomo00kooooo0_ooO`02ooooo`;oogl0;?ooool00ol0
003oooooooooo`08ooooo`002Oooool00ol0003oooooooooo`1Wooooo`;oogl05oooool2oomo033o
oooo00?o0000ooooooooool03oooool00ol0003oooooooooo`1Wooooo`;oogl05oooool2oomo033o
oooo00?o0000ooooooooool02?ooool000Wooooo00?o0000ooooooooool0BOooool2oomo06Oooooo
00?o0000ooooooooool03oooool00ol0003oooooooooo`19ooooo`;oogl0Ioooool00ol0003ooooo
ooooo`08ooooo`002Oooool00ol0003oooooooooo`19ooooo`;oogl01oooool2oomo01[ooooo0_oo
O`12ooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool0BOooool2oomo00Oooooo0_oo
O`0Jooooo`;oogl0@_ooool00ol0003oooooooooo`08ooooo`002Oooool00ol0003oooooooooo`1B
ooooo`;oogl06_ooool2oomo04;ooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`1B
ooooo`;oogl06_ooool2oomo04;ooooo00?o0000ooooooooool02?ooool000Wooooo00?o0000oooo
ooooool0JOooool2oomo04Oooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`1Yoooo
o`;oogl0Aoooool00ol0003oooooooooo`08ooooo`002Oooool00ol0003oooooooooo`1Yooooo`;o
ogl0Aoooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo06Wooooo0_ooO`17ooooo`03
o`000?oooooooooo00Sooooo0009ooooo`03o`000?oooooooooo0;;ooooo00?o0000ooooooooool0
3oooool00ol0003oooooooooo`2booooo`03o`000?oooooooooo00Sooooo0009ooooo`03o`000?oo
oooooooo0;;ooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`2booooo`03o`000?oo
oooooooo00Sooooo0009ooooo`03o`000?oooooooooo0;;ooooo00?o0000ooooooooool03oooool0
0ol0003oooooooooo`2booooo`03o`000?oooooooooo00Sooooo0009ooooo`03o`000?oooooooooo
05;ooooo0_ooO`1Nooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool0D_ooool2oomo
05kooooo00?o0000ooooooooool02?ooool000Wooooo00?o0000ooooooooool0D_ooool2oomo05ko
oooo00?o0000ooooooooool03oooool00ol0003oooooooooo`1Booooo`;oogl0G_ooool00ol0003o
ooooooooo`08ooooo`002Oooool00ol0003oooooooooo`1_ooooo`;oogl0@Oooool00ol0003ooooo
ooooo`0?ooooo`03o`000?oooooooooo06oooooo0_ooO`11ooooo`03o`000?oooooooooo00Sooooo
0009ooooo`03o`000?oooooooooo06oooooo0_ooO`11ooooo`03o`000?oooooooooo00oooooo00?o
0000ooooooooool0Koooool2oomo047ooooo00?o0000ooooooooool02?ooool000Wooooo00?o0000
ooooooooool0/_ooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo0;;ooooo00?o0000
ooooooooool02?ooool000Wooooo00?o0000ooooooooool0/_ooool00ol0003oooooooooo`0?oooo
o`03o`000?oooooooooo0;;ooooo00?o0000ooooooooool02?ooool000Wooooo00?o0000oooooooo
ool0COooool2oomo06?ooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`1=ooooo`;o
ogl0Hoooool00ol0003oooooooooo`08ooooo`002Oooool00ol0003oooooooooo`1=ooooo`;oogl0
5?ooool2oomo04gooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`1=ooooo`;oogl0
5?ooool2oomo04gooooo00?o0000ooooooooool02?ooool000Wooooo00?o0000ooooooooool0Hooo
ool2oomo04gooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`1Sooooo`;oogl0COoo
ool00ol0003oooooooooo`08ooooo`002Oooool00ol0003oooooooooo`1Iooooo`;oogl0Eoooool0
0ol0003oooooooooo`0?ooooo`03o`000?oooooooooo05Wooooo0_ooO`1Gooooo`03o`000?oooooo
oooo00Sooooo0009ooooo`03o`000?oooooooooo05Wooooo0_ooO`1Gooooo`03o`000?oooooooooo
00oooooo00?o0000ooooooooool0FOooool2oomo05Oooooo00?o0000ooooooooool02?ooool000Wo
oooo00?o0000ooooooooool0LOooool2oomo03oooooo00?o0000ooooooooool03oooool00ol0003o
ooooooooo`1aooooo`;oogl0?oooool00ol0003oooooooooo`08ooooo`002Oooool00ol0003ooooo
ooooo`1aooooo`;oogl0?oooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo077ooooo
0_ooO`0oooooo`03o`000?oooooooooo00Sooooo0009ooooo`03o`000?oooooooooo0;;ooooo00?o
0000ooooooooool03oooool00ol0003oooooooooo`2booooo`03o`000?oooooooooo00Sooooo0009
ooooo`03o`000?oooooooooo0;;ooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`2b
ooooo`03o`000?oooooooooo00Sooooo0009ooooo`03o`000?oooooooooo0;;ooooo00?o0000oooo
ooooool03oooool00ol0003oooooooooo`2booooo`03o`000?oooooooooo00Sooooo0009ooooo`03
o`000?oooooooooo0;;ooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`2booooo`03
o`000?oooooooooo00Sooooo0009ooooo`03o`000?oooooooooo0;;ooooo00?o0000ooooooooool0
3oooool00ol0003oooooooooo`2booooo`03o`000?oooooooooo00Sooooo0009ooooo`03o`000?oo
oooooooo0;;ooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`2booooo`03o`000?oo
oooooooo00Sooooo0009ooooo`03o`000?oooooooooo0;;ooooo00?o0000ooooooooool03oooool0
0ol0003oooooooooo`2booooo`03o`000?oooooooooo00Sooooo0009ooooo`03o`000?oooooooooo
0;;ooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`2booooo`03o`000?oooooooooo
00Sooooo0009ooooo`03o`000?oooooooooo0;;ooooo00?o0000ooooooooool03oooool00ol0003o
ooooooooo`2booooo`03o`000?oooooooooo00Sooooo0009ooooo`03o`000?oooooooooo0;;ooooo
00?o0000ooooooooool03oooool00ol0003oooooooooo`2booooo`03o`000?oooooooooo00Sooooo
0009ooooo`03o`000?oooooooooo0;;ooooo00?o0000ooooooooool03oooool00ol0003ooooooooo
o`2booooo`03o`000?oooooooooo00Sooooo0009ooooo`03o`000?oooooooooo0;;ooooo00?o0000
ooooooooool03oooool00ol0003oooooooooo`2booooo`03o`000?oooooooooo00Sooooo0009oooo
o`03o`000?oooooooooo0;;ooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`2boooo
o`03o`000?oooooooooo00Sooooo0009ooooo`03o`000?oooooooooo0;;ooooo00?o0000oooooooo
ool03oooool00ol0003oooooooooo`2booooo`03o`000?oooooooooo00Sooooo0009ooooo`03o`00
0?oooooooooo0;;ooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`2booooo`03o`00
0?oooooooooo00Sooooo0009ooooo`03o`000?oooooooooo0;;ooooo00?o0000ooooooooool03ooo
ool00ol0003oooooooooo`2booooo`03o`000?oooooooooo00Sooooo0009ooooo`03o`000?oooooo
oooo0;;ooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`2booooo`03o`000?oooooo
oooo00Sooooo0009ooooo`03o`000?oooooooooo0;;ooooo00?o0000ooooooooool03oooool00ol0
003oooooooooo`2booooo`03o`000?oooooooooo00Sooooo0009ooooo`03o`000?oooooooooo0;;o
oooo00?o0000ooooooooool03oooool00ol0003oooooooooo`2booooo`03o`000?oooooooooo00So
oooo0009ooooo`03o`000?oooooooooo0;;ooooo00?o0000ooooooooool03oooool00ol0003ooooo
ooooo`2booooo`03o`000?oooooooooo00Sooooo0009ooooo`03o`000?oooooooooo0;;ooooo00?o
0000ooooooooool03oooool00ol0003oooooooooo`2booooo`03o`000?oooooooooo00Sooooo0009
ooooo`03o`000?oooooooooo0;;ooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`2b
ooooo`03o`000?oooooooooo00Sooooo0009ooooo`03o`000?oooooooooo0;;ooooo00?o0000oooo
ooooool03oooool00ol0003oooooooooo`2booooo`03o`000?oooooooooo00Sooooo0009ooooo`03
o`000?oooooooooo0;;ooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`2booooo`03
o`000?oooooooooo00Sooooo0009ooooo`03o`000?oooooooooo05Sooooo0_ooO`1Hooooo`03o`00
0?oooooooooo00oooooo00?o0000ooooooooool0F?ooool2oomo05Sooooo00?o0000ooooooooool0
2?ooool000Wooooo00?o0000ooooooooool0F?ooool2oomo05Sooooo00?o0000ooooooooool03ooo
ool00ol0003oooooooooo`1Hooooo`;oogl0F?ooool00ol0003oooooooooo`08ooooo`002Oooool0
0ol0003oooooooooo`2booooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool0/_ooool0
0ol0003oooooooooo`08ooooo`002Oooool00ol0003oooooooooo`2booooo`03o`000?oooooooooo
00oooooo00?o0000ooooooooool0/_ooool00ol0003oooooooooo`08ooooo`002Oooool00ol0003o
ooooooooo`2booooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool0/_ooool00ol0003o
ooooooooo`08ooooo`002Oooool00ol0003oooooooooo`2booooo`03o`000?oooooooooo00oooooo
00?o0000ooooooooool0/_ooool00ol0003oooooooooo`08ooooo`002Oooool00ol0003ooooooooo
o`2booooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool0/_ooool00ol0003ooooooooo
o`08ooooo`002Oooool00ol0003oooooooooo`2booooo`03o`000?oooooooooo00oooooo00?o0000
ooooooooool0/_ooool00ol0003oooooooooo`08ooooo`002Oooool00ol0003oooooooooo`2boooo
o`03o`000?oooooooooo00oooooo00?o0000ooooooooool0/_ooool00ol0003oooooooooo`08oooo
o`002Oooool00ol0003oooooooooo`2booooo`03o`000?oooooooooo00oooooo00?o0000oooooooo
ool0/_ooool00ol0003oooooooooo`08ooooo`002Oooool00ol0003oooooooooo`2booooo`03o`00
0?oooooooooo00oooooo00?o0000ooooooooool0/_ooool00ol0003oooooooooo`08ooooo`002Ooo
ool00ol0003oooooooooo`2booooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool0/_oo
ool00ol0003oooooooooo`08ooooo`002Oooool00ol0003oooooooooo`2booooo`03o`000?oooooo
oooo00oooooo00?o0000ooooooooool0/_ooool00ol0003oooooooooo`08ooooo`002Oooool00ol0
003oooooooooo`2booooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool0/_ooool00ol0
003oooooooooo`08ooooo`002Oooool00ol0003oooooooooo`2booooo`03o`000?oooooooooo00oo
oooo00?o0000ooooooooool0/_ooool00ol0003oooooooooo`08ooooo`002Ooooonfo`00017ooooo
]_l0000:ooooo`00oooooonAooooo`00oooooonAooooo`00oooooonAooooo`00oooooonAooooo`00
oooooonAooooo`00oooooonAooooo`00oooooonAooooo`00oooooonAooooo`00oooooonAooooo`00
\
\>"],
  ImageRangeCache->{{{0, 399}, {399, 0}} -> {-0.0500105, -0.0500105, \
0.00526322, 0.00526322}, {{9.5, 190.438}, {389.5, 208.5}} -> {-1.15081, \
-1.15117, 0.0115117, 0.0115117}, {{208.5, 389.438}, {389.5, 208.5}} -> \
{-1.09771, -0.0754011, 0.0052648, 0.0052648}, {{9.5, 190.438}, {190.438, \
9.5}} -> {-1.11761, -3.34306, 0.0111796, 0.0111796}, {{208.5, 389.438}, \
{190.438, 9.5}} -> {-3.34236, -3.34306, 0.0111796, 0.0111796}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
%%ImageSize: 400 400 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.47619 0.0238095 0.47619 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.0238095 0.477324 0.477324 MathSubStart
%% ContourGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.480769 0.5 0.480769 [
[ 0 0 -0.125 0 ]
[ 0 0 -0.125 0 ]
[ 0 1 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
0 0 m
1 0 L
s
0 0 m
0 1 L
s
0 1 m
1 1 L
s
1 0 m
1 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
.01923 .98077 m
.98077 .98077 L
.98077 .01923 L
.01923 .01923 L
F
.5 Mabswid
.1 g
.01923 .21634 m
.02811 .23077 L
.03846 .247 L
.04038 .25 L
.05266 .26923 L
.05769 .27725 L
.06488 .28846 L
.07692 .30763 L
.07696 .30769 L
.08915 .32692 L
.09615 .33828 L
.10108 .34615 L
.11292 .36538 L
.11538 .36945 L
.12474 .38462 L
.13462 .40092 L
.13642 .40385 L
.14826 .42308 L
.15385 .43222 L
.16017 .44231 L
.17227 .46154 L
.17308 .46281 L
.18479 .48077 L
.19231 .49216 L
.19764 .5 L
.21096 .51923 L
.21154 .52006 L
.22489 .53846 L
.23077 .54641 L
.23939 .55769 L
.25 .57131 L
.25451 .57692 L
.26923 .59488 L
.27031 .59615 L
.28686 .61538 L
.28846 .61721 L
.30418 .63462 L
.30769 .63842 L
.3223 .65385 L
.32692 .65862 L
.34126 .67308 L
.34615 .6779 L
.36112 .69231 L
.36538 .69632 L
.38193 .71154 L
.38462 .71395 L
.40377 .73077 L
.40385 .73083 L
.42308 .74696 L
.42678 .75 L
.44231 .7624 L
.45104 .76923 L
.46154 .7772 L
.47669 .78846 L
.48077 .7914 L
.5 .80496 L
.50396 .80769 L
.51923 .81787 L
.53316 .82692 L
.53846 .83024 L
.55769 .842 L
.56469 .84615 L
.57692 .85313 L
.59615 .86374 L
.59923 .86538 L
.61538 .87365 L
.63462 .88304 L
.63796 .88462 L
.65385 .89172 L
.67308 .89982 L
.68323 .90385 L
.69231 .90722 L
.71154 .91391 L
.73077 .91991 L
.74205 .92308 L
.75 .92509 L
.76923 .92941 L
.78846 .93283 L
.80769 .93524 L
.82692 .93651 L
.84615 .93647 L
.86538 .93489 L
.88462 .93145 L
.90385 .92563 L
.9102 .92308 L
.92308 .91658 L
.94096 .90385 L
.94231 .90266 L
.95825 .88462 L
.96154 .87967 L
.96903 .86538 L
.97569 .84615 L
.97937 .82692 L
.98074 .80769 L
.98022 .78846 L
.9781 .76923 L
.97458 .75 L
.96981 .73077 L
.96389 .71154 L
.96154 .70472 L
.9569 .69231 L
.94897 .67308 L
.94231 .65832 L
.94015 .65385 L
.93041 .63462 L
.92308 .62101 L
.91988 .61538 L
.9085 .59615 L
.90385 .5886 L
.89633 .57692 L
.88462 .55941 L
.88342 .55769 L
.86967 .53846 L
.86538 .53264 L
.85516 .51923 L
.84615 .50774 L
.83989 .5 L
.82692 .48439 L
.82383 .48077 L
.80769 .46235 L
.80696 .46154 L
.78925 .44231 L
.78846 .44147 L
.77068 .42308 L
.76923 .42161 L
.75122 .40385 L
.75 .40268 L
.73081 .38462 L
.73077 .38457 L
.71154 .36727 L
.70939 .36538 L
.69231 .35071 L
.6869 .34615 L
.67308 .33483 L
.66324 .32692 L
.65385 .31958 L
.63835 .30769 L
.63462 .30492 L
.61538 .29085 L
.61206 .28846 L
.59615 .27738 L
.58426 .26923 L
.57692 .26438 L
.55769 .25183 L
.55484 .25 L
.53846 .23982 L
.5237 .23077 L
.51923 .22813 L
.5 .21683 L
.49092 .21154 L
.48077 .20582 L
.46154 .19499 L
.45677 .19231 L
.44231 .18441 L
.42308 .17377 L
.42183 .17308 L
.40385 .16333 L
.38677 .15385 L
.38462 .15269 L
.36538 .14212 L
.35211 .13462 L
.34615 .13134 L
.32692 .12047 L
.3181 .11538 L
.30769 .10954 L
.28846 .09839 L
.28463 .09615 L
.26923 .08739 L
.25134 .07692 L
.25 .07617 L
.23077 .06522 L
.21773 .05769 L
.21154 .05427 L
.19231 .04351 L
.18326 .03846 L
.17308 .03285 L
.15385 .02268 L
.14701 .01923 L
.01923 .01923 L
F
0 g
.01923 .21634 m
.02811 .23077 L
.03846 .247 L
.04038 .25 L
.05266 .26923 L
.05769 .27725 L
.06488 .28846 L
.07692 .30763 L
.07696 .30769 L
.08915 .32692 L
.09615 .33828 L
.10108 .34615 L
.11292 .36538 L
.11538 .36945 L
.12474 .38462 L
.13462 .40092 L
.13642 .40385 L
.14826 .42308 L
.15385 .43222 L
.16017 .44231 L
.17227 .46154 L
.17308 .46281 L
.18479 .48077 L
.19231 .49216 L
.19764 .5 L
.21096 .51923 L
.21154 .52006 L
.22489 .53846 L
.23077 .54641 L
.23939 .55769 L
.25 .57131 L
.25451 .57692 L
.26923 .59488 L
.27031 .59615 L
.28686 .61538 L
.28846 .61721 L
.30418 .63462 L
.30769 .63842 L
.3223 .65385 L
.32692 .65862 L
.34126 .67308 L
.34615 .6779 L
.36112 .69231 L
.36538 .69632 L
.38193 .71154 L
.38462 .71395 L
.40377 .73077 L
.40385 .73083 L
.42308 .74696 L
.42678 .75 L
Mistroke
.44231 .7624 L
.45104 .76923 L
.46154 .7772 L
.47669 .78846 L
.48077 .7914 L
.5 .80496 L
.50396 .80769 L
.51923 .81787 L
.53316 .82692 L
.53846 .83024 L
.55769 .842 L
.56469 .84615 L
.57692 .85313 L
.59615 .86374 L
.59923 .86538 L
.61538 .87365 L
.63462 .88304 L
.63796 .88462 L
.65385 .89172 L
.67308 .89982 L
.68323 .90385 L
.69231 .90722 L
.71154 .91391 L
.73077 .91991 L
.74205 .92308 L
.75 .92509 L
.76923 .92941 L
.78846 .93283 L
.80769 .93524 L
.82692 .93651 L
.84615 .93647 L
.86538 .93489 L
.88462 .93145 L
.90385 .92563 L
.9102 .92308 L
.92308 .91658 L
.94096 .90385 L
.94231 .90266 L
.95825 .88462 L
.96154 .87967 L
.96903 .86538 L
.97569 .84615 L
.97937 .82692 L
.98074 .80769 L
.98022 .78846 L
.9781 .76923 L
.97458 .75 L
.96981 .73077 L
.96389 .71154 L
.96154 .70472 L
Mistroke
.9569 .69231 L
.94897 .67308 L
.94231 .65832 L
.94015 .65385 L
.93041 .63462 L
.92308 .62101 L
.91988 .61538 L
.9085 .59615 L
.90385 .5886 L
.89633 .57692 L
.88462 .55941 L
.88342 .55769 L
.86967 .53846 L
.86538 .53264 L
.85516 .51923 L
.84615 .50774 L
.83989 .5 L
.82692 .48439 L
.82383 .48077 L
.80769 .46235 L
.80696 .46154 L
.78925 .44231 L
.78846 .44147 L
.77068 .42308 L
.76923 .42161 L
.75122 .40385 L
.75 .40268 L
.73081 .38462 L
.73077 .38457 L
.71154 .36727 L
.70939 .36538 L
.69231 .35071 L
.6869 .34615 L
.67308 .33483 L
.66324 .32692 L
.65385 .31958 L
.63835 .30769 L
.63462 .30492 L
.61538 .29085 L
.61206 .28846 L
.59615 .27738 L
.58426 .26923 L
.57692 .26438 L
.55769 .25183 L
.55484 .25 L
.53846 .23982 L
.5237 .23077 L
.51923 .22813 L
.5 .21683 L
.49092 .21154 L
Mistroke
.48077 .20582 L
.46154 .19499 L
.45677 .19231 L
.44231 .18441 L
.42308 .17377 L
.42183 .17308 L
.40385 .16333 L
.38677 .15385 L
.38462 .15269 L
.36538 .14212 L
.35211 .13462 L
.34615 .13134 L
.32692 .12047 L
.3181 .11538 L
.30769 .10954 L
.28846 .09839 L
.28463 .09615 L
.26923 .08739 L
.25134 .07692 L
.25 .07617 L
.23077 .06522 L
.21773 .05769 L
.21154 .05427 L
.19231 .04351 L
.18326 .03846 L
.17308 .03285 L
.15385 .02268 L
.14701 .01923 L
Mfstroke
.2 g
.03846 .05251 m
.05769 .04745 L
.07692 .04797 L
.09615 .05145 L
.11538 .05685 L
.11811 .05769 L
.13462 .06367 L
.15385 .07155 L
.16602 .07692 L
.17308 .08025 L
.19231 .08967 L
.20505 .09615 L
.21154 .09959 L
.23077 .11 L
.24058 .11538 L
.25 .12072 L
.26923 .13171 L
.27431 .13462 L
.28846 .14293 L
.30709 .15385 L
.30769 .1542 L
.32692 .16569 L
.33941 .17308 L
.34615 .17713 L
.36538 .18863 L
.37161 .19231 L
.38462 .20012 L
.40384 .21154 L
.40385 .21154 L
.42308 .22309 L
.436 .23077 L
.44231 .23458 L
.46154 .24618 L
.4679 .25 L
.48077 .2579 L
.49917 .26923 L
.5 .26975 L
.51923 .28194 L
.52942 .28846 L
.53846 .29439 L
.55769 .30721 L
.5584 .30769 L
.57692 .32054 L
.58595 .32692 L
.59615 .33434 L
.61204 .34615 L
.61538 .3487 L
.63462 .36371 L
.63671 .36538 L
.65385 .37943 L
.66001 .38462 L
.67308 .3959 L
.68204 .40385 L
.69231 .4132 L
.70287 .42308 L
.71154 .43142 L
.72255 .44231 L
.73077 .45066 L
.74116 .46154 L
.75 .47107 L
.75873 .48077 L
.76923 .49281 L
.7753 .5 L
.78846 .51614 L
.7909 .51923 L
.80553 .53846 L
.80769 .5414 L
.8192 .55769 L
.82692 .56917 L
.83191 .57692 L
.84366 .59615 L
.84615 .60043 L
.85439 .61538 L
.86412 .63462 L
.86538 .63727 L
.87272 .65385 L
.88018 .67308 L
.88462 .68625 L
.88638 .69231 L
.89118 .71154 L
.89441 .73077 L
.89582 .75 L
.89502 .76923 L
.89142 .78846 L
.88462 .80646 L
.88395 .80769 L
.87043 .82692 L
.86538 .83191 L
.84615 .8452 L
.84432 .84615 L
.82692 .85295 L
.80769 .85722 L
.78846 .859 L
.76923 .85886 L
.75 .85713 L
.73077 .85407 L
.71154 .84983 L
.69765 .84615 L
.69231 .84455 L
.67308 .83828 L
.65385 .83114 L
.64338 .82692 L
.63462 .82316 L
.61538 .81437 L
.60174 .80769 L
.59615 .80483 L
.57692 .7945 L
.5662 .78846 L
.55769 .78347 L
.53846 .77169 L
.53457 .76923 L
.51923 .75917 L
.50577 .75 L
.5 .74594 L
.48077 .73195 L
.47919 .73077 L
.46154 .71716 L
.45446 .71154 L
.44231 .7016 L
.43127 .69231 L
.42308 .68521 L
.40945 .67308 L
.40385 .66795 L
.38884 .65385 L
.38462 .64977 L
.36933 .63462 L
.36538 .6306 L
.35082 .61538 L
.34615 .61039 L
.33322 .59615 L
.32692 .58905 L
.31645 .57692 L
.30769 .56653 L
.30043 .55769 L
.28846 .54278 L
.28509 .53846 L
.27033 .51923 L
.26923 .51777 L
.25613 .5 L
.25 .49155 L
.24234 .48077 L
.23077 .46431 L
.22886 .46154 L
.21567 .44231 L
.21154 .43625 L
.20267 .42308 L
.19231 .40771 L
.18974 .40385 L
.17689 .38462 L
.17308 .37892 L
.16411 .36538 L
.15385 .35002 L
.1513 .34615 L
.13856 .32692 L
.13462 .32098 L
.12592 .30769 L
.11538 .29163 L
.11334 .28846 L
.10101 .26923 L
.09615 .26161 L
.08895 .25 L
.07719 .23077 L
.07692 .23032 L
.06601 .21154 L
.05769 .19666 L
.05538 .19231 L
.04556 .17308 L
.03846 .15797 L
.03671 .15385 L
.02919 .13462 L
.02344 .11538 L
.02019 .09615 L
.02152 .07692 L
.03128 .05769 L
F
0 g
.03846 .05251 m
.05769 .04745 L
.07692 .04797 L
.09615 .05145 L
.11538 .05685 L
.11811 .05769 L
.13462 .06367 L
.15385 .07155 L
.16602 .07692 L
.17308 .08025 L
.19231 .08967 L
.20505 .09615 L
.21154 .09959 L
.23077 .11 L
.24058 .11538 L
.25 .12072 L
.26923 .13171 L
.27431 .13462 L
.28846 .14293 L
.30709 .15385 L
.30769 .1542 L
.32692 .16569 L
.33941 .17308 L
.34615 .17713 L
.36538 .18863 L
.37161 .19231 L
.38462 .20012 L
.40384 .21154 L
.40385 .21154 L
.42308 .22309 L
.436 .23077 L
.44231 .23458 L
.46154 .24618 L
.4679 .25 L
.48077 .2579 L
.49917 .26923 L
.5 .26975 L
.51923 .28194 L
.52942 .28846 L
.53846 .29439 L
.55769 .30721 L
.5584 .30769 L
.57692 .32054 L
.58595 .32692 L
.59615 .33434 L
.61204 .34615 L
.61538 .3487 L
.63462 .36371 L
.63671 .36538 L
.65385 .37943 L
Mistroke
.66001 .38462 L
.67308 .3959 L
.68204 .40385 L
.69231 .4132 L
.70287 .42308 L
.71154 .43142 L
.72255 .44231 L
.73077 .45066 L
.74116 .46154 L
.75 .47107 L
.75873 .48077 L
.76923 .49281 L
.7753 .5 L
.78846 .51614 L
.7909 .51923 L
.80553 .53846 L
.80769 .5414 L
.8192 .55769 L
.82692 .56917 L
.83191 .57692 L
.84366 .59615 L
.84615 .60043 L
.85439 .61538 L
.86412 .63462 L
.86538 .63727 L
.87272 .65385 L
.88018 .67308 L
.88462 .68625 L
.88638 .69231 L
.89118 .71154 L
.89441 .73077 L
.89582 .75 L
.89502 .76923 L
.89142 .78846 L
.88462 .80646 L
.88395 .80769 L
.87043 .82692 L
.86538 .83191 L
.84615 .8452 L
.84432 .84615 L
.82692 .85295 L
.80769 .85722 L
.78846 .859 L
.76923 .85886 L
.75 .85713 L
.73077 .85407 L
.71154 .84983 L
.69765 .84615 L
.69231 .84455 L
.67308 .83828 L
Mistroke
.65385 .83114 L
.64338 .82692 L
.63462 .82316 L
.61538 .81437 L
.60174 .80769 L
.59615 .80483 L
.57692 .7945 L
.5662 .78846 L
.55769 .78347 L
.53846 .77169 L
.53457 .76923 L
.51923 .75917 L
.50577 .75 L
.5 .74594 L
.48077 .73195 L
.47919 .73077 L
.46154 .71716 L
.45446 .71154 L
.44231 .7016 L
.43127 .69231 L
.42308 .68521 L
.40945 .67308 L
.40385 .66795 L
.38884 .65385 L
.38462 .64977 L
.36933 .63462 L
.36538 .6306 L
.35082 .61538 L
.34615 .61039 L
.33322 .59615 L
.32692 .58905 L
.31645 .57692 L
.30769 .56653 L
.30043 .55769 L
.28846 .54278 L
.28509 .53846 L
.27033 .51923 L
.26923 .51777 L
.25613 .5 L
.25 .49155 L
.24234 .48077 L
.23077 .46431 L
.22886 .46154 L
.21567 .44231 L
.21154 .43625 L
.20267 .42308 L
.19231 .40771 L
.18974 .40385 L
.17689 .38462 L
.17308 .37892 L
Mistroke
.16411 .36538 L
.15385 .35002 L
.1513 .34615 L
.13856 .32692 L
.13462 .32098 L
.12592 .30769 L
.11538 .29163 L
.11334 .28846 L
.10101 .26923 L
.09615 .26161 L
.08895 .25 L
.07719 .23077 L
.07692 .23032 L
.06601 .21154 L
.05769 .19666 L
.05538 .19231 L
.04556 .17308 L
.03846 .15797 L
.03671 .15385 L
.02919 .13462 L
.02344 .11538 L
.02019 .09615 L
.02152 .07692 L
.03128 .05769 L
.03846 .05251 L
Mfstroke
.3 g
.09615 .10303 m
.11538 .10037 L
.13462 .10246 L
.15385 .10722 L
.17308 .11372 L
.17762 .11538 L
.19231 .12148 L
.21154 .13021 L
.22073 .13462 L
.23077 .13968 L
.25 .14975 L
.25762 .15385 L
.26923 .16029 L
.28846 .17118 L
.29177 .17308 L
.30769 .1824 L
.32446 .19231 L
.32692 .19378 L
.34615 .2054 L
.35631 .21154 L
.36538 .2171 L
.38462 .22889 L
.38768 .23077 L
.40385 .2408 L
.41871 .25 L
.42308 .25274 L
.44231 .26481 L
.44936 .26923 L
.46154 .27698 L
.4795 .28846 L
.48077 .28928 L
.5 .30184 L
.50888 .30769 L
.51923 .31464 L
.53726 .32692 L
.53846 .32776 L
.55769 .34132 L
.56442 .34615 L
.57692 .35535 L
.59026 .36538 L
.59615 .36993 L
.61473 .38462 L
.61538 .38514 L
.63462 .40111 L
.63782 .40385 L
.65385 .4179 L
.65959 .42308 L
.67308 .43561 L
.68007 .44231 L
.69231 .45439 L
.69932 .46154 L
.71154 .4744 L
.71739 .48077 L
.73077 .49586 L
.73431 .5 L
.75 .51909 L
.75011 .51923 L
.76479 .53846 L
.76923 .54457 L
.77836 .55769 L
.78846 .57312 L
.79083 .57692 L
.80214 .59615 L
.80769 .60637 L
.81226 .61538 L
.82112 .63462 L
.82692 .64904 L
.82863 .65385 L
.83464 .67308 L
.83896 .69231 L
.84131 .71154 L
.84123 .73077 L
.83797 .75 L
.83011 .76923 L
.82692 .77439 L
.81414 .78846 L
.80769 .79332 L
.78846 .8029 L
.7698 .80769 L
.76923 .80777 L
.75 .80957 L
.73077 .80912 L
.71714 .80769 L
.71154 .80687 L
.69231 .80313 L
.67308 .79809 L
.65385 .7919 L
.6443 .78846 L
.63462 .78466 L
.61538 .77644 L
.60004 .76923 L
.59615 .7673 L
.57692 .75725 L
.56393 .75 L
.55769 .74636 L
.53846 .7346 L
.53245 .73077 L
.51923 .722 L
.50415 .71154 L
.5 .70856 L
.48077 .69424 L
.47825 .69231 L
.46154 .67903 L
.4543 .67308 L
.44231 .66291 L
.43196 .65385 L
.42308 .64583 L
.41101 .63462 L
.40385 .62776 L
.39128 .61538 L
.38462 .60864 L
.37262 .59615 L
.36538 .58842 L
.35491 .57692 L
.34615 .56706 L
.33804 .55769 L
.32692 .54455 L
.3219 .53846 L
.30769 .52089 L
.30638 .51923 L
.29142 .5 L
.28846 .49614 L
.27691 .48077 L
.26923 .47042 L
.26274 .46154 L
.25 .44393 L
.24884 .44231 L
.23519 .42308 L
.23077 .41682 L
.22171 .40385 L
.21154 .38926 L
.20834 .38462 L
.19512 .36538 L
.19231 .36128 L
.18207 .34615 L
.17308 .33281 L
.16917 .32692 L
.1565 .30769 L
.15385 .30363 L
.14416 .28846 L
.13462 .27323 L
.13218 .26923 L
.12073 .25 L
.11538 .24073 L
.10993 .23077 L
.09997 .21154 L
.09615 .20392 L
.09111 .19231 L
.08373 .17308 L
.07848 .15385 L
.07692 .14331 L
.07659 .13462 L
.07692 .13007 L
.08104 .11538 L
F
0 g
.09615 .10303 m
.11538 .10037 L
.13462 .10246 L
.15385 .10722 L
.17308 .11372 L
.17762 .11538 L
.19231 .12148 L
.21154 .13021 L
.22073 .13462 L
.23077 .13968 L
.25 .14975 L
.25762 .15385 L
.26923 .16029 L
.28846 .17118 L
.29177 .17308 L
.30769 .1824 L
.32446 .19231 L
.32692 .19378 L
.34615 .2054 L
.35631 .21154 L
.36538 .2171 L
.38462 .22889 L
.38768 .23077 L
.40385 .2408 L
.41871 .25 L
.42308 .25274 L
.44231 .26481 L
.44936 .26923 L
.46154 .27698 L
.4795 .28846 L
.48077 .28928 L
.5 .30184 L
.50888 .30769 L
.51923 .31464 L
.53726 .32692 L
.53846 .32776 L
.55769 .34132 L
.56442 .34615 L
.57692 .35535 L
.59026 .36538 L
.59615 .36993 L
.61473 .38462 L
.61538 .38514 L
.63462 .40111 L
.63782 .40385 L
.65385 .4179 L
.65959 .42308 L
.67308 .43561 L
.68007 .44231 L
.69231 .45439 L
Mistroke
.69932 .46154 L
.71154 .4744 L
.71739 .48077 L
.73077 .49586 L
.73431 .5 L
.75 .51909 L
.75011 .51923 L
.76479 .53846 L
.76923 .54457 L
.77836 .55769 L
.78846 .57312 L
.79083 .57692 L
.80214 .59615 L
.80769 .60637 L
.81226 .61538 L
.82112 .63462 L
.82692 .64904 L
.82863 .65385 L
.83464 .67308 L
.83896 .69231 L
.84131 .71154 L
.84123 .73077 L
.83797 .75 L
.83011 .76923 L
.82692 .77439 L
.81414 .78846 L
.80769 .79332 L
.78846 .8029 L
.7698 .80769 L
.76923 .80777 L
.75 .80957 L
.73077 .80912 L
.71714 .80769 L
.71154 .80687 L
.69231 .80313 L
.67308 .79809 L
.65385 .7919 L
.6443 .78846 L
.63462 .78466 L
.61538 .77644 L
.60004 .76923 L
.59615 .7673 L
.57692 .75725 L
.56393 .75 L
.55769 .74636 L
.53846 .7346 L
.53245 .73077 L
.51923 .722 L
.50415 .71154 L
.5 .70856 L
Mistroke
.48077 .69424 L
.47825 .69231 L
.46154 .67903 L
.4543 .67308 L
.44231 .66291 L
.43196 .65385 L
.42308 .64583 L
.41101 .63462 L
.40385 .62776 L
.39128 .61538 L
.38462 .60864 L
.37262 .59615 L
.36538 .58842 L
.35491 .57692 L
.34615 .56706 L
.33804 .55769 L
.32692 .54455 L
.3219 .53846 L
.30769 .52089 L
.30638 .51923 L
.29142 .5 L
.28846 .49614 L
.27691 .48077 L
.26923 .47042 L
.26274 .46154 L
.25 .44393 L
.24884 .44231 L
.23519 .42308 L
.23077 .41682 L
.22171 .40385 L
.21154 .38926 L
.20834 .38462 L
.19512 .36538 L
.19231 .36128 L
.18207 .34615 L
.17308 .33281 L
.16917 .32692 L
.1565 .30769 L
.15385 .30363 L
.14416 .28846 L
.13462 .27323 L
.13218 .26923 L
.12073 .25 L
.11538 .24073 L
.10993 .23077 L
.09997 .21154 L
.09615 .20392 L
.09111 .19231 L
.08373 .17308 L
.07848 .15385 L
Mistroke
.07692 .14331 L
.07659 .13462 L
.07692 .13007 L
.08104 .11538 L
.09615 .10303 L
Mfstroke
.4 g
.13462 .14809 m
.15385 .14341 L
.17308 .14526 L
.19231 .15013 L
.20465 .15385 L
.21154 .15685 L
.23077 .16492 L
.24828 .17308 L
.25 .17395 L
.26923 .18374 L
.28524 .19231 L
.28846 .1941 L
.30769 .20494 L
.31913 .21154 L
.32692 .21614 L
.34615 .22763 L
.35136 .23077 L
.36538 .23936 L
.3826 .25 L
.38462 .25126 L
.40385 .26336 L
.41312 .26923 L
.42308 .2756 L
.44231 .28799 L
.44304 .28846 L
.46154 .30059 L
.4723 .30769 L
.48077 .31337 L
.5 .3264 L
.50077 .32692 L
.51923 .33977 L
.52825 .34615 L
.53846 .35351 L
.55461 .36538 L
.55769 .3677 L
.57692 .38244 L
.57969 .38462 L
.59615 .39783 L
.60344 .40385 L
.61538 .41396 L
.62584 .42308 L
.63462 .43095 L
.64688 .44231 L
.65385 .44895 L
.6666 .46154 L
.67308 .46814 L
.68503 .48077 L
.69231 .48875 L
.70218 .5 L
.71154 .51112 L
.71809 .51923 L
.73077 .53576 L
.73275 .53846 L
.74615 .55769 L
.75 .56355 L
.75828 .57692 L
.76908 .59615 L
.76923 .59644 L
.77845 .61538 L
.78631 .63462 L
.78846 .64021 L
.79245 .65385 L
.79662 .67308 L
.7984 .69231 L
.79707 .71154 L
.79126 .73077 L
.78846 .73643 L
.77759 .75 L
.76923 .75662 L
.75 .76558 L
.73279 .76923 L
.73077 .76947 L
.71154 .77017 L
.69795 .76923 L
.69231 .76855 L
.67308 .76508 L
.65385 .76008 L
.63462 .75374 L
.62462 .75 L
.61538 .7462 L
.59615 .73754 L
.58247 .73077 L
.57692 .72786 L
.55769 .71716 L
.5482 .71154 L
.53846 .7055 L
.51923 .69288 L
.51838 .69231 L
.5 .6793 L
.49161 .67308 L
.48077 .66475 L
.46713 .65385 L
.46154 .64922 L
.4445 .63462 L
.44231 .63267 L
.42339 .61538 L
.42308 .61509 L
.40385 .59642 L
.40358 .59615 L
.38488 .57692 L
.38462 .57664 L
.36714 .55769 L
.36538 .55573 L
.35023 .53846 L
.34615 .5337 L
.33402 .51923 L
.32692 .51058 L
.3184 .5 L
.30769 .48645 L
.30328 .48077 L
.28855 .46154 L
.28846 .46142 L
.27419 .44231 L
.26923 .43559 L
.26011 .42308 L
.25 .40908 L
.24627 .40385 L
.23266 .38462 L
.23077 .38193 L
.21931 .36538 L
.21154 .35405 L
.20621 .34615 L
.19343 .32692 L
.19231 .32522 L
.18106 .30769 L
.17308 .29492 L
.16917 .28846 L
.15792 .26923 L
.15385 .26206 L
.1475 .25 L
.13815 .23077 L
.13462 .22381 L
.1303 .21154 L
.12457 .19231 L
.12239 .17308 L
.12812 .15385 L
F
0 g
.13462 .14809 m
.15385 .14341 L
.17308 .14526 L
.19231 .15013 L
.20465 .15385 L
.21154 .15685 L
.23077 .16492 L
.24828 .17308 L
.25 .17395 L
.26923 .18374 L
.28524 .19231 L
.28846 .1941 L
.30769 .20494 L
.31913 .21154 L
.32692 .21614 L
.34615 .22763 L
.35136 .23077 L
.36538 .23936 L
.3826 .25 L
.38462 .25126 L
.40385 .26336 L
.41312 .26923 L
.42308 .2756 L
.44231 .28799 L
.44304 .28846 L
.46154 .30059 L
.4723 .30769 L
.48077 .31337 L
.5 .3264 L
.50077 .32692 L
.51923 .33977 L
.52825 .34615 L
.53846 .35351 L
.55461 .36538 L
.55769 .3677 L
.57692 .38244 L
.57969 .38462 L
.59615 .39783 L
.60344 .40385 L
.61538 .41396 L
.62584 .42308 L
.63462 .43095 L
.64688 .44231 L
.65385 .44895 L
.6666 .46154 L
.67308 .46814 L
.68503 .48077 L
.69231 .48875 L
.70218 .5 L
.71154 .51112 L
Mistroke
.71809 .51923 L
.73077 .53576 L
.73275 .53846 L
.74615 .55769 L
.75 .56355 L
.75828 .57692 L
.76908 .59615 L
.76923 .59644 L
.77845 .61538 L
.78631 .63462 L
.78846 .64021 L
.79245 .65385 L
.79662 .67308 L
.7984 .69231 L
.79707 .71154 L
.79126 .73077 L
.78846 .73643 L
.77759 .75 L
.76923 .75662 L
.75 .76558 L
.73279 .76923 L
.73077 .76947 L
.71154 .77017 L
.69795 .76923 L
.69231 .76855 L
.67308 .76508 L
.65385 .76008 L
.63462 .75374 L
.62462 .75 L
.61538 .7462 L
.59615 .73754 L
.58247 .73077 L
.57692 .72786 L
.55769 .71716 L
.5482 .71154 L
.53846 .7055 L
.51923 .69288 L
.51838 .69231 L
.5 .6793 L
.49161 .67308 L
.48077 .66475 L
.46713 .65385 L
.46154 .64922 L
.4445 .63462 L
.44231 .63267 L
.42339 .61538 L
.42308 .61509 L
.40385 .59642 L
.40358 .59615 L
.38488 .57692 L
Mistroke
.38462 .57664 L
.36714 .55769 L
.36538 .55573 L
.35023 .53846 L
.34615 .5337 L
.33402 .51923 L
.32692 .51058 L
.3184 .5 L
.30769 .48645 L
.30328 .48077 L
.28855 .46154 L
.28846 .46142 L
.27419 .44231 L
.26923 .43559 L
.26011 .42308 L
.25 .40908 L
.24627 .40385 L
.23266 .38462 L
.23077 .38193 L
.21931 .36538 L
.21154 .35405 L
.20621 .34615 L
.19343 .32692 L
.19231 .32522 L
.18106 .30769 L
.17308 .29492 L
.16917 .28846 L
.15792 .26923 L
.15385 .26206 L
.1475 .25 L
.13815 .23077 L
.13462 .22381 L
.1303 .21154 L
.12457 .19231 L
.12239 .17308 L
.12812 .15385 L
.13462 .14809 L
Mfstroke
.5 g
.17308 .18605 m
.19231 .18168 L
.21154 .18414 L
.23077 .18961 L
.2393 .19231 L
.25 .19687 L
.26923 .20545 L
.28189 .21154 L
.28846 .21495 L
.30769 .22517 L
.31784 .23077 L
.32692 .23595 L
.34615 .24717 L
.35092 .25 L
.36538 .25876 L
.38236 .26923 L
.38462 .27064 L
.40385 .28281 L
.41268 .28846 L
.42308 .2952 L
.44211 .30769 L
.44231 .30782 L
.46154 .32072 L
.47067 .32692 L
.48077 .33388 L
.49831 .34615 L
.5 .34736 L
.51923 .36122 L
.5249 .36538 L
.53846 .37554 L
.55031 .38462 L
.55769 .39039 L
.57445 .40385 L
.57692 .40588 L
.59615 .42213 L
.59725 .42308 L
.61538 .43928 L
.61867 .44231 L
.63462 .4575 L
.63871 .46154 L
.65385 .47703 L
.65736 .48077 L
.67308 .49818 L
.67465 .5 L
.69057 .51923 L
.69231 .52143 L
.7051 .53846 L
.71154 .5476 L
.71823 .55769 L
.72989 .57692 L
.73077 .57845 L
.73999 .59615 L
.74841 .61538 L
.75 .61896 L
.7549 .63462 L
.75913 .65385 L
.76053 .67308 L
.75799 .69231 L
.75 .71037 L
.74893 .71154 L
.73077 .72707 L
.72387 .73077 L
.71154 .7337 L
.69231 .73566 L
.67308 .73458 L
.65385 .73127 L
.65141 .73077 L
.63462 .72616 L
.61538 .71951 L
.59618 .71154 L
.59615 .71152 L
.57692 .7023 L
.55837 .69231 L
.55769 .69192 L
.53846 .68043 L
.527 .67308 L
.51923 .66786 L
.5 .65423 L
.49947 .65385 L
.48077 .63954 L
.47462 .63462 L
.46154 .62376 L
.45182 .61538 L
.44231 .6069 L
.43066 .59615 L
.42308 .58893 L
.41085 .57692 L
.40385 .56983 L
.39218 .55769 L
.38462 .5496 L
.37446 .53846 L
.36538 .52824 L
.35756 .51923 L
.34615 .5058 L
.34133 .5 L
.32692 .48233 L
.32567 .48077 L
.31051 .46154 L
.30769 .4579 L
.29577 .44231 L
.28846 .43259 L
.2814 .42308 L
.26923 .40643 L
.26737 .40385 L
.25368 .38462 L
.25 .37938 L
.24035 .36538 L
.23077 .35121 L
.22743 .34615 L
.21499 .32692 L
.21154 .32148 L
.20316 .30769 L
.19231 .28884 L
.1921 .28846 L
.18204 .26923 L
.17339 .25 L
.17308 .24922 L
.1667 .23077 L
.16328 .21154 L
.1673 .19231 L
F
0 g
.17308 .18605 m
.19231 .18168 L
.21154 .18414 L
.23077 .18961 L
.2393 .19231 L
.25 .19687 L
.26923 .20545 L
.28189 .21154 L
.28846 .21495 L
.30769 .22517 L
.31784 .23077 L
.32692 .23595 L
.34615 .24717 L
.35092 .25 L
.36538 .25876 L
.38236 .26923 L
.38462 .27064 L
.40385 .28281 L
.41268 .28846 L
.42308 .2952 L
.44211 .30769 L
.44231 .30782 L
.46154 .32072 L
.47067 .32692 L
.48077 .33388 L
.49831 .34615 L
.5 .34736 L
.51923 .36122 L
.5249 .36538 L
.53846 .37554 L
.55031 .38462 L
.55769 .39039 L
.57445 .40385 L
.57692 .40588 L
.59615 .42213 L
.59725 .42308 L
.61538 .43928 L
.61867 .44231 L
.63462 .4575 L
.63871 .46154 L
.65385 .47703 L
.65736 .48077 L
.67308 .49818 L
.67465 .5 L
.69057 .51923 L
.69231 .52143 L
.7051 .53846 L
.71154 .5476 L
.71823 .55769 L
.72989 .57692 L
Mistroke
.73077 .57845 L
.73999 .59615 L
.74841 .61538 L
.75 .61896 L
.7549 .63462 L
.75913 .65385 L
.76053 .67308 L
.75799 .69231 L
.75 .71037 L
.74893 .71154 L
.73077 .72707 L
.72387 .73077 L
.71154 .7337 L
.69231 .73566 L
.67308 .73458 L
.65385 .73127 L
.65141 .73077 L
.63462 .72616 L
.61538 .71951 L
.59618 .71154 L
.59615 .71152 L
.57692 .7023 L
.55837 .69231 L
.55769 .69192 L
.53846 .68043 L
.527 .67308 L
.51923 .66786 L
.5 .65423 L
.49947 .65385 L
.48077 .63954 L
.47462 .63462 L
.46154 .62376 L
.45182 .61538 L
.44231 .6069 L
.43066 .59615 L
.42308 .58893 L
.41085 .57692 L
.40385 .56983 L
.39218 .55769 L
.38462 .5496 L
.37446 .53846 L
.36538 .52824 L
.35756 .51923 L
.34615 .5058 L
.34133 .5 L
.32692 .48233 L
.32567 .48077 L
.31051 .46154 L
.30769 .4579 L
.29577 .44231 L
Mistroke
.28846 .43259 L
.2814 .42308 L
.26923 .40643 L
.26737 .40385 L
.25368 .38462 L
.25 .37938 L
.24035 .36538 L
.23077 .35121 L
.22743 .34615 L
.21499 .32692 L
.21154 .32148 L
.20316 .30769 L
.19231 .28884 L
.1921 .28846 L
.18204 .26923 L
.17339 .25 L
.17308 .24922 L
.1667 .23077 L
.16328 .21154 L
.1673 .19231 L
.17308 .18605 L
Mfstroke
.6 g
.21154 .21903 m
.23077 .21791 L
.25 .22144 L
.26923 .22775 L
.27773 .23077 L
.28846 .23569 L
.30769 .24488 L
.31781 .25 L
.32692 .25492 L
.34615 .26566 L
.35237 .26923 L
.36538 .27693 L
.38431 .28846 L
.38462 .28865 L
.40385 .30075 L
.41465 .30769 L
.42308 .3132 L
.44231 .32598 L
.44371 .32692 L
.46154 .3391 L
.47168 .34615 L
.48077 .35258 L
.49853 .36538 L
.5 .36646 L
.51923 .38082 L
.52421 .38462 L
.53846 .39572 L
.54862 .40385 L
.55769 .41127 L
.57169 .42308 L
.57692 .42761 L
.59336 .44231 L
.59615 .44488 L
.6136 .46154 L
.61538 .4633 L
.63238 .48077 L
.63462 .48315 L
.64969 .5 L
.65385 .50486 L
.66551 .51923 L
.67308 .52911 L
.67979 .53846 L
.69231 .5574 L
.69248 .55769 L
.70348 .57692 L
.71154 .59356 L
.7126 .59615 L
.71961 .61538 L
.72403 .63462 L
.72509 .65385 L
.72105 .67308 L
.71154 .68822 L
.70672 .69231 L
.69231 .69956 L
.67308 .70321 L
.65385 .70275 L
.63462 .69953 L
.61538 .69422 L
.60945 .69231 L
.59615 .68718 L
.57692 .67862 L
.56579 .67308 L
.55769 .6687 L
.53846 .6575 L
.53258 .65385 L
.51923 .64509 L
.50426 .63462 L
.5 .6315 L
.48077 .61674 L
.47908 .61538 L
.46154 .60081 L
.45616 .59615 L
.44231 .58372 L
.435 .57692 L
.42308 .56546 L
.41525 .55769 L
.40385 .54603 L
.39665 .53846 L
.38462 .52544 L
.37902 .51923 L
.36538 .50372 L
.36219 .5 L
.34615 .4809 L
.34604 .48077 L
.33049 .46154 L
.32692 .45704 L
.31546 .44231 L
.30769 .43213 L
.30091 .42308 L
.28846 .40614 L
.28681 .40385 L
.27317 .38462 L
.26923 .37895 L
.26006 .36538 L
.25 .35004 L
.24754 .34615 L
.23574 .32692 L
.23077 .31862 L
.22488 .30769 L
.21525 .28846 L
.21154 .28365 L
.20746 .26923 L
.20245 .25 L
.20328 .23077 L
F
0 g
.21154 .21903 m
.23077 .21791 L
.25 .22144 L
.26923 .22775 L
.27773 .23077 L
.28846 .23569 L
.30769 .24488 L
.31781 .25 L
.32692 .25492 L
.34615 .26566 L
.35237 .26923 L
.36538 .27693 L
.38431 .28846 L
.38462 .28865 L
.40385 .30075 L
.41465 .30769 L
.42308 .3132 L
.44231 .32598 L
.44371 .32692 L
.46154 .3391 L
.47168 .34615 L
.48077 .35258 L
.49853 .36538 L
.5 .36646 L
.51923 .38082 L
.52421 .38462 L
.53846 .39572 L
.54862 .40385 L
.55769 .41127 L
.57169 .42308 L
.57692 .42761 L
.59336 .44231 L
.59615 .44488 L
.6136 .46154 L
.61538 .4633 L
.63238 .48077 L
.63462 .48315 L
.64969 .5 L
.65385 .50486 L
.66551 .51923 L
.67308 .52911 L
.67979 .53846 L
.69231 .5574 L
.69248 .55769 L
.70348 .57692 L
.71154 .59356 L
.7126 .59615 L
.71961 .61538 L
.72403 .63462 L
.72509 .65385 L
Mistroke
.72105 .67308 L
.71154 .68822 L
.70672 .69231 L
.69231 .69956 L
.67308 .70321 L
.65385 .70275 L
.63462 .69953 L
.61538 .69422 L
.60945 .69231 L
.59615 .68718 L
.57692 .67862 L
.56579 .67308 L
.55769 .6687 L
.53846 .6575 L
.53258 .65385 L
.51923 .64509 L
.50426 .63462 L
.5 .6315 L
.48077 .61674 L
.47908 .61538 L
.46154 .60081 L
.45616 .59615 L
.44231 .58372 L
.435 .57692 L
.42308 .56546 L
.41525 .55769 L
.40385 .54603 L
.39665 .53846 L
.38462 .52544 L
.37902 .51923 L
.36538 .50372 L
.36219 .5 L
.34615 .4809 L
.34604 .48077 L
.33049 .46154 L
.32692 .45704 L
.31546 .44231 L
.30769 .43213 L
.30091 .42308 L
.28846 .40614 L
.28681 .40385 L
.27317 .38462 L
.26923 .37895 L
.26006 .36538 L
.25 .35004 L
.24754 .34615 L
.23574 .32692 L
.23077 .31862 L
.22488 .30769 L
.21525 .28846 L
Mistroke
.21154 .28365 L
.20746 .26923 L
.20245 .25 L
.20328 .23077 L
.21154 .21903 L
Mfstroke
.7 g
.25 .25696 m
.26923 .25402 L
.28846 .25868 L
.30769 .26587 L
.31617 .26923 L
.32692 .27452 L
.34615 .28439 L
.35378 .28846 L
.36538 .29504 L
.38462 .3064 L
.38676 .30769 L
.40385 .31828 L
.41736 .32692 L
.42308 .33066 L
.44231 .34351 L
.44619 .34615 L
.46154 .3568 L
.47362 .36538 L
.48077 .37056 L
.49969 .38462 L
.5 .38485 L
.51923 .39972 L
.52441 .40385 L
.53846 .41528 L
.54774 .42308 L
.55769 .43166 L
.56961 .44231 L
.57692 .44904 L
.58997 .46154 L
.59615 .46766 L
.60879 .48077 L
.61538 .48789 L
.62601 .5 L
.63462 .51031 L
.64159 .51923 L
.65385 .53608 L
.65544 .53846 L
.66745 .55769 L
.67308 .56762 L
.67741 .57692 L
.685 .59615 L
.68963 .61538 L
.69013 .63462 L
.68359 .65385 L
.67308 .66432 L
.65385 .67091 L
.63462 .67144 L
.61538 .66844 L
.59615 .66292 L
.57692 .65539 L
.57335 .65385 L
.55769 .64619 L
.53846 .63546 L
.53703 .63462 L
.51923 .62335 L
.50759 .61538 L
.5 .6099 L
.48202 .59615 L
.48077 .59515 L
.46154 .57914 L
.45898 .57692 L
.44231 .56188 L
.43783 .55769 L
.42308 .54338 L
.41817 .53846 L
.40385 .52364 L
.3997 .51923 L
.38462 .50268 L
.38223 .5 L
.3656 .48077 L
.36538 .48052 L
.34969 .46154 L
.34615 .45716 L
.33443 .44231 L
.32692 .43256 L
.3198 .42308 L
.30769 .40653 L
.30578 .40385 L
.29239 .38462 L
.28846 .37886 L
.27975 .36538 L
.26923 .34826 L
.26803 .34615 L
.25738 .32692 L
.25 .31211 L
.24849 .30769 L
.24191 .28846 L
.23987 .26923 L
F
0 g
.25 .25696 m
.26923 .25402 L
.28846 .25868 L
.30769 .26587 L
.31617 .26923 L
.32692 .27452 L
.34615 .28439 L
.35378 .28846 L
.36538 .29504 L
.38462 .3064 L
.38676 .30769 L
.40385 .31828 L
.41736 .32692 L
.42308 .33066 L
.44231 .34351 L
.44619 .34615 L
.46154 .3568 L
.47362 .36538 L
.48077 .37056 L
.49969 .38462 L
.5 .38485 L
.51923 .39972 L
.52441 .40385 L
.53846 .41528 L
.54774 .42308 L
.55769 .43166 L
.56961 .44231 L
.57692 .44904 L
.58997 .46154 L
.59615 .46766 L
.60879 .48077 L
.61538 .48789 L
.62601 .5 L
.63462 .51031 L
.64159 .51923 L
.65385 .53608 L
.65544 .53846 L
.66745 .55769 L
.67308 .56762 L
.67741 .57692 L
.685 .59615 L
.68963 .61538 L
.69013 .63462 L
.68359 .65385 L
.67308 .66432 L
.65385 .67091 L
.63462 .67144 L
.61538 .66844 L
.59615 .66292 L
.57692 .65539 L
Mistroke
.57335 .65385 L
.55769 .64619 L
.53846 .63546 L
.53703 .63462 L
.51923 .62335 L
.50759 .61538 L
.5 .6099 L
.48202 .59615 L
.48077 .59515 L
.46154 .57914 L
.45898 .57692 L
.44231 .56188 L
.43783 .55769 L
.42308 .54338 L
.41817 .53846 L
.40385 .52364 L
.3997 .51923 L
.38462 .50268 L
.38223 .5 L
.3656 .48077 L
.36538 .48052 L
.34969 .46154 L
.34615 .45716 L
.33443 .44231 L
.32692 .43256 L
.3198 .42308 L
.30769 .40653 L
.30578 .40385 L
.29239 .38462 L
.28846 .37886 L
.27975 .36538 L
.26923 .34826 L
.26803 .34615 L
.25738 .32692 L
.25 .31211 L
.24849 .30769 L
.24191 .28846 L
.23987 .26923 L
.25 .25696 L
Mfstroke
.8 g
.28846 .2939 m
.30769 .2913 L
.32692 .29704 L
.34615 .30512 L
.35219 .30769 L
.36538 .31445 L
.38462 .32509 L
.38785 .32692 L
.40385 .33645 L
.41931 .34615 L
.42308 .34861 L
.44231 .3614 L
.44813 .36538 L
.46154 .37478 L
.4751 .38462 L
.48077 .38881 L
.5 .40355 L
.50037 .40385 L
.51923 .41902 L
.52409 .42308 L
.53846 .43539 L
.5462 .44231 L
.55769 .45288 L
.56666 .46154 L
.57692 .47179 L
.58543 .48077 L
.59615 .49259 L
.60243 .5 L
.61538 .51626 L
.61756 .51923 L
.63068 .53846 L
.63462 .54431 L
.64153 .55769 L
.64968 .57692 L
.65385 .59343 L
.65424 .59615 L
.65385 .61291 L
.65333 .61538 L
.6388 .63462 L
.63462 .63601 L
.61538 .63901 L
.59615 .63657 L
.58839 .63462 L
.57692 .631 L
.55769 .62303 L
.54233 .61538 L
.53846 .61311 L
.51923 .60151 L
.51106 .59615 L
.5 .58836 L
.48477 .57692 L
.48077 .57374 L
.46154 .55769 L
.46154 .55769 L
.44231 .54028 L
.44038 .53846 L
.42308 .52151 L
.42084 .51923 L
.40385 .50136 L
.40259 .5 L
.38541 .48077 L
.38462 .47985 L
.36915 .46154 L
.36538 .45695 L
.35375 .44231 L
.34615 .43246 L
.33919 .42308 L
.32692 .40595 L
.32549 .40385 L
.31266 .38462 L
.30769 .37718 L
.30103 .36538 L
.29092 .34615 L
.28846 .34044 L
.28315 .32692 L
.27906 .30769 L
F
0 g
.28846 .2939 m
.30769 .2913 L
.32692 .29704 L
.34615 .30512 L
.35219 .30769 L
.36538 .31445 L
.38462 .32509 L
.38785 .32692 L
.40385 .33645 L
.41931 .34615 L
.42308 .34861 L
.44231 .3614 L
.44813 .36538 L
.46154 .37478 L
.4751 .38462 L
.48077 .38881 L
.5 .40355 L
.50037 .40385 L
.51923 .41902 L
.52409 .42308 L
.53846 .43539 L
.5462 .44231 L
.55769 .45288 L
.56666 .46154 L
.57692 .47179 L
.58543 .48077 L
.59615 .49259 L
.60243 .5 L
.61538 .51626 L
.61756 .51923 L
.63068 .53846 L
.63462 .54431 L
.64153 .55769 L
.64968 .57692 L
.65385 .59343 L
.65424 .59615 L
.65385 .61291 L
.65333 .61538 L
.6388 .63462 L
.63462 .63601 L
.61538 .63901 L
.59615 .63657 L
.58839 .63462 L
.57692 .631 L
.55769 .62303 L
.54233 .61538 L
.53846 .61311 L
.51923 .60151 L
.51106 .59615 L
.5 .58836 L
Mistroke
.48477 .57692 L
.48077 .57374 L
.46154 .55769 L
.46154 .55769 L
.44231 .54028 L
.44038 .53846 L
.42308 .52151 L
.42084 .51923 L
.40385 .50136 L
.40259 .5 L
.38541 .48077 L
.38462 .47985 L
.36915 .46154 L
.36538 .45695 L
.35375 .44231 L
.34615 .43246 L
.33919 .42308 L
.32692 .40595 L
.32549 .40385 L
.31266 .38462 L
.30769 .37718 L
.30103 .36538 L
.29092 .34615 L
.28846 .34044 L
.28315 .32692 L
.27906 .30769 L
.28846 .2939 L
Mfstroke
.9 g
.32692 .33804 m
.34615 .33039 L
.36538 .33814 L
.3828 .34615 L
.38462 .34692 L
.40385 .35702 L
.41832 .36538 L
.42308 .36851 L
.44231 .38105 L
.44759 .38462 L
.46154 .39436 L
.47441 .40385 L
.48077 .40865 L
.49889 .42308 L
.5 .42397 L
.51923 .44032 L
.52145 .44231 L
.53846 .45798 L
.54209 .46154 L
.55769 .47743 L
.56073 .48077 L
.57692 .49955 L
.57728 .5 L
.59162 .51923 L
.59615 .52477 L
.60328 .53846 L
.61171 .55769 L
.61513 .57692 L
.6076 .59615 L
.59615 .60225 L
.57692 .60194 L
.55769 .59668 L
.55585 .59615 L
.53846 .58859 L
.51923 .57791 L
.51755 .57692 L
.5 .56541 L
.48923 .55769 L
.48077 .55109 L
.4654 .53846 L
.46154 .53507 L
.44418 .51923 L
.44231 .51743 L
.42482 .5 L
.42308 .4982 L
.40693 .48077 L
.40385 .47734 L
.39032 .46154 L
.38462 .45469 L
.37492 .44231 L
.36538 .42971 L
.36076 .42308 L
.34786 .40385 L
.34615 .40095 L
.33645 .38462 L
.32768 .36538 L
.32692 .36217 L
.32365 .34615 L
F
0 g
.32692 .33804 m
.34615 .33039 L
.36538 .33814 L
.3828 .34615 L
.38462 .34692 L
.40385 .35702 L
.41832 .36538 L
.42308 .36851 L
.44231 .38105 L
.44759 .38462 L
.46154 .39436 L
.47441 .40385 L
.48077 .40865 L
.49889 .42308 L
.5 .42397 L
.51923 .44032 L
.52145 .44231 L
.53846 .45798 L
.54209 .46154 L
.55769 .47743 L
.56073 .48077 L
.57692 .49955 L
.57728 .5 L
.59162 .51923 L
.59615 .52477 L
.60328 .53846 L
.61171 .55769 L
.61513 .57692 L
.6076 .59615 L
.59615 .60225 L
.57692 .60194 L
.55769 .59668 L
.55585 .59615 L
.53846 .58859 L
.51923 .57791 L
.51755 .57692 L
.5 .56541 L
.48923 .55769 L
.48077 .55109 L
.4654 .53846 L
.46154 .53507 L
.44418 .51923 L
.44231 .51743 L
.42482 .5 L
.42308 .4982 L
.40693 .48077 L
.40385 .47734 L
.39032 .46154 L
.38462 .45469 L
.37492 .44231 L
Mistroke
.36538 .42971 L
.36076 .42308 L
.34786 .40385 L
.34615 .40095 L
.33645 .38462 L
.32768 .36538 L
.32692 .36217 L
.32365 .34615 L
.32692 .33804 L
Mfstroke
1 g
.38462 .3852 m
.40385 .38691 L
.42308 .39401 L
.43833 .40385 L
.44231 .40541 L
.46154 .41893 L
.46735 .42308 L
.48077 .43313 L
.49177 .44231 L
.5 .44909 L
.51295 .46154 L
.51923 .46696 L
.53136 .48077 L
.53846 .48719 L
.54676 .5 L
.55769 .51817 L
.55826 .51923 L
.56598 .53846 L
.55769 .5544 L
.53846 .55505 L
.51923 .54877 L
.50206 .53846 L
.5 .53748 L
.48077 .5238 L
.47475 .51923 L
.46154 .50805 L
.45267 .5 L
.44231 .48997 L
.43356 .48077 L
.42308 .46938 L
.41672 .46154 L
.40385 .44501 L
.40209 .44231 L
.3881 .42308 L
.38462 .41332 L
.37986 .40385 L
F
0 g
.38462 .3852 m
.40385 .38691 L
.42308 .39401 L
.43833 .40385 L
.44231 .40541 L
.46154 .41893 L
.46735 .42308 L
.48077 .43313 L
.49177 .44231 L
.5 .44909 L
.51295 .46154 L
.51923 .46696 L
.53136 .48077 L
.53846 .48719 L
.54676 .5 L
.55769 .51817 L
.55826 .51923 L
.56598 .53846 L
.55769 .5544 L
.53846 .55505 L
.51923 .54877 L
.50206 .53846 L
.5 .53748 L
.48077 .5238 L
.47475 .51923 L
.46154 .50805 L
.45267 .5 L
.44231 .48997 L
.43356 .48077 L
.42308 .46938 L
.41672 .46154 L
.40385 .44501 L
.40209 .44231 L
.3881 .42308 L
.38462 .41332 L
.37986 .40385 L
.38462 .3852 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.522676 0.0238095 0.97619 0.477324 MathSubStart
%% SurfaceGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1.04977 -0.0679587 1.04977 [
[ 0 0 0 0 ]
[ 1 .81114 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.39787 .81114 L
s
.39787 .81114 m
.40529 .59895 L
s
.40529 .59895 m
.03716 .25514 L
s
.68874 0 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.68874 0 m
.03716 .25514 L
s
.40529 .59895 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.39787 .81114 L
s
.39787 .81114 m
.40529 .59895 L
s
0 0 m
1 0 L
1 .81114 L
0 .81114 L
closepath
clip
newpath
.664 .741 .908 r
.39902 .59803 .40512 .60371 .41537 .60064 .40929 .59494 Mtetra
.40929 .59494 .41537 .60064 .42565 .59755 .4196 .59183 Mtetra
.4196 .59183 .42565 .59755 .43597 .59446 .42994 .58871 Mtetra
.42994 .58871 .43597 .59446 .44633 .59135 .44033 .58558 Mtetra
.44033 .58558 .44633 .59135 .45674 .58823 .45076 .58244 Mtetra
.45076 .58244 .45674 .58823 .46718 .5851 .46122 .57928 Mtetra
.46122 .57928 .46718 .5851 .47766 .58195 .47173 .57611 Mtetra
.47173 .57611 .47766 .58195 .48818 .5788 .48228 .57294 Mtetra
.48228 .57294 .48818 .5788 .49874 .57563 .49287 .56974 Mtetra
.49287 .56974 .49874 .57563 .50935 .57245 .5035 .56654 Mtetra
.5035 .56654 .50935 .57245 .51999 .56925 .51417 .56332 Mtetra
.51417 .56332 .51999 .56925 .53068 .56605 .52489 .5601 Mtetra
.663 .741 .908 r
.52489 .5601 .53068 .56605 .54141 .56283 .53564 .55686 Mtetra
.53564 .55686 .54141 .56283 .55218 .5596 .54644 .5536 Mtetra
.54644 .5536 .55218 .5596 .56299 .55636 .55728 .55034 Mtetra
.55728 .55034 .56299 .55636 .57385 .55311 .56816 .54707 Mtetra
.56816 .54707 .57385 .55311 .58474 .54984 .57909 .54379 Mtetra
.663 .742 .908 r
.57909 .54379 .58474 .54984 .59568 .54657 .59006 .5405 Mtetra
.663 .742 .909 r
.59006 .5405 .59568 .54657 .60667 .54329 .60107 .5372 Mtetra
.662 .742 .909 r
.60107 .5372 .60667 .54329 .6177 .54 .61213 .5339 Mtetra
.662 .742 .91 r
.61213 .5339 .6177 .54 .62877 .53671 .62323 .5306 Mtetra
.661 .743 .91 r
.62323 .5306 .62877 .53671 .63988 .53341 .63438 .52731 Mtetra
.66 .743 .911 r
.63438 .52731 .63988 .53341 .65104 .53012 .64557 .52403 Mtetra
.659 .744 .913 r
.64557 .52403 .65104 .53012 .66225 .52684 .65681 .52076 Mtetra
.658 .745 .914 r
.65681 .52076 .66225 .52684 .6735 .52356 .6681 .51752 Mtetra
.656 .746 .916 r
.6681 .51752 .6735 .52356 .6848 .52031 .67943 .51432 Mtetra
.654 .748 .919 r
.67943 .51432 .6848 .52031 .69615 .51708 .69082 .51115 Mtetra
.651 .75 .922 r
.69082 .51115 .69615 .51708 .70755 .51388 .70225 .50803 Mtetra
.648 .753 .926 r
.70225 .50803 .70755 .51388 .719 .51072 .71374 .50497 Mtetra
.645 .757 .93 r
.71374 .50497 .719 .51072 .7305 .5076 .72528 .50197 Mtetra
.641 .761 .935 r
.72528 .50197 .7305 .5076 .74205 .50452 .73688 .49904 Mtetra
.637 .765 .94 r
.73688 .49904 .74205 .50452 .75365 .50149 .74853 .49616 Mtetra
.633 .77 .946 r
.74853 .49616 .75365 .50149 .76531 .4985 .76024 .49334 Mtetra
.628 .776 .952 r
.76024 .49334 .76531 .4985 .77703 .49555 .77201 .49056 Mtetra
.624 .783 .958 r
.77201 .49056 .77703 .49555 .78879 .49263 .78383 .48781 Mtetra
.62 .789 .963 r
.78383 .48781 .78879 .49263 .80062 .48972 .79571 .48507 Mtetra
.617 .796 .968 r
.79571 .48507 .80062 .48972 .81249 .4868 .80764 .4823 Mtetra
.616 .803 .971 r
.80764 .4823 .81249 .4868 .82442 .48386 .81962 .47949 Mtetra
.616 .809 .974 r
.81962 .47949 .82442 .48386 .8364 .48087 .83166 .47659 Mtetra
.619 .815 .976 r
.83166 .47659 .8364 .48087 .84843 .47781 .84374 .47358 Mtetra
.623 .82 .976 r
.84374 .47358 .84843 .47781 .8605 .47465 .85586 .47044 Mtetra
.63 .824 .975 r
.85586 .47044 .8605 .47465 .87262 .47138 .86801 .46713 Mtetra
.638 .827 .973 r
.86801 .46713 .87262 .47138 .88477 .46797 .88021 .46363 Mtetra
.646 .827 .97 r
.88021 .46363 .88477 .46797 .89696 .46441 .89243 .45995 Mtetra
.655 .826 .965 r
.89243 .45995 .89696 .46441 .90919 .46071 .90469 .45608 Mtetra
.664 .824 .96 r
.90469 .45608 .90919 .46071 .92145 .45685 .91698 .45203 Mtetra
.672 .819 .954 r
.91698 .45203 .92145 .45685 .93374 .45286 .92929 .44781 Mtetra
.678 .814 .948 r
.92929 .44781 .93374 .45286 .94607 .44874 .94164 .44346 Mtetra
.682 .807 .942 r
.94164 .44346 .94607 .44874 .95844 .44452 .95403 .43899 Mtetra
.685 .8 .936 r
.95403 .43899 .95844 .44452 .97085 .44021 .96645 .43444 Mtetra
.664 .741 .908 r
.39287 .59231 .39902 .59803 .40929 .59494 .40317 .58919 Mtetra
.40317 .58919 .40929 .59494 .4196 .59183 .4135 .58606 Mtetra
.4135 .58606 .4196 .59183 .42994 .58871 .42387 .58292 Mtetra
.42387 .58292 .42994 .58871 .44033 .58558 .43428 .57977 Mtetra
.43428 .57977 .44033 .58558 .45076 .58244 .44474 .5766 Mtetra
.44474 .5766 .45076 .58244 .46122 .57928 .45523 .57343 Mtetra
.45523 .57343 .46122 .57928 .47173 .57611 .46576 .57024 Mtetra
.46576 .57024 .47173 .57611 .48228 .57294 .47634 .56703 Mtetra
.47634 .56703 .48228 .57294 .49287 .56974 .48695 .56382 Mtetra
.48695 .56382 .49287 .56974 .5035 .56654 .49761 .56059 Mtetra
.49761 .56059 .5035 .56654 .51417 .56332 .50831 .55735 Mtetra
.663 .741 .908 r
.50831 .55735 .51417 .56332 .52489 .5601 .51905 .5541 Mtetra
.51905 .5541 .52489 .5601 .53564 .55686 .52983 .55084 Mtetra
.52983 .55084 .53564 .55686 .54644 .5536 .54066 .54757 Mtetra
.54066 .54757 .54644 .5536 .55728 .55034 .55153 .54428 Mtetra
.55153 .54428 .55728 .55034 .56816 .54707 .56244 .54099 Mtetra
.663 .742 .908 r
.56244 .54099 .56816 .54707 .57909 .54379 .57339 .53769 Mtetra
.663 .742 .909 r
.57339 .53769 .57909 .54379 .59006 .5405 .58439 .53439 Mtetra
.662 .742 .909 r
.58439 .53439 .59006 .5405 .60107 .5372 .59544 .53108 Mtetra
.662 .742 .91 r
.59544 .53108 .60107 .5372 .61213 .5339 .60652 .52778 Mtetra
.661 .743 .911 r
.60652 .52778 .61213 .5339 .62323 .5306 .61765 .52449 Mtetra
.66 .743 .912 r
.61765 .52449 .62323 .5306 .63438 .52731 .62883 .52121 Mtetra
.658 .744 .913 r
.62883 .52121 .63438 .52731 .64557 .52403 .64006 .51796 Mtetra
.657 .745 .915 r
.64006 .51796 .64557 .52403 .65681 .52076 .65133 .51473 Mtetra
.655 .747 .918 r
.65133 .51473 .65681 .52076 .6681 .51752 .66265 .51155 Mtetra
.652 .749 .921 r
.66265 .51155 .6681 .51752 .67943 .51432 .67402 .50843 Mtetra
.649 .752 .925 r
.67402 .50843 .67943 .51432 .69082 .51115 .68545 .50537 Mtetra
.645 .755 .929 r
.68545 .50537 .69082 .51115 .70225 .50803 .69692 .50238 Mtetra
.64 .759 .934 r
.69692 .50238 .70225 .50803 .71374 .50497 .70846 .49947 Mtetra
.635 .764 .94 r
.70846 .49947 .71374 .50497 .72528 .50197 .72005 .49664 Mtetra
.629 .769 .947 r
.72005 .49664 .72528 .50197 .73688 .49904 .73169 .4939 Mtetra
.623 .775 .954 r
.73169 .4939 .73688 .49904 .74853 .49616 .7434 .49123 Mtetra
.616 .782 .961 r
.7434 .49123 .74853 .49616 .76024 .49334 .75516 .48863 Mtetra
.61 .79 .968 r
.75516 .48863 .76024 .49334 .77201 .49056 .76698 .48607 Mtetra
.603 .798 .974 r
.76698 .48607 .77201 .49056 .78383 .48781 .77887 .48354 Mtetra
.598 .806 .979 r
.77887 .48354 .78383 .48781 .79571 .48507 .7908 .48099 Mtetra
.595 .814 .984 r
.7908 .48099 .79571 .48507 .80764 .4823 .8028 .47839 Mtetra
.593 .822 .987 r
.8028 .47839 .80764 .4823 .81962 .47949 .81484 .47571 Mtetra
.595 .829 .988 r
.81484 .47571 .81962 .47949 .83166 .47659 .82693 .4729 Mtetra
.6 .836 .989 r
.82693 .4729 .83166 .47659 .84374 .47358 .83906 .46992 Mtetra
.608 .841 .988 r
.83906 .46992 .84374 .47358 .85586 .47044 .85122 .46675 Mtetra
.619 .845 .986 r
.85122 .46675 .85586 .47044 .86801 .46713 .86342 .46335 Mtetra
.632 .847 .982 r
.86342 .46335 .86801 .46713 .88021 .46363 .87565 .45972 Mtetra
.645 .847 .977 r
.87565 .45972 .88021 .46363 .89243 .45995 .88791 .45585 Mtetra
.658 .844 .972 r
.88791 .45585 .89243 .45995 .90469 .45608 .90019 .45175 Mtetra
.67 .84 .965 r
.90019 .45175 .90469 .45608 .91698 .45203 .9125 .44743 Mtetra
.679 .833 .957 r
.9125 .44743 .91698 .45203 .92929 .44781 .92483 .44292 Mtetra
.686 .825 .95 r
.92483 .44292 .92929 .44781 .94164 .44346 .93719 .43827 Mtetra
.691 .816 .942 r
.93719 .43827 .94164 .44346 .95403 .43899 .94959 .43351 Mtetra
.694 .806 .935 r
.94959 .43351 .95403 .43899 .96645 .43444 .96203 .42868 Mtetra
.664 .741 .908 r
.38668 .58654 .39287 .59231 .40317 .58919 .397 .5834 Mtetra
.397 .5834 .40317 .58919 .4135 .58606 .40736 .58025 Mtetra
.40736 .58025 .4135 .58606 .42387 .58292 .41776 .57709 Mtetra
.41776 .57709 .42387 .58292 .43428 .57977 .42819 .57391 Mtetra
.42819 .57391 .43428 .57977 .44474 .5766 .43867 .57073 Mtetra
.43867 .57073 .44474 .5766 .45523 .57343 .44919 .56753 Mtetra
.44919 .56753 .45523 .57343 .46576 .57024 .45975 .56431 Mtetra
.45975 .56431 .46576 .57024 .47634 .56703 .47035 .56109 Mtetra
.47035 .56109 .47634 .56703 .48695 .56382 .48099 .55785 Mtetra
.48099 .55785 .48695 .56382 .49761 .56059 .49168 .5546 Mtetra
.663 .741 .908 r
.49168 .5546 .49761 .56059 .50831 .55735 .5024 .55134 Mtetra
.5024 .55134 .50831 .55735 .51905 .5541 .51317 .54807 Mtetra
.51317 .54807 .51905 .5541 .52983 .55084 .52398 .54479 Mtetra
.52398 .54479 .52983 .55084 .54066 .54757 .53484 .54149 Mtetra
.53484 .54149 .54066 .54757 .55153 .54428 .54573 .53819 Mtetra
.663 .742 .909 r
.54573 .53819 .55153 .54428 .56244 .54099 .55667 .53488 Mtetra
.55667 .53488 .56244 .54099 .57339 .53769 .56766 .53157 Mtetra
.662 .742 .909 r
.56766 .53157 .57339 .53769 .58439 .53439 .57869 .52826 Mtetra
.661 .742 .91 r
.57869 .52826 .58439 .53439 .59544 .53108 .58976 .52495 Mtetra
.66 .743 .911 r
.58976 .52495 .59544 .53108 .60652 .52778 .60088 .52166 Mtetra
.659 .744 .912 r
.60088 .52166 .60652 .52778 .61765 .52449 .61204 .51839 Mtetra
.658 .745 .914 r
.61204 .51839 .61765 .52449 .62883 .52121 .62325 .51514 Mtetra
.656 .746 .916 r
.62325 .51514 .62883 .52121 .64006 .51796 .63451 .51194 Mtetra
.653 .748 .919 r
.63451 .51194 .64006 .51796 .65133 .51473 .64582 .50879 Mtetra
.65 .75 .923 r
.64582 .50879 .65133 .51473 .66265 .51155 .65717 .50571 Mtetra
.646 .753 .927 r
.65717 .50571 .66265 .51155 .67402 .50843 .66858 .50271 Mtetra
.641 .757 .933 r
.66858 .50271 .67402 .50843 .68545 .50537 .68005 .4998 Mtetra
.635 .761 .939 r
.68005 .4998 .68545 .50537 .69692 .50238 .69157 .49699 Mtetra
.628 .767 .946 r
.69157 .49699 .69692 .50238 .70846 .49947 .70315 .49429 Mtetra
.62 .773 .954 r
.70315 .49429 .70846 .49947 .72005 .49664 .71479 .49171 Mtetra
.611 .78 .962 r
.71479 .49171 .72005 .49664 .73169 .4939 .72649 .48922 Mtetra
.601 .788 .97 r
.72649 .48922 .73169 .4939 .7434 .49123 .73826 .48683 Mtetra
.591 .796 .978 r
.73826 .48683 .7434 .49123 .75516 .48863 .75008 .4845 Mtetra
.58 .805 .985 r
.75008 .4845 .75516 .48863 .76698 .48607 .76197 .48222 Mtetra
.571 .814 .99 r
.76197 .48222 .76698 .48607 .77887 .48354 .77391 .47994 Mtetra
.563 .823 .994 r
.77391 .47994 .77887 .48354 .7908 .48099 .78591 .47761 Mtetra
.559 .832 .997 r
.78591 .47761 .7908 .48099 .8028 .47839 .79797 .47519 Mtetra
.558 .84 .997 r
.79797 .47519 .8028 .47839 .81484 .47571 .81007 .47263 Mtetra
.563 .849 .997 r
.81007 .47263 .81484 .47571 .82693 .4729 .82221 .46988 Mtetra
.574 .856 .996 r
.82221 .46988 .82693 .4729 .83906 .46992 .83439 .46689 Mtetra
.589 .863 .994 r
.83439 .46689 .83906 .46992 .85122 .46675 .84661 .46363 Mtetra
.607 .867 .992 r
.84661 .46363 .85122 .46675 .86342 .46335 .85884 .46008 Mtetra
.627 .869 .988 r
.85884 .46008 .86342 .46335 .87565 .45972 .8711 .45623 Mtetra
.647 .868 .982 r
.8711 .45623 .87565 .45972 .88791 .45585 .88338 .45209 Mtetra
.664 .863 .975 r
.88338 .45209 .88791 .45585 .90019 .45175 .89568 .44767 Mtetra
.679 .855 .967 r
.89568 .44767 .90019 .45175 .9125 .44743 .908 .44301 Mtetra
.689 .846 .958 r
.908 .44301 .9125 .44743 .92483 .44292 .92035 .43814 Mtetra
.697 .835 .949 r
.92035 .43814 .92483 .44292 .93719 .43827 .93272 .43314 Mtetra
.701 .823 .94 r
.93272 .43314 .93719 .43827 .94959 .43351 .94512 .42803 Mtetra
.703 .811 .932 r
.94512 .42803 .94959 .43351 .96203 .42868 .95756 .42288 Mtetra
.664 .741 .908 r
.38045 .58074 .38668 .58654 .397 .5834 .39079 .57758 Mtetra
.39079 .57758 .397 .5834 .40736 .58025 .40117 .5744 Mtetra
.40117 .5744 .40736 .58025 .41776 .57709 .4116 .57122 Mtetra
.4116 .57122 .41776 .57709 .42819 .57391 .42206 .56802 Mtetra
.42206 .56802 .42819 .57391 .43867 .57073 .43256 .56481 Mtetra
.43256 .56481 .43867 .57073 .44919 .56753 .44311 .56159 Mtetra
.44311 .56159 .44919 .56753 .45975 .56431 .45369 .55835 Mtetra
.45369 .55835 .45975 .56431 .47035 .56109 .46432 .5551 Mtetra
.663 .741 .908 r
.46432 .5551 .47035 .56109 .48099 .55785 .47499 .55184 Mtetra
.47499 .55184 .48099 .55785 .49168 .5546 .4857 .54857 Mtetra
.4857 .54857 .49168 .5546 .5024 .55134 .49646 .54529 Mtetra
.49646 .54529 .5024 .55134 .51317 .54807 .50725 .54199 Mtetra
.50725 .54199 .51317 .54807 .52398 .54479 .51809 .53869 Mtetra
.51809 .53869 .52398 .54479 .53484 .54149 .52897 .53538 Mtetra
.663 .742 .909 r
.52897 .53538 .53484 .54149 .54573 .53819 .5399 .53206 Mtetra
.662 .742 .909 r
.5399 .53206 .54573 .53819 .55667 .53488 .55087 .52874 Mtetra
.662 .742 .91 r
.55087 .52874 .55667 .53488 .56766 .53157 .56188 .52542 Mtetra
.661 .742 .91 r
.56188 .52542 .56766 .53157 .57869 .52826 .57294 .52212 Mtetra
.66 .743 .911 r
.57294 .52212 .57869 .52826 .58976 .52495 .58404 .51882 Mtetra
.659 .744 .913 r
.58404 .51882 .58976 .52495 .60088 .52166 .59519 .51555 Mtetra
.657 .745 .915 r
.59519 .51555 .60088 .52166 .61204 .51839 .60638 .51232 Mtetra
.654 .746 .917 r
.60638 .51232 .61204 .51839 .62325 .51514 .61763 .50914 Mtetra
.651 .748 .921 r
.61763 .50914 .62325 .51514 .63451 .51194 .62892 .50603 Mtetra
.647 .751 .925 r
.62892 .50603 .63451 .51194 .64582 .50879 .64026 .503 Mtetra
.642 .754 .93 r
.64026 .503 .64582 .50879 .65717 .50571 .65166 .50006 Mtetra
.636 .758 .936 r
.65166 .50006 .65717 .50571 .66858 .50271 .66311 .49724 Mtetra
.629 .763 .944 r
.66311 .49724 .66858 .50271 .68005 .4998 .67463 .49455 Mtetra
.62 .77 .952 r
.67463 .49455 .68005 .4998 .69157 .49699 .6862 .492 Mtetra
.609 .777 .961 r
.6862 .492 .69157 .49699 .70315 .49429 .69783 .48958 Mtetra
.596 .784 .97 r
.69783 .48958 .70315 .49429 .71479 .49171 .70952 .48731 Mtetra
.582 .793 .98 r
.70952 .48731 .71479 .49171 .72649 .48922 .72129 .48515 Mtetra
.566 .802 .988 r
.72129 .48515 .72649 .48922 .73826 .48683 .73311 .4831 Mtetra
.549 .81 .994 r
.73311 .4831 .73826 .48683 .75008 .4845 .745 .48111 Mtetra
.532 .819 .998 r
.745 .48111 .75008 .4845 .76197 .48222 .75696 .47914 Mtetra
.517 .827 1 r
.75696 .47914 .76197 .48222 .77391 .47994 .76897 .47714 Mtetra
.506 .835 .999 r
.76897 .47714 .77391 .47994 .78591 .47761 .78104 .47505 Mtetra
.501 .843 .997 r
.78104 .47505 .78591 .47761 .79797 .47519 .79316 .4728 Mtetra
.505 .852 .994 r
.79316 .4728 .79797 .47519 .81007 .47263 .80532 .47033 Mtetra
.517 .862 .992 r
.80532 .47033 .81007 .47263 .82221 .46988 .81752 .46759 Mtetra
.537 .872 .992 r
.81752 .46759 .82221 .46988 .83439 .46689 .82975 .46452 Mtetra
.564 .881 .991 r
.82975 .46452 .83439 .46689 .84661 .46363 .842 .4611 Mtetra
.594 .888 .991 r
.842 .4611 .84661 .46363 .85884 .46008 .85427 .45731 Mtetra
.625 .89 .988 r
.85427 .45731 .85884 .46008 .8711 .45623 .86655 .45314 Mtetra
.652 .888 .983 r
.86655 .45314 .8711 .45623 .88338 .45209 .87885 .44862 Mtetra
.674 .881 .975 r
.87885 .44862 .88338 .45209 .89568 .44767 .89116 .44379 Mtetra
.691 .87 .966 r
.89116 .44379 .89568 .44767 .908 .44301 .90348 .4387 Mtetra
.703 .857 .956 r
.90348 .4387 .908 .44301 .92035 .43814 .91583 .43341 Mtetra
.71 .842 .945 r
.91583 .43341 .92035 .43814 .93272 .43314 .9282 .42798 Mtetra
.713 .828 .936 r
.9282 .42798 .93272 .43314 .94512 .42803 .94061 .42249 Mtetra
.713 .814 .928 r
.94061 .42249 .94512 .42803 .95756 .42288 .95306 .41698 Mtetra
.664 .741 .908 r
.37417 .57489 .38045 .58074 .39079 .57758 .38454 .57171 Mtetra
.38454 .57171 .39079 .57758 .40117 .5744 .39494 .56851 Mtetra
.39494 .56851 .40117 .5744 .4116 .57122 .40539 .5653 Mtetra
.40539 .5653 .4116 .57122 .42206 .56802 .41588 .56208 Mtetra
.41588 .56208 .42206 .56802 .43256 .56481 .42641 .55885 Mtetra
.42641 .55885 .43256 .56481 .44311 .56159 .43698 .5556 Mtetra
.43698 .5556 .44311 .56159 .45369 .55835 .4476 .55234 Mtetra
.663 .741 .908 r
.4476 .55234 .45369 .55835 .46432 .5551 .45825 .54907 Mtetra
.45825 .54907 .46432 .5551 .47499 .55184 .46895 .54579 Mtetra
.46895 .54579 .47499 .55184 .4857 .54857 .47968 .5425 Mtetra
.47968 .5425 .4857 .54857 .49646 .54529 .49046 .53919 Mtetra
.49046 .53919 .49646 .54529 .50725 .54199 .50129 .53588 Mtetra
.663 .742 .908 r
.50129 .53588 .50725 .54199 .51809 .53869 .51215 .53256 Mtetra
.663 .742 .909 r
.51215 .53256 .51809 .53869 .52897 .53538 .52306 .52923 Mtetra
.662 .742 .909 r
.52306 .52923 .52897 .53538 .5399 .53206 .53402 .5259 Mtetra
.662 .742 .91 r
.53402 .5259 .5399 .53206 .55087 .52874 .54502 .52258 Mtetra
.661 .743 .911 r
.54502 .52258 .55087 .52874 .56188 .52542 .55606 .51927 Mtetra
.66 .743 .912 r
.55606 .51927 .56188 .52542 .57294 .52212 .56714 .51597 Mtetra
.658 .744 .913 r
.56714 .51597 .57294 .52212 .58404 .51882 .57828 .51271 Mtetra
.656 .745 .916 r
.57828 .51271 .58404 .51882 .59519 .51555 .58946 .50949 Mtetra
.653 .747 .919 r
.58946 .50949 .59519 .51555 .60638 .51232 .60069 .50634 Mtetra
.649 .749 .922 r
.60069 .50634 .60638 .51232 .61763 .50914 .61196 .50326 Mtetra
.645 .752 .927 r
.61196 .50326 .61763 .50914 .62892 .50603 .62329 .50028 Mtetra
.639 .755 .933 r
.62329 .50028 .62892 .50603 .64026 .503 .63468 .49742 Mtetra
.631 .76 .94 r
.63468 .49742 .64026 .503 .65166 .50006 .64612 .49469 Mtetra
.622 .766 .949 r
.64612 .49469 .65166 .50006 .66311 .49724 .65762 .49213 Mtetra
.61 .772 .958 r
.65762 .49213 .66311 .49724 .67463 .49455 .66918 .48974 Mtetra
.595 .78 .968 r
.66918 .48974 .67463 .49455 .6862 .492 .6808 .48752 Mtetra
.578 .788 .979 r
.6808 .48752 .6862 .492 .69783 .48958 .69249 .48547 Mtetra
.557 .796 .988 r
.69249 .48547 .69783 .48958 .70952 .48731 .70425 .48359 Mtetra
.532 .804 .996 r
.70425 .48359 .70952 .48731 .72129 .48515 .71608 .48185 Mtetra
.505 .811 1 r
.71608 .48185 .72129 .48515 .73311 .4831 .72798 .48021 Mtetra
.476 .816 .999 r
.72798 .48021 .73311 .4831 .745 .48111 .73994 .47861 Mtetra
.449 .82 .993 r
.73994 .47861 .745 .48111 .75696 .47914 .75197 .477 Mtetra
.427 .822 .984 r
.75197 .477 .75696 .47914 .76897 .47714 .76405 .4753 Mtetra
.414 .826 .973 r
.76405 .4753 .76897 .47714 .78104 .47505 .77619 .47343 Mtetra
.413 .834 .965 r
.77619 .47343 .78104 .47505 .79316 .4728 .78838 .47132 Mtetra
.426 .845 .961 r
.78838 .47132 .79316 .4728 .80532 .47033 .8006 .46889 Mtetra
.453 .861 .962 r
.8006 .46889 .80532 .47033 .81752 .46759 .81285 .46608 Mtetra
.492 .878 .968 r
.81285 .46608 .81752 .46759 .82975 .46452 .82512 .46283 Mtetra
.538 .895 .975 r
.82512 .46283 .82975 .46452 .842 .4611 .83741 .45914 Mtetra
.585 .906 .981 r
.83741 .45914 .842 .4611 .85427 .45731 .8497 .45498 Mtetra
.628 .91 .982 r
.8497 .45498 .85427 .45731 .86655 .45314 .862 .45037 Mtetra
.664 .906 .979 r
.862 .45037 .86655 .45314 .87885 .44862 .8743 .44537 Mtetra
.691 .896 .971 r
.8743 .44537 .87885 .44862 .89116 .44379 .88661 .44003 Mtetra
.709 .881 .961 r
.88661 .44003 .89116 .44379 .90348 .4387 .89893 .43442 Mtetra
.719 .864 .95 r
.89893 .43442 .90348 .4387 .91583 .43341 .91127 .42863 Mtetra
.724 .847 .939 r
.91127 .42863 .91583 .43341 .9282 .42798 .92364 .42273 Mtetra
.725 .83 .93 r
.92364 .42273 .9282 .42798 .94061 .42249 .93605 .41681 Mtetra
.723 .815 .922 r
.93605 .41681 .94061 .42249 .95306 .41698 .9485 .41094 Mtetra
.664 .741 .908 r
.36785 .56901 .37417 .57489 .38454 .57171 .37824 .5658 Mtetra
.37824 .5658 .38454 .57171 .39494 .56851 .38867 .56258 Mtetra
.38867 .56258 .39494 .56851 .40539 .5653 .39914 .55935 Mtetra
.39914 .55935 .40539 .5653 .41588 .56208 .40966 .5561 Mtetra
.40966 .5561 .41588 .56208 .42641 .55885 .42022 .55285 Mtetra
.42022 .55285 .42641 .55885 .43698 .5556 .43081 .54958 Mtetra
.663 .741 .908 r
.43081 .54958 .43698 .5556 .4476 .55234 .44145 .5463 Mtetra
.44145 .5463 .4476 .55234 .45825 .54907 .45213 .543 Mtetra
.45213 .543 .45825 .54907 .46895 .54579 .46286 .5397 Mtetra
.46286 .5397 .46895 .54579 .47968 .5425 .47362 .53638 Mtetra
.47362 .53638 .47968 .5425 .49046 .53919 .48443 .53306 Mtetra
.663 .742 .908 r
.48443 .53306 .49046 .53919 .50129 .53588 .49528 .52973 Mtetra
.663 .742 .909 r
.49528 .52973 .50129 .53588 .51215 .53256 .50617 .52639 Mtetra
.662 .742 .909 r
.50617 .52639 .51215 .53256 .52306 .52923 .51711 .52305 Mtetra
.661 .742 .91 r
.51711 .52305 .52306 .52923 .53402 .5259 .52809 .51972 Mtetra
.661 .743 .911 r
.52809 .51972 .53402 .5259 .54502 .52258 .53912 .51641 Mtetra
.659 .743 .912 r
.53912 .51641 .54502 .52258 .55606 .51927 .55019 .51311 Mtetra
.657 .744 .914 r
.55019 .51311 .55606 .51927 .56714 .51597 .56131 .50986 Mtetra
.655 .745 .916 r
.56131 .50986 .56714 .51597 .57828 .51271 .57248 .50665 Mtetra
.652 .747 .92 r
.57248 .50665 .57828 .51271 .58946 .50949 .58369 .50352 Mtetra
.647 .75 .924 r
.58369 .50352 .58946 .50949 .60069 .50634 .59495 .50048 Mtetra
.642 .753 .929 r
.59495 .50048 .60069 .50634 .61196 .50326 .60626 .49755 Mtetra
.635 .757 .936 r
.60626 .49755 .61196 .50326 .62329 .50028 .61763 .49477 Mtetra
.625 .762 .944 r
.61763 .49477 .62329 .50028 .63468 .49742 .62906 .49215 Mtetra
.613 .768 .954 r
.62906 .49215 .63468 .49742 .64612 .49469 .64054 .48972 Mtetra
.598 .774 .964 r
.64054 .48972 .64612 .49469 .65762 .49213 .65209 .4875 Mtetra
.579 .782 .976 r
.65209 .4875 .65762 .49213 .66918 .48974 .66371 .48549 Mtetra
.555 .79 .987 r
.66371 .48549 .66918 .48974 .6808 .48752 .67539 .48371 Mtetra
.525 .797 .995 r
.67539 .48371 .6808 .48752 .69249 .48547 .68715 .48213 Mtetra
.488 .802 1 r
.68715 .48213 .69249 .48547 .70425 .48359 .69897 .48074 Mtetra
.446 .803 .997 r
.69897 .48074 .70425 .48359 .71608 .48185 .71088 .47949 Mtetra
.4 .8 .985 r
.71088 .47949 .71608 .48185 .72798 .48021 .72285 .47831 Mtetra
.354 .792 .964 r
.72285 .47831 .72798 .48021 .73994 .47861 .73489 .47715 Mtetra
.315 .782 .937 r
.73489 .47715 .73994 .47861 .75197 .477 .747 .47592 Mtetra
.289 .775 .91 r
.747 .47592 .75197 .477 .76405 .4753 .75916 .47451 Mtetra
.28 .775 .89 r
.75916 .47451 .76405 .4753 .77619 .47343 .77137 .47283 Mtetra
.293 .786 .881 r
.77137 .47283 .77619 .47343 .78838 .47132 .78362 .47079 Mtetra
.326 .808 .885 r
.78362 .47079 .78838 .47132 .8006 .46889 .7959 .46831 Mtetra
.379 .839 .901 r
.7959 .46831 .8006 .46889 .81285 .46608 .8082 .46532 Mtetra
.445 .873 .924 r
.8082 .46532 .81285 .46608 .82512 .46283 .8205 .46177 Mtetra
.517 .902 .948 r
.8205 .46177 .82512 .46283 .83741 .45914 .83281 .45766 Mtetra
.585 .922 .965 r
.83281 .45766 .83741 .45914 .8497 .45498 .84511 .45299 Mtetra
.642 .928 .973 r
.84511 .45299 .8497 .45498 .862 .45037 .85742 .44782 Mtetra
.684 .922 .971 r
.85742 .44782 .862 .45037 .8743 .44537 .86971 .44222 Mtetra
.712 .907 .964 r
.86971 .44222 .8743 .44537 .88661 .44003 .88202 .43626 Mtetra
.729 .888 .953 r
.88202 .43626 .88661 .44003 .89893 .43442 .89433 .43006 Mtetra
.737 .867 .941 r
.89433 .43006 .89893 .43442 .91127 .42863 .90666 .42371 Mtetra
.739 .847 .93 r
.90666 .42371 .91127 .42863 .92364 .42273 .91902 .4173 Mtetra
.738 .829 .921 r
.91902 .4173 .92364 .42273 .93605 .41681 .93143 .41094 Mtetra
.733 .812 .914 r
.93143 .41094 .93605 .41681 .9485 .41094 .94388 .40468 Mtetra
.664 .741 .908 r
.36148 .56307 .36785 .56901 .37824 .5658 .37189 .55985 Mtetra
.37189 .55985 .37824 .5658 .38867 .56258 .38235 .5566 Mtetra
.38235 .5566 .38867 .56258 .39914 .55935 .39285 .55335 Mtetra
.39285 .55335 .39914 .55935 .40966 .5561 .40339 .55008 Mtetra
.40339 .55008 .40966 .5561 .42022 .55285 .41397 .5468 Mtetra
.663 .741 .908 r
.41397 .5468 .42022 .55285 .43081 .54958 .4246 .54351 Mtetra
.4246 .54351 .43081 .54958 .44145 .5463 .43526 .5402 Mtetra
.43526 .5402 .44145 .5463 .45213 .543 .44597 .53689 Mtetra
.44597 .53689 .45213 .543 .46286 .5397 .45672 .53356 Mtetra
.45672 .53356 .46286 .5397 .47362 .53638 .46751 .53023 Mtetra
.663 .742 .908 r
.46751 .53023 .47362 .53638 .48443 .53306 .47835 .52688 Mtetra
.663 .742 .909 r
.47835 .52688 .48443 .53306 .49528 .52973 .48923 .52354 Mtetra
.662 .742 .909 r
.48923 .52354 .49528 .52973 .50617 .52639 .50015 .52019 Mtetra
.661 .742 .91 r
.50015 .52019 .50617 .52639 .51711 .52305 .51112 .51686 Mtetra
.66 .743 .911 r
.51112 .51686 .51711 .52305 .52809 .51972 .52213 .51354 Mtetra
.659 .743 .912 r
.52213 .51354 .52809 .51972 .53912 .51641 .53318 .51024 Mtetra
.657 .744 .914 r
.53318 .51024 .53912 .51641 .55019 .51311 .54428 .50699 Mtetra
.654 .746 .917 r
.54428 .50699 .55019 .51311 .56131 .50986 .55543 .5038 Mtetra
.65 .748 .921 r
.55543 .5038 .56131 .50986 .57248 .50665 .56663 .50069 Mtetra
.645 .75 .925 r
.56663 .50069 .57248 .50665 .58369 .50352 .57788 .49769 Mtetra
.639 .753 .931 r
.57788 .49769 .58369 .50352 .59495 .50048 .58917 .49482 Mtetra
.63 .758 .939 r
.58917 .49482 .59495 .50048 .60626 .49755 .60053 .49211 Mtetra
.619 .763 .948 r
.60053 .49211 .60626 .49755 .61763 .49477 .61194 .4896 Mtetra
.605 .769 .958 r
.61194 .4896 .61763 .49477 .62906 .49215 .62341 .48731 Mtetra
.586 .776 .97 r
.62341 .48731 .62906 .49215 .64054 .48972 .63494 .48527 Mtetra
.561 .784 .982 r
.63494 .48527 .64054 .48972 .65209 .4875 .64654 .4835 Mtetra
.528 .79 .993 r
.64654 .4835 .65209 .4875 .66371 .48549 .65822 .48199 Mtetra
.486 .794 .999 r
.65822 .48199 .66371 .48549 .67539 .48371 .66997 .48074 Mtetra
.433 .792 .996 r
.66997 .48074 .67539 .48371 .68715 .48213 .68179 .47974 Mtetra
.369 .782 .98 r
.68179 .47974 .68715 .48213 .69897 .48074 .6937 .47892 Mtetra
.299 .762 .947 r
.6937 .47892 .69897 .48074 .71088 .47949 .70568 .47823 Mtetra
.23 .733 .9 r
.70568 .47823 .71088 .47949 .72285 .47831 .71774 .47758 Mtetra
.171 .702 .846 r
.71774 .47758 .72285 .47831 .73489 .47715 .72986 .47689 Mtetra
.13 .677 .795 r
.72986 .47689 .73489 .47715 .747 .47592 .74205 .47602 Mtetra
.112 .665 .757 r
.74205 .47602 .747 .47592 .75916 .47451 .75429 .47487 Mtetra
.122 .672 .74 r
.75429 .47487 .75916 .47451 .77137 .47283 .76657 .47331 Mtetra
.159 .699 .746 r
.76657 .47331 .77137 .47283 .78362 .47079 .77888 .47124 Mtetra
.223 .744 .774 r
.77888 .47124 .78362 .47079 .7959 .46831 .79121 .46857 Mtetra
.31 .802 .819 r
.79121 .46857 .7959 .46831 .8082 .46532 .80355 .46525 Mtetra
.411 .861 .87 r
.80355 .46525 .8082 .46532 .8205 .46177 .81588 .46123 Mtetra
.513 .91 .917 r
.81588 .46123 .8205 .46177 .83281 .45766 .8282 .45654 Mtetra
.601 .937 .948 r
.8282 .45654 .83281 .45766 .84511 .45299 .8405 .45122 Mtetra
.668 .943 .962 r
.8405 .45122 .84511 .45299 .85742 .44782 .8528 .44534 Mtetra
.713 .933 .961 r
.8528 .44534 .85742 .44782 .86971 .44222 .86508 .43901 Mtetra
.739 .912 .953 r
.86508 .43901 .86971 .44222 .88202 .43626 .87737 .43235 Mtetra
.751 .889 .941 r
.87737 .43235 .88202 .43626 .89433 .43006 .88966 .42549 Mtetra
.755 .865 .929 r
.88966 .42549 .89433 .43006 .90666 .42371 .90198 .41853 Mtetra
.753 .843 .919 r
.90198 .41853 .90666 .42371 .91902 .4173 .91434 .4116 Mtetra
.748 .824 .911 r
.91434 .4116 .91902 .4173 .93143 .41094 .92674 .40479 Mtetra
.741 .807 .904 r
.92674 .40479 .93143 .41094 .94388 .40468 .93919 .39816 Mtetra
.664 .741 .908 r
.35506 .5571 .36148 .56307 .37189 .55985 .3655 .55385 Mtetra
.3655 .55385 .37189 .55985 .38235 .5566 .37599 .55058 Mtetra
.37599 .55058 .38235 .5566 .39285 .55335 .38651 .5473 Mtetra
.38651 .5473 .39285 .55335 .40339 .55008 .39708 .54401 Mtetra
.663 .741 .908 r
.39708 .54401 .40339 .55008 .41397 .5468 .40769 .54071 Mtetra
.40769 .54071 .41397 .5468 .4246 .54351 .41834 .53739 Mtetra
.41834 .53739 .4246 .54351 .43526 .5402 .42903 .53407 Mtetra
.42903 .53407 .43526 .5402 .44597 .53689 .43976 .53073 Mtetra
.43976 .53073 .44597 .53689 .45672 .53356 .45054 .52738 Mtetra
.663 .742 .908 r
.45054 .52738 .45672 .53356 .46751 .53023 .46136 .52403 Mtetra
.663 .742 .909 r
.46136 .52403 .46751 .53023 .47835 .52688 .47222 .52068 Mtetra
.662 .742 .909 r
.47222 .52068 .47835 .52688 .48923 .52354 .48313 .51732 Mtetra
.661 .742 .91 r
.48313 .51732 .48923 .52354 .50015 .52019 .49408 .51398 Mtetra
.66 .743 .911 r
.49408 .51398 .50015 .52019 .51112 .51686 .50508 .51065 Mtetra
.658 .743 .913 r
.50508 .51065 .51112 .51686 .52213 .51354 .51611 .50736 Mtetra
.656 .744 .915 r
.51611 .50736 .52213 .51354 .53318 .51024 .5272 .50411 Mtetra
.653 .746 .918 r
.5272 .50411 .53318 .51024 .54428 .50699 .53833 .50093 Mtetra
.649 .748 .922 r
.53833 .50093 .54428 .50699 .55543 .5038 .54951 .49784 Mtetra
.643 .75 .927 r
.54951 .49784 .55543 .5038 .56663 .50069 .56074 .49487 Mtetra
.636 .754 .933 r
.56074 .49487 .56663 .50069 .57788 .49769 .57202 .49206 Mtetra
.626 .758 .941 r
.57202 .49206 .57788 .49769 .58917 .49482 .58336 .48943 Mtetra
.613 .764 .951 r
.58336 .48943 .58917 .49482 .60053 .49211 .59475 .48703 Mtetra
.595 .77 .963 r
.59475 .48703 .60053 .49211 .61194 .4896 .6062 .48489 Mtetra
.571 .777 .976 r
.6062 .48489 .61194 .4896 .62341 .48731 .61772 .48304 Mtetra
.539 .783 .988 r
.61772 .48304 .62341 .48731 .63494 .48527 .62931 .4815 Mtetra
.496 .787 .997 r
.62931 .4815 .63494 .48527 .64654 .4835 .64097 .48029 Mtetra
.438 .785 .998 r
.64097 .48029 .64654 .4835 .65822 .48199 .65272 .47939 Mtetra
.364 .772 .982 r
.65272 .47939 .65822 .48199 .66997 .48074 .66454 .4788 Mtetra
.274 .743 .944 r
.66454 .4788 .66997 .48074 .68179 .47974 .67644 .47846 Mtetra
.177 .697 .88 r
.67644 .47846 .68179 .47974 .6937 .47892 .68843 .47831 Mtetra
.084 .64 .797 r
.68843 .47831 .6937 .47892 .70568 .47823 .7005 .47824 Mtetra
.008 .584 .71 r
.7005 .47824 .70568 .47823 .71774 .47758 .71264 .47816 Mtetra
.043 0 0 r
.71264 .47816 .71774 .47758 .72986 .47689 .72485 .47792 Mtetra
.065 0 0 r
.72485 .47792 .72986 .47689 .74205 .47602 .73712 .47738 Mtetra
.058 0 0 r
.73712 .47738 .74205 .47602 .75429 .47487 .74944 .4764 Mtetra
.021 0 0 r
.74944 .4764 .75429 .47487 .76657 .47331 .76179 .47484 Mtetra
0 0 0 r
.76179 .47484 .76657 .47331 .77888 .47124 .77415 .4726 Mtetra
.77415 .4726 .77888 .47124 .79121 .46857 .78652 .46957 Mtetra
.268 .769 .74 r
.78652 .46957 .79121 .46857 .80355 .46525 .79888 .46572 Mtetra
.406 .858 .825 r
.79888 .46572 .80355 .46525 .81588 .46123 .81123 .46105 Mtetra
.536 .924 .895 r
.81123 .46105 .81588 .46123 .8282 .45654 .82354 .4556 Mtetra
.639 .954 .936 r
.82354 .4556 .8282 .45654 .8405 .45122 .83584 .44945 Mtetra
.707 .955 .951 r
.83584 .44945 .8405 .45122 .8528 .44534 .84812 .44273 Mtetra
.747 .936 .948 r
.84812 .44273 .8528 .44534 .86508 .43901 .86038 .43558 Mtetra
.766 .91 .938 r
.86038 .43558 .86508 .43901 .87737 .43235 .87264 .42814 Mtetra
.772 .883 .926 r
.87264 .42814 .87737 .43235 .88966 .42549 .88492 .42057 Mtetra
.771 .857 .914 r
.88492 .42057 .88966 .42549 .90198 .41853 .89722 .413 Mtetra
.765 .835 .905 r
.89722 .413 .90198 .41853 .91434 .4116 .90957 .40555 Mtetra
.757 .816 .899 r
.90957 .40555 .91434 .4116 .92674 .40479 .92197 .3983 Mtetra
.747 .8 .895 r
.92197 .3983 .92674 .40479 .93919 .39816 .93444 .39133 Mtetra
.664 .741 .908 r
.3486 .55109 .35506 .5571 .3655 .55385 .35907 .54781 Mtetra
.35907 .54781 .3655 .55385 .37599 .55058 .36958 .54452 Mtetra
.36958 .54452 .37599 .55058 .38651 .5473 .38013 .54122 Mtetra
.663 .741 .908 r
.38013 .54122 .38651 .5473 .39708 .54401 .39072 .5379 Mtetra
.39072 .5379 .39708 .54401 .40769 .54071 .40135 .53458 Mtetra
.40135 .53458 .40769 .54071 .41834 .53739 .41203 .53124 Mtetra
.41203 .53124 .41834 .53739 .42903 .53407 .42275 .52789 Mtetra
.42275 .52789 .42903 .53407 .43976 .53073 .43351 .52453 Mtetra
.663 .742 .908 r
.43351 .52453 .43976 .53073 .45054 .52738 .44431 .52117 Mtetra
.662 .742 .909 r
.44431 .52117 .45054 .52738 .46136 .52403 .45516 .51781 Mtetra
.45516 .51781 .46136 .52403 .47222 .52068 .46605 .51444 Mtetra
.661 .742 .91 r
.46605 .51444 .47222 .52068 .48313 .51732 .47699 .51109 Mtetra
.66 .743 .911 r
.47699 .51109 .48313 .51732 .49408 .51398 .48796 .50776 Mtetra
.658 .743 .913 r
.48796 .50776 .49408 .51398 .50508 .51065 .49899 .50446 Mtetra
.656 .744 .915 r
.49899 .50446 .50508 .51065 .51611 .50736 .51006 .50122 Mtetra
.652 .746 .918 r
.51006 .50122 .51611 .50736 .5272 .50411 .52117 .49805 Mtetra
.648 .748 .922 r
.52117 .49805 .5272 .50411 .53833 .50093 .53233 .49498 Mtetra
.642 .751 .928 r
.53233 .49498 .53833 .50093 .54951 .49784 .54355 .49204 Mtetra
.633 .754 .935 r
.54355 .49204 .54951 .49784 .56074 .49487 .55481 .48928 Mtetra
.622 .759 .944 r
.55481 .48928 .56074 .49487 .57202 .49206 .56612 .48672 Mtetra
.607 .764 .955 r
.56612 .48672 .57202 .49206 .58336 .48943 .5775 .48443 Mtetra
.586 .77 .967 r
.5775 .48443 .58336 .48943 .59475 .48703 .58893 .48243 Mtetra
.557 .777 .981 r
.58893 .48243 .59475 .48703 .6062 .48489 .60044 .48077 Mtetra
.516 .781 .993 r
.60044 .48077 .6062 .48489 .61772 .48304 .61201 .47947 Mtetra
.46 .781 .998 r
.61201 .47947 .61772 .48304 .62931 .4815 .62366 .47857 Mtetra
.383 .77 .989 r
.62366 .47857 .62931 .4815 .64097 .48029 .63538 .47805 Mtetra
.284 .739 .955 r
.63538 .47805 .64097 .48029 .65272 .47939 .6472 .47789 Mtetra
.165 .684 .885 r
.6472 .47789 .65272 .47939 .66454 .4788 .6591 .47807 Mtetra
.042 .607 .783 r
.6591 .47807 .66454 .4788 .67644 .47846 .67109 .47849 Mtetra
.068 0 0 r
.67109 .47849 .67644 .47846 .68843 .47831 .68316 .47907 Mtetra
.149 0 0 r
.68316 .47907 .68843 .47831 .7005 .47824 .69532 .47967 Mtetra
.2 0 0 r
.69532 .47967 .7005 .47824 .71264 .47816 .70756 .48014 Mtetra
.221 0 0 r
.70756 .48014 .71264 .47816 .72485 .47792 .71986 .48031 Mtetra
.215 0 0 r
.71986 .48031 .72485 .47792 .73712 .47738 .73221 .48001 Mtetra
.182 0 0 r
.73221 .48001 .73712 .47738 .74944 .4764 .7446 .47908 Mtetra
.12 0 0 r
.7446 .47908 .74944 .4764 .76179 .47484 .75701 .47735 Mtetra
.024 0 0 r
.75701 .47735 .76179 .47484 .77415 .4726 .76942 .47472 Mtetra
0 0 0 r
.76942 .47472 .77415 .4726 .78652 .46957 .78182 .47111 Mtetra
.271 .763 .691 r
.78182 .47111 .78652 .46957 .79888 .46572 .79419 .46652 Mtetra
.443 .877 .806 r
.79419 .46652 .79888 .46572 .81123 .46105 .80653 .46098 Mtetra
.592 .948 .889 r
.80653 .46098 .81123 .46105 .82354 .4556 .81883 .45458 Mtetra
.694 .969 .929 r
.81883 .45458 .82354 .4556 .83584 .44945 .83111 .44746 Mtetra
.753 .957 .938 r
.83111 .44746 .83584 .44945 .84812 .44273 .84335 .43978 Mtetra
.781 .93 .931 r
.84335 .43978 .84812 .44273 .86038 .43558 .85559 .43172 Mtetra
.79 .899 .919 r
.85559 .43172 .86038 .43558 .87264 .42814 .86783 .42347 Mtetra
.789 .87 .908 r
.86783 .42347 .87264 .42814 .88492 .42057 .88009 .41518 Mtetra
.783 .844 .898 r
.88009 .41518 .88492 .42057 .89722 .413 .89238 .40701 Mtetra
.773 .823 .891 r
.89238 .40701 .89722 .413 .90957 .40555 .90472 .39906 Mtetra
.763 .805 .887 r
.90472 .39906 .90957 .40555 .92197 .3983 .91712 .39143 Mtetra
.751 .791 .885 r
.91712 .39143 .92197 .3983 .93444 .39133 .9296 .38416 Mtetra
.664 .741 .908 r
.34209 .54503 .3486 .55109 .35907 .54781 .35259 .54173 Mtetra
.35259 .54173 .35907 .54781 .36958 .54452 .36312 .53841 Mtetra
.663 .741 .908 r
.36312 .53841 .36958 .54452 .38013 .54122 .3737 .53509 Mtetra
.3737 .53509 .38013 .54122 .39072 .5379 .38431 .53175 Mtetra
.38431 .53175 .39072 .5379 .40135 .53458 .39497 .5284 Mtetra
.39497 .5284 .40135 .53458 .41203 .53124 .40568 .52504 Mtetra
.40568 .52504 .41203 .53124 .42275 .52789 .41642 .52167 Mtetra
.663 .742 .909 r
.41642 .52167 .42275 .52789 .43351 .52453 .42721 .5183 Mtetra
.662 .742 .909 r
.42721 .5183 .43351 .52453 .44431 .52117 .43804 .51492 Mtetra
.43804 .51492 .44431 .52117 .45516 .51781 .44892 .51155 Mtetra
.661 .742 .91 r
.44892 .51155 .45516 .51781 .46605 .51444 .45983 .50819 Mtetra
.66 .743 .911 r
.45983 .50819 .46605 .51444 .47699 .51109 .4708 .50485 Mtetra
.658 .743 .913 r
.4708 .50485 .47699 .51109 .48796 .50776 .4818 .50155 Mtetra
.655 .744 .915 r
.4818 .50155 .48796 .50776 .49899 .50446 .49285 .4983 Mtetra
.652 .746 .919 r
.49285 .4983 .49899 .50446 .51006 .50122 .50395 .49514 Mtetra
.647 .748 .923 r
.50395 .49514 .51006 .50122 .52117 .49805 .5151 .49209 Mtetra
.64 .751 .929 r
.5151 .49209 .52117 .49805 .53233 .49498 .52629 .48918 Mtetra
.631 .754 .937 r
.52629 .48918 .53233 .49498 .54355 .49204 .53753 .48646 Mtetra
.618 .759 .946 r
.53753 .48646 .54355 .49204 .55481 .48928 .54883 .48398 Mtetra
.6 .764 .958 r
.54883 .48398 .55481 .48928 .56612 .48672 .56018 .48178 Mtetra
.576 .77 .971 r
.56018 .48178 .56612 .48672 .5775 .48443 .5716 .47993 Mtetra
.541 .776 .985 r
.5716 .47993 .5775 .48443 .58893 .48243 .58308 .47845 Mtetra
.492 .778 .995 r
.58308 .47845 .58893 .48243 .60044 .48077 .59463 .4774 Mtetra
.421 .771 .996 r
.59463 .4774 .60044 .48077 .61201 .47947 .60626 .47679 Mtetra
.323 .747 .974 r
.60626 .47679 .61201 .47947 .62366 .47857 .61797 .47665 Mtetra
.195 .694 .914 r
.61797 .47665 .62366 .47857 .63538 .47805 .62977 .47696 Mtetra
.049 .608 .807 r
.62977 .47696 .63538 .47805 .6472 .47789 .64166 .47767 Mtetra
.091 0 0 r
.64166 .47767 .6472 .47789 .6591 .47807 .65365 .47871 Mtetra
.204 0 0 r
.65365 .47871 .6591 .47807 .67109 .47849 .66573 .47998 Mtetra
.282 0 0 r
.66573 .47998 .67109 .47849 .68316 .47907 .6779 .48133 Mtetra
.326 0 0 r
.6779 .48133 .68316 .47907 .69532 .47967 .69016 .4826 Mtetra
.343 0 0 r
.69016 .4826 .69532 .47967 .70756 .48014 .70249 .48358 Mtetra
.337 0 0 r
.70249 .48358 .70756 .48014 .71986 .48031 .71488 .48406 Mtetra
.307 0 0 r
.71488 .48406 .71986 .48031 .73221 .48001 .72731 .48386 Mtetra
.253 0 0 r
.72731 .48386 .73221 .48001 .7446 .47908 .73976 .48276 Mtetra
.168 0 0 r
.73976 .48276 .7446 .47908 .75701 .47735 .75222 .48063 Mtetra
.043 0 0 r
.75222 .48063 .75701 .47735 .76942 .47472 .76466 .47737 Mtetra
0 0 0 r
.76466 .47737 .76942 .47472 .78182 .47111 .77707 .47293 Mtetra
.329 .795 .687 r
.77707 .47293 .78182 .47111 .79419 .46652 .78944 .46735 Mtetra
.526 .918 .819 r
.78944 .46735 .79419 .46652 .80653 .46098 .80176 .46073 Mtetra
.672 .974 .896 r
.80176 .46073 .80653 .46098 .81883 .45458 .81404 .45321 Mtetra
.756 .974 .922 r
.81404 .45321 .81883 .45458 .83111 .44746 .82628 .44498 Mtetra
.795 .947 .922 r
.82628 .44498 .83111 .44746 .84335 .43978 .83849 .43626 Mtetra
.808 .913 .911 r
.83849 .43626 .84335 .43978 .85559 .43172 .8507 .42726 Mtetra
.808 .88 .898 r
.8507 .42726 .85559 .43172 .86783 .42347 .86291 .41819 Mtetra
.801 .851 .888 r
.86291 .41819 .86783 .42347 .88009 .41518 .87515 .40921 Mtetra
.79 .828 .881 r
.87515 .40921 .88009 .41518 .89238 .40701 .88743 .40048 Mtetra
.778 .808 .877 r
.88743 .40048 .89238 .40701 .90472 .39906 .89978 .3921 Mtetra
.766 .793 .875 r
.89978 .3921 .90472 .39906 .91712 .39143 .91219 .38414 Mtetra
.753 .781 .875 r
.91219 .38414 .91712 .39143 .9296 .38416 .92469 .37664 Mtetra
.664 .741 .908 r
.33554 .53892 .34209 .54503 .35259 .54173 .34605 .5356 Mtetra
.663 .741 .908 r
.34605 .5356 .35259 .54173 .36312 .53841 .35661 .53226 Mtetra
.35661 .53226 .36312 .53841 .3737 .53509 .36722 .52891 Mtetra
.36722 .52891 .3737 .53509 .38431 .53175 .37786 .52555 Mtetra
.37786 .52555 .38431 .53175 .39497 .5284 .38855 .52218 Mtetra
.38855 .52218 .39497 .5284 .40568 .52504 .39928 .5188 Mtetra
.663 .742 .909 r
.39928 .5188 .40568 .52504 .41642 .52167 .41005 .51542 Mtetra
.662 .742 .909 r
.41005 .51542 .41642 .52167 .42721 .5183 .42086 .51203 Mtetra
.42086 .51203 .42721 .5183 .43804 .51492 .43172 .50865 Mtetra
.661 .742 .91 r
.43172 .50865 .43804 .51492 .44892 .51155 .44262 .50528 Mtetra
.66 .743 .911 r
.44262 .50528 .44892 .51155 .45983 .50819 .45357 .50193 Mtetra
.658 .743 .913 r
.45357 .50193 .45983 .50819 .4708 .50485 .46456 .49862 Mtetra
.655 .744 .916 r
.46456 .49862 .4708 .50485 .4818 .50155 .47559 .49537 Mtetra
.651 .746 .919 r
.47559 .49537 .4818 .50155 .49285 .4983 .48667 .49221 Mtetra
.646 .748 .924 r
.48667 .49221 .49285 .4983 .50395 .49514 .4978 .48917 Mtetra
.638 .751 .93 r
.4978 .48917 .50395 .49514 .5151 .49209 .50897 .48629 Mtetra
.628 .754 .938 r
.50897 .48629 .5151 .49209 .52629 .48918 .5202 .48361 Mtetra
.614 .759 .948 r
.5202 .48361 .52629 .48918 .53753 .48646 .53147 .48119 Mtetra
.594 .764 .96 r
.53147 .48119 .53753 .48646 .54883 .48398 .5428 .47909 Mtetra
.566 .77 .974 r
.5428 .47909 .54883 .48398 .56018 .48178 .5542 .47735 Mtetra
.526 .774 .988 r
.5542 .47735 .56018 .48178 .5716 .47993 .56565 .47605 Mtetra
.467 .772 .997 r
.56565 .47605 .5716 .47993 .58308 .47845 .57718 .47523 Mtetra
.381 .758 .991 r
.57718 .47523 .58308 .47845 .59463 .4774 .58879 .47493 Mtetra
.259 .718 .952 r
.58879 .47493 .59463 .4774 .60626 .47679 .60048 .47517 Mtetra
.105 .639 .862 r
.60048 .47517 .60626 .47679 .61797 .47665 .61226 .47594 Mtetra
0 .523 .718 r
.61226 .47594 .61797 .47665 .62977 .47696 .62414 .4772 Mtetra
.209 0 0 r
.62414 .4772 .62977 .47696 .64166 .47767 .63612 .47889 Mtetra
.317 0 0 r
.63612 .47889 .64166 .47767 .65365 .47871 .64819 .48089 Mtetra
.384 0 0 r
.64819 .48089 .65365 .47871 .66573 .47998 .66037 .48305 Mtetra
.421 0 0 r
.66037 .48305 .66573 .47998 .6779 .48133 .67264 .48518 Mtetra
.433 0 0 r
.67264 .48518 .6779 .48133 .69016 .4826 .685 .48706 Mtetra
.426 0 0 r
.685 .48706 .69016 .4826 .70249 .48358 .69742 .48844 Mtetra
.4 0 0 r
.69742 .48844 .70249 .48358 .71488 .48406 .70989 .48908 Mtetra
.353 0 0 r
.70989 .48908 .71488 .48406 .72731 .48386 .72239 .48874 Mtetra
.28 0 0 r
.72239 .48874 .72731 .48386 .73976 .48276 .7349 .48723 Mtetra
.169 0 0 r
.7349 .48723 .73976 .48276 .75222 .48063 .74739 .48441 Mtetra
.008 0 0 r
.74739 .48441 .75222 .48063 .76466 .47737 .75984 .48022 Mtetra
0 0 0 r
.75984 .48022 .76466 .47737 .77707 .47293 .77225 .47467 Mtetra
.446 .866 .73 r
.77225 .47467 .77707 .47293 .78944 .46735 .7846 .46786 Mtetra
.642 .967 .852 r
.7846 .46786 .78944 .46735 .80176 .46073 .79689 .45996 Mtetra
.757 .986 .902 r
.79689 .45996 .80176 .46073 .81404 .45321 .80913 .45117 Mtetra
.81 .961 .909 r
.80913 .45117 .81404 .45321 .82628 .44498 .82133 .44176 Mtetra
.826 .924 .899 r
.82133 .44176 .82628 .44498 .83849 .43626 .83351 .43196 Mtetra
.826 .887 .886 r
.83351 .43196 .83849 .43626 .8507 .42726 .84568 .42203 Mtetra
.818 .856 .876 r
.84568 .42203 .8507 .42726 .86291 .41819 .85787 .41218 Mtetra
.807 .83 .869 r
.85787 .41218 .86291 .41819 .87515 .40921 .8701 .40259 Mtetra
.794 .809 .865 r
.8701 .40259 .87515 .40921 .88743 .40048 .88239 .39338 Mtetra
.78 .793 .863 r
.88239 .39338 .88743 .40048 .89978 .3921 .89474 .38464 Mtetra
.766 .78 .864 r
.89474 .38464 .89978 .3921 .91219 .38414 .90718 .37644 Mtetra
.753 .77 .867 r
.90718 .37644 .91219 .38414 .92469 .37664 .91971 .36878 Mtetra
.663 .741 .908 r
.32893 .53277 .33554 .53892 .34605 .5356 .33948 .52943 Mtetra
.33948 .52943 .34605 .5356 .35661 .53226 .35006 .52607 Mtetra
.35006 .52607 .35661 .53226 .36722 .52891 .36069 .52269 Mtetra
.36069 .52269 .36722 .52891 .37786 .52555 .37136 .51931 Mtetra
.37136 .51931 .37786 .52555 .38855 .52218 .38207 .51592 Mtetra
.38207 .51592 .38855 .52218 .39928 .5188 .39283 .51252 Mtetra
.662 .742 .909 r
.39283 .51252 .39928 .5188 .41005 .51542 .40363 .50912 Mtetra
.40363 .50912 .41005 .51542 .42086 .51203 .41447 .50573 Mtetra
.661 .742 .91 r
.41447 .50573 .42086 .51203 .43172 .50865 .42535 .50235 Mtetra
.659 .743 .911 r
.42535 .50235 .43172 .50865 .44262 .50528 .43628 .49899 Mtetra
.658 .743 .913 r
.43628 .49899 .44262 .50528 .45357 .50193 .44725 .49568 Mtetra
.655 .744 .916 r
.44725 .49568 .45357 .50193 .46456 .49862 .45827 .49242 Mtetra
.651 .746 .919 r
.45827 .49242 .46456 .49862 .47559 .49537 .46933 .48926 Mtetra
.645 .748 .924 r
.46933 .48926 .47559 .49537 .48667 .49221 .48044 .48622 Mtetra
.637 .751 .93 r
.48044 .48622 .48667 .49221 .4978 .48917 .49159 .48336 Mtetra
.626 .754 .939 r
.49159 .48336 .4978 .48917 .50897 .48629 .5028 .48071 Mtetra
.611 .758 .949 r
.5028 .48071 .50897 .48629 .5202 .48361 .51405 .47834 Mtetra
.589 .764 .962 r
.51405 .47834 .5202 .48361 .53147 .48119 .52536 .47632 Mtetra
.558 .768 .976 r
.52536 .47632 .53147 .48119 .5428 .47909 .53673 .4747 Mtetra
.512 .771 .99 r
.53673 .4747 .5428 .47909 .5542 .47735 .54816 .47356 Mtetra
.443 .766 .997 r
.54816 .47356 .5542 .47735 .56565 .47605 .55966 .47296 Mtetra
.341 .742 .983 r
.55966 .47296 .56565 .47605 .57718 .47523 .57124 .47294 Mtetra
.197 .685 .926 r
.57124 .47294 .57718 .47523 .58879 .47493 .58291 .47354 Mtetra
.019 .58 .805 r
.58291 .47354 .58879 .47493 .60048 .47517 .59466 .47477 Mtetra
.161 0 0 r
.59466 .47477 .60048 .47517 .61226 .47594 .60652 .47659 Mtetra
.306 0 0 r
.60652 .47659 .61226 .47594 .62414 .4772 .61848 .47893 Mtetra
.404 0 0 r
.61848 .47893 .62414 .4772 .63612 .47889 .63055 .48169 Mtetra
.461 0 0 r
.63055 .48169 .63612 .47889 .64819 .48089 .64272 .48471 Mtetra
.49 0 0 r
.64272 .48471 .64819 .48089 .66037 .48305 .655 .48777 Mtetra
.499 0 0 r
.655 .48777 .66037 .48305 .67264 .48518 .66737 .49063 Mtetra
.491 0 .013 r
.66737 .49063 .67264 .48518 .685 .48706 .67982 .493 Mtetra
.468 0 .021 r
.67982 .493 .685 .48706 .69742 .48844 .69233 .4946 Mtetra
.428 0 .006 r
.69233 .4946 .69742 .48844 .70989 .48908 .70488 .49514 Mtetra
.364 0 0 r
.70488 .49514 .70989 .48908 .72239 .48874 .71743 .49437 Mtetra
.268 0 0 r
.71743 .49437 .72239 .48874 .7349 .48723 .72998 .49211 Mtetra
.121 0 0 r
.72998 .49211 .7349 .48723 .74739 .48441 .74249 .48827 Mtetra
0 0 0 r
.74249 .48827 .74739 .48441 .75984 .48022 .75494 .48283 Mtetra
.361 .798 .633 r
.75494 .48283 .75984 .48022 .77225 .47467 .76732 .4759 Mtetra
.606 .949 .801 r
.76732 .4759 .77225 .47467 .7846 .46786 .77964 .46764 Mtetra
.757 .992 .879 r
.77964 .46764 .7846 .46786 .79689 .45996 .79189 .4583 Mtetra
.823 .971 .894 r
.79189 .4583 .79689 .45996 .80913 .45117 .80408 .44817 Mtetra
.844 .93 .886 r
.80408 .44817 .80913 .45117 .82133 .44176 .81624 .43754 Mtetra
.843 .89 .873 r
.81624 .43754 .82133 .44176 .83351 .43196 .82839 .4267 Mtetra
.834 .856 .862 r
.82839 .4267 .83351 .43196 .84568 .42203 .84054 .41591 Mtetra
.822 .829 .854 r
.84054 .41591 .84568 .42203 .85787 .41218 .85272 .40537 Mtetra
.808 .807 .85 r
.85272 .40537 .85787 .41218 .8701 .40259 .86495 .39525 Mtetra
.793 .791 .85 r
.86495 .39525 .8701 .40259 .88239 .39338 .87724 .38567 Mtetra
.779 .778 .852 r
.87724 .38567 .88239 .39338 .89474 .38464 .88962 .37668 Mtetra
.765 .768 .855 r
.88962 .37668 .89474 .38464 .90718 .37644 .90209 .36833 Mtetra
.751 .76 .86 r
.90209 .36833 .90718 .37644 .91971 .36878 .91465 .36059 Mtetra
.663 .741 .908 r
.32228 .52658 .32893 .53277 .33948 .52943 .33285 .52321 Mtetra
.33285 .52321 .33948 .52943 .35006 .52607 .34346 .51983 Mtetra
.34346 .51983 .35006 .52607 .36069 .52269 .35411 .51643 Mtetra
.35411 .51643 .36069 .52269 .37136 .51931 .36481 .51303 Mtetra
.36481 .51303 .37136 .51931 .38207 .51592 .37555 .50962 Mtetra
.662 .742 .909 r
.37555 .50962 .38207 .51592 .39283 .51252 .38633 .50621 Mtetra
.38633 .50621 .39283 .51252 .40363 .50912 .39716 .5028 Mtetra
.661 .742 .91 r
.39716 .5028 .40363 .50912 .41447 .50573 .40802 .49941 Mtetra
.659 .743 .911 r
.40802 .49941 .41447 .50573 .42535 .50235 .41894 .49604 Mtetra
.657 .743 .913 r
.41894 .49604 .42535 .50235 .43628 .49899 .42989 .49271 Mtetra
.655 .744 .916 r
.42989 .49271 .43628 .49899 .44725 .49568 .44089 .48945 Mtetra
.65 .746 .919 r
.44089 .48945 .44725 .49568 .45827 .49242 .45193 .48629 Mtetra
.645 .748 .924 r
.45193 .48629 .45827 .49242 .46933 .48926 .46302 .48325 Mtetra
.636 .75 .931 r
.46302 .48325 .46933 .48926 .48044 .48622 .47416 .48039 Mtetra
.625 .754 .939 r
.47416 .48039 .48044 .48622 .49159 .48336 .48534 .47777 Mtetra
.609 .758 .95 r
.48534 .47777 .49159 .48336 .5028 .48071 .49657 .47544 Mtetra
.585 .763 .963 r
.49657 .47544 .5028 .48071 .51405 .47834 .50785 .47348 Mtetra
.551 .767 .978 r
.50785 .47348 .51405 .47834 .52536 .47632 .51919 .47196 Mtetra
.5 .767 .991 r
.51919 .47196 .52536 .47632 .53673 .4747 .5306 .47096 Mtetra
.422 .758 .995 r
.5306 .47096 .53673 .4747 .54816 .47356 .54207 .47055 Mtetra
.305 .726 .973 r
.54207 .47055 .54816 .47356 .55966 .47296 .55362 .47079 Mtetra
.14 .651 .898 r
.55362 .47079 .55966 .47296 .57124 .47294 .56525 .47173 Mtetra
0 .522 .749 r
.56525 .47173 .57124 .47294 .58291 .47354 .57698 .47339 Mtetra
.243 0 0 r
.57698 .47339 .58291 .47354 .59466 .47477 .5888 .47575 Mtetra
.382 0 0 r
.5888 .47575 .59466 .47477 .60652 .47659 .60074 .47875 Mtetra
.469 0 0 r
.60074 .47875 .60652 .47659 .61848 .47893 .61279 .48228 Mtetra
.518 0 0 r
.61279 .48228 .61848 .47893 .63055 .48169 .62495 .48618 Mtetra
.542 .037 .004 r
.62495 .48618 .63055 .48169 .64272 .48471 .63723 .49022 Mtetra
.548 .063 .056 r
.63723 .49022 .64272 .48471 .655 .48777 .6496 .49413 Mtetra
.54 .069 .085 r
.6496 .49413 .655 .48777 .66737 .49063 .66208 .49759 Mtetra
.519 .056 .094 r
.66208 .49759 .66737 .49063 .67982 .493 .67462 .50025 Mtetra
.484 .023 .083 r
.67462 .50025 .67982 .493 .69233 .4946 .68721 .50179 Mtetra
.429 0 .048 r
.68721 .50179 .69233 .4946 .70488 .49514 .69982 .50189 Mtetra
.344 0 0 r
.69982 .50189 .70488 .49514 .71743 .49437 .71242 .50032 Mtetra
.212 0 0 r
.71242 .50032 .71743 .49437 .72998 .49211 .72498 .49693 Mtetra
.007 0 0 r
.72498 .49693 .72998 .49211 .74249 .48827 .73748 .49171 Mtetra
0 0 0 r
.73748 .49171 .74249 .48827 .75494 .48283 .74991 .48471 Mtetra
.569 .925 .75 r
.74991 .48471 .75494 .48283 .76732 .4759 .76226 .47615 Mtetra
.757 .995 .856 r
.76226 .47615 .76732 .4759 .77964 .46764 .77453 .46628 Mtetra
.837 .976 .88 r
.77453 .46628 .77964 .46764 .79189 .4583 .78673 .45542 Mtetra
.86 .931 .871 r
.78673 .45542 .79189 .4583 .80408 .44817 .79889 .44393 Mtetra
.858 .888 .857 r
.79889 .44393 .80408 .44817 .81624 .43754 .81101 .43214 Mtetra
.848 .852 .846 r
.81101 .43214 .81624 .43754 .82839 .4267 .82312 .42035 Mtetra
.834 .823 .838 r
.82312 .42035 .82839 .4267 .84054 .41591 .83526 .4088 Mtetra
.819 .802 .835 r
.83526 .4088 .84054 .41591 .85272 .40537 .84744 .39771 Mtetra
.805 .785 .835 r
.84744 .39771 .85272 .40537 .86495 .39525 .85968 .38721 Mtetra
.79 .773 .837 r
.85968 .38721 .86495 .39525 .87724 .38567 .872 .37737 Mtetra
.775 .763 .842 r
.872 .37737 .87724 .38567 .88962 .37668 .88441 .36825 Mtetra
.761 .756 .848 r
.88441 .36825 .88962 .37668 .90209 .36833 .89691 .35984 Mtetra
.748 .751 .855 r
.89691 .35984 .90209 .36833 .91465 .36059 .90953 .35211 Mtetra
.663 .741 .908 r
.31558 .52034 .32228 .52658 .33285 .52321 .32617 .51695 Mtetra
.32617 .51695 .33285 .52321 .34346 .51983 .33681 .51354 Mtetra
.33681 .51354 .34346 .51983 .35411 .51643 .34749 .51013 Mtetra
.34749 .51013 .35411 .51643 .36481 .51303 .35821 .50671 Mtetra
.662 .742 .909 r
.35821 .50671 .36481 .51303 .37555 .50962 .36898 .50328 Mtetra
.36898 .50328 .37555 .50962 .38633 .50621 .37979 .49986 Mtetra
.661 .742 .91 r
.37979 .49986 .38633 .50621 .39716 .5028 .39064 .49646 Mtetra
.66 .742 .911 r
.39064 .49646 .39716 .5028 .40802 .49941 .40153 .49308 Mtetra
.657 .743 .913 r
.40153 .49308 .40802 .49941 .41894 .49604 .41247 .48974 Mtetra
.655 .744 .916 r
.41247 .48974 .41894 .49604 .42989 .49271 .42345 .48646 Mtetra
.65 .745 .919 r
.42345 .48646 .42989 .49271 .44089 .48945 .43447 .48329 Mtetra
.644 .747 .924 r
.43447 .48329 .44089 .48945 .45193 .48629 .44554 .48025 Mtetra
.636 .75 .931 r
.44554 .48025 .45193 .48629 .46302 .48325 .45666 .47739 Mtetra
.624 .753 .939 r
.45666 .47739 .46302 .48325 .47416 .48039 .46782 .47477 Mtetra
.607 .757 .95 r
.46782 .47477 .47416 .48039 .48534 .47777 .47902 .47247 Mtetra
.582 .761 .964 r
.47902 .47247 .48534 .47777 .49657 .47544 .49028 .47055 Mtetra
.546 .765 .979 r
.49028 .47055 .49657 .47544 .50785 .47348 .5016 .4691 Mtetra
.49 .764 .992 r
.5016 .4691 .50785 .47348 .51919 .47196 .51297 .46821 Mtetra
.405 .751 .994 r
.51297 .46821 .51919 .47196 .5306 .47096 .52441 .46797 Mtetra
.274 .711 .965 r
.52441 .46797 .5306 .47096 .54207 .47055 .53592 .46844 Mtetra
.092 .62 .872 r
.53592 .46844 .54207 .47055 .55362 .47079 .54752 .46969 Mtetra
0 .471 .7 r
.54752 .46969 .55362 .47079 .56525 .47173 .55921 .47175 Mtetra
.308 0 0 r
.55921 .47175 .56525 .47173 .57698 .47339 .571 .47462 Mtetra
.44 0 0 r
.571 .47462 .57698 .47339 .5888 .47575 .5829 .47826 Mtetra
.519 0 0 r
.5829 .47826 .5888 .47575 .60074 .47875 .59492 .48255 Mtetra
.562 .047 0 r
.59492 .48255 .60074 .47875 .61279 .48228 .60706 .48734 Mtetra
.581 .093 .061 r
.60706 .48734 .61279 .48228 .62495 .48618 .61932 .49239 Mtetra
.586 .118 .11 r
.61932 .49239 .62495 .48618 .63723 .49022 .63169 .4974 Mtetra
.578 .124 .138 r
.63169 .4974 .63723 .49022 .6496 .49413 .64417 .50202 Mtetra
.559 .113 .149 r
.64417 .50202 .6496 .49413 .66208 .49759 .65674 .50585 Mtetra
.527 .085 .141 r
.65674 .50585 .66208 .49759 .67462 .50025 .66937 .5085 Mtetra
.479 .033 .112 r
.66937 .5085 .67462 .50025 .68721 .50179 .68202 .50959 Mtetra
.404 0 .055 r
.68202 .50959 .68721 .50179 .69982 .50189 .69468 .50884 Mtetra
.285 0 0 r
.69468 .50884 .69982 .50189 .71242 .50032 .7073 .50603 Mtetra
.092 0 0 r
.7073 .50603 .71242 .50032 .72498 .49693 .71986 .50111 Mtetra
0 0 0 r
.71986 .50111 .72498 .49693 .73748 .49171 .73234 .49415 Mtetra
.535 .901 .705 r
.73234 .49415 .73748 .49171 .74991 .48471 .74473 .48533 Mtetra
.761 .996 .838 r
.74473 .48533 .74991 .48471 .76226 .47615 .75703 .47496 Mtetra
.851 .977 .867 r
.75703 .47496 .76226 .47615 .77453 .46628 .76925 .4634 Mtetra
.873 .928 .857 r
.76925 .4634 .77453 .46628 .78673 .45542 .78141 .45104 Mtetra
.87 .881 .841 r
.78141 .45104 .78673 .45542 .79889 .44393 .79352 .43827 Mtetra
.858 .843 .829 r
.79352 .43827 .79889 .44393 .81101 .43214 .80561 .42543 Mtetra
.844 .815 .821 r
.80561 .42543 .81101 .43214 .82312 .42035 .81772 .41284 Mtetra
.829 .793 .818 r
.81772 .41284 .82312 .42035 .83526 .4088 .82985 .40071 Mtetra
.814 .777 .818 r
.82985 .40071 .83526 .4088 .84744 .39771 .84204 .38923 Mtetra
.799 .765 .822 r
.84204 .38923 .84744 .39771 .85968 .38721 .85431 .37849 Mtetra
.785 .756 .827 r
.85431 .37849 .85968 .38721 .872 .37737 .86666 .36854 Mtetra
.77 .75 .835 r
.86666 .36854 .872 .37737 .88441 .36825 .87911 .3594 Mtetra
.756 .746 .843 r
.87911 .3594 .88441 .36825 .89691 .35984 .89167 .35104 Mtetra
.743 .743 .852 r
.89167 .35104 .89691 .35984 .90953 .35211 .90435 .34339 Mtetra
.663 .741 .908 r
.30883 .51406 .31558 .52034 .32617 .51695 .31945 .51064 Mtetra
.31945 .51064 .32617 .51695 .33681 .51354 .33011 .50722 Mtetra
.33011 .50722 .33681 .51354 .34749 .51013 .34082 .50378 Mtetra
.663 .742 .909 r
.34082 .50378 .34749 .51013 .35821 .50671 .35156 .50035 Mtetra
.662 .742 .909 r
.35156 .50035 .35821 .50671 .36898 .50328 .36236 .49691 Mtetra
.661 .742 .91 r
.36236 .49691 .36898 .50328 .37979 .49986 .37319 .49349 Mtetra
.66 .742 .911 r
.37319 .49349 .37979 .49986 .39064 .49646 .38407 .4901 Mtetra
.658 .743 .913 r
.38407 .4901 .39064 .49646 .40153 .49308 .39499 .48674 Mtetra
.655 .744 .915 r
.39499 .48674 .40153 .49308 .41247 .48974 .40595 .48345 Mtetra
.65 .745 .919 r
.40595 .48345 .41247 .48974 .42345 .48646 .41696 .48026 Mtetra
.644 .747 .924 r
.41696 .48026 .42345 .48646 .43447 .48329 .428 .47721 Mtetra
.636 .749 .93 r
.428 .47721 .43447 .48329 .44554 .48025 .4391 .47434 Mtetra
.624 .752 .939 r
.4391 .47434 .44554 .48025 .45666 .47739 .45023 .47172 Mtetra
.606 .756 .95 r
.45023 .47172 .45666 .47739 .46782 .47477 .46142 .46943 Mtetra
.581 .76 .964 r
.46142 .46943 .46782 .47477 .47902 .47247 .47265 .46753 Mtetra
.543 .763 .979 r
.47265 .46753 .47902 .47247 .49028 .47055 .48393 .46614 Mtetra
.484 .761 .992 r
.48393 .46614 .49028 .47055 .5016 .4691 .49528 .46533 Mtetra
.393 .745 .992 r
.49528 .46533 .5016 .4691 .51297 .46821 .50668 .46521 Mtetra
.252 .697 .958 r
.50668 .46521 .51297 .46821 .52441 .46797 .51816 .46587 Mtetra
.055 .594 .853 r
.51816 .46587 .52441 .46797 .53592 .46844 .52971 .46738 Mtetra
.168 0 0 r
.52971 .46738 .53592 .46844 .54752 .46969 .54136 .4698 Mtetra
.358 0 0 r
.54136 .4698 .54752 .46969 .55921 .47175 .5531 .47313 Mtetra
.484 0 0 r
.5531 .47313 .55921 .47175 .571 .47462 .56496 .47736 Mtetra
.557 .021 0 r
.56496 .47736 .571 .47462 .5829 .47826 .57694 .48239 Mtetra
.595 .094 .031 r
.57694 .48239 .5829 .47826 .59492 .48255 .58904 .48806 Mtetra
.612 .138 .104 r
.58904 .48806 .59492 .48255 .60706 .48734 .60128 .49413 Mtetra
.616 .162 .151 r
.60128 .49413 .60706 .48734 .61932 .49239 .61364 .50027 Mtetra
.608 .168 .179 r
.61364 .50027 .61932 .49239 .63169 .4974 .62611 .50611 Mtetra
.591 .159 .19 r
.62611 .50611 .63169 .4974 .64417 .50202 .63869 .51119 Mtetra
.563 .134 .185 r
.63869 .51119 .64417 .50202 .65674 .50585 .65134 .51505 Mtetra
.519 .088 .161 r
.65134 .51505 .65674 .50585 .66937 .5085 .66404 .51726 Mtetra
.452 .012 .111 r
.66404 .51726 .66937 .5085 .68202 .50959 .67674 .51744 Mtetra
.344 0 .02 r
.67674 .51744 .68202 .50959 .69468 .50884 .68942 .51534 Mtetra
.162 0 0 r
.68942 .51534 .69468 .50884 .7073 .50603 .70204 .51084 Mtetra
0 0 0 r
.70204 .51084 .7073 .50603 .71986 .50111 .71458 .504 Mtetra
.509 .88 .671 r
.71458 .504 .71986 .50111 .73234 .49415 .72703 .49501 Mtetra
.768 .997 .827 r
.72703 .49501 .73234 .49415 .74473 .48533 .73937 .48418 Mtetra
.865 .974 .856 r
.73937 .48418 .74473 .48533 .75703 .47496 .75162 .47194 Mtetra
.884 .919 .843 r
.75162 .47194 .75703 .47496 .76925 .4634 .76379 .45871 Mtetra
.878 .869 .825 r
.76379 .45871 .76925 .4634 .78141 .45104 .7759 .44495 Mtetra
.865 .831 .811 r
.7759 .44495 .78141 .45104 .79352 .43827 .78798 .43106 Mtetra
.85 .802 .804 r
.78798 .43106 .79352 .43827 .80561 .42543 .80006 .41738 Mtetra
.835 .781 .8 r
.80006 .41738 .80561 .42543 .81772 .41284 .81217 .40418 Mtetra
.82 .766 .801 r
.81217 .40418 .81772 .41284 .82985 .40071 .82432 .39167 Mtetra
.806 .755 .806 r
.82432 .39167 .82985 .40071 .84204 .38923 .83653 .37998 Mtetra
.792 .748 .812 r
.83653 .37998 .84204 .38923 .85431 .37849 .84884 .36917 Mtetra
.778 .742 .82 r
.84884 .36917 .85431 .37849 .86666 .36854 .86124 .35925 Mtetra
.764 .739 .83 r
.86124 .35925 .86666 .36854 .87911 .3594 .87375 .3502 Mtetra
.751 .737 .84 r
.87375 .3502 .87911 .3594 .89167 .35104 .88637 .34197 Mtetra
.738 .736 .85 r
.88637 .34197 .89167 .35104 .90435 .34339 .89911 .33448 Mtetra
.663 .741 .908 r
.30202 .50773 .30883 .51406 .31945 .51064 .31267 .50429 Mtetra
.31267 .50429 .31945 .51064 .33011 .50722 .32336 .50085 Mtetra
.663 .742 .909 r
.32336 .50085 .33011 .50722 .34082 .50378 .33409 .4974 Mtetra
.662 .742 .909 r
.33409 .4974 .34082 .50378 .35156 .50035 .34486 .49395 Mtetra
.661 .742 .91 r
.34486 .49395 .35156 .50035 .36236 .49691 .35568 .49052 Mtetra
.66 .742 .911 r
.35568 .49052 .36236 .49691 .37319 .49349 .36654 .4871 Mtetra
.658 .743 .913 r
.36654 .4871 .37319 .49349 .38407 .4901 .37744 .48373 Mtetra
.655 .744 .915 r
.37744 .48373 .38407 .4901 .39499 .48674 .38839 .48043 Mtetra
.651 .745 .918 r
.38839 .48043 .39499 .48674 .40595 .48345 .39938 .47722 Mtetra
.645 .747 .923 r
.39938 .47722 .40595 .48345 .41696 .48026 .41041 .47414 Mtetra
.636 .749 .93 r
.41041 .47414 .41696 .48026 .428 .47721 .42148 .47126 Mtetra
.624 .752 .938 r
.42148 .47126 .428 .47721 .4391 .47434 .43259 .46862 Mtetra
.606 .755 .949 r
.43259 .46862 .4391 .47434 .45023 .47172 .44375 .46632 Mtetra
.581 .759 .963 r
.44375 .46632 .45023 .47172 .46142 .46943 .45496 .46443 Mtetra
.542 .761 .978 r
.45496 .46443 .46142 .46943 .47265 .46753 .46621 .46305 Mtetra
.481 .758 .991 r
.46621 .46305 .47265 .46753 .48393 .46614 .47752 .46229 Mtetra
.387 .74 .992 r
.47752 .46229 .48393 .46614 .49528 .46533 .48889 .46225 Mtetra
.239 .688 .955 r
.48889 .46225 .49528 .46533 .50668 .46521 .50032 .46305 Mtetra
.032 .575 .841 r
.50032 .46305 .50668 .46521 .51816 .46587 .51183 .46477 Mtetra
.201 0 0 r
.51183 .46477 .51816 .46587 .52971 .46738 .52343 .46749 Mtetra
.393 0 0 r
.52343 .46749 .52971 .46738 .54136 .4698 .53513 .47123 Mtetra
.517 0 0 r
.53513 .47123 .54136 .4698 .5531 .47313 .54693 .476 Mtetra
.586 .059 0 r
.54693 .476 .5531 .47313 .56496 .47736 .55886 .48172 Mtetra
.622 .13 .065 r
.55886 .48172 .56496 .47736 .57694 .48239 .57091 .48823 Mtetra
.637 .174 .135 r
.57091 .48823 .57694 .48239 .58904 .48806 .58311 .49529 Mtetra
.64 .197 .181 r
.58311 .49529 .58904 .48806 .60128 .49413 .59544 .50258 Mtetra
.633 .204 .209 r
.59544 .50258 .60128 .49413 .61364 .50027 .60789 .50967 Mtetra
.618 .197 .221 r
.60789 .50967 .61364 .50027 .62611 .50611 .62047 .51606 Mtetra
.592 .174 .218 r
.62047 .51606 .62611 .50611 .63869 .51119 .63313 .52122 Mtetra
.553 .133 .198 r
.63313 .52122 .63869 .51119 .65134 .51505 .64586 .52465 Mtetra
.492 .063 .153 r
.64586 .52465 .65134 .51505 .66404 .51726 .6586 .52588 Mtetra
.393 0 .07 r
.6586 .52588 .66404 .51726 .67674 .51744 .67134 .5246 Mtetra
.221 0 0 r
.67134 .5246 .67674 .51744 .68942 .51534 .68402 .52064 Mtetra
0 0 0 r
.68402 .52064 .68942 .51534 .70204 .51084 .69662 .51402 Mtetra
.493 .868 .652 r
.69662 .51402 .70204 .51084 .71458 .504 .70912 .50493 Mtetra
.781 .998 .824 r
.70912 .50493 .71458 .504 .72703 .49501 .72152 .49372 Mtetra
.877 .967 .848 r
.72152 .49372 .72703 .49501 .73937 .48418 .73381 .48084 Mtetra
.892 .905 .829 r
.73381 .48084 .73937 .48418 .75162 .47194 .746 .46677 Mtetra
.883 .853 .809 r
.746 .46677 .75162 .47194 .76379 .45871 .75813 .45203 Mtetra
.868 .815 .794 r
.75813 .45203 .76379 .45871 .7759 .44495 .77022 .43708 Mtetra
.853 .787 .786 r
.77022 .43708 .7759 .44495 .78798 .43106 .78228 .4223 Mtetra
.838 .767 .783 r
.78228 .4223 .78798 .43106 .80006 .41738 .79437 .40802 Mtetra
.824 .753 .785 r
.79437 .40802 .80006 .41738 .81217 .40418 .80649 .39446 Mtetra
.81 .743 .789 r
.80649 .39446 .81217 .40418 .82432 .39167 .81867 .38178 Mtetra
.797 .737 .796 r
.81867 .38178 .82432 .39167 .83653 .37998 .83093 .37007 Mtetra
.784 .733 .806 r
.83093 .37007 .83653 .37998 .84884 .36917 .84329 .35934 Mtetra
.77 .731 .816 r
.84329 .35934 .84884 .36917 .86124 .35925 .85575 .34959 Mtetra
.757 .73 .827 r
.85575 .34959 .86124 .35925 .87375 .3502 .86833 .34074 Mtetra
.744 .73 .839 r
.86833 .34074 .87375 .3502 .88637 .34197 .88102 .33272 Mtetra
.732 .731 .85 r
.88102 .33272 .88637 .34197 .89911 .33448 .89382 .32543 Mtetra
.663 .741 .908 r
.29517 .50136 .30202 .50773 .31267 .50429 .30584 .4979 Mtetra
.663 .742 .909 r
.30584 .4979 .31267 .50429 .32336 .50085 .31656 .49444 Mtetra
.662 .742 .909 r
.31656 .49444 .32336 .50085 .33409 .4974 .32731 .49098 Mtetra
.661 .742 .91 r
.32731 .49098 .33409 .4974 .34486 .49395 .33811 .48753 Mtetra
.66 .742 .911 r
.33811 .48753 .34486 .49395 .35568 .49052 .34896 .4841 Mtetra
.658 .743 .912 r
.34896 .4841 .35568 .49052 .36654 .4871 .35984 .48071 Mtetra
.655 .744 .915 r
.35984 .48071 .36654 .4871 .37744 .48373 .37077 .47738 Mtetra
.651 .745 .918 r
.37077 .47738 .37744 .48373 .38839 .48043 .38174 .47415 Mtetra
.645 .746 .923 r
.38174 .47415 .38839 .48043 .39938 .47722 .39275 .47105 Mtetra
.637 .748 .929 r
.39275 .47105 .39938 .47722 .41041 .47414 .4038 .46813 Mtetra
.625 .751 .937 r
.4038 .46813 .41041 .47414 .42148 .47126 .41489 .46547 Mtetra
.608 .754 .948 r
.41489 .46547 .42148 .47126 .43259 .46862 .42603 .46314 Mtetra
.582 .757 .962 r
.42603 .46314 .43259 .46862 .44375 .46632 .43721 .46123 Mtetra
.543 .759 .977 r
.43721 .46123 .44375 .46632 .45496 .46443 .44843 .45984 Mtetra
.483 .755 .99 r
.44843 .45984 .45496 .46443 .46621 .46305 .45971 .45909 Mtetra
.387 .737 .991 r
.45971 .45909 .46621 .46305 .47752 .46229 .47103 .4591 Mtetra
.236 .683 .955 r
.47103 .4591 .47752 .46229 .48889 .46225 .48243 .45998 Mtetra
.022 .566 .839 r
.48243 .45998 .48889 .46225 .50032 .46305 .49389 .46185 Mtetra
.219 0 0 r
.49389 .46185 .50032 .46305 .51183 .46477 .50543 .46479 Mtetra
.416 0 0 r
.50543 .46479 .51183 .46477 .52343 .46749 .51707 .46888 Mtetra
.54 0 0 r
.51707 .46888 .52343 .46749 .53513 .47123 .52881 .47411 Mtetra
.608 .088 0 r
.52881 .47411 .53513 .47123 .54693 .476 .54068 .48045 Mtetra
.643 .159 .088 r
.54068 .48045 .54693 .476 .55886 .48172 .55267 .48774 Mtetra
.658 .202 .158 r
.55267 .48774 .55886 .48172 .57091 .48823 .56481 .49577 Mtetra
.661 .226 .204 r
.56481 .49577 .57091 .48823 .58311 .49529 .57709 .50418 Mtetra
.655 .234 .232 r
.57709 .50418 .58311 .49529 .59544 .50258 .58952 .51252 Mtetra
.641 .228 .245 r
.58952 .51252 .59544 .50258 .60789 .50967 .60207 .52026 Mtetra
.618 .208 .244 r
.60207 .52026 .60789 .50967 .62047 .51606 .61473 .52679 Mtetra
.582 .17 .227 r
.61473 .52679 .62047 .51606 .63313 .52122 .62747 .53151 Mtetra
.526 .106 .186 r
.62747 .53151 .63313 .52122 .64586 .52465 .64025 .53391 Mtetra
.435 0 .109 r
.64025 .53391 .64586 .52465 .6586 .52588 .65303 .53356 Mtetra
.271 0 0 r
.65303 .53356 .6586 .52588 .67134 .5246 .66577 .53025 Mtetra
0 0 0 r
.66577 .53025 .67134 .5246 .68402 .52064 .67844 .52395 Mtetra
.489 .865 .65 r
.67844 .52395 .68402 .52064 .69662 .51402 .691 .51485 Mtetra
.799 .999 .829 r
.691 .51485 .69662 .51402 .70912 .50493 .70345 .50332 Mtetra
.887 .954 .842 r
.70345 .50332 .70912 .50493 .72152 .49372 .71579 .48985 Mtetra
.895 .887 .816 r
.71579 .48985 .72152 .49372 .73381 .48084 .72803 .47499 Mtetra
.883 .834 .793 r
.72803 .47499 .73381 .48084 .746 .46677 .74019 .45931 Mtetra
.867 .796 .778 r
.74019 .45931 .746 .46677 .75813 .45203 .75229 .44331 Mtetra
.852 .769 .769 r
.75229 .44331 .75813 .45203 .77022 .43708 .76436 .42745 Mtetra
.838 .751 .767 r
.76436 .42745 .77022 .43708 .78228 .4223 .77643 .41208 Mtetra
.825 .738 .768 r
.77643 .41208 .78228 .4223 .79437 .40802 .78854 .39748 Mtetra
.812 .73 .773 r
.78854 .39748 .79437 .40802 .80649 .39446 .80069 .38381 Mtetra
.8 .724 .781 r
.80069 .38381 .80649 .39446 .81867 .38178 .81292 .37118 Mtetra
.788 .722 .791 r
.81292 .37118 .81867 .38178 .83093 .37007 .82525 .35963 Mtetra
.775 .721 .802 r
.82525 .35963 .83093 .37007 .84329 .35934 .83767 .34914 Mtetra
.763 .722 .814 r
.83767 .34914 .84329 .35934 .85575 .34959 .85021 .33965 Mtetra
.75 .723 .827 r
.85021 .33965 .85575 .34959 .86833 .34074 .86286 .33108 Mtetra
.737 .725 .84 r
.86286 .33108 .86833 .34074 .88102 .33272 .87562 .32334 Mtetra
.725 .727 .852 r
.87562 .32334 .88102 .33272 .89382 .32543 .8885 .3163 Mtetra
.663 .741 .909 r
.28827 .49495 .29517 .50136 .30584 .4979 .29896 .49147 Mtetra
.662 .742 .909 r
.29896 .49147 .30584 .4979 .31656 .49444 .3097 .48799 Mtetra
.661 .742 .91 r
.3097 .48799 .31656 .49444 .32731 .49098 .32049 .48453 Mtetra
.66 .742 .911 r
.32049 .48453 .32731 .49098 .33811 .48753 .33131 .48108 Mtetra
.658 .743 .912 r
.33131 .48108 .33811 .48753 .34896 .4841 .34218 .47767 Mtetra
.656 .743 .914 r
.34218 .47767 .34896 .4841 .35984 .48071 .35309 .47432 Mtetra
.652 .744 .917 r
.35309 .47432 .35984 .48071 .37077 .47738 .36404 .47106 Mtetra
.646 .746 .922 r
.36404 .47106 .37077 .47738 .38174 .47415 .37503 .46792 Mtetra
.638 .748 .928 r
.37503 .46792 .38174 .47415 .39275 .47105 .38606 .46498 Mtetra
.626 .75 .936 r
.38606 .46498 .39275 .47105 .4038 .46813 .39713 .46228 Mtetra
.609 .753 .946 r
.39713 .46228 .4038 .46813 .41489 .46547 .40824 .4599 Mtetra
.584 .756 .96 r
.40824 .4599 .41489 .46547 .42603 .46314 .41939 .45795 Mtetra
.546 .757 .975 r
.41939 .45795 .42603 .46314 .43721 .46123 .43059 .45652 Mtetra
.487 .753 .989 r
.43059 .45652 .43721 .46123 .44843 .45984 .44183 .45574 Mtetra
.393 .735 .991 r
.44183 .45574 .44843 .45984 .45971 .45909 .45312 .45575 Mtetra
.243 .683 .958 r
.45312 .45575 .45971 .45909 .47103 .4591 .46447 .45666 Mtetra
.026 .565 .846 r
.46447 .45666 .47103 .4591 .48243 .45998 .47588 .4586 Mtetra
.223 0 0 r
.47588 .4586 .48243 .45998 .49389 .46185 .48737 .46171 Mtetra
.428 0 0 r
.48737 .46171 .49389 .46185 .50543 .46479 .49894 .46604 Mtetra
.556 0 0 r
.49894 .46604 .50543 .46479 .51707 .46888 .51062 .47166 Mtetra
.626 .109 0 r
.51062 .47166 .51707 .46888 .52881 .47411 .52241 .47852 Mtetra
.66 .181 .103 r
.52241 .47852 .52881 .47411 .54068 .48045 .53434 .48653 Mtetra
.675 .225 .174 r
.53434 .48653 .54068 .48045 .55267 .48774 .5464 .49545 Mtetra
.679 .249 .221 r
.5464 .49545 .55267 .48774 .56481 .49577 .55862 .50493 Mtetra
.673 .258 .249 r
.55862 .50493 .56481 .49577 .57709 .50418 .57099 .51451 Mtetra
.661 .254 .264 r
.57099 .51451 .57709 .50418 .58952 .51252 .58351 .5236 Mtetra
.64 .236 .264 r
.58351 .5236 .58952 .51252 .60207 .52026 .59615 .53153 Mtetra
.607 .202 .249 r
.59615 .53153 .60207 .52026 .61473 .52679 .60888 .53763 Mtetra
.556 .142 .212 r
.60888 .53763 .61473 .52679 .62747 .53151 .62168 .54126 Mtetra
.472 .041 .138 r
.62168 .54126 .62747 .53151 .64025 .53391 .6345 .54194 Mtetra
.315 0 0 r
.6345 .54194 .64025 .53391 .65303 .53356 .64729 .53937 Mtetra
0 0 0 r
.64729 .53937 .65303 .53356 .66577 .53025 .66001 .53349 Mtetra
.496 .873 .664 r
.66001 .53349 .66577 .53025 .67844 .52395 .67264 .52448 Mtetra
.818 .999 .84 r
.67264 .52448 .67844 .52395 .691 .51485 .68516 .51272 Mtetra
.893 .936 .836 r
.68516 .51272 .691 .51485 .70345 .50332 .69756 .49873 Mtetra
.894 .864 .803 r
.69756 .49873 .70345 .50332 .71579 .48985 .70985 .48313 Mtetra
.879 .811 .778 r
.70985 .48313 .71579 .48985 .72803 .47499 .72205 .46655 Mtetra
.863 .775 .762 r
.72205 .46655 .72803 .47499 .74019 .45931 .73418 .44955 Mtetra
.849 .75 .754 r
.73418 .44955 .74019 .45931 .75229 .44331 .74627 .43264 Mtetra
.836 .733 .751 r
.74627 .43264 .75229 .44331 .76436 .42745 .75835 .41622 Mtetra
.824 .722 .753 r
.75835 .41622 .76436 .42745 .77643 .41208 .77045 .40059 Mtetra
.812 .715 .758 r
.77045 .40059 .77643 .41208 .78854 .39748 .7826 .38594 Mtetra
.801 .711 .766 r
.7826 .38594 .78854 .39748 .80069 .38381 .79481 .37241 Mtetra
.79 .71 .776 r
.79481 .37241 .80069 .38381 .81292 .37118 .8071 .36003 Mtetra
.778 .71 .788 r
.8071 .36003 .81292 .37118 .82525 .35963 .8195 .3488 Mtetra
.766 .712 .801 r
.8195 .3488 .82525 .35963 .83767 .34914 .832 .33867 Mtetra
.754 .715 .815 r
.832 .33867 .83767 .34914 .85021 .33965 .84461 .32955 Mtetra
.742 .718 .829 r
.84461 .32955 .85021 .33965 .86286 .33108 .85734 .32133 Mtetra
.73 .722 .843 r
.85734 .32133 .86286 .33108 .87562 .32334 .87018 .3139 Mtetra
.719 .725 .855 r
.87018 .3139 .87562 .32334 .8885 .3163 .88313 .30714 Mtetra
.662 .742 .909 r
.28131 .48849 .28827 .49495 .29896 .49147 .29203 .485 Mtetra
.662 .742 .91 r
.29203 .485 .29896 .49147 .3097 .48799 .3028 .48151 Mtetra
.66 .742 .91 r
.3028 .48151 .3097 .48799 .32049 .48453 .3136 .47805 Mtetra
.659 .742 .912 r
.3136 .47805 .32049 .48453 .33131 .48108 .32445 .47461 Mtetra
.656 .743 .914 r
.32445 .47461 .33131 .48108 .34218 .47767 .33534 .47124 Mtetra
.652 .744 .917 r
.33534 .47124 .34218 .47767 .35309 .47432 .34628 .46794 Mtetra
.647 .745 .921 r
.34628 .46794 .35309 .47432 .36404 .47106 .35725 .46478 Mtetra
.639 .747 .927 r
.35725 .46478 .36404 .47106 .37503 .46792 .36826 .46179 Mtetra
.628 .749 .934 r
.36826 .46179 .37503 .46792 .38606 .46498 .37931 .45903 Mtetra
.612 .752 .944 r
.37931 .45903 .38606 .46498 .39713 .46228 .3904 .4566 Mtetra
.588 .754 .957 r
.3904 .4566 .39713 .46228 .40824 .4599 .40152 .45459 Mtetra
.552 .755 .972 r
.40152 .45459 .40824 .4599 .41939 .45795 .41269 .45309 Mtetra
.495 .752 .987 r
.41269 .45309 .41939 .45795 .43059 .45652 .4239 .45225 Mtetra
.405 .735 .992 r
.4239 .45225 .43059 .45652 .44183 .45574 .43515 .4522 Mtetra
.26 .686 .964 r
.43515 .4522 .44183 .45574 .45312 .45575 .44646 .45308 Mtetra
.044 .573 .861 r
.44646 .45308 .45312 .45575 .46447 .45666 .45782 .45505 Mtetra
.213 0 0 r
.45782 .45505 .46447 .45666 .47588 .4586 .46925 .45822 Mtetra
.429 0 0 r
.46925 .45822 .47588 .4586 .48737 .46171 .48076 .46272 Mtetra
.565 .004 0 r
.48076 .46272 .48737 .46171 .49894 .46604 .49236 .46862 Mtetra
.638 .122 0 r
.49236 .46862 .49894 .46604 .51062 .47166 .50407 .47592 Mtetra
.674 .197 .111 r
.50407 .47592 .51062 .47166 .52241 .47852 .51591 .48453 Mtetra
.69 .243 .184 r
.51591 .48453 .52241 .47852 .53434 .48653 .5279 .49426 Mtetra
.694 .268 .232 r
.5279 .49426 .53434 .48653 .5464 .49545 .54003 .50475 Mtetra
.69 .279 .262 r
.54003 .50475 .5464 .49545 .55862 .50493 .55233 .51551 Mtetra
.678 .276 .277 r
.55233 .51551 .55862 .50493 .57099 .51451 .56479 .52593 Mtetra
.659 .261 .279 r
.56479 .52593 .57099 .51451 .58351 .5236 .57739 .53527 Mtetra
.63 .229 .266 r
.57739 .53527 .58351 .5236 .59615 .53153 .5901 .54276 Mtetra
.583 .173 .231 r
.5901 .54276 .59615 .53153 .60888 .53763 .6029 .54769 Mtetra
.504 .076 .161 r
.6029 .54769 .60888 .53763 .62168 .54126 .61574 .54947 Mtetra
.353 0 .019 r
.61574 .54947 .62168 .54126 .6345 .54194 .62857 .54774 Mtetra
.029 0 0 r
.62857 .54774 .6345 .54194 .64729 .53937 .64135 .54237 Mtetra
.515 .89 .695 r
.64135 .54237 .64729 .53937 .66001 .53349 .65405 .53352 Mtetra
.837 .993 .854 r
.65405 .53352 .66001 .53349 .67264 .52448 .66663 .52161 Mtetra
.894 .913 .829 r
.66663 .52161 .67264 .52448 .68516 .51272 .6791 .50718 Mtetra
.888 .838 .79 r
.6791 .50718 .68516 .51272 .69756 .49873 .69145 .49092 Mtetra
.872 .787 .764 r
.69145 .49092 .69756 .49873 .70985 .48313 .7037 .4735 Mtetra
.857 .753 .747 r
.7037 .4735 .70985 .48313 .72205 .46655 .71588 .45556 Mtetra
.843 .73 .739 r
.71588 .45556 .72205 .46655 .73418 .44955 .728 .43767 Mtetra
.831 .715 .737 r
.728 .43767 .73418 .44955 .74627 .43264 .7401 .42024 Mtetra
.82 .705 .738 r
.7401 .42024 .74627 .43264 .75835 .41622 .75222 .40363 Mtetra
.81 .7 .744 r
.75222 .40363 .75835 .41622 .77045 .40059 .76436 .38805 Mtetra
.8 .697 .752 r
.76436 .38805 .77045 .40059 .7826 .38594 .77656 .37365 Mtetra
.79 .697 .762 r
.77656 .37365 .7826 .38594 .79481 .37241 .78884 .36047 Mtetra
.779 .699 .775 r
.78884 .36047 .79481 .37241 .8071 .36003 .80122 .34852 Mtetra
.769 .702 .789 r
.80122 .34852 .8071 .36003 .8195 .3488 .81369 .33774 Mtetra
.757 .706 .803 r
.81369 .33774 .8195 .3488 .832 .33867 .82628 .32806 Mtetra
.746 .71 .818 r
.82628 .32806 .832 .33867 .84461 .32955 .83897 .31937 Mtetra
.734 .715 .833 r
.83897 .31937 .84461 .32955 .85734 .32133 .85179 .31154 Mtetra
.723 .72 .847 r
.85179 .31154 .85734 .32133 .87018 .3139 .86471 .30445 Mtetra
.712 .724 .859 r
.86471 .30445 .87018 .3139 .88313 .30714 .87774 .29798 Mtetra
.662 .742 .909 r
.2743 .48199 .28131 .48849 .29203 .485 .28505 .47849 Mtetra
.661 .742 .91 r
.28505 .47849 .29203 .485 .3028 .48151 .29584 .475 Mtetra
.659 .742 .911 r
.29584 .475 .3028 .48151 .3136 .47805 .30667 .47155 Mtetra
.657 .743 .913 r
.30667 .47155 .3136 .47805 .32445 .47461 .31754 .46814 Mtetra
.653 .744 .916 r
.31754 .46814 .32445 .47461 .33534 .47124 .32845 .46482 Mtetra
.648 .745 .92 r
.32845 .46482 .33534 .47124 .34628 .46794 .33941 .46161 Mtetra
.641 .746 .925 r
.33941 .46161 .34628 .46794 .35725 .46478 .3504 .45857 Mtetra
.631 .748 .932 r
.3504 .45857 .35725 .46478 .36826 .46179 .36143 .45576 Mtetra
.615 .75 .942 r
.36143 .45576 .36826 .46179 .37931 .45903 .3725 .45325 Mtetra
.593 .753 .954 r
.3725 .45325 .37931 .45903 .3904 .4566 .3836 .45115 Mtetra
.559 .754 .969 r
.3836 .45115 .3904 .4566 .40152 .45459 .39474 .44957 Mtetra
.506 .751 .984 r
.39474 .44957 .40152 .45459 .41269 .45309 .40591 .44863 Mtetra
.421 .736 .992 r
.40591 .44863 .41269 .45309 .4239 .45225 .41713 .44848 Mtetra
.283 .693 .972 r
.41713 .44848 .4239 .45225 .43515 .4522 .42839 .44928 Mtetra
.073 .588 .882 r
.42839 .44928 .43515 .4522 .44646 .45308 .4397 .45119 Mtetra
0 .402 .683 r
.4397 .45119 .44646 .45308 .45782 .45505 .45107 .45436 Mtetra
.42 0 0 r
.45107 .45436 .45782 .45505 .46925 .45822 .46251 .45893 Mtetra
.568 .003 0 r
.46251 .45893 .46925 .45822 .48076 .46272 .47404 .46501 Mtetra
.647 .129 0 r
.47404 .46501 .48076 .46272 .49236 .46862 .48567 .47263 Mtetra
.685 .208 .112 r
.48567 .47263 .49236 .46862 .50407 .47592 .49741 .48174 Mtetra
.703 .257 .189 r
.49741 .48174 .50407 .47592 .51591 .48453 .5093 .49216 Mtetra
.707 .284 .24 r
.5093 .49216 .51591 .48453 .5279 .49426 .52134 .50355 Mtetra
.704 .296 .271 r
.52134 .50355 .5279 .49426 .54003 .50475 .53355 .51543 Mtetra
.694 .295 .288 r
.53355 .51543 .54003 .50475 .55233 .51551 .54593 .52712 Mtetra
.676 .282 .291 r
.54593 .52712 .55233 .51551 .56479 .52593 .55846 .53783 Mtetra
.65 .253 .279 r
.55846 .53783 .56479 .52593 .57739 .53527 .57114 .54673 Mtetra
.607 .2 .246 r
.57114 .54673 .57739 .53527 .5901 .54276 .58392 .55298 Mtetra
.534 .107 .178 r
.58392 .55298 .5901 .54276 .6029 .54769 .59677 .55592 Mtetra
.388 0 .034 r
.59677 .55592 .6029 .54769 .61574 .54947 .60963 .55508 Mtetra
.052 0 0 r
.60963 .55508 .61574 .54947 .62857 .54774 .62245 .55029 Mtetra
.545 .913 .74 r
.62245 .55029 .62857 .54774 .64135 .54237 .63521 .5417 Mtetra
.851 .979 .865 r
.63521 .5417 .64135 .54237 .65405 .53352 .64787 .52971 Mtetra
.89 .884 .821 r
.64787 .52971 .65405 .53352 .66663 .52161 .6604 .51492 Mtetra
.879 .81 .778 r
.6604 .51492 .66663 .52161 .6791 .50718 .67282 .49807 Mtetra
.862 .762 .75 r
.67282 .49807 .6791 .50718 .69145 .49092 .68514 .47991 Mtetra
.848 .73 .734 r
.68514 .47991 .69145 .49092 .7037 .4735 .69737 .46112 Mtetra
.835 .71 .726 r
.69737 .46112 .7037 .4735 .71588 .45556 .70954 .44231 Mtetra
.824 .697 .723 r
.70954 .44231 .71588 .45556 .728 .43767 .72168 .42396 Mtetra
.814 .688 .725 r
.72168 .42396 .728 .43767 .7401 .42024 .73382 .40644 Mtetra
.805 .684 .731 r
.73382 .40644 .7401 .42024 .75222 .40363 .74598 .39 Mtetra
.797 .683 .739 r
.74598 .39 .75222 .40363 .76436 .38805 .75819 .37477 Mtetra
.788 .684 .75 r
.75819 .37477 .76436 .38805 .77656 .37365 .77047 .36083 Mtetra
.779 .687 .762 r
.77047 .36083 .77656 .37365 .78884 .36047 .78283 .3482 Mtetra
.769 .691 .776 r
.78283 .3482 .78884 .36047 .80122 .34852 .79529 .33681 Mtetra
.759 .696 .792 r
.79529 .33681 .80122 .34852 .81369 .33774 .80785 .32659 Mtetra
.749 .702 .808 r
.80785 .32659 .81369 .33774 .82628 .32806 .82052 .31743 Mtetra
.738 .708 .823 r
.82052 .31743 .82628 .32806 .83897 .31937 .83331 .30921 Mtetra
.726 .714 .838 r
.83331 .30921 .83897 .31937 .85179 .31154 .8462 .30179 Mtetra
.716 .719 .852 r
.8462 .30179 .85179 .31154 .86471 .30445 .85921 .29505 Mtetra
.706 .724 .864 r
.85921 .29505 .86471 .30445 .87774 .29798 .87231 .28885 Mtetra
.661 .742 .91 r
.26724 .47546 .2743 .48199 .28505 .47849 .27801 .47195 Mtetra
.659 .742 .911 r
.27801 .47195 .28505 .47849 .29584 .475 .28882 .46847 Mtetra
.657 .743 .913 r
.28882 .46847 .29584 .475 .30667 .47155 .29968 .46504 Mtetra
.654 .743 .915 r
.29968 .46504 .30667 .47155 .31754 .46814 .31057 .46167 Mtetra
.649 .744 .919 r
.31057 .46167 .31754 .46814 .32845 .46482 .32151 .45842 Mtetra
.643 .746 .924 r
.32151 .45842 .32845 .46482 .33941 .46161 .33248 .45533 Mtetra
.633 .747 .93 r
.33248 .45533 .33941 .46161 .3504 .45857 .34349 .45245 Mtetra
.619 .749 .939 r
.34349 .45245 .3504 .45857 .36143 .45576 .35453 .44986 Mtetra
.598 .751 .951 r
.35453 .44986 .36143 .45576 .3725 .45325 .36561 .44766 Mtetra
.567 .753 .965 r
.36561 .44766 .3725 .45325 .3836 .45115 .37672 .44596 Mtetra
.518 .75 .98 r
.37672 .44596 .3836 .45115 .39474 .44957 .38787 .4449 Mtetra
.44 .738 .991 r
.38787 .4449 .39474 .44957 .40591 .44863 .39905 .44461 Mtetra
.313 .701 .979 r
.39905 .44461 .40591 .44863 .41713 .44848 .41027 .44527 Mtetra
.113 .608 .906 r
.41027 .44527 .41713 .44848 .42839 .44928 .42153 .44706 Mtetra
0 .431 .724 r
.42153 .44706 .42839 .44928 .4397 .45119 .43285 .45014 Mtetra
.399 0 0 r
.43285 .45014 .4397 .45119 .45107 .45436 .44422 .45469 Mtetra
.563 0 0 r
.44422 .45469 .45107 .45436 .46251 .45893 .45567 .46084 Mtetra
.651 .129 0 r
.45567 .46084 .46251 .45893 .47404 .46501 .4672 .46866 Mtetra
.694 .215 .108 r
.4672 .46866 .47404 .46501 .48567 .47263 .47885 .47815 Mtetra
.713 .267 .19 r
.47885 .47815 .48567 .47263 .49741 .48174 .49063 .48914 Mtetra
.719 .297 .244 r
.49063 .48914 .49741 .48174 .5093 .49216 .50257 .50133 Mtetra
.717 .311 .277 r
.50257 .50133 .5093 .49216 .52134 .50355 .51467 .5142 Mtetra
.708 .311 .295 r
.51467 .5142 .52134 .50355 .53355 .51543 .52695 .52708 Mtetra
.692 .3 .299 r
.52695 .52708 .53355 .51543 .54593 .52712 .5394 .53912 Mtetra
.668 .273 .289 r
.5394 .53912 .54593 .52712 .55846 .53783 .55201 .54938 Mtetra
.629 .224 .257 r
.55201 .54938 .55846 .53783 .57114 .54673 .56475 .55696 Mtetra
.56 .135 .19 r
.56475 .55696 .57114 .54673 .58392 .55298 .57759 .56107 Mtetra
.42 0 .043 r
.57759 .56107 .58392 .55298 .59677 .55592 .59046 .56116 Mtetra
.068 0 0 r
.59046 .56116 .59677 .55592 .60963 .55508 .60332 .55701 Mtetra
.582 .939 .795 r
.60332 .55701 .60963 .55508 .62245 .55029 .61614 .54874 Mtetra
.858 .957 .872 r
.61614 .54874 .62245 .55029 .63521 .5417 .62886 .53674 Mtetra
.88 .853 .811 r
.62886 .53674 .63521 .5417 .64787 .52971 .64147 .52168 Mtetra
.867 .782 .765 r
.64147 .52168 .64787 .52971 .6604 .51492 .65397 .50433 Mtetra
.851 .737 .737 r
.65397 .50433 .6604 .51492 .67282 .49807 .66636 .48551 Mtetra
.837 .708 .722 r
.66636 .48551 .67282 .49807 .68514 .47991 .67866 .46596 Mtetra
.826 .69 .714 r
.67866 .46596 .68514 .47991 .69737 .46112 .69089 .44634 Mtetra
.816 .679 .712 r
.69089 .44634 .69737 .46112 .70954 .44231 .70308 .42717 Mtetra
.808 .672 .714 r
.70308 .42717 .70954 .44231 .72168 .42396 .71525 .40884 Mtetra
.8 .669 .719 r
.71525 .40884 .72168 .42396 .73382 .40644 .72744 .39161 Mtetra
.793 .669 .727 r
.72744 .39161 .73382 .40644 .74598 .39 .73967 .37565 Mtetra
.785 .671 .738 r
.73967 .37565 .74598 .39 .75819 .37477 .75196 .36102 Mtetra
.777 .675 .751 r
.75196 .36102 .75819 .37477 .77047 .36083 .76432 .34775 Mtetra
.769 .68 .765 r
.76432 .34775 .77047 .36083 .78283 .3482 .77677 .33579 Mtetra
.76 .686 .781 r
.77677 .33579 .78283 .3482 .79529 .33681 .78932 .32507 Mtetra
.75 .693 .797 r
.78932 .32507 .79529 .33681 .80785 .32659 .80198 .31546 Mtetra
.74 .7 .814 r
.80198 .31546 .80785 .32659 .82052 .31743 .81474 .30686 Mtetra
.729 .707 .83 r
.81474 .30686 .82052 .31743 .83331 .30921 .82762 .29912 Mtetra
.719 .714 .845 r
.82762 .29912 .83331 .30921 .8462 .30179 .8406 .29211 Mtetra
.709 .719 .858 r
.8406 .29211 .8462 .30179 .85921 .29505 .85368 .28571 Mtetra
.699 .724 .869 r
.85368 .28571 .85921 .29505 .87231 .28885 .86686 .27978 Mtetra
.66 .742 .911 r
.26012 .46889 .26724 .47546 .27801 .47195 .27091 .46538 Mtetra
.658 .742 .912 r
.27091 .46538 .27801 .47195 .28882 .46847 .28175 .46192 Mtetra
.655 .743 .914 r
.28175 .46192 .28882 .46847 .29968 .46504 .29263 .45852 Mtetra
.651 .744 .918 r
.29263 .45852 .29968 .46504 .31057 .46167 .30354 .45522 Mtetra
.645 .745 .922 r
.30354 .45522 .31057 .46167 .32151 .45842 .3145 .45206 Mtetra
.636 .746 .928 r
.3145 .45206 .32151 .45842 .33248 .45533 .32549 .44911 Mtetra
.623 .748 .937 r
.32549 .44911 .33248 .45533 .34349 .45245 .33651 .44643 Mtetra
.604 .75 .947 r
.33651 .44643 .34349 .45245 .35453 .44986 .34757 .44412 Mtetra
.575 .751 .961 r
.34757 .44412 .35453 .44986 .36561 .44766 .35866 .44229 Mtetra
.531 .75 .976 r
.35866 .44229 .36561 .44766 .37672 .44596 .36978 .44107 Mtetra
.461 .74 .988 r
.36978 .44107 .37672 .44596 .38787 .4449 .38092 .44061 Mtetra
.346 .709 .985 r
.38092 .44061 .38787 .4449 .39905 .44461 .3921 .44109 Mtetra
.161 .63 .93 r
.3921 .44109 .39905 .44461 .41027 .44527 .40332 .44269 Mtetra
0 .467 .771 r
.40332 .44269 .41027 .44527 .42153 .44706 .41458 .44561 Mtetra
.365 0 0 r
.41458 .44561 .42153 .44706 .43285 .45014 .42588 .45005 Mtetra
.551 0 0 r
.42588 .45005 .43285 .45014 .44422 .45469 .43725 .45616 Mtetra
.651 .124 0 r
.43725 .45616 .44422 .45469 .45567 .46084 .4487 .46407 Mtetra
.7 .218 .099 r
.4487 .46407 .45567 .46084 .4672 .46866 .46024 .4738 Mtetra
.722 .274 .188 r
.46024 .4738 .4672 .46866 .47885 .47815 .47191 .48523 Mtetra
.729 .307 .245 r
.47191 .48523 .47885 .47815 .49063 .48914 .48372 .49807 Mtetra
.728 .323 .28 r
.48372 .49807 .49063 .48914 .50257 .50133 .4957 .51182 Mtetra
.72 .325 .3 r
.4957 .51182 .50257 .50133 .51467 .5142 .50786 .52578 Mtetra
.706 .315 .306 r
.50786 .52578 .51467 .5142 .52695 .52708 .52021 .53904 Mtetra
.684 .291 .296 r
.52021 .53904 .52695 .52708 .5394 .53912 .53274 .55061 Mtetra
.648 .245 .266 r
.53274 .55061 .5394 .53912 .55201 .54938 .54542 .55947 Mtetra
.585 .158 .198 r
.54542 .55947 .55201 .54938 .56475 .55696 .55822 .56474 Mtetra
.449 0 .046 r
.55822 .56474 .56475 .55696 .57759 .56107 .57109 .56579 Mtetra
.078 0 0 r
.57109 .56579 .57759 .56107 .59046 .56116 .58398 .56231 Mtetra
.621 .959 .853 r
.58398 .56231 .59046 .56116 .60332 .55701 .59684 .5544 Mtetra
.857 .926 .873 r
.59684 .5544 .60332 .55701 .61614 .54874 .60962 .54247 Mtetra
.867 .82 .8 r
.60962 .54247 .61614 .54874 .62886 .53674 .62231 .5272 Mtetra
.853 .753 .753 r
.62231 .5272 .62886 .53674 .64147 .52168 .63489 .50945 Mtetra
.838 .713 .726 r
.63489 .50945 .64147 .52168 .65397 .50433 .64736 .49006 Mtetra
.826 .687 .711 r
.64736 .49006 .65397 .50433 .66636 .48551 .65973 .46987 Mtetra
.816 .671 .703 r
.65973 .46987 .66636 .48551 .67866 .46596 .67203 .44955 Mtetra
.807 .661 .701 r
.67203 .44955 .67866 .46596 .69089 .44634 .68429 .42968 Mtetra
.8 .656 .704 r
.68429 .42968 .69089 .44634 .70308 .42717 .69652 .41065 Mtetra
.794 .654 .709 r
.69652 .41065 .70308 .42717 .71525 .40884 .70875 .39275 Mtetra
.787 .655 .717 r
.70875 .39275 .71525 .40884 .72744 .39161 .72101 .37614 Mtetra
.781 .658 .728 r
.72101 .37614 .72744 .39161 .73967 .37565 .73332 .36092 Mtetra
.774 .663 .74 r
.73332 .36092 .73967 .37565 .75196 .36102 .74569 .34709 Mtetra
.767 .669 .755 r
.74569 .34709 .75196 .36102 .76432 .34775 .75815 .33462 Mtetra
.759 .676 .77 r
.75815 .33462 .76432 .34775 .77677 .33579 .77069 .32343 Mtetra
.751 .684 .787 r
.77069 .32343 .77677 .33579 .78932 .32507 .78334 .31342 Mtetra
.741 .692 .805 r
.78334 .31342 .78932 .32507 .80198 .31546 .79609 .30447 Mtetra
.731 .7 .821 r
.79609 .30447 .80198 .31546 .81474 .30686 .80894 .29642 Mtetra
.721 .708 .837 r
.80894 .29642 .81474 .30686 .82762 .29912 .8219 .28916 Mtetra
.711 .715 .852 r
.8219 .28916 .82762 .29912 .8406 .29211 .83497 .28255 Mtetra
.702 .721 .864 r
.83497 .28255 .8406 .29211 .85368 .28571 .84813 .27645 Mtetra
.693 .726 .875 r
.84813 .27645 .85368 .28571 .86686 .27978 .86138 .27076 Mtetra
.659 .742 .912 r
.25294 .46228 .26012 .46889 .27091 .46538 .26376 .45879 Mtetra
.656 .743 .914 r
.26376 .45879 .27091 .46538 .28175 .46192 .27462 .45535 Mtetra
.652 .743 .917 r
.27462 .45535 .28175 .46192 .29263 .45852 .28552 .452 Mtetra
.647 .744 .921 r
.28552 .452 .29263 .45852 .30354 .45522 .29645 .44879 Mtetra
.638 .746 .926 r
.29645 .44879 .30354 .45522 .3145 .45206 .30743 .44576 Mtetra
.627 .747 .934 r
.30743 .44576 .3145 .45206 .32549 .44911 .31843 .44298 Mtetra
.61 .749 .944 r
.31843 .44298 .32549 .44911 .33651 .44643 .32947 .44055 Mtetra
.584 .75 .956 r
.32947 .44055 .33651 .44643 .34757 .44412 .34053 .43857 Mtetra
.545 .749 .971 r
.34053 .43857 .34757 .44412 .35866 .44229 .35163 .43717 Mtetra
.483 .742 .985 r
.35163 .43717 .35866 .44229 .36978 .44107 .36274 .43651 Mtetra
.381 .717 .988 r
.36274 .43651 .36978 .44107 .38092 .44061 .37389 .43676 Mtetra
.213 .652 .951 r
.37389 .43676 .38092 .44061 .3921 .44109 .38506 .43813 Mtetra
0 .509 .821 r
.38506 .43813 .3921 .44109 .40332 .44269 .39627 .44082 Mtetra
.318 0 0 r
.39627 .44082 .40332 .44269 .41458 .44561 .40751 .44506 Mtetra
.53 0 0 r
.40751 .44506 .41458 .44561 .42588 .45005 .4188 .45104 Mtetra
.647 .111 0 r
.4188 .45104 .42588 .45005 .43725 .45616 .43015 .45891 Mtetra
.704 .216 .085 r
.43015 .45891 .43725 .45616 .4487 .46407 .44159 .46875 Mtetra
.729 .278 .181 r
.44159 .46875 .4487 .46407 .46024 .4738 .45314 .48048 Mtetra
.738 .314 .243 r
.45314 .48048 .46024 .4738 .47191 .48523 .46482 .49382 Mtetra
.738 .332 .282 r
.46482 .49382 .47191 .48523 .48372 .49807 .47667 .50831 Mtetra
.731 .337 .303 r
.47667 .50831 .48372 .49807 .4957 .51182 .4887 .52321 Mtetra
.718 .329 .31 r
.4887 .52321 .4957 .51182 .50786 .52578 .50092 .53758 Mtetra
.698 .306 .301 r
.50092 .53758 .50786 .52578 .52021 .53904 .51334 .55036 Mtetra
.666 .263 .272 r
.51334 .55036 .52021 .53904 .53274 .55061 .52594 .56043 Mtetra
.607 .179 .204 r
.52594 .56043 .53274 .55061 .54542 .55947 .53869 .56682 Mtetra
.475 0 .044 r
.53869 .56682 .54542 .55947 .55822 .56474 .55154 .5688 Mtetra
.08 0 0 r
.55154 .5688 .55822 .56474 .57109 .56579 .56444 .56601 Mtetra
.657 .968 .904 r
.56444 .56601 .57109 .56579 .58398 .56231 .57734 .55849 Mtetra
.849 .891 .868 r
.57734 .55849 .58398 .56231 .59684 .5544 .59018 .54667 Mtetra
.852 .787 .787 r
.59018 .54667 .59684 .5544 .60962 .54247 .60294 .53128 Mtetra
.838 .726 .741 r
.60294 .53128 .60962 .54247 .62231 .5272 .6156 .5132 Mtetra
.825 .69 .715 r
.6156 .5132 .62231 .5272 .63489 .50945 .62815 .49336 Mtetra
.814 .667 .701 r
.62815 .49336 .63489 .50945 .64736 .49006 .64061 .47263 Mtetra
.805 .653 .694 r
.64061 .47263 .64736 .49006 .65973 .46987 .65299 .45174 Mtetra
.798 .645 .692 r
.65299 .45174 .65973 .46987 .67203 .44955 .66531 .43129 Mtetra
.792 .641 .695 r
.66531 .43129 .67203 .44955 .68429 .42968 .67761 .4117 Mtetra
.786 .641 .7 r
.67761 .4117 .68429 .42968 .69652 .41065 .68989 .39326 Mtetra
.781 .642 .708 r
.68989 .39326 .69652 .41065 .70875 .39275 .7022 .37613 Mtetra
.776 .646 .718 r
.7022 .37613 .70875 .39275 .72101 .37614 .71454 .36041 Mtetra
.771 .652 .731 r
.71454 .36041 .72101 .37614 .73332 .36092 .72693 .34612 Mtetra
.765 .659 .745 r
.72693 .34612 .73332 .36092 .74569 .34709 .7394 .33321 Mtetra
.758 .667 .761 r
.7394 .33321 .74569 .34709 .75815 .33462 .75195 .32163 Mtetra
.75 .675 .778 r
.75195 .32163 .75815 .33462 .77069 .32343 .7646 .31126 Mtetra
.742 .685 .796 r
.7646 .31126 .77069 .32343 .78334 .31342 .77734 .30198 Mtetra
.732 .694 .814 r
.77734 .30198 .78334 .31342 .79609 .30447 .79018 .29367 Mtetra
.723 .702 .83 r
.79018 .29367 .79609 .30447 .80894 .29642 .80313 .28617 Mtetra
.713 .71 .846 r
.80313 .28617 .80894 .29642 .8219 .28916 .81617 .27936 Mtetra
.704 .717 .859 r
.81617 .27936 .8219 .28916 .83497 .28255 .82931 .2731 Mtetra
.695 .723 .871 r
.82931 .2731 .83497 .28255 .84813 .27645 .84254 .26728 Mtetra
.688 .727 .88 r
.84254 .26728 .84813 .27645 .86138 .27076 .85587 .26181 Mtetra
.657 .742 .913 r
.24571 .45565 .25294 .46228 .26376 .45879 .25655 .45218 Mtetra
.653 .743 .916 r
.25655 .45218 .26376 .45879 .27462 .45535 .26743 .44878 Mtetra
.648 .744 .919 r
.26743 .44878 .27462 .45535 .28552 .452 .27835 .4455 Mtetra
.641 .745 .924 r
.27835 .4455 .28552 .452 .29645 .44879 .2893 .44239 Mtetra
.631 .746 .931 r
.2893 .44239 .29645 .44879 .30743 .44576 .30029 .43951 Mtetra
.616 .748 .94 r
.30029 .43951 .30743 .44576 .31843 .44298 .31131 .43695 Mtetra
.593 .749 .952 r
.31131 .43695 .31843 .44298 .32947 .44055 .32235 .43482 Mtetra
.558 .748 .966 r
.32235 .43482 .32947 .44055 .34053 .43857 .33342 .43323 Mtetra
.504 .743 .98 r
.33342 .43323 .34053 .43857 .35163 .43717 .34451 .43234 Mtetra
.415 .724 .989 r
.34451 .43234 .35163 .43717 .36274 .43651 .35563 .43233 Mtetra
.267 .673 .968 r
.35563 .43233 .36274 .43651 .37389 .43676 .36676 .43342 Mtetra
.034 .551 .868 r
.36676 .43342 .37389 .43676 .38506 .43813 .37791 .43582 Mtetra
.256 0 0 r
.37791 .43582 .38506 .43813 .39627 .44082 .3891 .43978 Mtetra
.498 0 0 r
.3891 .43978 .39627 .44082 .40751 .44506 .40031 .44553 Mtetra
.637 .092 0 r
.40031 .44553 .40751 .44506 .4188 .45104 .41158 .45327 Mtetra
.704 .209 .065 r
.41158 .45327 .4188 .45104 .43015 .45891 .42291 .46309 Mtetra
.734 .279 .172 r
.42291 .46309 .43015 .45891 .44159 .46875 .43434 .47496 Mtetra
.745 .319 .239 r
.43434 .47496 .44159 .46875 .45314 .48048 .44589 .48866 Mtetra
.746 .34 .281 r
.44589 .48866 .45314 .48048 .46482 .49382 .45759 .50372 Mtetra
.741 .346 .304 r
.45759 .50372 .46482 .49382 .47667 .50831 .46947 .51941 Mtetra
.729 .34 .312 r
.46947 .51941 .47667 .50831 .4887 .52321 .48156 .53475 Mtetra
.711 .319 .305 r
.48156 .53475 .4887 .52321 .50092 .53758 .49385 .54861 Mtetra
.682 .278 .275 r
.49385 .54861 .50092 .53758 .51334 .55036 .50635 .5598 Mtetra
.627 .197 .206 r
.50635 .5598 .51334 .55036 .52594 .56043 .51903 .56724 Mtetra
.499 .015 .037 r
.51903 .56724 .52594 .56043 .53869 .56682 .53184 .57011 Mtetra
.075 0 0 r
.53184 .57011 .53869 .56682 .55154 .5688 .54473 .56798 Mtetra
.685 .962 .941 r
.54473 .56798 .55154 .5688 .56444 .56601 .55765 .56087 Mtetra
.836 .852 .857 r
.55765 .56087 .56444 .56601 .57734 .55849 .57055 .5492 Mtetra
.836 .755 .775 r
.57055 .5492 .57734 .55849 .59018 .54667 .58337 .53373 Mtetra
.823 .701 .73 r
.58337 .53373 .59018 .54667 .60294 .53128 .59611 .51541 Mtetra
.812 .669 .705 r
.59611 .51541 .60294 .53128 .6156 .5132 .60875 .49521 Mtetra
.802 .649 .692 r
.60875 .49521 .6156 .5132 .62815 .49336 .6213 .47407 Mtetra
.795 .637 .686 r
.6213 .47407 .62815 .49336 .64061 .47263 .63376 .45275 Mtetra
.789 .63 .685 r
.63376 .45275 .64061 .47263 .65299 .45174 .64617 .43186 Mtetra
.784 .627 .687 r
.64617 .43186 .65299 .45174 .66531 .43129 .65853 .41185 Mtetra
.779 .628 .692 r
.65853 .41185 .66531 .43129 .67761 .4117 .67088 .393 Mtetra
.775 .63 .7 r
.67088 .393 .67761 .4117 .68989 .39326 .68324 .37549 Mtetra
.771 .635 .711 r
.68324 .37549 .68989 .39326 .7022 .37613 .69562 .3594 Mtetra
.766 .641 .723 r
.69562 .3594 .7022 .37613 .71454 .36041 .70805 .34474 Mtetra
.761 .649 .737 r
.70805 .34474 .71454 .36041 .72693 .34612 .72054 .3315 Mtetra
.755 .657 .753 r
.72054 .3315 .72693 .34612 .7394 .33321 .73311 .31959 Mtetra
.749 .667 .77 r
.73311 .31959 .7394 .33321 .75195 .32163 .74575 .30893 Mtetra
.741 .677 .788 r
.74575 .30893 .75195 .32163 .7646 .31126 .75849 .29938 Mtetra
.733 .687 .806 r
.75849 .29938 .7646 .31126 .77734 .30198 .77133 .29082 Mtetra
.724 .696 .824 r
.77133 .29082 .77734 .30198 .79018 .29367 .78426 .28312 Mtetra
.715 .705 .84 r
.78426 .28312 .79018 .29367 .80313 .28617 .79729 .27612 Mtetra
.705 .713 .854 r
.79729 .27612 .80313 .28617 .81617 .27936 .81042 .26971 Mtetra
.697 .72 .867 r
.81042 .26971 .81617 .27936 .82931 .2731 .82363 .26377 Mtetra
.689 .725 .877 r
.82363 .26377 .82931 .2731 .84254 .26728 .83693 .2582 Mtetra
.683 .729 .885 r
.83693 .2582 .84254 .26728 .85587 .26181 .85032 .2529 Mtetra
.655 .743 .914 r
.23842 .44899 .24571 .45565 .25655 .45218 .24928 .44555 Mtetra
.65 .743 .918 r
.24928 .44555 .25655 .45218 .26743 .44878 .26018 .44221 Mtetra
.644 .744 .922 r
.26018 .44221 .26743 .44878 .27835 .4455 .27112 .43902 Mtetra
.635 .745 .928 r
.27112 .43902 .27835 .4455 .2893 .44239 .28209 .43604 Mtetra
.621 .747 .936 r
.28209 .43604 .2893 .44239 .30029 .43951 .29309 .43335 Mtetra
.601 .747 .947 r
.29309 .43335 .30029 .43951 .31131 .43695 .30411 .43104 Mtetra
.571 .747 .96 r
.30411 .43104 .31131 .43695 .32235 .43482 .31516 .42925 Mtetra
.524 .744 .975 r
.31516 .42925 .32235 .43482 .33342 .43323 .32623 .42812 Mtetra
.448 .73 .987 r
.32623 .42812 .33342 .43323 .34451 .43234 .33731 .42783 Mtetra
.32 .691 .979 r
.33731 .42783 .34451 .43234 .35563 .43233 .34841 .4286 Mtetra
.108 .592 .909 r
.34841 .4286 .35563 .43233 .36676 .43342 .35952 .43067 Mtetra
0 .396 .715 r
.35952 .43067 .36676 .43342 .37791 .43582 .37065 .43429 Mtetra
.454 0 0 r
.37065 .43429 .37791 .43582 .3891 .43978 .3818 .43973 Mtetra
.621 .065 0 r
.3818 .43973 .3891 .43978 .40031 .44553 .39298 .44722 Mtetra
.702 .198 .039 r
.39298 .44722 .40031 .44553 .41158 .45327 .40421 .4569 Mtetra
.737 .277 .158 r
.40421 .4569 .41158 .45327 .42291 .46309 .41552 .46879 Mtetra
.751 .322 .233 r
.41552 .46879 .42291 .46309 .43434 .47496 .42693 .48268 Mtetra
.753 .345 .278 r
.42693 .48268 .43434 .47496 .44589 .48866 .43848 .49814 Mtetra
.749 .354 .304 r
.43848 .49814 .44589 .48866 .45759 .50372 .4502 .51445 Mtetra
.739 .349 .313 r
.4502 .51445 .45759 .50372 .46947 .51941 .46214 .5306 Mtetra
.722 .33 .306 r
.46214 .5306 .46947 .51941 .48156 .53475 .47429 .5454 Mtetra
.695 .291 .277 r
.47429 .5454 .48156 .53475 .49385 .54861 .48667 .55758 Mtetra
.645 .212 .206 r
.48667 .55758 .49385 .54861 .50635 .5598 .49926 .56596 Mtetra
.52 .027 .026 r
.49926 .56596 .50635 .5598 .51903 .56724 .51201 .56965 Mtetra
.061 0 0 r
.51201 .56965 .51903 .56724 .53184 .57011 .52489 .56815 Mtetra
.701 .939 .962 r
.52489 .56815 .53184 .57011 .54473 .56798 .53782 .56144 Mtetra
.82 .814 .844 r
.53782 .56144 .54473 .56798 .55765 .56087 .55075 .54995 Mtetra
.819 .726 .762 r
.55075 .54995 .55765 .56087 .57055 .5492 .56364 .53446 Mtetra
.809 .678 .72 r
.56364 .53446 .57055 .5492 .58337 .53373 .57646 .51597 Mtetra
.799 .649 .696 r
.57646 .51597 .58337 .53373 .59611 .51541 .58919 .49551 Mtetra
.791 .632 .684 r
.58919 .49551 .59611 .51541 .60875 .49521 .60182 .47407 Mtetra
.785 .622 .679 r
.60182 .47407 .60875 .49521 .6213 .47407 .61437 .45245 Mtetra
.779 .616 .678 r
.61437 .45245 .6213 .47407 .63376 .45275 .62686 .43127 Mtetra
.775 .614 .681 r
.62686 .43127 .63376 .45275 .64617 .43186 .6393 .41098 Mtetra
.771 .615 .686 r
.6393 .41098 .64617 .43186 .65853 .41185 .65172 .39188 Mtetra
.768 .619 .694 r
.65172 .39188 .65853 .41185 .67088 .393 .66414 .37412 Mtetra
.765 .624 .704 r
.66414 .37412 .67088 .393 .68324 .37549 .67657 .35779 Mtetra
.761 .631 .716 r
.67657 .35779 .68324 .37549 .69562 .3594 .68904 .34289 Mtetra
.757 .639 .731 r
.68904 .34289 .69562 .3594 .70805 .34474 .70156 .32941 Mtetra
.752 .649 .746 r
.70156 .32941 .70805 .34474 .72054 .3315 .71415 .31727 Mtetra
.747 .659 .764 r
.71415 .31727 .72054 .3315 .73311 .31959 .72681 .30638 Mtetra
.74 .669 .782 r
.72681 .30638 .73311 .31959 .74575 .30893 .73955 .29661 Mtetra
.732 .68 .8 r
.73955 .29661 .74575 .30893 .75849 .29938 .75239 .28786 Mtetra
.724 .691 .818 r
.75239 .28786 .75849 .29938 .77133 .29082 .76531 .27997 Mtetra
.715 .7 .835 r
.76531 .27997 .77133 .29082 .78426 .28312 .77833 .27283 Mtetra
.707 .709 .85 r
.77833 .27283 .78426 .28312 .79729 .27612 .79144 .26629 Mtetra
.698 .716 .863 r
.79144 .26629 .79729 .27612 .81042 .26971 .80464 .26023 Mtetra
.691 .723 .874 r
.80464 .26023 .81042 .26971 .82363 .26377 .81793 .25457 Mtetra
.684 .728 .883 r
.81793 .25457 .82363 .26377 .83693 .2582 .83129 .24919 Mtetra
.679 .731 .89 r
.83129 .24919 .83693 .2582 .85032 .2529 .84474 .24403 Mtetra
.652 .743 .916 r
.23107 .44231 .23842 .44899 .24928 .44555 .24195 .43891 Mtetra
.647 .744 .92 r
.24195 .43891 .24928 .44555 .26018 .44221 .25287 .43564 Mtetra
.639 .745 .925 r
.25287 .43564 .26018 .44221 .27112 .43902 .26382 .43256 Mtetra
.627 .746 .933 r
.26382 .43256 .27112 .43902 .28209 .43604 .27481 .42974 Mtetra
.61 .746 .942 r
.27481 .42974 .28209 .43604 .29309 .43335 .28581 .42727 Mtetra
.584 .747 .954 r
.28581 .42727 .29309 .43335 .30411 .43104 .29684 .42527 Mtetra
.543 .744 .969 r
.29684 .42527 .30411 .43104 .31516 .42925 .30789 .42389 Mtetra
.478 .734 .983 r
.30789 .42389 .31516 .42925 .32623 .42812 .31895 .4233 Mtetra
.368 .705 .985 r
.31895 .4233 .32623 .42812 .33731 .42783 .33002 .42373 Mtetra
.182 .628 .942 r
.33002 .42373 .33731 .42783 .34841 .4286 .34109 .42542 Mtetra
0 .457 .785 r
.34109 .42542 .34841 .4286 .35952 .43067 .35217 .42865 Mtetra
.397 0 0 r
.35217 .42865 .35952 .43067 .37065 .43429 .36326 .43372 Mtetra
.597 .029 0 r
.36326 .43372 .37065 .43429 .3818 .43973 .37436 .44087 Mtetra
.695 .182 .007 r
.37436 .44087 .3818 .43973 .39298 .44722 .38549 .45029 Mtetra
.738 .271 .141 r
.38549 .45029 .39298 .44722 .40421 .4569 .39668 .46205 Mtetra
.755 .322 .224 r
.39668 .46205 .40421 .4569 .41552 .46879 .40795 .47599 Mtetra
.759 .349 .274 r
.40795 .47599 .41552 .46879 .42693 .48268 .41935 .49169 Mtetra
.756 .359 .302 r
.41935 .49169 .42693 .48268 .43848 .49814 .43091 .50844 Mtetra
.747 .356 .313 r
.43091 .50844 .43848 .49814 .4502 .51445 .44268 .52521 Mtetra
.732 .339 .306 r
.44268 .52521 .4502 .51445 .46214 .5306 .45468 .54078 Mtetra
.708 .302 .277 r
.45468 .54078 .46214 .5306 .47429 .5454 .46693 .5538 Mtetra
.66 .224 .203 r
.46693 .5538 .47429 .5454 .48667 .55758 .47941 .56302 Mtetra
.537 .035 .009 r
.47941 .56302 .48667 .55758 .49926 .56596 .49209 .56744 Mtetra
.036 0 0 r
.49209 .56744 .49926 .56596 .51201 .56965 .50493 .56651 Mtetra
.708 .906 .965 r
.50493 .56651 .51201 .56965 .52489 .56815 .51786 .56018 Mtetra
.804 .778 .829 r
.51786 .56018 .52489 .56815 .53782 .56144 .53083 .54887 Mtetra
.803 .7 .751 r
.53083 .54887 .53782 .56144 .55075 .54995 .54378 .53339 Mtetra
.795 .657 .71 r
.54378 .53339 .55075 .54995 .56364 .53446 .55667 .5148 Mtetra
.787 .632 .689 r
.55667 .5148 .56364 .53446 .57646 .51597 .56948 .49418 Mtetra
.78 .617 .678 r
.56948 .49418 .57646 .51597 .58919 .49551 .5822 .47255 Mtetra
.775 .608 .673 r
.5822 .47255 .58919 .49551 .60182 .47407 .59484 .45075 Mtetra
.77 .604 .672 r
.59484 .45075 .60182 .47407 .61437 .45245 .60741 .42942 Mtetra
.767 .603 .675 r
.60741 .42942 .61437 .45245 .62686 .43127 .61994 .40902 Mtetra
.764 .605 .681 r
.61994 .40902 .62686 .43127 .6393 .41098 .63243 .3898 Mtetra
.761 .609 .689 r
.63243 .3898 .6393 .41098 .65172 .39188 .64491 .37195 Mtetra
.759 .614 .699 r
.64491 .37195 .65172 .39188 .66414 .37412 .6574 .35551 Mtetra
.756 .622 .711 r
.6574 .35551 .66414 .37412 .67657 .35779 .66992 .3405 Mtetra
.753 .631 .725 r
.66992 .3405 .67657 .35779 .68904 .34289 .68247 .32689 Mtetra
.749 .641 .741 r
.68247 .32689 .68904 .34289 .70156 .32941 .69508 .31461 Mtetra
.744 .651 .758 r
.69508 .31461 .70156 .32941 .71415 .31727 .70776 .30357 Mtetra
.738 .663 .776 r
.70776 .30357 .71415 .31727 .72681 .30638 .72051 .29365 Mtetra
.731 .674 .794 r
.72051 .29365 .72681 .30638 .73955 .29661 .73335 .28475 Mtetra
.724 .685 .813 r
.73335 .28475 .73955 .29661 .75239 .28786 .74627 .27673 Mtetra
.716 .696 .83 r
.74627 .27673 .75239 .28786 .76531 .27997 .75928 .26945 Mtetra
.707 .705 .846 r
.75928 .26945 .76531 .27997 .77833 .27283 .77238 .2628 Mtetra
.699 .713 .86 r
.77238 .2628 .77833 .27283 .79144 .26629 .78557 .25665 Mtetra
.692 .72 .871 r
.78557 .25665 .79144 .26629 .80464 .26023 .79884 .2509 Mtetra
.685 .726 .881 r
.79884 .2509 .80464 .26023 .81793 .25457 .81219 .24545 Mtetra
.679 .73 .888 r
.81219 .24545 .81793 .25457 .83129 .24919 .82562 .24023 Mtetra
.675 .733 .894 r
.82562 .24023 .83129 .24919 .84474 .24403 .83913 .23518 Mtetra
.649 .743 .918 r
.22366 .43561 .23107 .44231 .24195 .43891 .23456 .43227 Mtetra
.642 .744 .923 r
.23456 .43227 .24195 .43891 .25287 .43564 .2455 .42909 Mtetra
.632 .745 .929 r
.2455 .42909 .25287 .43564 .26382 .43256 .25646 .42614 Mtetra
.617 .745 .938 r
.25646 .42614 .26382 .43256 .27481 .42974 .26745 .4235 Mtetra
.595 .746 .949 r
.26745 .4235 .27481 .42974 .28581 .42727 .27847 .4213 Mtetra
.56 .744 .963 r
.27847 .4213 .28581 .42727 .29684 .42527 .2895 .41966 Mtetra
.505 .737 .978 r
.2895 .41966 .29684 .42527 .30789 .42389 .30054 .41877 Mtetra
.412 .716 .986 r
.30054 .41877 .30789 .42389 .31895 .4233 .31158 .41884 Mtetra
.252 .658 .964 r
.31158 .41884 .31895 .4233 .33002 .42373 .32262 .42013 Mtetra
0 .516 .848 r
.32262 .42013 .33002 .42373 .34109 .42542 .33365 .42294 Mtetra
.325 0 0 r
.33365 .42294 .34109 .42542 .35217 .42865 .34468 .42756 Mtetra
.563 0 0 r
.34468 .42756 .35217 .42865 .36326 .43372 .35571 .43429 Mtetra
.684 .159 0 r
.35571 .43429 .36326 .43372 .37436 .44087 .36675 .44337 Mtetra
.737 .262 .12 r
.36675 .44337 .37436 .44087 .38549 .45029 .37783 .45487 Mtetra
.757 .32 .212 r
.37783 .45487 .38549 .45029 .39668 .46205 .38896 .46871 Mtetra
.763 .35 .267 r
.38896 .46871 .39668 .46205 .40795 .47599 .40021 .48448 Mtetra
.761 .363 .298 r
.40021 .48448 .40795 .47599 .41935 .49169 .41161 .50148 Mtetra
.754 .362 .311 r
.41161 .50148 .41935 .49169 .43091 .50844 .42321 .5187 Mtetra
.741 .347 .305 r
.42321 .5187 .43091 .50844 .44268 .52521 .43505 .53486 Mtetra
.718 .311 .275 r
.43505 .53486 .44268 .52521 .45468 .54078 .44715 .54856 Mtetra
.674 .234 .198 r
.44715 .54856 .45468 .54078 .46693 .5538 .45951 .55846 Mtetra
.551 .038 0 r
.45951 .55846 .46693 .5538 .47941 .56302 .47211 .56351 Mtetra
0 0 0 r
.47211 .56351 .47941 .56302 .49209 .56744 .4849 .56308 Mtetra
.707 .867 .957 r
.4849 .56308 .49209 .56744 .50493 .56651 .49782 .55709 Mtetra
.787 .745 .814 r
.49782 .55709 .50493 .56651 .51786 .56018 .51081 .54596 Mtetra
.789 .676 .74 r
.51081 .54596 .51786 .56018 .53083 .54887 .52381 .53054 Mtetra
.783 .639 .702 r
.52381 .53054 .53083 .54887 .54378 .53339 .53676 .5119 Mtetra
.776 .617 .682 r
.53676 .5119 .54378 .53339 .55667 .5148 .54965 .4912 Mtetra
.771 .603 .672 r
.54965 .4912 .55667 .5148 .56948 .49418 .56246 .46949 Mtetra
.766 .596 .668 r
.56246 .46949 .56948 .49418 .5822 .47255 .57519 .44764 Mtetra
.762 .592 .667 r
.57519 .44764 .5822 .47255 .59484 .45075 .58785 .4263 Mtetra
.759 .592 .671 r
.58785 .4263 .59484 .45075 .60741 .42942 .60045 .40591 Mtetra
.756 .595 .677 r
.60045 .40591 .60741 .42942 .61994 .40902 .61301 .38674 Mtetra
.754 .599 .685 r
.61301 .38674 .61994 .40902 .63243 .3898 .62556 .36892 Mtetra
.752 .606 .695 r
.62556 .36892 .63243 .3898 .64491 .37195 .63811 .35252 Mtetra
.75 .614 .707 r
.63811 .35252 .64491 .37195 .6574 .35551 .65067 .33752 Mtetra
.748 .623 .721 r
.65067 .33752 .6574 .35551 .66992 .3405 .66327 .3239 Mtetra
.745 .633 .736 r
.66327 .3239 .66992 .3405 .68247 .32689 .67591 .31157 Mtetra
.741 .645 .753 r
.67591 .31157 .68247 .32689 .69508 .31461 .68861 .30046 Mtetra
.736 .656 .771 r
.68861 .30046 .69508 .31461 .70776 .30357 .70138 .29047 Mtetra
.73 .668 .79 r
.70138 .29047 .70776 .30357 .72051 .29365 .71422 .28147 Mtetra
.723 .68 .808 r
.71422 .28147 .72051 .29365 .73335 .28475 .72715 .27335 Mtetra
.715 .691 .826 r
.72715 .27335 .73335 .28475 .74627 .27673 .74015 .26599 Mtetra
.707 .701 .842 r
.74015 .26599 .74627 .27673 .75928 .26945 .75324 .25925 Mtetra
.7 .71 .856 r
.75324 .25925 .75928 .26945 .77238 .2628 .76641 .25302 Mtetra
.692 .718 .869 r
.76641 .25302 .77238 .2628 .78557 .25665 .77967 .24719 Mtetra
.686 .724 .879 r
.77967 .24719 .78557 .25665 .79884 .2509 .79301 .24169 Mtetra
.68 .729 .887 r
.79301 .24169 .79884 .2509 .81219 .24545 .80642 .23642 Mtetra
.676 .732 .893 r
.80642 .23642 .81219 .24545 .82562 .24023 .81991 .23132 Mtetra
.672 .735 .897 r
.81991 .23132 .82562 .24023 .83913 .23518 .83347 .22634 Mtetra
.645 .743 .921 r
.21618 .4289 .22366 .43561 .23456 .43227 .2271 .42562 Mtetra
.637 .744 .926 r
.2271 .42562 .23456 .43227 .2455 .42909 .23805 .42255 Mtetra
.624 .745 .934 r
.23805 .42255 .2455 .42909 .25646 .42614 .24903 .41976 Mtetra
.605 .745 .944 r
.24903 .41976 .25646 .42614 .26745 .4235 .26003 .41735 Mtetra
.576 .744 .956 r
.26003 .41735 .26745 .4235 .27847 .4213 .27104 .41546 Mtetra
.529 .739 .971 r
.27104 .41546 .27847 .4213 .2895 .41966 .28207 .41426 Mtetra
.451 .725 .984 r
.28207 .41426 .2895 .41966 .30054 .41877 .29309 .41397 Mtetra
.315 .682 .977 r
.29309 .41397 .30054 .41877 .31158 .41884 .3041 .41485 Mtetra
.081 .569 .899 r
.3041 .41485 .31158 .41884 .32262 .42013 .3151 .4172 Mtetra
0 .342 .672 r
.3151 .4172 .32262 .42013 .33365 .42294 .32608 .42134 Mtetra
.518 0 0 r
.32608 .42134 .33365 .42294 .34468 .42756 .33704 .42759 Mtetra
.668 .13 0 r
.33704 .42759 .34468 .42756 .35571 .43429 .348 .43622 Mtetra
.733 .249 .094 r
.348 .43622 .35571 .43429 .36675 .44337 .35897 .44737 Mtetra
.758 .315 .198 r
.35897 .44737 .36675 .44337 .37783 .45487 .36998 .46095 Mtetra
.767 .349 .259 r
.36998 .46095 .37783 .45487 .38896 .46871 .38107 .47663 Mtetra
.766 .365 .293 r
.38107 .47663 .38896 .46871 .40021 .48448 .39231 .49371 Mtetra
.76 .366 .307 r
.39231 .49371 .40021 .48448 .41161 .50148 .40373 .51118 Mtetra
.748 .352 .302 r
.40373 .51118 .41161 .50148 .42321 .5187 .4154 .52774 Mtetra
.727 .317 .271 r
.4154 .52774 .42321 .5187 .43505 .53486 .42735 .54194 Mtetra
.685 .241 .189 r
.42735 .54194 .43505 .53486 .44715 .54856 .43958 .55238 Mtetra
.561 .037 0 r
.43958 .55238 .44715 .54856 .45951 .55846 .45208 .55794 Mtetra
.048 .614 .764 r
.45208 .55794 .45951 .55846 .47211 .56351 .46482 .55794 Mtetra
.702 .827 .942 r
.46482 .55794 .47211 .56351 .4849 .56308 .47772 .55224 Mtetra
.772 .716 .8 r
.47772 .55224 .4849 .56308 .49782 .55709 .49072 .54129 Mtetra
.776 .656 .73 r
.49072 .54129 .49782 .55709 .51081 .54596 .50376 .52594 Mtetra
.772 .623 .695 r
.50376 .52594 .51081 .54596 .52381 .53054 .51678 .50732 Mtetra
.766 .603 .676 r
.51678 .50732 .52381 .53054 .53676 .5119 .52974 .48662 Mtetra
.762 .592 .667 r
.52974 .48662 .53676 .5119 .54965 .4912 .54263 .46492 Mtetra
.757 .585 .663 r
.54263 .46492 .54965 .4912 .56246 .46949 .55544 .44313 Mtetra
.754 .582 .664 r
.55544 .44313 .56246 .46949 .57519 .44764 .56818 .4219 Mtetra
.751 .583 .667 r
.56818 .4219 .57519 .44764 .58785 .4263 .58086 .40166 Mtetra
.749 .586 .673 r
.58086 .40166 .58785 .4263 .60045 .40591 .5935 .38267 Mtetra
.748 .591 .682 r
.5935 .38267 .60045 .40591 .61301 .38674 .60611 .36503 Mtetra
.746 .598 .692 r
.60611 .36503 .61301 .38674 .62556 .36892 .61872 .34879 Mtetra
.745 .606 .704 r
.61872 .34879 .62556 .36892 .63811 .35252 .63133 .33393 Mtetra
.743 .616 .718 r
.63133 .33393 .63811 .35252 .65067 .33752 .64397 .3204 Mtetra
.74 .627 .733 r
.64397 .3204 .65067 .33752 .66327 .3239 .65664 .30813 Mtetra
.737 .639 .75 r
.65664 .30813 .66327 .3239 .67591 .31157 .66937 .29704 Mtetra
.733 .651 .768 r
.66937 .29704 .67591 .31157 .68861 .30046 .68215 .28704 Mtetra
.728 .663 .786 r
.68215 .28704 .68861 .30046 .70138 .29047 .695 .27801 Mtetra
.722 .676 .805 r
.695 .27801 .70138 .29047 .71422 .28147 .70793 .26984 Mtetra
.715 .687 .823 r
.70793 .26984 .71422 .28147 .72715 .27335 .72093 .26241 Mtetra
.707 .698 .839 r
.72093 .26241 .72715 .27335 .74015 .26599 .73402 .25561 Mtetra
.7 .708 .854 r
.73402 .25561 .74015 .26599 .75324 .25925 .74718 .24932 Mtetra
.693 .716 .866 r
.74718 .24932 .75324 .25925 .76641 .25302 .76042 .24345 Mtetra
.686 .722 .877 r
.76042 .24345 .76641 .25302 .77967 .24719 .77374 .23789 Mtetra
.681 .727 .885 r
.77374 .23789 .77967 .24719 .79301 .24169 .78714 .23257 Mtetra
.676 .731 .892 r
.78714 .23257 .79301 .24169 .80642 .23642 .80061 .22743 Mtetra
.672 .734 .897 r
.80061 .22743 .80642 .23642 .81991 .23132 .81416 .22241 Mtetra
.67 .736 .9 r
.81416 .22241 .81991 .23132 .83347 .22634 .82778 .21748 Mtetra
.641 .743 .923 r
.20865 .42217 .21618 .4289 .2271 .42562 .21958 .41898 Mtetra
.63 .744 .93 r
.21958 .41898 .2271 .42562 .23805 .42255 .23055 .41604 Mtetra
.614 .744 .939 r
.23055 .41604 .23805 .42255 .24903 .41976 .24153 .41344 Mtetra
.589 .744 .95 r
.24153 .41344 .24903 .41976 .26003 .41735 .25253 .4113 Mtetra
.55 .741 .965 r
.25253 .4113 .26003 .41735 .27104 .41546 .26354 .40981 Mtetra
.484 .73 .98 r
.26354 .40981 .27104 .41546 .28207 .41426 .27454 .40916 Mtetra
.37 .7 .984 r
.27454 .40916 .28207 .41426 .29309 .41397 .28553 .40962 Mtetra
.166 .613 .936 r
.28553 .40962 .29309 .41397 .3041 .41485 .2965 .41149 Mtetra
0 .416 .754 r
.2965 .41149 .3041 .41485 .3151 .4172 .30744 .41512 Mtetra
.46 0 0 r
.30744 .41512 .3151 .4172 .32608 .42134 .31834 .42084 Mtetra
.645 .093 0 r
.31834 .42084 .32608 .42134 .33704 .42759 .32922 .42896 Mtetra
.725 .231 .063 r
.32922 .42896 .33704 .42759 .348 .43622 .34009 .43963 Mtetra
.757 .306 .18 r
.34009 .43963 .348 .43622 .35897 .44737 .35098 .45284 Mtetra
.768 .346 .248 r
.35098 .45284 .35897 .44737 .36998 .46095 .36194 .46827 Mtetra
.769 .365 .286 r
.36194 .46827 .36998 .46095 .38107 .47663 .37301 .48525 Mtetra
.764 .367 .301 r
.37301 .48525 .38107 .47663 .39231 .49371 .38427 .50278 Mtetra
.754 .355 .297 r
.38427 .50278 .39231 .49371 .40373 .51118 .39577 .51955 Mtetra
.735 .321 .264 r
.39577 .51955 .40373 .51118 .4154 .52774 .40756 .53407 Mtetra
.695 .244 .178 r
.40756 .53407 .4154 .52774 .42735 .54194 .41965 .5449 Mtetra
.566 .029 0 r
.41965 .5449 .42735 .54194 .43958 .55238 .43205 .55084 Mtetra
.104 .647 .843 r
.43205 .55084 .43958 .55238 .45208 .55794 .44471 .55117 Mtetra
.694 .789 .923 r
.44471 .55117 .45208 .55794 .46482 .55794 .45758 .54573 Mtetra
.758 .691 .787 r
.45758 .54573 .46482 .55794 .47772 .55224 .47059 .53495 Mtetra
.764 .639 .722 r
.47059 .53495 .47772 .55224 .49072 .54129 .48366 .5197 Mtetra
.762 .609 .689 r
.48366 .5197 .49072 .54129 .50376 .52594 .49674 .50114 Mtetra
.758 .592 .672 r
.49674 .50114 .50376 .52594 .51678 .50732 .50977 .48051 Mtetra
.753 .581 .663 r
.50977 .48051 .51678 .50732 .52974 .48662 .52273 .45892 Mtetra
.75 .576 .66 r
.52273 .45892 .52974 .48662 .54263 .46492 .53562 .4373 Mtetra
.747 .574 .661 r
.53562 .4373 .54263 .46492 .55544 .44313 .54843 .41629 Mtetra
.744 .575 .665 r
.54843 .41629 .55544 .44313 .56818 .4219 .56119 .39632 Mtetra
.742 .578 .671 r
.56119 .39632 .56818 .4219 .58086 .40166 .57389 .37763 Mtetra
.741 .584 .68 r
.57389 .37763 .58086 .40166 .5935 .38267 .58657 .36029 Mtetra
.74 .591 .69 r
.58657 .36029 .5935 .38267 .60611 .36503 .59923 .34434 Mtetra
.739 .6 .702 r
.59923 .34434 .60611 .36503 .61872 .34879 .61189 .32973 Mtetra
.738 .61 .716 r
.61189 .32973 .61872 .34879 .63133 .33393 .62457 .3164 Mtetra
.736 .622 .731 r
.62457 .3164 .63133 .33393 .64397 .3204 .63728 .30428 Mtetra
.733 .634 .748 r
.63728 .30428 .64397 .3204 .65664 .30813 .65003 .29329 Mtetra
.73 .646 .766 r
.65003 .29329 .65664 .30813 .66937 .29704 .66283 .28335 Mtetra
.725 .659 .784 r
.66283 .28335 .66937 .29704 .68215 .28704 .6757 .27434 Mtetra
.72 .672 .802 r
.6757 .27434 .68215 .28704 .695 .27801 .68863 .26617 Mtetra
.713 .684 .82 r
.68863 .26617 .695 .27801 .70793 .26984 .70163 .25872 Mtetra
.707 .695 .837 r
.70163 .25872 .70793 .26984 .72093 .26241 .71471 .25189 Mtetra
.7 .705 .852 r
.71471 .25189 .72093 .26241 .73402 .25561 .72786 .24556 Mtetra
.693 .713 .865 r
.72786 .24556 .73402 .25561 .74718 .24932 .74109 .23965 Mtetra
.686 .72 .875 r
.74109 .23965 .74718 .24932 .76042 .24345 .7544 .23405 Mtetra
.681 .726 .884 r
.7544 .23405 .76042 .24345 .77374 .23789 .76778 .22869 Mtetra
.676 .73 .891 r
.76778 .22869 .77374 .23789 .78714 .23257 .78124 .22352 Mtetra
.673 .734 .896 r
.78124 .22352 .78714 .23257 .80061 .22743 .79477 .21847 Mtetra
.67 .736 .9 r
.79477 .21847 .80061 .22743 .81416 .22241 .80837 .21351 Mtetra
.668 .738 .902 r
.80837 .21351 .81416 .22241 .82778 .21748 .82204 .20861 Mtetra
.635 .743 .926 r
.20104 .41544 .20865 .42217 .21958 .41898 .21199 .41235 Mtetra
.622 .744 .934 r
.21199 .41235 .21958 .41898 .23055 .41604 .22297 .40957 Mtetra
.601 .743 .944 r
.22297 .40957 .23055 .41604 .24153 .41344 .23395 .4072 Mtetra
.568 .741 .958 r
.23395 .4072 .24153 .41344 .25253 .4113 .24495 .40542 Mtetra
.513 .735 .974 r
.24495 .40542 .25253 .4113 .26354 .40981 .25594 .40442 Mtetra
.417 .713 .985 r
.25594 .40442 .26354 .40981 .27454 .40916 .26691 .40446 Mtetra
.243 .649 .961 r
.26691 .40446 .27454 .40916 .28553 .40962 .27785 .40586 Mtetra
0 .485 .826 r
.27785 .40586 .28553 .40962 .2965 .41149 .28876 .40895 Mtetra
.387 0 0 r
.28876 .40895 .2965 .41149 .30744 .41512 .29962 .41411 Mtetra
.613 .048 0 r
.29962 .41411 .30744 .41512 .31834 .42084 .31043 .42165 Mtetra
.714 .207 .025 r
.31043 .42165 .31834 .42084 .32922 .42896 .32121 .43177 Mtetra
.754 .295 .158 r
.32121 .43177 .32922 .42896 .34009 .43963 .33199 .44448 Mtetra
.769 .341 .234 r
.33199 .44448 .34009 .43963 .35098 .45284 .34281 .45951 Mtetra
.771 .362 .276 r
.34281 .45951 .35098 .45284 .36194 .46827 .35374 .47623 Mtetra
.767 .367 .294 r
.35374 .47623 .36194 .46827 .37301 .48525 .36483 .49363 Mtetra
.758 .356 .29 r
.36483 .49363 .37301 .48525 .38427 .50278 .37616 .51042 Mtetra
.741 .323 .256 r
.37616 .51042 .38427 .50278 .39577 .51955 .38779 .52508 Mtetra
.702 .245 .162 r
.38779 .52508 .39577 .51955 .40756 .53407 .39974 .53613 Mtetra
.565 .015 0 r
.39974 .53613 .40756 .53407 .41965 .5449 .41203 .54233 Mtetra
.164 .67 .905 r
.41203 .54233 .41965 .5449 .43205 .55084 .42462 .54291 Mtetra
.686 .755 .904 r
.42462 .54291 .43205 .55084 .44471 .55117 .43745 .53768 Mtetra
.746 .669 .776 r
.43745 .53768 .44471 .55117 .45758 .54573 .45045 .52706 Mtetra
.754 .624 .715 r
.45045 .52706 .45758 .54573 .47059 .53495 .46355 .51194 Mtetra
.753 .598 .684 r
.46355 .51194 .47059 .53495 .48366 .5197 .47667 .4935 Mtetra
.75 .582 .668 r
.47667 .4935 .48366 .5197 .49674 .50114 .48977 .47301 Mtetra
.746 .573 .66 r
.48977 .47301 .49674 .50114 .50977 .48051 .5028 .45161 Mtetra
.743 .568 .657 r
.5028 .45161 .50977 .48051 .52273 .45892 .51575 .43024 Mtetra
.74 .566 .658 r
.51575 .43024 .52273 .45892 .53562 .4373 .52864 .40956 Mtetra
.738 .568 .663 r
.52864 .40956 .53562 .4373 .54843 .41629 .54145 .38997 Mtetra
.736 .572 .669 r
.54145 .38997 .54843 .41629 .56119 .39632 .55422 .37168 Mtetra
.735 .578 .678 r
.55422 .37168 .56119 .39632 .57389 .37763 .56695 .35476 Mtetra
.734 .585 .689 r
.56695 .35476 .57389 .37763 .58657 .36029 .57966 .33919 Mtetra
.734 .595 .701 r
.57966 .33919 .58657 .36029 .59923 .34434 .59237 .32493 Mtetra
.733 .606 .715 r
.59237 .32493 .59923 .34434 .61189 .32973 .60509 .3119 Mtetra
.732 .617 .731 r
.60509 .3119 .61189 .32973 .62457 .3164 .61783 .30002 Mtetra
.729 .63 .747 r
.61783 .30002 .62457 .3164 .63728 .30428 .63061 .28921 Mtetra
.727 .643 .765 r
.63061 .28921 .63728 .30428 .65003 .29329 .64343 .27939 Mtetra
.723 .656 .783 r
.64343 .27939 .65003 .29329 .66283 .28335 .65631 .27047 Mtetra
.718 .669 .801 r
.65631 .27047 .66283 .28335 .6757 .27434 .66924 .26234 Mtetra
.712 .681 .819 r
.66924 .26234 .6757 .27434 .68863 .26617 .68225 .25491 Mtetra
.706 .693 .835 r
.68225 .25491 .68863 .26617 .70163 .25872 .69532 .24808 Mtetra
.699 .703 .85 r
.69532 .24808 .70163 .25872 .71471 .25189 .70847 .24173 Mtetra
.692 .712 .863 r
.70847 .24173 .71471 .25189 .72786 .24556 .72169 .23579 Mtetra
.686 .719 .874 r
.72169 .23579 .72786 .24556 .74109 .23965 .73498 .23017 Mtetra
.681 .725 .883 r
.73498 .23017 .74109 .23965 .7544 .23405 .74835 .22478 Mtetra
.676 .729 .89 r
.74835 .22478 .7544 .23405 .76778 .22869 .76179 .21958 Mtetra
.673 .733 .895 r
.76179 .21958 .76778 .22869 .78124 .22352 .7753 .21451 Mtetra
.67 .735 .899 r
.7753 .21451 .78124 .22352 .79477 .21847 .78888 .20952 Mtetra
.668 .737 .902 r
.78888 .20952 .79477 .21847 .80837 .21351 .80253 .20459 Mtetra
.667 .739 .904 r
.80253 .20459 .80837 .21351 .82204 .20861 .81625 .1997 Mtetra
.629 .743 .93 r
.19338 .4087 .20104 .41544 .21199 .41235 .20434 .40575 Mtetra
.611 .743 .939 r
.20434 .40575 .21199 .41235 .22297 .40957 .21531 .40317 Mtetra
.583 .742 .952 r
.21531 .40317 .22297 .40957 .23395 .4072 .2263 .40111 Mtetra
.537 .737 .968 r
.2263 .40111 .23395 .4072 .24495 .40542 .23727 .39978 Mtetra
.457 .722 .982 r
.23727 .39978 .24495 .40542 .25594 .40442 .24823 .39941 Mtetra
.311 .676 .976 r
.24823 .39941 .25594 .40442 .26691 .40446 .25916 .40033 Mtetra
.049 .546 .884 r
.25916 .40033 .26691 .40446 .27785 .40586 .27003 .40289 Mtetra
.301 0 0 r
.27003 .40289 .27785 .40586 .28876 .40895 .28085 .40745 Mtetra
.57 0 0 r
.28085 .40745 .28876 .40895 .29962 .41411 .29161 .41436 Mtetra
.698 .177 0 r
.29161 .41436 .29962 .41411 .31043 .42165 .30231 .42386 Mtetra
.749 .279 .131 r
.30231 .42386 .31043 .42165 .32121 .43177 .31299 .43597 Mtetra
.767 .332 .217 r
.31299 .43597 .32121 .43177 .33199 .44448 .32369 .45047 Mtetra
.772 .358 .264 r
.32369 .45047 .33199 .44448 .34281 .45951 .33448 .46675 Mtetra
.77 .364 .284 r
.33448 .46675 .34281 .45951 .35374 .47623 .34541 .48386 Mtetra
.762 .355 .28 r
.34541 .48386 .35374 .47623 .36483 .49363 .35658 .50047 Mtetra
.745 .322 .244 r
.35658 .50047 .36483 .49363 .37616 .51042 .36805 .51509 Mtetra
.707 .241 .142 r
.36805 .51509 .37616 .51042 .38779 .52508 .37986 .5262 Mtetra
.557 0 0 r
.37986 .5262 .38779 .52508 .39974 .53613 .39204 .53254 Mtetra
.224 .683 .948 r
.39204 .53254 .39974 .53613 .41203 .54233 .40454 .53329 Mtetra
.678 .725 .885 r
.40454 .53329 .41203 .54233 .42462 .54291 .41733 .52823 Mtetra
.736 .651 .766 r
.41733 .52823 .42462 .54291 .43745 .53768 .43033 .51777 Mtetra
.745 .611 .709 r
.43033 .51777 .43745 .53768 .45045 .52706 .44344 .50281 Mtetra
.746 .588 .68 r
.44344 .50281 .45045 .52706 .46355 .51194 .45661 .48454 Mtetra
.743 .574 .664 r
.45661 .48454 .46355 .51194 .47667 .4935 .46975 .46426 Mtetra
.74 .565 .657 r
.46975 .46426 .47667 .4935 .48977 .47301 .48284 .44314 Mtetra
.737 .561 .655 r
.48284 .44314 .48977 .47301 .5028 .45161 .49586 .42211 Mtetra
.734 .56 .657 r
.49586 .42211 .5028 .45161 .51575 .43024 .5088 .40183 Mtetra
.732 .562 .662 r
.5088 .40183 .51575 .43024 .52864 .40956 .52168 .3827 Mtetra
.73 .566 .669 r
.52168 .3827 .52864 .40956 .54145 .38997 .5345 .36491 Mtetra
.729 .573 .678 r
.5345 .36491 .54145 .38997 .55422 .37168 .54728 .34849 Mtetra
.729 .581 .689 r
.54728 .34849 .55422 .37168 .56695 .35476 .56003 .33341 Mtetra
.728 .591 .702 r
.56003 .33341 .56695 .35476 .57966 .33919 .57278 .31959 Mtetra
.728 .602 .716 r
.57278 .31959 .57966 .33919 .59237 .32493 .58553 .30694 Mtetra
.727 .614 .731 r
.58553 .30694 .59237 .32493 .60509 .3119 .5983 .29537 Mtetra
.725 .627 .748 r
.5983 .29537 .60509 .3119 .61783 .30002 .6111 .28482 Mtetra
.723 .64 .765 r
.6111 .28482 .61783 .30002 .63061 .28921 .62394 .27518 Mtetra
.72 .653 .783 r
.62394 .27518 .63061 .28921 .64343 .27939 .63683 .26639 Mtetra
.715 .666 .801 r
.63683 .26639 .64343 .27939 .65631 .27047 .64977 .25835 Mtetra
.71 .679 .818 r
.64977 .25835 .65631 .27047 .66924 .26234 .66278 .25098 Mtetra
.704 .691 .835 r
.66278 .25098 .66924 .26234 .68225 .25491 .67585 .24417 Mtetra
.698 .701 .849 r
.67585 .24417 .68225 .25491 .69532 .24808 .68899 .23783 Mtetra
.692 .71 .862 r
.68899 .23783 .69532 .24808 .70847 .24173 .7022 .23188 Mtetra
.686 .718 .873 r
.7022 .23188 .70847 .24173 .72169 .23579 .71548 .22624 Mtetra
.681 .724 .882 r
.71548 .22624 .72169 .23579 .73498 .23017 .72883 .22084 Mtetra
.676 .729 .889 r
.72883 .22084 .73498 .23017 .74835 .22478 .74226 .21561 Mtetra
.673 .732 .895 r
.74226 .21561 .74835 .22478 .76179 .21958 .75575 .21052 Mtetra
.67 .735 .899 r
.75575 .21052 .76179 .21958 .7753 .21451 .76931 .20551 Mtetra
.668 .737 .902 r
.76931 .20551 .7753 .21451 .78888 .20952 .78295 .20056 Mtetra
.667 .738 .904 r
.78295 .20056 .78888 .20952 .80253 .20459 .79665 .19564 Mtetra
.666 .739 .905 r
.79665 .19564 .80253 .20459 .81625 .1997 .81042 .19074 Mtetra
.62 .743 .934 r
.18564 .40198 .19338 .4087 .20434 .40575 .1966 .3992 Mtetra
.596 .742 .946 r
.1966 .3992 .20434 .40575 .21531 .40317 .20758 .39689 Mtetra
.558 .739 .961 r
.20758 .39689 .21531 .40317 .2263 .40111 .21854 .39524 Mtetra
.491 .729 .978 r
.21854 .39524 .2263 .40111 .23727 .39978 .22949 .39449 Mtetra
.368 .696 .983 r
.22949 .39449 .23727 .39978 .24823 .39941 .2404 .39494 Mtetra
.141 .598 .927 r
.2404 .39494 .24823 .39941 .25916 .40033 .25126 .39696 Mtetra
0 .37 .71 r
.25126 .39696 .25916 .40033 .27003 .40289 .26204 .40091 Mtetra
.514 0 0 r
.26204 .40091 .27003 .40289 .28085 .40745 .27275 .40716 Mtetra
.675 .139 0 r
.27275 .40716 .28085 .40745 .29161 .41436 .28339 .41596 Mtetra
.74 .258 .097 r
.28339 .41596 .29161 .41436 .30231 .42386 .29399 .42739 Mtetra
.764 .32 .195 r
.29399 .42739 .30231 .42386 .31299 .43597 .30458 .44123 Mtetra
.772 .35 .248 r
.30458 .44123 .31299 .43597 .32369 .45047 .31524 .45693 Mtetra
.771 .36 .271 r
.31524 .45693 .32369 .45047 .33448 .46675 .32603 .47356 Mtetra
.764 .351 .267 r
.32603 .47356 .33448 .46675 .34541 .48386 .33704 .48983 Mtetra
.749 .318 .229 r
.33704 .48983 .34541 .48386 .35658 .50047 .34836 .50424 Mtetra
.709 .233 .117 r
.34836 .50424 .35658 .50047 .36805 .51509 .36004 .51527 Mtetra
.539 0 0 r
.36004 .51527 .36805 .51509 .37986 .5262 .37209 .52162 Mtetra
.28 .686 .971 r
.37209 .52162 .37986 .5262 .39204 .53254 .38452 .52246 Mtetra
.671 .699 .868 r
.38452 .52246 .39204 .53254 .40454 .53329 .39726 .51754 Mtetra
.726 .636 .757 r
.39726 .51754 .40454 .53329 .41733 .52823 .41023 .50725 Mtetra
.738 .6 .704 r
.41023 .50725 .41733 .52823 .43033 .51777 .42336 .49248 Mtetra
.739 .579 .677 r
.42336 .49248 .43033 .51777 .44344 .50281 .43656 .47445 Mtetra
.737 .567 .662 r
.43656 .47445 .44344 .50281 .45661 .48454 .44975 .45445 Mtetra
.734 .559 .655 r
.44975 .45445 .45661 .48454 .46975 .46426 .46289 .43367 Mtetra
.731 .556 .654 r
.46289 .43367 .46975 .46426 .48284 .44314 .47596 .41306 Mtetra
.729 .555 .656 r
.47596 .41306 .48284 .44314 .49586 .42211 .48895 .39326 Mtetra
.727 .557 .661 r
.48895 .39326 .49586 .42211 .5088 .40183 .50187 .37467 Mtetra
.725 .562 .669 r
.50187 .37467 .5088 .40183 .52168 .3827 .51474 .35745 Mtetra
.724 .569 .679 r
.51474 .35745 .52168 .3827 .5345 .36491 .52755 .3416 Mtetra
.724 .577 .69 r
.52755 .3416 .5345 .36491 .54728 .34849 .54035 .32707 Mtetra
.723 .588 .703 r
.54035 .32707 .54728 .34849 .56003 .33341 .55313 .31376 Mtetra
.723 .599 .717 r
.55313 .31376 .56003 .33341 .57278 .31959 .56591 .30155 Mtetra
.723 .612 .733 r
.56591 .30155 .57278 .31959 .58553 .30694 .5787 .29037 Mtetra
.721 .625 .749 r
.5787 .29037 .58553 .30694 .5983 .29537 .59152 .28012 Mtetra
.719 .638 .766 r
.59152 .28012 .5983 .29537 .6111 .28482 .60438 .27073 Mtetra
.716 .652 .784 r
.60438 .27073 .6111 .28482 .62394 .27518 .61728 .26212 Mtetra
.713 .665 .801 r
.61728 .26212 .62394 .27518 .63683 .26639 .63022 .25421 Mtetra
.708 .678 .818 r
.63022 .25421 .63683 .26639 .64977 .25835 .64323 .24692 Mtetra
.702 .69 .835 r
.64323 .24692 .64977 .25835 .66278 .25098 .6563 .24016 Mtetra
.697 .7 .849 r
.6563 .24016 .66278 .25098 .67585 .24417 .66943 .23385 Mtetra
.691 .709 .862 r
.66943 .23385 .67585 .24417 .68899 .23783 .68263 .22792 Mtetra
.685 .717 .873 r
.68263 .22792 .68899 .23783 .7022 .23188 .6959 .22227 Mtetra
.681 .723 .882 r
.6959 .22227 .7022 .23188 .71548 .22624 .70924 .21686 Mtetra
.676 .728 .889 r
.70924 .21686 .71548 .22624 .72883 .22084 .72264 .21162 Mtetra
.673 .732 .894 r
.72264 .21162 .72883 .22084 .74226 .21561 .73612 .2065 Mtetra
.67 .735 .898 r
.73612 .2065 .74226 .21561 .75575 .21052 .74967 .20147 Mtetra
.668 .737 .901 r
.74967 .20147 .75575 .21052 .76931 .20551 .76328 .1965 Mtetra
.667 .738 .904 r
.76328 .1965 .76931 .20551 .78295 .20056 .77697 .19156 Mtetra
.666 .739 .905 r
.77697 .19156 .78295 .20056 .79665 .19564 .79072 .18664 Mtetra
.665 .74 .906 r
.79072 .18664 .79665 .19564 .81042 .19074 .80454 .18172 Mtetra
.607 .742 .941 r
.17783 .3953 .18564 .40198 .1966 .3992 .18879 .39275 Mtetra
.575 .741 .955 r
.18879 .39275 .1966 .3992 .20758 .39689 .19975 .39081 Mtetra
.519 .734 .972 r
.19975 .39081 .20758 .39689 .21854 .39524 .21069 .38969 Mtetra
.417 .711 .984 r
.21069 .38969 .21854 .39524 .22949 .39449 .22159 .3897 Mtetra
.224 .639 .956 r
.22159 .3897 .22949 .39449 .2404 .39494 .23243 .39118 Mtetra
0 .449 .792 r
.23243 .39118 .2404 .39494 .25126 .39696 .24319 .39452 Mtetra
.443 0 0 r
.24319 .39452 .25126 .39696 .26204 .40091 .25386 .40009 Mtetra
.643 .09 0 r
.25386 .40009 .26204 .40091 .27275 .40716 .26445 .40814 Mtetra
.727 .23 .056 r
.26445 .40814 .27275 .40716 .28339 .41596 .27497 .4188 Mtetra
.759 .304 .168 r
.27497 .4188 .28339 .41596 .29399 .42739 .28547 .43188 Mtetra
.77 .34 .229 r
.28547 .43188 .29399 .42739 .30458 .44123 .29601 .44687 Mtetra
.771 .352 .254 r
.29601 .44687 .30458 .44123 .31524 .45693 .30668 .46286 Mtetra
.765 .345 .251 r
.30668 .46286 .31524 .45693 .32603 .47356 .31755 .47862 Mtetra
.75 .311 .209 r
.31755 .47862 .32603 .47356 .33704 .48983 .32873 .49266 Mtetra
.708 .22 .084 r
.32873 .49266 .33704 .48983 .34836 .50424 .34027 .50345 Mtetra
.509 0 0 r
.34027 .50345 .34836 .50424 .36004 .51527 .35221 .50971 Mtetra
.328 .682 .979 r
.35221 .50971 .36004 .51527 .37209 .52162 .36455 .51057 Mtetra
.664 .678 .853 r
.36455 .51057 .37209 .52162 .38452 .52246 .37724 .50577 Mtetra
.718 .623 .75 r
.37724 .50577 .38452 .52246 .39726 .51754 .39019 .49566 Mtetra
.731 .591 .7 r
.39019 .49566 .39726 .51754 .41023 .50725 .40332 .48114 Mtetra
.733 .573 .674 r
.40332 .48114 .41023 .50725 .42336 .49248 .41654 .4634 Mtetra
.732 .561 .661 r
.41654 .4634 .42336 .49248 .43656 .47445 .42976 .44376 Mtetra
.73 .554 .654 r
.42976 .44376 .43656 .47445 .44975 .45445 .44295 .42339 Mtetra
.727 .551 .653 r
.44295 .42339 .44975 .45445 .46289 .43367 .45606 .40326 Mtetra
.724 .551 .656 r
.45606 .40326 .46289 .43367 .47596 .41306 .4691 .38402 Mtetra
.722 .554 .662 r
.4691 .38402 .47596 .41306 .48895 .39326 .48205 .36602 Mtetra
.72 .559 .67 r
.48205 .36602 .48895 .39326 .50187 .37467 .49495 .34942 Mtetra
.719 .566 .68 r
.49495 .34942 .50187 .37467 .51474 .35745 .5078 .3342 Mtetra
.719 .575 .692 r
.5078 .3342 .51474 .35745 .52755 .3416 .52062 .32027 Mtetra
.719 .586 .706 r
.52062 .32027 .52755 .3416 .54035 .32707 .53342 .30751 Mtetra
.719 .598 .72 r
.53342 .30751 .54035 .32707 .55313 .31376 .54623 .29581 Mtetra
.718 .61 .736 r
.54623 .29581 .55313 .31376 .56591 .30155 .55904 .28506 Mtetra
.717 .624 .752 r
.55904 .28506 .56591 .30155 .5787 .29037 .57187 .27516 Mtetra
.716 .637 .769 r
.57187 .27516 .5787 .29037 .59152 .28012 .58474 .26606 Mtetra
.713 .651 .786 r
.58474 .26606 .59152 .28012 .60438 .27073 .59765 .25767 Mtetra
.71 .664 .803 r
.59765 .25767 .60438 .27073 .61728 .26212 .6106 .24992 Mtetra
.705 .677 .82 r
.6106 .24992 .61728 .26212 .63022 .25421 .6236 .24275 Mtetra
.701 .689 .836 r
.6236 .24275 .63022 .25421 .64323 .24692 .63667 .23607 Mtetra
.695 .699 .85 r
.63667 .23607 .64323 .24692 .6563 .24016 .64979 .22981 Mtetra
.69 .709 .862 r
.64979 .22981 .6563 .24016 .66943 .23385 .66298 .22389 Mtetra
.685 .716 .873 r
.66298 .22389 .66943 .23385 .68263 .22792 .67624 .21826 Mtetra
.68 .723 .882 r
.67624 .21826 .68263 .22792 .6959 .22227 .68956 .21284 Mtetra
.676 .728 .889 r
.68956 .21284 .6959 .22227 .70924 .21686 .70295 .20759 Mtetra
.673 .732 .894 r
.70295 .20759 .70924 .21686 .72264 .21162 .71641 .20246 Mtetra
.67 .734 .898 r
.71641 .20246 .72264 .21162 .73612 .2065 .72994 .19742 Mtetra
.668 .737 .901 r
.72994 .19742 .73612 .2065 .74967 .20147 .74354 .19242 Mtetra
.667 .738 .903 r
.74354 .19242 .74967 .20147 .76328 .1965 .7572 .18747 Mtetra
.666 .739 .905 r
.7572 .18747 .76328 .1965 .77697 .19156 .77094 .18252 Mtetra
.665 .74 .906 r
.77094 .18252 .77697 .19156 .79072 .18664 .78474 .17758 Mtetra
.664 .74 .907 r
.78474 .17758 .79072 .18664 .80454 .18172 .7986 .17264 Mtetra
.589 .741 .949 r
.16993 .38871 .17783 .3953 .18879 .39275 .18089 .38649 Mtetra
.542 .737 .966 r
.18089 .38649 .18879 .39275 .19975 .39081 .19182 .38502 Mtetra
.458 .722 .982 r
.19182 .38502 .19975 .39081 .21069 .38969 .20271 .38461 Mtetra
.297 .67 .974 r
.20271 .38461 .21069 .38969 .22159 .3897 .21354 .38557 Mtetra
.008 .521 .861 r
.21354 .38557 .22159 .3897 .23243 .39118 .22428 .3883 Mtetra
.354 0 0 r
.22428 .3883 .23243 .39118 .24319 .39452 .23493 .39316 Mtetra
.6 .03 0 r
.23493 .39316 .24319 .39452 .25386 .40009 .24548 .40044 Mtetra
.709 .195 .005 r
.24548 .40044 .25386 .40009 .26445 .40814 .25594 .41026 Mtetra
.751 .282 .134 r
.25594 .41026 .26445 .40814 .27497 .4188 .26637 .42248 Mtetra
.766 .325 .203 r
.26637 .42248 .27497 .4188 .28547 .43188 .27681 .43663 Mtetra
.77 .341 .233 r
.27681 .43663 .28547 .43188 .29601 .44687 .28736 .45186 Mtetra
.765 .335 .23 r
.28736 .45186 .29601 .44687 .30668 .46286 .29811 .46695 Mtetra
.75 .3 .183 r
.29811 .46695 .30668 .46286 .31755 .47862 .30915 .48046 Mtetra
.703 .201 .041 r
.30915 .48046 .31755 .47862 .32873 .49266 .32057 .4909 Mtetra
.463 0 0 r
.32057 .4909 .32873 .49266 .34027 .50345 .3324 .49697 Mtetra
.37 .673 .975 r
.3324 .49697 .34027 .50345 .35221 .50971 .34466 .49779 Mtetra
.658 .659 .84 r
.34466 .49779 .35221 .50971 .36455 .51057 .35728 .49308 Mtetra
.711 .612 .745 r
.35728 .49308 .36455 .51057 .37724 .50577 .3702 .48318 Mtetra
.725 .584 .697 r
.3702 .48318 .37724 .50577 .39019 .49566 .38333 .46895 Mtetra
.728 .567 .673 r
.38333 .46895 .39019 .49566 .40332 .48114 .39656 .45158 Mtetra
.727 .557 .66 r
.39656 .45158 .40332 .48114 .41654 .4634 .40981 .43236 Mtetra
.725 .551 .654 r
.40981 .43236 .41654 .4634 .42976 .44376 .42303 .41249 Mtetra
.723 .548 .653 r
.42303 .41249 .42976 .44376 .44295 .42339 .43618 .39291 Mtetra
.72 .548 .657 r
.43618 .39291 .44295 .42339 .45606 .40326 .44924 .37426 Mtetra
.718 .551 .663 r
.44924 .37426 .45606 .40326 .4691 .38402 .46223 .3569 Mtetra
.716 .557 .672 r
.46223 .3569 .4691 .38402 .48205 .36602 .47515 .34096 Mtetra
.715 .564 .683 r
.47515 .34096 .48205 .36602 .49495 .34942 .48802 .3264 Mtetra
.715 .574 .695 r
.48802 .3264 .49495 .34942 .5078 .3342 .50085 .3131 Mtetra
.714 .585 .709 r
.50085 .3131 .5078 .3342 .52062 .32027 .51367 .30094 Mtetra
.714 .597 .724 r
.51367 .30094 .52062 .32027 .53342 .30751 .52649 .28977 Mtetra
.714 .61 .74 r
.52649 .28977 .53342 .30751 .54623 .29581 .53932 .27948 Mtetra
.714 .624 .756 r
.53932 .27948 .54623 .29581 .55904 .28506 .55216 .26998 Mtetra
.712 .638 .773 r
.55216 .26998 .55904 .28506 .57187 .27516 .56503 .2612 Mtetra
.71 .651 .789 r
.56503 .2612 .57187 .27516 .58474 .26606 .57794 .25306 Mtetra
.707 .665 .806 r
.57794 .25306 .58474 .26606 .59765 .25767 .5909 .2455 Mtetra
.703 .677 .822 r
.5909 .2455 .59765 .25767 .6106 .24992 .6039 .23847 Mtetra
.698 .689 .837 r
.6039 .23847 .6106 .24992 .6236 .24275 .61696 .23188 Mtetra
.694 .699 .851 r
.61696 .23188 .6236 .24275 .63667 .23607 .63007 .22569 Mtetra
.689 .709 .863 r
.63007 .22569 .63667 .23607 .64979 .22981 .64325 .21981 Mtetra
.684 .716 .874 r
.64325 .21981 .64979 .22981 .66298 .22389 .6565 .2142 Mtetra
.679 .723 .882 r
.6565 .2142 .66298 .22389 .67624 .21826 .66981 .20879 Mtetra
.676 .728 .889 r
.66981 .20879 .67624 .21826 .68956 .21284 .68318 .20354 Mtetra
.672 .731 .894 r
.68318 .20354 .68956 .21284 .70295 .20759 .69663 .1984 Mtetra
.67 .734 .898 r
.69663 .1984 .70295 .20759 .71641 .20246 .71014 .19333 Mtetra
.668 .736 .901 r
.71014 .19333 .71641 .20246 .72994 .19742 .72372 .18833 Mtetra
.667 .738 .903 r
.72372 .18833 .72994 .19742 .74354 .19242 .73736 .18335 Mtetra
.666 .739 .905 r
.73736 .18335 .74354 .19242 .7572 .18747 .75107 .17839 Mtetra
.665 .74 .906 r
.75107 .17839 .7572 .18747 .77094 .18252 .76485 .17343 Mtetra
.664 .74 .907 r
.76485 .17343 .77094 .18252 .78474 .17758 .7787 .16846 Mtetra
.664 .741 .907 r
.7787 .16846 .78474 .17758 .7986 .17264 .79262 .16349 Mtetra
.562 .739 .959 r
.16195 .38227 .16993 .38871 .18089 .38649 .17288 .38049 Mtetra
.492 .729 .977 r
.17288 .38049 .18089 .38649 .19182 .38502 .18376 .37967 Mtetra
.359 .694 .982 r
.18376 .37967 .19182 .38502 .20271 .38461 .19458 .38014 Mtetra
.11 .581 .913 r
.19458 .38014 .20271 .38461 .21354 .38557 .20532 .38227 Mtetra
0 .333 .668 r
.20532 .38227 .21354 .38557 .22428 .3883 .21595 .38642 Mtetra
.541 0 0 r
.21595 .38642 .22428 .3883 .23493 .39316 .22647 .39289 Mtetra
.682 .15 0 r
.22647 .39289 .23493 .39316 .24548 .40044 .23689 .40182 Mtetra
.738 .254 .091 r
.23689 .40182 .24548 .40044 .25594 .41026 .24726 .41311 Mtetra
.76 .306 .171 r
.24726 .41311 .25594 .41026 .26637 .42248 .25762 .42631 Mtetra
.766 .326 .206 r
.25762 .42631 .26637 .42248 .27681 .43663 .26807 .44064 Mtetra
.763 .321 .202 r
.26807 .44064 .27681 .43663 .28736 .45186 .27871 .45492 Mtetra
.747 .284 .149 r
.27871 .45492 .28736 .45186 .29811 .46695 .28964 .46778 Mtetra
.692 .173 0 r
.28964 .46778 .29811 .46695 .30915 .48046 .30094 .47774 Mtetra
.397 0 0 r
.30094 .47774 .30915 .48046 .32057 .4909 .31267 .48352 Mtetra
.405 .662 .964 r
.31267 .48352 .32057 .4909 .3324 .49697 .32484 .48426 Mtetra
.653 .644 .828 r
.32484 .48426 .3324 .49697 .34466 .49779 .3374 .47964 Mtetra
.704 .603 .74 r
.3374 .47964 .34466 .49779 .35728 .49308 .35029 .46998 Mtetra
.719 .578 .696 r
.35029 .46998 .35728 .49308 .3702 .48318 .3634 .45609 Mtetra
.723 .563 .672 r
.3634 .45609 .3702 .48318 .38333 .46895 .37663 .43916 Mtetra
.723 .553 .66 r
.37663 .43916 .38333 .46895 .39656 .45158 .3899 .42045 Mtetra
.722 .548 .655 r
.3899 .42045 .39656 .45158 .40981 .43236 .40314 .40114 Mtetra
.719 .546 .654 r
.40314 .40114 .40981 .43236 .42303 .41249 .41631 .38216 Mtetra
.717 .546 .658 r
.41631 .38216 .42303 .41249 .43618 .39291 .4294 .36416 Mtetra
.714 .55 .665 r
.4294 .36416 .43618 .39291 .44924 .37426 .4424 .34747 Mtetra
.713 .556 .674 r
.4424 .34747 .44924 .37426 .46223 .3569 .45533 .33221 Mtetra
.711 .564 .686 r
.45533 .33221 .46223 .3569 .47515 .34096 .46821 .31833 Mtetra
.711 .574 .699 r
.46821 .31833 .47515 .34096 .48802 .3264 .48105 .30569 Mtetra
.711 .586 .714 r
.48105 .30569 .48802 .3264 .50085 .3131 .49388 .29413 Mtetra
.71 .598 .729 r
.49388 .29413 .50085 .3131 .51367 .30094 .5067 .28352 Mtetra
.71 .612 .745 r
.5067 .28352 .51367 .30094 .52649 .28977 .51954 .27371 Mtetra
.71 .625 .761 r
.51954 .27371 .52649 .28977 .53932 .27948 .53238 .26463 Mtetra
.709 .639 .777 r
.53238 .26463 .53932 .27948 .55216 .26998 .54526 .25618 Mtetra
.707 .653 .794 r
.54526 .25618 .55216 .26998 .56503 .2612 .55817 .24831 Mtetra
.704 .666 .81 r
.55817 .24831 .56503 .2612 .57794 .25306 .57112 .24097 Mtetra
.7 .678 .825 r
.57112 .24097 .57794 .25306 .5909 .2455 .58412 .23409 Mtetra
.696 .69 .84 r
.58412 .23409 .5909 .2455 .6039 .23847 .59717 .22763 Mtetra
.692 .7 .853 r
.59717 .22763 .6039 .23847 .61696 .23188 .61028 .22151 Mtetra
.687 .709 .865 r
.61028 .22151 .61696 .23188 .63007 .22569 .62345 .21568 Mtetra
.683 .716 .875 r
.62345 .21568 .63007 .22569 .64325 .21981 .63668 .2101 Mtetra
.679 .723 .883 r
.63668 .2101 .64325 .21981 .6565 .2142 .64997 .2047 Mtetra
.675 .727 .889 r
.64997 .2047 .6565 .2142 .66981 .20879 .66333 .19945 Mtetra
.672 .731 .894 r
.66333 .19945 .66981 .20879 .68318 .20354 .67676 .1943 Mtetra
.67 .734 .898 r
.67676 .1943 .68318 .20354 .69663 .1984 .69025 .18923 Mtetra
.668 .736 .901 r
.69025 .18923 .69663 .1984 .71014 .19333 .70381 .18421 Mtetra
.667 .738 .903 r
.70381 .18421 .71014 .19333 .72372 .18833 .71744 .17922 Mtetra
.666 .739 .905 r
.71744 .17922 .72372 .18833 .73736 .18335 .73113 .17423 Mtetra
.665 .74 .906 r
.73113 .17423 .73736 .18335 .75107 .17839 .74489 .16926 Mtetra
.664 .74 .907 r
.74489 .16926 .75107 .17839 .76485 .17343 .75872 .16427 Mtetra
.664 .741 .907 r
.75872 .16427 .76485 .17343 .7787 .16846 .77262 .15927 Mtetra
.77262 .15927 .7787 .16846 .79262 .16349 .78658 .15426 Mtetra
.52 .735 .972 r
.15386 .37608 .16195 .38227 .17288 .38049 .16475 .37489 Mtetra
.411 .711 .985 r
.16475 .37489 .17288 .38049 .18376 .37967 .17556 .37488 Mtetra
.203 .63 .949 r
.17556 .37488 .18376 .37967 .19458 .38014 .18629 .37642 Mtetra
0 .425 .766 r
.18629 .37642 .19458 .38014 .20532 .38227 .19692 .37986 Mtetra
.462 0 0 r
.19692 .37986 .20532 .38227 .21595 .38642 .20742 .38551 Mtetra
.644 .091 0 r
.20742 .38551 .21595 .38642 .22647 .39289 .21781 .39351 Mtetra
.72 .217 .035 r
.21781 .39351 .22647 .39289 .23689 .40182 .22813 .4038 Mtetra
.75 .28 .13 r
.22813 .4038 .23689 .40182 .24726 .41311 .23844 .41598 Mtetra
.76 .305 .17 r
.23844 .41598 .24726 .41311 .25762 .42631 .24882 .42929 Mtetra
.758 .302 .167 r
.24882 .42929 .25762 .42631 .26807 .44064 .25936 .44265 Mtetra
.74 .261 .106 r
.25936 .44265 .26807 .44064 .27871 .45492 .27019 .45473 Mtetra
.673 .135 0 r
.27019 .45473 .27871 .45492 .28964 .46778 .28139 .4641 Mtetra
.311 0 0 r
.28139 .4641 .28964 .46778 .30094 .47774 .29303 .46952 Mtetra
.433 .651 .95 r
.29303 .46952 .30094 .47774 .31267 .48352 .30511 .47013 Mtetra
.648 .631 .819 r
.30511 .47013 .31267 .48352 .32484 .48426 .3176 .4656 Mtetra
.698 .596 .738 r
.3176 .4656 .32484 .48426 .3374 .47964 .33044 .4562 Mtetra
.714 .573 .695 r
.33044 .4562 .3374 .47964 .35029 .46998 .34353 .44273 Mtetra
.719 .559 .672 r
.34353 .44273 .35029 .46998 .3634 .45609 .35676 .42631 Mtetra
.72 .551 .661 r
.35676 .42631 .3634 .45609 .37663 .43916 .37003 .40818 Mtetra
.718 .546 .656 r
.37003 .40818 .37663 .43916 .3899 .42045 .38328 .3895 Mtetra
.716 .544 .656 r
.38328 .3895 .3899 .42045 .40314 .40114 .39646 .37119 Mtetra
.714 .546 .66 r
.39646 .37119 .40314 .40114 .41631 .38216 .40956 .35387 Mtetra
.711 .549 .668 r
.40956 .35387 .41631 .38216 .4294 .36416 .42257 .33788 Mtetra
.709 .556 .678 r
.42257 .33788 .4294 .36416 .4424 .34747 .4355 .32331 Mtetra
.708 .564 .69 r
.4355 .32331 .4424 .34747 .45533 .33221 .44838 .31011 Mtetra
.707 .575 .704 r
.44838 .31011 .45533 .33221 .46821 .31833 .46123 .29812 Mtetra
.707 .587 .719 r
.46123 .29812 .46821 .31833 .48105 .30569 .47405 .28718 Mtetra
.707 .6 .735 r
.47405 .28718 .48105 .30569 .49388 .29413 .48687 .27712 Mtetra
.707 .614 .751 r
.48687 .27712 .49388 .29413 .5067 .28352 .4997 .2678 Mtetra
.706 .628 .767 r
.4997 .2678 .5067 .28352 .51954 .27371 .51255 .25914 Mtetra
.705 .642 .783 r
.51255 .25914 .51954 .27371 .53238 .26463 .52542 .25105 Mtetra
.703 .655 .799 r
.52542 .25105 .53238 .26463 .54526 .25618 .53833 .24347 Mtetra
.701 .668 .814 r
.53833 .24347 .54526 .25618 .55817 .24831 .55128 .23635 Mtetra
.698 .68 .829 r
.55128 .23635 .55817 .24831 .57112 .24097 .56427 .22964 Mtetra
.694 .691 .843 r
.56427 .22964 .57112 .24097 .58412 .23409 .57731 .2233 Mtetra
.69 .701 .855 r
.57731 .2233 .58412 .23409 .59717 .22763 .59041 .21727 Mtetra
.685 .709 .866 r
.59041 .21727 .59717 .22763 .61028 .22151 .60356 .21151 Mtetra
.681 .717 .876 r
.60356 .21151 .61028 .22151 .62345 .21568 .61678 .20596 Mtetra
.678 .723 .884 r
.61678 .20596 .62345 .21568 .63668 .2101 .63006 .20058 Mtetra
.674 .728 .89 r
.63006 .20058 .63668 .2101 .64997 .2047 .6434 .19534 Mtetra
.672 .731 .895 r
.6434 .19534 .64997 .2047 .66333 .19945 .65681 .19019 Mtetra
.669 .734 .899 r
.65681 .19019 .66333 .19945 .67676 .1943 .67028 .18511 Mtetra
.668 .736 .901 r
.67028 .18511 .67676 .1943 .69025 .18923 .68383 .18007 Mtetra
.666 .738 .903 r
.68383 .18007 .69025 .18923 .70381 .18421 .69743 .17506 Mtetra
.665 .739 .905 r
.69743 .17506 .70381 .18421 .71744 .17922 .71111 .17006 Mtetra
.665 .74 .906 r
.71111 .17006 .71744 .17922 .73113 .17423 .72485 .16507 Mtetra
.664 .74 .907 r
.72485 .16507 .73113 .17423 .74489 .16926 .73866 .16006 Mtetra
.664 .741 .907 r
.73866 .16006 .74489 .16926 .75872 .16427 .75253 .15504 Mtetra
.75253 .15504 .75872 .16427 .77262 .15927 .76647 .15001 Mtetra
.664 .741 .908 r
.76647 .15001 .77262 .15927 .78658 .15426 .78049 .14495 Mtetra
.455 .723 .983 r
.14566 .37024 .15386 .37608 .16475 .37489 .15648 .36978 Mtetra
.285 .667 .971 r
.15648 .36978 .16475 .37489 .17556 .37488 .16721 .37075 Mtetra
0 .509 .848 r
.16721 .37075 .17556 .37488 .18629 .37642 .17783 .3735 Mtetra
.361 0 0 r
.17783 .3735 .18629 .37642 .19692 .37986 .18832 .37832 Mtetra
.589 .016 0 r
.18832 .37832 .19692 .37986 .20742 .38551 .1987 .38537 Mtetra
.692 .167 0 r
.1987 .38537 .20742 .38551 .21781 .39351 .209 .39461 Mtetra
.735 .245 .076 r
.209 .39461 .21781 .39351 .22813 .4038 .21926 .40569 Mtetra
.75 .277 .125 r
.21926 .40569 .22813 .4038 .23844 .41598 .22958 .4179 Mtetra
.749 .276 .121 r
.22958 .4179 .23844 .41598 .24882 .42929 .24006 .43024 Mtetra
.728 .23 .051 r
.24006 .43024 .24882 .42929 .25936 .44265 .2508 .44143 Mtetra
.64 .083 0 r
.2508 .44143 .25936 .44265 .27019 .45473 .26192 .45013 Mtetra
0 .346 .729 r
.26192 .45013 .27019 .45473 .28139 .4641 .27346 .45512 Mtetra
.457 .64 .935 r
.27346 .45512 .28139 .4641 .29303 .46952 .28546 .45557 Mtetra
.644 .621 .812 r
.28546 .45557 .29303 .46952 .30511 .47013 .29788 .45112 Mtetra
.693 .59 .736 r
.29788 .45112 .30511 .47013 .3176 .4656 .31067 .44202 Mtetra
.709 .57 .696 r
.31067 .44202 .3176 .4656 .33044 .4562 .32372 .42902 Mtetra
.715 .557 .674 r
.32372 .42902 .33044 .4562 .34353 .44273 .33693 .41318 Mtetra
.716 .549 .662 r
.33693 .41318 .34353 .44273 .35676 .42631 .3502 .39571 Mtetra
.715 .545 .658 r
.3502 .39571 .35676 .42631 .37003 .40818 .36345 .37772 Mtetra
.714 .544 .658 r
.36345 .37772 .37003 .40818 .38328 .3895 .37663 .36013 Mtetra
.711 .546 .663 r
.37663 .36013 .38328 .3895 .39646 .37119 .38973 .34353 Mtetra
.709 .55 .671 r
.38973 .34353 .39646 .37119 .40956 .35387 .40273 .32825 Mtetra
.707 .557 .682 r
.40273 .32825 .40956 .35387 .42257 .33788 .41566 .31438 Mtetra
.705 .566 .695 r
.41566 .31438 .42257 .33788 .4355 .32331 .42854 .30185 Mtetra
.704 .577 .71 r
.42854 .30185 .4355 .32331 .44838 .31011 .44137 .2905 Mtetra
.704 .59 .726 r
.44137 .2905 .44838 .31011 .46123 .29812 .45419 .28016 Mtetra
.703 .604 .742 r
.45419 .28016 .46123 .29812 .47405 .28718 .467 .27064 Mtetra
.703 .618 .758 r
.467 .27064 .47405 .28718 .48687 .27712 .47982 .26181 Mtetra
.703 .631 .774 r
.47982 .26181 .48687 .27712 .4997 .2678 .49266 .25357 Mtetra
.702 .645 .79 r
.49266 .25357 .4997 .2678 .51255 .25914 .50552 .24583 Mtetra
.7 .658 .805 r
.50552 .24583 .51255 .25914 .52542 .25105 .51842 .23854 Mtetra
.698 .671 .82 r
.51842 .23854 .52542 .25105 .53833 .24347 .53136 .23165 Mtetra
.695 .682 .834 r
.53136 .23165 .53833 .24347 .55128 .23635 .54434 .22513 Mtetra
.691 .693 .847 r
.54434 .22513 .55128 .23635 .56427 .22964 .55738 .21892 Mtetra
.688 .702 .858 r
.55738 .21892 .56427 .22964 .57731 .2233 .57046 .21299 Mtetra
.684 .711 .869 r
.57046 .21299 .57731 .2233 .59041 .21727 .5836 .20729 Mtetra
.68 .718 .877 r
.5836 .20729 .59041 .21727 .60356 .21151 .5968 .20178 Mtetra
.677 .723 .885 r
.5968 .20178 .60356 .21151 .61678 .20596 .61007 .19643 Mtetra
.674 .728 .891 r
.61007 .19643 .61678 .20596 .63006 .20058 .62339 .19119 Mtetra
.671 .732 .895 r
.62339 .19119 .63006 .20058 .6434 .19534 .63678 .18605 Mtetra
.669 .734 .899 r
.63678 .18605 .6434 .19534 .65681 .19019 .65024 .18096 Mtetra
.667 .736 .902 r
.65024 .18096 .65681 .19019 .67028 .18511 .66376 .17591 Mtetra
.666 .738 .904 r
.66376 .17591 .67028 .18511 .68383 .18007 .67735 .17089 Mtetra
.665 .739 .905 r
.67735 .17089 .68383 .18007 .69743 .17506 .691 .16587 Mtetra
.665 .74 .906 r
.691 .16587 .69743 .17506 .71111 .17006 .70472 .16086 Mtetra
.664 .74 .907 r
.70472 .16086 .71111 .17006 .72485 .16507 .71851 .15583 Mtetra
.664 .741 .907 r
.71851 .15583 .72485 .16507 .73866 .16006 .73236 .15079 Mtetra
.73236 .15079 .73866 .16006 .75253 .15504 .74629 .14574 Mtetra
.664 .741 .908 r
.74629 .14574 .75253 .15504 .76647 .15001 .76028 .14067 Mtetra
.76028 .14067 .76647 .15001 .78049 .14495 .77434 .13557 Mtetra
.354 .694 .982 r
.13731 .36485 .14566 .37024 .15648 .36978 .14805 .36527 Mtetra
.105 .58 .911 r
.14805 .36527 .15648 .36978 .16721 .37075 .15868 .36733 Mtetra
0 .344 .677 r
.15868 .36733 .16721 .37075 .17783 .3735 .16918 .37133 Mtetra
.512 0 0 r
.16918 .37133 .17783 .3735 .18832 .37832 .17956 .37742 Mtetra
.651 .102 0 r
.17956 .37742 .18832 .37832 .1987 .38537 .18984 .38558 Mtetra
.711 .198 .006 r
.18984 .38558 .1987 .38537 .209 .39461 .20008 .3955 Mtetra
.733 .24 .065 r
.20008 .3955 .209 .39461 .21926 .40569 .21037 .40655 Mtetra
.734 .239 .062 r
.21037 .40655 .21926 .40569 .22958 .4179 .22079 .41779 Mtetra
.707 .187 0 r
.22079 .41779 .22958 .4179 .24006 .43024 .23147 .42801 Mtetra
.589 .014 0 r
.23147 .42801 .24006 .43024 .2508 .44143 .24251 .43595 Mtetra
0 .417 .815 r
.24251 .43595 .2508 .44143 .26192 .45013 .25397 .44046 Mtetra
.476 .631 .921 r
.25397 .44046 .26192 .45013 .27346 .45512 .26589 .44071 Mtetra
.64 .612 .806 r
.26589 .44071 .27346 .45512 .28546 .45557 .27824 .43635 Mtetra
.687 .585 .736 r
.27824 .43635 .28546 .45557 .29788 .45112 .29097 .42759 Mtetra
.705 .567 .697 r
.29097 .42759 .29788 .45112 .31067 .44202 .30398 .41511 Mtetra
.711 .556 .676 r
.30398 .41511 .31067 .44202 .32372 .42902 .31715 .39992 Mtetra
.713 .549 .665 r
.31715 .39992 .32372 .42902 .33693 .41318 .3304 .38317 Mtetra
.713 .545 .66 r
.3304 .38317 .33693 .41318 .3502 .39571 .34364 .36595 Mtetra
.711 .545 .662 r
.34364 .36595 .3502 .39571 .36345 .37772 .35681 .34911 Mtetra
.709 .547 .667 r
.35681 .34911 .36345 .37772 .37663 .36013 .3699 .33325 Mtetra
.707 .552 .675 r
.3699 .33325 .37663 .36013 .38973 .34353 .38289 .31869 Mtetra
.705 .559 .687 r
.38289 .31869 .38973 .34353 .40273 .32825 .39581 .30552 Mtetra
.703 .569 .701 r
.39581 .30552 .40273 .32825 .41566 .31438 .40867 .29365 Mtetra
.702 .581 .717 r
.40867 .29365 .41566 .31438 .42854 .30185 .42149 .28293 Mtetra
.701 .594 .733 r
.42149 .28293 .42854 .30185 .44137 .2905 .43428 .27316 Mtetra
.7 .608 .75 r
.43428 .27316 .44137 .2905 .45419 .28016 .44708 .26416 Mtetra
.7 .622 .766 r
.44708 .26416 .45419 .28016 .467 .27064 .45989 .2558 Mtetra
.699 .636 .782 r
.45989 .2558 .467 .27064 .47982 .26181 .47271 .24797 Mtetra
.698 .649 .797 r
.47271 .24797 .47982 .26181 .49266 .25357 .48556 .24057 Mtetra
.697 .662 .812 r
.48556 .24057 .49266 .25357 .50552 .24583 .49845 .23357 Mtetra
.695 .674 .826 r
.49845 .23357 .50552 .24583 .51842 .23854 .51138 .22691 Mtetra
.692 .685 .839 r
.51138 .22691 .51842 .23854 .53136 .23165 .52435 .22057 Mtetra
.689 .695 .851 r
.52435 .22057 .53136 .23165 .54434 .22513 .53736 .2145 Mtetra
.685 .704 .862 r
.53736 .2145 .54434 .22513 .55738 .21892 .55043 .20866 Mtetra
.682 .712 .871 r
.55043 .20866 .55738 .21892 .57046 .21299 .56356 .20304 Mtetra
.679 .719 .879 r
.56356 .20304 .57046 .21299 .5836 .20729 .57675 .19758 Mtetra
.675 .724 .886 r
.57675 .19758 .5836 .20729 .5968 .20178 .58999 .19225 Mtetra
.673 .728 .892 r
.58999 .19225 .5968 .20178 .61007 .19643 .6033 .18703 Mtetra
.67 .732 .896 r
.6033 .18703 .61007 .19643 .62339 .19119 .61667 .18188 Mtetra
.669 .735 .899 r
.61667 .18188 .62339 .19119 .63678 .18605 .63011 .17679 Mtetra
.667 .737 .902 r
.63011 .17679 .63678 .18605 .65024 .18096 .64361 .17173 Mtetra
.666 .738 .904 r
.64361 .17173 .65024 .18096 .66376 .17591 .65718 .16669 Mtetra
.665 .739 .905 r
.65718 .16669 .66376 .17591 .67735 .17089 .67081 .16166 Mtetra
.665 .74 .906 r
.67081 .16166 .67735 .17089 .691 .16587 .68451 .15663 Mtetra
.664 .74 .907 r
.68451 .15663 .691 .16587 .70472 .16086 .69828 .15159 Mtetra
.664 .741 .907 r
.69828 .15159 .70472 .16086 .71851 .15583 .71211 .14653 Mtetra
.71211 .14653 .71851 .15583 .73236 .15079 .72602 .14145 Mtetra
.664 .741 .908 r
.72602 .14145 .73236 .15079 .74629 .14574 .73999 .13636 Mtetra
.73999 .13636 .74629 .14574 .76028 .14067 .75403 .13124 Mtetra
.75403 .13124 .76028 .14067 .77434 .13557 .76814 .1261 Mtetra
.21 .635 .952 r
.12882 .35996 .13731 .36485 .14805 .36527 .13946 .36136 Mtetra
0 .45 .789 r
.13946 .36136 .14805 .36527 .15868 .36733 .14997 .36454 Mtetra
.407 0 0 r
.14997 .36454 .15868 .36733 .16918 .37133 .16036 .36967 Mtetra
.59 .017 0 r
.16036 .36967 .16918 .37133 .17956 .37742 .17065 .37674 Mtetra
.673 .135 0 r
.17065 .37674 .17956 .37742 .18984 .38558 .18089 .38548 Mtetra
.706 .188 0 r
.18089 .38548 .18984 .38558 .20008 .3955 .19116 .39532 Mtetra
.709 .19 0 r
.19116 .39532 .20008 .3955 .21037 .40655 .20155 .40539 Mtetra
.672 .127 0 r
.20155 .40539 .21037 .40655 .22079 .41779 .21218 .41458 Mtetra
.511 0 0 r
.21218 .41458 .22079 .41779 .23147 .42801 .22315 .42171 Mtetra
.023 .476 .876 r
.22315 .42171 .23147 .42801 .24251 .43595 .23455 .42569 Mtetra
.493 .624 .908 r
.23455 .42569 .24251 .43595 .25397 .44046 .24639 .42572 Mtetra
.636 .606 .803 r
.24639 .42572 .25397 .44046 .26589 .44071 .25867 .42145 Mtetra
.683 .582 .736 r
.25867 .42145 .26589 .44071 .27824 .43635 .27134 .41304 Mtetra
.701 .566 .699 r
.27134 .41304 .27824 .43635 .29097 .42759 .28429 .40113 Mtetra
.708 .555 .679 r
.28429 .40113 .29097 .42759 .30398 .41511 .29742 .38665 Mtetra
.71 .549 .668 r
.29742 .38665 .30398 .41511 .31715 .39992 .31063 .37069 Mtetra
.711 .546 .664 r
.31063 .37069 .31715 .39992 .3304 .38317 .32384 .35427 Mtetra
.709 .546 .666 r
.32384 .35427 .3304 .38317 .34364 .36595 .33699 .33823 Mtetra
.707 .549 .671 r
.33699 .33823 .34364 .36595 .35681 .34911 .35006 .32314 Mtetra
.705 .554 .681 r
.35006 .32314 .35681 .34911 .3699 .33325 .36304 .30931 Mtetra
.703 .563 .693 r
.36304 .30931 .3699 .33325 .38289 .31869 .37593 .29682 Mtetra
.701 .573 .708 r
.37593 .29682 .38289 .31869 .39581 .30552 .38877 .28559 Mtetra
.699 .586 .725 r
.38877 .28559 .39581 .30552 .40867 .29365 .40156 .27546 Mtetra
.698 .599 .742 r
.40156 .27546 .40867 .29365 .42149 .28293 .41434 .26624 Mtetra
.697 .614 .759 r
.41434 .26624 .42149 .28293 .43428 .27316 .42711 .25774 Mtetra
.697 .628 .775 r
.42711 .25774 .43428 .27316 .44708 .26416 .4399 .24982 Mtetra
.696 .642 .791 r
.4399 .24982 .44708 .26416 .45989 .2558 .45271 .24237 Mtetra
.695 .655 .806 r
.45271 .24237 .45989 .2558 .47271 .24797 .46554 .23531 Mtetra
.693 .667 .819 r
.46554 .23531 .47271 .24797 .48556 .24057 .47841 .22858 Mtetra
.692 .678 .832 r
.47841 .22858 .48556 .24057 .49845 .23357 .49132 .22215 Mtetra
.689 .689 .844 r
.49132 .22215 .49845 .23357 .51138 .22691 .50428 .21598 Mtetra
.686 .698 .855 r
.50428 .21598 .51138 .22691 .52435 .22057 .51728 .21004 Mtetra
.683 .706 .865 r
.51728 .21004 .52435 .22057 .53736 .2145 .53033 .20431 Mtetra
.68 .714 .874 r
.53033 .20431 .53736 .2145 .55043 .20866 .54344 .19876 Mtetra
.677 .72 .881 r
.54344 .19876 .55043 .20866 .56356 .20304 .55661 .19334 Mtetra
.674 .725 .888 r
.55661 .19334 .56356 .20304 .57675 .19758 .56984 .18805 Mtetra
.672 .729 .893 r
.56984 .18805 .57675 .19758 .58999 .19225 .58313 .18284 Mtetra
.67 .732 .897 r
.58313 .18284 .58999 .19225 .6033 .18703 .59648 .1777 Mtetra
.668 .735 .9 r
.59648 .1777 .6033 .18703 .61667 .18188 .6099 .1726 Mtetra
.667 .737 .902 r
.6099 .1726 .61667 .18188 .63011 .17679 .62338 .16753 Mtetra
.666 .738 .904 r
.62338 .16753 .63011 .17679 .64361 .17173 .63693 .16248 Mtetra
.665 .739 .905 r
.63693 .16248 .64361 .17173 .65718 .16669 .65054 .15744 Mtetra
.665 .74 .906 r
.65054 .15744 .65718 .16669 .67081 .16166 .66422 .15238 Mtetra
.664 .74 .907 r
.66422 .15238 .67081 .16166 .68451 .15663 .67796 .14732 Mtetra
.664 .741 .907 r
.67796 .14732 .68451 .15663 .69828 .15159 .69178 .14224 Mtetra
.69178 .14224 .69828 .15159 .71211 .14653 .70566 .13715 Mtetra
.664 .741 .908 r
.70566 .13715 .71211 .14653 .72602 .14145 .71961 .13203 Mtetra
.71961 .13203 .72602 .14145 .73999 .13636 .73363 .12689 Mtetra
.73363 .12689 .73999 .13636 .75403 .13124 .74772 .12173 Mtetra
.74772 .12173 .75403 .13124 .76814 .1261 .76188 .11654 Mtetra
.039 .542 .877 r
.12018 .35559 .12882 .35996 .13946 .36136 .13071 .35798 Mtetra
.273 0 0 r
.13071 .35798 .13946 .36136 .14997 .36454 .14112 .36216 Mtetra
.5 0 0 r
.14112 .36216 .14997 .36454 .16036 .36967 .15143 .36814 Mtetra
.616 .051 0 r
.15143 .36814 .16036 .36967 .17065 .37674 .16168 .37568 Mtetra
.663 .118 0 r
.16168 .37568 .17065 .37674 .18089 .38548 .17195 .38428 Mtetra
.667 .122 0 r
.17195 .38428 .18089 .38548 .19116 .39532 .18233 .39315 Mtetra
.615 .047 0 r
.18233 .39315 .19116 .39532 .20155 .40539 .19293 .40127 Mtetra
.403 0 0 r
.19293 .40127 .20155 .40539 .21218 .41458 .20385 .40754 Mtetra
.127 .522 .915 r
.20385 .40754 .21218 .41458 .22315 .42171 .21518 .41095 Mtetra
.507 .619 .897 r
.21518 .41095 .22315 .42171 .23455 .42569 .22696 .41074 Mtetra
.633 .602 .8 r
.22696 .41074 .23455 .42569 .24639 .42572 .23916 .40655 Mtetra
.678 .58 .739 r
.23916 .40655 .24639 .42572 .25867 .42145 .25176 .39852 Mtetra
.697 .565 .703 r
.25176 .39852 .25867 .42145 .27134 .41304 .26464 .38722 Mtetra
.705 .556 .683 r
.26464 .38722 .27134 .41304 .28429 .40113 .27772 .37349 Mtetra
.708 .55 .672 r
.27772 .37349 .28429 .40113 .29742 .38665 .29088 .35837 Mtetra
.708 .548 .669 r
.29088 .35837 .29742 .38665 .31063 .37069 .30405 .3428 Mtetra
.707 .548 .671 r
.30405 .3428 .31063 .37069 .32384 .35427 .31717 .32759 Mtetra
.706 .552 .677 r
.31717 .32759 .32384 .35427 .33699 .33823 .33021 .31328 Mtetra
.703 .558 .687 r
.33021 .31328 .33699 .33823 .35006 .32314 .34316 .30018 Mtetra
.701 .567 .7 r
.34316 .30018 .35006 .32314 .36304 .30931 .35602 .28835 Mtetra
.699 .578 .716 r
.35602 .28835 .36304 .30931 .37593 .29682 .36883 .27773 Mtetra
.697 .591 .733 r
.36883 .27773 .37593 .29682 .38877 .28559 .3816 .26816 Mtetra
.696 .605 .751 r
.3816 .26816 .38877 .28559 .40156 .27546 .39435 .25945 Mtetra
.695 .62 .769 r
.39435 .25945 .40156 .27546 .41434 .26624 .4071 .25142 Mtetra
.694 .634 .785 r
.4071 .25142 .41434 .26624 .42711 .25774 .41986 .24391 Mtetra
.693 .648 .8 r
.41986 .24391 .42711 .25774 .4399 .24982 .43264 .23682 Mtetra
.692 .66 .814 r
.43264 .23682 .4399 .24982 .45271 .24237 .44545 .23006 Mtetra
.69 .672 .827 r
.44545 .23006 .45271 .24237 .46554 .23531 .4583 .2236 Mtetra
.689 .683 .839 r
.4583 .2236 .46554 .23531 .47841 .22858 .4712 .21738 Mtetra
.686 .693 .85 r
.4712 .21738 .47841 .22858 .49132 .22215 .48413 .21138 Mtetra
.684 .701 .86 r
.48413 .21138 .49132 .22215 .50428 .21598 .49712 .20557 Mtetra
.681 .709 .869 r
.49712 .20557 .50428 .21598 .51728 .21004 .51015 .19994 Mtetra
.678 .716 .877 r
.51015 .19994 .51728 .21004 .53033 .20431 .52325 .19445 Mtetra
.676 .721 .884 r
.52325 .19445 .53033 .20431 .54344 .19876 .5364 .18909 Mtetra
.673 .726 .889 r
.5364 .18909 .54344 .19876 .55661 .19334 .5496 .18382 Mtetra
.671 .73 .894 r
.5496 .18382 .55661 .19334 .56984 .18805 .56287 .17863 Mtetra
.669 .733 .898 r
.56287 .17863 .56984 .18805 .58313 .18284 .57621 .17349 Mtetra
.668 .735 .9 r
.57621 .17349 .58313 .18284 .59648 .1777 .5896 .16839 Mtetra
.667 .737 .903 r
.5896 .16839 .59648 .1777 .6099 .1726 .60306 .16332 Mtetra
.666 .738 .904 r
.60306 .16332 .6099 .1726 .62338 .16753 .61659 .15825 Mtetra
.665 .739 .905 r
.61659 .15825 .62338 .16753 .63693 .16248 .63018 .15319 Mtetra
.665 .74 .906 r
.63018 .15319 .63693 .16248 .65054 .15744 .64384 .14812 Mtetra
.664 .74 .907 r
.64384 .14812 .65054 .15744 .66422 .15238 .65757 .14304 Mtetra
.664 .741 .907 r
.65757 .14304 .66422 .15238 .67796 .14732 .67136 .13794 Mtetra
.67136 .13794 .67796 .14732 .69178 .14224 .68522 .13283 Mtetra
.664 .741 .908 r
.68522 .13283 .69178 .14224 .70566 .13715 .69915 .12769 Mtetra
.69915 .12769 .70566 .13715 .71961 .13203 .71315 .12253 Mtetra
.71315 .12253 .71961 .13203 .73363 .12689 .72722 .11734 Mtetra
.72722 .11734 .73363 .12689 .74772 .12173 .74135 .11214 Mtetra
.74135 .11214 .74772 .12173 .76188 .11654 .75556 .1069 Mtetra
0 .437 .777 r
.11138 .35163 .12018 .35559 .13071 .35798 .12182 .35489 Mtetra
.374 0 0 r
.12182 .35489 .13071 .35798 .14112 .36216 .13216 .35979 Mtetra
.527 0 0 r
.13216 .35979 .14112 .36216 .15143 .36814 .14244 .36615 Mtetra
.595 .023 0 r
.14244 .36615 .15143 .36814 .16168 .37568 .15272 .3735 Mtetra
.601 .03 0 r
.15272 .3735 .16168 .37568 .17195 .38428 .16311 .38115 Mtetra
.527 0 0 r
.16311 .38115 .17195 .38428 .18233 .39315 .17369 .38818 Mtetra
0 .29 .686 r
.17369 .38818 .18233 .39315 .19293 .40127 .18458 .39357 Mtetra
.217 .556 .934 r
.18458 .39357 .19293 .40127 .20385 .40754 .19586 .39638 Mtetra
.52 .616 .888 r
.19586 .39638 .20385 .40754 .21518 .41095 .20757 .39591 Mtetra
.631 .599 .8 r
.20757 .39591 .21518 .41095 .22696 .41074 .2197 .3918 Mtetra
.674 .58 .742 r
.2197 .3918 .22696 .41074 .23916 .40655 .23222 .38416 Mtetra
.693 .566 .707 r
.23222 .38416 .23916 .40655 .25176 .39852 .24503 .37348 Mtetra
.702 .557 .688 r
.24503 .37348 .25176 .39852 .26464 .38722 .25804 .36055 Mtetra
.705 .552 .678 r
.25804 .36055 .26464 .38722 .27772 .37349 .27114 .34629 Mtetra
.706 .55 .674 r
.27114 .34629 .27772 .37349 .29088 .35837 .28426 .33161 Mtetra
.706 .552 .677 r
.28426 .33161 .29088 .35837 .30405 .3428 .29734 .31725 Mtetra
.704 .556 .683 r
.29734 .31725 .30405 .3428 .31717 .32759 .31034 .30373 Mtetra
.702 .563 .694 r
.31034 .30373 .31717 .32759 .33021 .31328 .32325 .29134 Mtetra
.7 .572 .708 r
.32325 .29134 .33021 .31328 .34316 .30018 .33608 .28017 Mtetra
.698 .584 .725 r
.33608 .28017 .34316 .30018 .35602 .28835 .34885 .27013 Mtetra
.696 .598 .743 r
.34885 .27013 .35602 .28835 .36883 .27773 .36159 .26109 Mtetra
.694 .613 .761 r
.36159 .26109 .36883 .27773 .3816 .26816 .37431 .25285 Mtetra
.693 .627 .779 r
.37431 .25285 .3816 .26816 .39435 .25945 .38702 .24523 Mtetra
.691 .642 .795 r
.38702 .24523 .39435 .25945 .4071 .25142 .39976 .2381 Mtetra
.69 .655 .81 r
.39976 .2381 .4071 .25142 .41986 .24391 .41251 .23134 Mtetra
.689 .667 .823 r
.41251 .23134 .41986 .24391 .43264 .23682 .4253 .22487 Mtetra
.687 .678 .835 r
.4253 .22487 .43264 .23682 .44545 .23006 .43813 .21864 Mtetra
.686 .688 .846 r
.43813 .21864 .44545 .23006 .4583 .2236 .451 .21262 Mtetra
.684 .697 .856 r
.451 .21262 .4583 .2236 .4712 .21738 .46392 .20677 Mtetra
.681 .705 .865 r
.46392 .20677 .4712 .21738 .48413 .21138 .47688 .20109 Mtetra
.679 .712 .873 r
.47688 .20109 .48413 .21138 .49712 .20557 .4899 .19555 Mtetra
.677 .718 .88 r
.4899 .19555 .49712 .20557 .51015 .19994 .50297 .19013 Mtetra
.674 .723 .886 r
.50297 .19013 .51015 .19994 .52325 .19445 .5161 .18481 Mtetra
.672 .727 .891 r
.5161 .18481 .52325 .19445 .5364 .18909 .52929 .17958 Mtetra
.67 .731 .895 r
.52929 .17958 .5364 .18909 .5496 .18382 .54254 .1744 Mtetra
.669 .734 .899 r
.54254 .1744 .5496 .18382 .56287 .17863 .55585 .16927 Mtetra
.667 .736 .901 r
.55585 .16927 .56287 .17863 .57621 .17349 .56923 .16417 Mtetra
.666 .737 .903 r
.56923 .16417 .57621 .17349 .5896 .16839 .58267 .15908 Mtetra
.665 .738 .904 r
.58267 .15908 .5896 .16839 .60306 .16332 .59617 .154 Mtetra
.665 .739 .906 r
.59617 .154 .60306 .16332 .61659 .15825 .60974 .14893 Mtetra
.664 .74 .906 r
.60974 .14893 .61659 .15825 .63018 .15319 .62338 .14384 Mtetra
.664 .74 .907 r
.62338 .14384 .63018 .15319 .64384 .14812 .63709 .13874 Mtetra
.664 .741 .907 r
.63709 .13874 .64384 .14812 .65757 .14304 .65086 .13362 Mtetra
.65086 .13362 .65757 .14304 .67136 .13794 .6647 .12848 Mtetra
.664 .741 .908 r
.6647 .12848 .67136 .13794 .68522 .13283 .6786 .12333 Mtetra
.6786 .12333 .68522 .13283 .69915 .12769 .69258 .11814 Mtetra
.69258 .11814 .69915 .12769 .71315 .12253 .70663 .11294 Mtetra
.70663 .11294 .71315 .12253 .72722 .11734 .72074 .10771 Mtetra
.72074 .10771 .72722 .11734 .74135 .11214 .73493 .10245 Mtetra
.73493 .10245 .74135 .11214 .75556 .1069 .74918 .09717 Mtetra
0 .36 .7 r
.10246 .34787 .11138 .35163 .12182 .35489 .11284 .35173 Mtetra
.4 0 0 r
.11284 .35173 .12182 .35489 .13216 .35979 .12316 .35692 Mtetra
.491 0 0 r
.12316 .35692 .13216 .35979 .14244 .36615 .13347 .36305 Mtetra
.499 0 0 r
.13347 .36305 .14244 .36615 .15272 .3735 .14387 .36949 Mtetra
.401 0 0 r
.14387 .36949 .15272 .3735 .16311 .38115 .15446 .37541 Mtetra
0 .397 .802 r
.15446 .37541 .16311 .38115 .17369 .38818 .16533 .37991 Mtetra
.293 .582 .941 r
.16533 .37991 .17369 .38818 .18458 .39357 .17657 .38211 Mtetra
.532 .615 .881 r
.17657 .38211 .18458 .39357 .19586 .39638 .18822 .38136 Mtetra
.629 .599 .801 r
.18822 .38136 .19586 .39638 .20757 .39591 .20028 .37733 Mtetra
.67 .581 .746 r
.20028 .37733 .20757 .39591 .2197 .3918 .21271 .37008 Mtetra
.689 .568 .713 r
.21271 .37008 .2197 .3918 .23222 .38416 .22544 .36003 Mtetra
.699 .56 .694 r
.22544 .36003 .23222 .38416 .24503 .37348 .23837 .34791 Mtetra
.703 .555 .684 r
.23837 .34791 .24503 .37348 .25804 .36055 .2514 .33454 Mtetra
.704 .554 .681 r
.2514 .33454 .25804 .36055 .27114 .34629 .26446 .32075 Mtetra
.704 .556 .683 r
.26446 .32075 .27114 .34629 .28426 .33161 .27748 .30725 Mtetra
.703 .561 .691 r
.27748 .30725 .28426 .33161 .29734 .31725 .29043 .29453 Mtetra
.701 .568 .702 r
.29043 .29453 .29734 .31725 .31034 .30373 .3033 .28285 Mtetra
.699 .579 .717 r
.3033 .28285 .31034 .30373 .32325 .29134 .31609 .2723 Mtetra
.697 .591 .734 r
.31609 .2723 .32325 .29134 .33608 .28017 .32883 .26281 Mtetra
.694 .606 .753 r
.32883 .26281 .33608 .28017 .34885 .27013 .34152 .25426 Mtetra
.692 .621 .772 r
.34152 .25426 .34885 .27013 .36159 .26109 .35421 .24645 Mtetra
.69 .635 .789 r
.35421 .24645 .36159 .26109 .37431 .25285 .36689 .23921 Mtetra
.689 .649 .806 r
.36689 .23921 .37431 .25285 .38702 .24523 .37959 .23242 Mtetra
.687 .662 .82 r
.37959 .23242 .38702 .24523 .39976 .2381 .39232 .22595 Mtetra
.686 .674 .832 r
.39232 .22595 .39976 .2381 .41251 .23134 .40508 .21974 Mtetra
.684 .684 .844 r
.40508 .21974 .41251 .23134 .4253 .22487 .41788 .21372 Mtetra
.683 .693 .853 r
.41788 .21372 .4253 .22487 .43813 .21864 .43073 .20788 Mtetra
.681 .701 .862 r
.43073 .20788 .43813 .21864 .451 .21262 .44362 .20218 Mtetra
.679 .708 .87 r
.44362 .20218 .451 .21262 .46392 .20677 .45657 .19662 Mtetra
.677 .715 .877 r
.45657 .19662 .46392 .20677 .47688 .20109 .46956 .19116 Mtetra
.675 .72 .883 r
.46956 .19116 .47688 .20109 .4899 .19555 .48262 .1858 Mtetra
.673 .725 .889 r
.48262 .1858 .4899 .19555 .50297 .19013 .49573 .18053 Mtetra
.671 .729 .893 r
.49573 .18053 .50297 .19013 .5161 .18481 .50889 .17531 Mtetra
.669 .732 .897 r
.50889 .17531 .5161 .18481 .52929 .17958 .52212 .17015 Mtetra
.668 .734 .899 r
.52212 .17015 .52929 .17958 .54254 .1744 .53541 .16502 Mtetra
.667 .736 .902 r
.53541 .16502 .54254 .1744 .55585 .16927 .54877 .15992 Mtetra
.666 .738 .903 r
.54877 .15992 .55585 .16927 .56923 .16417 .56219 .15483 Mtetra
.665 .739 .905 r
.56219 .15483 .56923 .16417 .58267 .15908 .57567 .14974 Mtetra
.665 .74 .906 r
.57567 .14974 .58267 .15908 .59617 .154 .58922 .14464 Mtetra
.664 .74 .906 r
.58922 .14464 .59617 .154 .60974 .14893 .60284 .13954 Mtetra
.664 .74 .907 r
.60284 .13954 .60974 .14893 .62338 .14384 .61652 .13442 Mtetra
.664 .741 .907 r
.61652 .13442 .62338 .14384 .63709 .13874 .63027 .12928 Mtetra
.63027 .12928 .63709 .13874 .65086 .13362 .64409 .12413 Mtetra
.664 .741 .908 r
.64409 .12413 .65086 .13362 .6647 .12848 .65797 .11895 Mtetra
.65797 .11895 .6647 .12848 .6786 .12333 .67193 .11374 Mtetra
.67193 .11374 .6786 .12333 .69258 .11814 .68595 .10852 Mtetra
.68595 .10852 .69258 .11814 .70663 .11294 .70004 .10326 Mtetra
.70004 .10326 .70663 .11294 .72074 .10771 .71421 .09798 Mtetra
.71421 .09798 .72074 .10771 .73493 .10245 .72844 .09268 Mtetra
.72844 .09268 .73493 .10245 .74918 .09717 .74275 .08735 Mtetra
0 .342 .687 r
.09346 .34398 .10246 .34787 .11284 .35173 .10382 .34805 Mtetra
.343 0 0 r
.10382 .34805 .11284 .35173 .12316 .35692 .11418 .35299 Mtetra
.354 0 0 r
.11418 .35299 .12316 .35692 .13347 .36305 .12461 .35824 Mtetra
0 .318 .702 r
.12461 .35824 .13347 .36305 .14387 .36949 .13522 .36307 Mtetra
.036 .485 .882 r
.13522 .36307 .14387 .36949 .15446 .37541 .14608 .36667 Mtetra
.354 .601 .94 r
.14608 .36667 .15446 .37541 .16533 .37991 .15729 .36826 Mtetra
.543 .616 .876 r
.15729 .36826 .16533 .37991 .17657 .38211 .16888 .36723 Mtetra
.627 .6 .803 r
.16888 .36723 .17657 .38211 .18822 .38136 .18087 .36326 Mtetra
.667 .583 .752 r
.18087 .36326 .18822 .38136 .20028 .37733 .19322 .35638 Mtetra
.686 .571 .72 r
.19322 .35638 .20028 .37733 .21271 .37008 .20586 .34697 Mtetra
.696 .563 .701 r
.20586 .34697 .21271 .37008 .22544 .36003 .2187 .33565 Mtetra
.7 .559 .691 r
.2187 .33565 .22544 .36003 .23837 .34791 .23165 .32317 Mtetra
.702 .559 .689 r
.23165 .32317 .23837 .34791 .2514 .33454 .24464 .31029 Mtetra
.703 .561 .692 r
.24464 .31029 .2514 .33454 .26446 .32075 .25759 .29765 Mtetra
.702 .567 .699 r
.25759 .29765 .26446 .32075 .27748 .30725 .27049 .2857 Mtetra
.7 .575 .711 r
.27049 .2857 .27748 .30725 .29043 .29453 .2833 .27471 Mtetra
.698 .586 .727 r
.2833 .27471 .29043 .29453 .3033 .28285 .29605 .26476 Mtetra
.695 .599 .745 r
.29605 .26476 .3033 .28285 .31609 .2723 .30874 .2558 Mtetra
.693 .614 .764 r
.30874 .2558 .31609 .2723 .32883 .26281 .3214 .24769 Mtetra
.69 .629 .783 r
.3214 .24769 .32883 .26281 .34152 .25426 .33405 .24027 Mtetra
.688 .644 .8 r
.33405 .24027 .34152 .25426 .35421 .24645 .34669 .23338 Mtetra
.686 .658 .816 r
.34669 .23338 .35421 .24645 .36689 .23921 .35936 .22688 Mtetra
.685 .67 .83 r
.35936 .22688 .36689 .23921 .37959 .23242 .37206 .22068 Mtetra
.683 .681 .841 r
.37206 .22068 .37959 .23242 .39232 .22595 .38479 .21469 Mtetra
.682 .69 .852 r
.38479 .21469 .39232 .22595 .40508 .21974 .39757 .20886 Mtetra
.68 .698 .86 r
.39757 .20886 .40508 .21974 .41788 .21372 .41039 .20318 Mtetra
.679 .706 .868 r
.41039 .20318 .41788 .21372 .43073 .20788 .42326 .19761 Mtetra
.677 .712 .875 r
.42326 .19761 .43073 .20788 .44362 .20218 .43618 .19215 Mtetra
.675 .718 .881 r
.43618 .19215 .44362 .20218 .45657 .19662 .44915 .18677 Mtetra
.673 .722 .886 r
.44915 .18677 .45657 .19662 .46956 .19116 .46218 .18147 Mtetra
.672 .727 .891 r
.46218 .18147 .46956 .19116 .48262 .1858 .47527 .17623 Mtetra
.67 .73 .895 r
.47527 .17623 .48262 .1858 .49573 .18053 .48842 .17104 Mtetra
.669 .733 .898 r
.48842 .17104 .49573 .18053 .50889 .17531 .50162 .16589 Mtetra
.667 .735 .9 r
.50162 .16589 .50889 .17531 .52212 .17015 .51489 .16077 Mtetra
.666 .737 .902 r
.51489 .16077 .52212 .17015 .53541 .16502 .52823 .15566 Mtetra
.666 .738 .904 r
.52823 .15566 .53541 .16502 .54877 .15992 .54162 .15056 Mtetra
.665 .739 .905 r
.54162 .15056 .54877 .15992 .56219 .15483 .55508 .14545 Mtetra
.665 .74 .906 r
.55508 .14545 .56219 .15483 .57567 .14974 .56861 .14034 Mtetra
.664 .74 .907 r
.56861 .14034 .57567 .14974 .58922 .14464 .58221 .13522 Mtetra
.664 .741 .907 r
.58221 .13522 .58922 .14464 .60284 .13954 .59587 .13008 Mtetra
.59587 .13008 .60284 .13954 .61652 .13442 .60959 .12493 Mtetra
.664 .741 .908 r
.60959 .12493 .61652 .13442 .63027 .12928 .62339 .11975 Mtetra
.62339 .11975 .63027 .12928 .64409 .12413 .63725 .11455 Mtetra
.63725 .11455 .64409 .12413 .65797 .11895 .65119 .10932 Mtetra
.65119 .10932 .65797 .11895 .67193 .11374 .66519 .10407 Mtetra
.66519 .10407 .67193 .11374 .68595 .10852 .67926 .0988 Mtetra
.67926 .0988 .68595 .10852 .70004 .10326 .6934 .0935 Mtetra
.6934 .0935 .70004 .10326 .71421 .09798 .70762 .08817 Mtetra
.70762 .08817 .71421 .09798 .72844 .09268 .7219 .08282 Mtetra
.7219 .08282 .72844 .09268 .74275 .08735 .73626 .07744 Mtetra
0 .394 .753 r
.08442 .33956 .09346 .34398 .10382 .34805 .09483 .34335 Mtetra
0 .377 .748 r
.09483 .34335 .10382 .34805 .11418 .35299 .10531 .34746 Mtetra
0 .442 .829 r
.10531 .34746 .11418 .35299 .12461 .35824 .11594 .35123 Mtetra
.166 .551 .929 r
.11594 .35123 .12461 .35824 .13522 .36307 .12681 .35396 Mtetra
.405 .616 .936 r
.12681 .35396 .13522 .36307 .14608 .36667 .13799 .35494 Mtetra
.553 .62 .873 r
.13799 .35494 .14608 .36667 .15729 .36826 .14954 .35361 Mtetra
.627 .603 .807 r
.14954 .35361 .15729 .36826 .16888 .36723 .16145 .34969 Mtetra
.664 .587 .759 r
.16145 .34969 .16888 .36723 .18087 .36326 .17372 .34317 Mtetra
.683 .575 .728 r
.17372 .34317 .18087 .36326 .19322 .35638 .18626 .33437 Mtetra
.693 .568 .71 r
.18626 .33437 .19322 .35638 .20586 .34697 .19901 .32383 Mtetra
.698 .565 .7 r
.19901 .32383 .20586 .34697 .2187 .33565 .21188 .31223 Mtetra
.701 .564 .698 r
.21188 .31223 .2187 .33565 .23165 .32317 .22478 .30025 Mtetra
.701 .567 .701 r
.22478 .30025 .23165 .32317 .24464 .31029 .23766 .28845 Mtetra
.7 .573 .709 r
.23766 .28845 .24464 .31029 .25759 .29765 .25049 .27727 Mtetra
.699 .582 .721 r
.25049 .27727 .25759 .29765 .27049 .2857 .26325 .26695 Mtetra
.697 .594 .737 r
.26325 .26695 .27049 .2857 .2833 .27471 .27595 .25757 Mtetra
.694 .608 .756 r
.27595 .25757 .2833 .27471 .29605 .26476 .2886 .24909 Mtetra
.692 .623 .775 r
.2886 .24909 .29605 .26476 .30874 .2558 .30121 .24139 Mtetra
.689 .638 .794 r
.30121 .24139 .30874 .2558 .3214 .24769 .31382 .23432 Mtetra
.686 .653 .811 r
.31382 .23432 .3214 .24769 .33405 .24027 .32643 .22774 Mtetra
.684 .666 .826 r
.32643 .22774 .33405 .24027 .34669 .23338 .33906 .2215 Mtetra
.682 .678 .839 r
.33906 .2215 .34669 .23338 .35936 .22688 .35172 .21552 Mtetra
.681 .688 .85 r
.35172 .21552 .35936 .22688 .37206 .22068 .36443 .20973 Mtetra
.679 .696 .859 r
.36443 .20973 .37206 .22068 .38479 .21469 .37717 .20407 Mtetra
.678 .704 .867 r
.37717 .20407 .38479 .21469 .39757 .20886 .38997 .19852 Mtetra
.676 .71 .874 r
.38997 .19852 .39757 .20886 .41039 .20318 .40281 .19307 Mtetra
.675 .716 .88 r
.40281 .19307 .41039 .20318 .42326 .19761 .41571 .18769 Mtetra
.673 .721 .885 r
.41571 .18769 .42326 .19761 .43618 .19215 .42866 .18238 Mtetra
.672 .725 .889 r
.42866 .18238 .43618 .19215 .44915 .18677 .44167 .17713 Mtetra
.67 .728 .893 r
.44167 .17713 .44915 .18677 .46218 .18147 .45473 .17192 Mtetra
.669 .731 .896 r
.45473 .17192 .46218 .18147 .47527 .17623 .46786 .16675 Mtetra
.668 .734 .899 r
.46786 .16675 .47527 .17623 .48842 .17104 .48104 .16161 Mtetra
.667 .736 .901 r
.48104 .16161 .48842 .17104 .50162 .16589 .49429 .15649 Mtetra
.666 .737 .903 r
.49429 .15649 .50162 .16589 .51489 .16077 .5076 .15138 Mtetra
.665 .738 .904 r
.5076 .15138 .51489 .16077 .52823 .15566 .52097 .14627 Mtetra
.665 .739 .905 r
.52097 .14627 .52823 .15566 .54162 .15056 .53441 .14115 Mtetra
.664 .74 .906 r
.53441 .14115 .54162 .15056 .55508 .14545 .54792 .13603 Mtetra
.664 .74 .907 r
.54792 .13603 .55508 .14545 .56861 .14034 .56149 .13089 Mtetra
.664 .741 .907 r
.56149 .13089 .56861 .14034 .58221 .13522 .57513 .12573 Mtetra
.57513 .12573 .58221 .13522 .59587 .13008 .58883 .12055 Mtetra
.664 .741 .908 r
.58883 .12055 .59587 .13008 .60959 .12493 .60261 .11535 Mtetra
.60261 .11535 .60959 .12493 .62339 .11975 .61645 .11013 Mtetra
.61645 .11013 .62339 .11975 .63725 .11455 .63036 .10488 Mtetra
.63036 .10488 .63725 .11455 .65119 .10932 .64434 .09961 Mtetra
.64434 .09961 .65119 .10932 .66519 .10407 .65839 .09432 Mtetra
.65839 .09432 .66519 .10407 .67926 .0988 .67251 .08899 Mtetra
.67251 .08899 .67926 .0988 .6934 .0935 .6867 .08364 Mtetra
.6867 .08364 .6934 .0935 .70762 .08817 .70096 .07827 Mtetra
.70096 .07827 .70762 .08817 .7219 .08282 .71529 .07286 Mtetra
.71529 .07286 .7219 .08282 .73626 .07744 .7297 .06743 Mtetra
.009 .5 .869 r
.07542 .33419 .08442 .33956 .09483 .34335 .08595 .3372 Mtetra
.099 .538 .911 r
.08595 .3372 .09483 .34335 .10531 .34746 .09661 .33997 Mtetra
.273 .598 .951 r
.09661 .33997 .10531 .34746 .11594 .35123 .10749 .34185 Mtetra
.447 .629 .931 r
.10749 .34185 .11594 .35123 .12681 .35396 .11866 .34222 Mtetra
.563 .624 .871 r
.11866 .34222 .12681 .35396 .13799 .35494 .13016 .3406 Mtetra
.627 .608 .812 r
.13016 .3406 .13799 .35494 .14954 .35361 .14202 .33671 Mtetra
.661 .592 .767 r
.14202 .33671 .14954 .35361 .16145 .34969 .15419 .33052 Mtetra
.68 .581 .738 r
.15419 .33052 .16145 .34969 .17372 .34317 .16664 .32231 Mtetra
.69 .574 .72 r
.16664 .32231 .17372 .34317 .18626 .33437 .17929 .31253 Mtetra
.696 .571 .71 r
.17929 .31253 .18626 .33437 .19901 .32383 .19206 .30178 Mtetra
.699 .571 .708 r
.19206 .30178 .19901 .32383 .21188 .31223 .20487 .29065 Mtetra
.7 .575 .711 r
.20487 .29065 .21188 .31223 .22478 .30025 .21768 .27967 Mtetra
.699 .581 .72 r
.21768 .27967 .22478 .30025 .23766 .28845 .23044 .26923 Mtetra
.698 .591 .732 r
.23044 .26923 .23766 .28845 .25049 .27727 .24314 .25955 Mtetra
.696 .603 .749 r
.24314 .25955 .25049 .27727 .26325 .26695 .25578 .25071 Mtetra
.693 .617 .767 r
.25578 .25071 .26325 .26695 .27595 .25757 .26838 .24268 Mtetra
.69 .633 .786 r
.26838 .24268 .27595 .25757 .2886 .24909 .28095 .23536 Mtetra
.687 .648 .805 r
.28095 .23536 .2886 .24909 .30121 .24139 .29351 .2286 Mtetra
.684 .662 .822 r
.29351 .2286 .30121 .24139 .31382 .23432 .30609 .22228 Mtetra
.682 .675 .836 r
.30609 .22228 .31382 .23432 .32643 .22774 .31869 .21627 Mtetra
.68 .685 .848 r
.31869 .21627 .32643 .22774 .33906 .2215 .33132 .21049 Mtetra
.678 .695 .858 r
.33132 .21049 .33906 .2215 .35172 .21552 .34399 .20486 Mtetra
.677 .702 .866 r
.34399 .20486 .35172 .21552 .36443 .20973 .35671 .19934 Mtetra
.675 .709 .873 r
.35671 .19934 .36443 .20973 .37717 .20407 .36947 .19391 Mtetra
.674 .714 .879 r
.36947 .19391 .37717 .20407 .38997 .19852 .38229 .18855 Mtetra
.673 .719 .884 r
.38229 .18855 .38997 .19852 .40281 .19307 .39516 .18325 Mtetra
.672 .723 .888 r
.39516 .18325 .40281 .19307 .41571 .18769 .40809 .178 Mtetra
.67 .727 .892 r
.40809 .178 .41571 .18769 .42866 .18238 .42107 .17279 Mtetra
.669 .73 .895 r
.42107 .17279 .42866 .18238 .44167 .17713 .43411 .16761 Mtetra
.668 .733 .898 r
.43411 .16761 .44167 .17713 .45473 .17192 .44721 .16246 Mtetra
.667 .735 .9 r
.44721 .16246 .45473 .17192 .46786 .16675 .46038 .15733 Mtetra
.666 .736 .902 r
.46038 .15733 .46786 .16675 .48104 .16161 .4736 .1522 Mtetra
.666 .738 .904 r
.4736 .1522 .48104 .16161 .49429 .15649 .48689 .14708 Mtetra
.665 .739 .905 r
.48689 .14708 .49429 .15649 .5076 .15138 .50024 .14196 Mtetra
.665 .739 .906 r
.50024 .14196 .5076 .15138 .52097 .14627 .51366 .13683 Mtetra
.664 .74 .906 r
.51366 .13683 .52097 .14627 .53441 .14115 .52714 .13169 Mtetra
.664 .74 .907 r
.52714 .13169 .53441 .14115 .54792 .13603 .54069 .12653 Mtetra
.664 .741 .907 r
.54069 .12653 .54792 .13603 .56149 .13089 .5543 .12136 Mtetra
.5543 .12136 .56149 .13089 .57513 .12573 .56798 .11616 Mtetra
.664 .741 .908 r
.56798 .11616 .57513 .12573 .58883 .12055 .58173 .11094 Mtetra
.58173 .11094 .58883 .12055 .60261 .11535 .59555 .10569 Mtetra
.59555 .10569 .60261 .11535 .61645 .11013 .60944 .10043 Mtetra
.60944 .10043 .61645 .11013 .63036 .10488 .6234 .09513 Mtetra
.6234 .09513 .63036 .10488 .64434 .09961 .63743 .08981 Mtetra
.63743 .08981 .64434 .09961 .65839 .09432 .65152 .08447 Mtetra
.65152 .08447 .65839 .09432 .67251 .08899 .66569 .0791 Mtetra
.66569 .0791 .67251 .08899 .6867 .08364 .67993 .0737 Mtetra
.67993 .0737 .6867 .08364 .70096 .07827 .69424 .06827 Mtetra
.69424 .06827 .70096 .07827 .71529 .07286 .70863 .06282 Mtetra
.70863 .06282 .71529 .07286 .7297 .06743 .72309 .05734 Mtetra
.234 .604 .952 r
.06651 .32751 .07542 .33419 .08595 .3372 .07721 .32931 Mtetra
.356 .63 .957 r
.07721 .32931 .08595 .3372 .09661 .33997 .08811 .33039 Mtetra
.482 .64 .926 r
.08811 .33039 .09661 .33997 .10749 .34185 .09927 .33019 Mtetra
.572 .631 .871 r
.09927 .33019 .10749 .34185 .11866 .34222 .11074 .32827 Mtetra
.627 .614 .818 r
.11074 .32827 .11866 .34222 .13016 .3406 .12253 .32439 Mtetra
.659 .599 .777 r
.12253 .32439 .13016 .3406 .14202 .33671 .13463 .3185 Mtetra
.677 .588 .748 r
.13463 .3185 .14202 .33671 .15419 .33052 .14698 .31083 Mtetra
.688 .581 .731 r
.14698 .31083 .15419 .33052 .16664 .32231 .15953 .30177 Mtetra
.694 .578 .721 r
.15953 .30177 .16664 .32231 .17929 .31253 .17219 .29182 Mtetra
.697 .579 .719 r
.17219 .29182 .17929 .31253 .19206 .30178 .18491 .28152 Mtetra
.698 .583 .723 r
.18491 .28152 .19206 .30178 .20487 .29065 .19763 .27133 Mtetra
.698 .59 .731 r
.19763 .27133 .20487 .29065 .21768 .27967 .21032 .26159 Mtetra
.697 .6 .744 r
.21032 .26159 .21768 .27967 .23044 .26923 .22295 .25251 Mtetra
.695 .613 .761 r
.22295 .25251 .23044 .26923 .24314 .25955 .23554 .24418 Mtetra
.692 .627 .779 r
.23554 .24418 .24314 .25955 .25578 .25071 .24809 .23656 Mtetra
.689 .642 .798 r
.24809 .23656 .25578 .25071 .26838 .24268 .26061 .22958 Mtetra
.686 .657 .816 r
.26061 .22958 .26838 .24268 .28095 .23536 .27314 .2231 Mtetra
.683 .671 .832 r
.27314 .2231 .28095 .23536 .29351 .2286 .28567 .21701 Mtetra
.68 .683 .846 r
.28567 .21701 .29351 .2286 .30609 .22228 .29823 .21119 Mtetra
.678 .693 .857 r
.29823 .21119 .30609 .22228 .31869 .21627 .31083 .20557 Mtetra
.676 .701 .866 r
.31083 .20557 .31869 .21627 .33132 .21049 .32347 .20008 Mtetra
.675 .708 .873 r
.32347 .20008 .33132 .21049 .34399 .20486 .33616 .19468 Mtetra
.673 .714 .879 r
.33616 .19468 .34399 .20486 .35671 .19934 .34889 .18935 Mtetra
.672 .718 .884 r
.34889 .18935 .35671 .19934 .36947 .19391 .36169 .18407 Mtetra
.671 .722 .888 r
.36169 .18407 .36947 .19391 .38229 .18855 .37453 .17883 Mtetra
.67 .726 .891 r
.37453 .17883 .38229 .18855 .39516 .18325 .38743 .17362 Mtetra
.669 .729 .895 r
.38743 .17362 .39516 .18325 .40809 .178 .40039 .16845 Mtetra
.668 .732 .897 r
.40039 .16845 .40809 .178 .42107 .17279 .41341 .16329 Mtetra
.667 .734 .9 r
.41341 .16329 .42107 .17279 .43411 .16761 .42649 .15815 Mtetra
.667 .736 .901 r
.42649 .15815 .43411 .16761 .44721 .16246 .43962 .15303 Mtetra
.666 .737 .903 r
.43962 .15303 .44721 .16246 .46038 .15733 .45283 .1479 Mtetra
.665 .738 .904 r
.45283 .1479 .46038 .15733 .4736 .1522 .46609 .14277 Mtetra
.665 .739 .905 r
.46609 .14277 .4736 .1522 .48689 .14708 .47942 .13764 Mtetra
.664 .74 .906 r
.47942 .13764 .48689 .14708 .50024 .14196 .49281 .1325 Mtetra
.664 .74 .907 r
.49281 .1325 .50024 .14196 .51366 .13683 .50627 .12734 Mtetra
.50627 .12734 .51366 .13683 .52714 .13169 .5198 .12216 Mtetra
.664 .741 .907 r
.5198 .12216 .52714 .13169 .54069 .12653 .53339 .11696 Mtetra
.53339 .11696 .54069 .12653 .5543 .12136 .54705 .11175 Mtetra
.664 .741 .908 r
.54705 .11175 .5543 .12136 .56798 .11616 .56078 .10651 Mtetra
.56078 .10651 .56798 .11616 .58173 .11094 .57457 .10124 Mtetra
.57457 .10124 .58173 .11094 .59555 .10569 .58844 .09595 Mtetra
.58844 .09595 .59555 .10569 .60944 .10043 .60237 .09063 Mtetra
.60237 .09063 .60944 .10043 .6234 .09513 .61637 .08529 Mtetra
.61637 .08529 .6234 .09513 .63743 .08981 .63045 .07992 Mtetra
.63045 .07992 .63743 .08981 .65152 .08447 .64459 .07453 Mtetra
.64459 .07453 .65152 .08447 .66569 .0791 .65881 .06911 Mtetra
.65881 .06911 .66569 .0791 .67993 .0737 .6731 .06366 Mtetra
.6731 .06366 .67993 .0737 .69424 .06827 .68746 .05818 Mtetra
.68746 .05818 .69424 .06827 .70863 .06282 .7019 .05267 Mtetra
.7019 .05267 .70863 .06282 .72309 .05734 .71641 .04714 Mtetra
.421 .653 .955 r
.05773 .31931 .06651 .32751 .07721 .32931 .06866 .31962 Mtetra
.511 .651 .921 r
.06866 .31962 .07721 .32931 .08811 .33039 .07982 .31887 Mtetra
.582 .638 .872 r
.07982 .31887 .08811 .33039 .09927 .33019 .09125 .31667 Mtetra
.629 .622 .825 r
.09125 .31667 .09927 .33019 .11074 .32827 .10299 .31277 Mtetra
.657 .607 .787 r
.10299 .31277 .11074 .32827 .12253 .32439 .115 .30716 Mtetra
.675 .596 .76 r
.115 .30716 .12253 .32439 .13463 .3185 .12726 .29998 Mtetra
.686 .59 .743 r
.12726 .29998 .13463 .3185 .14698 .31083 .1397 .29158 Mtetra
.692 .587 .734 r
.1397 .29158 .14698 .31083 .15953 .30177 .15226 .28239 Mtetra
.695 .588 .732 r
.15226 .28239 .15953 .30177 .17219 .29182 .16488 .27286 Mtetra
.697 .592 .735 r
.16488 .27286 .17219 .29182 .18491 .28152 .17751 .2634 Mtetra
.697 .6 .744 r
.17751 .2634 .18491 .28152 .19763 .27133 .19012 .25432 Mtetra
.696 .61 .757 r
.19012 .25432 .19763 .27133 .21032 .26159 .20269 .24581 Mtetra
.693 .623 .773 r
.20269 .24581 .21032 .26159 .22295 .25251 .21522 .23795 Mtetra
.691 .637 .791 r
.21522 .23795 .22295 .25251 .23554 .24418 .22771 .23071 Mtetra
.687 .652 .81 r
.22771 .23071 .23554 .24418 .24809 .23656 .24019 .22403 Mtetra
.684 .667 .827 r
.24019 .22403 .24809 .23656 .26061 .22958 .25268 .2178 Mtetra
.681 .68 .842 r
.25268 .2178 .26061 .22958 .27314 .2231 .26517 .2119 Mtetra
.678 .691 .855 r
.26517 .2119 .27314 .2231 .28567 .21701 .2777 .20625 Mtetra
.676 .7 .865 r
.2777 .20625 .28567 .21701 .29823 .21119 .29026 .20076 Mtetra
.674 .707 .873 r
.29026 .20076 .29823 .21119 .31083 .20557 .30287 .19539 Mtetra
.673 .713 .879 r
.30287 .19539 .31083 .20557 .32347 .20008 .31553 .19008 Mtetra
.672 .718 .884 r
.31553 .19008 .32347 .20008 .33616 .19468 .32824 .18483 Mtetra
.671 .722 .888 r
.32824 .18483 .33616 .19468 .34889 .18935 .341 .17962 Mtetra
.67 .725 .891 r
.341 .17962 .34889 .18935 .36169 .18407 .35382 .17443 Mtetra
.669 .728 .894 r
.35382 .17443 .36169 .18407 .37453 .17883 .36669 .16926 Mtetra
.668 .731 .897 r
.36669 .16926 .37453 .17883 .38743 .17362 .37963 .16411 Mtetra
.667 .733 .899 r
.37963 .16411 .38743 .17362 .40039 .16845 .39262 .15897 Mtetra
.667 .735 .901 r
.39262 .15897 .40039 .16845 .41341 .16329 .40567 .15384 Mtetra
.666 .736 .903 r
.40567 .15384 .41341 .16329 .42649 .15815 .41879 .14871 Mtetra
.665 .738 .904 r
.41879 .14871 .42649 .15815 .43962 .15303 .43197 .14358 Mtetra
.665 .739 .905 r
.43197 .14358 .43962 .15303 .45283 .1479 .44521 .13845 Mtetra
.665 .739 .906 r
.44521 .13845 .45283 .1479 .46609 .14277 .45851 .1333 Mtetra
.664 .74 .906 r
.45851 .1333 .46609 .14277 .47942 .13764 .47188 .12814 Mtetra
.664 .74 .907 r
.47188 .12814 .47942 .13764 .49281 .1325 .48532 .12297 Mtetra
.664 .741 .907 r
.48532 .12297 .49281 .1325 .50627 .12734 .49882 .11777 Mtetra
.49882 .11777 .50627 .12734 .5198 .12216 .51239 .11255 Mtetra
.664 .741 .908 r
.51239 .11255 .5198 .12216 .53339 .11696 .52603 .10732 Mtetra
.52603 .10732 .53339 .11696 .54705 .11175 .53973 .10205 Mtetra
.53973 .10205 .54705 .11175 .56078 .10651 .5535 .09677 Mtetra
.5535 .09677 .56078 .10651 .57457 .10124 .56734 .09146 Mtetra
.56734 .09146 .57457 .10124 .58844 .09595 .58125 .08612 Mtetra
.58125 .08612 .58844 .09595 .60237 .09063 .59523 .08075 Mtetra
.59523 .08075 .60237 .09063 .61637 .08529 .60929 .07536 Mtetra
.60929 .07536 .61637 .08529 .63045 .07992 .62341 .06994 Mtetra
.62341 .06994 .63045 .07992 .64459 .07453 .6376 .0645 Mtetra
.6376 .0645 .64459 .07453 .65881 .06911 .65187 .05902 Mtetra
.65187 .05902 .65881 .06911 .6731 .06366 .66621 .05352 Mtetra
.66621 .05352 .6731 .06366 .68746 .05818 .68062 .04799 Mtetra
.68062 .04799 .68746 .05818 .7019 .05267 .6951 .04244 Mtetra
.6951 .04244 .7019 .05267 .71641 .04714 .70966 .03685 Mtetra
.536 .661 .916 r
.0491 .30957 .05773 .31931 .06866 .31962 .06027 .30831 Mtetra
.591 .646 .874 r
.06027 .30831 .06866 .31962 .07982 .31887 .07168 .30582 Mtetra
.63 .63 .832 r
.07168 .30582 .07982 .31887 .09125 .31667 .08336 .3019 Mtetra
.656 .616 .797 r
.08336 .3019 .09125 .31667 .10299 .31277 .0953 .29651 Mtetra
.673 .606 .772 r
.0953 .29651 .10299 .31277 .115 .30716 .10746 .28978 Mtetra
.683 .599 .756 r
.10746 .28978 .115 .30716 .12726 .29998 .1198 .28198 Mtetra
.69 .597 .747 r
.1198 .28198 .12726 .29998 .1397 .29158 .13226 .27348 Mtetra
.693 .598 .745 r
.13226 .27348 .1397 .29158 .15226 .28239 .14478 .26466 Mtetra
.695 .603 .749 r
.14478 .26466 .15226 .28239 .16488 .27286 .15732 .25588 Mtetra
.695 .61 .758 r
.15732 .25588 .16488 .27286 .17751 .2634 .16985 .24742 Mtetra
.694 .621 .77 r
.16985 .24742 .17751 .2634 .19012 .25432 .18235 .23943 Mtetra
.692 .634 .786 r
.18235 .23943 .19012 .25432 .20269 .24581 .19481 .232 Mtetra
.689 .648 .804 r
.19481 .232 .20269 .24581 .21522 .23795 .20726 .22511 Mtetra
.686 .662 .821 r
.20726 .22511 .21522 .23795 .22771 .23071 .21969 .2187 Mtetra
.682 .676 .837 r
.21969 .2187 .22771 .23071 .24019 .22403 .23213 .21268 Mtetra
.679 .688 .851 r
.23213 .21268 .24019 .22403 .25268 .2178 .24459 .20695 Mtetra
.676 .698 .863 r
.24459 .20695 .25268 .2178 .26517 .2119 .25708 .20144 Mtetra
.674 .706 .872 r
.25708 .20144 .26517 .2119 .2777 .20625 .26961 .19606 Mtetra
.672 .713 .879 r
.26961 .19606 .2777 .20625 .29026 .20076 .28219 .19078 Mtetra
.671 .718 .884 r
.28219 .19078 .29026 .20076 .30287 .19539 .29482 .18555 Mtetra
.67 .722 .888 r
.29482 .18555 .30287 .19539 .31553 .19008 .3075 .18036 Mtetra
.669 .725 .891 r
.3075 .18036 .31553 .19008 .32824 .18483 .32023 .17519 Mtetra
.668 .728 .894 r
.32023 .17519 .32824 .18483 .341 .17962 .33302 .17004 Mtetra
.668 .731 .897 r
.33302 .17004 .341 .17962 .35382 .17443 .34587 .1649 Mtetra
.667 .733 .899 r
.34587 .1649 .35382 .17443 .36669 .16926 .35878 .15977 Mtetra
.667 .734 .901 r
.35878 .15977 .36669 .16926 .37963 .16411 .37175 .15465 Mtetra
.666 .736 .902 r
.37175 .15465 .37963 .16411 .39262 .15897 .38478 .14952 Mtetra
.665 .737 .903 r
.38478 .14952 .39262 .15897 .40567 .15384 .39787 .14439 Mtetra
.665 .738 .904 r
.39787 .14439 .40567 .15384 .41879 .14871 .41102 .13925 Mtetra
.665 .739 .905 r
.41102 .13925 .41879 .14871 .43197 .14358 .42424 .13411 Mtetra
.664 .74 .906 r
.42424 .13411 .43197 .14358 .44521 .13845 .43752 .12895 Mtetra
.664 .74 .907 r
.43752 .12895 .44521 .13845 .45851 .1333 .45087 .12377 Mtetra
.45087 .12377 .45851 .1333 .47188 .12814 .46428 .11858 Mtetra
.664 .741 .907 r
.46428 .11858 .47188 .12814 .48532 .12297 .47776 .11336 Mtetra
.47776 .11336 .48532 .12297 .49882 .11777 .4913 .10813 Mtetra
.664 .741 .908 r
.4913 .10813 .49882 .11777 .51239 .11255 .50491 .10287 Mtetra
.50491 .10287 .51239 .11255 .52603 .10732 .51859 .09758 Mtetra
.51859 .09758 .52603 .10732 .53973 .10205 .53234 .09228 Mtetra
.53234 .09228 .53973 .10205 .5535 .09677 .54616 .08694 Mtetra
.54616 .08694 .5535 .09677 .56734 .09146 .56005 .08158 Mtetra
.56005 .08158 .56734 .09146 .58125 .08612 .574 .07619 Mtetra
.574 .07619 .58125 .08612 .59523 .08075 .58803 .07078 Mtetra
.58803 .07078 .59523 .08075 .60929 .07536 .60213 .06534 Mtetra
.60213 .06534 .60929 .07536 .62341 .06994 .6163 .05987 Mtetra
.6163 .05987 .62341 .06994 .6376 .0645 .63054 .05437 Mtetra
.63054 .05437 .6376 .0645 .65187 .05902 .64486 .04885 Mtetra
.64486 .04885 .65187 .05902 .66621 .05352 .65925 .04329 Mtetra
.65925 .04329 .66621 .05352 .68062 .04799 .67371 .03771 Mtetra
.67371 .03771 .68062 .04799 .6951 .04244 .68825 .0321 Mtetra
.68825 .0321 .6951 .04244 .70966 .03685 .70286 .02646 Mtetra
.6 .655 .876 r
.04061 .29849 .0491 .30957 .06027 .30831 .052 .29573 Mtetra
.632 .64 .84 r
.052 .29573 .06027 .30831 .07168 .30582 .06363 .29178 Mtetra
.656 .627 .809 r
.06363 .29178 .07168 .30582 .08336 .3019 .0755 .28658 Mtetra
.671 .616 .785 r
.0755 .28658 .08336 .3019 .0953 .29651 .08757 .28024 Mtetra
.681 .61 .77 r
.08757 .28024 .0953 .29651 .10746 .28978 .09982 .27297 Mtetra
.688 .608 .761 r
.09982 .27297 .10746 .28978 .1198 .28198 .11217 .26509 Mtetra
.691 .609 .759 r
.11217 .26509 .1198 .28198 .13226 .27348 .12459 .25692 Mtetra
.693 .614 .763 r
.12459 .25692 .13226 .27348 .14478 .26466 .13704 .24877 Mtetra
.693 .622 .772 r
.13704 .24877 .14478 .26466 .15732 .25588 .14949 .24086 Mtetra
.692 .632 .784 r
.14949 .24086 .15732 .25588 .16985 .24742 .16192 .23335 Mtetra
.69 .645 .799 r
.16192 .23335 .16985 .24742 .18235 .23943 .17432 .22631 Mtetra
.687 .658 .816 r
.17432 .22631 .18235 .23943 .19481 .232 .18672 .21973 Mtetra
.684 .672 .832 r
.18672 .21973 .19481 .232 .20726 .22511 .19911 .21356 Mtetra
.68 .684 .847 r
.19911 .21356 .20726 .22511 .21969 .2187 .21151 .20772 Mtetra
.677 .696 .86 r
.21151 .20772 .21969 .2187 .23213 .21268 .22393 .20214 Mtetra
.674 .705 .87 r
.22393 .20214 .23213 .21268 .24459 .20695 .23638 .19673 Mtetra
.672 .712 .878 r
.23638 .19673 .24459 .20695 .25708 .20144 .24888 .19145 Mtetra
.671 .718 .884 r
.24888 .19145 .25708 .20144 .26961 .19606 .26143 .18624 Mtetra
.669 .722 .888 r
.26143 .18624 .26961 .19606 .28219 .19078 .27402 .18107 Mtetra
.669 .725 .892 r
.27402 .18107 .28219 .19078 .29482 .18555 .28667 .17592 Mtetra
.668 .728 .895 r
.28667 .17592 .29482 .18555 .3075 .18036 .29938 .1708 Mtetra
.667 .731 .897 r
.29938 .1708 .3075 .18036 .32023 .17519 .31214 .16567 Mtetra
.667 .733 .899 r
.31214 .16567 .32023 .17519 .33302 .17004 .32497 .16056 Mtetra
.666 .734 .901 r
.32497 .16056 .33302 .17004 .34587 .1649 .33785 .15544 Mtetra
.666 .736 .902 r
.33785 .15544 .34587 .1649 .35878 .15977 .35079 .15032 Mtetra
.665 .737 .903 r
.35079 .15032 .35878 .15977 .37175 .15465 .3638 .14519 Mtetra
.665 .738 .904 r
.3638 .14519 .37175 .15465 .38478 .14952 .37686 .14005 Mtetra
.665 .739 .905 r
.37686 .14005 .38478 .14952 .39787 .14439 .38999 .13491 Mtetra
.664 .739 .906 r
.38999 .13491 .39787 .14439 .41102 .13925 .40318 .12975 Mtetra
.664 .74 .906 r
.40318 .12975 .41102 .13925 .42424 .13411 .41644 .12458 Mtetra
.664 .74 .907 r
.41644 .12458 .42424 .13411 .43752 .12895 .42976 .11938 Mtetra
.664 .741 .907 r
.42976 .11938 .43752 .12895 .45087 .12377 .44315 .11417 Mtetra
.44315 .11417 .45087 .12377 .46428 .11858 .4566 .10894 Mtetra
.664 .741 .908 r
.4566 .10894 .46428 .11858 .47776 .11336 .47012 .10368 Mtetra
.47012 .10368 .47776 .11336 .4913 .10813 .48371 .0984 Mtetra
.48371 .0984 .4913 .10813 .50491 .10287 .49737 .09309 Mtetra
.49737 .09309 .50491 .10287 .51859 .09758 .51109 .08776 Mtetra
.51109 .08776 .51859 .09758 .53234 .09228 .52489 .08241 Mtetra
.52489 .08241 .53234 .09228 .54616 .08694 .53875 .07702 Mtetra
.53875 .07702 .54616 .08694 .56005 .08158 .55268 .07161 Mtetra
.55268 .07161 .56005 .08158 .574 .07619 .56669 .06618 Mtetra
.56669 .06618 .574 .07619 .58803 .07078 .58076 .06071 Mtetra
.58076 .06071 .58803 .07078 .60213 .06534 .59491 .05522 Mtetra
.59491 .05522 .60213 .06534 .6163 .05987 .60913 .0497 Mtetra
.60913 .0497 .6163 .05987 .63054 .05437 .62342 .04415 Mtetra
.62342 .04415 .63054 .05437 .64486 .04885 .63778 .03857 Mtetra
.63778 .03857 .64486 .04885 .65925 .04329 .65222 .03297 Mtetra
.65222 .03297 .65925 .04329 .67371 .03771 .66673 .02733 Mtetra
.66673 .02733 .67371 .03771 .68825 .0321 .68132 .02167 Mtetra
.68132 .02167 .68825 .0321 .70286 .02646 .69599 .01598 Mtetra
.635 .65 .848 r
.03221 .28639 .04061 .29849 .052 .29573 .0438 .28239 Mtetra
.655 .638 .82 r
.0438 .28239 .052 .29573 .06363 .29178 .0556 .27734 Mtetra
.67 .628 .799 r
.0556 .27734 .06363 .29178 .0755 .28658 .06759 .27134 Mtetra
.679 .622 .784 r
.06759 .27134 .0755 .28658 .08757 .28024 .07973 .26455 Mtetra
.686 .62 .776 r
.07973 .26455 .08757 .28024 .09982 .27297 .09199 .25722 Mtetra
.689 .621 .775 r
.09199 .25722 .09982 .27297 .11217 .26509 .10432 .24963 Mtetra
.691 .626 .778 r
.10432 .24963 .11217 .26509 .12459 .25692 .11667 .24203 Mtetra
.691 .633 .786 r
.11667 .24203 .12459 .25692 .13704 .24877 .12904 .23462 Mtetra
.69 .644 .798 r
.12904 .23462 .13704 .24877 .14949 .24086 .1414 .22754 Mtetra
.688 .656 .812 r
.1414 .22754 .14949 .24086 .16192 .23335 .15374 .22085 Mtetra
.685 .668 .828 r
.15374 .22085 .16192 .23335 .17432 .22631 .16608 .21454 Mtetra
.682 .681 .843 r
.16608 .21454 .17432 .22631 .18672 .21973 .17843 .20858 Mtetra
.679 .693 .856 r
.17843 .20858 .18672 .21973 .19911 .21356 .19079 .20291 Mtetra
.675 .702 .867 r
.19079 .20291 .19911 .21356 .21151 .20772 .20317 .19744 Mtetra
.673 .711 .877 r
.20317 .19744 .21151 .20772 .22393 .20214 .2156 .19213 Mtetra
.671 .717 .883 r
.2156 .19213 .22393 .20214 .23638 .19673 .22806 .18691 Mtetra
.669 .722 .888 r
.22806 .18691 .23638 .19673 .24888 .19145 .24057 .18176 Mtetra
.668 .726 .892 r
.24057 .18176 .24888 .19145 .26143 .18624 .25314 .17663 Mtetra
.668 .728 .895 r
.25314 .17663 .26143 .18624 .27402 .18107 .26576 .17152 Mtetra
.667 .731 .897 r
.26576 .17152 .27402 .18107 .28667 .17592 .27844 .16642 Mtetra
.667 .733 .899 r
.27844 .16642 .28667 .17592 .29938 .1708 .29118 .16132 Mtetra
.666 .734 .901 r
.29118 .16132 .29938 .1708 .31214 .16567 .30397 .15621 Mtetra
.666 .736 .902 r
.30397 .15621 .31214 .16567 .32497 .16056 .31683 .1511 Mtetra
.665 .737 .903 r
.31683 .1511 .32497 .16056 .33785 .15544 .32975 .14598 Mtetra
.665 .738 .904 r
.32975 .14598 .33785 .15544 .35079 .15032 .34273 .14085 Mtetra
.665 .738 .905 r
.34273 .14085 .35079 .15032 .3638 .14519 .35577 .13571 Mtetra
.664 .739 .906 r
.35577 .13571 .3638 .14519 .37686 .14005 .36887 .13055 Mtetra
.664 .74 .906 r
.36887 .13055 .37686 .14005 .38999 .13491 .38204 .12538 Mtetra
.664 .74 .907 r
.38204 .12538 .38999 .13491 .40318 .12975 .39527 .12019 Mtetra
.39527 .12019 .40318 .12975 .41644 .12458 .40857 .11498 Mtetra
.664 .741 .907 r
.40857 .11498 .41644 .12458 .42976 .11938 .42193 .10975 Mtetra
.42193 .10975 .42976 .11938 .44315 .11417 .43536 .10449 Mtetra
.664 .741 .908 r
.43536 .10449 .44315 .11417 .4566 .10894 .44886 .09922 Mtetra
.44886 .09922 .4566 .10894 .47012 .10368 .46242 .09391 Mtetra
.46242 .09391 .47012 .10368 .48371 .0984 .47605 .08859 Mtetra
.47605 .08859 .48371 .0984 .49737 .09309 .48975 .08323 Mtetra
.48975 .08323 .49737 .09309 .51109 .08776 .50352 .07785 Mtetra
.50352 .07785 .51109 .08776 .52489 .08241 .51736 .07245 Mtetra
.51736 .07245 .52489 .08241 .53875 .07702 .53127 .06702 Mtetra
.53127 .06702 .53875 .07702 .55268 .07161 .54525 .06155 Mtetra
.54525 .06155 .55268 .07161 .56669 .06618 .5593 .05607 Mtetra
.5593 .05607 .56669 .06618 .58076 .06071 .57342 .05055 Mtetra
.57342 .05055 .58076 .06071 .59491 .05522 .58762 .04501 Mtetra
.58762 .04501 .59491 .05522 .60913 .0497 .60188 .03943 Mtetra
.60188 .03943 .60913 .0497 .62342 .04415 .61623 .03383 Mtetra
.61623 .03383 .62342 .04415 .63778 .03857 .63064 .0282 Mtetra
.63064 .0282 .63778 .03857 .65222 .03297 .64513 .02254 Mtetra
.64513 .02254 .65222 .03297 .66673 .02733 .65969 .01685 Mtetra
.65969 .01685 .66673 .02733 .68132 .02167 .67433 .01113 Mtetra
.67433 .01113 .68132 .02167 .69599 .01598 .68905 .00539 Mtetra
0 g
.68874 0 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.68874 0 m
.03716 .25514 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 0.522676 0.477324 0.97619 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.49505 0.5 0.49505 [
[ 0 0 -0.125 0 ]
[ 0 0 -0.125 0 ]
[ 0 1 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
0 0 m
1 0 L
s
0 0 m
0 1 L
s
0 1 m
1 1 L
s
1 0 m
1 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
1 .5 0 r
.015 w
.03175 .1355 Mdot
.03435 .12523 Mdot
.11137 .12765 Mdot
.14107 .18841 Mdot
.16218 .24538 Mdot
.17294 .21053 Mdot
.18267 .18577 Mdot
.18434 .1304 Mdot
.18553 .30956 Mdot
.20401 .239 Mdot
.21247 .27571 Mdot
.21687 .20845 Mdot
.22376 .2799 Mdot
.22832 .27485 Mdot
.29063 .20974 Mdot
.29686 .25079 Mdot
.30487 .22936 Mdot
.30683 .34623 Mdot
.32055 .20902 Mdot
.32574 .21979 Mdot
.34472 .28521 Mdot
.35998 .36393 Mdot
.36335 .24976 Mdot
.3794 .36608 Mdot
.42386 .66992 Mdot
.44391 .74519 Mdot
.45059 .34198 Mdot
.47208 .67586 Mdot
.47436 .71381 Mdot
.49778 .59825 Mdot
.50874 .91643 Mdot
.51516 .76219 Mdot
.53655 .61374 Mdot
.56563 .75219 Mdot
.59189 .65665 Mdot
.59581 .61604 Mdot
.59923 .6556 Mdot
.60292 .68499 Mdot
.62656 .67779 Mdot
.63555 .72451 Mdot
.63919 .652 Mdot
.64169 .6004 Mdot
.64246 .58611 Mdot
.64496 .54267 Mdot
.64608 .77288 Mdot
.65077 .64308 Mdot
.66065 .57816 Mdot
.67474 .59169 Mdot
.69296 .563 Mdot
.72815 .65902 Mdot
.73169 .58879 Mdot
.74669 .61318 Mdot
.74821 .65474 Mdot
.75963 .63781 Mdot
.79673 .57809 Mdot
.80925 .55852 Mdot
.81525 .58444 Mdot
.83417 .62985 Mdot
.83598 .55526 Mdot
.91595 .49319 Mdot
0 0 1 r
.005 w
.13523 .12963 m
.16128 .13452 L
.16351 .13523 L
.18734 .14391 L
.21339 .15753 L
.22039 .16128 L
.23945 .17299 L
.26091 .18734 L
.2655 .19077 L
.29156 .21032 L
.2955 .21339 L
.31761 .23138 L
.32704 .23945 L
.34367 .25419 L
.35581 .2655 L
.36972 .27885 L
.38227 .29156 L
.39578 .3056 L
.40661 .31761 L
.42183 .33499 L
.42886 .34367 L
.44789 .36834 L
.44886 .36972 L
.46675 .39578 L
.47394 .40387 L
.48125 .42183 L
.49205 .44789 L
.49265 .47394 L
.47394 .48987 L
.44789 .48896 L
.42183 .47934 L
.40687 .47394 L
.39578 .467 L
.36972 .45162 L
.36361 .44789 L
.34367 .43458 L
.32583 .42183 L
.31761 .41554 L
.29292 .39578 L
.29156 .39464 L
.2655 .37218 L
.26277 .36972 L
.23945 .34798 L
.23504 .34367 L
.21339 .32174 L
.20953 .31761 L
.18734 .29299 L
.18613 .29156 L
.16468 .2655 L
.16128 .26171 L
Mistroke
.14551 .23945 L
.13523 .22493 L
.12925 .21339 L
.11602 .18734 L
.10925 .16128 L
.11787 .13523 L
.13523 .12963 L
Mfstroke
.39578 .36451 m
.42183 .36132 L
.44789 .36378 L
.47273 .36972 L
.47394 .37008 L
.5 .3793 L
.52606 .39123 L
.53497 .39578 L
.55211 .40548 L
.57773 .42183 L
.57817 .42214 L
.60422 .44107 L
.61285 .44789 L
.63028 .46255 L
.64283 .47394 L
.65633 .48696 L
.66889 .5 L
.68239 .51498 L
.69159 .52606 L
.70844 .54815 L
.71118 .55211 L
.7278 .57817 L
.7345 .58967 L
.74122 .60422 L
.75113 .63028 L
.75669 .65633 L
.75639 .68239 L
.74594 .70844 L
.7345 .71983 L
.70844 .73022 L
.68239 .73184 L
.65633 .72851 L
.63028 .72154 L
.60422 .71161 L
.59684 .70844 L
.57817 .69924 L
.55211 .6844 L
.54883 .68239 L
.52606 .66734 L
.51093 .65633 L
.5 .64785 L
.47906 .63028 L
.47394 .62573 L
.45147 .60422 L
.44789 .60059 L
.4274 .57817 L
.42183 .57168 L
.40649 .55211 L
.39578 .5372 L
.38864 .52606 L
Mistroke
.37387 .5 L
.36972 .49285 L
.36243 .47394 L
.35489 .44789 L
.35243 .42183 L
.35776 .39578 L
.36972 .37737 L
.37974 .36972 L
.39578 .36451 L
Mfstroke
0 g
.03 w
.30139 .31039 Mdot
.55494 .54667 Mdot
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.522676 0.522676 0.97619 0.97619 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.49505 0.5 0.49505 [
[ 0 0 -0.125 0 ]
[ 0 0 -0.125 0 ]
[ 0 1 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
0 0 m
1 0 L
s
0 0 m
0 1 L
s
0 1 m
1 1 L
s
1 0 m
1 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
1 .5 0 r
.015 w
.03175 .1355 Mdot
.03435 .12523 Mdot
.11137 .12765 Mdot
.14107 .18841 Mdot
.16218 .24538 Mdot
.17294 .21053 Mdot
.18267 .18577 Mdot
.18434 .1304 Mdot
.18553 .30956 Mdot
.20401 .239 Mdot
.21247 .27571 Mdot
.21687 .20845 Mdot
.22376 .2799 Mdot
.22832 .27485 Mdot
.29063 .20974 Mdot
.29686 .25079 Mdot
.30487 .22936 Mdot
.30683 .34623 Mdot
.32055 .20902 Mdot
.32574 .21979 Mdot
.34472 .28521 Mdot
.35998 .36393 Mdot
.36335 .24976 Mdot
.3794 .36608 Mdot
.42386 .66992 Mdot
.44391 .74519 Mdot
.45059 .34198 Mdot
.47208 .67586 Mdot
.47436 .71381 Mdot
.49778 .59825 Mdot
.50874 .91643 Mdot
.51516 .76219 Mdot
.53655 .61374 Mdot
.56563 .75219 Mdot
.59189 .65665 Mdot
.59581 .61604 Mdot
.59923 .6556 Mdot
.60292 .68499 Mdot
.62656 .67779 Mdot
.63555 .72451 Mdot
.63919 .652 Mdot
.64169 .6004 Mdot
.64246 .58611 Mdot
.64496 .54267 Mdot
.64608 .77288 Mdot
.65077 .64308 Mdot
.66065 .57816 Mdot
.67474 .59169 Mdot
.69296 .563 Mdot
.72815 .65902 Mdot
.73169 .58879 Mdot
.74669 .61318 Mdot
.74821 .65474 Mdot
.75963 .63781 Mdot
.79673 .57809 Mdot
.80925 .55852 Mdot
.81525 .58444 Mdot
.83417 .62985 Mdot
.83598 .55526 Mdot
.91595 .49319 Mdot
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{400, 400},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40006@0001T2000`400?l00000o`00003ooooooonA
ooooo`00oooooonAooooo`00oooooonAooooo`00oooooonAooooo`00oooooonAooooo`00oooooonA
ooooo`00oooooonAooooo`00oooooonAooooo`00oooooonAooooo`00oooooonAooooo`002Ooooonf
00000=7ooooo0009ooooo`0300000?oooooooooo0;;ooooo00<00000ooooooooool0coooool000Wo
oooo00<00000ooooooooool0/_ooool00`00003oooooooooo`3?ooooo`002Oooool00`00003ooooo
ooooo`2booooo`0300000?oooooooooo0<oooooo0009ooooo`0300000?oooooooooo01Sooooo0_l0
00000`00003oooooooooo`2Eooooo`0300000?oooooooooo0<oooooo0009ooooo`0400000?oooooo
oooooooooaX06ATIT`000004ooooo`0300000?oooooooooo0<oooooo0009ooooo`0400000?oooooo
oooooooooa/06ATITP000004ooooo`0300000?oooooooooo0<oooooo0009ooooo`0400000?oooooo
oooooooooad06ATIT0000004ooooo`0300000?oooooooooo0<oooooo0009ooooo`0400000?oooooo
oooooooooal06ATISP000004ooooo`0300000?oooooooooo0<oooooo0009ooooo`0400000?oooooo
ooooooooo`D06ATI3000000@01TI6H`000001?ooool00`00003oooooooooo`3?ooooo`002Oooool0
1000003oooooooooooooool301TI6@03o`0000000000<c<c00/0<c<c00?o000001TI6@0I6AT03P0I
6AV;000000Cooooo00<00000ooooooooool0coooool000Wooooo00@00000oooooooooooooooo0P0I
6AT00ol00000<c<c03<c<`0<03<c<`<000003`0I6AT00ol00000000000000027000000Cooooo00<0
0000ooooooooool0coooool000Wooooo00@00000oooooooooooooooo0P0I6AT00`000000<c<c03<c
<`0?03<c<`<000003`0I6AV7000000Cooooo00<00000ooooooooool0coooool000Wooooo00H00000
oooooooooooooooo01TI6@00000E03<c<`<000003P0I6AV5000000Cooooo00<00000ooooooooool0
coooool000Wooooo00D00000oooooooooooooooo0000000I03<c<`03o`00000I6AT06ATI00`06ATI
00<00000o`0000000000P@000004ooooo`0300000?oooooooooo0<oooooo0009ooooo`0500000?oo
ooooooooooooo`0000006P0c<c<3000000h06ATIP@000004ooooo`0300000?oooooooooo0<oooooo
0009ooooo`0500000?ooooooooooooooo`0000007@0c<c<2000000d06ATIP0000004ooooo`030000
0?oooooooooo0<oooooo0009ooooo`0500000?ooooooooooooooo`0000007`0c<c<00`0000006ATI
01TI6@0<01TI6Gh000001?ooool00`00003oooooooooo`2;ooooo`;o0000@_ooool000Wooooo00D0
0000oooooooooooooooo0000000?03<c<`@000003@0c<c<00ol0000000000000000<01TI6Gd00000
1?ooool00`00003oooooooooo`28ooooo`?o000000?oooooo`000?ooool0@Oooool000Wooooo00D0
0000oooooooooooooooo0000000<03<c<`<00000101<C4`3000000d0<c<c0P00000<01TI6G/00000
1?ooool00`00003oooooooooo`26ooooo`;o00000oooool00onY_NSo0000o`000011ooooo`002Ooo
ool01@00003oooooooooooooool0000000/0<c<c00<0000004a<C01<C4`0201<C4`4000000/0<c<c
0P00000<01TI6GT000001?ooool00`00003oooooooooo`23ooooo`?o00000_ooool4ojVmj003o`00
0?oooooo0000043ooooo0009ooooo`0500000?ooooooooooooooo`0000002P0c<c<00`000000C4a<
04a<C00=04a<C004o`00000000000000000000T0<c<c00?o000001TI6@0I6AT02`0I6AUg000000Co
oooo00<00000ooooooooool0P?ooool3o`0000;ooooo1onY_NP00ol0003oooooo`000010ooooo`00
2Oooool01@00003oooooooooooooool0000000X0<c<c00<0000004a<C01<C4`04@1<C4`2000000P0
<c<c0P00000<01TI6@03o`0000000000000007<000001?ooool00`00003oooooooooo`1nooooo`;o
00000oooool9ojVmj004o`000?nY_NSoooooo`0003oooooo0009ooooo`0600000?oooooooooooooo
o`0I6AT00000200c<c<00`000000C4a<04a<C00D04a<C0030000000c<c<0<c<c00L0<c<c0P00000<
01TI6G@000001?ooool00`00003oooooooooo`1kooooo`?o00000_ooool<ojVmj005o`000?nY_NSo
ooooooooool00000?_ooool000Wooooo00H00000oooooooooooooooo01TI6@00000803<c<`030000
001<C4`0C4a<01D0C4a<1000000703<c<`03o`00000000006ATI00/06ATI00<00000o`0000000000
K`000004ooooo`0300000?oooooooooo07Wooooo0_l00003ooooo`koZKgX00Go0000ojVmj?nY_NSo
ooooo`00000nooooo`002Oooool01P00003oooooooooooooool06ATI000000P0<c<c00<0000004a<
C01<C4`06@1<C4`2000000L0<c<c00<0000001TI6@0I6AT02`0I6AU`000000Cooooo00<00000oooo
ooooool0M_ooool3o`0000;ooooo4OnY_NP01_l0003oZKgXojVmj?nY_NSoooooo`0003gooooo0009
ooooo`0400000?ooooooooooooooo`806ATI00<0000003<c<`0c<c<01@0c<c<00`000000C4a<04a<
C00904a<C0P000002P1<C4`00`000000<c<c03<c<`0503<c<`800000300I6AU_000000Cooooo00<0
0000ooooooooool0M?ooool2o`0000;ooooo5?nY_NP00ol0003oZKgXojVmj002ojVmj003o`000?oo
oooooooo03_ooooo0009ooooo`0400000?ooooooooooooooo`806ATI00<0000003<c<`0c<c<01@0c
<c<00`000000C4a<04a<C00704a<C003o`0000000000IVIV00L0IVIV0`00000804a<C08000001`0c
<c<2000000`06ATIK@000004ooooo`0300000?oooooooooo077ooooo0ol00002oooooaKoZKgX00?o
0000ojVmj?nY_NP00onY_NP00ol0003oooooooooo`0jooooo`002Oooool01000003ooooooooooooo
ool301TI6@030000000c<c<0<c<c00@0<c<c00<0000004a<C01<C4`01P1<C4`00ol00000IVIV06IV
IP0;06IVIP03o`0000000000000000L0C4a<0P00000703<c<`800000300I6AU[000000Cooooo00<0
0000ooooooooool0K_ooool3o`0000;ooooo6OnY_NP00ol0003oZKgXojVmj003ojVmj003ooooool0
003ooooo03[ooooo0009ooooo`0400000?ooooooooooooooo`<06ATI00?o000003<c<`0c<c<0100c
<c<00`000000C4a<04a<C00604a<C0030000001VIVH0IVIV00h0IVIV0P00000704a<C08000001`0c
<c<00`0000006ATI01TI6@0;01TI6FT000001?ooool00`00003oooooooooo`1/ooooo`;o00000ooo
oolLojVmj003o`000?nY_NSoZKgX00?oZKgX00?o0000ooooooooool0>Oooool000Wooooo00@00000
oooooooooooooooo0`0I6AT00`000000<c<c03<c<`0503<c<`030000001<C4`0C4a<00@0C4a<00<0
000006IVIP1VIVH04@1VIVH3000000H0C4a<00<0000003<c<`0c<c<01@0c<c<2000000`06ATIJ000
0004ooooo`0300000?oooooooooo06Wooooo0ol00002oooooaooZKgX00?o0000ojVmj?nY_NP00onY
_NP00ooooooo0000ooooo`0iooooo`002Oooool01000003oooooooooooooool401TI6@030000000c
<c<0<c<c00@0<c<c00<0000004a<C01<C4`0101<C4`00`000000IVIV06IVIP0D06IVIP03o`00001<
C4`0C4a<00@0C4a<00?o00000000000000001P0c<c<2000000d06ATII@000004ooooo`0300000?oo
oooooooo06Oooooo0_l00003ooooob7oZKgX00?o0000ojVmj?nY_NP01?nY_NP00ooooooo0000oooo
o`0hooooo`002Oooool01000003oooooooooooooool401TI6@030000000c<c<0<c<c00@0<c<c00<0
000004a<C01<C4`0101<C4`00`000000IVIV06IVIP0D06IVIP<000001`1<C4`00`000000<c<c03<c
<`0503<c<`800000300I6AT00ol0000000000000001Q000000Cooooo00<00000ooooooooool0I?oo
ool3o`0000;ooooo9?nY_NP00ol0003oZKgXojVmj004ojVmj003ooooool0003ooooo03Sooooo0009
ooooo`0400000?ooooooooooooooo`D06ATI00<0000003<c<`0c<c<0100c<c<00`000000C4a<04a<
C00304a<C0030000001VIVH0IVIV00P0IVIV2000000706IVIP<000001@1<C4`2000000L0<c<c00<0
000001TI6@0I6AT0300I6AUQ000000Cooooo00<00000ooooooooool0H_ooool2o`0000?ooooo9_nY
_NP00ol0003oZKgXojVmj005ojVmj003ooooool0003ooooo03Oooooo0009ooooo`0400000?oooooo
ooooooooo`D06ATI00<0000003<c<`0c<c<0100c<c<00`000000C4a<04a<C00404a<C0030000001V
IVH0IVIV00D0IVIV00?o00000000001oOgl01`1oOgl00`00003o000006IVIP0706IVIP030000001<
C4`0C4a<00@0C4a<00<0000003<c<`0c<c<01@0c<c<00ol000006ATI01TI6@0=01TI6El000001?oo
ool00`00003oooooooooo`1Oooooo`?o00000_oooolYojVmj003o`000?nY_NSoZKgX00KoZKgX00?o
ooooo`000?ooool0=_ooool000Wooooo00@00000oooooooooooooooo1P0I6AT00`000000<c<c03<c
<`0403<c<`030000001<C4`0C4a<00<0C4a<00<0000006IVIP1VIVH0101VIVH00ol00000Ogmo07mo
O`0:07moO`8000001`1VIVH2000000D0C4a<0P00000603<c<`<000003@0I6AT00`00003o00000000
001K000000Cooooo00<00000ooooooooool0GOooool2o`0000?ooooo:onY_NP00ol0003oZKgXojVm
j007ojVmj003o`000?oooooooooo03Gooooo0009ooooo`0400000?ooooooooooooooo`L06ATI00?o
000003<c<`0c<c<00`0c<c<00`000000C4a<04a<C00304a<C0030000001VIVH0IVIV00@0IVIV00<0
000007moO`1oOgl0301oOgl3000000H0IVIV0P00000504a<C08000001`0c<c<2000000h06ATIF`00
0004ooooo`0300000?oooooooooo05[ooooo0ol00002ooooobkoZKgX00?o0000ojVmj?nY_NP02?nY
_NP00ol0003oooooooooo`0dooooo`002Oooool01000003oooooooooooooool701TI6@030000000c
<c<0<c<c00@0<c<c00<0000004a<C01<C4`00`1<C4`00`000000IVIV06IVIP0306IVIP030000001o
Ogl0Ogmo00l0Ogmo0`00000506IVIP8000001@1<C4`2000000L0<c<c00<0000001TI6@0I6AT0300I
6AUJ000000Cooooo00<00000ooooooooool0Eoooool3o`0000?ooooo<?nY_NP00ol0003oZKgXojVm
j008ojVmj003ooooool0003ooooo03Cooooo0009ooooo`0400000?ooooooooooooooo`P06ATI00<0
000003<c<`0c<c<00`0c<c<00ol00000C4a<04a<C00304a<C0030000001VIVH0IVIV00<0IVIV00<0
000007moO`1oOgl04P1oOgl00ol00000IVIV06IVIP0406IVIP03o`00001<C4`0C4a<00@0C4a<00?o
000003<c<`0c<c<01@0c<c<2000000h06ATIF0000004ooooo`0300000?oooooooooo05Gooooo0_l0
0003oooooc?oZKgX00?o0000ojVmj?nY_NP02OnY_NP00ol0003oooooooooo`0cooooo`002Oooool0
1@00003oooooooooooooool0000000L06ATI00<0000003<c<`0c<c<00`0c<c<00`000000C4a<04a<
C00304a<C0030000001VIVH0IVIV00<0IVIV00<0000007moO`1oOgl04`1oOgl2000000D0IVIV0P00
000504a<C08000001`0c<c<2000000d06ATI00?o0000000000000000E0000004ooooo`0300000?oo
oooooooo05;ooooo0ol00003ooooocGoZKgX00?o0000ojVmj?nY_NP02OnY_NP00ooooooo0000oooo
o`0cooooo`002Oooool01@00003oooooooooooooool0000000P06ATI00<0000003<c<`0c<c<00`0c
<c<00`000000C4a<04a<C00204a<C0030000001VIVH0IVIV00<0IVIV00<0000007moO`1oOgl01@1o
Ogl:000000H0Ogmo0P00000506IVIP8000001@1<C4`00`000000<c<c03<c<`0603<c<`030000000I
6AT06ATI00`06ATIE@000004ooooo`0300000?oooooooooo053ooooo0_l00004ooooocOoZKgX00?o
0000ojVmj?nY_NP02_nY_NP00ol0003oooooooooo`0booooo`002Oooool01000003ooooooooooooo
ool2000000L06ATI00<0000003<c<`0c<c<00`0c<c<00`000000C4a<04a<C00204a<C0030000001V
IVH0IVIV00<0IVIV00<0000007moO`1oOgl01@1oOgl00`000000VIVI09VIV@0709VIV@0300000?l0
0000Ogmo00D0Ogmo0P00000506IVIP03o`00001<C4`0C4a<00<0C4a<00<0000003<c<`0c<c<01P0c
<c<00`0000006ATI01TI6@0=01TI6E<000001?ooool00`00003oooooooooo`1=ooooo`?o00000ooo
ool2ojVmi`CoZKgX0onY_NL00onY_NSoZKgWojVmi`04ojVmj0;oZKgW:?nY_NP00ol0003oZKgXojVm
j00:ojVmj003ooooool0003ooooo03;ooooo0009ooooo`0400000?ooooooooooooooo`800000200I
6AT00`000000<c<c03<c<`0303<c<`030000001<C4`0C4a<0080C4a<00?o000006IVIP1VIVH00P1V
IVH00`000000Ogmo07moO`0407moO`030000002IVIT0VIVI00X0VIVI0P00000607moO`03o`00001V
IVH0IVIV00<0IVIV0P00000404a<C08000001`0c<c<00ol000006ATI01TI6@0=01TI6@03o`000000
0000000004l000001?ooool00`00003oooooooooo`1;ooooo`;o00001?ooool5ojVmi`03ojVmj?nY
_NOoZKgW00;oZKgW00?oZ[gWojVmionY_NL00_nY_NL00onY_NSoZ[gWojVmi`03ojVmi`03ojVmj?nY
_NOoZKgW00CoZKgX0_nY_NLNojVmj003o`000?nY_NSoZKgX00_oZKgX00?oooooo`000?ooool0<Ooo
ool000Wooooo00@00000oooooooooooooooo0P00000801TI6@030000000c<c<0<c<c00<0<c<c00<0
000004a<C01<C4`00P1<C4`00`000000IVIV06IVIP0206IVIP030000001oOgl0Ogmo00@0Ogmo00<0
000009VIV@2IVIT0302IVIT3000000@0Ogmo0P00000506IVIP800000101<C4`00`000000<c<c03<c
<`0503<c<`8000003`0I6AU@000000Cooooo00<00000ooooooooool0B?ooool3o`0000?ooooo0onZ
_>L00onY_NOoZ[cWojZli`03ojZmi`03ojVmionZ_>OoZ[cW00?oZ[gW0_nY_NL4ojZmi`;oZKgW00?o
Z[gWojVmionY_NL00_nY_NL00onY_NSoZ[gWojVmi`03ojVmi`03ojVmj?nY_NOoZKgW00SoZKgX00?o
ZKgWojVmj?nY_NP03onY_NP00ol0003oZKgXojVmj00<ojVmj003o`000?oooooooooo033ooooo0009
ooooo`0400000?ooooooooooooooo`<00000200I6AT00`000000<c<c03<c<`0303<c<`030000001<
C4`0C4a<0080C4a<00<0000006IVIP1VIVH00P1VIVH00`000000Ogmo07moO`0307moO`030000002I
VIT0VIVI00l0VIVI0`00000307moO`8000001@1VIVH00`000000C4a<04a<C00204a<C0<000001P0c
<c<2000000l06ATICP000004ooooo`0300000?oooooooooo04Gooooo0ol00004ooooo`WoZ[cW00?o
Z[gWojZlionZ_>L00onZ_>L00onZ_NOoZ[cWojZli`04ojZmi`;oZ[cW0onZ_NL2ojVmi`CoZ[gW0_nY
_NL2ojZmi`03ojVmionZ_NOoZ[gW00?oZ[gW0_nY_NP01?nZ_NOoZKgWojVmionY_NL2ojVmj003ojVm
ionY_NSoZKgX00_oZKgX00?o0000ojVmj?nY_NP03?nY_NP00ooooooo0000ooooo`0`ooooo`002Ooo
ool01000003oooooooooooooool4000000P06ATI00<0000003<c<`0c<c<00`0c<c<00ol00000C4a<
04a<C00204a<C0050000001VIVH0IVIV06IVIP0000001@1oOgl00`000000VIVI09VIV@0B09VIV@03
o`00001oOgl0Ogmo0080Ogmo00?o00000000001VIVH00`1VIVH00ol00000C4a<04a<C00404a<C003
o`00000c<c<0<c<c00D0<c<c00?o00000000000I6AT03@0I6AU=000000Cooooo00<00000oooooooo
ool0@oooool2o`0000;ooooo0_nZ_>H4ojZli`;oZ[cV1OnZ_>L00onZ_>KoZ[cWojZli`08ojZli`03
ojZmionZ_>OoZ[cW00?oZ[cW00?oZ[gWojZlionZ_>L01?nZ_NL3ojZli`03ojZmionZ_>OoZ[gW00Wo
Z[gW00?oZKgWojZmionZ_NL00onY_NL00onY_NSoZ[gWojZmi`09ojVmj003o`000?nY_NSoZKgX00go
ZKgX00?oooooo`000?ooool0;oooool000Wooooo00@00000oooooooooooooooo1000000901TI6@03
0000000c<c<0<c<c0080<c<c00<0000004a<C01<C4`00P1<C4`01@000000IVIV06IVIP1VIVH00000
00D0Ogmo00<0000009VIV@2IVIT01`2IVIT5000000L0VIVI0P00000407moO`030000001VIVH0IVIV
0080IVIV0P00000504a<C08000001`0c<c<00`0000006ATI01TI6@0<01TI6@03o`00000000000000
04T000001?ooool00`00003oooooooooo`10ooooo`?o00000_ooool00onZ^nKoZ[cVojZliP02ojZl
iP03ojZlionZ^nKoZ[_V00?oZ[cV00?oZ[cWojZki_nZ^nH00onZ_>H00onZ_>OoZ[cVojZliP05ojZl
i`03ojZli_nZ_>OoZ[cW00?oZ[cW0_nZ_>H00onZ_>OoZ[cVojZliP05ojZli`04ojZli_nZ_>OoZ[cW
ojZli`;oZ[gW00?oZ[cWojZmionZ_NL00onZ_NL00onZ_>OoZ[gWojZmi`02ojZmi`03ojVmionZ_NOo
Z[gW00?oZ[gW00?oZKgXojZmionZ_NL00_nY_NP01?nZ_NOoZKgXojVmj?l0000?ojVmj003ooooool0
003ooooo02oooooo0009ooooo`0400000?ooooooooooooooo`D000002@0I6AT00`000000<c<c03<c
<`0203<c<`030000001<C4`0C4a<0080C4a<00D0000006IVIP1VIVH0IVIV0000000407moO`030000
002IVIT0VIVI00D0VIVI0P0000050;>c/`<000001P2IVIT2000000<0Ogmo0P00000406IVIP030000
001<C4`0C4a<00@0C4a<00<0000003<c<`0c<c<01@0c<c<2000000h06ATIBP000004ooooo`030000
0?oooooooooo03kooooo0_l00003ooooo`CoZ[_V0_nZ_>H5ojZkiP03ojZli_nZ^nKoZ[_V00?oZ[_V
00?oZ[cVojZki_nZ_>H00onZ_>H01?nZ_>OoZ[_VojZki_nZ^nH2ojZliP03ojZlionZ_>KoZ[cV00;o
Z[cV00?oZk_VojZli_nZ_>H00_nZ_>H00onZ_>OoZ[cVojZliP03ojZliP03ojZlionZ_>KoZ[cV00?o
Z[cW00?oZ[gWojZlionZ_>L00onZ_>L2ojZmi`;oZ[cW3?nZ_NL00onY_NSo0000ojZmi`0?ojVmj003
ooooool0003ooooo02kooooo0009ooooo`0400000?ooooooooooooooo`H00000200I6AT00`000000
<c<c03<c<`0203<c<`030000001<C4`0C4a<0080C4a<00D0000006IVIP1VIVH0IVIV0000000507mo
O`030000002IVIT0VIVI00<0VIVI00<000000;>c/`2c/k<0202c/k<00`00003o000009VIV@0509VI
V@03o`00001oOgl0Ogmo0080Ogmo00<0000006IVIP1VIVH00P1VIVH2000000D0C4a<00?o000003<c
<`0c<c<01P0c<c<00`0000006ATI01TI6@0<01TI6DT000001?ooool00`00003oooooooooo`0koooo
o`?o00000_ooool2ojZki@CoZ[_V0_nZ^nD5ojZkiP03oj^kiOnZ^nKoZ[_V00?oZ[_V00CoZk_UojZk
i_nZ^nKoZ[_V0_nZ_>H2oj^ki@;oZ[_V00CoZk[Uoj^kiOn[^nGoZk_U0_nZ_>H01?n[^nGoZk_Voj^k
i_n[^nH2ojZliP03oj^kiOnZ_>KoZ[cV00?oZ[cV00?oZk_VojZli_nZ_>H00_nZ_>H00onZ_>OoZ[cV
ojZli`08ojZli`04ojZli_nZ_>OoZ[cWojZli`;oZ[gW00?oZ[cWojZmionZ_NL01OnZ_NL01Ol0003o
Z[gWojZmionY_NSoZ[gW00goZKgX00?oooooo`000?ooool0;Oooool000Wooooo00@00000oooooooo
oooooooo1P0000000ol000006ATI01TI6@0501TI6@030000000c<c<0<c<c00<0<c<c00<0000004a<
C01<C4`00P1<C4`01Ol00000IVIV06IVIP1VIVH0000000@0Ogmo00<0000009VIV@2IVIT00P2IVIT0
0`000000/k>c0;>c/`0;0;>c/`8000001@2IVIT2000000<0Ogmo00?o00000000000000000`1VIVH2
000000@0C4a<0`00000603<c<`8000003P0I6AU7000000Cooooo00<00000ooooooooool0>Oooool2
o`0000?ooooo0_n[^^D3ojZki@03ojZki_n[^^GoZk[U00?oZ[_U00?oZ[_Voj^ji?n[^^@00on[^nD0
1?nZ^nKoZk[Toj^ji?n[^^@2oj^ki@05ojZki_n[^^GoZk[Uoj^jiOn[^nD00_n[^^@3oj^ji@03oj^k
iOn[^^CoZk[T00?oZk_U00?oZk_Voj^jiOn[^^D00on[^nD00onZ_>KoZk_Uoj^ki@03oj^kiP;oZ[cV
0_n[^nH2ojZliP;oZ[cW0_n[_>H00onZ_>OoZkcVoj^liP03ojZliP03ojZlionZ_>KoZ[cV00?oZ[cW
0_nZ_NL01OnZ_>OoZ[gWojZmionZ_NOo000000GoZ[gW0_nY_NP2ojZmi`03ojVmj?nZ_NOoZKgX00Ko
ZKgX00?o0000ooooooooool0;?ooool000Wooooo00@00000oooooooooooooooo2000000701TI6@03
0000000c<c<0<c<c0080<c<c00?o000004a<C01<C4`00P1<C4`01@000000IVIV06IVIP1VIVH00000
00@0Ogmo00<0000009VIV@2IVIT00P2IVIT00`000000/k>c0;>c/`0=0;>c/`8000001@2IVIT20000
00@0Ogmo00<0000006IVIP1VIVH00P1VIVH2000000D0C4a<0P00000603<c<`8000003P0I6AU50000
00Cooooo00<00000ooooooooool0=_ooool3o`0000?ooooo00?oZkWToj^jiOn[^^D00_n[^^D00onZ
^nGoZkWToj^ji@03oj^ji@03ojZkiOn[^NCoZk[T00?oZk[T00?oZk_Uoj^ii?n[^N@00_n[^^@00on[
^>?oZkWToj^ii002oj^ii003oj^jiOn/^N?oZk[T00?oZk[T00?oZk[Uojbihon[^^@00on[^^@00on[
^nGo[;[Toj^ji@03oj^ji@03oj^kiOn[^^CoZk_U00?oZk_U00?oZk_Voj^kiOn[^nD00_n[^nH00on[
^^CoZk_Uoj^ki@02oj^ki@03oj^li_n[^nGoZkcV00?oZkcV00?oZ[cVoj^li_nZ_>H00onZ_>H00onZ
_>OoZ[cVojZli`03ojZli`03ojZmionZ_>Oo000000coZ[gW0_nY_NP00onZ_NOoZKgXojVmj002ojVm
j003o`000?oooooooooo02_ooooo0009ooooo`0400000?ooooooooooooooo`P00000200I6AT00`00
0000<c<c03<c<`0203<c<`030000001<C4`0C4a<0080C4a<00D0000006IVIP1VIVH0IVIV00000003
07moO`030000002IVIT0VIVI00<0VIVI00<000000;>c/`2c/k<03P2c/k<2000000D0VIVI0P000003
07moO`800000101VIVH00`000000C4a<04a<C00404a<C0030000000c<c<0<c<c00D0<c<c0P00000>
01TI6D<000001?ooool00`00003oooooooooo`0cooooo`?o00001?ooool01?n[^>?oZkWToj^ii?n[
^N@2oj^ji@04oj^hhon[^NCoZkWToj^ii0;oZk[U00CoZkSSoj^ii?n[^NCoZkWT0_n[^^@2oj^hh`03
oj^ii?n/]n;o[;OR00?oZkSS0_n[^N@01?n/^>;o[;WSojbihon/^N<2oj^ji004ojbhh_n/^N?o[;WS
ojbih`;oZk[T00Co[;SRojbji?n/^^Co[;[T0_n[^^D01?n/^N?oZk[Toj^ji?n[^^@2oj^ki@;o[;[T
00?oZk_Uojbihon/^N<00on[^^@2oj^ki@04ojbji?n[^nGoZk_Uoj^ki@;oZkcV00CoZk_Uoj^li_n[
_>KoZkcV0_nZ_>H01?n[^nKoZ[cVojZli_nZ_>H2ojZli`;oZkcV00?oZ[cWo`000?nZ_>L00onZ_>L0
0onZ_NOoZ[cWojZli`09ojZmi`;oZKgX00?oZ[gWo`000?ooool0;?ooool000Wooooo00@00000oooo
oooooooooooo2@00000801TI6@030000000c<c<0<c<c0080<c<c00<0000004a<C01<C4`00P1<C4`0
1@000000IVIV06IVIP1VIVH0000000<0Ogmo00?o000009VIV@2IVIT00P2IVIT00`000000/k>c0;>c
/`0@0;>c/`03o`0000000000000000@0VIVI0P00000307moO`8000000`1VIVH2000000D0C4a<00<0
000003<c<`0c<c<01P0c<c<00ol000006ATI01TI6@0<01TI6D8000001?ooool00`00003ooooooooo
o`0aooooo`;o00001?ooool2oj^ghP?oZkSS00?oZkWToj^gh_n[]n800on[^><01?n[^NCoZkORoj^g
h_n[]n82oj^hh`05oj^ii?n/]n;o[;ORojbgh_n[^><00_n/]^43ojbghP03oj^hhon/]^7o[;KQ00?o
[;SR00?o[;WSojbghOn/]n400on/^>800on/^N?o[;OQojbgh@03ojbhhP04ojbji?n/^>;o[;SRojbh
hP;o[;WS00KoZk[Tojbih_n/^N;o[;WRojbji?n]^>84ojbih`03oj^ji?n/^N?o[;[T00?o[;[T00?o
Zk_Uojbji?n[^nD00on[^nD00on[_>KoZk_Uoj^ki@03oj^kiP03ojZli_n[^nKoZk_V00;oZkcV00Co
Zk_Uoj^li_n[_>Ko00000_nZ_>L00on[_>KoZ[cWojZli`02ojZli`03ojZmionZ_>OoZ[gW00WoZ[gW
00?o0000ooooooooool0:_ooool000Wooooo00@00000oooooooooooooooo2@00000801TI6@03o`00
000c<c<0<c<c0080<c<c00<0000004a<C01<C4`00P1<C4`01Ol00000IVIV06IVIP1VIVH0000000<0
Ogmo00<0000009VIV@2IVIT00P2IVIT00`000000/k>c0;>c/`050;>c/`L000001`2c/k<2000000@0
VIVI00<0000007moO`1oOgl00P1oOgl00`000000IVIV06IVIP0206IVIP800000101<C4`00`000000
<c<c03<c<`0603<c<`800000300I6AT00ol0000000000000000o000000Cooooo00<00000oooooooo
ool0;_ooool3o`0000Cooooo0_n/]^03oj^ghP03oj^hhon/]^3o[;KP00?oZkOR00KoZkSSojbfhOn/
]^7o[;KQoj^gh_n/]=l4ojbfh@03ojbgh_n/]Moo[;KQ00?o[;KQ00?o[;ORojbegon/]^400on/]^40
0on/^>;o[KGOojbgh@03ojbgh@03ojbhh_n]]]oo[;OQ00?o[;OQ00?o[;SRojfgh?n/^>800_n/^>80
1?n]]]oo[KOQojfghOn]]n42ojbihP04ojfgh?n]^>;o[KSRojfhhP;o[;WS00Co[KSQojbihon/^N?o
[;WS0_n/^^@01?n/^N;o[;[Tojbji?n/^^@2oj^ki@;o[;[T00?oZk_Uojbjhon/^^<00on/^nD00on[
^nKo[;_Tojbki003oj^ki@03oj^li_l0003oZk_U00?oZkcV0_nZ_>L01?n[_>KoZ[cWojZlionZ_>L2
ojZmi`;oZ[cW1_nZ_NL00ol0003oooooooooo`0Yooooo`002Oooool01000003oooooooooooooool:
000000L06ATI00<0000003<c<`0c<c<00`0c<c<01@000000C4a<04a<C01<C4`0000000@0IVIV00D0
000007moO`1oOgl0Ogmo0000000309VIV@030000002c/k<0/k>c00D0/k>c00<000000<c<c03<c<`0
103<c<`3000000H0/k>c00<0000009VIV@2IVIT00P2IVIT00`000000Ogmo07moO`0207moO`030000
001VIVH0IVIV00<0IVIV00<0000004a<C01<C4`00P1<C4`00`000000<c<c03<c<`0703<c<`030000
000I6AT06ATI00/06ATI@0000004ooooo`0300000?oooooooooo02cooooo0_l00005ooooo`03ojbc
gOn/]^3o[;KP00;o[;KP00?oZkORojbdg_n/]^000on/]^000on[]n;o[;COojbdg`02ojbfh@04ojfc
gOn/]=oo[;COojbdg`;o[;KQ00Co[K?Mojbegon/]Moo[;GO0_n/]^401?n]/mgo[;GOojbegon/]Ml2
ojbfh@04ojfdgOn]]Moo[KGOojfeg`;o[;OQ00Co[KCNojffgon]]]oo[KKO0_n/]n401On]]Mko[KOP
ojfgh?n]]n3o[;SR00?o[KKO00?o[KOQojjeg_n^]Mh00on]]n000on]^>;o[[KOojjfg`03ojfhh@03
ojbihon]^>7o[KSQ00?o[;WR00Ko[;[Tojfih_n]^N;o[KWRojbji?n]^N84ojbjh`03ojbkiOn/^^?o
[;_T00?o[;_T00CoZk_Uojbki?n[^nGo00000_n[^nD00on[_>KoZk_Uoj^ki@03oj^liP03ojZlion[
_>KoZkcV00;oZ[cW00CoZkcVojZlionZ_>OoZ[cW0onZ_NL00ol0003oooooooooo`0Yooooo`002Ooo
ool01000003oooooooooooooool:000000P06ATI00<0000003<c<`0c<c<00`0c<c<01@000000C4a<
04a<C01<C4`0000000<0IVIV00D0000007moO`1oOgl0Ogmo0000000409VIV@030000002c/k<0/k>c
00<0/k>c00<000000<c<c03<c<`0203<c<`00`00003o00000;>c/`040;>c/`030000002IVIT0VIVI
0080VIVI00<0000007moO`1oOgl00P1oOgl00`000000IVIV06IVIP0206IVIP030000001<C4`0C4a<
00<0C4a<0P00000803<c<`030000000I6AT06ATI00`06ATI?P000004ooooo`0300000?oooooooooo
02Wooooo0ol00005ooooo`04ojfafon//mgo[;?Mojbcg@;o[;KP00Co[K;Lojbdg_n/]=ko[;CN0_n/
]^02ojfbg003ojbdgon]/=[o[K3J00?o[K?M00?o[;COojfafon]/M/00on]/md00on/]Moo[K7Kojfa
f`03ojfcg@03ojbegon]/]_o[K;K00?o[KCM00?o[KGOojjbg?n^/]`00on]]=h00on]]]oo[[?Lojjc
g003ojfegP06ojfgh?n^]=go[[CMojjdgOn]]]oo[k?L1?n^]Mh00on]]n3o[[CMojjfg`03ojjfg`03
ojfhhOn^]]ko[KSQ00?o[KSQ00?o[;WRojjgh?n^]n000_n]^N801?n^]n3o[KWRojfih_n]^N82ojbj
h`04ojfih_n/^^?o[;[Sojbjh`;o[;_T00Ko[K[Sojbki?n/^nCo[;_To`000?n[^nD2ojbki003oj^k
iOn/^nCoZkcU00?oZkcU1_n[_>H00onZ_>OoZkcVojZmi`03ojZmi`03o`000?oooooooooo02Sooooo
0009ooooo`0400000?ooooooooooooooo`/00000200I6AT00`000000<c<c03<c<`0203<c<`03o`00
001<C4`0C4a<0080C4a<00D0000006IVIP1VIVH0IVIV0000000307moO`050000002IVIT0VIVI09VI
V@0000001@2c/k<00`000000c<c<0<c<c00:0<c<c0800000102c/k<2000000<0VIVI0P00000307mo
O`8000000`1VIVH2000000D0C4a<0P00000703<c<`800000300I6AT00ol0000000000000000k0000
00Cooooo00<00000ooooooooool09oooool2o`0000Gooooo0_n^[]L3ojfaf`03ojbcgOn^[mSo[ZoH
00?o[K;L00?o[;CNojf`fOn]/=T00on]/]`4ojf`fP03ojfcgOn^[]So[K7K00?o[K7K00?o[K?Mojj_
fOn]/M/00on]/M/00on]/mgo[[3Iojfbf`03ojfbf`03ojfdgOn^/=[o[[;L00?o[[;L00?o[KCNojja
f_n^/m`00on^/m`00on]]Mko[k;Kojnbf`02ojjdg@04ojnafOn_/mco[k?Lojncg0;o[[GN00Co[k;J
ojjdgOn^]=go[[CM0_n^]]l01?n_]=co[[KNojjfg_n^]]h2ojfhh@;o[kKN00?o[[OPojnegOn^]n00
0on^]n000on]^N;o[[OOojfihP03ojfihP03ojbjhon]^N7o[K[S00?o[K[S00?o[;_Tojfjhol00000
0_n/^n@01?n]^^?o[;_Tojbki?n/^n@2oj^li@03ojbkiOn[_>KoZkcV00OoZkcV0_nZ_NL2oj^liP03
o`000?oooooooooo02Oooooo0009ooooo`0400000?ooooooooooooooo`/00000200I6AT00`000000
<c<c03<c<`0303<c<`050000001<C4`0C4a<04a<C00000000`1VIVH01@000000Ogmo07moO`1oOgl0
000000<0VIVI00?o00000;>c/`2c/k<00`2c/k<00`000000c<c<0<c<c00<0<c<c0800000102c/k<0
0`000000VIVI09VIV@0209VIV@8000000`1oOgl2000000<0IVIV0P00000504a<C08000001`0c<c<0
0`0000006ATI01TI6@0;01TI6C`000001?ooool00`00003oooooooooo`0Tooooo`?o00001Oooool2
ojn[d`?o[ZkG00?o[K7Kojn/e?n_[=@00on^[mP00on]/]co[ZgFojf`f@03ojf`f@03ojfbg?n^[]Oo
[ZkG00;o[K3J00Co[Z_Dojj^f?n^[]So[ZkH0_n]/M/01?n^[=Ko[ZoIojj_fOn^[mT2ojfaf`04ojj]
e_n^/=Wo[[3Iojj`f@;o[K;K00Co[ZkGojj`f_n^/=[o[[3J0_n^/]`01?n_[mSo[[7Jojjaf_n^/MX2
ojjcg005ojn`f?n_/]_o[k;Kojnbfon`[]H00on_/MT00on_/mco/;3Hok2`f003ojnbfP03ojjdgOn`
/MWo[kCL00?o[kCL00?o[[KNok2cfon_]]h00_n_]]h01?n`/m[o[kGMojnegOn_]Md2ojjgh004ojne
gOn^]moo[[OOojjgg`;o[KWR00Co[kOOojfihOn]^N7o[KWQ0_n]^^<2ojjih@03ojfjhol0003o[K[S
00?o[K[S00?o[;_Tojfjhon/^nD00on/^nD00on[_>Ko[;_Uoj^liP09oj^liP03o`000?oooooooooo
02Oooooo0009ooooo`0400000?ooooooooooooooo``00000200I6AT00`000000<c<c03<c<`0303<c
<`050000001<C4`0C4a<04a<C00000000`1VIVH01@000000Ogmo07moO`1oOgl0000000<0VIVI00<0
00000;>c/`2c/k<00P2c/k<00`000000c<c<0<c<c00>0<c<c08000000`2c/k<3000000<0VIVI00<0
000007moO`1oOgl00P1oOgl00ol00000IVIV06IVIP0206IVIP030000001<C4`0C4a<00@0C4a<00<0
000003<c<`0c<c<01@0c<c<2000000`06ATI>`000004ooooo`0300000?oooooooooo02;ooooo0_l0
0006ooooo`03ok2Wcon_Zm?o[j_C00;o[j_C00?o[ZkGojnXd?n_[=@00on_[=@00on^[mSo[jWBojj]
eP02ojj]eP;o[K3I00Co[j[Cojj^eon^[]Oo[ZkG1?n^Zm@00on^[]So[jWBojj/eP03ojj/eP03ojj_
fOn_Z]?o[j[C00?o[ZgF00?o[[3Iojn[e?n_Zm@00on^[]L00on^/=[o[jcDojn/e003ojn_f003ojja
f_n_[MGo[jgE00?o[k3H00Ko[k;Kok2^e_n`[]Ko/:kFojnafOna[M@4ok2`f003ojnbf_na[mKo/;7I
00;o/;7I0_n_]=`01On`/MSo/;?Kok2cfon`/m_o[kKN00?o/;?J00?o[kGMok6cf_na/mX00on_]Md0
0on^]moo/;GLok2eg003ojngg`09ojfihOn_]moo[kOOojnggon^^N7o[kOOojjihOl0003o[[WQ00;o
[K[S00Co[[WQojfjhon]^^?o[K[S0_n/^nD2ojfjh`;o[;_U0_n[_>H2ojbki@03oj^li_n/^nGoZkcV
00?oZkcV00?o0000ooooooooool09_ooool000Wooooo00@00000oooooooooooooooo3@00000801TI
6@03o`00000c<c<0<c<c00<0<c<c00D0000004a<C01<C4`0C4a<0000000306IVIP05o`00001oOgl0
Ogmo07moOol000000`2IVIT01@000000/k>c0;>c/`2c/k<000000180c<c<0P0000040;>c/`04o`00
002IVIT0VIVI09VIV@8000000`1oOgl2000000<0IVIV00?o00000000001<C4`0101<C4`2000000L0
<c<c00<0000001TI6@0I6AT02`0I6ATi000000Cooooo00<00000ooooooooool07oooool3o`0000Ko
oooo00Co/:C<ok2Wcon`Yloo/:O?0_n_Zm<01?n`YLco[jS@ojnXd?n_Z=02ojn/e005ok2UcOn_ZM;o
[jWBojnYd_n^[MH00_n_Y/l3ojnZd`03ojj^eon_Z=3o[jS@00?o[Z_D0on_ZM83ojj/ePCo[j[C00?o
[ZgFojnXd?n_Zm@00on_Zm@00on^[]Oo[jWAojn/e003ojn/e003ojn_f?n`Z];o[jgE00?o[jgE00?o
[k3Hok2/don`[]H00_n`[]H01?naZ]7o/JgDok6]e?na[M@2ok2`f005ok6/dona[mKo/JoFok6_e_n`
/MT00_na[]D3ok2af006ok2cfona/=Oo/K3Gok6`eon`/m[o/[3G1?na/mX00on_]Mgo/K;Iok2eg003
ok2eg003ojnggon`]Mco/;GL00;o[kOO00Go/;GLojnggon_]moo[kOOo`000002ojngg`?o[[WQ00Ko
[K[Sojjih_n^^N;o[[WRojfjhon^^N83ojfji0;o[;_U00Co[K_TojbkiOn/^nGo[;_U0_n[_>H00on/
_>Goooooo`00000Wooooo`002Oooool01000003oooooooooooooool>000000L06ATI00<0000003<c
<`0c<c<00`0c<c<01Ol00000C4a<04a<C01<C4`0000000<0IVIV00D0000007moO`1oOgl0Ogmo0000
000309VIV@050000002c/k<0/k>c0;>c/`0000002@3<c<`5000000H0c<c<00<000000;>c/`2c/k<0
0P2c/k<2000000<0VIVI0P00000307moO`030000001VIVH0IVIV0080IVIV00<0000004a<C01<C4`0
101<C4`00`000000<c<c03<c<`0503<c<`030000000I6AT06ATI00/06ATI>0000004ooooo`030000
0?oooooooooo01cooooo0ol00008ooooo`?o/:C<0_n`Yll4ok2Uc003ojnXd?naX/Wo/:G=00?o/:G=
00?o[jWBok2Sb_n`XlX00on_Y/l00on_Z]?o/:C<ok2Tc003ojnXd003ojj[e?n_YLko[jG>00?o[jWB
00?o[ZcFojnWcon_Yll00_n_Z]<01?n`Y<co[jS@ojnXd?n_Z=02ojn[e004ok2Vc_n_ZM7o[jWAojnY
d@;o[jcD00Co/:O?ok2Zd_n`Z];o/:[B0_n_[MD01OnaZ=3o/:cCok2/don`[=?o/:kF00?o/J[A0_na
[M@4ok6/d`03ok6_e_nbZm7o/JkE00?o/JkE00?o/;7Hok:^e?na/=L00_na/=L01?nc[M?o/[3Gok:`
eonb/=L2ok6cfP04ok:`e_na/]Wo/K;Iok6bf@;o/;GL00?o/K;Iok2eg?n`]M`01On`]M`00on_]moo
/KGLo`000003ojngg`03ojjihOn_^=oo[kSO00;o[[WR00Ko[kSOojjih_n^^N;o[[WRojfji?n^^^84
ojfki003ojbkiOn]^nCo[;cU00?o[;cU00?o0000ooooooooool09Oooool000Wooooo00@00000oooo
oooooooooooo3`00000701TI6@030000000c<c<0<c<c0080<c<c00<0000004a<C01<C4`00P1<C4`0
1@000000IVIV06IVIP1VIVH0000000<0Ogmo00D0000009VIV@2IVIT0VIVI000000030;>c/`030000
003<c<`0c<c<00@0c<c<0P0000050>KViP8000001@3<c<`2000000@0/k>c00<0000009VIV@2IVIT0
0P2IVIT01@000000Ogmo07moO`1oOgl0000000@0IVIV00<0000004a<C01<C4`0101<C4`00`000000
<c<c03<c<`0503<c<`800000300I6ATg000000Cooooo00<00000ooooooooool06_ooool2o`0000Wo
oooo0_n`X/T3ok2Tc003ok2WconaXLSo/J7800?o/:G<0onaX/T3ok2Uc@Co/:?:00?o[jK?ok6Paon`
Y<`00on`Y<`00on_Z=3o/:;9ojnUcP03ojnUcP03ojnYd_n`Xl_o[jO?00;o[jO?00Co[j[Cok2Tc?n`
Y<co/:C<0_n_Z=04ok2VcP03ojnYdOn`Y<_o/:O?00?o/:O?00?o/:[Bok6Uc?naYL`00onaZ=000on`
[=?o/JO>ok6WcP03ok6Zd@03ok6]e?nbZLoo/ZW?00;o/JcC00Co/jS>ok:[dOnbZm7o/Z_A0_na[]D0
1OncZm3o/ZkDok:^e?nb[]Co/K3G00?o/jgC0_nb/=L4ok:`eP03ok6bfOnc/=Ko/K;I00?o/K;I00?o
/;GLok:cfOnb/mT00_n`]M`01?nb/mWo/KGLok6eg?l00002ojngg`03ok6fg?n_^=oo[kSO00Go[kSO
00?o[[WRojnhh?n^^^800_n^^^82ojfki004ojjjhon]^nCo[K_Tojfki0;o[;cU0_n/^n@00ol0003o
ooooooooo`0Tooooo`002Oooool01000003oooooooooooooool?000000L06ATI00<0000003<c<`0c
<c<00`0c<c<01@000000C4a<04a<C01<C4`0000000<0IVIV00D0000007moO`1oOgl0Ogmo00000003
09VIV@050000002c/k<0/k>c0;>c/`0000001P3<c<`00`000000i^KV0>KViP060>KViP030000003<
c<`0c<c<00@0c<c<00<000000;>c/`2c/k<00P2c/k<01Ol00000VIVI09VIV@2IVIT0000000@0Ogmo
00<0000006IVIP1VIVH00P1VIVH2000000D0C4a<00?o000003<c<`0c<c<01P0c<c<00`0000006ATI
01TI6@0:01TI6CH000001?ooool00`00003oooooooooo`0Gooooo`?o00002Oooool00on`X<Oo/:;9
ok2Rb@02ok2Rb@03ok2Tc?naWlGo/J7800?o/J7800?o/:G<ok6NaOnaW/D00onaX/T00on`YLgo/Io5
ok6Oa@02ok2SbP04ok6L`_naX<Oo/J37ok6Pa`;o/:C<00Co/Ig4ok2RbOn`X/Wo/:;90_n_YLh01Ona
WlKo/:?;ok2Sbon`Xl_o[jO?00;o/:780on`Y<`00on_Z=3o/:;9ok2Rb@03ok2VcP?o/:C;0on`Yll4
ok6Uc003ok6Xd?nbY<[o/JO>00?o/JO>00?o/J[Aok:Vc?nbZLl00_nbZLl01?na[=?o/jS>ok>Xc_nc
Z<h2ok:[d@05ok>Wc?ncZm3o/j_@ok>[d?nb[]@00_ndZ/l3ok>]d`03ok:`eonc[M;o/jgB00;o/[3F
00Co]:gAok>`e_nc/=Ko/k3F0_na/]T00onc/=Go/[?Iok:cf@05ok:cf@;o00001?na]]`00on_^=oo
/KKMok6fg@02ojnhg`05ok6ggOn_^>3o[kSPojnhh?n^^^800_n_^N43ojjjh`03ojfki?n]^^?o[K[S
00;o[;_T00?o[K_Sooooool000009Oooool000Wooooo00@00000oooooooooooooooo3`00000801TI
6@0300000?l00000<c<c00<0<c<c00D0000004a<C01<C4`0C4a<0000000306IVIP050000001oOgl0
Ogmo07moO`0000000`2IVIT01@000000/k>c0;>c/`2c/k?o000000D0c<c<00<000000>KViP3Vi^H0
1`3Vi^H00ol000000000000000040<c<c003o`000000000000000080/k>c0P00000209VIV@800000
0`1oOgl2000000@0IVIV00?o000004a<C01<C4`00`1<C4`2000000L0<c<c0P00000;01TI6CD00000
1?ooool00`00003oooooooooo`0Fooooo`;o00002_ooool3ok2Pa`?o/:;90onaWlD2ok6Qb004ok6L
`_naW/Go/Ik5ok6Na@;o/J;900Go/Yc1ok6OaOnaWlGo/Io5ok2SbP03ok6L`P;o/J371?naWL@2ok2R
b@Co/Io600?o/:?;ok6M`on`XLP00on`XLP00on`Y<co/Ik5ok2Rb@03ok2Rb@03ok2Vc_naX<Oo/J37
00?o/:C;00?o/:O?ok6Rb?naX/P00_naYL`01?nbX<Ko/ZC:ok:Tb_nbY<X2ok6WcP05ok:Rb?nbY/co
/ZK<ok:Vc?nbZLl00_ncYLX3ok>XcP06ok:[dOncYlco/jO<ok>Wc?ncZm3o]:O;1?ndZ/l00onc[M?o
]:[>ok>]dP02ok>]dPCo]:gA00?o/k3FokF]dOne[M400onc/=D00onb/mWo];3EokB`e@03o`000003
ok:cfOl0003o/[?I00;o/KKL0_nc]=X00ona]]go/kGJok6gg@03ok6gg@03ojnhh?na]mko[kWQ00?o
[kWQ00Go[[[SojnihOn_^N7o[K[SojnjhP04ojfkh`03o`000?oooooooooo02?ooooo0009ooooo`04
00000?oooooooooooooooa000000200I6AT00`000000<c<c03<c<`0303<c<`050000001<C4`0C4a<
04a<C?l000000`1VIVH01?l00000Ogmo07moO`00000309VIV@050000002c/k<0/k>c0;>c/`000000
1@3<c<`00`000000i^KV0>KViP0:0>KViP030000003<c<`0c<c<00@0c<c<00D000000;>c/`2c/k<0
/k>c0000000309VIV@8000000`1oOgl2000000<0IVIV0P00000504a<C08000001`0c<c<00`000000
6ATI01TI6@0901TI6@03o`00000000000000034000001?ooool00`00003oooooooooo`0Fooooo`03
o`000?oooooo000000Sooooo0_n`W/H3ok2Pa`03ok2RbOnaWL?o/Ig300;o/Io51?naW<82ok6Na@Co
/Yc100?o/Io5ok:I__naW<800onaW<800onaX<Oo/YZook:J_`03ok6Ma003ok2RbOnaVl7o/I_100?o
/Io60onaWL<2ok2Qb004ok6K`?naW/Go/Ik5ok6Na@;o/:;900Co/Ic2ok6PaonaX<Oo/J370_n`Y</0
1OnaW/Co/J;8ok6Rb?naX/So/JG<00?o/Z360_nbY<X4ok:Rb003ok:Vc?ncXLKo/jG:00?o/jG:00?o
/jS>okBTb?ncYl`00_ncYl`01?neXlKo]:O;okBWbondYl/2okBZc`05okFVbOndZ/ko]:[>okBZc_nc
[M800_neZLd3okB]d@Co]JgA00?o/k3EokF]dOl000000_l000001_nf[]7o];7EokBaeOnd/MGo/[?I
o`0000?o/kCJ00Co];;Fok>ef_nc]M[o/kGJ0_na]md01?nc]M_o/KONok6gg_na]mh2ojnih@;o/KSN
00?o[kWQok2igon_^^800_n_^^82ojfkh`;o[[[R00?o0000ooooooooool08_ooool000Wooooo00@0
0000oooooooooooooooo4@00000801TI6@030000000c<c<0<c<c00<0<c<c00D0000004a<C01<C4`0
C4a<0000000306IVIP040000001oOgl0Ogmo000000<0VIVI00D000000;>c/`2c/k<0/k>c00000004
0<c<c0030000003Vi^H0i^KV00/0i^KV0`0000040<c<c004o`00002c/k<0/k>c0;>c/`8000000`2I
VIT00`000000Ogmo07moO`0207moO`03o`00001VIVH0IVIV0080IVIV00<0000004a<C01<C4`0101<
C4`00`000000<c<c03<c<`0503<c<`030000000I6AT06ATI00X06ATI<P000004ooooo`0300000?oo
oooooooo01Kooooo00Co0000oooooooooooo00001Oooool01?n_W/Ko/9k6ok2Na_n`W/H2ok2Pa`05
ok2K`_naWL?o/Ig3ok6M`onaWlD00_naV[l3ok6L`P03ok6NaOnbVKko/YVn00?o/Yc10onbVKh3ok6L
`PCo/YZo00?o/Ig4ok:H_?naVl400onaVl400onaWlKo/IVnok6I_P02ok6M``04ok2Qb?naVl3o/I_0
ok6K`0;o/Ik51?naW<82ok6Pa`Co/Ik400?o/J;8ok:M`_nbX<H00onbX<H00onbY<[o/io4ok>Oa002
ok:Rb004ok>N`_ncXLKo/j76ok>QaP;o/jG:00Go]:34okBTb?ndY<So]:C8ok>Wc003okFSaP;o]:O;
1?neY/T00ondZ/ko]ZK9okFYc@03okFYc@03okB]dOnfZ/go]Z[=00;o]JgA0ol000000one[M7o];3E
okJ^d@02okJ^d@06okBaeOnf[m7o];7FokBae_l0003o/kCJ0ond/]H00onc]M[o];?Gok>ef`03ok>e
f`03ok6gg_nb]]co/[KL00;o/KSN00Go/[OLok2igon`^Moo/;WOojnjhP02ok2ih0;o[[[R00?o/;[Q
o`000?ooool08oooool000Wooooo00@00000oooooooooooooooo4@0000000ol000006ATI01TI6@06
01TI6@030000000c<c<0<c<c0080<c<c00?o000004a<C01<C4`00P1<C4`01@000000IVIV06IVIP1V
IVH000000080Ogmo00D0000009VIV@2IVIT0VIVI000000030;>c/`050000003<c<`0c<c<0<c<c000
0000403Vi^H00ol00000c<c<0<c<c0020<c<c08000000`2c/k<01?l00000VIVI09VIV@2IVIT20000
00<0Ogmo00<0000006IVIP1VIVH00P1VIVH00ol00000C4a<04a<C00404a<C003o`00000c<c<0<c<c
00D0<c<c00<0000001TI6@0I6AT02P0I6ATa000000Cooooo00<00000ooooooooool05_ooool01ol0
003ooooooooooooooooo0000oooooon]WlP01?n_W/H2ok2NaPCo/9_20_naWL<4ok6J_`03ok6L`_nb
Ukco/YVn00?o/YVn00?o/Yc1ok:G^onbVKh00onbVKh00onaW<;o/YNkok:G^`02ok:J_`04ok:D^?nb
V;co/YRlok:H_0;o/I_100Ko/YJjok6I__naVKko/IVnok6M`onbUk/4ok6K`003ok6NaOnbVKko/YVn
00?o/Ic200?o/J37ok:J`?nbV/000onaW/@3ok:M`P?o/Z360oncWl@01?nbX/So/ik2ok>N`_ncW/82
ok>QaP04ok>Ub_ndX<Co]:34okBPa0;o]:C81?neXlH00ondYl_o]Z?5okJSa@02okFVb@04okNSa?nf
Y/Wo]ZK9okJVb@;o]JW=00?o]jK8okJZcOnfZ/d00ol00002okNZc@03okF]dOngZlgo]ZkA00;o]ZkA
00Oo^:c=okJ_dOnf[m7o]ZoAokBae_ng[m;o000000?o];;F0ond/mL2ok>ef`;o];CH00?o/[KLokBe
fOnb]m`00onb]m`00on`^Moo/[SMok2ih002ok2ih0Co/;[Q00?o0000ooooooooool08Oooool000Wo
oooo00@00000oooooooooooooooo4P00000801TI6@030000000c<c<0<c<c0080<c<c00<0000004a<
C01<C4`00P1<C4`01@000000IVIV06IVIP1VIVH000000080Ogmo00D0000009VIV@2IVIT0VIVI0000
00030;>c/`050000003<c<`0c<c<0<c<c00000004@3Vi^H2000000@0c<c<00D000000;>c/`2c/k<0
/k>c0000000409VIV@050000001oOgl0Ogmo07moO`000000101VIVH2000000D0C4a<00<0000003<c
<`0c<c<01@0c<c<00`0000006ATI01TI6@0:01TI6@03o`0000000000000002d000001?ooool00`00
003oooooooooo`0Eooooo`03o`000?oooooooooo00;ooooo00CoZj3<ojfOb?n]WlSo[Io80on_W/H0
0on`W/Ko/9_2ok2K`P03ok2K`P03ok6M`onaVKko/IVn00?o/IZo0onbUk`2ok:I_P04ok:E^OnbUk_o
/YNkok:G^`;o/YVn00Go/YBhok:G^onbUk_o/YNkok:J_`02ok:D^0?o/YRl00Co/I_1ok:F^_nbU[[o
/YJj0_naVKh3ok:G^`?o/I_01?nbVKh00onaW<;o/YNkok:J`003ok:J`003ok6Na?nbVKgo/YVm00?o
/Yg200?o/Z36ok>K_oncVkl00_ncWl@4ok>N`P03ok>Qa_ndWL3o]9g000?o]:3400?o]:C8okFO`_ne
Wl800oneXlH3okJSa@04okFVbOngXlCo]j?4okNSa0;o]ZK90_ngY/P3o`0000;o^:O80_ngZ/d01Oni
YlSo]j_=okN[cOngZlgo]ZkA00?o^:c=00Oo]ZoAokR]c_ng[m;o]joBo`000?ng[m;o];;F00;o]k3C
00?o];?GokNbe?nd]=P00_nd]=P01?ng/mGo];GIokBefOnd]MT2ok:gg005okBff_nb^=go/[SMok:h
gOn`^N000_na^Mh2ok2jh@03ok6igooooooo000002;ooooo0009ooooo`0400000?oooooooooooooo
oa8000002@0I6AT00`000000<c<c03<c<`0203<c<`030000001<C4`0C4a<0080C4a<00D0000006IV
IP1VIVH0IVIV0000000207moO`050000002IVIT0VIVI09VIV@0000000`2c/k<01@000000c<c<0<c<
c03<c<`000000180i^KV00<000000<c<c03<c<`00P3<c<`01@000000/k>c0;>c/`2c/k<0000000@0
VIVI00@0000007moO`1oOgl0Ogmo0P00000406IVIP030000001<C4`0C4a<00<0C4a<00<0000003<c
<`0c<c<01@0c<c<00`0000006ATI01TI6@0:01TI6Bl000001?ooool00`00003oooooooooo`0Eoooo
o`04o`000?ooooooooooojNSd@?oZj3<0on]WlP00on_W/Ko[Yc5ok2K`P04ok2K`P03ok2H_onaVKko
/IVn00;o/IVn00?o/IZook6F^onbUk`00_nbUk`00onbVKko/YFiok:E^@03ok:G^`04ok:I__nbU;So
/YBhok:D^0;o/YNk1?nbU;P2ok:H_0Co/YJj00?o/IVnok:D]onbUk/00onbUk/00onaVl3o/YFiok:E
^@02ok:I_P04ok:C]onbUk_o/YNkok:G^`;o/Y[000Co/YJiok:I_OnbVKgo/YVm0_nbWL801OncV;_o
/i^ook>K_oncVkoo/io400;o/iZm0oncW/84okBM`003okBPa?neW;ko]Io200?o]Io200?o]J?6okJO
`OnfWl400_nfXlD4okNSa004okJVbOl0003o0000o`0000;o]jK80onhYlP01_ngZ/go^JO8okVWb?ni
YlSo]j_=okVXb0?o^:c=00Co^ZW9okR]c_nh[Lko^:g>0_ng[m801?l0003o]k3CokN`dong/=<3okNb
e006okBdf?ng/mGo]k?EokNceOnd]MWo]kCG1?nd]]X01Onb^=go];OKokBgfona^Mko/kSM00Co/KWO
00?o0000ooooooooool08?ooool000Wooooo00@00000oooooooooooooooo4`00000801TI6@030000
000c<c<0<c<c00<0<c<c00<0000004a<C01<C4`00P1<C4`010000000IVIV06IVIP00000307moO`04
0000002IVIT0VIVI000000<0/k>c00D000000<c<c03<c<`0c<c<0000000C0>KViP03o`00003<c<`0
c<c<0080c<c<00D000000;>c/`2c/k<0/k>c0000000409VIV@03o`00001oOgl0Ogmo0080Ogmo00<0
000006IVIP1VIVH00P1VIVH00ol00000C4a<04a<C00304a<C0030000000c<c<0<c<c00D0<c<c00?o
000001TI6@0I6AT02P0I6AT00`00003o00000000000[000000Cooooo00<00000ooooooooool05Ooo
ool00ol0003oXZKIojNSd@02ojNSd@?oZj3<00?o[Io8oj^Mb?n^W<D00_n^W<D2ok2K`P04ojjI`On`
V;oo/9Rook2H_`;o/IVn1?naU[/2ok:G_0Co/YFi0_nbUk/4ok:D^003ok:G^oncT[Go/i:e00?o/YBh
00?o/YRlok>C]_ncTkH00onbU[X3ok:D]`;o/YNk00Go/i:eok:E^OnbUKWo/YFiok:I_P02ok:C]`?o
/YNk00Co/Y[0ok:F^OnbU[Wo/YJi0_nbVKd4ok>H^`;o/i^o1?ncV[d00oncW/;o]9VlokBI_002okBM
`004okFI^_neW;ko]IbnokFL_P;o]Io200Go]YbmokJO`OnfWl7o]Yo1okJSa@02okNO`004okNSa?l0
003o0000o`0000?o^:?400Co]jK8okVS`oniXl?o^:O80_njY<<3okVWb0?o^JS800Co^:c=okZYbOnj
ZLWo^ZW90_nh[Lh3okV^cP05o`000?ng/=?o^Jo@okV_d?ng/]@00_ni/=43okNce@?o]kCG0_nd]]X2
okJef003okBgfonf]m[o/kSM00;o/kSM0_na^Ml2ok:igP03o`000?oooooooooo01oooooo0009oooo
o`0400000?oooooooooooooooa@00000200I6AT00ol00000<c<c03<c<`0303<c<`050000001<C4`0
C4a<04a<C?l000000`1VIVH01?l00000Ogmo07moOol0000309VIV@05o`00002c/k<0/k>c0;>c/`00
00000`3<c<`00`000000i^KV0>KViP060>KViPKo00001@3Vi^H300000080c<c<00Co00000000002c
/k<0/k>c0P00000309VIV@030000001oOgl0Ogmo0080Ogmo00?o000006IVIP1VIVH00P1VIVH20000
00@0C4a<0P00000603<c<`8000002`0I6AT]000000Cooooo00<00000ooooooooool05Oooool00ol0
003oXZKIoj:Vf@03ojNSd@03oj^Pc?nWX<ooZig800;oZig80_n^W<D01?n`Vl;o[YW1ojjI`On^VL42
ok2H_`03ok6I__naU[_o/IJk00?o/IJk00?o/YNlok:D^?nbU;P00onbUKT00onbUk_o/i>fok>C]P03
ok:D^0?o/i:e0onbU;P4ok>C]P03ok:F^_ncTK?o/YBg00;o/YBg00Co/YNkok>B]OncT[Go/i:e0_nb
UKT4ok:C]`;o/YNk1?nbU[T00onbVKgo/iBgok>D]`03ok>H^`03ok>K_ondUkWo]9Ni00;o/iZm00Go
]9JhokBI_?ndVKco]9VlokBM`002okFI^P?o]Ibn00Co]Io2okJL_OnfW;go]Ybm0_nfWl401OngWl3o
0000o`000?l0003o]j?400;o^9no0_nhXl@01?niX;oo^J?3okVS`oniXl<4okZT``03okVWb?njYLCo
^ZG400;o^JS800Go^jK4okZYbOnjZLWo^ZW9okR]cP02okZ[bP;o^Jk>00Co^jc;o`000?ni[m3o^Jo@
1?ni/=401Ong/mGo^K;BokVbd_ng]=Oo^K?D00?o][GH00Ko^;GFokJgf_nf]m[o][OJok>hgOne^=/3
ok:igP03okBigOoooooo0000023ooooo0009ooooo`0400000?oooooooooooooooa@00000200I6AT0
0`000000<c<c03<c<`0303<c<`030000001<C4`0C4a<0080C4a<00@0000006IVIP1VIVH000000`1o
Ogl010000000VIVI09VIV@0000030;>c/`050000003<c<`0c<c<0<c<c0000000203Vi^H00ol00000
oooo0?ooo`030?ooo`;o00001P3Vi^H01@000000c<c<0<c<c03<c<`0000000<0/k>c0P00000209VI
V@030000001oOgl0Ogmo0080Ogmo0P00000406IVIP030000001<C4`0C4a<00<0C4a<00<0000003<c
<`0c<c<01@0c<c<00`0000006ATI01TI6@0:01TI6B/000001?ooool00`00003oooooooooo`0Eoooo
o`03o`000?nRY]WoXZKI00;oYj?A00CoXJ?GojNPconWX<ooYj3?0_n[WLP00on^W<Go[9_5ojjI`@03
ojjI`@03ok2H_on_Ukko/IJk00Go/IJk0onbU;P3ok:E^@Co/i>f00?o/YBhok>A/oncT[D00oncT[D0
0onbU;So/i6bok>C]P03ok>C]P?o/i6c0_nbU;L4ok>B]@03ok:E^OncTK?o/i6c00?o/Y>g00?o/YNk
ok>B]OncT[D00onbU[T3ok>D]`?o/iRk0ondUkT01?ncV[go]9JhokBF^?ndU[P2okBI_0Co]IVj0_ne
W;h4okJL_@03okJO`Ol0003o000000;o]io000Go^IbkokRO_onhWkoo^9nookRSa003okVP_`03okVS
`onjXKoo^Z6o00;o^ZC300Go^j:ookZUa?njYLCo^ZG4okVXb003ok^Va003okZYbOnlYlGo^Z_:00;o
^Z_:0onk[</01?l0003o^Jo@ok^^c?nk[/`2okV`d@04ok^_c_ni/];o^K;BokVbdP?o^K?D00Ko][GH
okRee_nh]MKo^;GFokJgf_nh]]P3okFhf`05ok:ig_nd^Mgo];WMokBigOl000008?ooool000Wooooo
00@00000oooooooooooooooo5@00000801TI6@030000000c<c<0<c<c00<0<c<c00<0000004a<C01<
C4`00P1<C4`010000000IVIV06IVIP00000307moO`040000002IVIT0VIVI000000<0/k>c00D00000
0<c<c03<c<`0c<c<000000060>KViP03o`00003oool0oooo00H0oooo00?o00000>KViP3Vi^H0103V
i^H01@000000c<c<0<c<c03<c<`0000000@0/k>c00?o000009VIV@2IVIT00P00000407moO`030000
001VIVH0IVIV0080IVIV00?o000004a<C01<C4`00`1<C4`00`000000<c<c03<c<`0503<c<`03o`00
000I6AT06ATI00X06ATI:P000004ooooo`0300000?oooooooooo01Gooooo00Co0000oooooonIYn3o
VJOP0onQXmL2ojNPc`03oj^Mb?nWWLco[9_500;o[9_50on^VL43ojnG_PCo/IJk00?o/I>hok:D^?nb
U;P00_nbU;P00onbUKWo/Y:eok>C]P03ok>C]P?o/i6c0_ncT[D01?ncSk7o/i6bok>A/_ncTK82ok>C
]P05ok>?/?ncTK?o/i6cok>A/onbU;L00_ncT;43ok>B]@?o/i6c0onbTkL4ok>B]@03ok:F^OncTK?o
/iBg00?o/iBg00?o/iRkokBC]OndTkD00_ndUkT4okBF^003okBI_?nfU[Ko]YJf00?o]IVj00Co]Ibn
okJH^OnfV;Wo]Ybm0ol00002okNL_004okNO`?niW;_o^IbkokVL^`;o^9no1?niX;l3okZQ_`04okZT
`onkX[oo^j:ook^R_`;o^ZG40onkY/@01OnmYL3o_:O5okbWaOnlYlGo^Z_:00;o_:W60onk[</00ol0
003o^jk<ok^^c004ok^_cP05okVbd_nk/M3o^k7@okVce?nk/m800onh]MH01Onj]=Co^;KHokRff?nh
]]So]KSK00;o]kSJ0_nd^Md00onf^M_oooooo`00000Oooooo`002Oooool01000003ooooooooooooo
oolD00000003o`00000000006ATI00L06ATI00<0000003<c<`0c<c<00`0c<c<00`000000C4a<04a<
C00204a<C0040000001VIVH0IVIV000000<0Ogmo00@0000009VIV@2IVIT000000`2c/k<01@000000
c<c<0<c<c03<c<`0000000D0i^KV00?o00000?ooo`3oool01`3oool3o`0000@0i^KV00Ko00000<c<
c03<c<`0c<c<o`00000000030;>c/`040000002IVIT0VIVI09VIV@8000000`1oOgl2000000<0IVIV
00<0000004a<C01<C4`00`1<C4`00`000000<c<c03<c<`0503<c<`030000000I6AT06ATI00X06ATI
:@000004ooooo`0300000?oooooooooo01Cooooo00Co0000oooooooooooooooo0_nIYn000onQXmOo
UjGOoj6Qe002oj6Qe0;oYig<0on/VlD00on^VL7o[9S2ojnG_P03ojnG_P03ok6F^on`U;_o/I>h00;o
/I>h0_nbU;P4ok:B]@;o/i>f00Go/i2bok>A/oncTK?o/i6cok>B]@02ok>?/@?o/i6b00Co/i>fok>?
/?ncSk3o/hn`0_ncTK<3ok>@/@?o/i:e1?ncTK<00onbTkOo/i2aok>B]@03ok>B]@?o/i6c0_ncU;L0
1OndT;7o]9>eokBC]OndTkGo]9Ni00;o]9>d0ondU[P3okJF]P?o]IVj00Go]YRio`000?l0003o0000
okJL_@02okRI^0;o]ibl1?niW;/00onhWkoo^YfkokZM^`02okVP_`;o^ifk0_njXKl4ok^R_`04okZU
a?nlXkoo_:>ook^Va0?o_JG00_nlYlD4okbYaP04ok^/bonmZlSo_J_8o`0000;o_Jg90_nk[lh01?nm
[l_o^k7@ok^ad?nk/M03ok^cdP05okRee_nj]=Co^[CDokZde?nh]]P00_ni]]H00ong^=[o^KSHokJi
f`03okJif`03ooooool0003ooooo01gooooo0009ooooo`0400000?oooooooooooooooaH000002@0I
6AT00ol00000<c<c03<c<`0303<c<`050000001<C4`0C4a<04a<C?l000000`1VIVH01?l00000Ogmo
07moOol0000309VIV@04o`00002c/k<0/k>co`0000<0c<c<00<000000>KViP3Vi^H00`3Vi^H00ol0
0000oooo0?ooo`0:0?ooo`03o`00003Vi^H0i^KV0080i^KV00<000000<c<c03<c<`00P3<c<`01@00
0000/k>c0;>c/`2c/k<0000000@0VIVI00<0000007moO`1oOgl00P1oOgl01@000000IVIV06IVIP1V
IVH0000000D0C4a<00<0000003<c<`0c<c<01@0c<c<00`0000006ATI01TI6@0:01TI6BP000001?oo
ool00`00003oooooooooo`0Dooooo`04o`000?ooooooooooooooo`;oRJWZ0onGYMl3oj6Qe0;oYig<
00?o[9_5ojRKbOn/V<800_n/V<82ojnG_P04ojfF_on`U;_o/9Bkok2D^`;o/I>h00?o/YBhok:B]Onb
T[D00onbT[D01?ncTkKo/i2bok>@/_ncT;82ok>A/`Co/hna0_ncTK84ok>?/0;o/i6c1?ncT;400onc
T[Go/hj_ok>>[`03ok>A/`?o/i2a0_ncT[D01OndSjoo/i6cok>A/oncTK?o/iBg00;o]92a0ondTkD3
okBC]0?o]9Jh1?nfU[H3o`0000;o]YRi00Go^9JdokRI^?nhVKSo^9VhokNL_002okVI]`?o^Ibk0onj
WK/01OniX;oo^ifkok^M^onkWK_o^Z6o00;o_9nk0onkX[l3okbS_`Co_JG000?o_:O5okjV`_nnY/80
0_nlZLH01onoZ<?o_J_8okf[b?nmZlSo_Jg9o`000?nm[LT01?nm[l/01Onk/M3o_K7>okfac_nk/m;o
_K?@00?o^[CD00Co_;GBokVfe_ni]]Ko^KKF0oni^=P2okJif`;o^;WJ00?o0000ooooooooool07?oo
ool000Wooooo00@00000oooooooooooooooo5`00000801TI6@030000000c<c<0<c<c00@0<c<c00@0
000004a<C01<C4`000000`1VIVH010000000Ogmo07moO`00000309VIV@040000002c/k<0/k>c0000
00@0c<c<00<000000>KViP3Vi^H00`3Vi^H00ol00000oooo0?ooo`0:0?ooo`03o`00003Vi^H0i^KV
0080i^KV00<000000<c<c03<c<`00P3<c<`01@000000/k>c0;>c/`2c/k<0000000<0VIVI00<00000
07moO`1oOgl00`1oOgl01@000000IVIV06IVIP1VIVH0000000D0C4a<00<0000003<c<`0c<c<01@0c
<c<00`0000006ATI01TI6@0:01TI6BL000001?ooool00`00003oooooooooo`0Dooooo`03o`000?oo
oooooooo00;ooooo0_n9ZNX2oiNUg`;oXJ7D00?oU:?Ooj6OdonQWm<00onXVlT2ojbH`P03ojnG__n]
U[oo[IJo00?o/9Bk00?o/I>hok2B^?nbT[D01OnbT[D4ok>@/P;o/i6c1?ncSk400oncTK;o]8j^ok>?
/003ok>?/003ok>A/ondSZko]8j^00;o/i2a00Co]8f]ok>>[oncSZoo/hj_0_ncTK<01OndSJko/i2a
ok>@/OncT;7o/i:e00?o]8n_0_ncTK<4okB@/@;o]9>e1?ndTk@00ondU[So]Y:bokJB/P03o`0000?o
]YFe00Co]YRiokRF]?nhU[Co^9Jd0_nhVKP4okVI]`03okVL^onjV[Oo^YZg00;o^Yfk1?nkWK/4okbO
^`03ok^R_onmX;_o_J2k00;o_:>o00Co_Z:lokfU`?nmYL3o_jBm0onnY/801OnlZLKo_jS3oknX`ono
Z<?o_J_800;o_j[500?o0000okn/aono[<L00_nm[l/01?o0[lWo_K7>okfac_nm/Lh3okfcd005okZd
e?nl]M;o_;GBokbed_ni]]H00_nk]mD00oni^=So^[SGokRifP02okRifP03okVjf_oooooo000001go
oooo0009ooooo`0400000?oooooooooooooooaL000002@0I6AT00`000000<c<c03<c<`0303<c<`05
0000001<C4`0C4a<04a<C00000000`1VIVH010000000Ogmo07moO`00000309VIV@040000002c/k<0
/k>c000000<0c<c<00<000000>KViP3Vi^H00`3Vi^H00ol00000oooo0?ooo`0;0?ooo`03o`00003V
i^H0i^KV0080i^KV00<000000<c<c03<c<`00P3<c<`01Ol00000/k>c0;>c/`2c/k<0000000<0VIVI
00<0000007moO`1oOgl00`1oOgl01Ol00000IVIV06IVIP1VIVH0000000D0C4a<00?o000003<c<`0c
<c<01@0c<c<00`0000006ATI01TI6@0:01TI6BH000001?ooool00`00003oooooooooo`0Dooooo`03
o`000?oooooooooo00Cooooo00?oJjOdoh:Vjon2Y^/00onDXml2oj6Od`;oZ9_900?o[9S2ojRIa_n]
U[l00on]U[l2ok2D^`?o/9:h1?nbT[D2ok:@/`?o/i2b00?o/i6cok>?/?ncSk000oncSk43okB>[P;o
/hn`00Go]8f]okB>[_ndSZko]8j^ok>@/@02okB=[@?o/hj_00Co/i6cokB=[_ndSJko]8f^0_ncT;44
okB?[`;o/i6c1?ndT;400ondTkGo]I2`okF@/002okBC]005okJ@[ol0003o0000o`000?nfU[H00_ng
T[43okJE]@Co^9Jd00?o^9VhokVF/oniU[<00_niVKL01OnjUk?o^YZgokZJ]onjV[Oo^Yfk00;o^i^g
0onkWK/4okbO^`?o_J2k00Co_:>ookjR_?nnX[co_JG00onoY;d2okjV`P?o_jS300So`JS0oknZaOno
Z/Go_j[5okn/aol0003o_jc7okf_b`?o`:o900Co_K7>oknac?no/Lco_K?@0ono/lh00onl]M;o_[GA
ok^ge@02ok^ge@?o^[SG00Ko^;WJokVjf_ni^][o^K[Jooooool0000Looooo`002Oooool01000003o
oooooooooooooolG00000003o`00000I6AT06ATI00L06ATI00<0000003<c<`0c<c<00`0c<c<01@00
0000C4a<04a<C01<C4`0000000<0IVIV00<0000007moO`1oOgl00P00000209VIV@030000002c/k<0
/k>c008000000P3<c<`00`000000i^KV0>KViP020>KViP03o`00003oool0oooo00`0oooo0_l00003
0>KViP8000000`3<c<`010000000/k>c0;>c/`2c/k<200000080VIVI00?o00000000001oOgl00P1o
Ogl00`000000IVIV06IVIP0206IVIP800000101<C4`2000000H0<c<c0P00000:01TI6@03o`000000
0000000002<000001?ooool00`00003oooooooooo`0Dooooo`03o`000?oooooooooo00Gooooo00?o
>i[coh:Vjon2Y^/00_nDXml2oj6Od`03ojRKbOnPWM7oZ9W600;oZ9W60on]U[l00on`U;_o[YBlok2B
^002ok2B^0?o/Y:e0onbT;<3ok>@/P?o/hn`0_ncSk401OndSJko]8j^okB>[_ndSZko/hn`00;o]8f]
0ondSZh4okB=[@;o/hj_1?ndSJh00oncT;7o]8f/okB=[003okB?[`03ok>A/ondSZko]8j^00;o]92a
00Co]Hj]okF@/?neT;3o]I2`0ol00003okJB/PCo]i:a0_nfUKD4okRF]0?o^IJc00Co^IVgokZG/onj
Uk?o^YNc0_njV[L4ok^K]`03ok^M^onlW;Oo_9bg00;o_9nk0_nnWKL2okfP^`?o_Z:l1?noY;d01?nn
Y/;o`:Jnol2V__noZ<<3ol6X`006oknZaOo2Z/;o`Z[2okn/aol0003o`Zg50oo0[lT3oknac0?o_k?>
00Go`KC=okjedOnn]M7o_[GAok^ge@02okfge003okZheonl^MOo_;WG00;o^K[J00?o^k_Iooooool0
00007?ooool000Wooooo00@00000oooooooooooooooo6@00000801TI6@030000000c<c<0<c<c00<0
<c<c00<0000004a<C01<C4`00P1<C4`01@000000IVIV06IVIP1VIVKo000000<0Ogmo00@0000009VI
V@2IVIWo00000`2c/k<010000000c<c<0<c<c?l000040>KViP03o`00003oool0oooo00d0oooo00?o
00000>KViP3Vi^H00P3Vi^H01@000000c<c<0<c<c03<c<`0000000@0/k>c00D0000009VIV@2IVIT0
VIVI0000000307moO`030000001VIVH0IVIV00<0IVIV00<0000004a<C01<C4`00`1<C4`00`000000
<c<c03<c<`0503<c<`030000000I6AT06ATI00T06ATI90000004ooooo`0300000?oooooooooo01Co
oooo00?o0000ooooooooool01_ooool2oc^Jl`;oNj?]0_nBXMh3oj2Md@?oZ9W600?o[IJoojVGa?n^
U;`00_n^U;`3ok2B^003ok:B]OnaTKGo/Y2c00?o/Y2c00?o/i2bok>?/?ncSk000_ncSk001?ncSk7o
]8f^okB=[_ndSJh2okB>[PCo]8f]0_ndSZh01OndS:_o]8f]okB=[OndSJgo/hj_00;o]8b[0ondSJh3
okB=[0?o]8n_0ondSZh00ondT;7o]Hj]okF>[@03o`0000Co]Y2_0_nfT[801OngT:ko]i:aokNB/Ong
T[7o]YFe00;o^9>a0_nhU[@01?niTk3o^IJcokVF/oniU[<4okZG/`03okZJ]onkV;?o^iRc00;o^i^g
00Go_IVcokbL]onlW;Oo_9bgokbO^`03okjM]`03okfP^onoWkSo_inh00;o_Z:l00Co`:6ioknT_Ono
Y;go_jBm0oo0Y[h4ol6X`0?o`Z[200Go_jc7o`000?o2[LGo`Zg5ol2_b@02ol:_a`04oknac?o2//[o
`[;:oknccP?o`KC=00?o_[GAol6gd?nm]m@00_nm]m@3okbie`Co^k_I00?oooooo`000?ooool06_oo
ool000Wooooo00@00000oooooooooooooooo6@00000901TI6@030000000c<c<0<c<c00<0<c<c00<0
000004a<C01<C4`00P1<C4`01@000000IVIV06IVIP1VIVH000000080Ogmo00D0000009VIV@2IVIT0
VIVI000000020;>c/`050000003<c<`0c<c<0<c<c0000000103Vi^H00ol00000oooo0?ooo`0=0?oo
o`03o`00003Vi^H0i^KV0080i^KV00@000000<c<c03<c<`0c<c<0P0000030;>c/`050000002IVIT0
VIVI09VIV@0000000`1oOgl00`000000IVIV06IVIP0306IVIP030000001<C4`0C4a<00<0C4a<00?o
000003<c<`0c<c<01@0c<c<00`0000006ATI01TI6@0901TI6B<000001?ooool00`00003ooooooooo
o`0Cooooo`03o`000?oooooooooo00Sooooo0_l2Omh2og^Sk@;oTZ7N0onPWM400onXVLKoX9_?ojVG
a002ojVGa0;o[YBl0_n`T[P01?n^Tk[o/I6eok6A]OnaTKD3ok:@/`Go/hn`1?ndSJh2okB>[P05okB<
[?ndSJgo]8f]okB=[OndSZh00_ndS:/3okB=[@?o]8b[0ondSJh4okB=[003okB?[oneS:_o]8j^00;o
]8j^0ol000001?neSZgo]I2`okF@/?nfSZ`3okJ@[`03okJB/_ngT:ko]i2^00?o]i:a0onhTk401?nh
U[Co^I>`okVC/?niTk02okVF/`04okZD/?njUk?o^YNcokZG/`?o^iRc00Co^i^gokfI/onmVK?o_IVc
0_nlW;L4okjM]`?o_inh00Go_Z:lol2Q^Oo0XKWo`:6ioknT_@02ol6S^`03ol2V__o2Y[co`ZJl00?o
`JS000?o`jRnol:Z`_o2Z/800_o2[LD00ol0003oa:k3ol:_a`02ol:_a`?o`[;:0oo1]<d01Oo4]/go
`KO@ol6gd?o1]m3o_KOD00;o_kWC00?o_;WGokjje_nn^]H00_nk^mT2okblf@03o`000?oooooooooo
01Wooooo0009ooooo`0400000?oooooooooooooooaX000002@0I6AT00ol00000<c<c03<c<`0303<c
<`030000001<C4`0C4a<0080C4a<00Go000006IVIP1VIVH0IVIV0000000207moO`050000002IVIT0
VIVI09VIV@0000000P2c/k<01@000000c<c<0<c<c03<c<`0000000@0i^KV00?o00000?ooo`3oool0
3@3oool00ol00000i^KV0>KViP020>KViP030000003<c<`0c<c<0080c<c<00D000000;>c/`2c/k<0
/k>co`00000309VIV@06o`00001oOgl0Ogmo07moOol000000000101VIVH00ol00000C4a<04a<C003
04a<C0030000000c<c<0<c<c00D0<c<c00<0000001TI6@0I6AT02@0I6ATR000000Cooooo00<00000
ooooooooool04oooool00ol0003oooooooooo`0<ooooo`03odFIlombXNkoLZ7^00;oT9oN0onPVll2
ojVGa003ojjD_?nYU/;o[Y>j00;o[Y>j0onaTKD3ok:@/`Co/hn`0_ncSZl3okB=[P03okB>[_ndS:co
]8b/00?o]8f]0ondS:/3okB=[@Co]8b[00?o]8f^okF<Z_neS:X00ondSJ`3okF<Z`;o000000Go]Xb[
okF>[OneSZgo]Hj]okF@/002okJ>[0?o]Y2_1?ngT:h00ongT[7o^92^okRC/@02okRC/@Co^I>`00?o
^IJcokZD/?njU;000onjUk<3ok^H/`Co_IVc00?o_9bgokjK]?nnVk@00_nnWKL2oknM]0;o_inh1?o0
XKT3ol6S^`Co`ZJl00Co`JS0ol>X__o3Z;ko`Z[20_o4Zl401Oo2[LGoa:k3o`000?o4[/?o`Zo700;o
a;3600Co`[;:olBcbOo4/lWo`KC=0oo4]/d01?o1]m3o`kS@ol>hd?no^M<2ol6jd`03okjje_o0_=Oo
_;cI00;o_;cI00?o_[kJooooool000006_ooool000Wooooo00@00000oooooooooooooooo6P000009
01TI6@030000000c<c<0<c<c00<0<c<c00<0000004a<C01<C4`00P1<C4`01@000000IVIV06IVIP1V
IVH000000080Ogmo00D0000009VIV@2IVIT0VIVI000000020;>c/`030000003<c<`0c<c<0080c<c<
00D000000>KViP3Vi^H0i^KVo`00000@0?ooo`03o`00003Vi^H0i^KV0080i^KV00<000000<c<c03<
c<`00P3<c<`01@000000/k>c0;>c/`2c/k<0000000<0VIVI00<0000007moO`1oOgl00P1oOgl00`00
0000IVIV06IVIP0206IVIP030000001<C4`0C4a<00<0C4a<00<0000003<c<`0c<c<0100c<c<00`00
00006ATI01TI6@0901TI6B8000001?ooool00`00003oooooooooo`0Cooooo`03o`000?oooooooooo
00gooooo00?oE`00og:Qk_mbXNh00_n@Wmh2oj2Kc`03ojVGa?nPV/koZIK200;oZIK20on^TkX2ok6A
]@Co/Y2c0_ncSk03ok>>[`?o]8f^0ondS:`3okB=[@Co]8b[00?o]8f]okF;Z_neRjX00ondS:/3okF<
ZP;o]8f/00Go]X^Yo`000?l0003o0000okB>[P02okJ<Z`?o]Hj]0onfSZ`3okJ@[`Co]i2^0onhT:h2
okRC/@04okVA[OniTk3o^I>`okVC/0Co^YB`00?o^YNcok^E/?nkUK000_nkV;<01?nmUk3o_IVcokfI
/onmVK<3okjK]005okjM]onoWKCo_ifdoknM]?noWkP00_o1WkH2ol2Q^@;o`Z6g0_o1Xk/01?o4Y;Wo
`ZJlol:V_?o5Y[/3ol>X_P?oa:_10oo4[/<01?l0003oa;36olB`a_o4/<H3olBcb@?oa;K=00Coa[S=
ol>hd?o3^=3o`kS@0oo1^]<3ol2le`06okblfOnn_][o_[kJokjnf_oooooo00006Oooool000Wooooo
00@00000oooooooooooooooo6`00000901TI6@030000000c<c<0<c<c00<0<c<c00<0000004a<C01<
C4`00P1<C4`01@000000IVIV06IVIP1VIVH000000080Ogmo00D0000009VIV@2IVIT0VIVI00000002
0;>c/`030000003<c<`0c<c<0080c<c<00@000000>KViP3Vi^Ko00004@3oool00ol00000i^KV0>KV
iP020>KViP030000003<c<`0c<c<0080c<c<00D000000;>c/`2c/k<0/k>c0000000309VIV@030000
001oOgl0Ogmo0080Ogmo00<0000006IVIP1VIVH00P1VIVH00`000000C4a<04a<C00304a<C0030000
000c<c<0<c<c00@0<c<c00<0000001TI6@0I6AT02@0I6ATQ000000Cooooo00<00000ooooooooool0
4oooool00ol0003oooooooooo`0?ooooo`03oeX00?mWWNooIig_00;oSIkO0onPV/h2ojVF`P?o[Y>j
00?o/I6eojnB^?nbT;<00onbT;<00oncSk3o/Xnaok>>[`03ok>>[`03okB=[_ndSJgo]8b/00?o]8b/
00?o]8f]okF<ZoneS:/00ondS:/3okF;ZP;o]8b[00Co]X^YokF<Z_neS:[o]HbZ0ol000000onfRjWo
]Hb[okF<Z`03okJ<Z`?o]Hj]1?nfSZ`00onfT:oo]hj/okN>[002okN@[P05okR?ZonhT:ko^92^okR@
[_nhTk400_niTJd3okVC/0Co^YB`0onkUK000onkV;?o_IN`okfG/003okfI/`?o_Y^d1?noWK@3ol6O
]P05ol2Q^Oo2XKOo`Z6gol:Q]oo1Xk/00_o4Y;T01Oo2Y[coaJJkolFV^oo5Y[_o`jRn00;oaZVm00So
a:_1olJ/`?o6[<3oa:k3olN_`ol0003oajo3olB`aP;oak;600Coa;?9olNebOo7]LWoa;K=0oo6^<d0
1?o3^=3oaK_@olFkd?o1^]<2ol>me003ol2leoo1_]Oo`KkG00;o_[kJ00?o_l3Jooooool000006Ooo
ool000Wooooo00@00000oooooooooooooooo6`00000901TI6@030000000c<c<0<c<c00@0<c<c00D0
000004a<C01<C4`0C4a<0000000406IVIP040000001oOgl0Ogmo000000<0VIVI00@000000;>c/`2c
/k<000000`3<c<`01@000000i^KV0>KViP3Vi^Ko00000140oooo00?o00000>KViP3Vi^H00P3Vi^H0
0ol00000c<c<0<c<c0020<c<c0050000002c/k<0/k>c0;>c/`0000000`2IVIT00`000000Ogmo07mo
O`0207moO`03o`00001VIVH0IVIV0080IVIV00<0000004a<C01<C4`00P1<C4`00`000000<c<c03<c
<`0503<c<`030000000I6AT06ATI00T06ATI80000004ooooo`0300000?oooooooooo01?ooooo00?o
0000ooooooooool04Oooool2ofNMk`;oSIkO0_nPV/h3ojVF`P03ojjC^_nZUL3o[i:h00;o[i:h0_nb
T;<01?n`TKKo/Xnaok:?/OnbSk43ok>>[`?o]8f]0ondS:`3okF<Z`;o]8b[00Go]X^YokF;Z_neRj[o
]H^ZokB<Z`02okJ;Z@?o00001?nfRjT2okF<Z`Co]Xb[00?o]Hj]okJ<Z_nfS:X00onfSZ`3okN>[004
okN@[_nhSj_o^8n[okR?Z`;o^92^1?niTJd00oniTk3o^Y:]okZB[@02okZD/004okbC[OnkUK3o^iF`
ok^E/0Co_IN`00?o_IVcokjI/OnnVK400_nnVk@01?o0Vk7o_ifdoknM]?noWK@3ol6O]PCo`Z6g0oo4
Y;T4olFV^`?oaZVm0oo6[<03olN_``04o`000?o7//Koak;6olNbaP?oakG90oo6^<d01?o8^lkoaK_@
olFkd?o5^m03ol>me0?o`KkG0ono`=X2ooooo`03o`000?oooooooooo01Kooooo0009ooooo`040000
0?oooooooooooooooa`000002@0I6AT00`00003o000003<c<`0403<c<`050000001<C4`0C4a<04a<
C00000000`1VIVH01Ol00000Ogmo07moO`1oOgoo00000080VIVI00Go00000;>c/`2c/k<0/k>co`00
00030<c<c0040000003Vi^H0i^KV0>KViP;o0000403oool00ol00000i^KV0>KViP020>KViP800000
0`3<c<`01Ol00000/k>c0;>c/`2c/k?o000000<0VIVI00<0000007moO`1oOgl00P1oOgl00`000000
IVIV06IVIP0206IVIP03o`00001<C4`0C4a<0080C4a<0P00000603<c<`8000002P0I6ATO000000Co
oooo00<00000ooooooooool04oooool00ol0003oooooooooo`0Cooooo`03o`UlhOmJVO3oX9[>00;o
X9[>00?oZIK2oj2IcOnZUL000_nZUL02ojnB^003ok:@/on`TKKo/96f00?o/Xna0_ncSZl01?ncS[3o
]8f]okB=[OndSJd2okB<[005okF<[?neS:_o]Hb[okF<ZondS:/00onfRjT2okF;ZP?o000000?o]X^Y
okF<Z_neS:X01?nfRjT00oneS:_o]X^XokJ;Z003okJ<Z`?o]XbZ0_nfSZ`01?ngSJWo]hj/okN>[?ng
SZ`4okR?Z`;o^92^1?niTJd3okZB[@04okZD/?nlTjgo_9>]okbC[@;o^iF`1?nmUk03okjI/@05okjK
]?o0Vk7o`9^aol2K/OnoWK@00_o2WK82ol6O]P05ol>O]?o2XKOo`Z6gol:Q]oo5X[H00_o4Y;T00oo6
YKOoaJJkolFV^`02olNX^P;oaZVm00Cob:^lolJ/`?o6[<3obJno0oo7[l<01Ol0003oak;6olZea_o:
]LKoakG900;obKS:00Goa[S=olRkc_o8^lkob;_>olFkd002olNmd@04ol>me?o5_mGoaKoEol6ne`;o
`/7I00?o_l3Jol32g?o0`]`00_ooool00ol0003oooooooooo`0Eooooo`002Oooool01000003ooooo
oooooooooolM000000T06ATI00<0000003<c<`0c<c<0100c<c<01Ol00000C4a<04a<C01<C4`00000
00<0IVIV00D0000007moO`1oOgl0Ogmo0000000209VIV@050000002c/k<0/k>c0;>c/`0000000`3<
c<`00`000000i^KV0>KViP020>KViP03o`00003oool0oooo00h0oooo00?o00000>KViP3Vi^H00`3V
i^H01@000000c<c<0<c<c03<c<`0000000<0/k>c00D0000009VIV@2IVIT0VIVI0000000407moO`03
0000001VIVH0IVIV0080IVIV00<0000004a<C01<C4`00`1<C4`00`000000<c<c03<c<`0503<c<`03
0000000I6AT06ATI00P06ATI7P000004ooooo`0300000?oooooooooo01;ooooo00?o0000oooooooo
ool05_ooool00omJVO3oRigPoh^Mh003oj2Ic@;oZYG000?o[i:hoj^D__n`TKH00on`TKH2ok:?/@04
ok>>[oncS[3o/hj`ok>>/0;o]8f]00Co]8b/okF<[?neS:co]Hb/0_neS:/3okJ;Z@?o00001?nfRjT0
0oneS:[o]X^XokJ;Z@03okJ;Z@?o]X^X0_nfS:/01OngRjSo]XbZokJ<Z_nfS:[o]Xj/00?o]hfY0_ng
SZ`4okR?Z`03okR@[_niSj_o^Hn[00;o^I6]00Co^Y2[okZB[OnjTZgo^Y:]1?nlTjd00onkUK3o_IF^
okfE[P02okfG/004oknG[_nnVK7o_YVaokjI/@Co`9^a0oo2WK801Oo1WkKo`indol>O]?o3WkCo`Z6g
00;oaJ:f00Coa:BiolJU]oo6YKOoaJJk0oo7Z;X01?o6ZKgob:^lolR[_?o6[<03olV__`04olN_`oo:
//?ob[;3o`0000;ob[G60oo9^<X3olRkcP06olZocoo7_M7oakgAolNmdOo8`M?oaKoE0_o6`mL01?o2
`MWo`lCJol?4f_o0`]`2ol35g@03ooooool0003ooooo01Kooooo0009ooooo`0400000?oooooooooo
oooooah000002@0I6AT00`000000<c<c03<c<`0303<c<`030000001<C4`0C4a<0080C4a<00D00000
06IVIP1VIVH0IVIV0000000307moO`040000002IVIT0VIVI000000<0/k>c00D000000<c<c03<c<`0
c<c<000000030>KViP03o`00003oool0oooo00l0oooo00?o00000>KViP3Vi^H00`3Vi^H01Ol00000
c<c<0<c<c03<c<`0000000<0/k>c00D0000009VIV@2IVIT0VIVI0000000407moO`03o`00001VIVH0
IVIV0080IVIV00<0000004a<C01<C4`00`1<C4`00ol00000<c<c03<c<`0403<c<`030000000I6AT0
6ATI00T06ATI7@000004ooooo`0300000?oooooooooo01;ooooo00?o0000ooooooooool05oooool0
0on5_?SoRigPoh^Mh002oj2Ic@03ojZE`?nQVLgoZiBn00;oZiBn0on`TKH2ok:?/@Co/hj`0_ndSJd4
okF<[0;o]Hb[0ol000000onfRjWo]H^ZokJ;Z004okJ;Z@?o]X^X0onfRjT3okJ;Z004okJ<ZongRjSo
]h^XokN;Z0;o]XbZ1?ngSJT00ongSZco^8fYokR=Z@03okR?Z`?o^Hn[00Co^I6]okZ@ZonjT:_o^Y2[
0_njTZd01?nlTZ_o_9>]okbC[OnlTjd3okfE[P04okfG/?noUjko_iN^oknG[P;o_YVa1?o0Vk43ol:M
/PCo`ind0oo5X[H3olJU]`CoajRj0oo8Zk`3olV__`05olbb`?o://?ob[;3olZb`ol000000_o:]LH0
1Oo<^LOobKS:olblboo<_<_ob;_>00?ob[o?00?oakgAolS1doo8`M<00oo6`mL3ol?4fP?o`<GM0_oo
ool00ol0003oooooooooo`0Dooooo`002Oooool01000003ooooooooooooooolO000000T06ATI00<0
000003<c<`0c<c<00`0c<c<00`000000C4a<04a<C00204a<C0050000001VIVH0IVIV06IVIP000000
0`1oOgl010000000VIVI09VIV@0000030;>c/`050000003<c<`0c<c<0<c<c?l000000`3Vi^H00ol0
0000oooo0?ooo`0?0?ooo`03o`00003Vi^H0i^KV0080i^KV00<000000<c<c03<c<`00P3<c<`01@00
0000/k>c0;>c/`2c/k?o000000<0VIVI00?o00000000001oOgl00P1oOgl00`000000IVIV06IVIP02
06IVIP03o`00001<C4`0C4a<00<0C4a<00<0000003<c<`0c<c<0100c<c<00`0000006ATI01TI6@09
01TI6A`000001?ooool00`00003oooooooooo`0Booooo`03o`000?oooooooooo01Wooooo00?oBiC`
ohRMhOn8WN400onQVLd2oj^D_P?o/96f00?o/Xnaok6@]?naT;@00oncS[000ondSJgo]8j^okF<[002
okF<[0?o000000Co]Hb[okJ;ZOnfRjWo]X^Y0onfRjP3okJ;Z@?o]X^X0_nfRjT01?ngRjOo]X^XokJ;
Z?nfRjP4okN;Z0;o]XbZ00Go^8bXokN=ZOngSJWo]hfYokN>[002okR=Z@;o^8n[00Co^XjYokV?Zoni
Sj_o^Hn[1?njT:/00onjTZgo_9:[okbBZ`03okbC[@?o_IF^1?noUjh00onnVK7o`IV_ol6I[`02ol2K
/@;o`Y^`0_o2WK800oo4W[7o`indol>O]002olJQ/`;oaJ:f00CoajBeolJU]oo6YKOobJNg0oo7Z;X0
1Oo;Zk[ob:^lolR[_?o<[[gobJno00?oc;;000Cob[;3olffa?o=]/Co00000_o<^LL3olblb`?ob[o?
0_o<`m801?o8`M?ob/GFol[5e_o6`mL2olO7fP04ol?4f_o4amgoa<OMol35g@;o`<OO0_ooool00ol0
003oooooooooo`0Cooooo`002Oooool01000003ooooooooooooooolO000000T06ATI00<0000003<c
<`0c<c<00`0c<c<00`000000C4a<04a<C00304a<C005o`00001VIVH0IVIV06IVIP0000000`1oOgl0
10000000VIVI09VIV@0000030;>c/`050000003<c<`0c<c<0<c<c00000000`3Vi^H00ol00000oooo
0?ooo`0?0?ooo`03o`00003Vi^H0i^KV0080i^KV00<000000<c<c03<c<`00P3<c<`01@000000/k>c
0;>c/`2c/k<0000000@0VIVI00D0000007moO`1oOgl0Ogmo0000000406IVIP030000001<C4`0C4a<
0080C4a<00<0000003<c<`0c<c<01@0c<c<00`0000006ATI01TI6@0901TI6@03o`00000000000000
01P000001?ooool00`00003oooooooooo`0Booooo`03o`000?oooooooooo01Wooooo0_nF_O82ohRM
h@;oXIW=0on[U;h00on`TKKo[9Bmok6@]002ok6@]0?o/hj`0ondSZh2o`000004okF<[?neS:_o]Hb[
okF<Z`;o]X^Y00Co]XbZokJ;Z?nfRjSo]X^X0_nfRjT01OngRjSo]X^XokJ;Z?nfRjSo]X^Y00?o]h^W
0_nfRjP01OnhRjOo]h^XokN;Z?ngRjSo]XbZ00;o^8bX0ongSJT3okR=Z@04okR?ZonjSZWo^XjYokZ>
Z@;o^Hn[00Go^hnYokZ@ZonjT:_o^Y2[okZB[@02okbBZ`;o_9>]0_nmTj/2okfE[P04oknF[?noUjko
_iN^oknG[P?o`IV_00Go`9^aol:K/?o2Vk3o`Y^`ol:M/P02olBN/@05ol>O]?o6XK?oaZ6colJQ/oo5
X[H00_o7Y;D01Oo6YKOobJNgolVW]oo9YkOoajRj00;obj^j00?ob:^lolb^_Oo<[[d01?o<//03olff
a005olnjaOl0003ockk9olnnbOo<_</00_o>`Lh01?o:_looc<?Bolc3d_o>b=D3ol[5eP05ol_:fOo7
am[oal_LolO;g?o4amd00_o4bml01Oo0amoo`<[Rol3:h_oooooo000001Gooooo0009ooooo`040000
0?oooooooooooooooal0000000?o000001TI6@0I6AT01`0I6AT00`000000<c<c03<c<`0303<c<`03
0000001<C4`0C4a<00<0C4a<00D0000006IVIP1VIVH0IVIV0000000307moO`040000002IVIT0VIVI
000000<0/k>c00D000000<c<c03<c<`0c<c<000000030>KViP;o0000403oool00ol00000i^KV0>KV
iP020>KViP030000003<c<`0c<c<0080c<c<00Go00000;>c/`2c/k<0/k>c0000000409VIV@050000
001oOgl0Ogmo07moO`000000101VIVH00`000000C4a<04a<C00204a<C0030000000c<c<0<c<c00D0
<c<c00?o000001TI6@0I6AT02@0I6ATJ000000Cooooo00<00000ooooooooool04_ooool00ol0003o
ooooooooo`0Jooooo`03oiJml_nK_O3o=hk_00?oXIW=00CoZiBnoj6Ic?n/U;go[9Bm1?naT;@00onc
S[3o/Y2co`000002o`0000;o]Hb/00Go]Hj]okF<ZoneS:_o]Hb[okJ;Z@02okJ<ZP?o]X^X00Co]X^Y
okN;Z?ngRjSo]h^X0_nfRjP4okN;Y`03okJ;Z?nhRjOo^8^W00?o]h^X0onhS:P3okN=Z@?o^8fY1?nj
SZT00oniSj_o^hnYok^?Z@03okZ@Z`Co_9:[00Co_9>]okfCZonmTj_o_IF^0_noUZ`3oknG[P?o`IV_
1?o2Vk03olBN/@CoaZ6c0oo7Y;D4olVW]`?obj^j0oo<[[d00oo?/kkoc;;0olbb`002olng`P06olff
a?o?^/Gock[5olnnbOl0003ockk90oo>`Lh00oo@a]7oc<?Bolk8e@02olk8e@03ol[5e_o;b]WobloM
00?oal_L00GoalkPolC;goo3c^?o`lkSol3:hP02oko<i@03ooooool0003ooooo01?ooooo0009oooo
o`0400000?ooooooooooooooob4000002@0I6AT00ol00000<c<c03<c<`0303<c<`0300000?l00000
C4a<00<0C4a<00D0000006IVIP1VIVH0IVIV0000000307moO`040000002IVIT0VIVI000000<0/k>c
00D000000<c<c03<c<`0c<c<000000040>KViP03o`00003oool0oooo00h0oooo00?o00000>KViP3V
i^H00P3Vi^H00`000000c<c<0<c<c0020<c<c0050000002c/k<0/k>c0;>c/`000000102IVIT01Ol0
0000Ogmo07moO`1oOgl0000000@0IVIV00<0000004a<C01<C4`00P1<C4`00ol00000000003<c<`05
03<c<`030000000I6AT06ATI00T06ATI6@000004ooooo`0300000?oooooooooo01;ooooo00?o0000
ooooooooool07?ooool01?nK_O3o=hk_ohFMhon5WN<3oj6Ic0;o[9Bm0_naT;@3o`000004ok:@/ond
SZko]8j^okF<[0?o]Hj]0_neS:/4okJ<ZP;o]X^X1?ngRjP2okJ;Z0Co]h^W00?o]X^XokR;YonhRjL0
0ongRjP4okR<Z003okN=ZOniSJOo^HfW00;o^8fY00Go^XjWokZ>ZOnjSZWo^XjYokV?Z`02ok^?Z@?o
^Y2[1?nlTZ/3okfCZ`03okfE[_noUZco_iJ/00;o_iN^0_o1V:d2ol6I[`04ol>J[_o2Vk3o`Y^`ol:K
/0?oa9ja00Goaj2aolJQ/oo6XK?oaZ6colVT/`02olNT]@03ol^W]Oo9YkOobJNg00;oc:^h0_o;ZkX0
1Oo>[k_oc:jmolnc__o?/kkoc;;000?ockO20oo?^/D01OoB`<So0000om74cOoAa<goc/7>00;od<KA
00GodLgEolk8eOo>b=Goc/kIol_:f@03ol_?g@05olO;g?o7c^3oaM;TolGBi?o3c^<00_o1d>H01?no
c>Go_LkWokg>iol0000Dooooo`002Oooool01000003ooooooooooooooolQ000000T06ATI00<00000
03<c<`0c<c<0100c<c<00`000000C4a<04a<C00204a<C0050000001VIVH0IVIV06IVIP0000000`1o
Ogl01Ol00000VIVI09VIV@2IVIWo00000080/k>c00Go00000<c<c03<c<`0c<c<000000050>KViP03
o`00003oool0oooo00d0oooo00?o00000>KViP3Vi^H00P3Vi^H00`000000c<c<0<c<c0020<c<c003
0000002c/k<0/k>c0080/k>c00D0000009VIV@2IVIT0VIVI0000000307moO`030000001VIVH0IVIV
0080IVIV00<0000004a<C01<C4`00`1<C4`00`000000<c<c03<c<`0503<c<`030000000I6AT06ATI
00P06ATI6@000004ooooo`0300000?oooooooooo01;ooooo00?o0000ooooooooool07Oooool2oijn
k`;oQIgS0_nQVL`01On/U;go0000o`000?l0003o[IBm00?o/Y2c0_ndSZh4okF>[@;o]Hb[00Co]Xj]
okJ<Z_nfS:[o]XbZ0_nfRjP01OngS:Wo]h^XokN;Z?ngRjSo]X^X00Go]h^W1?nhRjL00ongRjSo^HbW
okR<Z003okR<Z0?o^HfW00?o^8fYokZ>YonjSZL00onjSZT4ok^?Z@03okZ@ZonlTJWo_96Y00;o_9:[
00Co_Y>ZokfCZonmTj_o_I>[1?noUZ`01?noUjko`IR]ol6H[Oo1VJl3ol>J[P04ol:K/?o5WJooaIf_
olBN/@;oaj2a0_o6XK<2olVT/`04olNT]Oo;YkGobjNeolVW]`?oc:^h00?obj^jolj_^oo>[k/00oo?
/kh3olng`P;odkc400Sock[5om;0b?oB`<SodLC=o`000?oAa<goe<_Aom36d@;odLgE0oo>c]T01Oo>
e=kobloMol_?gOo:dn7oalkP00;oaM;T00?o`mGWol7@i_o1d>H00_nod^T01?nmc^Oo^loYok_?jOl0
000Cooooo`002Oooool01000003ooooooooooooooolR000000T06ATI00<0000003<c<`0c<c<0100c
<c<00`000000C4a<04a<C00204a<C0050000001VIVH0IVIV06IVIP0000000`1oOgl010000000VIVI
09VIV@0000030;>c/`050000003<c<`0c<c<0<c<c00000001@3Vi^H00ol00000oooo0?ooo`0=0?oo
o`03o`00003Vi^H0i^KV0080i^KV00<000000<c<c03<c<`00P3<c<`00`000000/k>c0;>c/`020;>c
/`040000002IVIT0VIVI000000@0Ogmo00<0000006IVIP1VIVH00P1VIVH00`000000C4a<04a<C003
04a<C0030000000c<c<0<c<c00D0<c<c00<0000001TI6@0I6AT0200I6ATH000000Cooooo00<00000
ooooooooool04Oooool00ol0003oooooooooo`0Oooooo`;oXKk^00Go88GZo`000?l0003o0000oj:J
c004ojfD_@;o/Y2c00?o]8j^ok>@/_ncT;800oneSZd00oneS:_o]Xj]okJ>[@03okJ<ZP03okJ;Z?ng
S:Wo]hbY00?o]h^X1_ngRjL4okR;Y`03okN;Z?niS:Oo^HbW00?o^8bX0oniSJL00onhSJWo^XjWokZ>
Y`03okZ>Z@Co^hnY0onlTJT01?nlTZ_o_Y>ZokjCZ_nnTjX2okfCZ`Co_iJ/0oo1V:d4ol>J[P?oaIf_
00Goa9jaolNP/Oo7X;7oaj2aolJQ/`02olVT/`?objNe1?o<ZkP3olj_^`05om6d_?o?/kkod[S0om:h
`?o?]l800ooC_<@3om;0b006omG7c?oAa<go0000omC;dOoEd]KodLgE0_oBe=X01Oo>c]Woc]CNolkD
g_o=fN?ob]?Q00;ob=SU00CoaM;Tol?Eioo3eNOo`M3V0_nod^T01_nle>_o^loYok_?jOnid>cooooo
o`0001;ooooo0009ooooo`0400000?ooooooooooooooob8000002P0I6AT00`000000<c<c03<c<`03
03<c<`030000001<C4`0C4a<0080C4a<00<0000006IVIP1VIVH00P1VIVH01@000000Ogmo07moO`1o
Ogl000000080VIVI00D000000;>c/`2c/k<0/k>c000000030<c<c0030000003Vi^H0i^KV00<0i^KV
00?o00000?ooo`3oool0303oool00ol00000i^KV0>KViP030>KViP030000003<c<`0c<c<0080c<c<
00Go00000;>c/`2c/k<0/k>c0000000309VIV@030000001oOgl0Ogmo0080Ogmo00<0000006IVIP1V
IVH00P1VIVH00ol00000C4a<04a<C00304a<C0030000000c<c<0<c<c00D0<c<c00?o000001TI6@0I
6AT0200I6ATG000000Cooooo00<00000ooooooooool04Oooool00ol0003oooooooooo`0Oooooo`?o
000000?oX[k]oh6NiOn1W^D00_nRV/`3ojfD_@03ok:@/on^U;co/i2b00;o/i2b0oneSZd3okJ>[@?o
]XbZ0ongS:T3okN;Z0Go]h^W0_nhS:L3okR;Y`?o^HbW0_nhS:P01?njSJOo^HfWokV=YoniSJL4okZ>
Y`03okZ>ZOnkSjSo^hnX00?o^hnY0onlTJT4okjCZP03okfCZoo0UJ[o`9FZ00;o_iJ/00Co`YN[ol6H
[Oo1V:go`IR]1?o3VZh3olFM[`Coaj2a0oo9Y;<01?o<YkCobjNeol^W]Oo>[;H3olb[^004om2`^Oo>
[k_odKBlom6d_0?od[S000Koe/34om>la?oC_<Codkc4omK4b?oB`<P2omG7c006omS@d_oDbm7o0000
omGBe_oEfmcod]CJ0_oAfn001Oo>e=kocMWSolgIhoo9g^Sob=SU00;oaM_Y00Co`mGWol3Gjoo0en_o
_m;Y0_nle>/01OnkcnWo^M3/okW@k?oooooo000001;ooooo0009ooooo`0400000?oooooooooooooo
ob<000002P0I6AT00`000000<c<c03<c<`0303<c<`0300000?l00000C4a<0080C4a<00<0000006IV
IP1VIVH00P1VIVH01@000000Ogmo07moO`1oOgl000000080VIVI00H000000;>c/`2c/k<0/k>c0000
0?l000020<c<c0800000103Vi^H00ol00000oooo0?ooo`0<0?ooo`03o`00003Vi^H0i^KV00<0i^KV
00?o00000<c<c03<c<`00P3<c<`01@000000/k>c0;>c/`2c/k<0000000<0VIVI00<0000007moO`1o
Ogl00P1oOgl00`000000IVIV06IVIP0206IVIP030000001<C4`0C4a<00<0C4a<00<0000003<c<`0c
<c<0100c<c<00`0000006ATI01TI6@0901TI6AH000001?ooool00`00003oooooooooo`0Aooooo`03
o`000?oooooooooo01cooooo0ol00002ooooo`04oj:nkOnT_^coY;k/o`Eih0?oXY[<00Co[IBmoj:K
cOn^U;co[YBl1?ncT;800oneSZgo]96bokJ>[@03okJ>[@;o]XbZ1?ngS:T00ongRjSo^8fYokN;Y`03
okN;Y`?o^8bW0_nhRjL01OniSJOo^HbWokV<YoniS:Oo^8bX00?o^XfW0_niSJL4okZ>Y`?o^hnX0_nk
SjT2okf@Z0;o_96Y00Co_i:YokjCZ_nnTj[o_Y>Z0oo0UJX01OnoUZco`YN[ol:GZoo2Uj_o`IR]00;o
a9Z/0_o3VZh2olJM[P;oaIf_00?ob:2_olNP/Oo7X;400_o:Y;401?o9Y;?oc:NdolbW]?o;YkD3olj/
]P03olb[^?o@/;Wod;2i00?odKBl00?oe[_0om:h`?oF`<@00_oF`<@01OoC_<Coe/C8omK4b?oIcLgo
eLO<00;of=3B00KofM[Ho`000?oEfmcoeM_Lom?Sh_oAfn02olkQi@05olgIhoo9g^SobMkXolGRkOo5
fnT00_o1gNd01?o0en_o_MS^okgHk_nle>/2okWDkP05okW@k?nfd>go]]3]ooooool000004Oooool0
00Wooooo00@00000oooooooooooooooo9000000:01TI6@030000000c<c<0<c<c00<0<c<c00<00000
04a<C01<C4`00P1<C4`01@000000IVIV06IVIP1VIVH0000000@0Ogmo00Go000009VIV@2IVIWo0000
000000030;>c/`050000003<c<`0c<c<0<c<c0000000103Vi^H2o`0000`0oooo00?o00000>KViP3V
i^H0103Vi^H01@000000c<c<0<c<c03<c<`0000000<0/k>c00<0000009VIV@2IVIT00P2IVIT00`00
0000Ogmo07moO`0207moO`050000001VIVH0IVIV06IVIP0000001@1<C4`00`000000<c<c03<c<`05
03<c<`030000000I6AT06ATI00P06ATI5P000004ooooo`0300000?oooooooooo017ooooo00?o0000
ooooooooool06Oooool3o`0000Kooooo00CoY;k/ojFnjonU_^_o1GWP0_mnWnP2oj:Kc@?o[YBl0_nc
T;801?n_UKco]96bokBA/_ndTK83okJ>[@03okJ<Z_ngSZco]hj/00?o]hbY0onhSJT3okN;Y`?o^8bW
00Co^8^WokV=YoniSJOo^HfW0_niS:L4okZ=Y`03okV=YonkSZOo^hjW00?o^XjW0onkSjP01OnkSjWo
_I2Xokf@Z?nmT:So_96Y00;o_i:Y0onnTjX3ol2EZPCo`YN[00Co`IR]olBJ[?o4VZco`iZ^0oo6WJh0
1?o5WJoob:2_olRP[oo7X;43olZT/@03olVT/oo<YkCoc:Nd00CocZbf0oo@/;T01?oD]kcodKBlomJk
`?oF^l03omK0a0;of/W900Goe/C8omW=cOoIcLgofmODomS@dP02omWJf006omOSgol0003odn?Rom?S
h_o>jNWoc^7U0_o:i^/01Oo9g^SoaN;]ol3Sl?o0ho3o`Mg]00;o_=g`00Co_MS^okWHl?nif?3o^MC^
0_nfdnl00onfd>go/lo^ok??kP02o`00013ooooo0009ooooo`0400000?ooooooooooooooobD00000
2P0I6AT00`000000<c<c03<c<`0303<c<`030000001<C4`0C4a<0080C4a<00@0000006IVIP1VIVH0
IVIV0P00000307moO`050000002IVIT0VIVI09VIV@0000000`2c/k<01@000000c<c<0<c<c03<c<`0
000000D0i^KV00?o00000?ooo`3oool02P3oool00ol00000i^KV0>KViP030>KViP030000003<c<`0
c<c<0080c<c<00D000000;>c/`2c/k<0/k>c0000000409VIV@03o`00001oOgl0Ogmo0080Ogmo00D0
000006IVIP1VIVH0IVIV0000000504a<C0030000000c<c<0<c<c00D0<c<c00<0000001TI6@0I6AT0
200I6ATE000000Cooooo00<00000ooooooooool04Oooool00ol0003oooooooooo`0Fooooo`?o0000
2_ooool01?nU_^_oY[k[ojJnjonT_^`2ogjOj0;oXY_=0_n^U;`00oncT;;o[iFlojnE_003okBA/P;o
]Xj]00Co]I6bokN>[?ngSZco]hj/0_ngS:T01?nhSjco^8fYokR=ZOnhSJT2okN;Y`04okV=Z?nhS:Oo
^8bWokR<Y`Co^HfW0_niS:L4okZ=Y`03okV=YonkSZOo^hjW00;o^XjW00Co_8nWok^?Z?nkSjSo^hnX
1?nmT:P00onlTJWo_i:YoknBZ@02okjCZP;o`IBY0_o0UJX01?o3Uj[o`YN[ol:GZoo2Uj/3olBJ[0Co
aYf^0oo8X:l4olZT/@?oc:Nd00?od:ffolj/]_o>[;H00_oB/[T00oo@/;Woe;NlomBg_003omJk`003
om[4a?oF`<Cof/W900;of/W900KogMC?omW=cOoKemCofmODom_SfooIf]P2omOSg`06om?/i_l0003o
c^WYolkYjOo7k^kob^K[0_o4j?001OnmjO?o`>?`ok[Slonjho?o_=g`00;o^=gc00Co^MS`okGGlOnb
eO;o/]Gb0_ncd_001?nccnko/Lk_ok7>kol0000@ooooo`002Oooool01000003ooooooooooooooolV
000000X06ATI00<0000003<c<`0c<c<00`0c<c<00`000000C4a<04a<C00204a<C0030000001VIVH0
IVIV0080IVIV00D0000007moO`1oOgl0Ogmo0000000309VIV@050000002c/k<0/k>c0;>c/`000000
0`3<c<`00`000000i^KV0>KViP030>KViP?o00002@3oool00ol00000i^KV0>KViP040>KViP030000
003<c<`0c<c<0080c<c<00H000000;>c/`2c/k<0/k>co`000000000309VIV@030000001oOgl0Ogmo
0080Ogmo00H0000006IVIP1VIVH0IVIVo`000000000404a<C0030000000c<c<0<c<c00D0<c<c00?o
000001TI6@0I6AT0200I6AT00ol0000000000000000A000000Cooooo00<00000ooooooooool04Ooo
ool00ol0003oooooooooo`0Dooooo`;o00003oooool2ojJnj`06ojBnk?l0J]3oXY_=oj:KcOn^U;co
Xic>1?n_UK`2okBA/P03okJ>[OneTK;o]I6b00?o]hj/00?o]hbYokR?[?nhSj`00onhSJT01?ngRjOo
^HfXokV=Z?niSJP2okR<Y`Co^HfW00?o^HbWokZ=YonjSJL00onjSJL3ok^>Y`04okZ>YonlSjOo_8nW
okb?Y`;o^hnX00Co_Y6Xokf@Z?nmT:So_I2X1?noTZT01?nnTj[o`IBYol6DZOo0UJX2ol>GZP?o`YN[
0oo4VZ`01?o7WJgoaYf^olJM[_o6WJh3olRP[`06olbU/Oo:Y;7obZBaolZT/Oo>ZK?oc:Nd0_o@[KH0
1?o>[;Kod[:iom:b^OoB/[T3omBg_004omVo`OoF^l3of/C4om[4a0?of/W90_oMe<l00ooNhMOofmOD
om_Sf`02omS^hP06omOSgooCk>KodncVol_bk?l0003oank^0_noko800oo4j?3o_NWcokKXmP02ok[S
l`;o/=kg0_ncfo@01?n`f?Go/]Gbok;El_n_do<3ok3@l@03ok7>kon_c>oo0000013ooooo0009oooo
o`0400000?ooooooooooooooobH000002P0I6AT00ol00000<c<c03<c<`0303<c<`030000001<C4`0
C4a<0080C4a<00<0000006IVIP1VIVH00`1VIVH010000000Ogmo07moO`00000409VIV@05o`00002c
/k<0/k>co`00000000000`3<c<`00`000000i^KV0>KViP050>KViP03o`00003oool0oooo00H0oooo
00?o00000>KViP3Vi^H0103Vi^H00`000000c<c<0<c<c0020<c<c0030000002c/k<0/k>c0080/k>c
00D0000009VIV@2IVIT0VIVI0000000407moO`030000001VIVH0IVIV0080IVIV00<0000004a<C01<
C4`00P1<C4`00`000000<c<c03<c<`0503<c<`030000000I6AT06ATI00P06ATI50000004ooooo`03
00000?oooooooooo013ooooo00?o0000ooooooooool04_ooool3o`0001;ooooo0_nV_^X00onU_^_o
NJ7[ogVQj`03oj>LcP?o[iFl0_ndTK84okFA/P;o]hj/1?nhSj`2okR=Z@Co^HfX00?o^8bWokZ>Z?ni
SJL00oniSJL5okZ=Y`04ok^?YonkSZOo^hjWok^>Y`Co_8nW00?o^hnXokjAZ?nnTJP00onmT:P4oknB
Z@?o`IBY00?o`9FZol>GZ_o3UjX00_o2Uj/2olFJ[003olBJ[?o7WJgoaif]00;oaYf^0_o9XJl01Oo8
X:ooc:FaolbU/Oo<YK7obZBa00;ocZVc00?oc:Ndom2]]_o@[KH01?oB/[T01?oG^[goe;NlomVo`OoI
_l43om[4a004omk@booJbLWogMC?omgDc`;og^7G00?ofn?KomS^h_oHk^800_o?m^P01?oCk>Kobo;/
okCdlol00002oko_lP;o[nch00Go]^Sfok3Un?n/hOWo[>7iok3Nm`02ojgJm`04ok3HmOn]eOCo[MGd
ojoCl`;o[M3b0_n^c_42ojo<k`03o`000?oooooooooo00kooooo0009ooooo`0400000?oooooooooo
ooooobL000002@0I6AT00`000000<c<c03<c<`0403<c<`030000001<C4`0C4a<0080C4a<00<00000
06IVIP1VIVH00`1VIVH010000000Ogmo07moO`00000309VIV@030000002c/k<0/k>c0080/k>c00D0
00000<c<c03<c<`0c<c<000000070>KViP?o0000103oool00ol00000i^KV0>KViP060>KViP030000
003<c<`0c<c<0080c<c<00<000000;>c/`2c/k<00P2c/k<01@000000VIVI09VIV@2IVIT0000000@0
Ogmo00<0000006IVIP1VIVH00P1VIVH00`000000C4a<04a<C00204a<C0030000000c<c<0<c<c00@0
<c<c00<0000001TI6@0I6AT02@0I6ATC000000Cooooo00<00000ooooooooool04?ooool00ol0003o
ooooooooo`0?ooooo`?o00005Oooool3ojNnj@03ojJnjomiXN_oNJ7[00;oXic>0on_UK`00ondTK;o
/INlokFA/P03okFA/P;o]hj/1?nhSj`2okR=Z@Co^HfX00?o^8bWokZ>Z?njSZP00oniSJL4okZ=Y`?o
^hnW0_nkSZL01OnmT:So_8nWokb?YonlSjOo^hnX00;o_Y6X0_nmT:P2oknCZ0?o_i:Y0oo1U:T4ol>G
ZP04ol:GZoo5VZcoaIZ/olBJ[0?oaif]00CoaYf^olVQ[oo9XJoob:2_0oo<YK43oljY/`?od:ff00?o
eKFiom:b^OoB/[T00_oG^[d3omVo`@06omg;aooJa<Cog]3;omk@booPg]?ogMC?0_oNhML00ooLk]ko
d_STomS^hP02olofj0;o/OS]00OoXoC_okCdlon[lOKo0000ojC]nOn_k?SoZNOj00;oY^?k00Co[>7i
ojWLnOnYg?Wo[M[g0_n[eoL01?n]eOCo[=7dojcAm?n]d?86ooooo`03o`000?oooooooooo00gooooo
0009ooooo`0400000?ooooooooooooooobL000002P0I6AT00`000000<c<c03<c<`0403<c<`030000
001<C4`0C4a<0080C4a<00<0000006IVIP1VIVH00P1VIVH01@000000Ogmo07moO`1oOgl0000000<0
VIVI00<000000;>c/`2c/k<00P2c/k<010000000c<c<0<c<c03<c<`2000000P0i^KV1Ol000080>KV
iP030000003<c<`0c<c<0080c<c<00<000000;>c/`2c/k<00P2c/k<01@000000VIVI09VIV@2IVIT0
000000@0Ogmo00<0000006IVIP1VIVH00P1VIVH00`000000C4a<04a<C00304a<C0030000000c<c<0
<c<c00@0<c<c00<0000001TI6@0I6AT02@0I6ATB000000Cooooo00<00000ooooooooool04?ooool0
0ol0003oooooooooo`0<ooooo`?o00006Oooool01?nW_^WoZ;gYojRmjOnX_NT2ojNnjP;oM:?_00?o
[iFlojBNconaUk`00_naUk`3okFA/P03okN>[?nfT[7o]Y:a00?o^8n/00?o^8fYokV@[?niT:`00oni
SJP3okZ>Z0;o^HfW00Co^hnYokZ=YonjSJOo^XfW1?nkSjL00onkSZOo_I2Xokf@Z003okb?Y`Co_Y6X
00?o_I2XoknCZ?noTjP00_noTZT2ol6EZ@;o`IBY1?o3UjX3olFJ[0Coaif]0oo9XJl4olbU/@05om2[
/oo>ZK?ocZVcom>`]_o@[KH00ooE]KT01OoB/[WoekZmomNj_OoLa/?ofKo100;ogL_700Woh][?omk@
booPg]?oh=kComo]fooNhMOog>kNom;hi?o1o>H00_n/nND01OnGl^?o/OS]oj?dkonIko;oUNcg00;o
UNOk00Co0000oioSo?nOhocoY^?k0_nUg_/01?nYg?WoZ=ShojSHn?n[eoL2ojWBm@03ojcAm?oooooo
oooo00Kooooo00?o0000ooooooooool03Oooool000Wooooo00@00000oooooooooooooooo:000000:
01TI6@030000000c<c<0<c<c00@0<c<c00<0000004a<C01<C4`00P1<C4`2000000<0IVIV00@00000
07moO`1oOgl0Ogmo0P00000209VIV@030000002c/k<0/k>c0080/k>c00<000000<c<c03<c<`00P3<
c<`00`000000i^KV0>KViP0C0>KViP030000003<c<`0c<c<0080c<c<00<000000;>c/`2c/k<00P2c
/k<01@000000VIVI09VIV@2IVIT0000000@0Ogmo00<0000006IVIP1VIVH00P1VIVH00ol00000C4a<
04a<C00304a<C0030000000c<c<0<c<c00@0<c<c00<0000001TI6@0I6AT02@0I6ATA000000Cooooo
00<00000ooooooooool04?ooool00ol0003oooooooooo`09ooooo`?o00007_ooool3ojRmj@;oYkkY
00CoM:?_ojBNconTW/ooY9k?0_naUk`2okFA/P04ok:H_?nfT[7o]Y:aokJB/@;o^8n/00Co^9>bokV@
[?niT:co^I2/0_niSJP01OnjTJco^XjXokZ>Z?njSZSo^HfW00?o^hnY0_njSJL01OnlTJWo^hnWok^?
YonkSjOo^hjW00;o_I2X0onlSjL4okjAZ0?o_i>X00Go_i:Yol6EZOo1UJWo`IFYol6DZ@02olBHZ`?o
`iNZ0oo5VZ`4olNM[@?obJ6_00?ocZNaolbU/Oo<YK400_o@Zk<01?o>ZK?odk2fom>`]_o@[KH3omFe
^@;oekZm0_oLa/<3omg;a`04on;JcooRjmOoh=kComo]f`;oe_WQ00Wo`OgQojCgf_n6jm7o[?WUoiOb
hon9k>GoPnSZohCVl_n9iOT00_nEio/00onKgOgo0000oj3No002oj7Hn`03ojGHn_nUdoSoYM?h00;o
Ym?g3?ooool00ol0003oooooooooo`0=ooooo`002Oooool01000003ooooooooooooooolY000000X0
6ATI00<0000003<c<`0c<c<0100c<c<00`000000C4a<04a<C00304a<C0050000001VIVH0IVIV06IV
IP000000101oOgl01@000000VIVI09VIVOl00000000000<0/k>c00<000000<c<c03<c<`00P3<c<`0
0ol0000000000>KViP0B0>KViP030000003<c<`0c<c<0080c<c<00<000000;>c/`2c/k<00P2c/k<0
1@000000VIVI09VIV@2IVIT0000000@0Ogmo00<0000006IVIP1VIVH00`1VIVH00`000000C4a<04a<
C00204a<C0030000000c<c<0<c<c00D0<c<c00<0000001TI6@0I6AT0200I6ATA000000Cooooo00<0
0000ooooooooool04?ooool00ol0003oooooooooo`06ooooo`?o00008_ooool5ojRmj@05odl00?nT
W/ooY9k?ok6G_?nUXM400onbV;`3okJB/@03okR?[?nhTk;o^9>b00?o^I2/00Co^HfXokZA[?njTJco
^Y6/0_njSZP4ok^?Z@03okZ=YonlTJWo_96Y00?o^hnW1?nmT:P00onlSjOo_Y:XokjBZ003okjAZ0?o
_i>X1?o1UJT00oo1U:Woa9R[olBHZ`02ol>GZP;oaY^/00?oaIZ/olRO[Oo8Wjd00_o7WJd2ol^S[`04
olVQ[oo>Yk7ocZNaolbU/@?od:^c0ooC/;H3omFe^@;ofl2o00GoekZmomc6`ooLa/?oh]G;omg;a`02
on;Jc`08on;[eooIn]go`OkKomKihOo1oN7oY?OJohK[dOmQe^H2og?LmP04oggPmon9gogoRMomoi3Q
o@;oU]cn00CoVmgmoikHo?l0003oXMSk0_nSdoT00onUdoSoooooooooo`0=ooooo`03o`000?oooooo
oooo00gooooo0009ooooo`0400000?ooooooooooooooobT0000000?o000001TI6@0I6AT0200I6AT0
0`000000<c<c03<c<`0403<c<`030000001<C4`0C4a<00<0C4a<00D0000006IVIP1VIVH0IVIV0000
000407moO`050000002IVIT0VIVI09VIV@0000000`2c/k<00`000000c<c<0<c<c0030<c<c0800000
4@3Vi^H00`000000c<c<0<c<c0030<c<c0030000002c/k<0/k>c0080/k>c00Go000009VIV@2IVIT0
VIVI0000000407moO`030000001VIVH0IVIV0080IVIV00<0000004a<C01<C4`00`1<C4`00`000000
<c<c03<c<`0503<c<`03o`00000I6AT06ATI00P06ATI40000004ooooo`0300000?oooooooooo013o
oooo00?o0000ooooooooool00oooool3o`0002Kooooo1OnX_NT2ofjVl`?oYJ7A0onbV;`2okJB/@Co
^9>b0_niT:`4okZA[0;o^XjX00Go^i:/ok^?ZOnkSjWo^hnYokZ=Y`02okbAZ@?o^hnW1?nmT:P00onl
SjOo_Y:XokjBZ002okjAZ0;o`9BY0_noTjP4ol6EZ@?oa9R[00Go`iNZolJK[?o6VjcoaY^/olFJ[002
olRO[@05olNM[Oo;Xjoobj>_ol^S[oo9XJl00_o>Yk44om2[/`05omJe^?oC/;Kodk2fomVj^ooE]KT0
0ooK`;l02ooQclOog<K3on;EbooReL_oi>ODon;JcooRjmOofO[Mol7nfonKl/goL]fj00;oJMGg00Co
KMSfoh7Jo_n1f_koQ=cm0_n@fOl01?nBfokoVMKmoiWFoOnKeo`2oioAn@03oj7BnOl0003ooooo017o
oooo00?o0000ooooooooool03Oooool000Wooooo00@00000oooooooooooooooo:`00000:01TI6@03
o`00000c<c<0<c<c00@0<c<c00?o000004a<C01<C4`00`1<C4`01@000000IVIV06IVIP1VIVKo0000
00@0Ogmo00D0000009VIV@2IVIT0VIVI000000030;>c/`0300000?l00000c<c<00@0c<c<00<00000
0>KViP3Vi^H03P3Vi^H00`000000c<c<0<c<c0040<c<c0030000002c/k<0/k>c0080/k>c00D00000
09VIV@2IVIT0VIVI0000000407moO`03o`00001VIVH0IVIV0080IVIV00<0000004a<C01<C4`00`1<
C4`00`000000<c<c03<c<`0403<c<`030000000I6AT06ATI00T06ATI3`000004ooooo`0300000?oo
oooooooo00oooooo00Co0000oooooooooooooooo0ol0000[ooooo`;oZKgX00CoZ;gYojVmj?m^Y_?o
KZKc0_nUXM43ok:H_003okJB/OndV[go]9Zm00?o^9>b0_niT:`01OniUK;o^Y6/okZA[?njTJco^XjX
00;o^i:/0onkSjT4okbAZ@03ok^?YonnTZWo_Y:Y00?o_I2X0onnTZP01OnnTJSo`9BYol2DZOo0U:Wo
_i>X00;o`iNZ0oo1UJT3olBHZ`CoaY^/0oo8Wjd4ol^S[`?ocZNa00?odjnfom2[/oo@Zk<00_oF]KP0
0ooC/;KofKZkomVj^`03om_0_`;ohLo700SoiN?@on;EbooTimCoi>ODomgifoo2o]KoG<bRohCCo`;o
PMGo00CoP=OoohoDoon?e?ooS]Oo0_nGd_`00onHe?coWLoioig?n@03oik@n@05oioAnOoooooooooo
ooooool000004Oooool00ol0003oooooooooo`0=ooooo`002Oooool01000003oooooooooooooool[
000000X06ATI00<0000003<c<`0c<c<01@0c<c<00`000000C4a<04a<C00204a<C0030000001VIVH0
IVIV0080IVIV00D0000007moO`1oOgl0Ogmo0000000409VIV@03o`00002c/k<0/k>c0080/k>c00<0
00000<c<c03<c<`00P3<c<`00ol0000000000>KViP0>0>KViP030000003<c<`0c<c<00@0c<c<00<0
00000;>c/`2c/k<00P2c/k<01@000000VIVI09VIV@2IVIT0000000@0Ogmo00<0000006IVIP1VIVH0
0P1VIVH00`000000C4a<04a<C00304a<C0030000000c<c<0<c<c00@0<c<c00<0000001TI6@0I6AT0
2@0I6AT?000000Cooooo00<00000ooooooooool03oooool4o`0002kooooo1_nY_NP01OnX_NSoYJ7A
ojFQdOnbV;coYjCC00?o]9Zm0onhTk800oniT:co^IFbokVE/P03okZA[0?o^i:/0onkSjT4okbAZ@03
ok^?YonnTZWo_Y:Y00;o_I2X00Co_iB[okjBZ?nnTZSo_Y:X1?o0U:T00onoTjSo`iNZol>GZP02ol6E
Z@;oaIZ/0_o4V:/01?o7WJgoaY^/olJK[?o6Vj`3olRO[@06olfV/Oo;Xjoobj>_ol^S[oo@Z[?ocZNa
0ooC[kH00oo@Zk?oe[FhomJe^003omVj^`03omo9`ooK`;oohLo700;ohLo700GoiN?@on3gfOoTimCo
gOWKol;neP02oiC>o0;oT]3m00CoT=;noiW>n_nIc_[oV=3k0_nMboL2oig=n003oig?nOoooooooooo
00Kooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`0=ooooo`002Oooool01000003o
ooooooooooooool/000000X06ATI00<0000003<c<`0c<c<01@0c<c<00`000000C4a<04a<C00204a<
C0030000001VIVH0IVIV0080IVIV00@0000007moO`1oOgl0Ogmo0P00000309VIV@030000002c/k<0
/k>c0080/k>c00<000000<c<c03<c<`00`3<c<`00`000000i^KV0>KViP0<0>KViP030000003<c<`0
c<c<00@0c<c<00<000000;>c/`2c/k<00P2c/k<00`000000VIVI09VIV@0209VIV@050000001oOgl0
Ogmo07moO`0000001@1VIVH00`000000C4a<04a<C00304a<C0030000000c<c<0<c<c00@0<c<c00<0
000001TI6@0I6AT02@0I6AT>000000Cooooo00<00000ooooooooool03oooool2o`00037ooooo1onY
_NP01?mWZOKoYjCCojNTdonWY=<3okBJ_@03okRC/_nfW;ko^IFb00;o^IFb0onjTJ`4ok^B[003ok^?
ZOnmU:go_IB]00?o_96Y0onnTZT01?nmT:So_iB[oknDZonoU:/2okjBZ004ol:G[?o0U:Wo`9BYol2D
Z@?o`iNZ00Go`IFYolFJ[?o5VZcoaIZ/olBHZ`02olNM[@;oaY^/0_o:XJl01Oo8WjgocJJaolfV/Oo=
Y[7obj>_00;od:Zc00CocZNaom>_]_oC[kKodjnf0ooF]KP01?oL`koofKZkomo9`ooObL<2onCMc@05
on7?aooUhm3oh?OIon3gfOo4om<00_nGboX01?nDc_coW<[goic:monJc?T2oio8m@;oW/Wf00?oWL_g
ooooooooool02oooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo00cooooo0009oooo
o`0400000?ooooooooooooooobd000002P0I6AT00`000000<c<c03<c<`0403<c<`030000001<C4`0
C4a<00<0C4a<00<0000006IVIP1VIVH00P1VIVH00`000000Ogmo07moO`0207moO`050000002IVIT0
VIVI09VIV@000000102c/k<00`000000c<c<0<c<c0030<c<c0<000002P3Vi^H00`000000c<c<0<c<
c0050<c<c003o`00002c/k<0/k>c00<0/k>c00<0000009VIV@2IVIT00P2IVIT01Ol00000Ogmo07mo
O`1oOgl0000000@0IVIV00<0000004a<C01<C4`00`1<C4`00`000000<c<c03<c<`0503<c<`030000
000I6AT06ATI00P06ATI3P000004ooooo`0300000?oooooooooo017ooooo00?o0000ooooooooool0
;oooool8ojVmj0;oYjCC0_ndV[d00onXZ=Oo]YbnokJL_P04okVE/P03okZA[?nkUk?o^iNc00?o^i:/
0onmU:d2okbAZ@04okjF[_nnTZWo_Y:YokjBZ@Co_iB[00?o_Y:Xol:G[?o2Uj`00oo0U:T3ol>GZPCo
aIZ/00Goa9R[olNM[Oo7WJgoaif]olJK[002olZQ[`04olRO[Oo=Y[7ocJJaolfV/@?od:Zc0ooC[kH2
omVl_005omJe^?oL`koog<>oon?Fb_oObL<00_oTgLd01_oSm=OoaooBolOod_oPmmWoa?oCoio6m0;o
WLSf00GoX/Gboj36lonPa_?oX<Kcoio8m@0Booooo`03o`000?oooooooooo00kooooo00?o0000oooo
ooooool03?ooool000Wooooo00@00000oooooooooooooooo;P00000:01TI6@03o`0000000000<c<c
00@0<c<c0P00000404a<C08000000`1VIVH00ol00000Ogmo07moO`0207moO`040000002IVIT0VIVI
09VIV@8000000`2c/k<2000000H0c<c<100000050>KViP8000001`3<c<`00`000000/k>c0;>c/`03
0;>c/`030000002IVIT0VIVI0080VIVI00<0000007moO`1oOgl00P1oOgl00`000000IVIV06IVIP02
06IVIP030000001<C4`0C4a<00<0C4a<00<0000003<c<`0c<c<01@0c<c<00ol000006ATI01TI6@08
01TI6@03o`0000000000000000X000001?ooool00`00003oooooooooo`0Booooo`03o`000?oooooo
oooo02oooooo2OnY_NP01?mN[?WoZ:SGojRXeonXZ=L2okJL_P;o^IFb00Co]inook^G/onkUk?o^iNc
0_nkTZ`01OnlVKCo_IB]okfD[OnmU:go_96Y00?o_YJ^0_nnTZT01Oo0VJoo_iB[oknDZonoU:_o_Y:X
00;o`YN/0_o0U:T2olBJ[@;o`iNZ00CoaYf^olFJ[?o5VZcoaIZ/1?o7WJd3olZQ[`CocJJa00Godk2g
om2Z/oo@Z[?oe[Jiom>_]P03omVl_0?og<>o00CohmK:onC_e_oTgLgohoCG0_o7om800on2hJ_oY<;_
ojC2k`02oj?3l003oj;5l_oooooooooo01Kooooo00?o0000ooooooooool03Oooool00ol0003ooooo
ooooo`0<ooooo`002Oooool01000003oooooooooooooool_000000/06ATI00<0000003<c<`0c<c<0
100c<c<00`000000C4a<04a<C00304a<C0050000001VIVH0IVIV06IVIP000000101oOgl00ol00000
000009VIV@0209VIV@030000002c/k<0/k>c0080/k>c0P0000080<c<c0D000002@3<c<`00`000000
/k>c0;>c/`030;>c/`030000002IVIT0VIVI0080VIVI00<0000007moO`1oOgl00P1oOgl00`000000
IVIV06IVIP0206IVIP030000001<C4`0C4a<00<0C4a<00<0000003<c<`0c<c<01@0c<c<00`000000
6ATI01TI6@0801TI6@d000001?ooool00`00003oooooooooo`0Cooooo`03o`000?oooooooooo033o
oooo2OnY_NP2ojRXe`;o]Ybn00?o^IFbokNO_ongWkl00onkUk<01?nkTZco_9VdokbI]?nlVK@2okfD
[@Co_YJ^00?o_Y:Yol2I[oo0VJl00onoU:/4ol:G[004ol2DZOo4VZgoa9Z]ol>GZP;oaYf^0oo5VZ`0
0oo9XK3oaif]olNM[@02olbV/P;obZ6_00?ocj^dolfV/Oo=Y[400_oC/;L00oo@Z[?oe[JiomJf^@03
omVl_0;ohLo700Kog<>oon?Fb_oSe/[oi>oFolcoe?mngZH3ojG1kP03ojC2kooooooooooo01[ooooo
00?o0000ooooooooool03Oooool00ol0003oooooooooo`0<ooooo`002Oooool01000003ooooooooo
ooooool`000000/06ATI00<0000003<c<`0c<c<0100c<c<00`000000C4a<04a<C00304a<C0040000
001VIVH0IVIV06IVIP800000101oOgl010000000VIVI09VIV@2IVIT2000000@0/k>c00<000000<c<
c03<c<`04`3<c<`00`000000/k>c0;>c/`040;>c/`030000002IVIT0VIVI0080VIVI00<0000007mo
O`1oOgl00P1oOgl00`000000IVIV06IVIP0206IVIP030000001<C4`0C4a<00<0C4a<00?o000003<c
<`0c<c<01@0c<c<00`0000006ATI01TI6@0801TI6@`000001?ooool00`00003oooooooooo`0Doooo
o`;o0000<Oooool9ojVmj003oe>^n_nY[M[oZJgJ00Co]ino0_nkUk<4okbI]0;o_IB]00Go_YbeokjF
[_nnUZko_YJ^okjBZ@02ol2I[`?o_iB[1?o2Uj`3olBJ[@05ol>GZ_o6WJkoaYf^olJM[_o5VZ`00_o9
XK001Oo7WJgoc:JbolbV/_o<Y[;obZ6_00;ocj^d00CocJJaom>`]ooC/;Oodk2g0ooF][T00ooMb<?o
fKblon7?a`02on7?a`05onCYe?oSe/[oi>oFolcoe?mngZH00_nU`>d00onU`Nkoooooooooo`0Moooo
o`03o`000?oooooooooo00cooooo00?o0000ooooooooool03?ooool000Wooooo00@00000oooooooo
oooooooo<00000000ol000006ATI01TI6@0901TI6@03o`00000c<c<0<c<c00@0<c<c00?o000004a<
C01<C4`00`1<C4`00`000000IVIV06IVIP0206IVIP030000001oOgl0Ogmo0080Ogmo00<0000009VI
V@2IVIT00P2IVIT00`000000/k>c0;>c/`020;>c/`0300000?l0000000000180c<c<00<000000;>c
/`2c/k<0102c/k<00`000000VIVI09VIV@0209VIV@030000001oOgl0Ogmo0080Ogmo00?o000006IV
IP1VIVH00`1VIVH00`000000C4a<04a<C00304a<C0030000000c<c<0<c<c00D0<c<c00<0000001TI
6@0I6AT0200I6AT;000000Cooooo00<00000ooooooooool05_ooool00ol0003oooooooooo`0_oooo
o`[oZKgX0_nY[MX3okNO_`03ok^G/oniX/7o^J;100?o_9Vd00?o_IB]okjL]OnnW;D00onnUZh4ol2I
[`03oknDZoo3Vk3o`i^`00;o`YN/00CoaInaolBJ[Oo4VZgoa9Z]1?o6WJh3olVQ/0Coc:Jb0oo?Zk@4
om>`]`04om[0`?oF][WogLS3omg8``;ohn;B00KohLo7onCYe?oTjMCodOoGojNojonV_n`Tooooo`03
o`000?oooooooooo00_ooooo00?o0000ooooooooool03?ooool000Wooooo00@00000oooooooooooo
oooo<@00000;01TI6@030000000c<c<0<c<c00@0<c<c00<0000004a<C01<C4`0101<C4`00`000000
IVIV06IVIP0206IVIP060000001oOgl0Ogmo07moOol000000000102IVIT00`000000/k>c0;>c/`04
0;>c/`030000003<c<`0c<c<00l0c<c<00<000000;>c/`2c/k<0102c/k<00`000000VIVI09VIV@02
09VIV@030000001oOgl0Ogmo00<0Ogmo00<0000006IVIP1VIVH00P1VIVH00`000000C4a<04a<C003
04a<C0030000000c<c<0<c<c00D0<c<c00<0000001TI6@0I6AT02@0I6AT00ol00000000000000007
000000Cooooo00<00000ooooooooool05oooool00ol0003oooooooooo`0_ooooo`_oZKgX00?oAjoh
okNO_on[/]h00oniX/43okbI]0Co_Ybe00?o_YJ^ol6O]oo0VJl00oo0VJl3ol>K/004ol:G[?o5Wk7o
aInaolFO/@;oa9Z]1?o6WJh3olVQ/005oln]^?o<Y[;oc:JbolbV/_oB/kX00_o?Zk@00ooF^Kgodk2g
om>`]`02om[0`003omJf^OoMb<?ogLS300;ohn;B00?oe_kJonCYe?oAomL0:?ooool00ol0003ooooo
ooooo`0:ooooo`03o`000?oooooooooo00cooooo0009ooooo`0400000?oooooooooooooooc800000
2`0I6AT00`000000<c<c03<c<`0403<c<`030000001<C4`0C4a<00@0C4a<00<0000006IVIP1VIVH0
0P1VIVH00`000000Ogmo07moO`0207moO`030000002IVIT0VIVI0080VIVI0P0000050;>c/`<00000
3@3<c<`00`000000/k>c0;>c/`050;>c/`030000002IVIT0VIVI0080VIVI00<0000007moO`1oOgl0
0`1oOgl00`000000IVIV06IVIP0206IVIP030000001<C4`0C4a<00<0C4a<00<0000003<c<`0c<c<0
1@0c<c<00`0000006ATI01TI6@0901TI6@X000001?ooool00`00003oooooooooo`0Hooooo`03o`00
0?oooooooooo02oooooo3?nY_NP2oj^bgP?o^J;100?o_9VdokbVa?nlY/@00_nnW;D01?nnZlKo`Ing
ol6O]oo1WkL2ol2I[`04ol>S^?o3Vk3o`i^`ol>K/0CoaIna00?oa9Z]olRS/oo8Xk<00_o6WJh2ol^X
]@03olVQ/?o?[KSocjfh00;oc:Jb0_oB/kX01Oo?ZkCoe[VmomJi_OoF^Kgodk2g00;of/3000KohM[?
omg8`ooSh];ohn;BomKnf_mngjTZooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool0
2oooool000Wooooo00@00000oooooooooooooooo<`00000;01TI6@030000000c<c<0<c<c00@0<c<c
00<0000004a<C01<C4`0101<C4`00`000000IVIV06IVIP0206IVIP030000001oOgl0Ogmo0080Ogmo
00<0000009VIV@2IVIT00`2IVIT00`000000/k>c0;>c/`050;>c/`8000002`3<c<`00`000000/k>c
0;>c/`050;>c/`030000002IVIT0VIVI00<0VIVI00<0000007moO`1oOgl00`1oOgl00`000000IVIV
06IVIP0206IVIP030000001<C4`0C4a<00<0C4a<00<0000003<c<`0c<c<01@0c<c<00`0000006ATI
01TI6@0901TI6@T000001?ooool00`00003oooooooooo`0Iooooo`;o0000<?ooool<ojVmj004ocV^
l_niX/7o^J;1ojfihP?o_:K400?o_Ybeokj[a_nnZlH00oo1WkL01?o0VJoo`j>hol>S^?o3XkP2ol>K
/0CoaIna0oo8Xk<01Oo6WJkobjReol^X]Oo;Z;GobJ6`00?ocjfh00?oc:Jbom:c^_oB/kX00ooF^Kd2
omgAc006om[0`?oQf/oohM[?omWjgOoSh];oe_kJ;Oooool00ol0003oooooooooo`0:ooooo`03o`00
0?oooooooooo00_ooooo0009ooooo`0400000?oooooooooooooooc<0000000?o000001TI6@0I6AT0
2@0I6AT00ol00000<c<c03<c<`0403<c<`03o`0000000000C4a<00<0C4a<00?o00000000001VIVH0
0`1VIVH00`000000Ogmo07moO`0207moO`03o`0000000000VIVI00<0VIVI0P0000070;>c/`D00000
0P3<c<`300000003o`00002c/k<0/k>c00H0/k>c00<0000009VIV@2IVIT00`2IVIT00`000000Ogmo
07moO`0307moO`030000001VIVH0IVIV0080IVIV00?o000004a<C01<C4`00`1<C4`00`000000<c<c
03<c<`0503<c<`030000000I6AT06ATI00T06ATI2@000004ooooo`0300000?oooooooooo01_ooooo
00?o0000ooooooooool0;_ooool>ojVmj0;o[KWR00?o_:K4ojo1ionnZlH00onnZlH2ol6O]`Co`j>h
00?o`i^`olJW^_o6YkX00_o5Wk42olV]_@;ob:>c1?o;Z;D3oln]^006omK1a_oB/k[od[>jom:c^_oJ
bLWoe[Vm0_oMdL`2om_dg`03on7JcooIn]goPn>a033ooooo00?o0000ooooooooool02Oooool00ol0
003oooooooooo`0;ooooo`002Oooool01000003ooooooooooooooole000000/06ATI00<0000003<c
<`0c<c<01@0c<c<00`000000C4a<04a<C00304a<C08000000`1VIVH00ol00000000007moO`0307mo
O`030000002IVIT0VIVI00<0VIVI0P00000:0;>c/`800000302c/k<00`000000VIVI09VIV@0309VI
V@030000001oOgl0Ogmo00<0Ogmo00<0000006IVIP1VIVH00`1VIVH00`000000C4a<04a<C00304a<
C0030000000c<c<0<c<c00@0<c<c00<0000001TI6@0I6AT02@0I6AT9000000Cooooo00<00000oooo
ooooool07?ooool00ol0003oooooooooo`0^ooooo`koZKgX00Co:J_Wojo1ion_`NOo[l7W0onnZlH0
0oo1WkOo`[39ol:`b@02ol>S^005olFgc?o6Yk[oaZNjolJW^_o5Wk400oo9[Kd00oo8Xk?ocK?0olfc
`003ol^X]@03om6i`oo?[KSoe/7600;oe/7600God[>jom[9bOoJbLWofngOomgAc003om_dgcCooooo
00?o0000ooooooooool02?ooool00ol0003oooooooooo`0;ooooo`002Oooool01000003ooooooooo
oooooolf000000/06ATI00<0000003<c<`0c<c<01@0c<c<00`000000C4a<04a<C00404a<C0030000
001VIVH0IVIV0080IVIV00<0000007moO`1oOgl00P1oOgl2000000D0VIVI0`00000D0;>c/`030000
002IVIT0VIVI00@0VIVI00<0000007moO`1oOgl00`1oOgl00`000000IVIV06IVIP0306IVIP030000
001<C4`0C4a<00@0C4a<00?o000003<c<`0c<c<0100c<c<00`0000006ATI01TI6@0901TI6@P00000
1?ooool00`00003oooooooooo`0Mooooo`03o`000?oooooooooo02kooooo3onY_NP2ojo1i`;o_Z_6
00Go/LW/ol:`bOo2/<Wo`[39ol>S^003olFgc0;oaZNj00CobKk@olV]_Oo9[KgobJfm1?o=/l000oo;
Z;GodKW3om6i``03omK1aP;ofNCN00?of/W9om_]gooKkMl00_nDl</00ooKm=ooooooooooo`0coooo
o`03o`000?oooooooooo00Sooooo00?o0000ooooooooool02oooool000Wooooo00@00000oooooooo
oooooooo=P0000000ol000006ATI01TI6@0901TI6@030000000c<c<0<c<c00D0<c<c00?o000004a<
C01<C4`0101<C4`00ol00000IVIV06IVIP0206IVIP800000101oOgl00`000000VIVI09VIV@0509VI
V@030000002c/k<0/k>c0140/k>c00<0000009VIV@2IVIT0102IVIT00`000000Ogmo07moO`0307mo
O`030000001VIVH0IVIV00<0IVIV00<0000004a<C01<C4`0101<C4`00`000000<c<c03<c<`0503<c
<`030000000I6AT06ATI00T06ATI1`000004ooooo`0300000?oooooooooo01kooooo0_l0000_oooo
oa;oZKgX0_nabN`00oo2/<Wo/m?aok?Cl@03olFgc005olJW^_o9_]3obKk@olVnd?o9[Kd00_o=am@2
olfc`006om7@f?oA^L?odKW3om6i`ooFf]_oe/760ooIi=h01?nNmM[ofngOoiC`bonDl</hooooo`03
o`000?oooooooooo00Oooooo00?o0000ooooooooool02oooool000Wooooo00@00000oooooooooooo
oooo>000000;01TI6@030000000c<c<0<c<c00D0<c<c00<0000004a<C01<C4`0101<C4`00`000000
IVIV06IVIP0306IVIP030000001oOgl0Ogmo0080Ogmo00?o00000000002IVIT0102IVIT00ol00000
00000000000@0;>c/`030000002IVIT0VIVI00D0VIVI00<0000007moO`1oOgl00`1oOgl00`000000
IVIV06IVIP0306IVIP030000001<C4`0C4a<00@0C4a<00<0000003<c<`0c<c<01@0c<c<00`000000
6ATI01TI6@0901TI6@03o`0000000000000000@000001?ooool00`00003oooooooooo`0Pooooo`03
o`000?oooooooooo02gooooo5?nY_NP3ok?Cl@03olFgc?ndgOCobKk@00;obKk@00Go]NOgolg7e?o=
amCocLODolfc`003om7@f003om6i`ooFf]_oe][K00;oZ?OW00?ofNCNoikef_ooool0??ooool00ol0
003oooooooooo`07ooooo`03o`000?oooooooooo00[ooooo0009ooooo`0400000?oooooooooooooo
ocT000002`0I6AT00`000000<c<c03<c<`0503<c<`030000001<C4`0C4a<00@0C4a<00<0000006IV
IP1VIVH00`1VIVH00`000000Ogmo07moO`0307moO`8000001P2IVIT4000000T0/k>c0`00000809VI
V@030000001oOgl0Ogmo00<0Ogmo00<0000006IVIP1VIVH00`1VIVH00`000000C4a<04a<C00404a<
C0030000000c<c<0<c<c00D0<c<c00<0000001TI6@0I6AT02@0I6AT7000000Cooooo00<00000oooo
ooooool08Oooool00ol0003oooooooooo`0^oooooaKoZKgX0_ndgO@01Oo9_]3o]NOgokGWmoneioOo
cLOD00?o/o3f00CodM3Hojofl?n_m_3oe][K@oooool00ol0003oooooooooo`06ooooo`03o`000?oo
oooooooo00[ooooo0009ooooo`0400000?ooooooooooooooocX000002`0I6AT00`000000<c<c03<c
<`0503<c<`030000001<C4`0C4a<00@0C4a<00<0000006IVIP1VIVH00`1VIVH00`000000Ogmo07mo
O`0407moO`030000002IVIT0VIVI00L0VIVI2@00000:09VIV@030000001oOgl0Ogmo00D0Ogmo00<0
000006IVIP1VIVH00`1VIVH00`000000C4a<04a<C00404a<C0030000000c<c<0<c<c00D0<c<c00<0
000001TI6@0I6AT02@0I6AT6000000Cooooo00<00000ooooooooool08_ooool00ol0003ooooooooo
o`0^oooooaWoZKgXCOooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00[ooooo0009
ooooo`0400000?ooooooooooooooocX0000000?o000001TI6@0I6AT02@0I6AT00ol00000000003<c
<`0503<c<`8000001@1<C4`00`000000IVIV06IVIP0306IVIP03o`0000000000Ogmo00@0Ogmo00?o
00000000002IVIT06@2IVIT00`000000Ogmo07moO`0507moO`030000001VIVH0IVIV00<0IVIV00<0
000004a<C01<C4`0101<C4`00`000000<c<c03<c<`0503<c<`030000000I6AT06ATI00X06ATI1@00
0004ooooo`0300000?oooooooooo02?ooooo00?o0000ooooooooool0;_oooolDojVmj5;ooooo00?o
0000ooooooooool01Oooool00ol0003oooooooooo`0:ooooo`002Oooool01000003ooooooooooooo
ooll000000`06ATI00<0000003<c<`0c<c<01@0c<c<2000000@0C4a<00?o00000000001VIVH0101V
IVH2000000D0Ogmo0`00000G09VIV@030000001oOgl0Ogmo00D0Ogmo00<0000006IVIP1VIVH00`1V
IVH00`000000C4a<04a<C00404a<C0030000000c<c<0<c<c00D0<c<c00<0000001TI6@0I6AT02P0I
6AT5000000Cooooo00<00000ooooooooool09?ooool2o`0002oooooo4?nY_NQFooooo`03o`000?oo
oooooooo00Cooooo00?o0000ooooooooool02_ooool000Wooooo00@00000oooooooooooooooo?@00
000<01TI6@030000000c<c<0<c<c00H0<c<c00<0000004a<C01<C4`00`1<C4`2000000D0IVIV0P00
000607moO`<000004`2IVIT00`000000Ogmo07moO`0507moO`030000001VIVH0IVIV00@0IVIV00<0
000004a<C01<C4`01@1<C4`00`000000<c<c03<c<`0503<c<`03o`00000I6AT06ATI00X06ATI1000
0004ooooo`0300000?oooooooooo02Kooooo00?o0000ooooooooool0;Oooool=ojVmj5Sooooo00?o
0000ooooooooool01?ooool00ol0003oooooooooo`0:ooooo`002Oooool01000003ooooooooooooo
oolm00000003o`00000I6AT06ATI00X06ATI00?o000003<c<`0c<c<01P0c<c<00`000000C4a<04a<
C00404a<C0030000001VIVH0IVIV00@0IVIV0P00000707moO`030000002IVIT0VIVI00h0VIVI0P00
00000ol00000Ogmo07moO`0507moO`030000001VIVH0IVIV00@0IVIV00<0000004a<C01<C4`01@1<
C4`00`000000<c<c03<c<`0503<c<`030000000I6AT06ATI00X06ATI10000004ooooo`0300000?oo
oooooooo02Oooooo00?o0000ooooooooool0;Oooool8ojVmj5gooooo00?o0000ooooooooool00ooo
ool00ol0003oooooooooo`0:ooooo`002Oooool01000003ooooooooooooooolo000000`06ATI00<0
000003<c<`0c<c<01@0c<c<00ol00000000004a<C00504a<C0030000001VIVH0IVIV00D0IVIV00<0
000007moO`1oOgl01@1oOgl00ol0000000000000000<09VIV@030000001oOgl0Ogmo00P0Ogmo00<0
000006IVIP1VIVH0101VIVH00`000000C4a<04a<C00504a<C0030000000c<c<0<c<c00D0<c<c00<0
000001TI6@0I6AT02P0I6AT4000000Cooooo00<00000ooooooooool0:?ooool00ol0003ooooooooo
o`0]ooooo`?oZKgXH_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Wooooo0009
ooooo`0400000?oooooooooooooood000000300I6AT00`000000<c<c03<c<`0603<c<`030000001<
C4`0C4a<00@0C4a<00<0000006IVIP1VIVH01@1VIVH2000000P0Ogmo3000000;07moO`030000001V
IVH0IVIV00@0IVIV00<0000004a<C01<C4`01@1<C4`00`000000<c<c03<c<`0503<c<`030000000I
6AT06ATI00/06ATI0`000004ooooo`0300000?oooooooooo02Wooooo0_l0000]ooooo`03o`000?oo
oooooooo06?ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`09ooooo`002Oooool0
1000003ooooooooooooooom1000000`06ATI00<0000003<c<`0c<c<01P0c<c<00`000000C4a<04a<
C00404a<C08000001`1VIVH200000003o`00001oOgl0Ogmo01T0Ogmo00<0000006IVIP1VIVH01@1V
IVH00`000000C4a<04a<C00504a<C0030000000c<c<0<c<c00H0<c<c00<0000001TI6@0I6AT02P0I
6AT3000000Cooooo00<00000ooooooooool0:oooool00ol0003oooooooooo`0Zooooo`03o`000?oo
oooooooo06?ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`09ooooo`002Oooool0
1000003ooooooooooooooom100000003o`00000000006ATI00X06ATI0P00000703<c<`03o`000000
0000C4a<00D0C4a<0P00000706IVIP<00000601oOgl00`00003o000006IVIP0606IVIP030000001<
C4`0C4a<00D0C4a<00<0000003<c<`0c<c<01P0c<c<00`0000006ATI01TI6@0:01TI6@<000001?oo
ool00`00003oooooooooo`0/ooooo`03o`000?oooooooooo02Wooooo00?o0000ooooooooool0I?oo
ool01Ol0003ooooooooooooooooo000000_ooooo0009ooooo`0400000?oooooooooooooood@00000
300I6AT2000000L0<c<c00<0000004a<C01<C4`01@1<C4`2000000P0IVIV0`00000D07moO`030000
001VIVH0IVIV00L0IVIV00<0000004a<C01<C4`01@1<C4`00`000000<c<c03<c<`0603<c<`030000
000I6AT06ATI00X06ATI0`000004ooooo`0300000?oooooooooo02gooooo00?o0000ooooooooool0
:?ooool00ol0003oooooooooo`1Uooooo`04o`000?ooooooooooo`0000_ooooo0009ooooo`040000
0?ooooooooooooooodD000003@0I6AT00`000000<c<c03<c<`0503<c<`8000001`1<C4`00`000000
IVIV06IVIP0806IVIP@000003`1oOgl00`000000IVIV06IVIP0706IVIP030000001<C4`0C4a<00H0
C4a<00<0000003<c<`0c<c<01`0c<c<00`0000006ATI01TI6@0:01TI6@8000001?ooool00`00003o
ooooooooo`0^ooooo`;o0000:?ooool00ol0003oooooooooo`1Vooooo`03o`000?oooooo000000_o
oooo0009ooooo`0400000?ooooooooooooooodL00000300I6AT00`000000<c<c03<c<`0603<c<`03
0000001<C4`0C4a<00D0C4a<00@00000o`000000000000002P1VIVH3000000T0Ogmo0P0000000ol0
0000IVIV06IVIP0806IVIP03o`00001<C4`0C4a<00H0C4a<00<0000003<c<`0c<c<01`0c<c<00`00
00006ATI01TI6@0:01TI6@8000001?ooool00`00003oooooooooo`0`ooooo`03o`000?oooooooooo
02Gooooo00?o0000ooooooooool0I_ooool00ol0003oooooo`00000;ooooo`002Oooool01000003o
oooooooooooooom8000000`06ATI00<0000003<c<`0c<c<01P0c<c<00ol00000000004a<C00804a<
C08000002`1VIVH9000000d0IVIV00<0000004a<C01<C4`01P1<C4`00`000000<c<c03<c<`0703<c
<`030000000I6AT06ATI00X06ATI0P000004ooooo`0300000?oooooooooo037ooooo00?o0000oooo
ooooool09?ooool00ol0003oooooooooo`1Wooooo`03o`000?oooooo000000[ooooo0009ooooo`04
00000?ooooooooooooooodT00000300I6AT00`000000<c<c03<c<`0703<c<`8000002@1<C4`00`00
0000IVIV06IVIP0N06IVIP030000001<C4`0C4a<00H0C4a<00<0000003<c<`0c<c<01`0c<c<00`00
00006ATI01TI6@0:01TI6@8000001?ooool00`00003oooooooooo`0booooo`03o`000?oooooooooo
02?ooooo00?o0000ooooooooool0J?ooool2o`0000[ooooo0009ooooo`0400000?oooooooooooooo
odT0000000?o000001TI6@0I6AT02P0I6AT2000000T0<c<c00<0000004a<C01<C4`01`1<C4`20000
01d0IVIV00<0000004a<C01<C4`01`1<C4`00`000000<c<c03<c<`0703<c<`030000000I6AT06ATI
00/06ATI00<00000ooooooooool00_ooool00`00003oooooooooo`0cooooo`;o00008oooool00ol0
003oooooooooo`1Wooooo`?o00002_ooool000Wooooo00@00000ooooooooooooooooB`00000=01TI
6@800000200c<c<00ol00000000004a<C00804a<C0D000005P1VIVH2000000X0C4a<00<0000003<c
<`0c<c<01`0c<c<00`0000006ATI01TI6@0;01TI6@0300000?oooooooooo00;ooooo00<00000oooo
ooooool0=Oooool00ol0003oooooooooo`0Pooooo`03o`000?oooooooooo06?ooooo1?l0000=oooo
o`002Oooool01000003ooooooooooooooom<000000h06ATI0P00000803<c<`800000301<C4`30000
0140IVIV0P00000<04a<C0030000000c<c<0<c<c00L0<c<c00<0000001TI6@0I6AT02`0I6AT00`00
003oooooooooo`02ooooo`0300000?oooooooooo03Kooooo00?o0000ooooooooool07oooool00ol0
003oooooooooo`1Pooooo`?o00004Oooool000Wooooo00@00000ooooooooooooooooCP00000>01TI
6@030000000c<c<0<c<c00L0<c<c0P00000=04a<C0@000002P1VIVH3000000d0C4a<00<0000003<c
<`0c<c<0200c<c<00`0000006ATI01TI6@0<01TI6@0500000?ooooooooooooooo`000000>Oooool0
0ol0003oooooooooo`0Nooooo`03o`000?oooooooooo05cooooo1?l0000Dooooo`002Oooool01000
003ooooooooooooooom?000000h06ATI00<0000003<c<`0c<c<0200c<c<00`00003o00000000000>
04a<C00300000?l00000000000D0000000?o00000000001<C4`03P1<C4`00ol00000<c<c03<c<`09
03<c<`030000000I6AT06ATI00`06ATI00D00000oooooooooooooooo0000000jooooo`;o00007_oo
ool00ol0003oooooooooo`1Hooooo`Co00006?ooool000Wooooo00@00000ooooooooooooooooD000
000=01TI6@03o`0000000000<c<c00/0<c<c0P00000U04a<C0030000000c<c<0<c<c00T0<c<c00<0
000001TI6@0I6AT0300I6AT01@00003oooooooooooooool0000003cooooo00?o0000ooooooooool0
6oooool00ol0003oooooooooo`1Dooooo`Co00007?ooool000Wooooo00@00000oooooooooooooooo
D@00000>01TI6@800000300c<c<200000280C4a<00<0000003<c<`0c<c<02P0c<c<00`0000006ATI
01TI6@0<01TI6@0500000?ooooooooooooooo`000000?Oooool00ol0003oooooooooo`0Jooooo`03
o`000?oooooooooo057ooooo0ol0000Pooooo`002Oooool01000003ooooooooooooooomB000000l0
6ATI00<0000003<c<`0c<c<02`0c<c<2000001l0C4a<00<0000003<c<`0c<c<02P0c<c<00`000000
6ATI01TI6@0=01TI6@0500000?ooooooooooooooo`000000?_ooool00ol0003oooooooooo`0Ioooo
o`03o`000?oooooooooo04gooooo1?l0000Sooooo`002Oooool01000003ooooooooooooooomB0000
0003o`00000000006ATI00d06ATI00?o00000000000c<c<0300c<c<01000003o000000000000000H
04a<C080000000?o000003<c<`0c<c<02`0c<c<00`0000006ATI01TI6@0=01TI6@0500000?oooooo
ooooooooo`000000?oooool2o`0001Wooooo00?o0000ooooooooool0BOooool4o`0002Oooooo0009
ooooo`0400000?oooooooooooooooeD000003`0I6AT2000000l0<c<c1000000C04a<C0030000000c
<c<0<c<c00h0<c<c00<0000001TI6@0I6AT03@0I6AT01@00003oooooooooooooool00000047ooooo
00?o0000ooooooooool05_ooool00ol0003oooooooooo`15ooooo`Co0000:oooool000Wooooo00@0
0000ooooooooooooooooEP00000@01TI6@8000004@0c<c<3000000d0C4a<0`00000@03<c<`030000
000I6AT06ATI00h06ATI00D00000oooooooooooooooo00000012ooooo`03o`000?oooooooooo01Co
oooo00?o0000ooooooooool0@oooool3o`0002oooooo0009ooooo`0400000?oooooooooooooooeH0
000000?o00000000000000003`0I6AT00`00003o00000000000A03<c<`80000000?o000000000000
00002000000C03<c<`030000000I6AT06ATI00h06ATI00D00000oooooooooooooooo00000013oooo
o`03o`000?oooooooooo01?ooooo00?o0000ooooooooool0?oooool4o`0003;ooooo0009ooooo`04
00000?oooooooooooooooeX000004@0I6AT2000002l0<c<c00<0000001TI6@0I6AT03P0I6AT01@00
003oooooooooooooool0000004Cooooo0_l0000Cooooo`03o`000?oooooooooo03_ooooo1?l0000f
ooooo`002Oooool01000003ooooooooooooooomK000001806ATI0P00000/03<c<`030000000I6AT0
6ATI00l06ATI00D00000oooooooooooooooo00000016ooooo`03o`000?oooooooooo013ooooo00?o
0000ooooooooool0=oooool4o`0003[ooooo0009ooooo`0400000?oooooooooooooooe`000004`0I
6AT00`000000<c<c03<c<`0X03<c<`030000000I6AT06ATI01006ATI00D00000oooooooooooooooo
00000017ooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool0<oooool4o`0003kooooo
0009ooooo`0400000?oooooooooooooooe`0000000?o00000000000000004@0I6AT01?l000000000
00000000000T03<c<`0300000?l000006ATI01806ATI00D00000oooooooooooooooo00000018oooo
o`03o`000?oooooooooo00kooooo00?o0000ooooooooool0<?ooool3o`0004;ooooo0009ooooo`04
00000?ooooooooooooooof4000004`0I6AT200000240<c<c00<0000001TI6@0I6AT04`0I6AT01@00
003oooooooooooooool0000004Wooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0/
ooooo`Co0000AOooool000Wooooo00@00000ooooooooooooooooH@0000000ol000006ATI01TI6@0B
01TI6@<000007@0c<c<00`0000006ATI01TI6@0C01TI6@0300000?oooooooooo00;ooooo00<00000
ooooooooool0B?ooool2o`0000gooooo00?o0000ooooooooool0:?ooool4o`0004Wooooo0009oooo
o`0400000?ooooooooooooooof@000005@0I6AT01000003o000000000000000G03<c<`8000005P0I
6AT00`00003oooooooooo`02ooooo`0300000?oooooooooo04[ooooo00?o0000ooooooooool02_oo
ool00ol0003oooooooooo`0Tooooo`Co0000COooool000Wooooo00@00000ooooooooooooooooIP00
000G01TI6@H000003@0c<c<4000001P06ATI00<00000ooooooooool00_ooool00`00003ooooooooo
o`1;ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool08Oooool3o`00057ooooo0009
ooooo`0400000?ooooooooooooooofP000006`0I6AT=000001`06ATI00<00000ooooooooool00_oo
ool00`00003oooooooooo`1<ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool07Ooo
ool4o`0005Cooooo0009ooooo`0400000?ooooooooooooooofP0000000?o000001TI6@0I6AT0@00I
6AT2000000Cooooo00<00000ooooooooool0COooool2o`0000Sooooo00?o0000ooooooooool06Ooo
ool4o`0005Sooooo0009ooooo`0400000?ooooooooooooooof/00000@00I6AT2000000Cooooo00<0
0000ooooooooool0Coooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo01Gooooo1?l0
001Looooo`002Oooool01000003ooooooooooooooom]000003h06ATI0P000004ooooo`0300000?oo
oooooooo053ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`0Booooo`?o0000H?oo
ool000Wooooo00@00000ooooooooooooooooK`00000k01TI6@<000001?ooool00`00003ooooooooo
o`1Aooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool03_ooool4o`0006?ooooo0009
ooooo`0400000?ooooooooooooooog800000=`0I6AT01?l000000000000000000004ooooo`030000
0?oooooooooo05;ooooo0_l00003ooooo`03o`000?oooooooooo00[ooooo1?l0001Wooooo`002Ooo
ool01000003ooooooooooooooomd000003@06ATI1@000004ooooo`0300000?oooooooooo05Cooooo
00Co0000oooooooooooo00002?ooool4o`0006_ooooo0009ooooo`0400000?ooooooooooooooogH0
0000<@0I6AT6000000Cooooo00<00000ooooooooool0EOooool00ol0003oooooo`000005ooooo`?o
0000Koooool000Wooooo00@00000ooooooooooooooooN00000000ol000006ATI01TI6@0[01TI6@L0
00001?ooool00`00003oooooooooo`1Fooooo`;o000000?oooooo`000?l000000_l0001booooo`00
2Oooool01000003oooooooooooooooml000002T06ATI20000004ooooo`0300000?oooooooooo05Oo
oooo0_l0001fooooo`002Oooool01000003ooooooooooooooon0000002@06ATI2@000004ooooo`03
00000?oooooooooo0<oooooo0009ooooo`0400000?oooooooooooooooh800000800I6AT;000000Co
oooo00<00000ooooooooool0coooool000Wooooo00@00000ooooooooooooooooQ`00000G01TI6@l0
00001?ooool00`00003oooooooooo`3?ooooo`002Oooool01000003ooooooooooooooon:00000100
6ATI4`000004ooooo`0300000?oooooooooo0<oooooo0009ooooo`0400000?ooooooooooooooojd0
00001?ooool00`00003oooooooooo`3?ooooo`002Oooool01000003ooooooooooooooon]000000Co
oooo00<00000ooooooooool0coooool000Wooooo00@00000oooooooooooooooo[@000004ooooo`03
00000?oooooooooo0<oooooo0009ooooo`0400000?ooooooooooooooojd000001?ooool00`00003o
ooooooooo`3?ooooo`002Oooool01000003ooooooooooooooon]000000Cooooo00<00000oooooooo
ool0coooool000Wooooo00@00000oooooooooooooooo[@000004ooooo`0300000?oooooooooo0<oo
oooo0009ooooo`0400000?ooooooooooooooojd000001?ooool00`00003oooooooooo`3?ooooo`00
2Oooool01000003ooooooooooooooon]000000Cooooo00<00000ooooooooool0coooool000Wooooo
00@00000oooooooooooooooo[@000004ooooo`0300000?oooooooooo0<oooooo0009ooooo`030000
0?oooooooooo0;;ooooo00<00000ooooooooool0coooool000Wooooo00<00000ooooooooool0/_oo
ool00`00003oooooooooo`3?ooooo`002Oooool00`00003oooooooooo`2booooo`0300000?oooooo
oooo0<oooooo0009oooookH00000dOooool00?ooooooTOooool00?ooooooTOooool00?ooooooTOoo
ool00?ooooooTOooool00?ooooooTOooool00?ooooooTOooool00?ooooooTOooool00?ooooooTOoo
ool00?ooooooTOooool00?ooooooTOooool00?ooooooTOooool00?ooooooTOooool00?ooooooTOoo
ool00?ooooooTOooool00?ooooooTOooool00?ooooooTOooool00?ooooooTOooool000Wooooo]_l0
000AoooookKo00002_ooool000Wooooo00?o0000ooooooooool0/_ooool00ol0003oooooooooo`0?
ooooo`03o`000?oooooooooo0;;ooooo00?o0000ooooooooool02?ooool000Wooooo00?o0000oooo
ooooool0/_ooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo0;;ooooo00?o0000oooo
ooooool02?ooool000Wooooo00?o0000ooooooooool0/_ooool00ol0003oooooooooo`0?ooooo`03
o`000?oooooooooo0;;ooooo00?o0000ooooooooool02?ooool000Wooooo00?o0000ooooooooool0
/_ooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo0;;ooooo00?o0000ooooooooool0
2?ooool000Wooooo00?o0000ooooooooool0/_ooool00ol0003oooooooooo`0?ooooo`03o`000?oo
oooooooo0;;ooooo00?o0000ooooooooool02?ooool000Wooooo00?o0000ooooooooool0/_ooool0
0ol0003oooooooooo`0?ooooo`03o`000?oooooooooo0;;ooooo00?o0000ooooooooool02?ooool0
00Wooooo00?o0000ooooooooool0/_ooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo
0;;ooooo00?o0000ooooooooool02?ooool000Wooooo00?o0000ooooooooool0/_ooool00ol0003o
ooooooooo`0?ooooo`03o`000?oooooooooo0;;ooooo00?o0000ooooooooool02?ooool000Wooooo
00?o0000ooooooooool0/_ooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo0;;ooooo
00?o0000ooooooooool02?ooool000Wooooo00?o0000ooooooooool0/_ooool00ol0003ooooooooo
o`0?ooooo`03o`000?oooooooooo0;;ooooo00?o0000ooooooooool02?ooool000Wooooo00?o0000
ooooooooool0/_ooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo0;;ooooo00?o0000
ooooooooool02?ooool000Wooooo00?o0000ooooooooool0/_ooool00ol0003oooooooooo`0?oooo
o`03o`000?oooooooooo0;;ooooo00?o0000ooooooooool02?ooool000Wooooo00?o0000oooooooo
ool0/_ooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo0;;ooooo00?o0000oooooooo
ool02?ooool000Wooooo00?o0000ooooooooool0/_ooool00ol0003oooooooooo`0?ooooo`03o`00
0?oooooooooo0;;ooooo00?o0000ooooooooool02?ooool000Wooooo00?o0000ooooooooool0/_oo
ool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo0;;ooooo00?o0000ooooooooool02?oo
ool000Wooooo00?o0000ooooooooool0/_ooool00ol0003oooooooooo`0?ooooo`03o`000?oooooo
oooo0;;ooooo00?o0000ooooooooool02?ooool000Wooooo00?o0000ooooooooool0/_ooool00ol0
003oooooooooo`0?ooooo`03o`000?oooooooooo0;;ooooo00?o0000ooooooooool02?ooool000Wo
oooo00?o0000ooooooooool0/_ooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo0;;o
oooo00?o0000ooooooooool02?ooool000Wooooo00?o0000ooooooooool0/_ooool00ol0003ooooo
ooooo`0?ooooo`03o`000?oooooooooo0;;ooooo00?o0000ooooooooool02?ooool000Wooooo00?o
0000ooooooooool0/_ooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo0;;ooooo00?o
0000ooooooooool02?ooool000Wooooo00?o0000ooooooooool0/_ooool00ol0003oooooooooo`0?
ooooo`03o`000?oooooooooo0;;ooooo00?o0000ooooooooool02?ooool000Wooooo00?o0000oooo
ooooool0/_ooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo0;;ooooo00?o0000oooo
ooooool02?ooool000Wooooo00?o0000ooooooooool00oooool2oomo00_ooooo0_ooO`2Pooooo`03
o`000?oooooooooo00oooooo00?o0000ooooooooool00oooool2oomo00_ooooo0_ooO`2Pooooo`03
o`000?oooooooooo00Sooooo0009ooooo`03o`000?oooooooooo00;ooooo0oooO`0;ooooo`;oogl0
0_ooool60000o`04o`00ooooooooooooooooo`;oogl0T_ooool00ol0003oooooooooo`0?ooooo`03
o`000?oooooooooo00;ooooo0oooO`0;ooooo`;oogl03?ooool2oomo09;ooooo00?o0000oooooooo
ool02?ooool000Wooooo00?o0000ooooooooool00_ooool2oomo00kooooo0P000?l7ooooo`<0003o
0_ooO`2Booooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool00_ooool2oomo01[ooooo
0_ooO`2Booooo`03o`000?oooooooooo00Sooooo0009ooooo`03o`000?oooooooooo01;ooooo00<0
003oooooooooool02Oooool30000oi7ooooo00?o0000ooooooooool03oooool00ol0003ooooooooo
o`2booooo`03o`000?oooooooooo00Sooooo0009ooooo`03o`000?oooooooooo01;ooooo00<0003o
ooooooooool03?ooool20000ohoooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`2b
ooooo`03o`000?oooooooooo00Sooooo0009ooooo`03o`000?oooooooooo017ooooo00<0003ooooo
ooooool03oooool00`000?ooooooooooo`2<ooooo`03o`000?oooooooooo00oooooo00?o0000oooo
ooooool0/_ooool00ol0003oooooooooo`08ooooo`002Oooool00ol0003oooooooooo`0Aooooo`03
0000oooooooooooo013ooooo00?o003o0000o`000?l0Roooool00ol0003oooooooooo`0?ooooo`03
o`000?oooooooooo0;;ooooo00?o0000ooooooooool02?ooool000Wooooo00?o0000ooooooooool0
4Oooool00`000?ooooooooooo`0Cooooo`030000oooooooooooo08Sooooo00?o0000ooooooooool0
3oooool00ol0003oooooooooo`2booooo`03o`000?oooooooooo00Sooooo0009ooooo`03o`000?oo
oooooooo017ooooo00<0003oooooooooool05?ooool20000ohSooooo00?o0000ooooooooool03ooo
ool00ol0003oooooooooo`2booooo`03o`000?oooooooooo00Sooooo0009ooooo`03o`000?oooooo
oooo01;ooooo00<0003oooooooooool05Oooool00`000?ooooooooooo`25ooooo`03o`000?oooooo
oooo00oooooo00?o0000ooooooooool0/_ooool00ol0003oooooooooo`08ooooo`002Oooool00ol0
003oooooooooo`0Booooo`030000oooooooooooo01Kooooo00<0003oooooooooool0Q?ooool00ol0
003oooooooooo`0?ooooo`03o`000?oooooooooo0;;ooooo00?o0000ooooooooool02?ooool000Wo
oooo00?o0000ooooooooool04_ooool010000?ooooooooooooooool2oomo00Gooooo0_ooO`0=oooo
o`03o`00oooooooooooo08?ooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`0Foooo
o`;oogl01Oooool2oomo09?ooooo00?o0000ooooooooool02?ooool000Wooooo00?o0000oooooooo
ool04_ooool010000?ooooooooooooooool2oomo00Gooooo0_ooO`0>ooooo`80003oPoooool00ol0
003oooooooooo`0?ooooo`03o`000?oooooooooo01Kooooo0_ooO`05ooooo`;oogl0Toooool00ol0
003oooooooooo`08ooooo`002Oooool00ol0003oooooooooo`0Cooooo`030000oooooooooooo01Wo
oooo0P000?n1ooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool0/_ooool00ol0003o
ooooooooo`08ooooo`002Oooool00ol0003oooooooooo`0Cooooo`030000oooooooooooo01_ooooo
00<0003oooooooooool0O_ooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo0;;ooooo
00?o0000ooooooooool02?ooool000Wooooo00?o0000ooooooooool04oooool00`000?oooooooooo
o`06ooooo`;oogl01_ooool2oomo00_ooooo00?oogl0o`00ooooool00_ooool2oomo07[ooooo00?o
0000ooooooooool03oooool00ol0003oooooooooo`0Looooo`;oogl01_ooool2oomo00_ooooo0_oo
O`03ooooo`;oogl0N_ooool00ol0003oooooooooo`08ooooo`002Oooool00ol0003oooooooooo`0D
ooooo`030000oooooooooooo00Gooooo0_ooO`06ooooo`;oogl02oooool2oomo0080003o00?ooooo
oomo0?ooO`00N_ooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo01cooooo0_ooO`06
ooooo`;oogl02oooool2oomo00?ooooo0_ooO`1jooooo`03o`000?oooooooooo00Sooooo0009oooo
o`03o`000?oooooooooo01Gooooo00<0003oooooooooool07Oooool010000?oooooooomo0?ooO`1i
ooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool0=oooool2oomo07Wooooo00?o0000
ooooooooool02?ooool000Wooooo00?o0000ooooooooool05_ooool00`000?ooooooooooo`0Joooo
o`;oogl000Cooooo0000ooooO`3oogl0NOooool00ol0003oooooooooo`0?ooooo`03o`000?oooooo
oooo03?ooooo0_ooO`02ooooo`;oogl0NOooool00ol0003oooooooooo`08ooooo`002Oooool00ol0
003oooooooooo`0Fooooo`030000oooooooooooo01[ooooo0_ooO`02ooooo`03o`00oooooooooooo
07Sooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`0cooooo`;oogl0OOooool00ol0
003oooooooooo`08ooooo`002Oooool00ol0003oooooooooo`0Gooooo`030000oooooooooooo00Oo
oooo0_ooO`0Eooooo`030000oooooooooooo07Oooooo00?o0000ooooooooool03oooool00ol0003o
ooooooooo`0Qooooo`;oogl0Soooool00ol0003oooooooooo`08ooooo`002Oooool00ol0003ooooo
ooooo`0Gooooo`030000oooooooooooo00;oogl01Oooool2oomo01Kooooo00<0003oooooooooool0
M_ooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo01[ooooo0_ooO`05ooooo`;oogl0
Soooool00ol0003oooooooooo`08ooooo`002Oooool00ol0003oooooooooo`0Hooooo`040000oooo
ooooogl0oomo01Kooooo0_ooO`06ooooo`040000ooooooooooooooooo`;oogl0L_ooool00ol0003o
ooooooooo`0?ooooo`03o`000?oooooooooo01[ooooo0_ooO`0Fooooo`;oogl02_ooool2oomo07;o
oooo00?o0000ooooooooool02?ooool000Wooooo00?o0000ooooooooool06Oooool00`000?oooooo
ooooo`0Fooooo`;oogl01oooool00`000?ooooooooooo`02oomo07;ooooo00?o0000ooooooooool0
3oooool00ol0003oooooooooo`0booooo`;oogl02_ooool2oomo07;ooooo00?o0000ooooooooool0
2?ooool000Wooooo00?o0000ooooooooool06_ooool00`000?ooooooooooo`0Oooooo`030000oooo
oooooooo07?ooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`2booooo`03o`000?oo
oooooooo00Sooooo0009ooooo`03o`000?oooooooooo01_ooooo00?o003oooooooooool07oooool0
0`000?ooooooooooo`1booooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool0/_ooool0
0ol0003oooooooooo`08ooooo`002Oooool00ol0003oooooooooo`0Kooooo`030000oooooooooooo
023ooooo00<0003oooooooooool0LOooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo
0;;ooooo00?o0000ooooooooool02?ooool000Wooooo00?o0000ooooooooool07?ooool00`000?oo
ooooooooo`04ooooo`;oogl000?ooooooomo0?ooO`005oooool00`000?ooooooooooo`1`ooooo`03
o`000?oooooooooo00oooooo00?o0000ooooooooool08oooool2oomo0003ooooooooO`3oogl008[o
oooo00?o0000ooooooooool02?ooool000Wooooo00?o0000ooooooooool07Oooool00`000?oooooo
ooooo`03ooooo`Googl06?ooool00`000?ooooooooooo`1_ooooo`03o`000?oooooooooo00oooooo
00?o0000ooooooooool08oooool5oomo08[ooooo00?o0000ooooooooool02?ooool000Wooooo00?o
0000ooooooooool07_ooool00`000?ooooooooooo`04ooooo`;oogl05?ooool2oomo00Cooooo00<0
003oooooooooool0K_ooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo02Gooooo0_oo
O`0Dooooo`;oogl0MOooool00ol0003oooooooooo`08ooooo`002Oooool00ol0003oooooooooo`0O
ooooo`030000oooooooooooo01Wooooo0_ooO`05ooooo`80003oK_ooool00ol0003oooooooooo`0?
ooooo`03o`000?oooooooooo03_ooooo0_ooO`1eooooo`03o`000?oooooooooo00Sooooo0009oooo
o`03o`000?oooooooooo01oooooo00<0003oooooooooool04?ooool3o`0000oooooo00<0003ooooo
ooooool0Joooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo0;;ooooo00?o0000oooo
ooooool02?ooool000Wooooo00?o0000ooooooooool08?ooool00`000?ooooooooooo`0>ooooo`Go
00003oooool00`000?ooooooooooo`1Zooooo`03o`000?oooooooooo00oooooo00?o0000oooooooo
ool0/_ooool00ol0003oooooooooo`08ooooo`002Oooool00ol0003oooooooooo`0Nooooo`;oogl0
00?ooooo0000ooooool03_ooool5o`0000oooooo00<0003oooooooooool0J_ooool00ol0003ooooo
ooooo`0?ooooo`03o`000?oooooooooo01kooooo0_ooO`2Booooo`03o`000?oooooooooo00Sooooo
0009ooooo`03o`000?oooooooooo01kooooo0_ooO`02ooooo`030000oooooooooooo00cooooo1Ol0
000@ooooo`030000oooooooooooo06Wooooo00?o0000ooooooooool03oooool00ol0003ooooooooo
o`0Nooooo`;oogl0T_ooool00ol0003oooooooooo`08ooooo`002Oooool00ol0003oooooooooo`0S
ooooo`030000ool00?oooooo00cooooo0ol0000Booooo`030000oooooooooooo06Sooooo00?o0000
ooooooooool03oooool00ol0003oooooooooo`2booooo`03o`000?oooooooooo00Sooooo0009oooo
o`03o`000?oooooooooo02Gooooo00<0003oooooooooool07oooool00`000?ooooooooooo`1Xoooo
o`03o`000?oooooooooo00oooooo00?o0000ooooooooool0/_ooool00ol0003oooooooooo`08oooo
o`002Oooool00ol0003oooooooooo`0Vooooo`030000oooooooooooo01oooooo00<0003ooooooooo
ool0Ioooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo0;;ooooo00?o0000oooooooo
ool02?ooool000Wooooo00?o0000ooooooooool09oooool00`000?ooooooooooo`0Oooooo`80003o
Ioooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo0;;ooooo00?o0000ooooooooool0
2?ooool000Wooooo00?o0000ooooooooool0:?ooool00`000?ooooooooooo`0Pooooo`030000oooo
oooooooo00;oogl0H_ooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo04kooooo0_oo
O`1Rooooo`03o`000?oooooooooo00Sooooo0009ooooo`03o`000?oooooooooo02Sooooo00?o003o
0000ooooool02Oooool2oomo01Gooooo00<0003oooooooooool00_ooO`1Rooooo`03o`000?oooooo
oooo00oooooo00?o0000ooooooooool0=?ooool2oomo01Sooooo0_ooO`1Rooooo`03o`000?oooooo
oooo00Sooooo0009ooooo`03o`000?oooooooooo02[ooooo00<0003oooooooooool01oooool2oomo
01Kooooo00<0003oooooooooool0Hoooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo
03Cooooo0_ooO`1looooo`03o`000?oooooooooo00Sooooo0009ooooo`03o`000?oooooooooo02_o
oooo00<0003oooooooooool06Oooool6o`00o`030000oooooooooooo06;ooooo00?o0000oooooooo
ool03oooool00ol0003oooooooooo`2booooo`03o`000?oooooooooo00Sooooo0009ooooo`03o`00
0?oooooooooo02cooooo00<0003oooooooooool03_ooool2oomo00;ooooo0_ooO`001?ooool0003o
0000ool00?l6ooooo`Go003oH?ooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo03go
oooo0_ooO`02ooooo`;oogl0Koooool00ol0003oooooooooo`08ooooo`002Oooool00ol0003ooooo
ooooo`0]ooooo`80003o3_ooool2oomo00;ooooo0`000?l:ooooo`040000ooooooooooooooooo`?o
003oGOooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo03gooooo0_ooO`02ooooo`;o
ogl0Koooool00ol0003oooooooooo`08ooooo`002Oooool00ol0003oooooooooo`0_ooooo`030000
oooooooooooo00kooooo00<0003oooooooooool02oooool00`000?ooooooooooo`04ooooo`;o003o
Foooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo0;;ooooo00?o0000ooooooooool0
2?ooool000Wooooo00?o0000ooooooooool0<?ooool00`000?ooooooooooo`0=ooooo`030000oooo
oooooooo00cooooo00<0003oooooooooool01Oooool2o`00oeWooooo00?o0000ooooooooool03ooo
ool00ol0003oooooooooo`2booooo`03o`000?oooooooooo00Sooooo0009ooooo`03o`000?oooooo
oooo037ooooo00<0003oooooooooool02oooool00`000?ooooooooooo`0>ooooo`030000oooooooo
oooo00Kooooo0ol00?mFooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool0/_ooool0
0ol0003oooooooooo`08ooooo`002Oooool00ol0003oooooooooo`0booooo`030000oooooooooooo
00[ooooo00<0003oooooooooool03_ooool00`000?ooooooooooo`09ooooo`;o003oE?ooool00ol0
003oooooooooo`0?ooooo`03o`000?oooooooooo0;;ooooo00?o0000ooooooooool02?ooool000Wo
oooo00?o0000ooooooooool0<_ooool00ol00?l0003oooooo`09ooooo`030000oooooooooooo013o
oooo0P000?l;ooooo`?o003oDOooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo0;;o
oooo00?o0000ooooooooool02?ooool000Wooooo00?o0000ooooooooool0=?ooool20000o`Sooooo
00<0003oooooooooool04_ooool00`000?ooooooooooo`0;ooooo`;o003oCoooool00ol0003ooooo
ooooo`0?ooooo`03o`000?oooooooooo0;;ooooo00?o0000ooooooooool02?ooool000Wooooo00?o
0000ooooooooool0=_ooool00`000?ooooooooooo`05ooooo`030000oooooooooooo01;ooooo00<0
003oooooooooool03Oooool2o`00odgooooo00?o0000ooooooooool03oooool00ol0003ooooooooo
o`2booooo`03o`000?oooooooooo00Sooooo0009ooooo`03o`000?oooooooooo03Oooooo00<0003o
ooooooooool00oooool00`000?ooooooooooo`0Dooooo`030000oooooooooooo00kooooo00?o003o
ooooooooool0B_ooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo0;;ooooo00?o0000
ooooooooool02?ooool000Wooooo00?o0000ooooooooool0>?ooool00ol00?ooooooooooo`02oooo
o`030000oooooooooooo01Cooooo00<0003oooooooooool03oooool00ol00?ooooooooooo`19oooo
o`03o`000?oooooooooo00oooooo00?o0000ooooooooool0/_ooool00ol0003oooooooooo`08oooo
o`002Oooool00ol0003oooooooooo`0iooooo`050000ooooooooooooooooo`000?l05_ooool00`00
0?ooooooooooo`0@ooooo`03o`00oooooooooooo04Sooooo00?o0000ooooooooool03oooool00ol0
003oooooooooo`2booooo`03o`000?oooooooooo00Sooooo0009ooooo`03o`000?oooooooooo03[o
oooo00@0003oooooooooool0003o5oooool00`000?ooooooooooo`0@ooooo`03o`00oooooooooooo
04Oooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`2booooo`03o`000?oooooooooo
00Sooooo0009ooooo`03o`000?oooooooooo03_ooooo0`000?lGooooo`030000oooooooooooo017o
oooo00?o003oooooooooool0A_ooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo0;;o
oooo00?o0000ooooooooool02?ooool000Wooooo00?o0000ooooooooool0?Oooool20000oaKooooo
00<0003oooooooooool04_ooool2o`00odKooooo00?o0000ooooooooool03oooool00ol0003ooooo
ooooo`2booooo`03o`000?oooooooooo00Sooooo0009ooooo`03o`000?oooooooooo03gooooo00<0
003oooooo`000?l05_ooool00`000?ooooooooooo`0Cooooo`03o`00oooooooooooo04?ooooo00?o
0000ooooooooool03oooool00ol0003oooooooooo`2booooo`03o`000?oooooooooo00Sooooo0009
ooooo`03o`000?oooooooooo03gooooo00D0003ooooooooooooo003o0000o`0Dooooo`030000oooo
oooooooo01Cooooo00?o003oooooooooool0@_ooool00ol0003oooooooooo`0?ooooo`03o`000?oo
oooooooo0;;ooooo00?o0000ooooooooool02?ooool000Wooooo00?o0000ooooooooool0?_ooool0
10000?ooooooooooooooool20000oa;ooooo00<0003oooooooooool05Oooool00ol00?oooooooooo
o`11ooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool0/_ooool00ol0003ooooooooo
o`08ooooo`002Oooool00ol0003oooooooooo`0nooooo`030000oooooooooooo00?ooooo00<0003o
ooooooooool03oooool00`000?ooooooooooo`0Fooooo`03o`00oooooooooooo043ooooo00?o0000
ooooooooool03oooool00ol0003oooooooooo`2booooo`03o`000?oooooooooo00Sooooo0009oooo
o`03o`000?oooooooooo03kooooo00<0003oooooooooool01?ooool20000o`oooooo00<0003ooooo
ooooool05oooool00ol00?ooooooooooo`0oooooo`03o`000?oooooooooo00oooooo00?o0000oooo
ooooool0/_ooool00ol0003oooooooooo`08ooooo`002Oooool00ol0003oooooooooo`0oooooo`03
0000oooooooooooo00Gooooo0P000?l=ooooo`030000oooooooooooo01Sooooo0_l00?loooooo`03
o`000?oooooooooo00oooooo00?o0000ooooooooool0/_ooool00ol0003oooooooooo`08ooooo`00
2Oooool00ol0003oooooooooo`0oooooo`030000oooooooooooo00Oooooo0P000?l:ooooo`030000
oooooooooooo01_ooooo00?o003oooooooooool0??ooool00ol0003oooooooooo`0?ooooo`03o`00
0?oooooooooo0;;ooooo00?o0000ooooooooool02?ooool000Wooooo00?o0000ooooooooool0@?oo
ool00`000?ooooooooooo`08ooooo`<0003o1_ooool00`000?ooooooooooo`0Mooooo`03o`00oooo
oooooooo03_ooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`2booooo`03o`000?oo
oooooooo00Sooooo0009ooooo`03o`000?oooooooooo043ooooo00<0003oooooooooool02oooool6
0000ob3ooooo00?o003oooooooooool0:oooool2oomo00kooooo00?o0000ooooooooool03oooool0
0ol0003oooooooooo`2Rooooo`;oogl03_ooool00ol0003oooooooooo`08ooooo`002Oooool00ol0
003oooooooooo`10ooooo`030000oooooooooooo03;ooooo00?o003oooooooooool0:_ooool2oomo
00kooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`2Rooooo`;oogl03_ooool00ol0
003oooooooooo`08ooooo`002Oooool00ol0003oooooooooo`11ooooo`030000oooooooooooo03;o
oooo00?o003oooooooooool0>Oooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo0;;o
oooo00?o0000ooooooooool02?ooool000Wooooo00?o0000ooooooooool0@Oooool00`000?oooooo
ooooo`0cooooo`03o`00oooooooooooo03Sooooo00?o0000ooooooooool03oooool00ol0003ooooo
ooooo`2booooo`03o`000?oooooooooo00Sooooo0009ooooo`03o`000?oooooooooo04;ooooo00<0
003oooooooooool0<oooool00ol00?ooooooooooo`0gooooo`03o`000?oooooooooo00oooooo00?o
0000ooooooooool0/_ooool00ol0003oooooooooo`08ooooo`002Oooool00ol0003oooooooooo`12
ooooo`030000oooooooooooo03Cooooo00?o003oooooooooool0=_ooool00ol0003oooooooooo`0?
ooooo`03o`000?oooooooooo0;;ooooo00?o0000ooooooooool02?ooool000Wooooo00?o0000oooo
ooooool0@oooool00`000?ooooooooooo`0dooooo`03o`00oooooooooooo03Gooooo00?o0000oooo
ooooool03oooool00ol0003oooooooooo`2booooo`03o`000?oooooooooo00Sooooo0009ooooo`03
o`000?oooooooooo04Cooooo00?o003oooooooooool0<oooool00ol00?ooooooooooo`0eooooo`03
o`000?oooooooooo00oooooo00?o0000ooooooooool0/_ooool00ol0003oooooooooo`08ooooo`00
2Oooool00ol0003oooooooooo`15ooooo`03o`00oooooooooooo01Sooooo0ol0000Hooooo`03o`00
oooooooooooo03Cooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`2booooo`03o`00
0?oooooooooo00Sooooo0009ooooo`03o`000?oooooooooo04Gooooo00?o003oooooooooool05ooo
ool5o`0000gooooo0_ooO`09ooooo`03o`00oooooooooooo03?ooooo00?o0000ooooooooool03ooo
ool00ol0003oooooooooo`1aooooo`;oogl0?oooool00ol0003oooooooooo`08ooooo`002Oooool0
0ol0003oooooooooo`16ooooo`03o`00oooooooooooo01Kooooo1Ol0000=ooooo`;oogl02_ooool0
0ol00?ooooooooooo`0booooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool0LOooool2
oomo03oooooo00?o0000ooooooooool02?ooool000Wooooo00?o0000ooooooooool0Aoooool00ol0
0?ooooooooooo`0Eooooo`Go00006_ooool00ol00?ooooooooooo`0Booooo`;oogl07Oooool00ol0
003oooooooooo`0?ooooo`03o`000?oooooooooo09?ooooo0_ooO`0Mooooo`03o`000?oooooooooo
00Sooooo0009ooooo`03o`000?oooooooooo04Oooooo00?o003oooooooooool05_ooool3o`0001_o
oooo00?o003oooooooooool03_ooool2oomo00;ooooo0_ooO`0Mooooo`03o`000?oooooooooo00oo
oooo00?o0000ooooooooool0Soooool2oomo00;ooooo0_ooO`0Mooooo`03o`000?oooooooooo00So
oooo0009ooooo`03o`000?oooooooooo04Sooooo00?o003oooooooooool0;oooool2oomo00?ooooo
00?o003oooooooooool03Oooool2oomo027ooooo00?o0000ooooooooool03oooool00ol0003ooooo
ooooo`1jooooo`;oogl04oooool2oomo027ooooo00?o0000ooooooooool02?ooool000Wooooo00?o
0000ooooooooool0BOooool00ol00?ooooooooooo`0^ooooo`;oogl01?ooool00ol00?oooooooooo
o`0_ooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool0N_ooool2oomo03Kooooo00?o
0000ooooooooool02?ooool000Wooooo00?o0000ooooooooool0BOooool00ol00?ooooooooooo`0X
ooooo`;oogl02_ooool00ol00?ooooooooooo`09ooooo`;oogl09?ooool00ol0003oooooooooo`0?
ooooo`03o`000?oooooooooo07Cooooo0_ooO`0Fooooo`;oogl09?ooool00ol0003oooooooooo`08
ooooo`002Oooool00ol0003oooooooooo`1:ooooo`03o`00oooooooooooo02Oooooo0_ooO`0;oooo
o`03o`00oooooooooooo00Sooooo0_ooO`0Tooooo`03o`000?oooooooooo00oooooo00?o0000oooo
ooooool0M?ooool2oomo01Kooooo0_ooO`0Tooooo`03o`000?oooooooooo00Sooooo0009ooooo`03
o`000?oooooooooo04_ooooo00?o003oooooooooool08_ooool2oomo00oooooo00?o003ooomo0?oo
ool03?ooool2oomo023ooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`1`ooooo`;o
ogl03oooool2oomo00gooooo0_ooO`0Pooooo`03o`000?oooooooooo00Sooooo0009ooooo`03o`00
0?oooooooooo04cooooo00?o003oooooooooool08Oooool2oomo00Cooooo0_ooO`09ooooo`03oomo
0?l00?oooooo00cooooo0_ooO`0Pooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool0
L?ooool2oomo00Cooooo0_ooO`09ooooo`;oogl03Oooool2oomo023ooooo00?o0000ooooooooool0
2?ooool000Wooooo00?o0000ooooooooool0COooool00ol00?ooooooooooo`06ooooo`;oogl06?oo
ool2oomo00Cooooo0_ooO`0:ooooo`03o`00oooooooooooo02gooooo00?o0000ooooooooool03ooo
ool00ol0003oooooooooo`1Fooooo`;oogl06?ooool2oomo00Cooooo0_ooO`0jooooo`03o`000?oo
oooooooo00Sooooo0009ooooo`03o`000?oooooooooo04kooooo0_l00?l6ooooo`;oogl06?ooool2
oomo017ooooo00?o003oooooooooool0;?ooool00ol0003oooooooooo`0?ooooo`03o`000?oooooo
oooo05Kooooo0_ooO`0Hooooo`;oogl0@?ooool00ol0003oooooooooo`08ooooo`002Oooool00ol0
003oooooooooo`1@ooooo`03o`00oooooooooooo033ooooo00?o003oooooooooool0;?ooool00ol0
003oooooooooo`0?ooooo`03o`000?oooooooooo0;;ooooo00?o0000ooooooooool02?ooool000Wo
oooo00?o0000ooooooooool0DOooool00ol00?ooooooooooo`09ooooo`;oogl02Oooool2oomo01Wo
oooo00?oogl0o`00ooooool0;?ooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo05go
oooo0_ooO`09ooooo`;oogl06Oooool2oomo02gooooo00?o0000ooooooooool02?ooool000Wooooo
00?o0000ooooooooool0D_ooool00ol00?ooooooooooo`08ooooo`;oogl02Oooool2oomo01Wooooo
00?oogl0o`00ooooool0;?ooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo05gooooo
0_ooO`09ooooo`;oogl06Oooool2oomo02gooooo00?o0000ooooooooool02?ooool000Wooooo00?o
0000ooooooooool0Doooool00ol00?ooooooooooo`0^ooooo`03o`00oooooooooooo02_ooooo00?o
0000ooooooooool03oooool00ol0003oooooooooo`2booooo`03o`000?oooooooooo00Sooooo0009
ooooo`03o`000?oooooooooo05Cooooo00?o003oooooooooool0;_ooool00ol00?ooooooooooo`0;
ooooo`;oogl07Oooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo09?ooooo0_ooO`0M
ooooo`03o`000?oooooooooo00Sooooo0009ooooo`03o`000?oooooooooo05Gooooo00?o003ooooo
ooooool0;Oooool00ol00?ooogl0oomo000;ooooo`;oogl07Oooool00ol0003oooooooooo`0?oooo
o`03o`000?oooooooooo08Kooooo0_ooO`0;ooooo`;oogl07Oooool00ol0003oooooooooo`08oooo
o`002Oooool00ol0003oooooooooo`1Fooooo`03o`00oooooooooooo01Wooooo0_ooO`0Aooooo`03
o`00ooooO`3oogl002[ooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`1booooo`;o
ogl04_ooool2oomo02[ooooo00?o0000ooooooooool02?ooool000Wooooo00?o0000ooooooooool0
Eoooool00ol00?ooooooooooo`0Hooooo`;oogl04_ooool00ol00?ooooooooooo`0Yooooo`03o`00
0?oooooooooo00oooooo00?o0000ooooooooool0L_ooool2oomo03kooooo00?o0000ooooooooool0
2?ooool000Wooooo00?o0000ooooooooool0F?ooool00ol00?ooooooooooo`0>ooooo`;oogl01Ooo
ool2oomo01;ooooo0_ooO`000ol00?ooooooooooo`0Yooooo`03o`000?oooooooooo00oooooo00?o
0000ooooooooool0JOooool2oomo00Gooooo0_ooO`0Booooo`;oogl0;?ooool00ol0003ooooooooo
o`08ooooo`002Oooool00ol0003oooooooooo`1Iooooo`;o003o3?ooool4oomo00Gooooo0_ooO`0>
ooooo`;oogl00_ooool2oomo0003o`00oooooooooooo02Wooooo00?o0000ooooooooool03oooool0
0ol0003oooooooooo`1Wooooo`Coogl01Oooool2oomo00kooooo0_ooO`02ooooo`;oogl0;?ooool0
0ol0003oooooooooo`08ooooo`002Oooool00ol0003oooooooooo`1Kooooo`03o`00oooooooooooo
00Wooooo0_ooO`0Gooooo`;oogl01?ooool00ol00?ooooooooooo`0Yooooo`03o`000?oooooooooo
00oooooo00?o0000ooooooooool0Ioooool2oomo01Oooooo0_ooO`0`ooooo`03o`000?oooooooooo
00Sooooo0009ooooo`03o`000?oooooooooo04Wooooo0_ooO`0Aooooo`;o003o:?ooool00ol00?oo
ooooooooo`0Yooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool0BOooool2oomo06Oo
oooo00?o0000ooooooooool02?ooool000Wooooo00?o0000ooooooooool0BOooool2oomo00Oooooo
0_ooO`0:ooooo`;o003o3_ooool2oomo01Kooooo00?o003oooooooooool0:Oooool00ol0003ooooo
ooooo`0?ooooo`03o`000?oooooooooo04Wooooo0_ooO`07ooooo`;oogl06_ooool2oomo04;ooooo
00?o0000ooooooooool02?ooool000Wooooo00?o0000ooooooooool0D_ooool2oomo00cooooo00?o
003oooooooooool02oooool2oomo01Kooooo00?o003oooooooooool0:Oooool00ol0003ooooooooo
o`0?ooooo`03o`000?oooooooooo05;ooooo0_ooO`0Jooooo`;oogl0@_ooool00ol0003ooooooooo
o`08ooooo`002Oooool00ol0003oooooooooo`1Qooooo`;o003o1_ooool2oomo01_ooooo00?o003o
ooooooooool0:Oooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo06Wooooo0_ooO`17
ooooo`03o`000?oooooooooo00Sooooo0009ooooo`03o`000?oooooooooo06?ooooo0_l00?l4oooo
o`;oogl06_ooool00ol00?ooooooooooo`0Zooooo`03o`000?oooooooooo00oooooo00?o0000oooo
ooooool0JOooool2oomo04Oooooo00?o0000ooooooooool02?ooool000Wooooo00?o0000oooooooo
ool0IOooool00ol00?ooooooooooo`0Mooooo`03o`00oooooooooooo02[ooooo00?o0000oooooooo
ool03oooool00ol0003oooooooooo`2booooo`03o`000?oooooooooo00Sooooo0009ooooo`03o`00
0?oooooooooo06Kooooo0ol00?lLooooo`03o`00oooooooooooo02[ooooo00?o0000ooooooooool0
3oooool00ol0003oooooooooo`2booooo`03o`000?oooooooooo00Sooooo0009ooooo`03o`000?oo
oooooooo06Wooooo00?o003oooooooooool06?ooool00ol00?ooooooooooo`0[ooooo`03o`000?oo
oooooooo00oooooo00?o0000ooooooooool0/_ooool00ol0003oooooooooo`08ooooo`002Oooool0
0ol0003oooooooooo`1Booooo`;oogl05_ooool2o`00oaOooooo00?o003oooooooooool0;?ooool0
0ol0003oooooooooo`0?ooooo`03o`000?oooooooooo05;ooooo0_ooO`1Nooooo`03o`000?oooooo
oooo00Sooooo0009ooooo`03o`000?oooooooooo05;ooooo0_ooO`0Hooooo`?o003o4_ooool2o`00
oboooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`1Booooo`;oogl0G_ooool00ol0
003oooooooooo`08ooooo`002Oooool00ol0003oooooooooo`1_ooooo`Co003o2oooool3o`00oc7o
oooo00?o0000ooooooooool03oooool00ol0003oooooooooo`1_ooooo`;oogl0@Oooool00ol0003o
ooooooooo`08ooooo`002Oooool00ol0003oooooooooo`1_ooooo`;oogl00_ooool;o`00ocCooooo
00?o0000ooooooooool03oooool00ol0003oooooooooo`1_ooooo`;oogl0@Oooool00ol0003ooooo
ooooo`08ooooo`002Oooool00ol0003oooooooooo`2booooo`03o`000?oooooooooo00oooooo00?o
0000ooooooooool0/_ooool00ol0003oooooooooo`08ooooo`002Oooool00ol0003oooooooooo`2b
ooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool0/_ooool00ol0003oooooooooo`08
ooooo`002Oooool00ol0003oooooooooo`1=ooooo`;oogl0Hoooool00ol0003oooooooooo`0?oooo
o`03o`000?oooooooooo04gooooo0_ooO`1Sooooo`03o`000?oooooooooo00Sooooo0009ooooo`03
o`000?oooooooooo04gooooo0_ooO`0Dooooo`;oogl0COooool00ol0003oooooooooo`0?ooooo`03
o`000?oooooooooo04gooooo0_ooO`0Dooooo`;oogl0COooool00ol0003oooooooooo`08ooooo`00
2Oooool00ol0003oooooooooo`1Sooooo`;oogl0COooool00ol0003oooooooooo`0?ooooo`03o`00
0?oooooooooo06?ooooo0_ooO`1=ooooo`03o`000?oooooooooo00Sooooo0009ooooo`03o`000?oo
oooooooo05Wooooo0_ooO`1Gooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool0FOoo
ool2oomo05Oooooo00?o0000ooooooooool02?ooool000Wooooo00?o0000ooooooooool0FOooool2
oomo05Oooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`1Iooooo`;oogl0Eoooool0
0ol0003oooooooooo`08ooooo`002Oooool00ol0003oooooooooo`1aooooo`;oogl0?oooool00ol0
003oooooooooo`0?ooooo`03o`000?oooooooooo077ooooo0_ooO`0oooooo`03o`000?oooooooooo
00Sooooo0009ooooo`03o`000?oooooooooo077ooooo0_ooO`0oooooo`03o`000?oooooooooo00oo
oooo00?o0000ooooooooool0LOooool2oomo03oooooo00?o0000ooooooooool02?ooool000Wooooo
00?o0000ooooooooool0/_ooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo0;;ooooo
00?o0000ooooooooool02?ooool000Wooooo00?o0000ooooooooool0/_ooool00ol0003ooooooooo
o`0?ooooo`03o`000?oooooooooo0;;ooooo00?o0000ooooooooool02?ooool000Wooooo00?o0000
ooooooooool0/_ooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo0;;ooooo00?o0000
ooooooooool02?ooool000Wooooo00?o0000ooooooooool0/_ooool00ol0003oooooooooo`0?oooo
o`03o`000?oooooooooo0;;ooooo00?o0000ooooooooool02?ooool000Wooooo00?o0000oooooooo
ool0/_ooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo0;;ooooo00?o0000oooooooo
ool02?ooool000Wooooo00?o0000ooooooooool0/_ooool00ol0003oooooooooo`0?ooooo`03o`00
0?oooooooooo0;;ooooo00?o0000ooooooooool02?ooool000Wooooo00?o0000ooooooooool0/_oo
ool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo0;;ooooo00?o0000ooooooooool02?oo
ool000Wooooo00?o0000ooooooooool0/_ooool00ol0003oooooooooo`0?ooooo`03o`000?oooooo
oooo0;;ooooo00?o0000ooooooooool02?ooool000Wooooo00?o0000ooooooooool0/_ooool00ol0
003oooooooooo`0?ooooo`03o`000?oooooooooo0;;ooooo00?o0000ooooooooool02?ooool000Wo
oooo00?o0000ooooooooool0/_ooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo0;;o
oooo00?o0000ooooooooool02?ooool000Wooooo00?o0000ooooooooool0/_ooool00ol0003ooooo
ooooo`0?ooooo`03o`000?oooooooooo0;;ooooo00?o0000ooooooooool02?ooool000Wooooo00?o
0000ooooooooool0/_ooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo0;;ooooo00?o
0000ooooooooool02?ooool000Wooooo00?o0000ooooooooool0/_ooool00ol0003oooooooooo`0?
ooooo`03o`000?oooooooooo0;;ooooo00?o0000ooooooooool02?ooool000Wooooo00?o0000oooo
ooooool0/_ooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo0;;ooooo00?o0000oooo
ooooool02?ooool000Wooooo00?o0000ooooooooool0/_ooool00ol0003oooooooooo`0?ooooo`03
o`000?oooooooooo0;;ooooo00?o0000ooooooooool02?ooool000Wooooo00?o0000ooooooooool0
/_ooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo0;;ooooo00?o0000ooooooooool0
2?ooool000Wooooo00?o0000ooooooooool0/_ooool00ol0003oooooooooo`0?ooooo`03o`000?oo
oooooooo0;;ooooo00?o0000ooooooooool02?ooool000Wooooo00?o0000ooooooooool0/_ooool0
0ol0003oooooooooo`0?ooooo`03o`000?oooooooooo0;;ooooo00?o0000ooooooooool02?ooool0
00Wooooo00?o0000ooooooooool0/_ooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo
0;;ooooo00?o0000ooooooooool02?ooool000Wooooo00?o0000ooooooooool0/_ooool00ol0003o
ooooooooo`0?ooooo`03o`000?oooooooooo0;;ooooo00?o0000ooooooooool02?ooool000Wooooo
00?o0000ooooooooool0/_ooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo0;;ooooo
00?o0000ooooooooool02?ooool000Wooooo00?o0000ooooooooool0/_ooool00ol0003ooooooooo
o`0?ooooo`03o`000?oooooooooo0;;ooooo00?o0000ooooooooool02?ooool000Wooooo00?o0000
ooooooooool0/_ooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo0;;ooooo00?o0000
ooooooooool02?ooool000Wooooo00?o0000ooooooooool0/_ooool00ol0003oooooooooo`0?oooo
o`03o`000?oooooooooo0;;ooooo00?o0000ooooooooool02?ooool000Wooooo00?o0000oooooooo
ool0F?ooool2oomo05Sooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`1Hooooo`;o
ogl0F?ooool00ol0003oooooooooo`08ooooo`002Oooool00ol0003oooooooooo`1Hooooo`;oogl0
F?ooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo05Sooooo0_ooO`1Hooooo`03o`00
0?oooooooooo00Sooooo0009ooooo`03o`000?oooooooooo0;;ooooo00?o0000ooooooooool03ooo
ool00ol0003oooooooooo`2booooo`03o`000?oooooooooo00Sooooo0009ooooo`03o`000?oooooo
oooo0;;ooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`2booooo`03o`000?oooooo
oooo00Sooooo0009ooooo`03o`000?oooooooooo0;;ooooo00?o0000ooooooooool03oooool00ol0
003oooooooooo`2booooo`03o`000?oooooooooo00Sooooo0009ooooo`03o`000?oooooooooo0;;o
oooo00?o0000ooooooooool03oooool00ol0003oooooooooo`2booooo`03o`000?oooooooooo00So
oooo0009ooooo`03o`000?oooooooooo0;;ooooo00?o0000ooooooooool03oooool00ol0003ooooo
ooooo`2booooo`03o`000?oooooooooo00Sooooo0009ooooo`03o`000?oooooooooo0;;ooooo00?o
0000ooooooooool03oooool00ol0003oooooooooo`2booooo`03o`000?oooooooooo00Sooooo0009
ooooo`03o`000?oooooooooo0;;ooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`2b
ooooo`03o`000?oooooooooo00Sooooo0009ooooo`03o`000?oooooooooo0;;ooooo00?o0000oooo
ooooool03oooool00ol0003oooooooooo`2booooo`03o`000?oooooooooo00Sooooo0009ooooo`03
o`000?oooooooooo0;;ooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`2booooo`03
o`000?oooooooooo00Sooooo0009ooooo`03o`000?oooooooooo0;;ooooo00?o0000ooooooooool0
3oooool00ol0003oooooooooo`2booooo`03o`000?oooooooooo00Sooooo0009ooooo`03o`000?oo
oooooooo0;;ooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`2booooo`03o`000?oo
oooooooo00Sooooo0009ooooo`03o`000?oooooooooo0;;ooooo00?o0000ooooooooool03oooool0
0ol0003oooooooooo`2booooo`03o`000?oooooooooo00Sooooo0009ooooo`03o`000?oooooooooo
0;;ooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`2booooo`03o`000?oooooooooo
00Sooooo0009oooookKo00004Ooooonfo`0000[ooooo003ooooooi7ooooo003ooooooi7ooooo003o
oooooi7ooooo003ooooooi7ooooo003ooooooi7ooooo003ooooooi7ooooo003ooooooi7ooooo003o
oooooi7ooooo003ooooooi7ooooo0000\
\>"],
  ImageRangeCache->{{{0, 399}, {399, 0}} -> {-0.0500105, -0.0500105, \
0.00526322, 0.00526322}, {{9.5, 190.438}, {389.5, 208.5}} -> {-1.15081, \
-1.15117, 0.0115117, 0.0115117}, {{208.5, 389.438}, {389.5, 208.5}} -> \
{-1.09771, -0.0754011, 0.0052648, 0.0052648}, {{9.5, 190.438}, {190.438, \
9.5}} -> {-1.11761, -3.34306, 0.0111796, 0.0111796}, {{208.5, 389.438}, \
{190.438, 9.5}} -> {-3.34236, -3.34306, 0.0111796, 0.0111796}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
%%ImageSize: 400 400 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.47619 0.0238095 0.47619 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.0238095 0.477324 0.477324 MathSubStart
%% ContourGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.480769 0.5 0.480769 [
[ 0 0 -0.125 0 ]
[ 0 0 -0.125 0 ]
[ 0 1 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
0 0 m
1 0 L
s
0 0 m
0 1 L
s
0 1 m
1 1 L
s
1 0 m
1 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
.01923 .98077 m
.98077 .98077 L
.98077 .01923 L
.01923 .01923 L
F
.5 Mabswid
.1 g
.01923 .18078 m
.02818 .19231 L
.03846 .20426 L
.04463 .21154 L
.05769 .22721 L
.06074 .23077 L
.07692 .24992 L
.07699 .25 L
.09358 .26923 L
.09615 .27219 L
.10983 .28846 L
.11538 .29503 L
.12547 .30769 L
.13462 .31929 L
.14018 .32692 L
.15365 .34615 L
.15385 .3464 L
.16589 .36538 L
.17308 .37854 L
.17595 .38462 L
.18423 .40385 L
.19091 .42308 L
.19231 .42756 L
.19691 .44231 L
.20294 .46154 L
.20948 .48077 L
.21154 .48641 L
.21686 .5 L
.22515 .51923 L
.23077 .5312 L
.23439 .53846 L
.24463 .55769 L
.25 .56718 L
.25582 .57692 L
.26798 .59615 L
.26923 .59807 L
.28116 .61538 L
.28846 .62552 L
.29531 .63462 L
.30769 .65044 L
.31047 .65385 L
.3267 .67308 L
.32692 .67333 L
.34407 .69231 L
.34615 .69454 L
.36261 .71154 L
.36538 .71431 L
.38241 .73077 L
.38462 .73283 L
.40358 .75 L
.40385 .75023 L
.42308 .76658 L
.42629 .76923 L
.44231 .78197 L
.45074 .78846 L
.46154 .79648 L
.47717 .80769 L
.48077 .81017 L
.5 .82304 L
.50602 .82692 L
.51923 .8351 L
.53788 .84615 L
.53846 .84648 L
.55769 .85703 L
.57379 .86538 L
.57692 .86693 L
.59615 .87603 L
.61538 .88448 L
.61571 .88462 L
.63462 .89209 L
.65385 .89902 L
.66862 .90385 L
.67308 .90518 L
.69231 .9105 L
.71154 .91501 L
.73077 .91866 L
.75 .92138 L
.7692 .92308 L
.76923 .92308 L
.78846 .92367 L
.8072 .92308 L
.80769 .92304 L
.82692 .92103 L
.84615 .91742 L
.86538 .9119 L
.88462 .90403 L
.88499 .90385 L
.90385 .893 L
.91508 .88462 L
.92308 .87746 L
.93411 .86538 L
.94231 .85413 L
.9471 .84615 L
.95603 .82692 L
.96154 .80941 L
.96195 .80769 L
.96546 .78846 L
.96698 .76923 L
.96677 .75 L
.96504 .73077 L
.96192 .71154 L
.96154 .70954 L
.95754 .69231 L
.95198 .67308 L
.94534 .65385 L
.94231 .64589 L
.93763 .63462 L
.92888 .61538 L
.92308 .60363 L
.91915 .59615 L
.90842 .57692 L
.90385 .56917 L
.89671 .55769 L
.88462 .53928 L
.88406 .53846 L
.87035 .51923 L
.86538 .51255 L
.85566 .5 L
.84615 .4882 L
.83993 .48077 L
.82692 .46577 L
.82312 .46154 L
.80769 .44495 L
.80515 .44231 L
.78846 .42551 L
.78596 .42308 L
.76923 .4073 L
.76545 .40385 L
.75 .39019 L
.74348 .38462 L
.73077 .3741 L
.7199 .36538 L
.71154 .35893 L
.69446 .34615 L
.69231 .34461 L
.67308 .33115 L
.66682 .32692 L
.65385 .31851 L
.6365 .30769 L
.63462 .30657 L
.61538 .29544 L
.60273 .28846 L
.59615 .28501 L
.57692 .2753 L
.56424 .26923 L
.55769 .26626 L
.53846 .25792 L
.51923 .25013 L
.51891 .25 L
.5 .24297 L
.48077 .23611 L
.46562 .23077 L
.46154 .22937 L
.44231 .22253 L
.42308 .21502 L
.41483 .21154 L
.40385 .20679 L
.38462 .19751 L
.37466 .19231 L
.36538 .18736 L
.34615 .17608 L
.34118 .17308 L
.32692 .16457 L
.31064 .15385 L
.30769 .15201 L
.28846 .13934 L
.28157 .13462 L
.26923 .1267 L
.25314 .11538 L
.25 .11343 L
.23077 .10039 L
.22471 .09615 L
.21154 .08779 L
.19583 .07692 L
.19231 .07483 L
.17308 .06233 L
.1661 .05769 L
.15385 .05042 L
.13509 .03846 L
.13462 .03816 L
.11538 .02659 L
.10189 .01923 L
.01923 .01923 L
F
0 g
.01923 .18078 m
.02818 .19231 L
.03846 .20426 L
.04463 .21154 L
.05769 .22721 L
.06074 .23077 L
.07692 .24992 L
.07699 .25 L
.09358 .26923 L
.09615 .27219 L
.10983 .28846 L
.11538 .29503 L
.12547 .30769 L
.13462 .31929 L
.14018 .32692 L
.15365 .34615 L
.15385 .3464 L
.16589 .36538 L
.17308 .37854 L
.17595 .38462 L
.18423 .40385 L
.19091 .42308 L
.19231 .42756 L
.19691 .44231 L
.20294 .46154 L
.20948 .48077 L
.21154 .48641 L
.21686 .5 L
.22515 .51923 L
.23077 .5312 L
.23439 .53846 L
.24463 .55769 L
.25 .56718 L
.25582 .57692 L
.26798 .59615 L
.26923 .59807 L
.28116 .61538 L
.28846 .62552 L
.29531 .63462 L
.30769 .65044 L
.31047 .65385 L
.3267 .67308 L
.32692 .67333 L
.34407 .69231 L
.34615 .69454 L
.36261 .71154 L
.36538 .71431 L
.38241 .73077 L
.38462 .73283 L
.40358 .75 L
Mistroke
.40385 .75023 L
.42308 .76658 L
.42629 .76923 L
.44231 .78197 L
.45074 .78846 L
.46154 .79648 L
.47717 .80769 L
.48077 .81017 L
.5 .82304 L
.50602 .82692 L
.51923 .8351 L
.53788 .84615 L
.53846 .84648 L
.55769 .85703 L
.57379 .86538 L
.57692 .86693 L
.59615 .87603 L
.61538 .88448 L
.61571 .88462 L
.63462 .89209 L
.65385 .89902 L
.66862 .90385 L
.67308 .90518 L
.69231 .9105 L
.71154 .91501 L
.73077 .91866 L
.75 .92138 L
.7692 .92308 L
.76923 .92308 L
.78846 .92367 L
.8072 .92308 L
.80769 .92304 L
.82692 .92103 L
.84615 .91742 L
.86538 .9119 L
.88462 .90403 L
.88499 .90385 L
.90385 .893 L
.91508 .88462 L
.92308 .87746 L
.93411 .86538 L
.94231 .85413 L
.9471 .84615 L
.95603 .82692 L
.96154 .80941 L
.96195 .80769 L
.96546 .78846 L
.96698 .76923 L
.96677 .75 L
.96504 .73077 L
Mistroke
.96192 .71154 L
.96154 .70954 L
.95754 .69231 L
.95198 .67308 L
.94534 .65385 L
.94231 .64589 L
.93763 .63462 L
.92888 .61538 L
.92308 .60363 L
.91915 .59615 L
.90842 .57692 L
.90385 .56917 L
.89671 .55769 L
.88462 .53928 L
.88406 .53846 L
.87035 .51923 L
.86538 .51255 L
.85566 .5 L
.84615 .4882 L
.83993 .48077 L
.82692 .46577 L
.82312 .46154 L
.80769 .44495 L
.80515 .44231 L
.78846 .42551 L
.78596 .42308 L
.76923 .4073 L
.76545 .40385 L
.75 .39019 L
.74348 .38462 L
.73077 .3741 L
.7199 .36538 L
.71154 .35893 L
.69446 .34615 L
.69231 .34461 L
.67308 .33115 L
.66682 .32692 L
.65385 .31851 L
.6365 .30769 L
.63462 .30657 L
.61538 .29544 L
.60273 .28846 L
.59615 .28501 L
.57692 .2753 L
.56424 .26923 L
.55769 .26626 L
.53846 .25792 L
.51923 .25013 L
.51891 .25 L
.5 .24297 L
Mistroke
.48077 .23611 L
.46562 .23077 L
.46154 .22937 L
.44231 .22253 L
.42308 .21502 L
.41483 .21154 L
.40385 .20679 L
.38462 .19751 L
.37466 .19231 L
.36538 .18736 L
.34615 .17608 L
.34118 .17308 L
.32692 .16457 L
.31064 .15385 L
.30769 .15201 L
.28846 .13934 L
.28157 .13462 L
.26923 .1267 L
.25314 .11538 L
.25 .11343 L
.23077 .10039 L
.22471 .09615 L
.21154 .08779 L
.19583 .07692 L
.19231 .07483 L
.17308 .06233 L
.1661 .05769 L
.15385 .05042 L
.13509 .03846 L
.13462 .03816 L
.11538 .02659 L
.10189 .01923 L
Mfstroke
.2 g
.01923 .13371 m
.01984 .13462 L
.03266 .15385 L
.03846 .16193 L
.04677 .17308 L
.05769 .18753 L
.06149 .19231 L
.0769 .21154 L
.07692 .21157 L
.09308 .23077 L
.09615 .23442 L
.10965 .25 L
.11538 .25661 L
.1265 .26923 L
.13462 .27843 L
.14348 .28846 L
.15385 .30016 L
.16044 .30769 L
.17308 .32212 L
.17717 .32692 L
.19231 .34475 L
.19346 .34615 L
.20916 .36538 L
.21154 .36824 L
.22384 .38462 L
.23077 .39414 L
.23713 .40385 L
.24887 .42308 L
.25 .42504 L
.25912 .44231 L
.26797 .46154 L
.26923 .46452 L
.27606 .48077 L
.28399 .5 L
.28846 .51051 L
.29233 .51923 L
.30147 .53846 L
.30769 .55053 L
.3116 .55769 L
.32285 .57692 L
.32692 .58346 L
.33527 .59615 L
.34615 .61167 L
.34889 .61538 L
.36379 .63462 L
.36538 .63659 L
.38001 .65385 L
.38462 .65903 L
.39764 .67308 L
.40385 .67949 L
.41679 .69231 L
.42308 .69829 L
.43761 .71154 L
.44231 .71566 L
.46032 .73077 L
.46154 .73175 L
.48077 .74666 L
.48526 .75 L
.5 .76049 L
.51292 .76923 L
.51923 .77332 L
.53846 .78517 L
.54407 .78846 L
.55769 .79607 L
.57692 .80606 L
.58022 .80769 L
.59615 .81511 L
.61538 .82326 L
.62478 .82692 L
.63462 .83047 L
.65385 .8367 L
.67308 .84195 L
.69231 .84614 L
.69236 .84615 L
.71154 .84917 L
.73077 .85097 L
.75 .85139 L
.76923 .85023 L
.78846 .8472 L
.79328 .84615 L
.80769 .84187 L
.82692 .83353 L
.83793 .82692 L
.84615 .8208 L
.85961 .80769 L
.86538 .80039 L
.87279 .78846 L
.88094 .76923 L
.88462 .75606 L
.88557 .75 L
.8875 .73077 L
.88723 .71154 L
.88508 .69231 L
.88462 .68901 L
.88127 .67308 L
.87594 .65385 L
.86923 .63462 L
.86538 .62495 L
.8612 .61538 L
.85188 .59615 L
.84615 .5854 L
.84134 .57692 L
.82956 .55769 L
.82692 .55363 L
.81654 .53846 L
.80769 .52632 L
.80227 .51923 L
.78846 .50208 L
.78671 .5 L
.76978 .48077 L
.76923 .48018 L
.75138 .46154 L
.75 .46016 L
.73139 .44231 L
.73077 .44173 L
.71154 .42469 L
.70964 .42308 L
.69231 .4089 L
.68585 .40385 L
.67308 .39423 L
.65969 .38462 L
.65385 .38059 L
.63462 .36791 L
.63062 .36538 L
.61538 .35615 L
.59792 .34615 L
.59615 .34518 L
.57692 .33501 L
.56079 .32692 L
.55769 .32543 L
.53846 .31637 L
.51961 .30769 L
.51923 .30752 L
.5 .29876 L
.48077 .28966 L
.47832 .28846 L
.46154 .28017 L
.44231 .26986 L
.44116 .26923 L
.42308 .25906 L
.40811 .25 L
.40385 .24737 L
.38462 .23512 L
.37798 .23077 L
.36538 .22248 L
.34954 .21154 L
.34615 .20923 L
.32692 .1958 L
.322 .19231 L
.30769 .18242 L
.29469 .17308 L
.28846 .16882 L
.26923 .15509 L
.26748 .15385 L
.25 .14191 L
.2396 .13462 L
.23077 .12882 L
.21154 .11571 L
.21106 .11538 L
.19231 .10341 L
.18107 .09615 L
.17308 .09138 L
.15385 .07971 L
.14918 .07692 L
.13462 .06888 L
.11538 .05847 L
.11392 .05769 L
.09615 .04916 L
.07692 .04067 L
.07222 .03846 L
.05769 .0336 L
.03846 .02872 L
.01923 .02954 L
F
0 g
.01923 .13371 m
.01984 .13462 L
.03266 .15385 L
.03846 .16193 L
.04677 .17308 L
.05769 .18753 L
.06149 .19231 L
.0769 .21154 L
.07692 .21157 L
.09308 .23077 L
.09615 .23442 L
.10965 .25 L
.11538 .25661 L
.1265 .26923 L
.13462 .27843 L
.14348 .28846 L
.15385 .30016 L
.16044 .30769 L
.17308 .32212 L
.17717 .32692 L
.19231 .34475 L
.19346 .34615 L
.20916 .36538 L
.21154 .36824 L
.22384 .38462 L
.23077 .39414 L
.23713 .40385 L
.24887 .42308 L
.25 .42504 L
.25912 .44231 L
.26797 .46154 L
.26923 .46452 L
.27606 .48077 L
.28399 .5 L
.28846 .51051 L
.29233 .51923 L
.30147 .53846 L
.30769 .55053 L
.3116 .55769 L
.32285 .57692 L
.32692 .58346 L
.33527 .59615 L
.34615 .61167 L
.34889 .61538 L
.36379 .63462 L
.36538 .63659 L
.38001 .65385 L
.38462 .65903 L
.39764 .67308 L
.40385 .67949 L
Mistroke
.41679 .69231 L
.42308 .69829 L
.43761 .71154 L
.44231 .71566 L
.46032 .73077 L
.46154 .73175 L
.48077 .74666 L
.48526 .75 L
.5 .76049 L
.51292 .76923 L
.51923 .77332 L
.53846 .78517 L
.54407 .78846 L
.55769 .79607 L
.57692 .80606 L
.58022 .80769 L
.59615 .81511 L
.61538 .82326 L
.62478 .82692 L
.63462 .83047 L
.65385 .8367 L
.67308 .84195 L
.69231 .84614 L
.69236 .84615 L
.71154 .84917 L
.73077 .85097 L
.75 .85139 L
.76923 .85023 L
.78846 .8472 L
.79328 .84615 L
.80769 .84187 L
.82692 .83353 L
.83793 .82692 L
.84615 .8208 L
.85961 .80769 L
.86538 .80039 L
.87279 .78846 L
.88094 .76923 L
.88462 .75606 L
.88557 .75 L
.8875 .73077 L
.88723 .71154 L
.88508 .69231 L
.88462 .68901 L
.88127 .67308 L
.87594 .65385 L
.86923 .63462 L
.86538 .62495 L
.8612 .61538 L
.85188 .59615 L
Mistroke
.84615 .5854 L
.84134 .57692 L
.82956 .55769 L
.82692 .55363 L
.81654 .53846 L
.80769 .52632 L
.80227 .51923 L
.78846 .50208 L
.78671 .5 L
.76978 .48077 L
.76923 .48018 L
.75138 .46154 L
.75 .46016 L
.73139 .44231 L
.73077 .44173 L
.71154 .42469 L
.70964 .42308 L
.69231 .4089 L
.68585 .40385 L
.67308 .39423 L
.65969 .38462 L
.65385 .38059 L
.63462 .36791 L
.63062 .36538 L
.61538 .35615 L
.59792 .34615 L
.59615 .34518 L
.57692 .33501 L
.56079 .32692 L
.55769 .32543 L
.53846 .31637 L
.51961 .30769 L
.51923 .30752 L
.5 .29876 L
.48077 .28966 L
.47832 .28846 L
.46154 .28017 L
.44231 .26986 L
.44116 .26923 L
.42308 .25906 L
.40811 .25 L
.40385 .24737 L
.38462 .23512 L
.37798 .23077 L
.36538 .22248 L
.34954 .21154 L
.34615 .20923 L
.32692 .1958 L
.322 .19231 L
.30769 .18242 L
Mistroke
.29469 .17308 L
.28846 .16882 L
.26923 .15509 L
.26748 .15385 L
.25 .14191 L
.2396 .13462 L
.23077 .12882 L
.21154 .11571 L
.21106 .11538 L
.19231 .10341 L
.18107 .09615 L
.17308 .09138 L
.15385 .07971 L
.14918 .07692 L
.13462 .06888 L
.11538 .05847 L
.11392 .05769 L
.09615 .04916 L
.07692 .04067 L
.07222 .03846 L
.05769 .0336 L
.03846 .02872 L
.01923 .02954 L
Mfstroke
.3 g
.03846 .06529 m
.05769 .06401 L
.07692 .06698 L
.09615 .07279 L
.10822 .07692 L
.11538 .08038 L
.13462 .0894 L
.14806 .09615 L
.15385 .09935 L
.17308 .11026 L
.18195 .11538 L
.19231 .12178 L
.21154 .13384 L
.21278 .13462 L
.23077 .14659 L
.24173 .15385 L
.25 .15958 L
.26923 .17288 L
.26952 .17308 L
.28846 .1867 L
.29641 .19231 L
.30769 .20054 L
.32299 .21154 L
.32692 .21442 L
.34615 .22844 L
.3494 .23077 L
.36538 .24242 L
.37604 .25 L
.38462 .2561 L
.40352 .26923 L
.40385 .26945 L
.42308 .28263 L
.43191 .28846 L
.44231 .2952 L
.46154 .3072 L
.46235 .30769 L
.48077 .31878 L
.49501 .32692 L
.5 .32974 L
.51923 .34038 L
.52996 .34615 L
.53846 .35077 L
.55769 .36119 L
.56538 .36538 L
.57692 .37185 L
.59615 .38298 L
.5989 .38462 L
.61538 .3948 L
.6293 .40385 L
.63462 .40744 L
.65385 .42108 L
.65654 .42308 L
.67308 .43586 L
.681 .44231 L
.69231 .45192 L
.70308 .46154 L
.71154 .46945 L
.72307 .48077 L
.73077 .4887 L
.7412 .5 L
.75 .51005 L
.75764 .51923 L
.76923 .53405 L
.7725 .53846 L
.78583 .55769 L
.78846 .56174 L
.79769 .57692 L
.80769 .59536 L
.80809 .59615 L
.81699 .61538 L
.82435 .63462 L
.82692 .64217 L
.83008 .65385 L
.83402 .67308 L
.83595 .69231 L
.83554 .71154 L
.83221 .73077 L
.82692 .74628 L
.82499 .75 L
.81193 .76923 L
.80769 .77366 L
.78846 .78799 L
.78764 .78846 L
.76923 .79656 L
.75 .80153 L
.73077 .80388 L
.71154 .80416 L
.69231 .80272 L
.67308 .79975 L
.65385 .79543 L
.63462 .78987 L
.63027 .78846 L
.61538 .78311 L
.59615 .77522 L
.58306 .76923 L
.57692 .76623 L
.55769 .75612 L
.54694 .75 L
.53846 .7449 L
.51923 .73254 L
.51662 .73077 L
.5 .71896 L
.49016 .71154 L
.48077 .70411 L
.46663 .69231 L
.46154 .68785 L
.44548 .67308 L
.44231 .67001 L
.42636 .65385 L
.42308 .65035 L
.40903 .63462 L
.40385 .62848 L
.39332 .61538 L
.38462 .60384 L
.37911 .59615 L
.36627 .57692 L
.36538 .57552 L
.35468 .55769 L
.34615 .54229 L
.34412 .53846 L
.3343 .51923 L
.32692 .50441 L
.32476 .5 L
.31495 .48077 L
.30769 .46749 L
.30431 .46154 L
.29249 .44231 L
.28846 .43609 L
.27936 .42308 L
.26923 .40925 L
.26492 .40385 L
.25 .38537 L
.24934 .38462 L
.23299 .36538 L
.23077 .36279 L
.21605 .34615 L
.21154 .34105 L
.19875 .32692 L
.19231 .31977 L
.18131 .30769 L
.17308 .2986 L
.1639 .28846 L
.15385 .27728 L
.14669 .26923 L
.13462 .25554 L
.12984 .25 L
.11538 .23309 L
.11347 .23077 L
.09776 .21154 L
.09615 .20954 L
.08293 .19231 L
.07692 .18433 L
.06905 .17308 L
.05769 .15609 L
.05634 .15385 L
.04524 .13462 L
.03846 .12248 L
.03632 .11538 L
.03163 .09615 L
.03204 .07692 L
F
0 g
.03846 .06529 m
.05769 .06401 L
.07692 .06698 L
.09615 .07279 L
.10822 .07692 L
.11538 .08038 L
.13462 .0894 L
.14806 .09615 L
.15385 .09935 L
.17308 .11026 L
.18195 .11538 L
.19231 .12178 L
.21154 .13384 L
.21278 .13462 L
.23077 .14659 L
.24173 .15385 L
.25 .15958 L
.26923 .17288 L
.26952 .17308 L
.28846 .1867 L
.29641 .19231 L
.30769 .20054 L
.32299 .21154 L
.32692 .21442 L
.34615 .22844 L
.3494 .23077 L
.36538 .24242 L
.37604 .25 L
.38462 .2561 L
.40352 .26923 L
.40385 .26945 L
.42308 .28263 L
.43191 .28846 L
.44231 .2952 L
.46154 .3072 L
.46235 .30769 L
.48077 .31878 L
.49501 .32692 L
.5 .32974 L
.51923 .34038 L
.52996 .34615 L
.53846 .35077 L
.55769 .36119 L
.56538 .36538 L
.57692 .37185 L
.59615 .38298 L
.5989 .38462 L
.61538 .3948 L
.6293 .40385 L
.63462 .40744 L
Mistroke
.65385 .42108 L
.65654 .42308 L
.67308 .43586 L
.681 .44231 L
.69231 .45192 L
.70308 .46154 L
.71154 .46945 L
.72307 .48077 L
.73077 .4887 L
.7412 .5 L
.75 .51005 L
.75764 .51923 L
.76923 .53405 L
.7725 .53846 L
.78583 .55769 L
.78846 .56174 L
.79769 .57692 L
.80769 .59536 L
.80809 .59615 L
.81699 .61538 L
.82435 .63462 L
.82692 .64217 L
.83008 .65385 L
.83402 .67308 L
.83595 .69231 L
.83554 .71154 L
.83221 .73077 L
.82692 .74628 L
.82499 .75 L
.81193 .76923 L
.80769 .77366 L
.78846 .78799 L
.78764 .78846 L
.76923 .79656 L
.75 .80153 L
.73077 .80388 L
.71154 .80416 L
.69231 .80272 L
.67308 .79975 L
.65385 .79543 L
.63462 .78987 L
.63027 .78846 L
.61538 .78311 L
.59615 .77522 L
.58306 .76923 L
.57692 .76623 L
.55769 .75612 L
.54694 .75 L
.53846 .7449 L
.51923 .73254 L
Mistroke
.51662 .73077 L
.5 .71896 L
.49016 .71154 L
.48077 .70411 L
.46663 .69231 L
.46154 .68785 L
.44548 .67308 L
.44231 .67001 L
.42636 .65385 L
.42308 .65035 L
.40903 .63462 L
.40385 .62848 L
.39332 .61538 L
.38462 .60384 L
.37911 .59615 L
.36627 .57692 L
.36538 .57552 L
.35468 .55769 L
.34615 .54229 L
.34412 .53846 L
.3343 .51923 L
.32692 .50441 L
.32476 .5 L
.31495 .48077 L
.30769 .46749 L
.30431 .46154 L
.29249 .44231 L
.28846 .43609 L
.27936 .42308 L
.26923 .40925 L
.26492 .40385 L
.25 .38537 L
.24934 .38462 L
.23299 .36538 L
.23077 .36279 L
.21605 .34615 L
.21154 .34105 L
.19875 .32692 L
.19231 .31977 L
.18131 .30769 L
.17308 .2986 L
.1639 .28846 L
.15385 .27728 L
.14669 .26923 L
.13462 .25554 L
.12984 .25 L
.11538 .23309 L
.11347 .23077 L
.09776 .21154 L
.09615 .20954 L
Mistroke
.08293 .19231 L
.07692 .18433 L
.06905 .17308 L
.05769 .15609 L
.05634 .15385 L
.04524 .13462 L
.03846 .12248 L
.03632 .11538 L
.03163 .09615 L
.03204 .07692 L
.03846 .06529 L
Mfstroke
.4 g
.09615 .09577 m
.09868 .09615 L
.11538 .10003 L
.13462 .10715 L
.15306 .11538 L
.15385 .11588 L
.17308 .12584 L
.18885 .13462 L
.19231 .1367 L
.21154 .14842 L
.22026 .15385 L
.23077 .16072 L
.24936 .17308 L
.25 .17352 L
.26923 .18692 L
.27694 .19231 L
.28846 .20061 L
.30362 .21154 L
.30769 .21454 L
.32692 .22876 L
.32966 .23077 L
.34615 .24314 L
.35539 .25 L
.36538 .25749 L
.38121 .26923 L
.38462 .27175 L
.40385 .28595 L
.40728 .28846 L
.42308 .29992 L
.434 .30769 L
.44231 .31351 L
.46154 .32671 L
.46186 .32692 L
.48077 .33958 L
.49089 .34615 L
.5 .35199 L
.51923 .36405 L
.5214 .36538 L
.53846 .37592 L
.55268 .38462 L
.55769 .38771 L
.57692 .39967 L
.58353 .40385 L
.59615 .41203 L
.6126 .42308 L
.61538 .42501 L
.63462 .43886 L
.63919 .44231 L
.65385 .45381 L
.66319 .46154 L
.67308 .4701 L
.68475 .48077 L
.69231 .48803 L
.70409 .5 L
.71154 .50799 L
.72142 .51923 L
.73077 .53059 L
.73686 .53846 L
.75 .5569 L
.75053 .55769 L
.76245 .57692 L
.76923 .58928 L
.77264 .59615 L
.78106 .61538 L
.78761 .63462 L
.78846 .63626 L
.7921 .65385 L
.79423 .67308 L
.79351 .69231 L
.78904 .71154 L
.78846 .71325 L
.77904 .73077 L
.76923 .74182 L
.75854 .75 L
.75 .75472 L
.73077 .76168 L
.71154 .765 L
.69231 .76569 L
.67308 .76427 L
.65385 .76107 L
.63462 .75628 L
.61538 .75006 L
.61523 .75 L
.59615 .74245 L
.57692 .73352 L
.57149 .73077 L
.55769 .72327 L
.53846 .71168 L
.53824 .71154 L
.51923 .69869 L
.51048 .69231 L
.5 .68422 L
.48648 .67308 L
.48077 .6681 L
.46534 .65385 L
.46154 .65013 L
.44653 .63462 L
.44231 .62997 L
.42973 .61538 L
.42308 .60715 L
.41465 .59615 L
.40385 .58101 L
.40106 .57692 L
.38868 .55769 L
.38462 .55105 L
.37715 .53846 L
.36599 .51923 L
.36538 .5182 L
.35472 .5 L
.34615 .48605 L
.34282 .48077 L
.32998 .46154 L
.32692 .45713 L
.31605 .44231 L
.30769 .43132 L
.301 .42308 L
.28846 .40784 L
.28497 .40385 L
.26923 .38581 L
.26813 .38462 L
.25075 .36538 L
.25 .36456 L
.23303 .34615 L
.23077 .3437 L
.21517 .32692 L
.21154 .323 L
.19736 .30769 L
.19231 .3022 L
.17976 .28846 L
.17308 .28107 L
.16254 .26923 L
.15385 .25935 L
.14585 .25 L
.13462 .23668 L
.12982 .23077 L
.11538 .21254 L
.11463 .21154 L
.10055 .19231 L
.09615 .18638 L
.08781 .17308 L
.07692 .15398 L
.07687 .15385 L
.06845 .13462 L
.0643 .11538 L
.07692 .09693 L
.07961 .09615 L
F
0 g
.09615 .09577 m
.09868 .09615 L
.11538 .10003 L
.13462 .10715 L
.15306 .11538 L
.15385 .11588 L
.17308 .12584 L
.18885 .13462 L
.19231 .1367 L
.21154 .14842 L
.22026 .15385 L
.23077 .16072 L
.24936 .17308 L
.25 .17352 L
.26923 .18692 L
.27694 .19231 L
.28846 .20061 L
.30362 .21154 L
.30769 .21454 L
.32692 .22876 L
.32966 .23077 L
.34615 .24314 L
.35539 .25 L
.36538 .25749 L
.38121 .26923 L
.38462 .27175 L
.40385 .28595 L
.40728 .28846 L
.42308 .29992 L
.434 .30769 L
.44231 .31351 L
.46154 .32671 L
.46186 .32692 L
.48077 .33958 L
.49089 .34615 L
.5 .35199 L
.51923 .36405 L
.5214 .36538 L
.53846 .37592 L
.55268 .38462 L
.55769 .38771 L
.57692 .39967 L
.58353 .40385 L
.59615 .41203 L
.6126 .42308 L
.61538 .42501 L
.63462 .43886 L
.63919 .44231 L
.65385 .45381 L
.66319 .46154 L
Mistroke
.67308 .4701 L
.68475 .48077 L
.69231 .48803 L
.70409 .5 L
.71154 .50799 L
.72142 .51923 L
.73077 .53059 L
.73686 .53846 L
.75 .5569 L
.75053 .55769 L
.76245 .57692 L
.76923 .58928 L
.77264 .59615 L
.78106 .61538 L
.78761 .63462 L
.78846 .63626 L
.7921 .65385 L
.79423 .67308 L
.79351 .69231 L
.78904 .71154 L
.78846 .71325 L
.77904 .73077 L
.76923 .74182 L
.75854 .75 L
.75 .75472 L
.73077 .76168 L
.71154 .765 L
.69231 .76569 L
.67308 .76427 L
.65385 .76107 L
.63462 .75628 L
.61538 .75006 L
.61523 .75 L
.59615 .74245 L
.57692 .73352 L
.57149 .73077 L
.55769 .72327 L
.53846 .71168 L
.53824 .71154 L
.51923 .69869 L
.51048 .69231 L
.5 .68422 L
.48648 .67308 L
.48077 .6681 L
.46534 .65385 L
.46154 .65013 L
.44653 .63462 L
.44231 .62997 L
.42973 .61538 L
.42308 .60715 L
Mistroke
.41465 .59615 L
.40385 .58101 L
.40106 .57692 L
.38868 .55769 L
.38462 .55105 L
.37715 .53846 L
.36599 .51923 L
.36538 .5182 L
.35472 .5 L
.34615 .48605 L
.34282 .48077 L
.32998 .46154 L
.32692 .45713 L
.31605 .44231 L
.30769 .43132 L
.301 .42308 L
.28846 .40784 L
.28497 .40385 L
.26923 .38581 L
.26813 .38462 L
.25075 .36538 L
.25 .36456 L
.23303 .34615 L
.23077 .3437 L
.21517 .32692 L
.21154 .323 L
.19736 .30769 L
.19231 .3022 L
.17976 .28846 L
.17308 .28107 L
.16254 .26923 L
.15385 .25935 L
.14585 .25 L
.13462 .23668 L
.12982 .23077 L
.11538 .21254 L
.11463 .21154 L
.10055 .19231 L
.09615 .18638 L
.08781 .17308 L
.07692 .15398 L
.07687 .15385 L
.06845 .13462 L
.0643 .11538 L
.07692 .09693 L
.07961 .09615 L
.09615 .09577 L
Mfstroke
.5 g
.11538 .12025 m
.13462 .12487 L
.15385 .13171 L
.16186 .13462 L
.17308 .14025 L
.19231 .15031 L
.19881 .15385 L
.21154 .16135 L
.23052 .17308 L
.23077 .17324 L
.25 .18586 L
.25959 .19231 L
.26923 .19901 L
.28695 .21154 L
.28846 .21263 L
.30769 .22671 L
.31321 .23077 L
.32692 .24106 L
.33879 .25 L
.34615 .2556 L
.36402 .26923 L
.36538 .27028 L
.38462 .28506 L
.38905 .28846 L
.40385 .29978 L
.41424 .30769 L
.42308 .31435 L
.43989 .32692 L
.44231 .32871 L
.46154 .34284 L
.46609 .34615 L
.48077 .35667 L
.49312 .36538 L
.5 .37017 L
.51923 .38343 L
.52096 .38462 L
.53846 .39655 L
.5492 .40385 L
.55769 .40965 L
.57692 .42293 L
.57714 .42308 L
.59615 .43664 L
.60387 .44231 L
.61538 .45103 L
.62869 .46154 L
.63462 .4664 L
.65125 .48077 L
.65385 .48311 L
.67153 .5 L
.67308 .50156 L
.68958 .51923 L
.69231 .52234 L
.70551 .53846 L
.71154 .54643 L
.7194 .55769 L
.73077 .57601 L
.73128 .57692 L
.74112 .59615 L
.74882 .61538 L
.75 .61729 L
.75415 .63462 L
.75675 .65385 L
.75591 .67308 L
.75018 .69231 L
.75 .69272 L
.73603 .71154 L
.73077 .71577 L
.71154 .72552 L
.69231 .72982 L
.67308 .73074 L
.65385 .72911 L
.63462 .72538 L
.61538 .71982 L
.59615 .71258 L
.59367 .71154 L
.57692 .70373 L
.55769 .69329 L
.55601 .69231 L
.53846 .68124 L
.52675 .67308 L
.51923 .66747 L
.50232 .65385 L
.5 .65185 L
.48125 .63462 L
.48077 .63414 L
.46276 .61538 L
.46154 .61402 L
.44634 .59615 L
.44231 .5911 L
.43152 .57692 L
.42308 .56519 L
.41787 .55769 L
.40489 .53846 L
.40385 .5369 L
.3921 .51923 L
.38462 .50818 L
.37901 .5 L
.36538 .48094 L
.36526 .48077 L
.35066 .46154 L
.34615 .45578 L
.33513 .44231 L
.32692 .43247 L
.31872 .42308 L
.30769 .41053 L
.30156 .40385 L
.28846 .3895 L
.28384 .38462 L
.26923 .36902 L
.26574 .36538 L
.25 .34878 L
.24747 .34615 L
.23077 .32855 L
.22922 .32692 L
.21154 .30809 L
.21117 .30769 L
.19349 .28846 L
.19231 .28717 L
.17635 .26923 L
.17308 .26553 L
.1599 .25 L
.15385 .2428 L
.14434 .23077 L
.13462 .21823 L
.12989 .21154 L
.11686 .19231 L
.11538 .1899 L
.10576 .17308 L
.0977 .15385 L
.09617 .13462 L
F
0 g
.11538 .12025 m
.13462 .12487 L
.15385 .13171 L
.16186 .13462 L
.17308 .14025 L
.19231 .15031 L
.19881 .15385 L
.21154 .16135 L
.23052 .17308 L
.23077 .17324 L
.25 .18586 L
.25959 .19231 L
.26923 .19901 L
.28695 .21154 L
.28846 .21263 L
.30769 .22671 L
.31321 .23077 L
.32692 .24106 L
.33879 .25 L
.34615 .2556 L
.36402 .26923 L
.36538 .27028 L
.38462 .28506 L
.38905 .28846 L
.40385 .29978 L
.41424 .30769 L
.42308 .31435 L
.43989 .32692 L
.44231 .32871 L
.46154 .34284 L
.46609 .34615 L
.48077 .35667 L
.49312 .36538 L
.5 .37017 L
.51923 .38343 L
.52096 .38462 L
.53846 .39655 L
.5492 .40385 L
.55769 .40965 L
.57692 .42293 L
.57714 .42308 L
.59615 .43664 L
.60387 .44231 L
.61538 .45103 L
.62869 .46154 L
.63462 .4664 L
.65125 .48077 L
.65385 .48311 L
.67153 .5 L
.67308 .50156 L
Mistroke
.68958 .51923 L
.69231 .52234 L
.70551 .53846 L
.71154 .54643 L
.7194 .55769 L
.73077 .57601 L
.73128 .57692 L
.74112 .59615 L
.74882 .61538 L
.75 .61729 L
.75415 .63462 L
.75675 .65385 L
.75591 .67308 L
.75018 .69231 L
.75 .69272 L
.73603 .71154 L
.73077 .71577 L
.71154 .72552 L
.69231 .72982 L
.67308 .73074 L
.65385 .72911 L
.63462 .72538 L
.61538 .71982 L
.59615 .71258 L
.59367 .71154 L
.57692 .70373 L
.55769 .69329 L
.55601 .69231 L
.53846 .68124 L
.52675 .67308 L
.51923 .66747 L
.50232 .65385 L
.5 .65185 L
.48125 .63462 L
.48077 .63414 L
.46276 .61538 L
.46154 .61402 L
.44634 .59615 L
.44231 .5911 L
.43152 .57692 L
.42308 .56519 L
.41787 .55769 L
.40489 .53846 L
.40385 .5369 L
.3921 .51923 L
.38462 .50818 L
.37901 .5 L
.36538 .48094 L
.36526 .48077 L
.35066 .46154 L
Mistroke
.34615 .45578 L
.33513 .44231 L
.32692 .43247 L
.31872 .42308 L
.30769 .41053 L
.30156 .40385 L
.28846 .3895 L
.28384 .38462 L
.26923 .36902 L
.26574 .36538 L
.25 .34878 L
.24747 .34615 L
.23077 .32855 L
.22922 .32692 L
.21154 .30809 L
.21117 .30769 L
.19349 .28846 L
.19231 .28717 L
.17635 .26923 L
.17308 .26553 L
.1599 .25 L
.15385 .2428 L
.14434 .23077 L
.13462 .21823 L
.12989 .21154 L
.11686 .19231 L
.11538 .1899 L
.10576 .17308 L
.0977 .15385 L
.09617 .13462 L
.11538 .12025 L
Mfstroke
.6 g
.13462 .14861 m
.15385 .14883 L
.16936 .15385 L
.17308 .15504 L
.19231 .16362 L
.21045 .17308 L
.21154 .17387 L
.23077 .18516 L
.24234 .19231 L
.25 .19734 L
.26923 .2103 L
.27104 .21154 L
.28846 .22384 L
.29808 .23077 L
.30769 .23785 L
.32392 .25 L
.32692 .25228 L
.34615 .26705 L
.34897 .26923 L
.36538 .28203 L
.37358 .28846 L
.38462 .29713 L
.398 .30769 L
.40385 .31228 L
.42244 .32692 L
.42308 .32742 L
.44231 .34246 L
.44705 .34615 L
.46154 .35732 L
.47206 .36538 L
.48077 .37197 L
.49755 .38462 L
.5 .38644 L
.51923 .40076 L
.52339 .40385 L
.53846 .41501 L
.5493 .42308 L
.55769 .42935 L
.57473 .44231 L
.57692 .444 L
.59615 .4592 L
.59902 .46154 L
.61538 .47528 L
.62163 .48077 L
.63462 .49266 L
.64219 .5 L
.65385 .5119 L
.66056 .51923 L
.67308 .5339 L
.67667 .53846 L
.69052 .55769 L
.69231 .56032 L
.70207 .57692 L
.71116 .59615 L
.71154 .59643 L
.71755 .61538 L
.72074 .63462 L
.71967 .65385 L
.71177 .67308 L
.71154 .67343 L
.69231 .6897 L
.68585 .69231 L
.67308 .69556 L
.65385 .69672 L
.63462 .69468 L
.62033 .69231 L
.61538 .69015 L
.59615 .68346 L
.57692 .67478 L
.57355 .67308 L
.55769 .66416 L
.54169 .65385 L
.53846 .65158 L
.51923 .63693 L
.51642 .63462 L
.5 .62006 L
.4951 .61538 L
.48077 .60076 L
.47651 .59615 L
.46154 .57896 L
.45984 .57692 L
.44443 .55769 L
.44231 .55496 L
.4297 .53846 L
.42308 .52972 L
.41514 .51923 L
.40385 .50453 L
.40031 .5 L
.38493 .48077 L
.38462 .48038 L
.36884 .46154 L
.36538 .45748 L
.35201 .44231 L
.34615 .43573 L
.3345 .42308 L
.32692 .41488 L
.31643 .40385 L
.30769 .39464 L
.29797 .38462 L
.28846 .37476 L
.2793 .36538 L
.26923 .355 L
.26061 .34615 L
.25 .33516 L
.24208 .32692 L
.23077 .31502 L
.2239 .30769 L
.21154 .29433 L
.20624 .28846 L
.19231 .27278 L
.18927 .26923 L
.17319 .25 L
.17308 .24987 L
.15823 .23077 L
.15385 .2258 L
.14479 .21154 L
.13462 .195 L
.13357 .19231 L
.12524 .17308 L
.12681 .15385 L
F
0 g
.13462 .14861 m
.15385 .14883 L
.16936 .15385 L
.17308 .15504 L
.19231 .16362 L
.21045 .17308 L
.21154 .17387 L
.23077 .18516 L
.24234 .19231 L
.25 .19734 L
.26923 .2103 L
.27104 .21154 L
.28846 .22384 L
.29808 .23077 L
.30769 .23785 L
.32392 .25 L
.32692 .25228 L
.34615 .26705 L
.34897 .26923 L
.36538 .28203 L
.37358 .28846 L
.38462 .29713 L
.398 .30769 L
.40385 .31228 L
.42244 .32692 L
.42308 .32742 L
.44231 .34246 L
.44705 .34615 L
.46154 .35732 L
.47206 .36538 L
.48077 .37197 L
.49755 .38462 L
.5 .38644 L
.51923 .40076 L
.52339 .40385 L
.53846 .41501 L
.5493 .42308 L
.55769 .42935 L
.57473 .44231 L
.57692 .444 L
.59615 .4592 L
.59902 .46154 L
.61538 .47528 L
.62163 .48077 L
.63462 .49266 L
.64219 .5 L
.65385 .5119 L
.66056 .51923 L
.67308 .5339 L
.67667 .53846 L
Mistroke
.69052 .55769 L
.69231 .56032 L
.70207 .57692 L
.71116 .59615 L
.71154 .59643 L
.71755 .61538 L
.72074 .63462 L
.71967 .65385 L
.71177 .67308 L
.71154 .67343 L
.69231 .6897 L
.68585 .69231 L
.67308 .69556 L
.65385 .69672 L
.63462 .69468 L
.62033 .69231 L
.61538 .69015 L
.59615 .68346 L
.57692 .67478 L
.57355 .67308 L
.55769 .66416 L
.54169 .65385 L
.53846 .65158 L
.51923 .63693 L
.51642 .63462 L
.5 .62006 L
.4951 .61538 L
.48077 .60076 L
.47651 .59615 L
.46154 .57896 L
.45984 .57692 L
.44443 .55769 L
.44231 .55496 L
.4297 .53846 L
.42308 .52972 L
.41514 .51923 L
.40385 .50453 L
.40031 .5 L
.38493 .48077 L
.38462 .48038 L
.36884 .46154 L
.36538 .45748 L
.35201 .44231 L
.34615 .43573 L
.3345 .42308 L
.32692 .41488 L
.31643 .40385 L
.30769 .39464 L
.29797 .38462 L
.28846 .37476 L
Mistroke
.2793 .36538 L
.26923 .355 L
.26061 .34615 L
.25 .33516 L
.24208 .32692 L
.23077 .31502 L
.2239 .30769 L
.21154 .29433 L
.20624 .28846 L
.19231 .27278 L
.18927 .26923 L
.17319 .25 L
.17308 .24987 L
.15823 .23077 L
.15385 .2258 L
.14479 .21154 L
.13462 .195 L
.13357 .19231 L
.12524 .17308 L
.12681 .15385 L
.13462 .14861 L
Mfstroke
.7 g
.15385 .17993 m
.17308 .17321 L
.19231 .1775 L
.21154 .18683 L
.22332 .19231 L
.23077 .19707 L
.25 .20886 L
.25431 .21154 L
.26923 .22135 L
.28297 .23077 L
.28846 .23468 L
.30769 .24872 L
.30942 .25 L
.32692 .26318 L
.33479 .26923 L
.34615 .27805 L
.35931 .28846 L
.36538 .29327 L
.38329 .30769 L
.38462 .30875 L
.40385 .32436 L
.40698 .32692 L
.42308 .34 L
.4306 .34615 L
.44231 .35562 L
.45429 .36538 L
.46154 .37119 L
.47816 .38462 L
.48077 .38669 L
.5 .40209 L
.50219 .40385 L
.51923 .41742 L
.52627 .42308 L
.53846 .43283 L
.55009 .44231 L
.55769 .44851 L
.57319 .46154 L
.57692 .4647 L
.59504 .48077 L
.59615 .48177 L
.61518 .5 L
.61538 .5002 L
.63327 .51923 L
.63462 .52071 L
.64906 .53846 L
.65385 .54469 L
.66236 .55769 L
.67292 .57692 L
.67308 .57726 L
.68039 .59615 L
.68397 .61538 L
.68187 .63462 L
.67308 .65064 L
.66934 .65385 L
.65385 .65956 L
.63462 .66148 L
.61538 .65904 L
.59721 .65385 L
.59615 .65347 L
.57692 .64531 L
.55769 .63472 L
.55753 .63462 L
.53846 .62181 L
.52995 .61538 L
.51923 .60656 L
.50751 .59615 L
.5 .589 L
.48799 .57692 L
.48077 .56927 L
.47021 .55769 L
.46154 .54786 L
.45339 .53846 L
.44231 .52551 L
.43693 .51923 L
.42308 .50309 L
.42039 .5 L
.40385 .48118 L
.40348 .48077 L
.38603 .46154 L
.38462 .45998 L
.36803 .44231 L
.36538 .4395 L
.34951 .42308 L
.34615 .4196 L
.33061 .40385 L
.32692 .4001 L
.31147 .38462 L
.30769 .38081 L
.29228 .36538 L
.28846 .36155 L
.27321 .34615 L
.26923 .34212 L
.25446 .32692 L
.25 .32234 L
.2362 .30769 L
.23077 .30196 L
.21863 .28846 L
.21154 .28067 L
.20196 .26923 L
.19231 .25781 L
.1865 .25 L
.17308 .23146 L
.17266 .23077 L
.1606 .21154 L
.15385 .19377 L
.15344 .19231 L
F
0 g
.15385 .17993 m
.17308 .17321 L
.19231 .1775 L
.21154 .18683 L
.22332 .19231 L
.23077 .19707 L
.25 .20886 L
.25431 .21154 L
.26923 .22135 L
.28297 .23077 L
.28846 .23468 L
.30769 .24872 L
.30942 .25 L
.32692 .26318 L
.33479 .26923 L
.34615 .27805 L
.35931 .28846 L
.36538 .29327 L
.38329 .30769 L
.38462 .30875 L
.40385 .32436 L
.40698 .32692 L
.42308 .34 L
.4306 .34615 L
.44231 .35562 L
.45429 .36538 L
.46154 .37119 L
.47816 .38462 L
.48077 .38669 L
.5 .40209 L
.50219 .40385 L
.51923 .41742 L
.52627 .42308 L
.53846 .43283 L
.55009 .44231 L
.55769 .44851 L
.57319 .46154 L
.57692 .4647 L
.59504 .48077 L
.59615 .48177 L
.61518 .5 L
.61538 .5002 L
.63327 .51923 L
.63462 .52071 L
.64906 .53846 L
.65385 .54469 L
.66236 .55769 L
.67292 .57692 L
.67308 .57726 L
.68039 .59615 L
Mistroke
.68397 .61538 L
.68187 .63462 L
.67308 .65064 L
.66934 .65385 L
.65385 .65956 L
.63462 .66148 L
.61538 .65904 L
.59721 .65385 L
.59615 .65347 L
.57692 .64531 L
.55769 .63472 L
.55753 .63462 L
.53846 .62181 L
.52995 .61538 L
.51923 .60656 L
.50751 .59615 L
.5 .589 L
.48799 .57692 L
.48077 .56927 L
.47021 .55769 L
.46154 .54786 L
.45339 .53846 L
.44231 .52551 L
.43693 .51923 L
.42308 .50309 L
.42039 .5 L
.40385 .48118 L
.40348 .48077 L
.38603 .46154 L
.38462 .45998 L
.36803 .44231 L
.36538 .4395 L
.34951 .42308 L
.34615 .4196 L
.33061 .40385 L
.32692 .4001 L
.31147 .38462 L
.30769 .38081 L
.29228 .36538 L
.28846 .36155 L
.27321 .34615 L
.26923 .34212 L
.25446 .32692 L
.25 .32234 L
.2362 .30769 L
.23077 .30196 L
.21863 .28846 L
.21154 .28067 L
.20196 .26923 L
.19231 .25781 L
Mistroke
.1865 .25 L
.17308 .23146 L
.17266 .23077 L
.1606 .21154 L
.15385 .19377 L
.15344 .19231 L
.15385 .17993 L
Mfstroke
.8 g
.19231 .19919 m
.21154 .20039 L
.23077 .21073 L
.23271 .21154 L
.25 .22074 L
.26669 .23077 L
.26923 .23283 L
.28846 .24599 L
.29422 .25 L
.30769 .25967 L
.32043 .26923 L
.32692 .27414 L
.34507 .28846 L
.34615 .2893 L
.36538 .30479 L
.36892 .30769 L
.38462 .32053 L
.39222 .32692 L
.40385 .33654 L
.41513 .34615 L
.42308 .35274 L
.43782 .36538 L
.44231 .36908 L
.46041 .38462 L
.46154 .38554 L
.48077 .40194 L
.48298 .40385 L
.5 .41831 L
.50549 .42308 L
.51923 .43482 L
.52773 .44231 L
.53846 .45162 L
.54937 .46154 L
.55769 .469 L
.56998 .48077 L
.57692 .48735 L
.58907 .5 L
.59615 .50735 L
.60617 .51923 L
.61538 .53045 L
.6208 .53846 L
.63249 .55769 L
.63462 .56211 L
.64049 .57692 L
.64331 .59615 L
.63462 .61472 L
.63383 .61538 L
.61538 .62203 L
.59615 .62 L
.5814 .61538 L
.57692 .61363 L
.55769 .60398 L
.54474 .59615 L
.53846 .59154 L
.51958 .57692 L
.51923 .57662 L
.5 .55962 L
.49792 .55769 L
.48077 .54102 L
.4782 .53846 L
.46154 .52141 L
.45942 .51923 L
.44231 .50141 L
.44094 .5 L
.42308 .48147 L
.42239 .48077 L
.40385 .46184 L
.40355 .46154 L
.38462 .44258 L
.38434 .44231 L
.36538 .42364 L
.36481 .42308 L
.34615 .40491 L
.34505 .40385 L
.32692 .38627 L
.32521 .38462 L
.30769 .36754 L
.30549 .36538 L
.28846 .34856 L
.28606 .34615 L
.26923 .32911 L
.26712 .32692 L
.25 .30891 L
.24889 .30769 L
.23154 .28846 L
.23077 .28795 L
.21525 .26923 L
.21154 .26414 L
.20067 .25 L
.19231 .23622 L
.18902 .23077 L
.18251 .21154 L
F
0 g
.19231 .19919 m
.21154 .20039 L
.23077 .21073 L
.23271 .21154 L
.25 .22074 L
.26669 .23077 L
.26923 .23283 L
.28846 .24599 L
.29422 .25 L
.30769 .25967 L
.32043 .26923 L
.32692 .27414 L
.34507 .28846 L
.34615 .2893 L
.36538 .30479 L
.36892 .30769 L
.38462 .32053 L
.39222 .32692 L
.40385 .33654 L
.41513 .34615 L
.42308 .35274 L
.43782 .36538 L
.44231 .36908 L
.46041 .38462 L
.46154 .38554 L
.48077 .40194 L
.48298 .40385 L
.5 .41831 L
.50549 .42308 L
.51923 .43482 L
.52773 .44231 L
.53846 .45162 L
.54937 .46154 L
.55769 .469 L
.56998 .48077 L
.57692 .48735 L
.58907 .5 L
.59615 .50735 L
.60617 .51923 L
.61538 .53045 L
.6208 .53846 L
.63249 .55769 L
.63462 .56211 L
.64049 .57692 L
.64331 .59615 L
.63462 .61472 L
.63383 .61538 L
.61538 .62203 L
.59615 .62 L
.5814 .61538 L
Mistroke
.57692 .61363 L
.55769 .60398 L
.54474 .59615 L
.53846 .59154 L
.51958 .57692 L
.51923 .57662 L
.5 .55962 L
.49792 .55769 L
.48077 .54102 L
.4782 .53846 L
.46154 .52141 L
.45942 .51923 L
.44231 .50141 L
.44094 .5 L
.42308 .48147 L
.42239 .48077 L
.40385 .46184 L
.40355 .46154 L
.38462 .44258 L
.38434 .44231 L
.36538 .42364 L
.36481 .42308 L
.34615 .40491 L
.34505 .40385 L
.32692 .38627 L
.32521 .38462 L
.30769 .36754 L
.30549 .36538 L
.28846 .34856 L
.28606 .34615 L
.26923 .32911 L
.26712 .32692 L
.25 .30891 L
.24889 .30769 L
.23154 .28846 L
.23077 .28795 L
.21525 .26923 L
.21154 .26414 L
.20067 .25 L
.19231 .23622 L
.18902 .23077 L
.18251 .21154 L
.19231 .19919 L
Mfstroke
.9 g
.23077 .2283 m
.23625 .23077 L
.25 .23633 L
.26923 .24624 L
.27635 .25 L
.28846 .2577 L
.3051 .26923 L
.30769 .27132 L
.32692 .28646 L
.32951 .28846 L
.34615 .30134 L
.35387 .30769 L
.36538 .31688 L
.37702 .32692 L
.38462 .333 L
.39935 .34615 L
.40385 .34966 L
.42109 .36538 L
.42308 .36683 L
.44231 .3845 L
.44243 .38462 L
.46154 .40184 L
.46366 .40385 L
.48077 .4194 L
.48458 .42308 L
.5 .43725 L
.50509 .44231 L
.51923 .45561 L
.5249 .46154 L
.53846 .47491 L
.5436 .48077 L
.55769 .49614 L
.56059 .5 L
.57543 .51923 L
.57692 .52199 L
.58695 .53846 L
.5907 .55769 L
.57692 .57111 L
.55769 .56838 L
.53846 .55814 L
.53754 .55769 L
.51923 .54564 L
.50883 .53846 L
.5 .53074 L
.48584 .51923 L
.48077 .51429 L
.46453 .5 L
.46154 .49695 L
.44384 .48077 L
.44231 .47919 L
.42333 .46154 L
.42308 .46128 L
.40385 .44347 L
.40256 .44231 L
.38462 .42576 L
.38166 .42308 L
.36538 .40806 L
.36077 .40385 L
.34615 .39029 L
.34004 .38462 L
.32692 .37232 L
.31964 .36538 L
.30769 .35399 L
.29978 .34615 L
.28846 .33511 L
.28068 .32692 L
.26923 .31535 L
.2626 .30769 L
.25 .29399 L
.24594 .28846 L
.23135 .26923 L
.23077 .26839 L
.21976 .25 L
.2181 .23077 L
F
0 g
.23077 .2283 m
.23625 .23077 L
.25 .23633 L
.26923 .24624 L
.27635 .25 L
.28846 .2577 L
.3051 .26923 L
.30769 .27132 L
.32692 .28646 L
.32951 .28846 L
.34615 .30134 L
.35387 .30769 L
.36538 .31688 L
.37702 .32692 L
.38462 .333 L
.39935 .34615 L
.40385 .34966 L
.42109 .36538 L
.42308 .36683 L
.44231 .3845 L
.44243 .38462 L
.46154 .40184 L
.46366 .40385 L
.48077 .4194 L
.48458 .42308 L
.5 .43725 L
.50509 .44231 L
.51923 .45561 L
.5249 .46154 L
.53846 .47491 L
.5436 .48077 L
.55769 .49614 L
.56059 .5 L
.57543 .51923 L
.57692 .52199 L
.58695 .53846 L
.5907 .55769 L
.57692 .57111 L
.55769 .56838 L
.53846 .55814 L
.53754 .55769 L
.51923 .54564 L
.50883 .53846 L
.5 .53074 L
.48584 .51923 L
.48077 .51429 L
.46453 .5 L
.46154 .49695 L
.44384 .48077 L
.44231 .47919 L
Mistroke
.42333 .46154 L
.42308 .46128 L
.40385 .44347 L
.40256 .44231 L
.38462 .42576 L
.38166 .42308 L
.36538 .40806 L
.36077 .40385 L
.34615 .39029 L
.34004 .38462 L
.32692 .37232 L
.31964 .36538 L
.30769 .35399 L
.29978 .34615 L
.28846 .33511 L
.28068 .32692 L
.26923 .31535 L
.2626 .30769 L
.25 .29399 L
.24594 .28846 L
.23135 .26923 L
.23077 .26839 L
.21976 .25 L
.2181 .23077 L
.23077 .2283 L
Mfstroke
1 g
.26923 .26812 m
.27314 .26923 L
.28846 .27635 L
.30769 .28811 L
.30827 .28846 L
.32692 .29984 L
.33717 .30769 L
.34615 .31717 L
.36163 .32692 L
.36538 .3333 L
.38003 .34615 L
.38462 .35031 L
.40098 .36538 L
.40385 .36811 L
.42099 .38462 L
.42308 .38669 L
.44014 .40385 L
.44231 .40611 L
.45833 .42308 L
.46154 .42664 L
.47521 .44231 L
.48077 .44924 L
.48982 .46154 L
.48077 .47787 L
.46154 .46627 L
.45476 .46154 L
.44231 .45247 L
.42904 .44231 L
.42308 .43765 L
.40491 .42308 L
.40385 .42221 L
.38462 .40664 L
.38113 .40385 L
.36538 .39087 L
.35806 .38462 L
.34615 .37483 L
.33601 .36538 L
.32692 .35882 L
.3151 .34615 L
.30769 .33636 L
.2955 .32692 L
.28846 .31605 L
.2779 .30769 L
.26923 .29224 L
.26668 .28846 L
.26124 .26923 L
F
0 g
.26923 .26812 m
.27314 .26923 L
.28846 .27635 L
.30769 .28811 L
.30827 .28846 L
.32692 .29984 L
.33717 .30769 L
.34615 .31717 L
.36163 .32692 L
.36538 .3333 L
.38003 .34615 L
.38462 .35031 L
.40098 .36538 L
.40385 .36811 L
.42099 .38462 L
.42308 .38669 L
.44014 .40385 L
.44231 .40611 L
.45833 .42308 L
.46154 .42664 L
.47521 .44231 L
.48077 .44924 L
.48982 .46154 L
.48077 .47787 L
.46154 .46627 L
.45476 .46154 L
.44231 .45247 L
.42904 .44231 L
.42308 .43765 L
.40491 .42308 L
.40385 .42221 L
.38462 .40664 L
.38113 .40385 L
.36538 .39087 L
.35806 .38462 L
.34615 .37483 L
.33601 .36538 L
.32692 .35882 L
.3151 .34615 L
.30769 .33636 L
.2955 .32692 L
.28846 .31605 L
.2779 .30769 L
.26923 .29224 L
.26668 .28846 L
.26124 .26923 L
.26923 .26812 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.522676 0.0238095 0.97619 0.477324 MathSubStart
%% SurfaceGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1.04977 -0.0679587 1.04977 [
[ 0 0 0 0 ]
[ 1 .81114 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.39787 .81114 L
s
.39787 .81114 m
.40529 .59895 L
s
.40529 .59895 m
.03716 .25514 L
s
.68874 0 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.68874 0 m
.03716 .25514 L
s
.40529 .59895 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.39787 .81114 L
s
.39787 .81114 m
.40529 .59895 L
s
0 0 m
1 0 L
1 .81114 L
0 .81114 L
closepath
clip
newpath
.664 .741 .908 r
.39902 .59803 .40512 .60371 .41537 .60064 .40929 .59494 Mtetra
.40929 .59494 .41537 .60064 .42565 .59755 .4196 .59183 Mtetra
.4196 .59183 .42565 .59755 .43597 .59446 .42994 .58871 Mtetra
.42994 .58871 .43597 .59446 .44633 .59135 .44033 .58558 Mtetra
.44033 .58558 .44633 .59135 .45674 .58823 .45076 .58244 Mtetra
.45076 .58244 .45674 .58823 .46718 .5851 .46122 .57928 Mtetra
.46122 .57928 .46718 .5851 .47766 .58195 .47173 .57612 Mtetra
.47173 .57612 .47766 .58195 .48818 .5788 .48228 .57294 Mtetra
.48228 .57294 .48818 .5788 .49874 .57563 .49287 .56975 Mtetra
.49287 .56975 .49874 .57563 .50935 .57245 .5035 .56654 Mtetra
.663 .741 .908 r
.5035 .56654 .50935 .57245 .51999 .56925 .51417 .56333 Mtetra
.51417 .56333 .51999 .56925 .53068 .56605 .52489 .5601 Mtetra
.52489 .5601 .53068 .56605 .54141 .56283 .53564 .55687 Mtetra
.53564 .55687 .54141 .56283 .55218 .55961 .54644 .55362 Mtetra
.54644 .55362 .55218 .55961 .56299 .55637 .55728 .55036 Mtetra
.663 .742 .908 r
.55728 .55036 .56299 .55637 .57385 .55312 .56816 .5471 Mtetra
.663 .742 .909 r
.56816 .5471 .57385 .55312 .58474 .54987 .57909 .54383 Mtetra
.662 .742 .909 r
.57909 .54383 .58474 .54987 .59568 .54661 .59006 .54056 Mtetra
.662 .742 .91 r
.59006 .54056 .59568 .54661 .60667 .54334 .60107 .53729 Mtetra
.661 .743 .91 r
.60107 .53729 .60667 .54334 .6177 .54008 .61213 .53402 Mtetra
.66 .743 .911 r
.61213 .53402 .6177 .54008 .62877 .53681 .62324 .53076 Mtetra
.659 .744 .912 r
.62324 .53076 .62877 .53681 .63989 .53355 .63438 .52752 Mtetra
.658 .745 .914 r
.63438 .52752 .63989 .53355 .65105 .5303 .64558 .52429 Mtetra
.657 .746 .916 r
.64558 .52429 .65105 .5303 .66226 .52706 .65682 .5211 Mtetra
.655 .748 .918 r
.65682 .5211 .66226 .52706 .67352 .52384 .66811 .51793 Mtetra
.653 .75 .921 r
.66811 .51793 .67352 .52384 .68482 .52064 .67945 .5148 Mtetra
.65 .752 .924 r
.67945 .5148 .68482 .52064 .69617 .51747 .69084 .51172 Mtetra
.648 .756 .928 r
.69084 .51172 .69617 .51747 .70757 .51433 .70229 .50868 Mtetra
.645 .759 .932 r
.70229 .50868 .70757 .51433 .71903 .51122 .71378 .50569 Mtetra
.642 .763 .937 r
.71378 .50569 .71903 .51122 .73053 .50814 .72533 .50274 Mtetra
.639 .768 .941 r
.72533 .50274 .73053 .50814 .74208 .50508 .73693 .49982 Mtetra
.636 .773 .946 r
.73693 .49982 .74208 .50508 .75369 .50205 .74858 .49693 Mtetra
.633 .779 .951 r
.74858 .49693 .75369 .50205 .76535 .49903 .76029 .49405 Mtetra
.631 .784 .955 r
.76029 .49405 .76535 .49903 .77706 .49601 .77205 .49116 Mtetra
.629 .79 .959 r
.77205 .49116 .77706 .49601 .78882 .49297 .78386 .48825 Mtetra
.629 .796 .963 r
.78386 .48825 .78882 .49297 .80063 .4899 .79573 .48528 Mtetra
.63 .802 .965 r
.79573 .48528 .80063 .4899 .81249 .48678 .80764 .48224 Mtetra
.632 .807 .967 r
.80764 .48224 .81249 .48678 .8244 .4836 .81959 .47911 Mtetra
.635 .811 .967 r
.81959 .47911 .8244 .4836 .83635 .48033 .83159 .47585 Mtetra
.64 .815 .967 r
.83159 .47585 .83635 .48033 .84835 .47697 .84363 .47247 Mtetra
.646 .817 .965 r
.84363 .47247 .84835 .47697 .86038 .4735 .8557 .46894 Mtetra
.652 .817 .963 r
.8557 .46894 .86038 .4735 .87246 .46992 .86782 .46526 Mtetra
.658 .817 .96 r
.86782 .46526 .87246 .46992 .88458 .46622 .87997 .46143 Mtetra
.664 .815 .956 r
.87997 .46143 .88458 .46622 .89673 .46241 .89215 .45747 Mtetra
.67 .811 .951 r
.89215 .45747 .89673 .46241 .90893 .4585 .90438 .45338 Mtetra
.674 .807 .946 r
.90438 .45338 .90893 .4585 .92116 .4545 .91664 .44918 Mtetra
.678 .802 .941 r
.91664 .44918 .92116 .4545 .93344 .45041 .92893 .4449 Mtetra
.68 .796 .936 r
.92893 .4449 .93344 .45041 .94576 .44627 .94127 .44056 Mtetra
.681 .79 .932 r
.94127 .44056 .94576 .44627 .95812 .44208 .95366 .43617 Mtetra
.682 .784 .927 r
.95366 .43617 .95812 .44208 .97053 .43787 .96609 .43177 Mtetra
.664 .741 .908 r
.39287 .59231 .39902 .59803 .40929 .59494 .40317 .58919 Mtetra
.40317 .58919 .40929 .59494 .4196 .59183 .4135 .58606 Mtetra
.4135 .58606 .4196 .59183 .42994 .58871 .42387 .58292 Mtetra
.42387 .58292 .42994 .58871 .44033 .58558 .43428 .57977 Mtetra
.43428 .57977 .44033 .58558 .45076 .58244 .44474 .5766 Mtetra
.44474 .5766 .45076 .58244 .46122 .57928 .45523 .57343 Mtetra
.45523 .57343 .46122 .57928 .47173 .57612 .46576 .57024 Mtetra
.46576 .57024 .47173 .57612 .48228 .57294 .47634 .56704 Mtetra
.663 .741 .908 r
.47634 .56704 .48228 .57294 .49287 .56975 .48695 .56382 Mtetra
.48695 .56382 .49287 .56975 .5035 .56654 .49761 .5606 Mtetra
.49761 .5606 .5035 .56654 .51417 .56333 .50831 .55736 Mtetra
.50831 .55736 .51417 .56333 .52489 .5601 .51905 .55411 Mtetra
.51905 .55411 .52489 .5601 .53564 .55687 .52983 .55086 Mtetra
.52983 .55086 .53564 .55687 .54644 .55362 .54066 .54759 Mtetra
.663 .742 .909 r
.54066 .54759 .54644 .55362 .55728 .55036 .55153 .54432 Mtetra
.55153 .54432 .55728 .55036 .56816 .5471 .56244 .54104 Mtetra
.662 .742 .909 r
.56244 .54104 .56816 .5471 .57909 .54383 .5734 .53776 Mtetra
.662 .742 .91 r
.5734 .53776 .57909 .54383 .59006 .54056 .58439 .53449 Mtetra
.661 .743 .911 r
.58439 .53449 .59006 .54056 .60107 .53729 .59544 .53122 Mtetra
.66 .743 .912 r
.59544 .53122 .60107 .53729 .61213 .53402 .60653 .52797 Mtetra
.659 .744 .913 r
.60653 .52797 .61213 .53402 .62324 .53076 .61766 .52473 Mtetra
.657 .745 .915 r
.61766 .52473 .62324 .53076 .63438 .52752 .62884 .52152 Mtetra
.655 .747 .917 r
.62884 .52152 .63438 .52752 .64558 .52429 .64007 .51835 Mtetra
.653 .749 .92 r
.64007 .51835 .64558 .52429 .65682 .5211 .65135 .51523 Mtetra
.65 .751 .923 r
.65135 .51523 .65682 .5211 .66811 .51793 .66268 .51215 Mtetra
.647 .754 .927 r
.66268 .51215 .66811 .51793 .67945 .5148 .67406 .50913 Mtetra
.643 .758 .932 r
.67406 .50913 .67945 .5148 .69084 .51172 .68549 .50618 Mtetra
.639 .762 .937 r
.68549 .50618 .69084 .51172 .70229 .50868 .69697 .50329 Mtetra
.635 .767 .943 r
.69697 .50329 .70229 .50868 .71378 .50569 .70851 .50046 Mtetra
.63 .773 .948 r
.70851 .50046 .71378 .50569 .72533 .50274 .72011 .49769 Mtetra
.626 .779 .955 r
.72011 .49769 .72533 .50274 .73693 .49982 .73176 .49496 Mtetra
.621 .786 .961 r
.73176 .49496 .73693 .49982 .74858 .49693 .74346 .49226 Mtetra
.617 .793 .966 r
.74346 .49226 .74858 .49693 .76029 .49405 .75523 .48956 Mtetra
.613 .8 .971 r
.75523 .48956 .76029 .49405 .77205 .49116 .76704 .48684 Mtetra
.611 .808 .975 r
.76704 .48684 .77205 .49116 .78386 .48825 .77891 .48407 Mtetra
.611 .815 .978 r
.77891 .48407 .78386 .48825 .79573 .48528 .79082 .48123 Mtetra
.613 .822 .98 r
.79082 .48123 .79573 .48528 .80764 .48224 .80279 .47827 Mtetra
.617 .828 .981 r
.80279 .47827 .80764 .48224 .81959 .47911 .81479 .47517 Mtetra
.623 .832 .981 r
.81479 .47517 .81959 .47911 .83159 .47585 .82684 .47191 Mtetra
.631 .836 .979 r
.82684 .47191 .83159 .47585 .84363 .47247 .83892 .46846 Mtetra
.64 .838 .976 r
.83892 .46846 .84363 .47247 .8557 .46894 .85103 .46483 Mtetra
.649 .838 .973 r
.85103 .46483 .8557 .46894 .86782 .46526 .86318 .46101 Mtetra
.659 .836 .968 r
.86318 .46101 .86782 .46526 .87997 .46143 .87536 .45701 Mtetra
.667 .832 .963 r
.87536 .45701 .87997 .46143 .89215 .45747 .88758 .45283 Mtetra
.674 .827 .957 r
.88758 .45283 .89215 .45747 .90438 .45338 .89982 .44851 Mtetra
.68 .821 .951 r
.89982 .44851 .90438 .45338 .91664 .44918 .9121 .44407 Mtetra
.684 .814 .945 r
.9121 .44407 .91664 .44918 .92893 .4449 .92442 .43954 Mtetra
.687 .806 .939 r
.92442 .43954 .92893 .4449 .94127 .44056 .93677 .43495 Mtetra
.688 .798 .933 r
.93677 .43495 .94127 .44056 .95366 .43617 .94918 .43033 Mtetra
.688 .79 .928 r
.94918 .43033 .95366 .43617 .96609 .43177 .96163 .4257 Mtetra
.664 .741 .908 r
.38668 .58654 .39287 .59231 .40317 .58919 .397 .5834 Mtetra
.397 .5834 .40317 .58919 .4135 .58606 .40736 .58025 Mtetra
.40736 .58025 .4135 .58606 .42387 .58292 .41776 .57709 Mtetra
.41776 .57709 .42387 .58292 .43428 .57977 .42819 .57392 Mtetra
.42819 .57392 .43428 .57977 .44474 .5766 .43867 .57073 Mtetra
.43867 .57073 .44474 .5766 .45523 .57343 .44919 .56753 Mtetra
.44919 .56753 .45523 .57343 .46576 .57024 .45975 .56432 Mtetra
.663 .741 .908 r
.45975 .56432 .46576 .57024 .47634 .56704 .47035 .56109 Mtetra
.47035 .56109 .47634 .56704 .48695 .56382 .48099 .55786 Mtetra
.48099 .55786 .48695 .56382 .49761 .5606 .49168 .55461 Mtetra
.49168 .55461 .49761 .5606 .50831 .55736 .5024 .55135 Mtetra
.5024 .55135 .50831 .55736 .51905 .55411 .51317 .54809 Mtetra
.51317 .54809 .51905 .55411 .52983 .55086 .52398 .54481 Mtetra
.663 .742 .909 r
.52398 .54481 .52983 .55086 .54066 .54759 .53484 .54153 Mtetra
.662 .742 .909 r
.53484 .54153 .54066 .54759 .55153 .54432 .54573 .53825 Mtetra
.54573 .53825 .55153 .54432 .56244 .54104 .55667 .53496 Mtetra
.661 .742 .91 r
.55667 .53496 .56244 .54104 .5734 .53776 .56766 .53168 Mtetra
.66 .743 .911 r
.56766 .53168 .5734 .53776 .58439 .53449 .57869 .52841 Mtetra
.659 .744 .912 r
.57869 .52841 .58439 .53449 .59544 .53122 .58976 .52516 Mtetra
.658 .745 .914 r
.58976 .52516 .59544 .53122 .60653 .52797 .60088 .52194 Mtetra
.656 .746 .916 r
.60088 .52194 .60653 .52797 .61766 .52473 .61205 .51875 Mtetra
.654 .747 .919 r
.61205 .51875 .61766 .52473 .62884 .52152 .62326 .51561 Mtetra
.651 .75 .922 r
.62326 .51561 .62884 .52152 .64007 .51835 .63453 .51252 Mtetra
.647 .752 .926 r
.63453 .51252 .64007 .51835 .65135 .51523 .64584 .5095 Mtetra
.643 .756 .931 r
.64584 .5095 .65135 .51523 .66268 .51215 .65721 .50656 Mtetra
.639 .76 .936 r
.65721 .50656 .66268 .51215 .67406 .50913 .66863 .5037 Mtetra
.633 .765 .942 r
.66863 .5037 .67406 .50913 .68549 .50618 .6801 .50093 Mtetra
.627 .771 .949 r
.6801 .50093 .68549 .50618 .69697 .50329 .69163 .49825 Mtetra
.62 .777 .956 r
.69163 .49825 .69697 .50329 .70851 .50046 .70322 .49564 Mtetra
.612 .784 .964 r
.70322 .49564 .70851 .50046 .72011 .49769 .71487 .49311 Mtetra
.605 .792 .971 r
.71487 .49311 .72011 .49769 .73176 .49496 .72658 .49062 Mtetra
.598 .801 .978 r
.72658 .49062 .73176 .49496 .74346 .49226 .73834 .48816 Mtetra
.591 .81 .983 r
.73834 .48816 .74346 .49226 .75523 .48956 .75016 .48569 Mtetra
.586 .818 .988 r
.75016 .48569 .75523 .48956 .76704 .48684 .76203 .48317 Mtetra
.583 .827 .991 r
.76203 .48317 .76704 .48684 .77891 .48407 .77396 .48057 Mtetra
.583 .835 .993 r
.77396 .48057 .77891 .48407 .79082 .48123 .78593 .47785 Mtetra
.587 .843 .993 r
.78593 .47785 .79082 .48123 .80279 .47827 .79795 .47496 Mtetra
.594 .85 .993 r
.79795 .47496 .80279 .47827 .81479 .47517 .81 .47188 Mtetra
.605 .856 .991 r
.81 .47188 .81479 .47517 .82684 .47191 .8221 .46857 Mtetra
.618 .859 .989 r
.8221 .46857 .82684 .47191 .83892 .46846 .83422 .46503 Mtetra
.632 .861 .985 r
.83422 .46503 .83892 .46846 .85103 .46483 .84637 .46124 Mtetra
.647 .861 .981 r
.84637 .46124 .85103 .46483 .86318 .46101 .85855 .45721 Mtetra
.66 .857 .975 r
.85855 .45721 .86318 .46101 .87536 .45701 .87076 .45296 Mtetra
.672 .852 .969 r
.87076 .45296 .87536 .45701 .88758 .45283 .88299 .44851 Mtetra
.681 .844 .961 r
.88299 .44851 .88758 .45283 .89982 .44851 .89526 .4439 Mtetra
.688 .836 .954 r
.89526 .4439 .89982 .44851 .9121 .44407 .90755 .43915 Mtetra
.693 .826 .947 r
.90755 .43915 .9121 .44407 .92442 .43954 .91988 .43431 Mtetra
.695 .816 .94 r
.91988 .43431 .92442 .43954 .93677 .43495 .93225 .42943 Mtetra
.696 .806 .933 r
.93225 .42943 .93677 .43495 .94918 .43033 .94467 .42453 Mtetra
.695 .796 .928 r
.94467 .42453 .94918 .43033 .96163 .4257 .95713 .41965 Mtetra
.664 .741 .908 r
.38045 .58074 .38668 .58654 .397 .5834 .39079 .57758 Mtetra
.39079 .57758 .397 .5834 .40736 .58025 .40117 .5744 Mtetra
.40117 .5744 .40736 .58025 .41776 .57709 .4116 .57122 Mtetra
.4116 .57122 .41776 .57709 .42819 .57392 .42206 .56802 Mtetra
.42206 .56802 .42819 .57392 .43867 .57073 .43256 .56481 Mtetra
.43256 .56481 .43867 .57073 .44919 .56753 .44311 .56159 Mtetra
.663 .741 .908 r
.44311 .56159 .44919 .56753 .45975 .56432 .45369 .55835 Mtetra
.45369 .55835 .45975 .56432 .47035 .56109 .46432 .55511 Mtetra
.46432 .55511 .47035 .56109 .48099 .55786 .47499 .55185 Mtetra
.47499 .55185 .48099 .55786 .49168 .55461 .4857 .54858 Mtetra
.4857 .54858 .49168 .55461 .5024 .55135 .49646 .54531 Mtetra
.663 .742 .908 r
.49646 .54531 .5024 .55135 .51317 .54809 .50725 .54202 Mtetra
.663 .742 .909 r
.50725 .54202 .51317 .54809 .52398 .54481 .51809 .53873 Mtetra
.662 .742 .909 r
.51809 .53873 .52398 .54481 .53484 .54153 .52897 .53544 Mtetra
.662 .742 .91 r
.52897 .53544 .53484 .54153 .54573 .53825 .5399 .53215 Mtetra
.661 .742 .91 r
.5399 .53215 .54573 .53825 .55667 .53496 .55087 .52886 Mtetra
.66 .743 .911 r
.55087 .52886 .55667 .53496 .56766 .53168 .56188 .5256 Mtetra
.659 .744 .913 r
.56188 .5256 .56766 .53168 .57869 .52841 .57294 .52235 Mtetra
.657 .745 .915 r
.57294 .52235 .57869 .52841 .58976 .52516 .58404 .51913 Mtetra
.655 .746 .917 r
.58404 .51913 .58976 .52516 .60088 .52194 .5952 .51597 Mtetra
.652 .748 .92 r
.5952 .51597 .60088 .52194 .61205 .51875 .6064 .51285 Mtetra
.649 .75 .924 r
.6064 .51285 .61205 .51875 .62326 .51561 .61765 .50981 Mtetra
.644 .753 .928 r
.61765 .50981 .62326 .51561 .63453 .51252 .62895 .50686 Mtetra
.639 .757 .934 r
.62895 .50686 .63453 .51252 .64584 .5095 .6403 .504 Mtetra
.633 .762 .94 r
.6403 .504 .64584 .5095 .65721 .50656 .65171 .50125 Mtetra
.626 .767 .948 r
.65171 .50125 .65721 .50656 .66863 .5037 .66317 .49861 Mtetra
.617 .774 .956 r
.66317 .49861 .66863 .5037 .6801 .50093 .67469 .49609 Mtetra
.607 .781 .964 r
.67469 .49609 .6801 .50093 .69163 .49825 .68628 .49368 Mtetra
.596 .789 .973 r
.68628 .49368 .69163 .49825 .70322 .49564 .69792 .49137 Mtetra
.584 .798 .981 r
.69792 .49137 .70322 .49564 .71487 .49311 .70963 .48914 Mtetra
.571 .807 .988 r
.70963 .48914 .71487 .49311 .72658 .49062 .72139 .48696 Mtetra
.559 .817 .994 r
.72139 .48696 .72658 .49062 .73834 .48816 .73322 .48479 Mtetra
.548 .826 .997 r
.73322 .48479 .73834 .48816 .75016 .48569 .7451 .48258 Mtetra
.54 .835 .999 r
.7451 .48258 .75016 .48569 .76203 .48317 .75704 .48029 Mtetra
.536 .844 .999 r
.75704 .48029 .76203 .48317 .77396 .48057 .76903 .47787 Mtetra
.538 .853 .998 r
.76903 .47787 .77396 .48057 .78593 .47785 .78106 .47526 Mtetra
.546 .861 .996 r
.78106 .47526 .78593 .47785 .79795 .47496 .79313 .47242 Mtetra
.559 .87 .995 r
.79313 .47242 .79795 .47496 .81 .47188 .80524 .46931 Mtetra
.578 .877 .993 r
.80524 .46931 .81 .47188 .8221 .46857 .81737 .46591 Mtetra
.6 .882 .992 r
.81737 .46591 .8221 .46857 .83422 .46503 .82954 .4622 Mtetra
.622 .885 .989 r
.82954 .4622 .83422 .46503 .84637 .46124 .84172 .45818 Mtetra
.644 .884 .984 r
.84172 .45818 .84637 .46124 .85855 .45721 .85393 .45387 Mtetra
.663 .879 .979 r
.85393 .45387 .85855 .45721 .87076 .45296 .86615 .44929 Mtetra
.679 .872 .972 r
.86615 .44929 .87076 .45296 .88299 .44851 .8784 .44449 Mtetra
.691 .862 .964 r
.8784 .44449 .88299 .44851 .89526 .4439 .89068 .4395 Mtetra
.699 .85 .955 r
.89068 .4395 .89526 .4439 .90755 .43915 .90298 .43439 Mtetra
.703 .838 .947 r
.90298 .43439 .90755 .43915 .91988 .43431 .91532 .42919 Mtetra
.705 .825 .939 r
.91532 .42919 .91988 .43431 .93225 .42943 .9277 .42396 Mtetra
.705 .813 .932 r
.9277 .42396 .93225 .42943 .94467 .42453 .94013 .41874 Mtetra
.703 .802 .926 r
.94013 .41874 .94467 .42453 .95713 .41965 .95261 .41358 Mtetra
.664 .741 .908 r
.37417 .57489 .38045 .58074 .39079 .57758 .38454 .57171 Mtetra
.38454 .57171 .39079 .57758 .40117 .5744 .39494 .56851 Mtetra
.39494 .56851 .40117 .5744 .4116 .57122 .40539 .5653 Mtetra
.40539 .5653 .4116 .57122 .42206 .56802 .41588 .56208 Mtetra
.41588 .56208 .42206 .56802 .43256 .56481 .42641 .55885 Mtetra
.663 .741 .908 r
.42641 .55885 .43256 .56481 .44311 .56159 .43698 .55561 Mtetra
.43698 .55561 .44311 .56159 .45369 .55835 .4476 .55235 Mtetra
.4476 .55235 .45369 .55835 .46432 .55511 .45825 .54908 Mtetra
.45825 .54908 .46432 .55511 .47499 .55185 .46895 .5458 Mtetra
.46895 .5458 .47499 .55185 .4857 .54858 .47968 .54252 Mtetra
.663 .742 .908 r
.47968 .54252 .4857 .54858 .49646 .54531 .49046 .53922 Mtetra
.663 .742 .909 r
.49046 .53922 .49646 .54531 .50725 .54202 .50129 .53592 Mtetra
.662 .742 .909 r
.50129 .53592 .50725 .54202 .51809 .53873 .51215 .53262 Mtetra
.662 .742 .91 r
.51215 .53262 .51809 .53873 .52897 .53544 .52306 .52932 Mtetra
.661 .742 .91 r
.52306 .52932 .52897 .53544 .5399 .53215 .53402 .52603 Mtetra
.66 .743 .912 r
.53402 .52603 .5399 .53215 .55087 .52886 .54502 .52276 Mtetra
.658 .744 .913 r
.54502 .52276 .55087 .52886 .56188 .5256 .55606 .51952 Mtetra
.656 .745 .915 r
.55606 .51952 .56188 .5256 .57294 .52235 .56715 .51632 Mtetra
.654 .746 .918 r
.56715 .51632 .57294 .52235 .58404 .51913 .57829 .51317 Mtetra
.65 .748 .921 r
.57829 .51317 .58404 .51913 .5952 .51597 .58947 .51009 Mtetra
.646 .751 .926 r
.58947 .51009 .5952 .51597 .6064 .51285 .6007 .50709 Mtetra
.641 .754 .931 r
.6007 .50709 .6064 .51285 .61765 .50981 .61199 .5042 Mtetra
.635 .758 .937 r
.61199 .5042 .61765 .50981 .62895 .50686 .62333 .50143 Mtetra
.627 .764 .945 r
.62333 .50143 .62895 .50686 .6403 .504 .63472 .4988 Mtetra
.617 .77 .953 r
.63472 .4988 .6403 .504 .65171 .50125 .64618 .49631 Mtetra
.605 .777 .963 r
.64618 .49631 .65171 .50125 .66317 .49861 .65769 .49397 Mtetra
.591 .785 .972 r
.65769 .49397 .66317 .49861 .67469 .49609 .66927 .49178 Mtetra
.575 .793 .982 r
.66927 .49178 .67469 .49609 .68628 .49368 .6809 .48972 Mtetra
.556 .802 .99 r
.6809 .48972 .68628 .49368 .69792 .49137 .69261 .48779 Mtetra
.535 .811 .997 r
.69261 .48779 .69792 .49137 .70963 .48914 .70438 .48593 Mtetra
.514 .818 1 r
.70438 .48593 .70963 .48914 .72139 .48696 .71621 .48411 Mtetra
.493 .825 .999 r
.71621 .48411 .72139 .48696 .73322 .48479 .7281 .48228 Mtetra
.475 .832 .995 r
.7281 .48228 .73322 .48479 .7451 .48258 .74005 .48037 Mtetra
.464 .838 .989 r
.74005 .48037 .7451 .48258 .75704 .48029 .75206 .47832 Mtetra
.46 .845 .983 r
.75206 .47832 .75704 .48029 .76903 .47787 .76411 .47607 Mtetra
.467 .855 .978 r
.76411 .47607 .76903 .47787 .78106 .47526 .7762 .47355 Mtetra
.483 .866 .976 r
.7762 .47355 .78106 .47526 .79313 .47242 .78833 .47072 Mtetra
.509 .879 .977 r
.78833 .47072 .79313 .47242 .80524 .46931 .80049 .46752 Mtetra
.541 .892 .98 r
.80049 .46752 .80524 .46931 .81737 .46591 .81267 .46395 Mtetra
.577 .901 .983 r
.81267 .46395 .81737 .46591 .82954 .4622 .82486 .45998 Mtetra
.612 .906 .984 r
.82486 .45998 .82954 .4622 .84172 .45818 .83707 .45564 Mtetra
.644 .906 .982 r
.83707 .45564 .84172 .45818 .85393 .45387 .8493 .45096 Mtetra
.67 .901 .978 r
.8493 .45096 .85393 .45387 .86615 .44929 .86154 .44596 Mtetra
.69 .891 .971 r
.86154 .44596 .86615 .44929 .8784 .44449 .8738 .44072 Mtetra
.703 .878 .963 r
.8738 .44072 .8784 .44449 .89068 .4395 .88608 .43529 Mtetra
.712 .863 .954 r
.88608 .43529 .89068 .4395 .90298 .43439 .89839 .42973 Mtetra
.716 .848 .945 r
.89839 .42973 .90298 .43439 .91532 .42919 .91074 .42411 Mtetra
.717 .832 .936 r
.91074 .42411 .91532 .42919 .9277 .42396 .92312 .4185 Mtetra
.715 .818 .929 r
.92312 .4185 .9277 .42396 .94013 .41874 .93555 .41293 Mtetra
.711 .805 .923 r
.93555 .41293 .94013 .41874 .95261 .41358 .94804 .40745 Mtetra
.664 .741 .908 r
.36785 .56901 .37417 .57489 .38454 .57171 .37824 .5658 Mtetra
.37824 .5658 .38454 .57171 .39494 .56851 .38867 .56258 Mtetra
.38867 .56258 .39494 .56851 .40539 .5653 .39914 .55935 Mtetra
.39914 .55935 .40539 .5653 .41588 .56208 .40966 .5561 Mtetra
.663 .741 .908 r
.40966 .5561 .41588 .56208 .42641 .55885 .42022 .55285 Mtetra
.42022 .55285 .42641 .55885 .43698 .55561 .43081 .54958 Mtetra
.43081 .54958 .43698 .55561 .4476 .55235 .44145 .5463 Mtetra
.44145 .5463 .4476 .55235 .45825 .54908 .45213 .54301 Mtetra
.45213 .54301 .45825 .54908 .46895 .5458 .46285 .53972 Mtetra
.663 .742 .908 r
.46285 .53972 .46895 .5458 .47968 .54252 .47362 .53641 Mtetra
.663 .742 .909 r
.47362 .53641 .47968 .54252 .49046 .53922 .48443 .5331 Mtetra
.662 .742 .909 r
.48443 .5331 .49046 .53922 .50129 .53592 .49528 .52979 Mtetra
.662 .742 .91 r
.49528 .52979 .50129 .53592 .51215 .53262 .50617 .52649 Mtetra
.661 .743 .911 r
.50617 .52649 .51215 .53262 .52306 .52932 .51711 .52319 Mtetra
.659 .743 .912 r
.51711 .52319 .52306 .52932 .53402 .52603 .52809 .51992 Mtetra
.658 .744 .914 r
.52809 .51992 .53402 .52603 .54502 .52276 .53912 .51668 Mtetra
.656 .745 .916 r
.53912 .51668 .54502 .52276 .55606 .51952 .5502 .51349 Mtetra
.653 .747 .919 r
.5502 .51349 .55606 .51952 .56715 .51632 .56132 .51036 Mtetra
.649 .749 .922 r
.56132 .51036 .56715 .51632 .57829 .51317 .57248 .5073 Mtetra
.644 .751 .927 r
.57248 .5073 .57829 .51317 .58947 .51009 .5837 .50436 Mtetra
.638 .755 .933 r
.5837 .50436 .58947 .51009 .6007 .50709 .59497 .50153 Mtetra
.63 .759 .94 r
.59497 .50153 .6007 .50709 .61199 .5042 .6063 .49885 Mtetra
.62 .765 .949 r
.6063 .49885 .61199 .5042 .62333 .50143 .61768 .49634 Mtetra
.607 .771 .959 r
.61768 .49634 .62333 .50143 .63472 .4988 .62912 .494 Mtetra
.592 .779 .969 r
.62912 .494 .63472 .4988 .64618 .49631 .64062 .49186 Mtetra
.573 .787 .98 r
.64062 .49186 .64618 .49631 .65769 .49397 .65218 .48991 Mtetra
.549 .795 .99 r
.65218 .48991 .65769 .49397 .66927 .49178 .66382 .48814 Mtetra
.521 .802 .997 r
.66382 .48814 .66927 .49178 .6809 .48972 .67552 .48653 Mtetra
.489 .808 1 r
.67552 .48653 .6809 .48972 .69261 .48779 .68729 .48504 Mtetra
.453 .811 .997 r
.68729 .48504 .69261 .48779 .70438 .48593 .69913 .48363 Mtetra
.416 .81 .986 r
.69913 .48363 .70438 .48593 .71621 .48411 .71103 .48224 Mtetra
.383 .808 .97 r
.71103 .48224 .71621 .48411 .7281 .48228 .723 .48078 Mtetra
.357 .805 .95 r
.723 .48078 .7281 .48228 .74005 .48037 .73502 .47919 Mtetra
.344 .806 .932 r
.73502 .47919 .74005 .48037 .75206 .47832 .7471 .47738 Mtetra
.346 .812 .919 r
.7471 .47738 .75206 .47832 .76411 .47607 .75921 .47527 Mtetra
.364 .826 .915 r
.75921 .47527 .76411 .47607 .7762 .47355 .77137 .47279 Mtetra
.397 .846 .919 r
.77137 .47279 .7762 .47355 .78833 .47072 .78355 .46989 Mtetra
.443 .87 .931 r
.78355 .46989 .78833 .47072 .80049 .46752 .79575 .46652 Mtetra
.497 .893 .945 r
.79575 .46652 .80049 .46752 .81267 .46395 .80797 .46268 Mtetra
.553 .913 .96 r
.80797 .46268 .81267 .46395 .82486 .45998 .82019 .45836 Mtetra
.604 .924 .97 r
.82019 .45836 .82486 .45998 .83707 .45564 .83243 .45359 Mtetra
.648 .926 .974 r
.83243 .45359 .83707 .45564 .8493 .45096 .84467 .44842 Mtetra
.682 .92 .972 r
.84467 .44842 .8493 .45096 .86154 .44596 .85692 .44291 Mtetra
.705 .907 .967 r
.85692 .44291 .86154 .44596 .8738 .44072 .86918 .43713 Mtetra
.72 .891 .958 r
.86918 .43713 .8738 .44072 .88608 .43529 .88146 .43117 Mtetra
.727 .873 .949 r
.88146 .43117 .88608 .43529 .89839 .42973 .89377 .42511 Mtetra
.73 .855 .94 r
.89377 .42511 .89839 .42973 .91074 .42411 .90611 .41902 Mtetra
.729 .837 .932 r
.90611 .41902 .91074 .42411 .92312 .4185 .9185 .41297 Mtetra
.725 .821 .924 r
.9185 .41297 .92312 .4185 .93555 .41293 .93093 .40703 Mtetra
.72 .807 .919 r
.93093 .40703 .93555 .41293 .94804 .40745 .94343 .40122 Mtetra
.664 .741 .908 r
.36148 .56308 .36785 .56901 .37824 .5658 .37189 .55985 Mtetra
.37189 .55985 .37824 .5658 .38867 .56258 .38235 .5566 Mtetra
.38235 .5566 .38867 .56258 .39914 .55935 .39285 .55335 Mtetra
.663 .741 .908 r
.39285 .55335 .39914 .55935 .40966 .5561 .40339 .55008 Mtetra
.40339 .55008 .40966 .5561 .42022 .55285 .41397 .5468 Mtetra
.41397 .5468 .42022 .55285 .43081 .54958 .4246 .54351 Mtetra
.4246 .54351 .43081 .54958 .44145 .5463 .43526 .54021 Mtetra
.43526 .54021 .44145 .5463 .45213 .54301 .44597 .53691 Mtetra
.44597 .53691 .45213 .54301 .46285 .53972 .45672 .53359 Mtetra
.663 .742 .909 r
.45672 .53359 .46285 .53972 .47362 .53641 .46751 .53027 Mtetra
.662 .742 .909 r
.46751 .53027 .47362 .53641 .48443 .5331 .47835 .52695 Mtetra
.661 .742 .91 r
.47835 .52695 .48443 .5331 .49528 .52979 .48923 .52364 Mtetra
.66 .742 .911 r
.48923 .52364 .49528 .52979 .50617 .52649 .50015 .52034 Mtetra
.659 .743 .912 r
.50015 .52034 .50617 .52649 .51711 .52319 .51112 .51706 Mtetra
.657 .744 .914 r
.51112 .51706 .51711 .52319 .52809 .51992 .52213 .51382 Mtetra
.655 .745 .916 r
.52213 .51382 .52809 .51992 .53912 .51668 .53318 .51064 Mtetra
.652 .747 .919 r
.53318 .51064 .53912 .51668 .5502 .51349 .54429 .50752 Mtetra
.647 .749 .923 r
.54429 .50752 .5502 .51349 .56132 .51036 .55544 .5045 Mtetra
.642 .752 .929 r
.55544 .5045 .56132 .51036 .57248 .5073 .56664 .50159 Mtetra
.634 .755 .935 r
.56664 .50159 .57248 .5073 .5837 .50436 .57789 .49883 Mtetra
.625 .76 .943 r
.57789 .49883 .5837 .50436 .59497 .50153 .5892 .49625 Mtetra
.613 .766 .953 r
.5892 .49625 .59497 .50153 .6063 .49885 .60057 .49385 Mtetra
.597 .772 .964 r
.60057 .49385 .6063 .49885 .61768 .49634 .61199 .49168 Mtetra
.577 .78 .975 r
.61199 .49168 .61768 .49634 .62912 .494 .62348 .48974 Mtetra
.551 .787 .986 r
.62348 .48974 .62912 .494 .64062 .49186 .63503 .48804 Mtetra
.519 .794 .995 r
.63503 .48804 .64062 .49186 .65218 .48991 .64666 .48657 Mtetra
.478 .797 .999 r
.64666 .48657 .65218 .48991 .66382 .48814 .65835 .48532 Mtetra
.429 .796 .995 r
.65835 .48532 .66382 .48814 .67552 .48653 .67012 .48424 Mtetra
.373 .788 .979 r
.67012 .48424 .67552 .48653 .68729 .48504 .68196 .48329 Mtetra
.315 .773 .949 r
.68196 .48329 .68729 .48504 .69913 .48363 .69388 .48239 Mtetra
.26 .753 .91 r
.69388 .48239 .69913 .48363 .71103 .48224 .70586 .48147 Mtetra
.217 .733 .868 r
.70586 .48147 .71103 .48224 .723 .48078 .7179 .48041 Mtetra
.19 .72 .83 r
.7179 .48041 .723 .48078 .73502 .47919 .73 .47913 Mtetra
.185 .718 .804 r
.73 .47913 .73502 .47919 .7471 .47738 .74215 .47753 Mtetra
.201 .73 .793 r
.74215 .47753 .7471 .47738 .75921 .47527 .75433 .47551 Mtetra
.24 .756 .8 r
.75433 .47551 .75921 .47527 .77137 .47279 .76655 .47299 Mtetra
.299 .795 .823 r
.76655 .47299 .77137 .47279 .78355 .46989 .77878 .46993 Mtetra
.372 .84 .856 r
.77878 .46993 .78355 .46989 .79575 .46652 .79103 .46628 Mtetra
.454 .883 .893 r
.79103 .46628 .79575 .46652 .80797 .46268 .80327 .46205 Mtetra
.534 .918 .926 r
.80327 .46205 .80797 .46268 .82019 .45836 .81552 .45725 Mtetra
.605 .938 .949 r
.81552 .45725 .82019 .45836 .83243 .45359 .82777 .45192 Mtetra
.66 .943 .961 r
.82777 .45192 .83243 .45359 .84467 .44842 .84001 .44616 Mtetra
.7 .936 .963 r
.84001 .44616 .84467 .44842 .85692 .44291 .85226 .44002 Mtetra
.725 .92 .959 r
.85226 .44002 .85692 .44291 .86918 .43713 .86452 .43362 Mtetra
.739 .9 .951 r
.86452 .43362 .86918 .43713 .88146 .43117 .87679 .42706 Mtetra
.745 .879 .941 r
.87679 .42706 .88146 .43117 .89377 .42511 .8891 .42043 Mtetra
.745 .858 .932 r
.8891 .42043 .89377 .42511 .90611 .41902 .90143 .41383 Mtetra
.742 .839 .924 r
.90143 .41383 .90611 .41902 .9185 .41297 .91382 .40732 Mtetra
.736 .822 .918 r
.91382 .40732 .9185 .41297 .93093 .40703 .92626 .40098 Mtetra
.728 .807 .913 r
.92626 .40098 .93093 .40703 .94343 .40122 .93877 .39484 Mtetra
.664 .741 .908 r
.35506 .5571 .36148 .56308 .37189 .55985 .3655 .55385 Mtetra
.3655 .55385 .37189 .55985 .38235 .5566 .37599 .55058 Mtetra
.663 .741 .908 r
.37599 .55058 .38235 .5566 .39285 .55335 .38651 .54731 Mtetra
.38651 .54731 .39285 .55335 .40339 .55008 .39708 .54402 Mtetra
.39708 .54402 .40339 .55008 .41397 .5468 .40769 .54072 Mtetra
.40769 .54072 .41397 .5468 .4246 .54351 .41834 .53741 Mtetra
.41834 .53741 .4246 .54351 .43526 .54021 .42903 .53409 Mtetra
.42903 .53409 .43526 .54021 .44597 .53691 .43976 .53076 Mtetra
.663 .742 .909 r
.43976 .53076 .44597 .53691 .45672 .53359 .45054 .52743 Mtetra
.662 .742 .909 r
.45054 .52743 .45672 .53359 .46751 .53027 .46136 .5241 Mtetra
.661 .742 .91 r
.46136 .5241 .46751 .53027 .47835 .52695 .47222 .52078 Mtetra
.66 .742 .911 r
.47222 .52078 .47835 .52695 .48923 .52364 .48313 .51747 Mtetra
.659 .743 .912 r
.48313 .51747 .48923 .52364 .50015 .52034 .49408 .51419 Mtetra
.657 .744 .914 r
.49408 .51419 .50015 .52034 .51112 .51706 .50507 .51095 Mtetra
.654 .745 .917 r
.50507 .51095 .51112 .51706 .52213 .51382 .51611 .50777 Mtetra
.651 .747 .92 r
.51611 .50777 .52213 .51382 .53318 .51064 .5272 .50466 Mtetra
.646 .749 .924 r
.5272 .50466 .53318 .51064 .54429 .50752 .53833 .50167 Mtetra
.639 .752 .93 r
.53833 .50167 .54429 .50752 .55544 .5045 .54952 .4988 Mtetra
.631 .756 .937 r
.54952 .4988 .55544 .5045 .56664 .50159 .56075 .4961 Mtetra
.62 .76 .946 r
.56075 .4961 .56664 .50159 .57789 .49883 .57204 .4936 Mtetra
.606 .766 .956 r
.57204 .4936 .57789 .49883 .5892 .49625 .58339 .49132 Mtetra
.587 .773 .968 r
.58339 .49132 .5892 .49625 .60057 .49385 .5948 .48931 Mtetra
.562 .779 .98 r
.5948 .48931 .60057 .49385 .61199 .49168 .60627 .48757 Mtetra
.528 .785 .991 r
.60627 .48757 .61199 .49168 .62348 .48974 .61781 .48613 Mtetra
.484 .789 .998 r
.61781 .48613 .62348 .48974 .63503 .48804 .62942 .48498 Mtetra
.428 .786 .996 r
.62942 .48498 .63503 .48804 .64666 .48657 .64111 .4841 Mtetra
.358 .773 .979 r
.64111 .4841 .64666 .48657 .65835 .48532 .65287 .48347 Mtetra
.277 .747 .942 r
.65287 .48347 .65835 .48532 .67012 .48424 .66472 .48302 Mtetra
.194 .709 .884 r
.66472 .48302 .67012 .48424 .68196 .48329 .67663 .48267 Mtetra
.117 .665 .814 r
.67663 .48267 .68196 .48329 .69388 .48239 .68863 .48234 Mtetra
.056 .622 .743 r
.68863 .48234 .69388 .48239 .70586 .48147 .70069 .4819 Mtetra
0 0 0 r
.70069 .4819 .70586 .48147 .7179 .48041 .71282 .48125 Mtetra
.71282 .48125 .7179 .48041 .73 .47913 .72499 .48025 Mtetra
.72499 .48025 .73 .47913 .74215 .47753 .73722 .47879 Mtetra
.73722 .47879 .74215 .47753 .75433 .47551 .74947 .47678 Mtetra
.74947 .47678 .75433 .47551 .76655 .47299 .76174 .47412 Mtetra
.209 .728 .709 r
.76174 .47412 .76655 .47299 .77878 .46993 .77402 .47077 Mtetra
.313 .801 .771 r
.77402 .47077 .77878 .46993 .79103 .46628 .7863 .46671 Mtetra
.425 .869 .836 r
.7863 .46671 .79103 .46628 .80327 .46205 .79857 .46194 Mtetra
.531 .922 .891 r
.79857 .46194 .80327 .46205 .81552 .45725 .81083 .45652 Mtetra
.619 .951 .928 r
.81083 .45652 .81552 .45725 .82777 .45192 .82308 .45052 Mtetra
.684 .958 .947 r
.82308 .45052 .82777 .45192 .84001 .44616 .83532 .44403 Mtetra
.726 .947 .952 r
.83532 .44403 .84001 .44616 .85226 .44002 .84757 .43717 Mtetra
.75 .928 .948 r
.84757 .43717 .85226 .44002 .86452 .43362 .85981 .43006 Mtetra
.761 .904 .94 r
.85981 .43006 .86452 .43362 .87679 .42706 .87208 .42283 Mtetra
.763 .88 .931 r
.87208 .42283 .87679 .42706 .8891 .42043 .88437 .41559 Mtetra
.76 .857 .922 r
.88437 .41559 .8891 .42043 .90143 .41383 .8967 .40844 Mtetra
.753 .837 .915 r
.8967 .40844 .90143 .41383 .91382 .40732 .90908 .40147 Mtetra
.745 .819 .91 r
.90908 .40147 .91382 .40732 .92626 .40098 .92153 .39473 Mtetra
.736 .804 .906 r
.92153 .39473 .92626 .40098 .93877 .39484 .93405 .38827 Mtetra
.664 .741 .908 r
.3486 .55109 .35506 .5571 .3655 .55385 .35907 .54781 Mtetra
.663 .741 .908 r
.35907 .54781 .3655 .55385 .37599 .55058 .36958 .54452 Mtetra
.36958 .54452 .37599 .55058 .38651 .54731 .38013 .54122 Mtetra
.38013 .54122 .38651 .54731 .39708 .54402 .39072 .53791 Mtetra
.39072 .53791 .39708 .54402 .40769 .54072 .40135 .53459 Mtetra
.40135 .53459 .40769 .54072 .41834 .53741 .41203 .53126 Mtetra
.41203 .53126 .41834 .53741 .42903 .53409 .42275 .52792 Mtetra
.663 .742 .909 r
.42275 .52792 .42903 .53409 .43976 .53076 .43351 .52458 Mtetra
.662 .742 .909 r
.43351 .52458 .43976 .53076 .45054 .52743 .44431 .52124 Mtetra
.661 .742 .91 r
.44431 .52124 .45054 .52743 .46136 .5241 .45516 .5179 Mtetra
.66 .742 .911 r
.45516 .5179 .46136 .5241 .47222 .52078 .46605 .51459 Mtetra
.659 .743 .912 r
.46605 .51459 .47222 .52078 .48313 .51747 .47698 .5113 Mtetra
.657 .744 .914 r
.47698 .5113 .48313 .51747 .49408 .51419 .48796 .50806 Mtetra
.654 .745 .917 r
.48796 .50806 .49408 .51419 .50507 .51095 .49898 .50487 Mtetra
.65 .747 .92 r
.49898 .50487 .50507 .51095 .51611 .50777 .51005 .50178 Mtetra
.645 .749 .925 r
.51005 .50178 .51611 .50777 .5272 .50466 .52117 .4988 Mtetra
.638 .752 .931 r
.52117 .4988 .5272 .50466 .53833 .50167 .53234 .49597 Mtetra
.628 .756 .939 r
.53234 .49597 .53833 .50167 .54952 .4988 .54355 .49332 Mtetra
.616 .76 .948 r
.54355 .49332 .54952 .4988 .56075 .4961 .55482 .49089 Mtetra
.599 .766 .959 r
.55482 .49089 .56075 .4961 .57204 .4936 .56615 .48873 Mtetra
.576 .772 .972 r
.56615 .48873 .57204 .4936 .58339 .49132 .57754 .48686 Mtetra
.546 .778 .984 r
.57754 .48686 .58339 .49132 .5948 .48931 .58899 .48533 Mtetra
.504 .782 .995 r
.58899 .48533 .5948 .48931 .60627 .48757 .60051 .48414 Mtetra
.447 .78 .998 r
.60051 .48414 .60627 .48757 .61781 .48613 .61211 .48331 Mtetra
.372 .768 .987 r
.61211 .48331 .61781 .48613 .62942 .48498 .62378 .48282 Mtetra
.279 .739 .951 r
.62378 .48282 .62942 .48498 .64111 .4841 .63554 .48264 Mtetra
.171 .689 .886 r
.63554 .48264 .64111 .4841 .65287 .48347 .64738 .48272 Mtetra
.064 .623 .795 r
.64738 .48272 .65287 .48347 .66472 .48302 .6593 .48297 Mtetra
.03 0 0 r
.6593 .48297 .66472 .48302 .67663 .48267 .6713 .48329 Mtetra
.099 0 0 r
.6713 .48329 .67663 .48267 .68863 .48234 .68338 .48354 Mtetra
.141 0 0 r
.68338 .48354 .68863 .48234 .70069 .4819 .69553 .4836 Mtetra
.155 0 0 r
.69553 .4836 .70069 .4819 .71282 .48125 .70774 .48331 Mtetra
.145 0 0 r
.70774 .48331 .71282 .48125 .72499 .48025 .71999 .48253 Mtetra
.11 0 0 r
.71999 .48253 .72499 .48025 .73722 .47879 .73228 .48113 Mtetra
.049 0 0 r
.73228 .48113 .73722 .47879 .74947 .47678 .7446 .479 Mtetra
0 0 0 r
.7446 .479 .74947 .47678 .76174 .47412 .75692 .47607 Mtetra
.75692 .47607 .76174 .47412 .77402 .47077 .76924 .47229 Mtetra
.284 .772 .701 r
.76924 .47229 .77402 .47077 .7863 .46671 .78155 .46765 Mtetra
.424 .865 .792 r
.78155 .46765 .7863 .46671 .79857 .46194 .79384 .46221 Mtetra
.552 .932 .866 r
.79384 .46221 .79857 .46194 .81083 .45652 .8061 .45602 Mtetra
.652 .965 .913 r
.8061 .45602 .81083 .45652 .82308 .45052 .81835 .4492 Mtetra
.719 .968 .935 r
.81835 .4492 .82308 .45052 .83532 .44403 .83058 .44187 Mtetra
.758 .953 .939 r
.83058 .44187 .83532 .44403 .84757 .43717 .84281 .43419 Mtetra
.776 .928 .934 r
.84281 .43419 .84757 .43717 .85981 .43006 .85504 .4263 Mtetra
.782 .901 .926 r
.85504 .4263 .85981 .43006 .87208 .42283 .86729 .41835 Mtetra
.78 .875 .917 r
.86729 .41835 .87208 .42283 .88437 .41559 .87957 .41047 Mtetra
.773 .851 .91 r
.87957 .41047 .88437 .41559 .8967 .40844 .8919 .40278 Mtetra
.763 .831 .904 r
.8919 .40278 .8967 .40844 .90908 .40147 .90428 .39534 Mtetra
.753 .814 .901 r
.90428 .39534 .90908 .40147 .92153 .39473 .91673 .38823 Mtetra
.742 .799 .898 r
.91673 .38823 .92153 .39473 .93405 .38827 .92926 .38146 Mtetra
.663 .741 .908 r
.34209 .54503 .3486 .55109 .35907 .54781 .35259 .54173 Mtetra
.35259 .54173 .35907 .54781 .36958 .54452 .36312 .53842 Mtetra
.36312 .53842 .36958 .54452 .38013 .54122 .3737 .53509 Mtetra
.3737 .53509 .38013 .54122 .39072 .53791 .38431 .53176 Mtetra
.38431 .53176 .39072 .53791 .40135 .53459 .39497 .52842 Mtetra
.39497 .52842 .40135 .53459 .41203 .53126 .40568 .52507 Mtetra
.663 .742 .909 r
.40568 .52507 .41203 .53126 .42275 .52792 .41642 .52171 Mtetra
.662 .742 .909 r
.41642 .52171 .42275 .52792 .43351 .52458 .42721 .51836 Mtetra
.661 .742 .91 r
.42721 .51836 .43351 .52458 .44431 .52124 .43804 .51502 Mtetra
.66 .742 .911 r
.43804 .51502 .44431 .52124 .45516 .5179 .44891 .51169 Mtetra
.659 .743 .912 r
.44891 .51169 .45516 .5179 .46605 .51459 .45983 .50839 Mtetra
.657 .744 .914 r
.45983 .50839 .46605 .51459 .47698 .5113 .47079 .50514 Mtetra
.653 .745 .917 r
.47079 .50514 .47698 .5113 .48796 .50806 .4818 .50196 Mtetra
.649 .746 .92 r
.4818 .50196 .48796 .50806 .49898 .50487 .49285 .49887 Mtetra
.644 .749 .925 r
.49285 .49887 .49898 .50487 .51005 .50178 .50395 .4959 Mtetra
.636 .751 .932 r
.50395 .4959 .51005 .50178 .52117 .4988 .51509 .49309 Mtetra
.626 .755 .94 r
.51509 .49309 .52117 .4988 .53234 .49597 .52629 .49048 Mtetra
.612 .76 .949 r
.52629 .49048 .53234 .49597 .54355 .49332 .53754 .48812 Mtetra
.593 .765 .961 r
.53754 .48812 .54355 .49332 .55482 .49089 .54884 .48605 Mtetra
.567 .771 .974 r
.54884 .48605 .55482 .49089 .56615 .48873 .56021 .48432 Mtetra
.531 .775 .987 r
.56021 .48432 .56615 .48873 .57754 .48686 .57164 .48297 Mtetra
.48 .776 .996 r
.57164 .48297 .57754 .48686 .58899 .48533 .58314 .48203 Mtetra
.41 .768 .995 r
.58314 .48203 .58899 .48533 .60051 .48414 .59472 .4815 Mtetra
.316 .744 .972 r
.59472 .4815 .60051 .48414 .61211 .48331 .60637 .4814 Mtetra
.197 .695 .915 r
.60637 .4814 .61211 .48331 .62378 .48282 .61811 .48168 Mtetra
.065 .62 .819 r
.61811 .48168 .62378 .48282 .63554 .48264 .62994 .4823 Mtetra
.06 0 0 r
.62994 .4823 .63554 .48264 .64738 .48272 .64186 .48318 Mtetra
.161 0 0 r
.64186 .48318 .64738 .48272 .6593 .48297 .65386 .48418 Mtetra
.231 0 0 r
.65386 .48418 .6593 .48297 .6713 .48329 .66595 .48519 Mtetra
.271 0 0 r
.66595 .48519 .6713 .48329 .68338 .48354 .67812 .48603 Mtetra
.285 0 0 r
.67812 .48603 .68338 .48354 .69553 .4836 .69036 .48654 Mtetra
.276 0 0 r
.69036 .48654 .69553 .4836 .70774 .48331 .70265 .48655 Mtetra
.245 0 0 r
.70265 .48655 .70774 .48331 .71999 .48253 .71498 .48589 Mtetra
.192 0 0 r
.71498 .48589 .71999 .48253 .73228 .48113 .72734 .48442 Mtetra
.114 0 0 r
.72734 .48442 .73228 .48113 .7446 .479 .73971 .48203 Mtetra
.006 0 0 r
.73971 .48203 .7446 .479 .75692 .47607 .75208 .47866 Mtetra
0 0 0 r
.75208 .47866 .75692 .47607 .76924 .47229 .76443 .47428 Mtetra
.295 .77 .662 r
.76443 .47428 .76924 .47229 .78155 .46765 .77676 .4689 Mtetra
.461 .881 .775 r
.77676 .4689 .78155 .46765 .79384 .46221 .78906 .46261 Mtetra
.602 .953 .859 r
.78906 .46261 .79384 .46221 .8061 .45602 .80132 .4555 Mtetra
.703 .979 .906 r
.80132 .4555 .8061 .45602 .81835 .4492 .81355 .44772 Mtetra
.762 .973 .923 r
.81355 .44772 .81835 .4492 .83058 .44187 .82577 .43946 Mtetra
.791 .949 .924 r
.82577 .43946 .83058 .44187 .84281 .43419 .83797 .43087 Mtetra
.801 .92 .917 r
.83797 .43087 .84281 .43419 .85504 .4263 .85018 .42216 Mtetra
.8 .891 .909 r
.85018 .42216 .85504 .4263 .86729 .41835 .86242 .41348 Mtetra
.793 .864 .902 r
.86242 .41348 .86729 .41835 .87957 .41047 .87469 .40497 Mtetra
.783 .841 .896 r
.87469 .40497 .87957 .41047 .8919 .40278 .88701 .39674 Mtetra
.771 .822 .893 r
.88701 .39674 .8919 .40278 .90428 .39534 .8994 .38887 Mtetra
.758 .806 .891 r
.8994 .38887 .90428 .39534 .91673 .38823 .91186 .38142 Mtetra
.746 .792 .89 r
.91186 .38142 .91673 .38823 .92926 .38146 .92441 .37438 Mtetra
.663 .741 .908 r
.33554 .53892 .34209 .54503 .35259 .54173 .34605 .5356 Mtetra
.34605 .5356 .35259 .54173 .36312 .53842 .35661 .53227 Mtetra
.35661 .53227 .36312 .53842 .3737 .53509 .36722 .52892 Mtetra
.36722 .52892 .3737 .53509 .38431 .53176 .37786 .52557 Mtetra
.37786 .52557 .38431 .53176 .39497 .52842 .38855 .52221 Mtetra
.663 .742 .909 r
.38855 .52221 .39497 .52842 .40568 .52507 .39927 .51884 Mtetra
.662 .742 .909 r
.39927 .51884 .40568 .52507 .41642 .52171 .41005 .51548 Mtetra
.661 .742 .91 r
.41005 .51548 .41642 .52171 .42721 .51836 .42086 .51212 Mtetra
.66 .742 .911 r
.42086 .51212 .42721 .51836 .43804 .51502 .43172 .50878 Mtetra
.659 .743 .912 r
.43172 .50878 .43804 .51502 .44891 .51169 .44262 .50547 Mtetra
.656 .744 .914 r
.44262 .50547 .44891 .51169 .45983 .50839 .45356 .50221 Mtetra
.653 .745 .917 r
.45356 .50221 .45983 .50839 .47079 .50514 .46455 .49902 Mtetra
.649 .746 .92 r
.46455 .49902 .47079 .50514 .4818 .50196 .47558 .49592 Mtetra
.643 .748 .925 r
.47558 .49592 .4818 .50196 .49285 .49887 .48666 .49295 Mtetra
.635 .751 .932 r
.48666 .49295 .49285 .49887 .50395 .4959 .49779 .49016 Mtetra
.624 .754 .94 r
.49779 .49016 .50395 .4959 .51509 .49309 .50897 .48758 Mtetra
.609 .759 .95 r
.50897 .48758 .51509 .49309 .52629 .49048 .52019 .48527 Mtetra
.588 .764 .962 r
.52019 .48527 .52629 .49048 .53754 .48812 .53148 .48328 Mtetra
.559 .769 .976 r
.53148 .48328 .53754 .48812 .54884 .48605 .54282 .48167 Mtetra
.518 .772 .989 r
.54282 .48167 .54884 .48605 .56021 .48432 .55422 .48048 Mtetra
.459 .769 .997 r
.55422 .48048 .56021 .48432 .57164 .48297 .5657 .47975 Mtetra
.376 .755 .99 r
.5657 .47975 .57164 .48297 .58314 .48203 .57725 .47951 Mtetra
.262 .718 .954 r
.57725 .47951 .58314 .48203 .59472 .4815 .58888 .47977 Mtetra
.121 .648 .874 r
.58888 .47977 .59472 .4815 .60637 .4814 .6006 .4805 Mtetra
0 .548 .749 r
.6006 .4805 .60637 .4814 .61811 .48168 .61241 .48166 Mtetra
.165 0 0 r
.61241 .48166 .61811 .48168 .62994 .4823 .62432 .48316 Mtetra
.267 0 0 r
.62432 .48316 .62994 .4823 .64186 .48318 .63632 .48488 Mtetra
.333 0 0 r
.63632 .48488 .64186 .48318 .65386 .48418 .64841 .48668 Mtetra
.369 0 0 r
.64841 .48668 .65386 .48418 .66595 .48519 .66059 .48837 Mtetra
.381 0 0 r
.66059 .48837 .66595 .48519 .67812 .48603 .67285 .48976 Mtetra
.373 0 0 r
.67285 .48976 .67812 .48603 .69036 .48654 .68517 .49065 Mtetra
.347 0 0 r
.68517 .49065 .69036 .48654 .70265 .48655 .69754 .49084 Mtetra
.302 0 0 r
.69754 .49084 .70265 .48655 .71498 .48589 .70995 .49017 Mtetra
.234 0 0 r
.70995 .49017 .71498 .48589 .72734 .48442 .72237 .48847 Mtetra
.137 0 0 r
.72237 .48847 .72734 .48442 .73971 .48203 .7348 .48565 Mtetra
.006 0 0 r
.7348 .48565 .73971 .48203 .75208 .47866 .7472 .48166 Mtetra
0 0 0 r
.7472 .48166 .75208 .47866 .76443 .47428 .75958 .47648 Mtetra
.354 .803 .665 r
.75958 .47648 .76443 .47428 .77676 .4689 .77191 .47018 Mtetra
.537 .919 .787 r
.77191 .47018 .77676 .4689 .78906 .46261 .7842 .46287 Mtetra
.676 .977 .866 r
.7842 .46287 .78906 .46261 .80132 .4555 .79645 .45469 Mtetra
.762 .986 .902 r
.79645 .45469 .80132 .4555 .81355 .44772 .80867 .44585 Mtetra
.804 .966 .91 r
.80867 .44585 .81355 .44772 .82577 .43946 .82086 .43655 Mtetra
.82 .935 .906 r
.82086 .43655 .82577 .43946 .83797 .43087 .83304 .42703 Mtetra
.82 .903 .898 r
.83304 .42703 .83797 .43087 .85018 .42216 .84523 .41748 Mtetra
.813 .874 .891 r
.84523 .41748 .85018 .42216 .86242 .41348 .85745 .40807 Mtetra
.802 .849 .885 r
.85745 .40807 .86242 .41348 .87469 .40497 .86972 .39897 Mtetra
.789 .828 .882 r
.86972 .39897 .87469 .40497 .88701 .39674 .88204 .39026 Mtetra
.776 .811 .881 r
.88204 .39026 .88701 .39674 .8994 .38887 .89444 .38201 Mtetra
.762 .796 .881 r
.89444 .38201 .8994 .38887 .91186 .38142 .90692 .37426 Mtetra
.748 .784 .882 r
.90692 .37426 .91186 .38142 .92441 .37438 .91949 .36702 Mtetra
.663 .741 .908 r
.32893 .53278 .33554 .53892 .34605 .5356 .33948 .52943 Mtetra
.33948 .52943 .34605 .5356 .35661 .53227 .35006 .52607 Mtetra
.35006 .52607 .35661 .53227 .36722 .52892 .36069 .52271 Mtetra
.36069 .52271 .36722 .52892 .37786 .52557 .37136 .51933 Mtetra
.663 .742 .909 r
.37136 .51933 .37786 .52557 .38855 .52221 .38207 .51596 Mtetra
.662 .742 .909 r
.38207 .51596 .38855 .52221 .39927 .51884 .39283 .51258 Mtetra
.661 .742 .91 r
.39283 .51258 .39927 .51884 .41005 .51548 .40362 .50921 Mtetra
.66 .742 .911 r
.40362 .50921 .41005 .51548 .42086 .51212 .41446 .50586 Mtetra
.659 .743 .912 r
.41446 .50586 .42086 .51212 .43172 .50878 .42535 .50253 Mtetra
.657 .743 .914 r
.42535 .50253 .43172 .50878 .44262 .50547 .43628 .49926 Mtetra
.653 .744 .917 r
.43628 .49926 .44262 .50547 .45356 .50221 .44725 .49605 Mtetra
.649 .746 .92 r
.44725 .49605 .45356 .50221 .46455 .49902 .45826 .49294 Mtetra
.643 .748 .925 r
.45826 .49294 .46455 .49902 .47558 .49592 .46932 .48997 Mtetra
.635 .75 .932 r
.46932 .48997 .47558 .49592 .48666 .49295 .48043 .48718 Mtetra
.623 .754 .94 r
.48043 .48718 .48666 .49295 .49779 .49016 .49158 .48462 Mtetra
.607 .758 .95 r
.49158 .48462 .49779 .49016 .50897 .48758 .50279 .48234 Mtetra
.585 .762 .963 r
.50279 .48234 .50897 .48758 .52019 .48527 .51404 .4804 Mtetra
.554 .766 .977 r
.51404 .4804 .52019 .48527 .53148 .48328 .52536 .47888 Mtetra
.508 .768 .99 r
.52536 .47888 .53148 .48328 .54282 .48167 .53674 .47782 Mtetra
.442 .762 .996 r
.53674 .47782 .54282 .48167 .55422 .48048 .54818 .47727 Mtetra
.347 .741 .985 r
.54818 .47727 .55422 .48048 .5657 .47975 .55971 .47729 Mtetra
.217 .692 .937 r
.55971 .47729 .5657 .47975 .57725 .47951 .57131 .47787 Mtetra
.057 .604 .838 r
.57131 .47787 .57725 .47951 .58888 .47977 .583 .47902 Mtetra
.108 0 0 r
.583 .47902 .58888 .47977 .6006 .4805 .59479 .48069 Mtetra
.248 0 0 r
.59479 .48069 .6006 .4805 .61241 .48166 .60667 .4828 Mtetra
.347 0 0 r
.60667 .4828 .61241 .48166 .62432 .48316 .61866 .48523 Mtetra
.409 0 0 r
.61866 .48523 .62432 .48316 .63632 .48488 .63074 .48782 Mtetra
.441 0 0 r
.63074 .48782 .63632 .48488 .64841 .48668 .64292 .49039 Mtetra
.452 0 0 r
.64292 .49039 .64841 .48668 .66059 .48837 .65519 .49272 Mtetra
.445 0 0 r
.65519 .49272 .66059 .48837 .67285 .48976 .66754 .49458 Mtetra
.423 0 0 r
.66754 .49458 .67285 .48976 .68517 .49065 .67995 .49573 Mtetra
.384 0 0 r
.67995 .49573 .68517 .49065 .69754 .49084 .6924 .49598 Mtetra
.326 0 0 r
.6924 .49598 .69754 .49084 .70995 .49017 .70488 .49512 Mtetra
.242 0 0 r
.70488 .49512 .70995 .49017 .72237 .48847 .71736 .49302 Mtetra
.123 0 0 r
.71736 .49302 .72237 .48847 .7348 .48565 .72982 .48957 Mtetra
0 0 0 r
.72982 .48957 .7348 .48565 .7472 .48166 .74225 .48475 Mtetra
.74225 .48475 .7472 .48166 .75958 .47648 .75464 .47858 Mtetra
.462 .868 .708 r
.75464 .47858 .75958 .47648 .77191 .47018 .76697 .47116 Mtetra
.643 .965 .821 r
.76697 .47116 .77191 .47018 .7842 .46287 .77925 .46266 Mtetra
.759 .993 .878 r
.77925 .46266 .7842 .46287 .79645 .45469 .79148 .45328 Mtetra
.816 .977 .894 r
.79148 .45328 .79645 .45469 .80867 .44585 .80367 .44328 Mtetra
.837 .945 .892 r
.80367 .44328 .80867 .44585 .82086 .43655 .81583 .43293 Mtetra
.84 .91 .884 r
.81583 .43293 .82086 .43655 .83304 .42703 .82799 .42246 Mtetra
.832 .879 .877 r
.82799 .42246 .83304 .42703 .84523 .41748 .84017 .4121 Mtetra
.821 .852 .872 r
.84017 .4121 .84523 .41748 .85745 .40807 .85238 .40203 Mtetra
.807 .83 .869 r
.85238 .40203 .85745 .40807 .86972 .39897 .86464 .3924 Mtetra
.792 .812 .868 r
.86464 .3924 .86972 .39897 .88204 .39026 .87698 .38327 Mtetra
.777 .798 .869 r
.87698 .38327 .88204 .39026 .89444 .38201 .88939 .37472 Mtetra
.763 .785 .872 r
.88939 .37472 .89444 .38201 .90692 .37426 .9019 .36675 Mtetra
.749 .776 .875 r
.9019 .36675 .90692 .37426 .91949 .36702 .9145 .35935 Mtetra
.663 .741 .908 r
.32228 .52659 .32893 .53278 .33948 .52943 .33285 .52322 Mtetra
.33285 .52322 .33948 .52943 .35006 .52607 .34346 .51984 Mtetra
.34346 .51984 .35006 .52607 .36069 .52271 .35411 .51645 Mtetra
.663 .741 .909 r
.35411 .51645 .36069 .52271 .37136 .51933 .36481 .51306 Mtetra
.662 .742 .909 r
.36481 .51306 .37136 .51933 .38207 .51596 .37555 .50967 Mtetra
.662 .742 .91 r
.37555 .50967 .38207 .51596 .39283 .51258 .38633 .50628 Mtetra
.66 .742 .91 r
.38633 .50628 .39283 .51258 .40362 .50921 .39715 .50292 Mtetra
.659 .743 .912 r
.39715 .50292 .40362 .50921 .41446 .50586 .40802 .49958 Mtetra
.657 .743 .914 r
.40802 .49958 .41446 .50586 .42535 .50253 .41893 .49628 Mtetra
.654 .744 .916 r
.41893 .49628 .42535 .50253 .43628 .49926 .42988 .49306 Mtetra
.649 .745 .92 r
.42988 .49306 .43628 .49926 .44725 .49605 .44088 .48994 Mtetra
.643 .747 .925 r
.44088 .48994 .44725 .49605 .45826 .49294 .45192 .48695 Mtetra
.635 .75 .931 r
.45192 .48695 .45826 .49294 .46932 .48997 .463 .48415 Mtetra
.623 .753 .939 r
.463 .48415 .46932 .48997 .48043 .48718 .47414 .48158 Mtetra
.607 .756 .95 r
.47414 .48158 .48043 .48718 .49158 .48462 .48532 .47931 Mtetra
.584 .76 .962 r
.48532 .47931 .49158 .48462 .50279 .48234 .49655 .47741 Mtetra
.55 .763 .977 r
.49655 .47741 .50279 .48234 .51404 .4804 .50784 .47594 Mtetra
.502 .764 .989 r
.50784 .47594 .51404 .4804 .52536 .47888 .51919 .47497 Mtetra
.431 .756 .995 r
.51919 .47497 .52536 .47888 .53674 .47782 .5306 .47457 Mtetra
.327 .73 .981 r
.5306 .47457 .53674 .47782 .54818 .47727 .54209 .47478 Mtetra
.184 .671 .925 r
.54209 .47478 .54818 .47727 .55971 .47729 .55366 .47565 Mtetra
.009 .568 .81 r
.55366 .47565 .55971 .47729 .57131 .47787 .56532 .47716 Mtetra
.167 0 0 r
.56532 .47716 .57131 .47787 .583 .47902 .57707 .47929 Mtetra
.309 0 0 r
.57707 .47929 .583 .47902 .59479 .48069 .58892 .48196 Mtetra
.406 0 0 r
.58892 .48196 .59479 .48069 .60667 .4828 .60088 .48507 Mtetra
.464 0 0 r
.60088 .48507 .60667 .4828 .61866 .48523 .61295 .48845 Mtetra
.494 0 0 r
.61295 .48845 .61866 .48523 .63074 .48782 .62512 .4919 Mtetra
.505 0 0 r
.62512 .4919 .63074 .48782 .64292 .49039 .63739 .49519 Mtetra
.499 0 0 r
.63739 .49519 .64292 .49039 .65519 .49272 .64975 .49807 Mtetra
.481 0 0 r
.64975 .49807 .65519 .49272 .66754 .49458 .66219 .50028 Mtetra
.448 0 0 r
.66219 .50028 .66754 .49458 .67995 .49573 .67468 .50156 Mtetra
.398 0 0 r
.67468 .50156 .67995 .49573 .6924 .49598 .6872 .50168 Mtetra
.324 0 0 r
.6872 .50168 .6924 .49598 .70488 .49512 .69974 .50046 Mtetra
.219 0 0 r
.69974 .50046 .70488 .49512 .71736 .49302 .71227 .49774 Mtetra
.068 0 0 r
.71227 .49774 .71736 .49302 .72982 .48957 .72477 .49344 Mtetra
0 0 0 r
.72477 .49344 .72982 .48957 .74225 .48475 .73722 .48756 Mtetra
.384 .809 .631 r
.73722 .48756 .74225 .48475 .75464 .47858 .7496 .48018 Mtetra
.607 .946 .777 r
.7496 .48018 .75464 .47858 .76697 .47116 .76192 .47145 Mtetra
.755 .995 .855 r
.76192 .47145 .76697 .47116 .77925 .46266 .77418 .46161 Mtetra
.827 .984 .879 r
.77418 .46161 .77925 .46266 .79148 .45328 .78638 .45094 Mtetra
.853 .949 .878 r
.78638 .45094 .79148 .45328 .80367 .44328 .79854 .43976 Mtetra
.857 .912 .869 r
.79854 .43976 .80367 .44328 .81583 .43293 .81067 .42835 Mtetra
.849 .879 .861 r
.81067 .42835 .81583 .43293 .82799 .42246 .82282 .417 Mtetra
.837 .851 .856 r
.82282 .417 .82799 .42246 .84017 .4121 .83498 .40591 Mtetra
.822 .828 .853 r
.83498 .40591 .84017 .4121 .85238 .40203 .84719 .39528 Mtetra
.807 .81 .853 r
.84719 .39528 .85238 .40203 .86464 .3924 .85947 .3852 Mtetra
.792 .796 .855 r
.85947 .3852 .86464 .3924 .87698 .38327 .87182 .37576 Mtetra
.777 .784 .859 r
.87182 .37576 .87698 .38327 .88939 .37472 .88426 .36699 Mtetra
.762 .774 .863 r
.88426 .36699 .88939 .37472 .9019 .36675 .8968 .35887 Mtetra
.747 .767 .869 r
.8968 .35887 .9019 .36675 .9145 .35935 .90944 .35138 Mtetra
.663 .741 .908 r
.31558 .52035 .32228 .52659 .33285 .52322 .32617 .51696 Mtetra
.32617 .51696 .33285 .52322 .34346 .51984 .33681 .51356 Mtetra
.663 .741 .909 r
.33681 .51356 .34346 .51984 .35411 .51645 .34749 .51016 Mtetra
.662 .742 .909 r
.34749 .51016 .35411 .51645 .36481 .51306 .35821 .50675 Mtetra
.35821 .50675 .36481 .51306 .37555 .50967 .36897 .50335 Mtetra
.661 .742 .91 r
.36897 .50335 .37555 .50967 .38633 .50628 .37978 .49996 Mtetra
.659 .742 .911 r
.37978 .49996 .38633 .50628 .39715 .50292 .39063 .49661 Mtetra
.657 .743 .913 r
.39063 .49661 .39715 .50292 .40802 .49958 .40152 .49329 Mtetra
.654 .744 .916 r
.40152 .49329 .40802 .49958 .41893 .49628 .41246 .49005 Mtetra
.65 .745 .919 r
.41246 .49005 .41893 .49628 .42988 .49306 .42344 .4869 Mtetra
.644 .747 .924 r
.42344 .4869 .42988 .49306 .44088 .48994 .43446 .48389 Mtetra
.635 .749 .93 r
.43446 .48389 .44088 .48994 .45192 .48695 .44552 .48107 Mtetra
.624 .751 .938 r
.44552 .48107 .45192 .48695 .463 .48415 .45663 .47848 Mtetra
.607 .755 .949 r
.45663 .47848 .463 .48415 .47414 .48158 .46779 .4762 Mtetra
.584 .758 .961 r
.46779 .4762 .47414 .48158 .48532 .47931 .479 .47429 Mtetra
.55 .761 .975 r
.479 .47429 .48532 .47931 .49655 .47741 .49026 .47284 Mtetra
.5 .76 .988 r
.49026 .47284 .49655 .47741 .50784 .47594 .50158 .47193 Mtetra
.427 .751 .994 r
.50158 .47193 .50784 .47594 .51919 .47497 .51296 .47162 Mtetra
.318 .721 .979 r
.51296 .47162 .51919 .47497 .5306 .47457 .52441 .47198 Mtetra
.166 .656 .92 r
.52441 .47198 .5306 .47457 .54209 .47478 .53594 .47305 Mtetra
0 .544 .797 r
.53594 .47305 .54209 .47478 .55366 .47565 .54755 .47486 Mtetra
.204 0 0 r
.54755 .47486 .55366 .47565 .56532 .47716 .55927 .47738 Mtetra
.35 0 0 r
.55927 .47738 .56532 .47716 .57707 .47929 .57108 .48055 Mtetra
.447 0 0 r
.57108 .48055 .57707 .47929 .58892 .48196 .583 .48427 Mtetra
.504 0 0 r
.583 .48427 .58892 .48196 .60088 .48507 .59504 .48838 Mtetra
.534 .004 0 r
.59504 .48838 .60088 .48507 .61295 .48845 .60719 .49269 Mtetra
.545 .035 0 r
.60719 .49269 .61295 .48845 .62512 .4919 .61945 .49693 Mtetra
.542 .046 .027 r
.61945 .49693 .62512 .4919 .63739 .49519 .63181 .50086 Mtetra
.526 .039 .043 r
.63181 .50086 .63739 .49519 .64975 .49807 .64425 .50417 Mtetra
.498 .016 .042 r
.64425 .50417 .64975 .49807 .66219 .50028 .65677 .50659 Mtetra
.455 0 .022 r
.65677 .50659 .66219 .50028 .67468 .50156 .66934 .50782 Mtetra
.391 0 0 r
.66934 .50782 .67468 .50156 .6872 .50168 .68193 .50764 Mtetra
.298 0 0 r
.68193 .50764 .6872 .50168 .69974 .50046 .69452 .50582 Mtetra
.159 0 0 r
.69452 .50582 .69974 .50046 .71227 .49774 .70709 .50224 Mtetra
0 0 0 r
.70709 .50224 .71227 .49774 .72477 .49344 .71961 .49683 Mtetra
.71961 .49683 .72477 .49344 .73722 .48756 .73206 .48964 Mtetra
.572 .925 .74 r
.73206 .48964 .73722 .48756 .7496 .48018 .74443 .48082 Mtetra
.753 .995 .838 r
.74443 .48082 .7496 .48018 .76192 .47145 .75673 .47062 Mtetra
.839 .986 .867 r
.75673 .47062 .76192 .47145 .77418 .46161 .76895 .45935 Mtetra
.868 .948 .864 r
.76895 .45935 .77418 .46161 .78638 .45094 .78112 .44736 Mtetra
.87 .907 .854 r
.78112 .44736 .78638 .45094 .79854 .43976 .79325 .43503 Mtetra
.862 .872 .845 r
.79325 .43503 .79854 .43976 .81067 .42835 .80537 .42265 Mtetra
.849 .844 .838 r
.80537 .42265 .81067 .42835 .82282 .417 .81751 .41052 Mtetra
.835 .822 .836 r
.81751 .41052 .82282 .417 .83498 .40591 .82967 .39884 Mtetra
.82 .804 .836 r
.82967 .39884 .83498 .40591 .84719 .39528 .8419 .38776 Mtetra
.804 .79 .839 r
.8419 .38776 .84719 .39528 .85947 .3852 .85419 .37737 Mtetra
.789 .779 .844 r
.85419 .37737 .85947 .3852 .87182 .37576 .86657 .36773 Mtetra
.774 .771 .85 r
.86657 .36773 .87182 .37576 .88426 .36699 .87905 .35883 Mtetra
.759 .764 .857 r
.87905 .35883 .88426 .36699 .8968 .35887 .89163 .35065 Mtetra
.745 .758 .864 r
.89163 .35065 .8968 .35887 .90944 .35138 .90432 .34314 Mtetra
.663 .741 .908 r
.30883 .51407 .31558 .52035 .32617 .51696 .31945 .51066 Mtetra
.31945 .51066 .32617 .51696 .33681 .51356 .33011 .50724 Mtetra
.662 .742 .909 r
.33011 .50724 .33681 .51356 .34749 .51016 .34081 .50382 Mtetra
.34081 .50382 .34749 .51016 .35821 .50675 .35156 .5004 Mtetra
.661 .742 .91 r
.35156 .5004 .35821 .50675 .36897 .50335 .36235 .497 Mtetra
.659 .742 .911 r
.36235 .497 .36897 .50335 .37978 .49996 .37318 .49362 Mtetra
.657 .743 .913 r
.37318 .49362 .37978 .49996 .39063 .49661 .38406 .49029 Mtetra
.655 .743 .915 r
.38406 .49029 .39063 .49661 .40152 .49329 .39498 .48702 Mtetra
.65 .745 .918 r
.39498 .48702 .40152 .49329 .41246 .49005 .40594 .48384 Mtetra
.645 .746 .923 r
.40594 .48384 .41246 .49005 .42344 .4869 .41694 .4808 Mtetra
.636 .748 .929 r
.41694 .4808 .42344 .4869 .43446 .48389 .42798 .47794 Mtetra
.625 .75 .937 r
.42798 .47794 .43446 .48389 .44552 .48107 .43907 .47531 Mtetra
.609 .753 .947 r
.43907 .47531 .44552 .48107 .45663 .47848 .45021 .473 Mtetra
.586 .756 .959 r
.45021 .473 .45663 .47848 .46779 .4762 .46139 .47107 Mtetra
.552 .758 .973 r
.46139 .47107 .46779 .4762 .479 .47429 .47262 .4696 Mtetra
.503 .757 .987 r
.47262 .4696 .479 .47429 .49026 .47284 .4839 .46869 Mtetra
.429 .747 .994 r
.4839 .46869 .49026 .47284 .50158 .47193 .49525 .46841 Mtetra
.319 .717 .98 r
.49525 .46841 .50158 .47193 .51296 .47162 .50666 .46885 Mtetra
.164 .65 .922 r
.50666 .46885 .51296 .47162 .52441 .47198 .51815 .47006 Mtetra
0 .534 .798 r
.51815 .47006 .52441 .47198 .53594 .47305 .52972 .47208 Mtetra
.221 0 0 r
.52972 .47208 .53594 .47305 .54755 .47486 .54138 .4749 Mtetra
.373 0 0 r
.54138 .4749 .54755 .47486 .55927 .47738 .55315 .47848 Mtetra
.473 0 0 r
.55315 .47848 .55927 .47738 .57108 .48055 .56503 .48272 Mtetra
.532 0 0 r
.56503 .48272 .57108 .48055 .583 .48427 .57702 .48748 Mtetra
.564 .037 0 r
.57702 .48748 .583 .48427 .59504 .48838 .58913 .49256 Mtetra
.576 .07 .014 r
.58913 .49256 .59504 .48838 .60719 .49269 .60136 .49772 Mtetra
.575 .084 .052 r
.60136 .49772 .60719 .49269 .61945 .49693 .6137 .50268 Mtetra
.563 .082 .071 r
.6137 .50268 .61945 .49693 .63181 .50086 .62615 .50712 Mtetra
.54 .064 .074 r
.62615 .50712 .63181 .50086 .64425 .50417 .63868 .51074 Mtetra
.503 .028 .061 r
.63868 .51074 .64425 .50417 .65677 .50659 .65127 .5132 Mtetra
.448 0 .027 r
.65127 .5132 .65677 .50659 .66934 .50782 .66391 .5142 Mtetra
.365 0 0 r
.66391 .5142 .66934 .50782 .68193 .50764 .67656 .51347 Mtetra
.239 0 0 r
.67656 .51347 .68193 .50764 .69452 .50582 .6892 .5108 Mtetra
.043 0 0 r
.6892 .5108 .69452 .50582 .70709 .50224 .70179 .50607 Mtetra
0 0 0 r
.70179 .50607 .70709 .50224 .71961 .49683 .71431 .49925 Mtetra
.54 .905 .715 r
.71431 .49925 .71961 .49683 .73206 .48964 .72675 .4905 Mtetra
.754 .995 .83 r
.72675 .4905 .73206 .48964 .74443 .48082 .7391 .48005 Mtetra
.85 .984 .859 r
.7391 .48005 .74443 .48082 .75673 .47062 .75137 .46825 Mtetra
.879 .941 .852 r
.75137 .46825 .75673 .47062 .76895 .45935 .76356 .45553 Mtetra
.88 .897 .839 r
.76356 .45553 .76895 .45935 .78112 .44736 .7757 .44229 Mtetra
.871 .86 .827 r
.7757 .44229 .78112 .44736 .79325 .43503 .78781 .42891 Mtetra
.857 .832 .821 r
.78781 .42891 .79325 .43503 .80537 .42265 .79992 .41573 Mtetra
.843 .81 .818 r
.79992 .41573 .80537 .42265 .81751 .41052 .81206 .40299 Mtetra
.829 .794 .819 r
.81206 .40299 .81751 .41052 .82967 .39884 .82424 .39087 Mtetra
.814 .781 .822 r
.82424 .39087 .82967 .39884 .8419 .38776 .83649 .37949 Mtetra
.799 .771 .828 r
.83649 .37949 .8419 .38776 .85419 .37737 .84881 .36893 Mtetra
.784 .764 .835 r
.84881 .36893 .85419 .37737 .86657 .36773 .86124 .35919 Mtetra
.769 .758 .843 r
.86124 .35919 .86657 .36773 .87905 .35883 .87376 .35027 Mtetra
.755 .754 .851 r
.87376 .35027 .87905 .35883 .89163 .35065 .88639 .34211 Mtetra
.741 .751 .86 r
.88639 .34211 .89163 .35065 .90432 .34314 .89913 .33465 Mtetra
.663 .741 .908 r
.30202 .50775 .30883 .51407 .31945 .51066 .31267 .50431 Mtetra
.663 .741 .909 r
.31267 .50431 .31945 .51066 .33011 .50724 .32336 .50088 Mtetra
.662 .742 .909 r
.32336 .50088 .33011 .50724 .34081 .50382 .33409 .49745 Mtetra
.661 .742 .91 r
.33409 .49745 .34081 .50382 .35156 .5004 .34486 .49402 Mtetra
.66 .742 .911 r
.34486 .49402 .35156 .5004 .36235 .497 .35568 .49062 Mtetra
.658 .743 .912 r
.35568 .49062 .36235 .497 .37318 .49362 .36653 .48726 Mtetra
.655 .743 .915 r
.36653 .48726 .37318 .49362 .38406 .49029 .37743 .48396 Mtetra
.651 .744 .918 r
.37743 .48396 .38406 .49029 .39498 .48702 .38838 .48075 Mtetra
.646 .745 .922 r
.38838 .48075 .39498 .48702 .40594 .48384 .39936 .47767 Mtetra
.638 .747 .927 r
.39936 .47767 .40594 .48384 .41694 .4808 .41038 .47476 Mtetra
.627 .749 .935 r
.41038 .47476 .41694 .4808 .42798 .47794 .42145 .47209 Mtetra
.611 .752 .945 r
.42145 .47209 .42798 .47794 .43907 .47531 .43256 .46972 Mtetra
.589 .754 .956 r
.43256 .46972 .43907 .47531 .45021 .473 .44372 .46773 Mtetra
.557 .756 .97 r
.44372 .46773 .45021 .473 .46139 .47107 .45492 .46621 Mtetra
.51 .754 .984 r
.45492 .46621 .46139 .47107 .47262 .4696 .46617 .46526 Mtetra
.438 .745 .992 r
.46617 .46526 .47262 .4696 .4839 .46869 .47748 .46496 Mtetra
.331 .716 .983 r
.47748 .46496 .4839 .46869 .49525 .46841 .48885 .46541 Mtetra
.178 .652 .932 r
.48885 .46541 .49525 .46841 .50666 .46885 .5003 .46667 Mtetra
0 .538 .815 r
.5003 .46667 .50666 .46885 .51815 .47006 .51182 .4688 Mtetra
.217 0 0 r
.51182 .4688 .51815 .47006 .52972 .47208 .52343 .47181 Mtetra
.378 0 0 r
.52343 .47181 .52972 .47208 .54138 .4749 .53514 .47568 Mtetra
.486 0 0 r
.53514 .47568 .54138 .4749 .55315 .47848 .54696 .48033 Mtetra
.55 0 0 r
.54696 .48033 .55315 .47848 .56503 .48272 .5589 .48563 Mtetra
.585 .058 0 r
.5589 .48563 .56503 .48272 .57702 .48748 .57096 .49139 Mtetra
.601 .095 .022 r
.57096 .49139 .57702 .48748 .58913 .49256 .58314 .49738 Mtetra
.603 .113 .063 r
.58314 .49738 .58913 .49256 .60136 .49772 .59545 .50331 Mtetra
.594 .115 .086 r
.59545 .50331 .60136 .49772 .6137 .50268 .60787 .50887 Mtetra
.576 .103 .094 r
.60787 .50887 .6137 .50268 .62615 .50712 .6204 .51371 Mtetra
.545 .074 .087 r
.6204 .51371 .62615 .50712 .63868 .51074 .63301 .51748 Mtetra
.498 .024 .061 r
.63301 .51748 .63868 .51074 .65127 .5132 .64568 .51981 Mtetra
.425 0 .009 r
.64568 .51981 .65127 .5132 .66391 .5142 .65838 .52034 Mtetra
.311 0 0 r
.65838 .52034 .66391 .5142 .67656 .51347 .67108 .51878 Mtetra
.124 0 0 r
.67108 .51878 .67656 .51347 .6892 .5108 .68375 .51491 Mtetra
0 0 0 r
.68375 .51491 .6892 .5108 .70179 .50607 .69635 .50867 Mtetra
.512 .89 .702 r
.69635 .50867 .70179 .50607 .71431 .49925 .70886 .50014 Mtetra
.759 .995 .832 r
.70886 .50014 .71431 .49925 .72675 .4905 .72127 .48957 Mtetra
.861 .979 .856 r
.72127 .48957 .72675 .4905 .7391 .48005 .73359 .47736 Mtetra
.887 .928 .842 r
.73359 .47736 .7391 .48005 .75137 .46825 .74582 .46398 Mtetra
.885 .88 .824 r
.74582 .46398 .75137 .46825 .76356 .45553 .75798 .44989 Mtetra
.874 .842 .81 r
.75798 .44989 .76356 .45553 .7757 .44229 .7701 .43556 Mtetra
.861 .815 .803 r
.7701 .43556 .7757 .44229 .78781 .42891 .78221 .42134 Mtetra
.847 .794 .8 r
.78221 .42134 .78781 .42891 .79992 .41573 .79433 .40755 Mtetra
.833 .779 .801 r
.79433 .40755 .79992 .41573 .81206 .40299 .80648 .39439 Mtetra
.82 .768 .805 r
.80648 .39439 .81206 .40299 .82424 .39087 .81869 .38202 Mtetra
.806 .76 .811 r
.81869 .38202 .82424 .39087 .83649 .37949 .83097 .37051 Mtetra
.792 .755 .819 r
.83097 .37051 .83649 .37949 .84881 .36893 .84335 .35991 Mtetra
.778 .75 .828 r
.84335 .35991 .84881 .36893 .86124 .35919 .85582 .3502 Mtetra
.764 .747 .838 r
.85582 .3502 .86124 .35919 .87376 .35027 .8684 .34135 Mtetra
.75 .745 .848 r
.8684 .34135 .87376 .35027 .88639 .34211 .88109 .3333 Mtetra
.736 .744 .858 r
.88109 .3333 .88639 .34211 .89913 .33465 .89389 .32595 Mtetra
.663 .741 .909 r
.29517 .50138 .30202 .50775 .31267 .50431 .30584 .49793 Mtetra
.662 .742 .909 r
.30584 .49793 .31267 .50431 .32336 .50088 .31655 .49448 Mtetra
.661 .742 .91 r
.31655 .49448 .32336 .50088 .33409 .49745 .32731 .49104 Mtetra
.66 .742 .911 r
.32731 .49104 .33409 .49745 .34486 .49402 .33811 .48761 Mtetra
.658 .742 .912 r
.33811 .48761 .34486 .49402 .35568 .49062 .34895 .48423 Mtetra
.656 .743 .914 r
.34895 .48423 .35568 .49062 .36653 .48726 .35983 .4809 Mtetra
.652 .744 .917 r
.35983 .4809 .36653 .48726 .37743 .48396 .37076 .47765 Mtetra
.647 .745 .92 r
.37076 .47765 .37743 .48396 .38838 .48075 .38172 .47452 Mtetra
.64 .746 .926 r
.38172 .47452 .38838 .48075 .39936 .47767 .39273 .47156 Mtetra
.63 .748 .933 r
.39273 .47156 .39936 .47767 .41038 .47476 .40377 .46882 Mtetra
.615 .75 .942 r
.40377 .46882 .41038 .47476 .42145 .47209 .41486 .46638 Mtetra
.594 .752 .953 r
.41486 .46638 .42145 .47209 .43256 .46972 .42599 .4643 Mtetra
.564 .754 .967 r
.42599 .4643 .43256 .46972 .44372 .46773 .43717 .4627 Mtetra
.519 .752 .981 r
.43717 .4627 .44372 .46773 .45492 .46621 .44839 .46166 Mtetra
.453 .744 .991 r
.44839 .46166 .45492 .46621 .46617 .46526 .45966 .46128 Mtetra
.352 .718 .986 r
.45966 .46128 .46617 .46526 .47748 .46496 .47099 .46166 Mtetra
.206 .661 .946 r
.47099 .46166 .47748 .46496 .48885 .46541 .48239 .46289 Mtetra
.015 .554 .843 r
.48239 .46289 .48885 .46541 .5003 .46667 .49386 .46504 Mtetra
.192 0 0 r
.49386 .46504 .5003 .46667 .51182 .4688 .50541 .46813 Mtetra
.366 0 0 r
.50541 .46813 .51182 .4688 .52343 .47181 .51706 .47216 Mtetra
.485 0 0 r
.51706 .47216 .52343 .47181 .53514 .47568 .52882 .47707 Mtetra
.558 0 0 r
.52882 .47707 .53514 .47568 .54696 .48033 .54069 .48276 Mtetra
.599 .067 0 r
.54069 .48276 .54696 .48033 .5589 .48563 .55269 .48907 Mtetra
.619 .11 .016 r
.55269 .48907 .5589 .48563 .57096 .49139 .56481 .49576 Mtetra
.625 .133 .062 r
.56481 .49576 .57096 .49139 .58314 .49738 .57707 .50257 Mtetra
.621 .14 .091 r
.57707 .50257 .58314 .49738 .59545 .50331 .58945 .5092 Mtetra
.607 .134 .105 r
.58945 .5092 .59545 .50331 .60787 .50887 .60195 .51527 Mtetra
.582 .112 .103 r
.60195 .51527 .60787 .50887 .6204 .51371 .61456 .5204 Mtetra
.542 .071 .085 r
.61456 .5204 .6204 .51371 .63301 .51748 .62725 .52416 Mtetra
.48 .002 .042 r
.62725 .52416 .63301 .51748 .64568 .51981 .63998 .5261 Mtetra
.378 0 0 r
.63998 .5261 .64568 .51981 .65838 .52034 .65274 .52583 Mtetra
.203 0 0 r
.65274 .52583 .65838 .52034 .67108 .51878 .66547 .52303 Mtetra
0 0 0 r
.66547 .52303 .67108 .51878 .68375 .51491 .67814 .51754 Mtetra
.486 .878 .7 r
.67814 .51754 .68375 .51491 .69635 .50867 .69073 .5094 Mtetra
.766 .997 .843 r
.69073 .5094 .69635 .50867 .70886 .50014 .70321 .49887 Mtetra
.87 .968 .856 r
.70321 .49887 .70886 .50014 .72127 .48957 .71559 .48635 Mtetra
.89 .908 .832 r
.71559 .48635 .72127 .48957 .73359 .47736 .72787 .47239 Mtetra
.885 .858 .809 r
.72787 .47239 .73359 .47736 .74582 .46398 .74007 .45754 Mtetra
.873 .82 .794 r
.74007 .45754 .74582 .46398 .75798 .44989 .75222 .4423 Mtetra
.86 .794 .785 r
.75222 .4423 .75798 .44989 .7701 .43556 .76433 .42712 Mtetra
.847 .775 .782 r
.76433 .42712 .7701 .43556 .78221 .42134 .77645 .41232 Mtetra
.834 .762 .783 r
.77645 .41232 .78221 .42134 .79433 .40755 .78859 .39817 Mtetra
.822 .753 .787 r
.78859 .39817 .79433 .40755 .80648 .39439 .80078 .38481 Mtetra
.809 .747 .794 r
.80078 .38481 .80648 .39439 .81869 .38202 .81303 .37237 Mtetra
.797 .743 .803 r
.81303 .37237 .81869 .38202 .83097 .37051 .82537 .3609 Mtetra
.784 .74 .813 r
.82537 .3609 .83097 .37051 .84335 .35991 .8378 .35039 Mtetra
.77 .739 .824 r
.8378 .35039 .84335 .35991 .85582 .3502 .85033 .34083 Mtetra
.757 .738 .835 r
.85033 .34083 .85582 .3502 .8684 .34135 .86297 .33215 Mtetra
.744 .738 .846 r
.86297 .33215 .8684 .34135 .88109 .3333 .87572 .32427 Mtetra
.731 .738 .857 r
.87572 .32427 .88109 .3333 .89389 .32595 .88859 .31709 Mtetra
.662 .742 .909 r
.28827 .49497 .29517 .50138 .30584 .49793 .29896 .4915 Mtetra
.29896 .4915 .30584 .49793 .31655 .49448 .3097 .48804 Mtetra
.661 .742 .91 r
.3097 .48804 .31655 .49448 .32731 .49104 .32048 .48459 Mtetra
.659 .742 .911 r
.32048 .48459 .32731 .49104 .33811 .48761 .33131 .48118 Mtetra
.657 .743 .913 r
.33131 .48118 .33811 .48761 .34895 .48423 .34217 .47781 Mtetra
.653 .743 .916 r
.34217 .47781 .34895 .48423 .35983 .4809 .35308 .47452 Mtetra
.649 .744 .919 r
.35308 .47452 .35983 .4809 .37076 .47765 .36402 .47135 Mtetra
.642 .745 .924 r
.36402 .47135 .37076 .47765 .38172 .47452 .37501 .46832 Mtetra
.632 .747 .93 r
.37501 .46832 .38172 .47452 .39273 .47156 .38604 .46551 Mtetra
.619 .749 .939 r
.38604 .46551 .39273 .47156 .40377 .46882 .3971 .46297 Mtetra
.6 .75 .949 r
.3971 .46297 .40377 .46882 .41486 .46638 .40821 .4608 Mtetra
.572 .751 .962 r
.40821 .4608 .41486 .46638 .42599 .4643 .41936 .45908 Mtetra
.531 .75 .976 r
.41936 .45908 .42599 .4643 .43717 .4627 .43055 .45791 Mtetra
.471 .743 .988 r
.43055 .45791 .43717 .4627 .44839 .46166 .44179 .45739 Mtetra
.38 .722 .989 r
.44179 .45739 .44839 .46166 .45966 .46128 .45308 .45764 Mtetra
.245 .674 .961 r
.45308 .45764 .45966 .46128 .47099 .46166 .46443 .45876 Mtetra
.063 .58 .878 r
.46443 .45876 .47099 .46166 .48239 .46289 .47585 .46081 Mtetra
0 .436 .725 r
.47585 .46081 .48239 .46289 .49386 .46504 .48734 .46386 Mtetra
.333 0 0 r
.48734 .46386 .49386 .46504 .50541 .46813 .49893 .46791 Mtetra
.469 0 0 r
.49893 .46791 .50541 .46813 .51706 .47216 .51062 .47295 Mtetra
.555 0 0 r
.51062 .47295 .51706 .47216 .52882 .47707 .52241 .47887 Mtetra
.605 .064 0 r
.52241 .47887 .52882 .47707 .54069 .48276 .53434 .48556 Mtetra
.632 .115 0 r
.53434 .48556 .54069 .48276 .55269 .48907 .54639 .4928 Mtetra
.643 .145 .051 r
.54639 .4928 .55269 .48907 .56481 .49576 .55858 .50038 Mtetra
.644 .159 .086 r
.55858 .50038 .56481 .49576 .57707 .50257 .5709 .50797 Mtetra
.635 .16 .107 r
.5709 .50797 .57707 .50257 .58945 .5092 .58336 .51523 Mtetra
.616 .146 .113 r
.58336 .51523 .58945 .5092 .60195 .51527 .59594 .52174 Mtetra
.584 .113 .103 r
.59594 .52174 .60195 .51527 .61456 .5204 .60862 .52701 Mtetra
.531 .054 .07 r
.60862 .52701 .61456 .5204 .62725 .52416 .62137 .5305 Mtetra
.441 0 0 r
.62137 .5305 .62725 .52416 .63998 .5261 .63417 .53169 Mtetra
.281 0 0 r
.63417 .53169 .63998 .5261 .65274 .52583 .64695 .53013 Mtetra
0 0 0 r
.64695 .53013 .65274 .52583 .66547 .52303 .6597 .52557 Mtetra
.459 .867 .707 r
.6597 .52557 .66547 .52303 .67814 .51754 .67236 .51797 Mtetra
.775 .996 .86 r
.67236 .51797 .67814 .51754 .69073 .5094 .68492 .50759 Mtetra
.875 .952 .856 r
.68492 .50759 .69073 .5094 .70321 .49887 .69736 .49488 Mtetra
.888 .884 .823 r
.69736 .49488 .70321 .49887 .71559 .48635 .7097 .48044 Mtetra
.88 .832 .795 r
.7097 .48044 .71559 .48635 .72787 .47239 .72195 .4649 Mtetra
.867 .795 .778 r
.72195 .4649 .72787 .47239 .74007 .45754 .73413 .44885 Mtetra
.854 .77 .769 r
.73413 .44885 .74007 .45754 .75222 .4423 .74628 .43278 Mtetra
.842 .754 .765 r
.74628 .43278 .75222 .4423 .76433 .42712 .75841 .41706 Mtetra
.831 .743 .766 r
.75841 .41706 .76433 .42712 .77645 .41232 .77056 .40197 Mtetra
.821 .736 .771 r
.77056 .40197 .77645 .41232 .78859 .39817 .78274 .3877 Mtetra
.81 .731 .778 r
.78274 .3877 .78859 .39817 .80078 .38481 .79497 .37437 Mtetra
.799 .729 .787 r
.79497 .37437 .80078 .38481 .81303 .37237 .80728 .36205 Mtetra
.787 .728 .797 r
.80728 .36205 .81303 .37237 .82537 .3609 .81968 .35076 Mtetra
.775 .728 .809 r
.81968 .35076 .82537 .3609 .8378 .35039 .83217 .34048 Mtetra
.763 .729 .822 r
.83217 .34048 .8378 .35039 .85033 .34083 .84477 .33116 Mtetra
.75 .73 .834 r
.84477 .33116 .85033 .34083 .86297 .33215 .85749 .32273 Mtetra
.737 .732 .846 r
.85749 .32273 .86297 .33215 .87572 .32427 .87031 .31508 Mtetra
.725 .733 .858 r
.87031 .31508 .87572 .32427 .88859 .31709 .88325 .30811 Mtetra
.662 .742 .909 r
.28131 .48851 .28827 .49497 .29896 .4915 .29203 .48503 Mtetra
.661 .742 .91 r
.29203 .48503 .29896 .4915 .3097 .48804 .30279 .48156 Mtetra
.66 .742 .911 r
.30279 .48156 .3097 .48804 .32048 .48459 .3136 .47812 Mtetra
.657 .742 .912 r
.3136 .47812 .32048 .48459 .33131 .48118 .32445 .47472 Mtetra
.655 .743 .915 r
.32445 .47472 .33131 .48118 .34217 .47781 .33534 .47139 Mtetra
.65 .744 .918 r
.33534 .47139 .34217 .47781 .35308 .47452 .34626 .46816 Mtetra
.644 .744 .922 r
.34626 .46816 .35308 .47452 .36402 .47135 .35723 .46507 Mtetra
.636 .746 .928 r
.35723 .46507 .36402 .47135 .37501 .46832 .36824 .46217 Mtetra
.623 .747 .935 r
.36824 .46217 .37501 .46832 .38604 .46551 .37929 .45953 Mtetra
.606 .749 .945 r
.37929 .45953 .38604 .46551 .3971 .46297 .39037 .45724 Mtetra
.581 .75 .957 r
.39037 .45724 .3971 .46297 .40821 .4608 .4015 .45537 Mtetra
.545 .749 .971 r
.4015 .45537 .40821 .4608 .41936 .45908 .41266 .45403 Mtetra
.491 .743 .984 r
.41266 .45403 .41936 .45908 .43055 .45791 .42387 .45334 Mtetra
.411 .727 .99 r
.42387 .45334 .43055 .45791 .44179 .45739 .43512 .4534 Mtetra
.292 .688 .974 r
.43512 .4534 .44179 .45739 .45308 .45764 .44643 .45431 Mtetra
.125 .61 .914 r
.44643 .45431 .45308 .45764 .46443 .45876 .45779 .45618 Mtetra
0 .482 .788 r
.45779 .45618 .46443 .45876 .47585 .46081 .46923 .45906 Mtetra
.278 0 0 r
.46923 .45906 .47585 .46081 .48734 .46386 .48075 .463 Mtetra
.434 0 0 r
.48075 .463 .48734 .46386 .49893 .46791 .49237 .468 Mtetra
.538 0 0 r
.49237 .468 .49893 .46791 .51062 .47295 .50408 .47399 Mtetra
.602 .049 0 r
.50408 .47399 .51062 .47295 .52241 .47887 .51592 .48088 Mtetra
.638 .11 0 r
.51592 .48088 .52241 .47887 .53434 .48556 .52789 .48852 Mtetra
.657 .15 .029 r
.52789 .48852 .53434 .48556 .54639 .4928 .54 .49669 Mtetra
.664 .173 .074 r
.54 .49669 .54639 .4928 .55858 .50038 .55225 .50514 Mtetra
.661 .182 .104 r
.55225 .50514 .55858 .50038 .5709 .50797 .56464 .51353 Mtetra
.647 .176 .12 r
.56464 .51353 .5709 .50797 .58336 .51523 .57717 .5214 Mtetra
.622 .153 .119 r
.57717 .5214 .58336 .51523 .59594 .52174 .58982 .52823 Mtetra
.578 .105 .096 r
.58982 .52823 .59594 .52174 .60862 .52701 .60257 .53337 Mtetra
.501 .016 .036 r
.60257 .53337 .60862 .52701 .62137 .5305 .61538 .53616 Mtetra
.357 0 0 r
.61538 .53616 .62137 .5305 .63417 .53169 .62821 .536 Mtetra
.065 0 0 r
.62821 .536 .63417 .53169 .64695 .53013 .64101 .5325 Mtetra
.427 .854 .716 r
.64101 .5325 .64695 .53013 .6597 .52557 .65374 .52557 Mtetra
.783 .993 .879 r
.65374 .52557 .6597 .52557 .67236 .51797 .66637 .51544 Mtetra
.875 .93 .855 r
.66637 .51544 .67236 .51797 .68492 .50759 .67889 .50261 Mtetra
.881 .855 .812 r
.67889 .50261 .68492 .50759 .69736 .49488 .69129 .48777 Mtetra
.87 .802 .781 r
.69129 .48777 .69736 .49488 .7097 .48044 .7036 .47163 Mtetra
.857 .768 .763 r
.7036 .47163 .7097 .48044 .72195 .4649 .71584 .45487 Mtetra
.845 .745 .753 r
.71584 .45487 .72195 .4649 .73413 .44885 .72802 .43802 Mtetra
.834 .731 .75 r
.72802 .43802 .73413 .44885 .74628 .43278 .74019 .42149 Mtetra
.825 .722 .751 r
.74019 .42149 .74628 .43278 .75841 .41706 .75235 .40557 Mtetra
.816 .717 .755 r
.75235 .40557 .75841 .41706 .77056 .40197 .76454 .39047 Mtetra
.807 .714 .762 r
.76454 .39047 .77056 .40197 .78274 .3877 .77677 .37632 Mtetra
.798 .714 .772 r
.77677 .37632 .78274 .3877 .79497 .37437 .78907 .36321 Mtetra
.788 .714 .782 r
.78907 .36321 .79497 .37437 .80728 .36205 .80145 .35118 Mtetra
.778 .716 .795 r
.80145 .35118 .80728 .36205 .81968 .35076 .81392 .34021 Mtetra
.766 .719 .808 r
.81392 .34021 .81968 .35076 .83217 .34048 .82649 .33027 Mtetra
.754 .721 .822 r
.82649 .33027 .83217 .34048 .84477 .33116 .83917 .32128 Mtetra
.742 .724 .835 r
.83917 .32128 .84477 .33116 .85749 .32273 .85195 .31316 Mtetra
.73 .727 .848 r
.85195 .31316 .85749 .32273 .87031 .31508 .86485 .30578 Mtetra
.719 .73 .86 r
.86485 .30578 .87031 .31508 .88325 .30811 .87786 .29905 Mtetra
.661 .742 .91 r
.2743 .48202 .28131 .48851 .29203 .48503 .28504 .47853 Mtetra
.66 .742 .91 r
.28504 .47853 .29203 .48503 .30279 .48156 .29583 .47505 Mtetra
.658 .742 .912 r
.29583 .47505 .30279 .48156 .3136 .47812 .30666 .47162 Mtetra
.656 .742 .914 r
.30666 .47162 .3136 .47812 .32445 .47472 .31753 .46824 Mtetra
.652 .743 .916 r
.31753 .46824 .32445 .47472 .33534 .47139 .32845 .46496 Mtetra
.646 .744 .92 r
.32845 .46496 .33534 .47139 .34626 .46816 .3394 .4618 Mtetra
.639 .745 .925 r
.3394 .4618 .34626 .46816 .35723 .46507 .35039 .45881 Mtetra
.628 .746 .932 r
.35039 .45881 .35723 .46507 .36824 .46217 .36141 .45606 Mtetra
.613 .747 .941 r
.36141 .45606 .36824 .46217 .37929 .45953 .37248 .45363 Mtetra
.591 .748 .952 r
.37248 .45363 .37929 .45953 .39037 .45724 .38358 .4516 Mtetra
.559 .747 .965 r
.38358 .4516 .39037 .45724 .4015 .45537 .39472 .45007 Mtetra
.513 .743 .978 r
.39472 .45007 .4015 .45537 .41266 .45403 .40589 .44916 Mtetra
.444 .731 .988 r
.40589 .44916 .41266 .45403 .42387 .45334 .41711 .44897 Mtetra
.342 .701 .983 r
.41711 .44897 .42387 .45334 .43512 .4534 .42838 .44962 Mtetra
.196 .641 .946 r
.42838 .44962 .43512 .4534 .44643 .45431 .4397 .4512 Mtetra
.006 .534 .852 r
.4397 .4512 .44643 .45431 .45779 .45618 .45108 .45382 Mtetra
0 .386 .695 r
.45108 .45382 .45779 .45618 .46923 .45906 .46254 .45752 Mtetra
.376 0 0 r
.46254 .45752 .46923 .45906 .48075 .463 .47408 .46232 Mtetra
.504 0 0 r
.47408 .46232 .48075 .463 .49237 .468 .48572 .46821 Mtetra
.586 .02 0 r
.48572 .46821 .49237 .468 .50408 .47399 .49747 .47512 Mtetra
.636 .095 0 r
.49747 .47512 .50408 .47399 .51592 .48088 .50935 .48297 Mtetra
.665 .148 0 r
.50935 .48297 .51592 .48088 .52789 .48852 .52136 .49158 Mtetra
.68 .182 .056 r
.52136 .49158 .52789 .48852 .54 .49669 .53351 .50075 Mtetra
.683 .2 .098 r
.53351 .50075 .54 .49669 .55225 .50514 .54582 .51017 Mtetra
.676 .204 .125 r
.54582 .51017 .55225 .50514 .56464 .51353 .55828 .51938 Mtetra
.657 .191 .135 r
.55828 .51938 .56464 .51353 .57717 .5214 .57088 .52779 Mtetra
.621 .153 .122 r
.57088 .52779 .57717 .5214 .58982 .52823 .5836 .53466 Mtetra
.556 .077 .074 r
.5836 .53466 .58982 .52823 .60257 .53337 .59641 .53914 Mtetra
.431 0 0 r
.59641 .53914 .60257 .53337 .61538 .53616 .60926 .5405 Mtetra
.154 0 0 r
.60926 .5405 .61538 .53616 .62821 .536 .6221 .53817 Mtetra
.388 .835 .724 r
.6221 .53817 .62821 .536 .64101 .5325 .63489 .53199 Mtetra
.788 .986 .896 r
.63489 .53199 .64101 .5325 .65374 .52557 .64759 .52216 Mtetra
.871 .903 .851 r
.64759 .52216 .65374 .52557 .66637 .51544 .66017 .50926 Mtetra
.871 .824 .799 r
.66017 .50926 .66637 .51544 .67889 .50261 .67265 .49407 Mtetra
.857 .772 .766 r
.67265 .49407 .67889 .50261 .69129 .48777 .68502 .47741 Mtetra
.844 .739 .748 r
.68502 .47741 .69129 .48777 .7036 .47163 .69731 .46002 Mtetra
.833 .719 .739 r
.69731 .46002 .7036 .47163 .71584 .45487 .70955 .44251 Mtetra
.824 .707 .736 r
.70955 .44251 .71584 .45487 .72802 .43802 .72176 .4253 Mtetra
.816 .701 .737 r
.72176 .4253 .72802 .43802 .74019 .42149 .73396 .40869 Mtetra
.809 .697 .742 r
.73396 .40869 .74019 .42149 .75235 .40557 .74618 .39289 Mtetra
.802 .697 .749 r
.74618 .39289 .75235 .40557 .76454 .39047 .75843 .37804 Mtetra
.795 .698 .758 r
.75843 .37804 .76454 .39047 .77677 .37632 .77073 .36423 Mtetra
.787 .7 .769 r
.77073 .36423 .77677 .37632 .78907 .36321 .7831 .35152 Mtetra
.778 .703 .781 r
.7831 .35152 .78907 .36321 .80145 .35118 .79555 .33992 Mtetra
.768 .707 .795 r
.79555 .33992 .80145 .35118 .81392 .34021 .8081 .32939 Mtetra
.757 .712 .809 r
.8081 .32939 .81392 .34021 .82649 .33027 .82075 .31987 Mtetra
.746 .716 .824 r
.82075 .31987 .82649 .33027 .83917 .32128 .83351 .31128 Mtetra
.735 .72 .838 r
.83351 .31128 .83917 .32128 .85195 .31316 .84638 .3035 Mtetra
.723 .724 .851 r
.84638 .3035 .85195 .31316 .86485 .30578 .85936 .29643 Mtetra
.712 .728 .863 r
.85936 .29643 .86485 .30578 .87786 .29905 .87244 .28995 Mtetra
.661 .742 .91 r
.26723 .47548 .2743 .48202 .28504 .47853 .27801 .47198 Mtetra
.659 .742 .911 r
.27801 .47198 .28504 .47853 .29583 .47505 .28882 .46851 Mtetra
.657 .742 .913 r
.28882 .46851 .29583 .47505 .30666 .47162 .29967 .46509 Mtetra
.653 .743 .915 r
.29967 .46509 .30666 .47162 .31753 .46824 .31057 .46175 Mtetra
.649 .743 .918 r
.31057 .46175 .31753 .46824 .32845 .46496 .3215 .45852 Mtetra
.642 .744 .923 r
.3215 .45852 .32845 .46496 .3394 .4618 .33247 .45544 Mtetra
.633 .745 .929 r
.33247 .45544 .3394 .4618 .35039 .45881 .34348 .45258 Mtetra
.619 .746 .937 r
.34348 .45258 .35039 .45881 .36141 .45606 .35453 .45001 Mtetra
.6 .746 .947 r
.35453 .45001 .36141 .45606 .37248 .45363 .36561 .4478 Mtetra
.573 .746 .959 r
.36561 .4478 .37248 .45363 .38358 .4516 .37672 .44606 Mtetra
.533 .743 .972 r
.37672 .44606 .38358 .4516 .39472 .45007 .38787 .44489 Mtetra
.476 .734 .983 r
.38787 .44489 .39472 .45007 .40589 .44916 .39906 .44441 Mtetra
.391 .713 .987 r
.39906 .44441 .40589 .44916 .41711 .44897 .41029 .44473 Mtetra
.268 .668 .968 r
.41029 .44473 .41711 .44897 .42838 .44962 .42157 .44597 Mtetra
.1 .585 .907 r
.42157 .44597 .42838 .44962 .4397 .4512 .4329 .44822 Mtetra
0 .458 .785 r
.4329 .44822 .4397 .4512 .45108 .45382 .4443 .45156 Mtetra
.292 0 0 r
.4443 .45156 .45108 .45382 .46254 .45752 .45577 .45603 Mtetra
.447 0 0 r
.45577 .45603 .46254 .45752 .47408 .46232 .46733 .46165 Mtetra
.555 0 0 r
.46733 .46165 .47408 .46232 .48572 .46821 .47899 .46842 Mtetra
.624 .069 0 r
.47899 .46842 .48572 .46821 .49747 .47512 .49077 .4763 Mtetra
.668 .138 0 r
.49077 .4763 .49747 .47512 .50935 .48297 .50268 .48518 Mtetra
.692 .186 .033 r
.50268 .48518 .50935 .48297 .52136 .49158 .51473 .49493 Mtetra
.703 .217 .091 r
.51473 .49493 .52136 .49158 .53351 .50075 .52693 .50528 Mtetra
.701 .231 .131 r
.52693 .50528 .53351 .50075 .54582 .51017 .5393 .51578 Mtetra
.688 .227 .153 r
.5393 .51578 .54582 .51017 .55828 .51938 .55182 .52578 Mtetra
.658 .199 .151 r
.55182 .52578 .55828 .51938 .57088 .52779 .56449 .53442 Mtetra
.605 .136 .115 r
.56449 .53442 .57088 .52779 .5836 .53466 .57727 .54069 Mtetra
.498 .004 .013 r
.57727 .54069 .5836 .53466 .59641 .53914 .59012 .54363 Mtetra
.246 0 0 r
.59012 .54363 .59641 .53914 .60926 .5405 .60299 .54253 Mtetra
.338 .808 .722 r
.60299 .54253 .60926 .5405 .6221 .53817 .61582 .53711 Mtetra
.79 .975 .91 r
.61582 .53711 .6221 .53817 .63489 .53199 .62857 .52759 Mtetra
.864 .873 .844 r
.62857 .52759 .63489 .53199 .64759 .52216 .64122 .51461 Mtetra
.858 .792 .785 r
.64122 .51461 .64759 .52216 .66017 .50926 .65376 .49908 Mtetra
.843 .742 .752 r
.65376 .49908 .66017 .50926 .67265 .49407 .6662 .48193 Mtetra
.83 .712 .734 r
.6662 .48193 .67265 .49407 .68502 .47741 .67856 .46401 Mtetra
.82 .694 .725 r
.67856 .46401 .68502 .47741 .69731 .46002 .69087 .44595 Mtetra
.812 .684 .723 r
.69087 .44595 .69731 .46002 .70955 .44251 .70313 .4282 Mtetra
.806 .679 .725 r
.70313 .4282 .70955 .44251 .72176 .4253 .71538 .41106 Mtetra
.8 .678 .729 r
.71538 .41106 .72176 .4253 .73396 .40869 .72764 .39472 Mtetra
.795 .679 .736 r
.72764 .39472 .73396 .40869 .74618 .39289 .73992 .37931 Mtetra
.79 .682 .745 r
.73992 .37931 .74618 .39289 .75843 .37804 .75224 .36493 Mtetra
.783 .685 .756 r
.75224 .36493 .75843 .37804 .77073 .36423 .76462 .35165 Mtetra
.776 .69 .769 r
.76462 .35165 .77073 .36423 .7831 .35152 .77707 .33949 Mtetra
.768 .695 .783 r
.77707 .33949 .7831 .35152 .79555 .33992 .78961 .32843 Mtetra
.758 .701 .797 r
.78961 .32843 .79555 .33992 .8081 .32939 .80224 .31843 Mtetra
.748 .707 .813 r
.80224 .31843 .8081 .32939 .82075 .31987 .81498 .30939 Mtetra
.738 .713 .828 r
.81498 .30939 .82075 .31987 .83351 .31128 .82782 .30123 Mtetra
.727 .718 .842 r
.82782 .30123 .83351 .31128 .84638 .3035 .84077 .29383 Mtetra
.716 .723 .855 r
.84077 .29383 .84638 .3035 .85936 .29643 .85382 .28707 Mtetra
.706 .727 .866 r
.85382 .28707 .85936 .29643 .87244 .28995 .86698 .28084 Mtetra
.66 .742 .911 r
.26012 .4689 .26723 .47548 .27801 .47198 .27091 .4654 Mtetra
.658 .742 .912 r
.27091 .4654 .27801 .47198 .28882 .46851 .28175 .46194 Mtetra
.655 .742 .914 r
.28175 .46194 .28882 .46851 .29967 .46509 .29263 .45854 Mtetra
.651 .743 .917 r
.29263 .45854 .29967 .46509 .31057 .46175 .30354 .45524 Mtetra
.645 .743 .921 r
.30354 .45524 .31057 .46175 .3215 .45852 .3145 .45207 Mtetra
.637 .744 .926 r
.3145 .45207 .3215 .45852 .33247 .45544 .32549 .4491 Mtetra
.625 .745 .933 r
.32549 .4491 .33247 .45544 .34348 .45258 .33652 .44637 Mtetra
.609 .745 .941 r
.33652 .44637 .34348 .45258 .35453 .45001 .34758 .44399 Mtetra
.586 .745 .952 r
.34758 .44399 .35453 .45001 .36561 .4478 .35867 .44202 Mtetra
.553 .743 .965 r
.35867 .44202 .36561 .4478 .37672 .44606 .3698 .44058 Mtetra
.505 .736 .977 r
.3698 .44058 .37672 .44606 .38787 .44489 .38096 .43978 Mtetra
.436 .721 .985 r
.38096 .43978 .38787 .44489 .39906 .44441 .39216 .43974 Mtetra
.336 .689 .981 r
.39216 .43974 .39906 .44441 .41029 .44473 .4034 .44057 Mtetra
.195 .629 .947 r
.4034 .44057 .41029 .44473 .42157 .44597 .41469 .44237 Mtetra
.016 .528 .865 r
.41469 .44237 .42157 .44597 .4329 .44822 .42603 .44525 Mtetra
0 .389 .726 r
.42603 .44525 .4329 .44822 .4443 .45156 .43743 .44927 Mtetra
.363 0 0 r
.43743 .44927 .4443 .45156 .45577 .45603 .44892 .45449 Mtetra
.503 0 0 r
.44892 .45449 .45577 .45603 .46733 .46165 .4605 .46096 Mtetra
.6 .031 0 r
.4605 .46096 .46733 .46165 .47899 .46842 .47218 .4687 Mtetra
.663 .122 0 r
.47218 .4687 .47899 .46842 .49077 .4763 .48398 .4777 Mtetra
.701 .188 .008 r
.48398 .4777 .49077 .4763 .50268 .48518 .49591 .48789 Mtetra
.72 .233 .085 r
.49591 .48789 .50268 .48518 .51473 .49493 .508 .49907 Mtetra
.724 .257 .141 r
.508 .49907 .51473 .49493 .52693 .50528 .52025 .5108 Mtetra
.714 .261 .174 r
.52025 .5108 .52693 .50528 .5393 .51578 .53267 .52239 Mtetra
.69 .242 .183 r
.53267 .52239 .5393 .51578 .55182 .52578 .54526 .53283 Mtetra
.645 .19 .158 r
.54526 .53283 .55182 .52578 .56449 .53442 .55799 .54092 Mtetra
.555 .075 .071 r
.55799 .54092 .56449 .53442 .57727 .54069 .57081 .54548 Mtetra
.334 0 0 r
.57081 .54548 .57727 .54069 .59012 .54363 .58369 .54561 Mtetra
.278 .77 .706 r
.58369 .54561 .59012 .54363 .60299 .54253 .59655 .54093 Mtetra
.791 .961 .919 r
.59655 .54093 .60299 .54253 .61582 .53711 .60935 .53165 Mtetra
.854 .843 .832 r
.60935 .53165 .61582 .53711 .62857 .52759 .62206 .51853 Mtetra
.844 .76 .771 r
.62206 .51853 .62857 .52759 .64122 .51461 .63466 .50261 Mtetra
.828 .713 .737 r
.63466 .50261 .64122 .51461 .65376 .49908 .64717 .48497 Mtetra
.815 .685 .721 r
.64717 .48497 .65376 .49908 .6662 .48193 .6596 .46657 Mtetra
.806 .67 .713 r
.6596 .46657 .6662 .48193 .67856 .46401 .67197 .44808 Mtetra
.799 .662 .712 r
.67197 .44808 .67856 .46401 .69087 .44595 .6843 .42994 Mtetra
.794 .659 .714 r
.6843 .42994 .69087 .44595 .70313 .4282 .69661 .41243 Mtetra
.79 .66 .719 r
.69661 .41243 .70313 .4282 .71538 .41106 .70892 .39572 Mtetra
.787 .662 .726 r
.70892 .39572 .71538 .41106 .72764 .39472 .72124 .37993 Mtetra
.783 .666 .735 r
.72124 .37993 .72764 .39472 .73992 .37931 .73359 .36514 Mtetra
.778 .671 .745 r
.73359 .36514 .73992 .37931 .75224 .36493 .74599 .35141 Mtetra
.772 .677 .758 r
.74599 .35141 .75224 .36493 .76462 .35165 .75845 .3388 Mtetra
.766 .683 .771 r
.75845 .3388 .76462 .35165 .77707 .33949 .77099 .3273 Mtetra
.758 .69 .786 r
.77099 .3273 .77707 .33949 .78961 .32843 .78362 .31686 Mtetra
.749 .697 .802 r
.78362 .31686 .78961 .32843 .80224 .31843 .79635 .30744 Mtetra
.739 .704 .818 r
.79635 .30744 .80224 .31843 .81498 .30939 .80917 .29892 Mtetra
.729 .711 .833 r
.80917 .29892 .81498 .30939 .82782 .30123 .8221 .29121 Mtetra
.719 .717 .847 r
.8221 .29121 .82782 .30123 .84077 .29383 .83513 .28419 Mtetra
.709 .722 .86 r
.83513 .28419 .84077 .29383 .85382 .28707 .84826 .27774 Mtetra
.7 .727 .871 r
.84826 .27774 .85382 .28707 .86698 .28084 .86149 .27175 Mtetra
.659 .742 .911 r
.25294 .46228 .26012 .4689 .27091 .4654 .26376 .45878 Mtetra
.656 .742 .913 r
.26376 .45878 .27091 .4654 .28175 .46194 .27462 .45533 Mtetra
.653 .742 .915 r
.27462 .45533 .28175 .46194 .29263 .45854 .28552 .45196 Mtetra
.648 .743 .919 r
.28552 .45196 .29263 .45854 .30354 .45524 .29646 .44871 Mtetra
.641 .743 .923 r
.29646 .44871 .30354 .45524 .3145 .45207 .30744 .44562 Mtetra
.631 .744 .929 r
.30744 .44562 .3145 .45207 .32549 .4491 .31845 .44275 Mtetra
.618 .744 .936 r
.31845 .44275 .32549 .4491 .33652 .44637 .32949 .44018 Mtetra
.598 .744 .946 r
.32949 .44018 .33652 .44637 .34758 .44399 .34057 .43799 Mtetra
.571 .742 .957 r
.34057 .43799 .34758 .44399 .35867 .44202 .35167 .43627 Mtetra
.532 .738 .969 r
.35167 .43627 .35867 .44202 .3698 .44058 .36281 .43513 Mtetra
.477 .727 .98 r
.36281 .43513 .3698 .44058 .38096 .43978 .37398 .43469 Mtetra
.397 .705 .984 r
.37398 .43469 .38096 .43978 .39216 .43974 .38519 .43507 Mtetra
.284 .663 .971 r
.38519 .43507 .39216 .43974 .4034 .44057 .39644 .43638 Mtetra
.131 .589 .923 r
.39644 .43638 .4034 .44057 .41469 .44237 .40773 .43871 Mtetra
0 .475 .825 r
.40773 .43871 .41469 .44237 .42603 .44525 .41909 .44219 Mtetra
0 .326 .674 r
.41909 .44219 .42603 .44525 .43743 .44927 .4305 .44689 Mtetra
.427 0 0 r
.4305 .44689 .43743 .44927 .44892 .45449 .44199 .45293 Mtetra
.561 0 0 r
.44199 .45293 .44892 .45449 .4605 .46096 .45358 .4604 Mtetra
.652 .1 0 r
.45358 .4604 .4605 .46096 .47218 .4687 .46527 .46938 Mtetra
.707 .189 0 r
.46527 .46938 .47218 .4687 .48398 .4777 .47708 .4799 Mtetra
.735 .248 .085 r
.47708 .4799 .48398 .4777 .49591 .48789 .48904 .49182 Mtetra
.743 .282 .156 r
.48904 .49182 .49591 .48789 .508 .49907 .50116 .50474 Mtetra
.736 .293 .2 r
.50116 .50474 .508 .49907 .52025 .5108 .51345 .51791 Mtetra
.715 .281 .217 r
.51345 .51791 .52025 .5108 .53267 .52239 .52593 .53017 Mtetra
.676 .238 .201 r
.52593 .53017 .53267 .52239 .54526 .53283 .53858 .5401 Mtetra
.601 .139 .129 r
.53858 .5401 .54526 .53283 .55799 .54092 .55137 .54627 Mtetra
.41 0 0 r
.55137 .54627 .55799 .54092 .57081 .54548 .56423 .54758 Mtetra
0 0 0 r
.56423 .54758 .57081 .54548 .58369 .54561 .5771 .54352 Mtetra
.794 .947 .923 r
.5771 .54352 .58369 .54561 .59655 .54093 .58994 .53435 Mtetra
.845 .813 .819 r
.58994 .53435 .59655 .54093 .60935 .53165 .6027 .52095 Mtetra
.83 .731 .755 r
.6027 .52095 .60935 .53165 .62206 .51853 .61536 .50454 Mtetra
.814 .686 .723 r
.61536 .50454 .62206 .51853 .63466 .50261 .62793 .48638 Mtetra
.801 .661 .708 r
.62793 .48638 .63466 .50261 .64717 .48497 .64043 .46751 Mtetra
.792 .647 .702 r
.64043 .46751 .64717 .48497 .6596 .46657 .65287 .44867 Mtetra
.786 .641 .701 r
.65287 .44867 .6596 .46657 .67197 .44808 .66527 .43029 Mtetra
.782 .64 .704 r
.66527 .43029 .67197 .44808 .6843 .42994 .67765 .41259 Mtetra
.779 .642 .71 r
.67765 .41259 .6843 .42994 .69661 .41243 .69002 .3957 Mtetra
.777 .646 .717 r
.69002 .3957 .69661 .41243 .70892 .39572 .70239 .3797 Mtetra
.775 .651 .726 r
.70239 .3797 .70892 .39572 .72124 .37993 .71479 .36467 Mtetra
.772 .657 .736 r
.71479 .36467 .72124 .37993 .73359 .36514 .72722 .35066 Mtetra
.768 .664 .748 r
.72722 .35066 .73359 .36514 .74599 .35141 .73971 .33772 Mtetra
.762 .671 .762 r
.73971 .33772 .74599 .35141 .75845 .3388 .75226 .32587 Mtetra
.756 .679 .777 r
.75226 .32587 .75845 .3388 .77099 .3273 .76489 .3151 Mtetra
.748 .687 .792 r
.76489 .3151 .77099 .3273 .78362 .31686 .77761 .30534 Mtetra
.74 .695 .809 r
.77761 .30534 .78362 .31686 .79635 .30744 .79042 .29652 Mtetra
.731 .703 .825 r
.79042 .29652 .79635 .30744 .80917 .29892 .80334 .28853 Mtetra
.721 .711 .84 r
.80334 .28853 .80917 .29892 .8221 .29121 .81635 .28126 Mtetra
.712 .717 .853 r
.81635 .28126 .8221 .29121 .83513 .28419 .82946 .27461 Mtetra
.703 .723 .865 r
.82946 .27461 .83513 .28419 .84826 .27774 .84266 .26845 Mtetra
.694 .727 .876 r
.84266 .26845 .84826 .27774 .86149 .27175 .85596 .26269 Mtetra
.658 .742 .912 r
.24571 .45562 .25294 .46228 .26376 .45878 .25655 .45212 Mtetra
.655 .742 .914 r
.25655 .45212 .26376 .45878 .27462 .45533 .26744 .44869 Mtetra
.651 .742 .917 r
.26744 .44869 .27462 .45533 .28552 .45196 .27836 .44535 Mtetra
.645 .743 .92 r
.27836 .44535 .28552 .45196 .29646 .44871 .28932 .44216 Mtetra
.637 .743 .925 r
.28932 .44216 .29646 .44871 .30744 .44562 .30032 .43915 Mtetra
.625 .743 .932 r
.30032 .43915 .30744 .44562 .31845 .44275 .31134 .4364 Mtetra
.609 .743 .94 r
.31134 .4364 .31845 .44275 .32949 .44018 .3224 .43398 Mtetra
.587 .742 .95 r
.3224 .43398 .32949 .44018 .34057 .43799 .33349 .43198 Mtetra
.556 .738 .961 r
.33349 .43198 .34057 .43799 .35167 .43627 .34461 .43051 Mtetra
.511 .731 .973 r
.34461 .43051 .35167 .43627 .36281 .43513 .35576 .42966 Mtetra
.449 .716 .981 r
.35576 .42966 .36281 .43513 .37398 .43469 .36695 .42957 Mtetra
.36 .688 .981 r
.36695 .42957 .37398 .43469 .38519 .43507 .37816 .43034 Mtetra
.237 .636 .959 r
.37816 .43034 .38519 .43507 .39644 .43638 .38942 .43209 Mtetra
.074 .549 .899 r
.38942 .43209 .39644 .43638 .40773 .43871 .40072 .43495 Mtetra
0 .419 .784 r
.40072 .43495 .40773 .43871 .41909 .44219 .41207 .43905 Mtetra
.328 0 0 r
.41207 .43905 .41909 .44219 .4305 .44689 .42349 .44456 Mtetra
.507 0 0 r
.42349 .44456 .4305 .44689 .44199 .45293 .43498 .45165 Mtetra
.635 .074 0 r
.43498 .45165 .44199 .45293 .45358 .4604 .44656 .4605 Mtetra
.712 .189 0 r
.44656 .4605 .45358 .4604 .46527 .46938 .45825 .47126 Mtetra
.748 .265 .091 r
.45825 .47126 .46527 .46938 .47708 .4799 .47006 .48385 Mtetra
.759 .307 .177 r
.47006 .48385 .47708 .4799 .48904 .49182 .48203 .49793 Mtetra
.753 .322 .229 r
.48203 .49793 .48904 .49182 .50116 .50474 .49418 .51266 Mtetra
.733 .314 .251 r
.49418 .51266 .50116 .50474 .51345 .51791 .50653 .52675 Mtetra
.699 .277 .242 r
.50653 .52675 .51345 .51791 .52593 .53017 .51908 .53851 Mtetra
.634 .192 .182 r
.51908 .53851 .52593 .53017 .53858 .5401 .53179 .54626 Mtetra
.472 0 0 r
.53179 .54626 .53858 .5401 .55137 .54627 .54462 .54864 Mtetra
0 0 0 r
.54462 .54864 .55137 .54627 .56423 .54758 .5575 .54505 Mtetra
.799 .934 .92 r
.5575 .54505 .56423 .54758 .5771 .54352 .57036 .5358 Mtetra
.838 .786 .803 r
.57036 .5358 .5771 .54352 .58994 .53435 .58317 .52192 Mtetra
.818 .705 .74 r
.58317 .52192 .58994 .53435 .6027 .52095 .59589 .50486 Mtetra
.801 .662 .71 r
.59589 .50486 .6027 .52095 .61536 .50454 .60852 .48607 Mtetra
.787 .639 .696 r
.60852 .48607 .61536 .50454 .62793 .48638 .62108 .46673 Mtetra
.778 .626 .692 r
.62108 .46673 .62793 .48638 .64043 .46751 .63359 .4476 Mtetra
.773 .622 .692 r
.63359 .4476 .64043 .46751 .65287 .44867 .64606 .42909 Mtetra
.77 .622 .696 r
.64606 .42909 .65287 .44867 .66527 .43029 .65851 .41137 Mtetra
.768 .626 .702 r
.65851 .41137 .66527 .43029 .67765 .41259 .67095 .39449 Mtetra
.767 .631 .71 r
.67095 .39449 .67765 .41259 .69002 .3957 .68339 .37848 Mtetra
.766 .637 .718 r
.68339 .37848 .69002 .3957 .70239 .3797 .69584 .36338 Mtetra
.764 .644 .728 r
.69584 .36338 .70239 .3797 .71479 .36467 .70831 .34924 Mtetra
.762 .652 .74 r
.70831 .34924 .71479 .36467 .72722 .35066 .72083 .33613 Mtetra
.758 .66 .753 r
.72083 .33613 .72722 .35066 .73971 .33772 .7334 .32407 Mtetra
.753 .669 .768 r
.7334 .32407 .73971 .33772 .75226 .32587 .74605 .31305 Mtetra
.747 .678 .784 r
.74605 .31305 .75226 .32587 .76489 .3151 .75877 .30304 Mtetra
.739 .687 .8 r
.75877 .30304 .76489 .3151 .77761 .30534 .77158 .29397 Mtetra
.731 .696 .817 r
.77158 .29397 .77761 .30534 .79042 .29652 .78448 .28575 Mtetra
.722 .704 .833 r
.78448 .28575 .79042 .29652 .80334 .28853 .79748 .27827 Mtetra
.713 .712 .847 r
.79748 .27827 .80334 .28853 .81635 .28126 .81057 .27143 Mtetra
.704 .718 .86 r
.81057 .27143 .81635 .28126 .82946 .27461 .82376 .26511 Mtetra
.696 .724 .871 r
.82376 .26511 .82946 .27461 .84266 .26845 .83704 .25922 Mtetra
.689 .728 .88 r
.83704 .25922 .84266 .26845 .85596 .26269 .8504 .25366 Mtetra
.656 .742 .913 r
.23842 .44891 .24571 .45562 .25655 .45212 .24929 .44542 Mtetra
.653 .742 .915 r
.24929 .44542 .25655 .45212 .26744 .44869 .2602 .44201 Mtetra
.648 .742 .918 r
.2602 .44201 .26744 .44869 .27836 .44535 .27114 .43872 Mtetra
.641 .742 .922 r
.27114 .43872 .27836 .44535 .28932 .44216 .28212 .43558 Mtetra
.632 .742 .927 r
.28212 .43558 .28932 .44216 .30032 .43915 .29314 .43266 Mtetra
.619 .742 .934 r
.29314 .43266 .30032 .43915 .31134 .4364 .30418 .43002 Mtetra
.601 .741 .943 r
.30418 .43002 .31134 .4364 .3224 .43398 .31526 .42775 Mtetra
.576 .739 .953 r
.31526 .42775 .3224 .43398 .33349 .43198 .32636 .42595 Mtetra
.541 .734 .964 r
.32636 .42595 .33349 .43198 .34461 .43051 .33749 .4247 Mtetra
.492 .723 .974 r
.33749 .4247 .34461 .43051 .35576 .42966 .34865 .42413 Mtetra
.423 .704 .981 r
.34865 .42413 .35576 .42966 .36695 .42957 .35985 .42435 Mtetra
.327 .668 .975 r
.35985 .42435 .36695 .42957 .37816 .43034 .37107 .42549 Mtetra
.192 .606 .945 r
.37107 .42549 .37816 .43034 .38942 .43209 .38233 .42769 Mtetra
.01 .502 .869 r
.38233 .42769 .38942 .43209 .40072 .43495 .39363 .43114 Mtetra
0 .344 .721 r
.39363 .43114 .40072 .43495 .41207 .43905 .40498 .43605 Mtetra
.44 0 0 r
.40498 .43605 .41207 .43905 .42349 .44456 .41638 .44269 Mtetra
.614 .046 0 r
.41638 .44269 .42349 .44456 .43498 .45165 .42786 .45135 Mtetra
.715 .191 0 r
.42786 .45135 .43498 .45165 .44656 .4605 .43941 .46227 Mtetra
.76 .282 .105 r
.43941 .46227 .44656 .4605 .45825 .47126 .45108 .47551 Mtetra
.771 .329 .202 r
.45108 .47551 .45825 .47126 .47006 .48385 .46288 .49072 Mtetra
.764 .347 .259 r
.46288 .49072 .47006 .48385 .48203 .49793 .47487 .50702 Mtetra
.745 .341 .285 r
.47487 .50702 .48203 .49793 .49418 .51266 .48706 .52293 Mtetra
.713 .309 .28 r
.48706 .52293 .49418 .51266 .50653 .52675 .49948 .5365 Mtetra
.656 .234 .23 r
.49948 .5365 .50653 .52675 .51908 .53851 .5121 .54574 Mtetra
.516 .04 .063 r
.5121 .54574 .51908 .53851 .53179 .54626 .52489 .54905 Mtetra
0 0 0 r
.52489 .54905 .53179 .54626 .54462 .54864 .53776 .54574 Mtetra
.808 .922 .913 r
.53776 .54574 .54462 .54864 .5575 .54505 .55065 .53615 Mtetra
.832 .762 .785 r
.55065 .53615 .5575 .54505 .57036 .5358 .5635 .52154 Mtetra
.809 .682 .724 r
.5635 .52154 .57036 .5358 .58317 .52192 .57627 .50362 Mtetra
.79 .641 .697 r
.57627 .50362 .58317 .52192 .59589 .50486 .58897 .48407 Mtetra
.776 .619 .686 r
.58897 .48407 .59589 .50486 .60852 .48607 .60159 .46419 Mtetra
.766 .608 .683 r
.60159 .46419 .60852 .48607 .62108 .46673 .61417 .4448 Mtetra
.761 .605 .684 r
.61417 .4448 .62108 .46673 .63359 .4476 .62671 .42627 Mtetra
.758 .606 .689 r
.62671 .42627 .63359 .4476 .64606 .42909 .63922 .40867 Mtetra
.757 .611 .696 r
.63922 .40867 .64606 .42909 .65851 .41137 .65173 .39197 Mtetra
.757 .617 .704 r
.65173 .39197 .65851 .41137 .67095 .39449 .66423 .37613 Mtetra
.757 .624 .713 r
.66423 .37613 .67095 .39449 .68339 .37848 .67673 .36116 Mtetra
.757 .632 .723 r
.67673 .36116 .68339 .37848 .69584 .36338 .68926 .34707 Mtetra
.755 .64 .734 r
.68926 .34707 .69584 .36338 .70831 .34924 .70182 .33394 Mtetra
.753 .649 .747 r
.70182 .33394 .70831 .34924 .72083 .33613 .71442 .32179 Mtetra
.749 .659 .761 r
.71442 .32179 .72083 .33613 .7334 .32407 .72708 .31064 Mtetra
.744 .669 .777 r
.72708 .31064 .7334 .32407 .74605 .31305 .73982 .30047 Mtetra
.738 .679 .793 r
.73982 .30047 .74605 .31305 .75877 .30304 .75263 .29122 Mtetra
.731 .688 .81 r
.75263 .29122 .75877 .30304 .77158 .29397 .76553 .28283 Mtetra
.723 .698 .826 r
.76553 .28283 .77158 .29397 .78448 .28575 .77852 .27518 Mtetra
.714 .706 .841 r
.77852 .27518 .78448 .28575 .79748 .27827 .7916 .26818 Mtetra
.706 .714 .855 r
.7916 .26818 .79748 .27827 .81057 .27143 .80477 .26173 Mtetra
.698 .72 .867 r
.80477 .26173 .81057 .27143 .82376 .26511 .81803 .25571 Mtetra
.69 .726 .877 r
.81803 .25571 .82376 .26511 .83704 .25922 .83138 .25005 Mtetra
.684 .73 .885 r
.83138 .25005 .83704 .25922 .8504 .25366 .84481 .24467 Mtetra
.655 .742 .913 r
.23108 .44217 .23842 .44891 .24929 .44542 .24197 .43869 Mtetra
.651 .742 .916 r
.24197 .43869 .24929 .44542 .2602 .44201 .2529 .4353 Mtetra
.646 .742 .919 r
.2529 .4353 .2602 .44201 .27114 .43872 .26387 .43204 Mtetra
.638 .742 .924 r
.26387 .43204 .27114 .43872 .28212 .43558 .27487 .42896 Mtetra
.627 .742 .929 r
.27487 .42896 .28212 .43558 .29314 .43266 .2859 .42613 Mtetra
.613 .741 .937 r
.2859 .42613 .29314 .43266 .30418 .43002 .29696 .4236 Mtetra
.593 .739 .945 r
.29696 .4236 .30418 .43002 .31526 .42775 .30805 .42148 Mtetra
.565 .735 .955 r
.30805 .42148 .31526 .42775 .32636 .42595 .31917 .41984 Mtetra
.527 .728 .966 r
.31917 .41984 .32636 .42595 .33749 .4247 .33031 .4188 Mtetra
.474 .715 .975 r
.33031 .4188 .33749 .4247 .34865 .42413 .34149 .41848 Mtetra
.399 .69 .978 r
.34149 .41848 .34865 .42413 .35985 .42435 .35268 .419 Mtetra
.291 .646 .968 r
.35268 .419 .35985 .42435 .37107 .42549 .36391 .42054 Mtetra
.131 .566 .924 r
.36391 .42054 .37107 .42549 .38233 .42769 .37517 .42331 Mtetra
0 .425 .809 r
.37517 .42331 .38233 .42769 .39363 .43114 .38646 .42759 Mtetra
.366 0 0 r
.38646 .42759 .39363 .43114 .40498 .43605 .39778 .43375 Mtetra
.593 .021 0 r
.39778 .43375 .40498 .43605 .41638 .44269 .40915 .44218 Mtetra
.72 .196 0 r
.40915 .44218 .41638 .44269 .42786 .45135 .42057 .45325 Mtetra
.769 .299 .126 r
.42057 .45325 .42786 .45135 .43941 .46227 .43208 .4671 Mtetra
.779 .35 .23 r
.43208 .4671 .43941 .46227 .45108 .47551 .44371 .48344 Mtetra
.771 .368 .288 r
.44371 .48344 .45108 .47551 .46288 .49072 .45551 .50131 Mtetra
.752 .363 .315 r
.45551 .50131 .46288 .49072 .47487 .50702 .46752 .51903 Mtetra
.722 .334 .313 r
.46752 .51903 .47487 .50702 .48706 .52293 .47979 .53438 Mtetra
.67 .266 .271 r
.47979 .53438 .48706 .52293 .49948 .5365 .49231 .54501 Mtetra
.546 .091 .122 r
.49231 .54501 .49948 .5365 .5121 .54574 .50503 .54908 Mtetra
0 0 0 r
.50503 .54908 .5121 .54574 .52489 .54905 .51789 .54579 Mtetra
.821 .909 .899 r
.51789 .54579 .52489 .54905 .53776 .54574 .53081 .53559 Mtetra
.828 .739 .767 r
.53081 .53559 .53776 .54574 .55065 .53615 .5437 .51998 Mtetra
.801 .662 .71 r
.5437 .51998 .55065 .53615 .5635 .52154 .55654 .50095 Mtetra
.78 .623 .685 r
.55654 .50095 .5635 .52154 .57627 .50362 .56929 .48046 Mtetra
.766 .602 .676 r
.56929 .48046 .57627 .50362 .58897 .48407 .58198 .45997 Mtetra
.756 .592 .674 r
.58198 .45997 .58897 .48407 .60159 .46419 .59462 .44031 Mtetra
.749 .589 .677 r
.59462 .44031 .60159 .46419 .61417 .4448 .60722 .42182 Mtetra
.747 .592 .684 r
.60722 .42182 .61417 .4448 .62671 .42627 .6198 .40446 Mtetra
.746 .597 .691 r
.6198 .40446 .62671 .42627 .63922 .40867 .63237 .3881 Mtetra
.747 .604 .699 r
.63237 .3881 .63922 .40867 .65173 .39197 .64494 .37261 Mtetra
.748 .613 .708 r
.64494 .37261 .65173 .39197 .66423 .37613 .6575 .35793 Mtetra
.748 .621 .718 r
.6575 .35793 .66423 .37613 .67673 .36116 .67008 .34407 Mtetra
.748 .63 .729 r
.67008 .34407 .67673 .36116 .68926 .34707 .68268 .33107 Mtetra
.747 .64 .742 r
.68268 .33107 .68926 .34707 .70182 .33394 .69532 .31897 Mtetra
.744 .65 .756 r
.69532 .31897 .70182 .33394 .71442 .32179 .70801 .30781 Mtetra
.74 .66 .771 r
.70801 .30781 .71442 .32179 .72708 .31064 .72076 .29757 Mtetra
.735 .671 .787 r
.72076 .29757 .72708 .31064 .73982 .30047 .73358 .28823 Mtetra
.729 .681 .804 r
.73358 .28823 .73982 .30047 .75263 .29122 .74649 .27972 Mtetra
.722 .692 .821 r
.74649 .27972 .75263 .29122 .76553 .28283 .75947 .27196 Mtetra
.714 .701 .836 r
.75947 .27196 .76553 .28283 .77852 .27518 .77255 .26484 Mtetra
.706 .71 .851 r
.77255 .26484 .77852 .27518 .7916 .26818 .7857 .25827 Mtetra
.699 .717 .863 r
.7857 .25827 .7916 .26818 .80477 .26173 .79895 .25216 Mtetra
.691 .723 .874 r
.79895 .25216 .80477 .26173 .81803 .25571 .81228 .24641 Mtetra
.685 .728 .882 r
.81228 .24641 .81803 .25571 .83138 .25005 .82569 .24095 Mtetra
.68 .731 .889 r
.82569 .24095 .83138 .25005 .84481 .24467 .83918 .2357 Mtetra
.654 .742 .914 r
.22368 .43538 .23108 .44217 .24197 .43869 .23459 .4319 Mtetra
.649 .742 .917 r
.23459 .4319 .24197 .43869 .2529 .4353 .24554 .42854 Mtetra
.643 .741 .92 r
.24554 .42854 .2529 .4353 .26387 .43204 .25653 .42532 Mtetra
.635 .741 .925 r
.25653 .42532 .26387 .43204 .27487 .42896 .26755 .4223 Mtetra
.623 .74 .931 r
.26755 .4223 .27487 .42896 .2859 .42613 .2786 .41954 Mtetra
.607 .739 .938 r
.2786 .41954 .2859 .42613 .29696 .4236 .28968 .41712 Mtetra
.586 .736 .947 r
.28968 .41712 .29696 .4236 .30805 .42148 .30079 .41512 Mtetra
.556 .731 .957 r
.30079 .41512 .30805 .42148 .31917 .41984 .31192 .41364 Mtetra
.515 .721 .966 r
.31192 .41364 .31917 .41984 .33031 .4188 .32308 .41279 Mtetra
.457 .705 .974 r
.32308 .41279 .33031 .4188 .34149 .41848 .33426 .41272 Mtetra
.369 .674 .975 r
.33426 .41272 .34149 .41848 .35268 .419 .34546 .41361 Mtetra
.233 .614 .954 r
.34546 .41361 .35268 .419 .36391 .42054 .35668 .41571 Mtetra
.014 .493 .872 r
.35668 .41571 .36391 .42054 .37517 .42331 .36792 .41936 Mtetra
0 .273 .66 r
.36792 .41936 .37517 .42331 .38646 .42759 .37917 .42502 Mtetra
.575 0 0 r
.37917 .42502 .38646 .42759 .39778 .43375 .39043 .43321 Mtetra
.726 .205 0 r
.39043 .43321 .39778 .43375 .40915 .44218 .40172 .44442 Mtetra
.777 .316 .152 r
.40172 .44442 .40915 .44218 .42057 .45325 .41306 .4589 Mtetra
.785 .368 .259 r
.41306 .4589 .42057 .45325 .43208 .4671 .4245 .47637 Mtetra
.775 .385 .316 r
.4245 .47637 .43208 .4671 .44371 .48344 .43609 .49581 Mtetra
.755 .379 .342 r
.43609 .49581 .44371 .48344 .45551 .50131 .44791 .51533 Mtetra
.727 .352 .341 r
.44791 .51533 .45551 .50131 .46752 .51903 .46001 .5324 Mtetra
.678 .29 .303 r
.46001 .5324 .46752 .51903 .47979 .53438 .47241 .5443 Mtetra
.564 .127 .17 r
.47241 .5443 .47979 .53438 .49231 .54501 .48506 .54894 Mtetra
0 0 0 r
.48506 .54894 .49231 .54501 .50503 .54908 .49791 .54542 Mtetra
.836 .894 .881 r
.49791 .54542 .50503 .54908 .51789 .54579 .51086 .53431 Mtetra
.825 .719 .748 r
.51086 .53431 .51789 .54579 .53081 .53559 .52381 .51739 Mtetra
.795 .645 .696 r
.52381 .51739 .53081 .53559 .5437 .51998 .53671 .49702 Mtetra
.773 .608 .674 r
.53671 .49702 .5437 .51998 .55654 .50095 .54953 .47541 Mtetra
.757 .588 .666 r
.54953 .47541 .55654 .50095 .56929 .48046 .56229 .45419 Mtetra
.746 .578 .667 r
.56229 .45419 .56929 .48046 .58198 .45997 .57498 .43424 Mtetra
.739 .576 .671 r
.57498 .43424 .58198 .45997 .59462 .44031 .58764 .41582 Mtetra
.736 .579 .679 r
.58764 .41582 .59462 .44031 .60722 .42182 .60028 .39879 Mtetra
.736 .585 .687 r
.60028 .39879 .60722 .42182 .6198 .40446 .61291 .3829 Mtetra
.737 .594 .696 r
.61291 .3829 .6198 .40446 .63237 .3881 .62553 .36791 Mtetra
.739 .603 .706 r
.62553 .36791 .63237 .3881 .64494 .37261 .63815 .35369 Mtetra
.74 .612 .716 r
.63815 .35369 .64494 .37261 .6575 .35793 .65078 .3402 Mtetra
.741 .622 .727 r
.65078 .3402 .6575 .35793 .67008 .34407 .66343 .32747 Mtetra
.74 .632 .739 r
.66343 .32747 .67008 .34407 .68268 .33107 .67611 .31556 Mtetra
.739 .642 .752 r
.67611 .31556 .68268 .33107 .69532 .31897 .68882 .30451 Mtetra
.736 .653 .767 r
.68882 .30451 .69532 .31897 .70801 .30781 .7016 .29431 Mtetra
.732 .664 .783 r
.7016 .29431 .70801 .30781 .72076 .29757 .71444 .28496 Mtetra
.727 .675 .8 r
.71444 .28496 .72076 .29757 .73358 .28823 .72734 .27641 Mtetra
.721 .686 .816 r
.72734 .27641 .73358 .28823 .74649 .27972 .74033 .26857 Mtetra
.714 .696 .832 r
.74033 .26857 .74649 .27972 .75947 .27196 .7534 .26138 Mtetra
.706 .705 .847 r
.7534 .26138 .75947 .27196 .77255 .26484 .76655 .25473 Mtetra
.699 .713 .86 r
.76655 .25473 .77255 .26484 .7857 .25827 .77978 .24854 Mtetra
.692 .72 .871 r
.77978 .24854 .7857 .25827 .79895 .25216 .7931 .24272 Mtetra
.686 .725 .88 r
.7931 .24272 .79895 .25216 .81228 .24641 .80649 .23719 Mtetra
.681 .73 .887 r
.80649 .23719 .81228 .24641 .82569 .24095 .81997 .23189 Mtetra
.676 .733 .893 r
.81997 .23189 .82569 .24095 .83918 .2357 .83352 .22675 Mtetra
.652 .741 .915 r
.21622 .42853 .22368 .43538 .23459 .4319 .22715 .42507 Mtetra
.647 .741 .918 r
.22715 .42507 .23459 .4319 .24554 .42854 .23813 .42173 Mtetra
.641 .741 .921 r
.23813 .42173 .24554 .42854 .25653 .42532 .24914 .41854 Mtetra
.631 .74 .926 r
.24914 .41854 .25653 .42532 .26755 .4223 .26018 .41557 Mtetra
.619 .739 .932 r
.26018 .41557 .26755 .4223 .2786 .41954 .27125 .41288 Mtetra
.602 .737 .939 r
.27125 .41288 .2786 .41954 .28968 .41712 .28234 .41055 Mtetra
.579 .733 .948 r
.28234 .41055 .28968 .41712 .30079 .41512 .29347 .40866 Mtetra
.547 .726 .957 r
.29347 .40866 .30079 .41512 .31192 .41364 .30461 .40733 Mtetra
.501 .714 .967 r
.30461 .40733 .31192 .41364 .32308 .41279 .31578 .4067 Mtetra
.431 .692 .974 r
.31578 .4067 .32308 .41279 .33426 .41272 .32696 .40697 Mtetra
.314 .647 .968 r
.32696 .40697 .33426 .41272 .34546 .41361 .33815 .40842 Mtetra
.107 .545 .914 r
.33815 .40842 .34546 .41361 .35668 .41571 .34934 .41147 Mtetra
0 .326 .717 r
.34934 .41147 .35668 .41571 .36792 .41936 .36052 .41666 Mtetra
.563 0 0 r
.36052 .41666 .36792 .41936 .37917 .42502 .37169 .42463 Mtetra
.732 .217 0 r
.37169 .42463 .37917 .42502 .39043 .43321 .38284 .436 Mtetra
.782 .333 .181 r
.38284 .436 .39043 .43321 .40172 .44442 .39401 .4511 Mtetra
.787 .382 .286 r
.39401 .4511 .40172 .44442 .41306 .4589 .40524 .46971 Mtetra
.776 .398 .34 r
.40524 .46971 .41306 .4589 .4245 .47637 .41661 .49072 Mtetra
.756 .392 .364 r
.41661 .49072 .4245 .47637 .43609 .49581 .42822 .51201 Mtetra
.728 .366 .363 r
.42822 .51201 .43609 .49581 .44791 .51533 .44013 .5307 Mtetra
.682 .307 .329 r
.44013 .5307 .44791 .51533 .46001 .5324 .45239 .54374 Mtetra
.573 .152 .205 r
.45239 .54374 .46001 .5324 .47241 .5443 .46498 .54875 Mtetra
0 0 0 r
.46498 .54875 .47241 .5443 .48506 .54894 .47782 .54474 Mtetra
.85 .874 .858 r
.47782 .54474 .48506 .54894 .49791 .54542 .49081 .53244 Mtetra
.822 .7 .73 r
.49081 .53244 .49791 .54542 .51086 .53431 .50383 .51395 Mtetra
.79 .63 .682 r
.50383 .51395 .51086 .53431 .52381 .51739 .51681 .49199 Mtetra
.767 .594 .664 r
.51681 .49199 .52381 .51739 .53671 .49702 .52971 .46909 Mtetra
.751 .575 .658 r
.52971 .46909 .53671 .49702 .54953 .47541 .54253 .44704 Mtetra
.739 .566 .66 r
.54253 .44704 .54953 .47541 .56229 .45419 .55529 .42676 Mtetra
.731 .565 .666 r
.55529 .42676 .56229 .45419 .57498 .43424 .568 .40843 Mtetra
.727 .568 .675 r
.568 .40843 .57498 .43424 .58764 .41582 .58069 .39179 Mtetra
.726 .575 .685 r
.58069 .39179 .58764 .41582 .60028 .39879 .59336 .37646 Mtetra
.727 .584 .695 r
.59336 .37646 .60028 .39879 .61291 .3829 .60603 .36208 Mtetra
.73 .594 .705 r
.60603 .36208 .61291 .3829 .62553 .36791 .6187 .34845 Mtetra
.732 .604 .715 r
.6187 .34845 .62553 .36791 .63815 .35369 .63138 .33547 Mtetra
.733 .614 .725 r
.63138 .33547 .63815 .35369 .65078 .3402 .64407 .32316 Mtetra
.734 .625 .737 r
.64407 .32316 .65078 .3402 .66343 .32747 .65679 .31156 Mtetra
.733 .635 .75 r
.65679 .31156 .66343 .32747 .67611 .31556 .66954 .30072 Mtetra
.731 .647 .765 r
.66954 .30072 .67611 .31556 .68882 .30451 .68234 .29066 Mtetra
.728 .658 .78 r
.68234 .29066 .68882 .30451 .7016 .29431 .69519 .28138 Mtetra
.724 .67 .796 r
.69519 .28138 .7016 .29431 .71444 .28496 .70811 .27285 Mtetra
.719 .681 .813 r
.70811 .27285 .71444 .28496 .72734 .27641 .7211 .26501 Mtetra
.712 .692 .829 r
.7211 .26501 .72734 .27641 .74033 .26857 .73416 .25779 Mtetra
.706 .702 .844 r
.73416 .25779 .74033 .26857 .7534 .26138 .74731 .25109 Mtetra
.699 .71 .857 r
.74731 .25109 .7534 .26138 .76655 .25473 .76053 .24485 Mtetra
.692 .717 .868 r
.76053 .24485 .76655 .25473 .77978 .24854 .77383 .23898 Mtetra
.686 .723 .878 r
.77383 .23898 .77978 .24854 .7931 .24272 .78721 .2334 Mtetra
.681 .728 .886 r
.78721 .2334 .7931 .24272 .80649 .23719 .80067 .22805 Mtetra
.677 .732 .892 r
.80067 .22805 .80649 .23719 .81997 .23189 .8142 .22286 Mtetra
.673 .735 .896 r
.8142 .22286 .81997 .23189 .83352 .22675 .82781 .2178 Mtetra
.651 .741 .915 r
.2087 .42164 .21622 .42853 .22715 .42507 .21966 .41819 Mtetra
.646 .741 .918 r
.21966 .41819 .22715 .42507 .23813 .42173 .23065 .41486 Mtetra
.638 .74 .922 r
.23065 .41486 .23813 .42173 .24914 .41854 .24168 .4117 Mtetra
.629 .739 .927 r
.24168 .4117 .24914 .41854 .26018 .41557 .25274 .40878 Mtetra
.615 .737 .933 r
.25274 .40878 .26018 .41557 .27125 .41288 .26383 .40614 Mtetra
.597 .734 .94 r
.26383 .40614 .27125 .41288 .28234 .41055 .27495 .40388 Mtetra
.572 .729 .948 r
.27495 .40388 .28234 .41055 .29347 .40866 .28609 .40211 Mtetra
.536 .72 .958 r
.28609 .40211 .29347 .40866 .30461 .40733 .29724 .40096 Mtetra
.478 .704 .969 r
.29724 .40096 .30461 .40733 .31578 .4067 .30841 .40066 Mtetra
.377 .67 .973 r
.30841 .40066 .31578 .4067 .32696 .40697 .31958 .40152 Mtetra
.183 .586 .94 r
.31958 .40152 .32696 .40697 .33815 .40842 .33073 .40402 Mtetra
0 .368 .759 r
.33073 .40402 .33815 .40842 .34934 .41147 .34184 .40877 Mtetra
.558 0 0 r
.34184 .40877 .34934 .41147 .36052 .41666 .35291 .41656 Mtetra
.739 .231 .012 r
.35291 .41656 .36052 .41666 .37169 .42463 .36393 .4281 Mtetra
.785 .347 .21 r
.36393 .4281 .37169 .42463 .38284 .436 .37492 .44385 Mtetra
.787 .394 .31 r
.37492 .44385 .38284 .436 .39401 .4511 .38593 .46359 Mtetra
.775 .408 .36 r
.38593 .46359 .39401 .4511 .40524 .46971 .39706 .48612 Mtetra
.756 .401 .382 r
.39706 .48612 .40524 .46971 .41661 .49072 .40843 .50911 Mtetra
.728 .376 .381 r
.40843 .50911 .41661 .49072 .42822 .51201 .42014 .52933 Mtetra
.683 .318 .349 r
.42014 .52933 .42822 .51201 .44013 .5307 .43225 .54335 Mtetra
.575 .166 .229 r
.43225 .54335 .44013 .5307 .45239 .54374 .44478 .54851 Mtetra
0 0 0 r
.44478 .54851 .45239 .54374 .46498 .54875 .45762 .54378 Mtetra
.86 .849 .831 r
.45762 .54378 .46498 .54875 .47782 .54474 .47067 .53006 Mtetra
.819 .682 .712 r
.47067 .53006 .47782 .54474 .49081 .53244 .48379 .50978 Mtetra
.786 .616 .67 r
.48379 .50978 .49081 .53244 .50383 .51395 .49687 .48605 Mtetra
.763 .583 .654 r
.49687 .48605 .50383 .51395 .51681 .49199 .50986 .46171 Mtetra
.745 .565 .651 r
.50986 .46171 .51681 .49199 .52971 .46909 .52275 .43874 Mtetra
.733 .557 .654 r
.52275 .43874 .52971 .46909 .54253 .44704 .53556 .41808 Mtetra
.724 .555 .661 r
.53556 .41808 .54253 .44704 .55529 .42676 .54832 .39984 Mtetra
.719 .559 .672 r
.54832 .39984 .55529 .42676 .568 .40843 .56104 .38363 Mtetra
.717 .567 .683 r
.56104 .38363 .568 .40843 .58069 .39179 .57376 .36892 Mtetra
.719 .576 .694 r
.57376 .36892 .58069 .39179 .59336 .37646 .58647 .35524 Mtetra
.721 .587 .705 r
.58647 .35524 .59336 .37646 .60603 .36208 .59918 .34229 Mtetra
.724 .598 .715 r
.59918 .34229 .60603 .36208 .6187 .34845 .6119 .32993 Mtetra
.726 .608 .726 r
.6119 .32993 .6187 .34845 .63138 .33547 .62463 .31814 Mtetra
.727 .619 .737 r
.62463 .31814 .63138 .33547 .64407 .32316 .63738 .30696 Mtetra
.727 .63 .75 r
.63738 .30696 .64407 .32316 .65679 .31156 .65016 .29644 Mtetra
.726 .642 .764 r
.65016 .29644 .65679 .31156 .66954 .30072 .66298 .28661 Mtetra
.724 .653 .779 r
.66298 .28661 .66954 .30072 .68234 .29066 .67585 .27749 Mtetra
.721 .665 .795 r
.67585 .27749 .68234 .29066 .69519 .28138 .68878 .26905 Mtetra
.716 .677 .811 r
.68878 .26905 .69519 .28138 .70811 .27285 .70178 .26126 Mtetra
.711 .688 .826 r
.70178 .26126 .70811 .27285 .7211 .26501 .71484 .25405 Mtetra
.705 .698 .841 r
.71484 .25405 .7211 .26501 .73416 .25779 .72798 .24734 Mtetra
.698 .707 .855 r
.72798 .24734 .73416 .25779 .74731 .25109 .7412 .24108 Mtetra
.692 .715 .866 r
.7412 .24108 .74731 .25109 .76053 .24485 .75449 .23517 Mtetra
.686 .721 .876 r
.75449 .23517 .76053 .24485 .77383 .23898 .76785 .22956 Mtetra
.681 .727 .884 r
.76785 .22956 .77383 .23898 .78721 .2334 .7813 .22417 Mtetra
.677 .731 .891 r
.7813 .22417 .78721 .2334 .80067 .22805 .79481 .21895 Mtetra
.673 .734 .895 r
.79481 .21895 .80067 .22805 .8142 .22286 .8084 .21385 Mtetra
.671 .736 .899 r
.8084 .21385 .8142 .22286 .82781 .2178 .82206 .20885 Mtetra
.65 .741 .916 r
.20112 .41469 .2087 .42164 .21966 .41819 .2121 .41124 Mtetra
.644 .74 .919 r
.2121 .41124 .21966 .41819 .23065 .41486 .22312 .40792 Mtetra
.637 .739 .923 r
.22312 .40792 .23065 .41486 .24168 .4117 .23417 .40479 Mtetra
.626 .738 .927 r
.23417 .40479 .24168 .4117 .25274 .40878 .24525 .40189 Mtetra
.612 .735 .933 r
.24525 .40189 .25274 .40878 .26383 .40614 .25636 .39931 Mtetra
.592 .732 .941 r
.25636 .39931 .26383 .40614 .27495 .40388 .26749 .39714 Mtetra
.562 .725 .95 r
.26749 .39714 .27495 .40388 .28609 .40211 .27864 .39554 Mtetra
.514 .713 .962 r
.27864 .39554 .28609 .40211 .29724 .40096 .2898 .39472 Mtetra
.425 .687 .973 r
.2898 .39472 .29724 .40096 .30841 .40066 .30094 .39505 Mtetra
.242 .616 .956 r
.30094 .39505 .30841 .40066 .31958 .40152 .31206 .39704 Mtetra
0 .402 .788 r
.31206 .39704 .31958 .40152 .33073 .40402 .32311 .40142 Mtetra
.559 0 0 r
.32311 .40142 .33073 .40402 .34184 .40877 .33408 .40905 Mtetra
.745 .246 .041 r
.33408 .40905 .34184 .40877 .35291 .41656 .34496 .42079 Mtetra
.786 .36 .236 r
.34496 .42079 .35291 .41656 .36393 .4281 .35576 .43717 Mtetra
.786 .404 .331 r
.35576 .43717 .36393 .4281 .37492 .44385 .36655 .45801 Mtetra
.774 .415 .377 r
.36655 .45801 .37492 .44385 .38593 .46359 .37743 .48199 Mtetra
.755 .408 .396 r
.37743 .48199 .38593 .46359 .39706 .48612 .38854 .50657 Mtetra
.728 .383 .395 r
.38854 .50657 .39706 .48612 .40843 .50911 .40004 .52816 Mtetra
.683 .326 .363 r
.40004 .52816 .40843 .50911 .42014 .52933 .412 .54299 Mtetra
.574 .172 .243 r
.412 .54299 .42014 .52933 .43225 .54335 .42446 .54813 Mtetra
0 0 0 r
.42446 .54813 .43225 .54335 .44478 .54851 .43732 .54248 Mtetra
.864 .819 .803 r
.43732 .54248 .44478 .54851 .45762 .54378 .45045 .52715 Mtetra
.816 .665 .696 r
.45045 .52715 .45762 .54378 .47067 .53006 .46368 .50493 Mtetra
.782 .605 .659 r
.46368 .50493 .47067 .53006 .48379 .50978 .47688 .47932 Mtetra
.759 .574 .646 r
.47688 .47932 .48379 .50978 .49687 .48605 .48997 .45347 Mtetra
.741 .556 .644 r
.48997 .45347 .49687 .48605 .50986 .46171 .50295 .42953 Mtetra
.728 .548 .649 r
.50295 .42953 .50986 .46171 .52275 .43874 .51582 .40846 Mtetra
.718 .547 .658 r
.51582 .40846 .52275 .43874 .53556 .41808 .52861 .3903 Mtetra
.712 .551 .67 r
.52861 .3903 .53556 .41808 .54832 .39984 .54137 .37453 Mtetra
.71 .56 .682 r
.54137 .37453 .54832 .39984 .56104 .38363 .55412 .36047 Mtetra
.711 .57 .695 r
.55412 .36047 .56104 .38363 .57376 .36892 .56686 .34754 Mtetra
.713 .582 .707 r
.56686 .34754 .57376 .36892 .58647 .35524 .5796 .33534 Mtetra
.716 .593 .717 r
.5796 .33534 .58647 .35524 .59918 .34229 .59234 .32368 Mtetra
.719 .604 .728 r
.59234 .32368 .59918 .34229 .6119 .32993 .60511 .31249 Mtetra
.721 .615 .739 r
.60511 .31249 .6119 .32993 .62463 .31814 .61789 .30182 Mtetra
.721 .626 .751 r
.61789 .30182 .62463 .31814 .63738 .30696 .63069 .2917 Mtetra
.721 .638 .765 r
.63069 .2917 .63738 .30696 .65016 .29644 .64354 .28218 Mtetra
.72 .65 .779 r
.64354 .28218 .65016 .29644 .66298 .28661 .65642 .27328 Mtetra
.717 .662 .794 r
.65642 .27328 .66298 .28661 .67585 .27749 .66937 .265 Mtetra
.713 .674 .81 r
.66937 .265 .67585 .27749 .68878 .26905 .68237 .25731 Mtetra
.708 .685 .825 r
.68237 .25731 .68878 .26905 .70178 .26126 .69543 .25015 Mtetra
.703 .696 .84 r
.69543 .25015 .70178 .26126 .71484 .25405 .70857 .24348 Mtetra
.697 .705 .853 r
.70857 .24348 .71484 .25405 .72798 .24734 .72178 .23721 Mtetra
.692 .713 .865 r
.72178 .23721 .72798 .24734 .7412 .24108 .73506 .2313 Mtetra
.686 .72 .875 r
.73506 .2313 .7412 .24108 .75449 .23517 .74841 .22566 Mtetra
.681 .725 .883 r
.74841 .22566 .75449 .23517 .76785 .22956 .76184 .22024 Mtetra
.677 .73 .89 r
.76184 .22024 .76785 .22956 .7813 .22417 .77534 .215 Mtetra
.673 .733 .895 r
.77534 .215 .7813 .22417 .79481 .21895 .78891 .20988 Mtetra
.671 .735 .899 r
.78891 .20988 .79481 .21895 .8084 .21385 .80256 .20485 Mtetra
.669 .737 .901 r
.80256 .20485 .8084 .21385 .82206 .20885 .81627 .19987 Mtetra
.649 .74 .916 r
.19348 .40768 .20112 .41469 .2121 .41124 .20449 .40422 Mtetra
.643 .739 .919 r
.20449 .40422 .2121 .41124 .22312 .40792 .21553 .40091 Mtetra
.635 .738 .923 r
.21553 .40091 .22312 .40792 .23417 .40479 .2266 .39779 Mtetra
.624 .736 .928 r
.2266 .39779 .23417 .40479 .24525 .40189 .23771 .39493 Mtetra
.608 .733 .934 r
.23771 .39493 .24525 .40189 .25636 .39931 .24883 .39243 Mtetra
.583 .729 .943 r
.24883 .39243 .25636 .39931 .26749 .39714 .25997 .39042 Mtetra
.542 .72 .956 r
.25997 .39042 .26749 .39714 .27864 .39554 .27112 .38915 Mtetra
.462 .7 .97 r
.27112 .38915 .27864 .39554 .2898 .39472 .28224 .38901 Mtetra
.289 .639 .966 r
.28224 .38901 .2898 .39472 .30094 .39505 .29332 .39056 Mtetra
0 .428 .807 r
.29332 .39056 .30094 .39505 .31206 .39704 .30432 .39461 Mtetra
.564 0 0 r
.30432 .39461 .31206 .39704 .32311 .40142 .3152 .40212 Mtetra
.75 .26 .069 r
.3152 .40212 .32311 .40142 .33408 .40905 .32593 .41406 Mtetra
.787 .37 .259 r
.32593 .41406 .33408 .40905 .34496 .42079 .33654 .43104 Mtetra
.785 .411 .347 r
.33654 .43104 .34496 .42079 .35576 .43717 .34709 .45289 Mtetra
.772 .421 .39 r
.34709 .45289 .35576 .43717 .36655 .45801 .35771 .4782 Mtetra
.754 .413 .407 r
.35771 .4782 .36655 .45801 .37743 .48199 .36856 .50419 Mtetra
.727 .388 .404 r
.36856 .50419 .37743 .48199 .38854 .50657 .37983 .52698 Mtetra
.683 .331 .372 r
.37983 .52698 .38854 .50657 .40004 .52816 .39164 .54242 Mtetra
.569 .17 .247 r
.39164 .54242 .40004 .52816 .412 .54299 .40404 .54734 Mtetra
0 0 0 r
.40404 .54734 .412 .54299 .42446 .54813 .41694 .54065 Mtetra
.862 .787 .776 r
.41694 .54065 .42446 .54813 .43732 .54248 .43016 .52361 Mtetra
.811 .648 .681 r
.43016 .52361 .43732 .54248 .45045 .52715 .44353 .4994 Mtetra
.778 .594 .65 r
.44353 .4994 .45045 .52715 .46368 .50493 .45687 .47189 Mtetra
.756 .565 .639 r
.45687 .47189 .46368 .50493 .47688 .47932 .47008 .44453 Mtetra
.738 .549 .638 r
.47008 .44453 .47688 .47932 .48997 .45347 .48315 .41962 Mtetra
.724 .542 .644 r
.48315 .41962 .48997 .45347 .50295 .42953 .49608 .39815 Mtetra
.713 .541 .655 r
.49608 .39815 .50295 .42953 .51582 .40846 .50891 .38007 Mtetra
.706 .546 .668 r
.50891 .38007 .51582 .40846 .52861 .3903 .5217 .36473 Mtetra
.703 .555 .683 r
.5217 .36473 .52861 .3903 .54137 .37453 .53446 .35133 Mtetra
.703 .566 .697 r
.53446 .35133 .54137 .37453 .55412 .36047 .54721 .33917 Mtetra
.706 .578 .71 r
.54721 .33917 .55412 .36047 .56686 .34754 .55997 .32775 Mtetra
.709 .59 .721 r
.55997 .32775 .56686 .34754 .5796 .33534 .57274 .31682 Mtetra
.712 .602 .732 r
.57274 .31682 .5796 .33534 .59234 .32368 .58552 .3063 Mtetra
.714 .613 .742 r
.58552 .3063 .59234 .32368 .60511 .31249 .59832 .29619 Mtetra
.716 .624 .754 r
.59832 .29619 .60511 .31249 .61789 .30182 .61115 .28654 Mtetra
.716 .636 .767 r
.61115 .28654 .61789 .30182 .63069 .2917 .62401 .27739 Mtetra
.715 .648 .781 r
.62401 .27739 .63069 .2917 .64354 .28218 .63692 .26878 Mtetra
.713 .66 .796 r
.63692 .26878 .64354 .28218 .65642 .27328 .64987 .26071 Mtetra
.71 .671 .811 r
.64987 .26071 .65642 .27328 .66937 .265 .66288 .25316 Mtetra
.706 .683 .825 r
.66288 .25316 .66937 .265 .68237 .25731 .67594 .2461 Mtetra
.701 .694 .84 r
.67594 .2461 .68237 .25731 .69543 .25015 .68908 .23949 Mtetra
.696 .703 .853 r
.68908 .23949 .69543 .25015 .70857 .24348 .70228 .23326 Mtetra
.691 .711 .864 r
.70228 .23326 .70857 .24348 .72178 .23721 .71555 .22735 Mtetra
.686 .718 .874 r
.71555 .22735 .72178 .23721 .73506 .2313 .72889 .22171 Mtetra
.681 .724 .882 r
.72889 .22171 .73506 .2313 .74841 .22566 .7423 .21628 Mtetra
.677 .729 .889 r
.7423 .21628 .74841 .22566 .76184 .22024 .75579 .21102 Mtetra
.673 .732 .894 r
.75579 .21102 .76184 .22024 .77534 .215 .76934 .20587 Mtetra
.671 .735 .898 r
.76934 .20587 .77534 .215 .78891 .20988 .78297 .20082 Mtetra
.669 .737 .901 r
.78297 .20082 .78891 .20988 .80256 .20485 .79667 .19582 Mtetra
.667 .738 .903 r
.79667 .19582 .80256 .20485 .81627 .19987 .81043 .19086 Mtetra
.648 .74 .916 r
.18578 .4006 .19348 .40768 .20449 .40422 .19681 .39714 Mtetra
.642 .739 .919 r
.19681 .39714 .20449 .40422 .21553 .40091 .20788 .39383 Mtetra
.633 .737 .923 r
.20788 .39383 .21553 .40091 .2266 .39779 .21897 .39073 Mtetra
.62 .735 .929 r
.21897 .39073 .2266 .39779 .23771 .39493 .23009 .38794 Mtetra
.599 .731 .937 r
.23009 .38794 .23771 .39493 .24883 .39243 .24123 .38559 Mtetra
.563 .725 .95 r
.24123 .38559 .24883 .39243 .25997 .39042 .25236 .38393 Mtetra
.49 .71 .968 r
.25236 .38393 .25997 .39042 .27112 .38915 .26347 .38338 Mtetra
.324 .658 .972 r
.26347 .38338 .27112 .38915 .28224 .38901 .27452 .38455 Mtetra
0 .448 .821 r
.27452 .38455 .28224 .38901 .29332 .39056 .28546 .38831 Mtetra
.57 0 0 r
.28546 .38831 .29332 .39056 .30432 .39461 .29624 .39573 Mtetra
.753 .271 .094 r
.29624 .39573 .30432 .39461 .3152 .40212 .30684 .40785 Mtetra
.786 .377 .277 r
.30684 .40785 .3152 .40212 .32593 .41406 .31725 .42535 Mtetra
.784 .416 .36 r
.31725 .42535 .32593 .41406 .33654 .43104 .32757 .44807 Mtetra
.771 .425 .399 r
.32757 .44807 .33654 .43104 .34709 .45289 .33791 .47452 Mtetra
.753 .417 .415 r
.33791 .47452 .34709 .45289 .35771 .4782 .3485 .5017 Mtetra
.727 .391 .411 r
.3485 .5017 .35771 .4782 .36856 .50419 .35953 .52543 Mtetra
.683 .334 .376 r
.35953 .52543 .36856 .50419 .37983 .52698 .3712 .54126 Mtetra
.56 .161 .241 r
.3712 .54126 .37983 .52698 .39164 .54242 .38354 .54583 Mtetra
.495 .891 .741 r
.38354 .54583 .39164 .54242 .40404 .54734 .39648 .538 Mtetra
.854 .753 .75 r
.39648 .538 .40404 .54734 .41694 .54065 .40982 .51927 Mtetra
.804 .633 .669 r
.40982 .51927 .41694 .54065 .43016 .52361 .42334 .49313 Mtetra
.774 .583 .641 r
.42334 .49313 .43016 .52361 .44353 .4994 .43684 .46382 Mtetra
.752 .557 .632 r
.43684 .46382 .44353 .4994 .45687 .47189 .45019 .43504 Mtetra
.735 .543 .633 r
.45019 .43504 .45687 .47189 .47008 .44453 .46335 .40923 Mtetra
.72 .536 .64 r
.46335 .40923 .47008 .44453 .48315 .41962 .47635 .38739 Mtetra
.709 .536 .652 r
.47635 .38739 .48315 .41962 .49608 .39815 .48922 .36939 Mtetra
.701 .541 .667 r
.48922 .36939 .49608 .39815 .50891 .38007 .50202 .35448 Mtetra
.698 .551 .684 r
.50202 .35448 .50891 .38007 .5217 .36473 .51479 .34173 Mtetra
.697 .564 .7 r
.51479 .34173 .5217 .36473 .53446 .35133 .52755 .33032 Mtetra
.699 .577 .714 r
.52755 .33032 .53446 .35133 .54721 .33917 .54031 .31969 Mtetra
.702 .589 .726 r
.54031 .31969 .54721 .33917 .55997 .32775 .55309 .30951 Mtetra
.706 .601 .737 r
.55309 .30951 .55997 .32775 .57274 .31682 .56588 .29968 Mtetra
.708 .612 .747 r
.56588 .29968 .57274 .31682 .58552 .3063 .5787 .29017 Mtetra
.71 .624 .759 r
.5787 .29017 .58552 .3063 .59832 .29619 .59154 .28103 Mtetra
.711 .635 .771 r
.59154 .28103 .59832 .29619 .61115 .28654 .60442 .27229 Mtetra
.71 .647 .784 r
.60442 .27229 .61115 .28654 .62401 .27739 .61733 .26401 Mtetra
.709 .659 .798 r
.61733 .26401 .62401 .27739 .63692 .26878 .63029 .25619 Mtetra
.706 .67 .812 r
.63029 .25619 .63692 .26878 .64987 .26071 .6433 .24883 Mtetra
.703 .682 .827 r
.6433 .24883 .64987 .26071 .66288 .25316 .65637 .24191 Mtetra
.699 .692 .84 r
.65637 .24191 .66288 .25316 .67594 .2461 .6695 .23538 Mtetra
.694 .702 .853 r
.6695 .23538 .67594 .2461 .68908 .23949 .6827 .22921 Mtetra
.689 .71 .864 r
.6827 .22921 .68908 .23949 .70228 .23326 .69596 .22333 Mtetra
.685 .717 .874 r
.69596 .22333 .70228 .23326 .71555 .22735 .70929 .2177 Mtetra
.68 .723 .882 r
.70929 .2177 .71555 .22735 .72889 .22171 .72269 .21227 Mtetra
.677 .728 .889 r
.72269 .21227 .72889 .22171 .7423 .21628 .73616 .207 Mtetra
.673 .732 .894 r
.73616 .207 .7423 .21628 .75579 .21102 .7497 .20184 Mtetra
.671 .734 .898 r
.7497 .20184 .75579 .21102 .76934 .20587 .7633 .19677 Mtetra
.669 .736 .901 r
.7633 .19677 .76934 .20587 .78297 .20082 .77698 .19175 Mtetra
.667 .738 .903 r
.77698 .19175 .78297 .20082 .79667 .19582 .79073 .18677 Mtetra
.666 .739 .905 r
.79073 .18677 .79667 .19582 .81043 .19086 .80455 .18181 Mtetra
.647 .739 .916 r
.17803 .39345 .18578 .4006 .19681 .39714 .18908 .38999 Mtetra
.64 .738 .92 r
.18908 .38999 .19681 .39714 .20788 .39383 .20017 .38669 Mtetra
.629 .736 .924 r
.20017 .38669 .20788 .39383 .21897 .39073 .21128 .38365 Mtetra
.612 .734 .932 r
.21128 .38365 .21897 .39073 .23009 .38794 .22241 .38101 Mtetra
.579 .729 .945 r
.22241 .38101 .23009 .38794 .24123 .38559 .23353 .37903 Mtetra
.512 .717 .965 r
.23353 .37903 .24123 .38559 .25236 .38393 .24462 .37813 Mtetra
.352 .672 .976 r
.24462 .37813 .25236 .38393 .26347 .38338 .25564 .37897 Mtetra
0 .465 .831 r
.25564 .37897 .26347 .38338 .27452 .38455 .26652 .38249 Mtetra
.575 0 0 r
.26652 .38249 .27452 .38455 .28546 .38831 .27721 .3898 Mtetra
.755 .279 .114 r
.27721 .3898 .28546 .38831 .29624 .39573 .28767 .40204 Mtetra
.785 .383 .29 r
.28767 .40204 .29624 .39573 .30684 .40785 .2979 .41994 Mtetra
.783 .42 .369 r
.2979 .41994 .30684 .40785 .31725 .42535 .30797 .44334 Mtetra
.771 .428 .406 r
.30797 .44334 .31725 .42535 .32757 .44807 .31805 .47066 Mtetra
.753 .42 .42 r
.31805 .47066 .32757 .44807 .33791 .47452 .32837 .49873 Mtetra
.728 .394 .414 r
.32837 .49873 .33791 .47452 .3485 .5017 .33918 .52311 Mtetra
.684 .334 .377 r
.33918 .52311 .3485 .5017 .35953 .52543 .35069 .5391 Mtetra
.549 .142 .223 r
.35069 .5391 .35953 .52543 .3712 .54126 .36298 .54317 Mtetra
.68 .978 .858 r
.36298 .54317 .3712 .54126 .38354 .54583 .37597 .53421 Mtetra
.843 .72 .728 r
.37597 .53421 .38354 .54583 .39648 .538 .38945 .51389 Mtetra
.797 .617 .658 r
.38945 .51389 .39648 .538 .40982 .51927 .40314 .48601 Mtetra
.769 .574 .634 r
.40314 .48601 .40982 .51927 .42334 .49313 .41681 .4551 Mtetra
.749 .551 .627 r
.41681 .4551 .42334 .49313 .43684 .46382 .43031 .42509 Mtetra
.732 .537 .629 r
.43031 .42509 .43684 .46382 .45019 .43504 .44358 .39852 Mtetra
.718 .532 .637 r
.44358 .39852 .45019 .43504 .46335 .40923 .45664 .37639 Mtetra
.706 .532 .65 r
.45664 .37639 .46335 .40923 .47635 .38739 .46954 .3585 Mtetra
.698 .538 .668 r
.46954 .3585 .47635 .38739 .48922 .36939 .48235 .34402 Mtetra
.693 .549 .686 r
.48235 .34402 .48922 .36939 .50202 .35448 .49512 .33189 Mtetra
.692 .563 .704 r
.49512 .33189 .50202 .35448 .51479 .34173 .50787 .3212 Mtetra
.693 .577 .72 r
.50787 .3212 .51479 .34173 .52755 .33032 .52063 .31133 Mtetra
.697 .59 .733 r
.52063 .31133 .52755 .33032 .54031 .31969 .53341 .3019 Mtetra
.7 .602 .744 r
.53341 .3019 .54031 .31969 .55309 .30951 .5462 .29275 Mtetra
.703 .614 .754 r
.5462 .29275 .55309 .30951 .56588 .29968 .55903 .28385 Mtetra
.705 .625 .765 r
.55903 .28385 .56588 .29968 .5787 .29017 .57188 .27524 Mtetra
.706 .636 .776 r
.57188 .27524 .5787 .29017 .59154 .28103 .58476 .26695 Mtetra
.706 .647 .789 r
.58476 .26695 .59154 .28103 .60442 .27229 .59768 .25902 Mtetra
.705 .659 .802 r
.59768 .25902 .60442 .27229 .61733 .26401 .61064 .25149 Mtetra
.703 .671 .816 r
.61064 .25149 .61733 .26401 .63029 .25619 .62365 .24435 Mtetra
.7 .682 .829 r
.62365 .24435 .63029 .25619 .6433 .24883 .63672 .23758 Mtetra
.696 .692 .842 r
.63672 .23758 .6433 .24883 .65637 .24191 .64985 .23117 Mtetra
.692 .702 .854 r
.64985 .23117 .65637 .24191 .6695 .23538 .66303 .22507 Mtetra
.688 .71 .865 r
.66303 .22507 .6695 .23538 .6827 .22921 .67629 .21924 Mtetra
.683 .717 .874 r
.67629 .21924 .6827 .22921 .69596 .22333 .6896 .21364 Mtetra
.68 .723 .882 r
.6896 .21364 .69596 .22333 .70929 .2177 .70299 .20822 Mtetra
.676 .728 .889 r
.70299 .20822 .70929 .2177 .72269 .21227 .71644 .20294 Mtetra
.673 .731 .894 r
.71644 .20294 .72269 .21227 .73616 .207 .72997 .19777 Mtetra
.671 .734 .898 r
.72997 .19777 .73616 .207 .7497 .20184 .74356 .19269 Mtetra
.669 .736 .901 r
.74356 .19269 .7497 .20184 .7633 .19677 .75722 .18765 Mtetra
.667 .738 .903 r
.75722 .18765 .7633 .19677 .77698 .19175 .77095 .18265 Mtetra
.666 .739 .904 r
.77095 .18265 .77698 .19175 .79073 .18677 .78474 .17767 Mtetra
.665 .74 .906 r
.78474 .17767 .79073 .18677 .80455 .18181 .79861 .1727 Mtetra
.646 .739 .917 r
.17021 .38624 .17803 .39345 .18908 .38999 .18128 .38279 Mtetra
.637 .737 .921 r
.18128 .38279 .18908 .38999 .20017 .38669 .19239 .37955 Mtetra
.621 .735 .928 r
.19239 .37955 .20017 .38669 .21128 .38365 .20351 .37667 Mtetra
.592 .732 .941 r
.20351 .37667 .21128 .38365 .22241 .38101 .21462 .37441 Mtetra
.53 .723 .962 r
.21462 .37441 .22241 .38101 .23353 .37903 .22569 .37322 Mtetra
.376 .685 .979 r
.22569 .37322 .23353 .37903 .24462 .37813 .23668 .37377 Mtetra
0 .482 .84 r
.23668 .37377 .24462 .37813 .25564 .37897 .24751 .37705 Mtetra
.576 0 0 r
.24751 .37705 .25564 .37897 .26652 .38249 .25811 .38423 Mtetra
.755 .284 .127 r
.25811 .38423 .26652 .38249 .27721 .3898 .26844 .3965 Mtetra
.784 .386 .298 r
.26844 .3965 .27721 .3898 .28767 .40204 .27849 .41463 Mtetra
.782 .422 .375 r
.27849 .41463 .28767 .40204 .2979 .41994 .28833 .43845 Mtetra
.771 .43 .41 r
.28833 .43845 .2979 .41994 .30797 .44334 .29815 .46631 Mtetra
.754 .422 .422 r
.29815 .46631 .30797 .44334 .31805 .47066 .30821 .4949 Mtetra
.729 .395 .414 r
.30821 .4949 .31805 .47066 .32837 .49873 .3188 .51958 Mtetra
.685 .333 .373 r
.3188 .51958 .32837 .49873 .33918 .52311 .33017 .53548 Mtetra
.532 .111 .187 r
.33017 .53548 .33918 .52311 .35069 .5391 .34242 .53895 Mtetra
.796 .977 .906 r
.34242 .53895 .35069 .5391 .36298 .54317 .35547 .52891 Mtetra
.829 .689 .709 r
.35547 .52891 .36298 .54317 .37597 .53421 .36908 .50722 Mtetra
.789 .603 .649 r
.36908 .50722 .37597 .53421 .38945 .51389 .38294 .4779 Mtetra
.764 .565 .629 r
.38294 .4779 .38945 .51389 .40314 .48601 .39679 .44572 Mtetra
.745 .544 .623 r
.39679 .44572 .40314 .48601 .41681 .4551 .41044 .41476 Mtetra
.729 .533 .626 r
.41044 .41476 .41681 .4551 .43031 .42509 .42381 .38763 Mtetra
.716 .528 .635 r
.42381 .38763 .43031 .42509 .44358 .39852 .43694 .36534 Mtetra
.704 .53 .65 r
.43694 .36534 .44358 .39852 .45664 .37639 .44987 .34762 Mtetra
.695 .537 .669 r
.44987 .34762 .45664 .37639 .46954 .3585 .46269 .33355 Mtetra
.689 .549 .69 r
.46269 .33355 .46954 .3585 .48235 .34402 .47544 .32201 Mtetra
.687 .564 .71 r
.47544 .32201 .48235 .34402 .49512 .33189 .48818 .31201 Mtetra
.688 .579 .727 r
.48818 .31201 .49512 .33189 .50787 .3212 .50093 .30285 Mtetra
.691 .593 .741 r
.50093 .30285 .50787 .3212 .52063 .31133 .5137 .29412 Mtetra
.695 .605 .752 r
.5137 .29412 .52063 .31133 .53341 .3019 .52649 .28564 Mtetra
.698 .616 .762 r
.52649 .28564 .53341 .3019 .5462 .29275 .53931 .27734 Mtetra
.7 .627 .772 r
.53931 .27734 .5462 .29275 .55903 .28385 .55215 .26925 Mtetra
.701 .638 .783 r
.55215 .26925 .55903 .28385 .57188 .27524 .56504 .26141 Mtetra
.701 .649 .795 r
.56504 .26141 .57188 .27524 .58476 .26695 .57796 .25387 Mtetra
.701 .661 .807 r
.57796 .25387 .58476 .26695 .59768 .25902 .59092 .24663 Mtetra
.699 .672 .82 r
.59092 .24663 .59768 .25902 .61064 .25149 .60393 .23973 Mtetra
.697 .683 .833 r
.60393 .23973 .61064 .25149 .62365 .24435 .617 .23315 Mtetra
.693 .693 .845 r
.617 .23315 .62365 .24435 .63672 .23758 .63012 .22686 Mtetra
.69 .702 .856 r
.63012 .22686 .63672 .23758 .64985 .23117 .64329 .22086 Mtetra
.686 .71 .866 r
.64329 .22086 .64985 .23117 .66303 .22507 .65654 .21509 Mtetra
.682 .717 .875 r
.65654 .21509 .66303 .22507 .67629 .21924 .66984 .20952 Mtetra
.679 .723 .883 r
.66984 .20952 .67629 .21924 .6896 .21364 .68321 .20412 Mtetra
.675 .727 .889 r
.68321 .20412 .6896 .21364 .70299 .20822 .69665 .19885 Mtetra
.673 .731 .894 r
.69665 .19885 .70299 .20822 .71644 .20294 .71016 .19368 Mtetra
.67 .734 .898 r
.71016 .19368 .71644 .20294 .72997 .19777 .72373 .18858 Mtetra
.668 .736 .901 r
.72373 .18858 .72997 .19777 .74356 .19269 .73737 .18353 Mtetra
.667 .738 .903 r
.73737 .18353 .74356 .19269 .75722 .18765 .75108 .17852 Mtetra
.666 .739 .904 r
.75108 .17852 .75722 .18765 .77095 .18265 .76486 .17352 Mtetra
.665 .74 .906 r
.76486 .17352 .77095 .18265 .78474 .17767 .77871 .16853 Mtetra
.77871 .16853 .78474 .17767 .79861 .1727 .79262 .16353 Mtetra
.642 .738 .918 r
.16232 .379 .17021 .38624 .18128 .38279 .17341 .37559 Mtetra
.629 .737 .925 r
.17341 .37559 .18128 .38279 .19239 .37955 .18452 .37252 Mtetra
.602 .735 .938 r
.18452 .37252 .19239 .37955 .20351 .37667 .19563 .37003 Mtetra
.544 .728 .96 r
.19563 .37003 .20351 .37667 .21462 .37441 .20668 .36858 Mtetra
.396 .695 .981 r
.20668 .36858 .21462 .37441 .22569 .37322 .21764 .36888 Mtetra
0 .499 .851 r
.21764 .36888 .22569 .37322 .23668 .37377 .22841 .37192 Mtetra
.572 0 0 r
.22841 .37192 .23668 .37377 .24751 .37705 .23894 .37891 Mtetra
.753 .284 .132 r
.23894 .37891 .24751 .37705 .25811 .38423 .24914 .39109 Mtetra
.783 .386 .302 r
.24914 .39109 .25811 .38423 .26844 .3965 .25903 .40923 Mtetra
.782 .423 .377 r
.25903 .40923 .26844 .3965 .27849 .41463 .26866 .43315 Mtetra
.771 .431 .41 r
.26866 .43315 .27849 .41463 .28833 .43845 .27824 .46116 Mtetra
.755 .423 .422 r
.27824 .46116 .28833 .43845 .29815 .46631 .28806 .48985 Mtetra
.732 .396 .412 r
.28806 .48985 .29815 .46631 .30821 .4949 .29845 .51445 Mtetra
.686 .33 .364 r
.29845 .51445 .30821 .4949 .3188 .51958 .30969 .52999 Mtetra
.506 .06 .126 r
.30969 .52999 .3188 .51958 .33017 .53548 .3219 .53278 Mtetra
.833 .912 .89 r
.3219 .53278 .33017 .53548 .34242 .53895 .33501 .5218 Mtetra
.814 .661 .694 r
.33501 .5218 .34242 .53895 .35547 .52891 .34875 .49903 Mtetra
.78 .59 .642 r
.34875 .49903 .35547 .52891 .36908 .50722 .36278 .46867 Mtetra
.759 .557 .624 r
.36278 .46867 .36908 .50722 .38294 .4779 .37679 .43562 Mtetra
.741 .539 .62 r
.37679 .43562 .38294 .4779 .39679 .44572 .39058 .40408 Mtetra
.727 .529 .623 r
.39058 .40408 .39679 .44572 .41044 .41476 .40406 .37667 Mtetra
.714 .525 .633 r
.40406 .37667 .41044 .41476 .42381 .38763 .41725 .35438 Mtetra
.702 .528 .65 r
.41725 .35438 .42381 .38763 .43694 .36534 .43021 .33691 Mtetra
.693 .537 .671 r
.43021 .33691 .43694 .36534 .44987 .34762 .44303 .32327 Mtetra
.687 .55 .694 r
.44303 .32327 .44987 .34762 .46269 .33355 .45577 .31229 Mtetra
.684 .566 .717 r
.45577 .31229 .46269 .33355 .47544 .32201 .46849 .30291 Mtetra
.684 .583 .735 r
.46849 .30291 .47544 .32201 .48818 .31201 .48121 .29441 Mtetra
.687 .597 .75 r
.48121 .29441 .48818 .31201 .50093 .30285 .49396 .28633 Mtetra
.69 .61 .762 r
.49396 .28633 .50093 .30285 .5137 .29412 .50673 .27847 Mtetra
.693 .621 .772 r
.50673 .27847 .5137 .29412 .52649 .28564 .51954 .27074 Mtetra
.695 .632 .781 r
.51954 .27074 .52649 .28564 .53931 .27734 .53238 .26316 Mtetra
.696 .642 .792 r
.53238 .26316 .53931 .27734 .55215 .26925 .54526 .25576 Mtetra
.697 .653 .802 r
.54526 .25576 .55215 .26925 .56504 .26141 .55817 .24859 Mtetra
.697 .664 .814 r
.55817 .24859 .56504 .26141 .57796 .25387 .57113 .24166 Mtetra
.695 .674 .825 r
.57113 .24166 .57796 .25387 .59092 .24663 .58414 .23501 Mtetra
.693 .684 .837 r
.58414 .23501 .59092 .24663 .60393 .23973 .5972 .22861 Mtetra
.691 .694 .848 r
.5972 .22861 .60393 .23973 .617 .23315 .61031 .22248 Mtetra
.687 .703 .859 r
.61031 .22248 .617 .23315 .63012 .22686 .62348 .21657 Mtetra
.684 .711 .868 r
.62348 .21657 .63012 .22686 .64329 .22086 .63671 .21087 Mtetra
.681 .717 .877 r
.63671 .21087 .64329 .22086 .65654 .21509 .65 .20535 Mtetra
.677 .723 .884 r
.65 .20535 .65654 .21509 .66984 .20952 .66336 .19998 Mtetra
.674 .727 .89 r
.66336 .19998 .66984 .20952 .68321 .20412 .67678 .19472 Mtetra
.672 .731 .894 r
.67678 .19472 .68321 .20412 .69665 .19885 .69027 .18955 Mtetra
.67 .734 .898 r
.69027 .18955 .69665 .19885 .71016 .19368 .70383 .18445 Mtetra
.668 .736 .901 r
.70383 .18445 .71016 .19368 .72373 .18858 .71745 .17939 Mtetra
.667 .738 .903 r
.71745 .17939 .72373 .18858 .73737 .18353 .73114 .17436 Mtetra
.666 .739 .904 r
.73114 .17436 .73737 .18353 .75108 .17852 .7449 .16934 Mtetra
.665 .74 .906 r
.7449 .16934 .75108 .17852 .76486 .17352 .75872 .16433 Mtetra
.75872 .16433 .76486 .17352 .77871 .16853 .77262 .15931 Mtetra
.664 .741 .907 r
.77262 .15931 .77871 .16853 .79262 .16353 .78658 .15429 Mtetra
.635 .738 .923 r
.15436 .37176 .16232 .379 .17341 .37559 .16546 .36852 Mtetra
.61 .737 .935 r
.16546 .36852 .17341 .37559 .18452 .37252 .17655 .36584 Mtetra
.555 .732 .958 r
.17655 .36584 .18452 .37252 .19563 .37003 .18759 .36417 Mtetra
.415 .704 .982 r
.18759 .36417 .19563 .37003 .20668 .36858 .19852 .36423 Mtetra
.014 .52 .866 r
.19852 .36423 .20668 .36858 .21764 .36888 .20925 .36701 Mtetra
.56 0 0 r
.20925 .36701 .21764 .36888 .22841 .37192 .2197 .37375 Mtetra
.75 .279 .128 r
.2197 .37375 .22841 .37192 .23894 .37891 .2298 .38567 Mtetra
.782 .385 .3 r
.2298 .38567 .23894 .37891 .24914 .39109 .23954 .40357 Mtetra
.782 .422 .375 r
.23954 .40357 .24914 .39109 .25903 .40923 .24899 .42725 Mtetra
.772 .431 .409 r
.24899 .42725 .25903 .40923 .26866 .43315 .25836 .45497 Mtetra
.757 .423 .418 r
.25836 .45497 .26866 .43315 .27824 .46116 .26797 .48329 Mtetra
.735 .396 .406 r
.26797 .48329 .27824 .46116 .28806 .48985 .27819 .5074 Mtetra
.689 .324 .349 r
.27819 .5074 .28806 .48985 .29845 .51445 .28931 .52232 Mtetra
.46 0 .021 r
.28931 .52232 .29845 .51445 .30969 .52999 .30149 .52438 Mtetra
.827 .832 .851 r
.30149 .52438 .30969 .52999 .3219 .53278 .31464 .51263 Mtetra
.798 .636 .681 r
.31464 .51263 .3219 .53278 .33501 .5218 .32849 .48915 Mtetra
.772 .577 .636 r
.32849 .48915 .33501 .5218 .34875 .49903 .34267 .45822 Mtetra
.753 .549 .621 r
.34267 .45822 .34875 .49903 .36278 .46867 .35683 .4248 Mtetra
.737 .534 .617 r
.35683 .4248 .36278 .46867 .37679 .43562 .37075 .3931 Mtetra
.724 .525 .622 r
.37075 .3931 .37679 .43562 .39058 .40408 .38433 .36572 Mtetra
.712 .523 .633 r
.38433 .36572 .39058 .40408 .40406 .37667 .39757 .34363 Mtetra
.701 .527 .65 r
.39757 .34363 .40406 .37667 .41725 .35438 .41055 .32651 Mtetra
.691 .538 .673 r
.41055 .32651 .41725 .35438 .43021 .33691 .42336 .31332 Mtetra
.685 .553 .699 r
.42336 .31332 .43021 .33691 .44303 .32327 .43608 .30285 Mtetra
.681 .571 .724 r
.43608 .30285 .44303 .32327 .45577 .31229 .44878 .29405 Mtetra
.681 .588 .745 r
.44878 .29405 .45577 .31229 .46849 .30291 .46147 .28614 Mtetra
.683 .604 .761 r
.46147 .28614 .46849 .30291 .48121 .29441 .47419 .27865 Mtetra
.686 .616 .773 r
.47419 .27865 .48121 .29441 .49396 .28633 .48695 .27134 Mtetra
.688 .627 .783 r
.48695 .27134 .49396 .28633 .50673 .27847 .49973 .26414 Mtetra
.691 .638 .792 r
.49973 .26414 .50673 .27847 .51954 .27074 .51256 .25704 Mtetra
.692 .648 .801 r
.51256 .25704 .51954 .27074 .53238 .26316 .52542 .25006 Mtetra
.693 .658 .811 r
.52542 .25006 .53238 .26316 .54526 .25576 .53833 .24325 Mtetra
.693 .668 .821 r
.53833 .24325 .54526 .25576 .55817 .24859 .55128 .23663 Mtetra
.692 .677 .832 r
.55128 .23663 .55817 .24859 .57113 .24166 .56428 .23021 Mtetra
.69 .687 .842 r
.56428 .23021 .57113 .24166 .58414 .23501 .57732 .22402 Mtetra
.688 .696 .852 r
.57732 .22402 .58414 .23501 .5972 .22861 .59043 .21803 Mtetra
.685 .704 .862 r
.59043 .21803 .5972 .22861 .61031 .22248 .60358 .21223 Mtetra
.682 .712 .871 r
.60358 .21223 .61031 .22248 .62348 .21657 .6168 .20661 Mtetra
.679 .718 .878 r
.6168 .20661 .62348 .21657 .63671 .21087 .63008 .20115 Mtetra
.676 .723 .885 r
.63008 .20115 .63671 .21087 .65 .20535 .64342 .1958 Mtetra
.674 .728 .89 r
.64342 .1958 .65 .20535 .66336 .19998 .65683 .19056 Mtetra
.671 .731 .895 r
.65683 .19056 .66336 .19998 .67678 .19472 .6703 .1854 Mtetra
.669 .734 .898 r
.6703 .1854 .67678 .19472 .69027 .18955 .68384 .18029 Mtetra
.668 .736 .901 r
.68384 .18029 .69027 .18955 .70383 .18445 .69744 .17523 Mtetra
.667 .738 .903 r
.69744 .17523 .70383 .18445 .71745 .17939 .71111 .17018 Mtetra
.666 .739 .904 r
.71111 .17018 .71745 .17939 .73114 .17436 .72485 .16515 Mtetra
.665 .74 .906 r
.72485 .16515 .73114 .17436 .7449 .16934 .73866 .16012 Mtetra
.73866 .16012 .7449 .16934 .75872 .16433 .75253 .15508 Mtetra
.664 .741 .907 r
.75253 .15508 .75872 .16433 .77262 .15931 .76648 .15004 Mtetra
.76648 .15004 .77262 .15931 .78658 .15429 .78049 .14497 Mtetra
.617 .739 .933 r
.14632 .36465 .15436 .37176 .16546 .36852 .1574 .36181 Mtetra
.565 .736 .956 r
.1574 .36181 .16546 .36852 .17655 .36584 .16842 .35994 Mtetra
.434 .712 .982 r
.16842 .35994 .17655 .36584 .18759 .36417 .17932 .35975 Mtetra
.05 .545 .885 r
.17932 .35975 .18759 .36417 .19852 .36423 .19001 .36224 Mtetra
.537 0 0 r
.19001 .36224 .19852 .36423 .20925 .36701 .20041 .36863 Mtetra
.744 .268 .115 r
.20041 .36863 .20925 .36701 .2197 .37375 .21042 .38013 Mtetra
.781 .38 .293 r
.21042 .38013 .2197 .37375 .2298 .38567 .22004 .39752 Mtetra
.782 .419 .37 r
.22004 .39752 .2298 .38567 .23954 .40357 .22934 .42057 Mtetra
.774 .43 .403 r
.22934 .42057 .23954 .40357 .24899 .42725 .23854 .44755 Mtetra
.76 .422 .412 r
.23854 .44755 .24899 .42725 .25836 .45497 .24798 .47502 Mtetra
.739 .394 .397 r
.24798 .47502 .25836 .45497 .26797 .48329 .25805 .49824 Mtetra
.692 .314 .326 r
.25805 .49824 .26797 .48329 .27819 .5074 .26907 .51228 Mtetra
.37 0 0 r
.26907 .51228 .27819 .5074 .28931 .52232 .28122 .51359 Mtetra
.805 .761 .811 r
.28122 .51359 .28931 .52232 .30149 .52438 .29441 .5013 Mtetra
.783 .615 .671 r
.29441 .5013 .30149 .52438 .31464 .51263 .30834 .47752 Mtetra
.763 .566 .632 r
.30834 .47752 .31464 .51263 .32849 .48915 .32264 .44654 Mtetra
.747 .542 .618 r
.32264 .44654 .32849 .48915 .34267 .45822 .33693 .41326 Mtetra
.733 .529 .616 r
.33693 .41326 .34267 .45822 .35683 .4248 .35095 .38184 Mtetra
.721 .522 .621 r
.35095 .38184 .35683 .4248 .37075 .3931 .3646 .35484 Mtetra
.71 .522 .633 r
.3646 .35484 .37075 .3931 .38433 .36572 .37789 .33318 Mtetra
.699 .528 .652 r
.37789 .33318 .38433 .36572 .39757 .34363 .39088 .31651 Mtetra
.69 .54 .677 r
.39088 .31651 .39757 .34363 .41055 .32651 .40368 .3038 Mtetra
.684 .557 .706 r
.40368 .3038 .41055 .32651 .42336 .31332 .41638 .29383 Mtetra
.679 .577 .733 r
.41638 .29383 .42336 .31332 .43608 .30285 .42904 .28553 Mtetra
.678 .596 .756 r
.42904 .28553 .43608 .30285 .44878 .29405 .4417 .27814 Mtetra
.68 .612 .773 r
.4417 .27814 .44878 .29405 .46147 .28614 .45439 .27116 Mtetra
.682 .625 .785 r
.45439 .27116 .46147 .28614 .47419 .27865 .46712 .26436 Mtetra
.684 .635 .794 r
.46712 .26436 .47419 .27865 .48695 .27134 .47988 .25763 Mtetra
.687 .645 .803 r
.47988 .25763 .48695 .27134 .49973 .26414 .49269 .25096 Mtetra
.688 .654 .811 r
.49269 .25096 .49973 .26414 .51256 .25704 .50553 .24437 Mtetra
.689 .663 .82 r
.50553 .24437 .51256 .25704 .52542 .25006 .51842 .23789 Mtetra
.689 .673 .829 r
.51842 .23789 .52542 .25006 .53833 .24325 .53136 .23156 Mtetra
.688 .682 .838 r
.53136 .23156 .53833 .24325 .55128 .23663 .54435 .22538 Mtetra
.687 .691 .848 r
.54435 .22538 .55128 .23663 .56428 .23021 .55738 .21937 Mtetra
.685 .699 .857 r
.55738 .21937 .56428 .23021 .57732 .22402 .57047 .21353 Mtetra
.682 .706 .866 r
.57047 .21353 .57732 .22402 .59043 .21803 .58361 .20785 Mtetra
.68 .713 .874 r
.58361 .20785 .59043 .21803 .60358 .21223 .59682 .20232 Mtetra
.677 .719 .881 r
.59682 .20232 .60358 .21223 .6168 .20661 .61008 .1969 Mtetra
.675 .724 .887 r
.61008 .1969 .6168 .20661 .63008 .20115 .6234 .1916 Mtetra
.673 .728 .892 r
.6234 .1916 .63008 .20115 .64342 .1958 .63679 .18638 Mtetra
.671 .731 .896 r
.63679 .18638 .64342 .1958 .65683 .19056 .65025 .18122 Mtetra
.669 .734 .899 r
.65025 .18122 .65683 .19056 .6703 .1854 .66377 .17611 Mtetra
.668 .736 .901 r
.66377 .17611 .6703 .1854 .68384 .18029 .67735 .17104 Mtetra
.666 .738 .903 r
.67735 .17104 .68384 .18029 .69744 .17523 .69101 .16598 Mtetra
.666 .739 .905 r
.69101 .16598 .69744 .17523 .71111 .17018 .70472 .16094 Mtetra
.665 .74 .906 r
.70472 .16094 .71111 .17018 .72485 .16515 .71851 .15589 Mtetra
.71851 .15589 .72485 .16515 .73866 .16012 .73237 .15083 Mtetra
.664 .74 .907 r
.73237 .15083 .73866 .16012 .75253 .15508 .74629 .14577 Mtetra
.664 .741 .907 r
.74629 .14577 .75253 .15508 .76648 .15004 .76028 .14068 Mtetra
.76028 .14068 .76648 .15004 .78049 .14497 .77434 .13558 Mtetra
.575 .738 .953 r
.13816 .35789 .14632 .36465 .1574 .36181 .14917 .35584 Mtetra
.453 .719 .982 r
.14917 .35584 .1574 .36181 .16842 .35994 .16005 .3554 Mtetra
.097 .574 .907 r
.16005 .3554 .16842 .35994 .17932 .35975 .17071 .35756 Mtetra
.502 0 0 r
.17071 .35756 .17932 .35975 .19001 .36224 .18106 .3635 Mtetra
.735 .25 .089 r
.18106 .3635 .19001 .36224 .20041 .36863 .19101 .3744 Mtetra
.778 .371 .279 r
.19101 .3744 .20041 .36863 .21042 .38013 .20054 .39099 Mtetra
.782 .414 .36 r
.20054 .39099 .21042 .38013 .22004 .39752 .20973 .41303 Mtetra
.775 .427 .395 r
.20973 .41303 .22004 .39752 .22934 .42057 .21882 .43882 Mtetra
.763 .419 .403 r
.21882 .43882 .22934 .42057 .23854 .44755 .22813 .46499 Mtetra
.743 .39 .382 r
.22813 .46499 .23854 .44755 .24798 .47502 .23809 .48692 Mtetra
.695 .298 .29 r
.23809 .48692 .24798 .47502 .25805 .49824 .24904 .49986 Mtetra
.175 0 0 r
.24904 .49986 .25805 .49824 .26907 .51228 .26115 .50042 Mtetra
.781 .704 .778 r
.26115 .50042 .26907 .51228 .28122 .51359 .27435 .48782 Mtetra
.769 .596 .664 r
.27435 .48782 .28122 .51359 .29441 .5013 .28834 .46417 Mtetra
.754 .557 .629 r
.28834 .46417 .29441 .5013 .30834 .47752 .30271 .43365 Mtetra
.741 .536 .617 r
.30271 .43365 .30834 .47752 .32264 .44654 .31708 .40105 Mtetra
.729 .525 .615 r
.31708 .40105 .32264 .44654 .33693 .41326 .33118 .37036 Mtetra
.718 .52 .621 r
.33118 .37036 .33693 .41326 .35095 .38184 .34488 .34408 Mtetra
.708 .521 .635 r
.34488 .34408 .35095 .38184 .3646 .35484 .35819 .32306 Mtetra
.698 .529 .655 r
.35819 .32306 .3646 .35484 .37789 .33318 .37119 .30696 Mtetra
.69 .543 .682 r
.37119 .30696 .37789 .33318 .39088 .31651 .38397 .29477 Mtetra
.683 .563 .713 r
.38397 .29477 .39088 .31651 .40368 .3038 .39664 .28527 Mtetra
.678 .585 .743 r
.39664 .28527 .40368 .3038 .41638 .29383 .40927 .27744 Mtetra
.676 .605 .768 r
.40927 .27744 .41638 .29383 .42904 .28553 .4219 .27049 Mtetra
.677 .621 .786 r
.4219 .27049 .42904 .28553 .4417 .27814 .43455 .26396 Mtetra
.679 .634 .798 r
.43455 .26396 .4417 .27814 .45439 .27116 .44725 .25759 Mtetra
.681 .644 .807 r
.44725 .25759 .45439 .27116 .46712 .26436 .45998 .25127 Mtetra
.683 .653 .814 r
.45998 .25127 .46712 .26436 .47988 .25763 .47276 .24498 Mtetra
.684 .662 .822 r
.47276 .24498 .47988 .25763 .49269 .25096 .48559 .23873 Mtetra
.685 .67 .829 r
.48559 .23873 .49269 .25096 .50553 .24437 .49846 .23256 Mtetra
.685 .678 .837 r
.49846 .23256 .50553 .24437 .51842 .23789 .51138 .22649 Mtetra
.685 .687 .846 r
.51138 .22649 .51842 .23789 .53136 .23156 .52435 .22054 Mtetra
.684 .695 .854 r
.52435 .22054 .53136 .23156 .54435 .22538 .53736 .21471 Mtetra
.682 .702 .862 r
.53736 .21471 .54435 .22538 .55738 .21937 .55044 .20902 Mtetra
.68 .709 .87 r
.55044 .20902 .55738 .21937 .57047 .21353 .56357 .20344 Mtetra
.678 .715 .877 r
.56357 .20344 .57047 .21353 .58361 .20785 .57675 .19799 Mtetra
.676 .721 .883 r
.57675 .19799 .58361 .20785 .59682 .20232 .59 .19263 Mtetra
.674 .725 .888 r
.59 .19263 .59682 .20232 .61008 .1969 .60331 .18736 Mtetra
.672 .729 .893 r
.60331 .18736 .61008 .1969 .6234 .1916 .61668 .18216 Mtetra
.67 .732 .896 r
.61668 .18216 .6234 .1916 .63679 .18638 .63012 .17702 Mtetra
.668 .734 .899 r
.63012 .17702 .63679 .18638 .65025 .18122 .64362 .17191 Mtetra
.667 .736 .902 r
.64362 .17191 .65025 .18122 .66377 .17611 .65718 .16683 Mtetra
.666 .738 .903 r
.65718 .16683 .66377 .17611 .67735 .17104 .67082 .16176 Mtetra
.665 .739 .905 r
.67082 .16176 .67735 .17104 .69101 .16598 .68451 .1567 Mtetra
.665 .74 .906 r
.68451 .1567 .69101 .16598 .70472 .16094 .69828 .15164 Mtetra
.664 .74 .906 r
.69828 .15164 .70472 .16094 .71851 .15589 .71212 .14656 Mtetra
.664 .741 .907 r
.71212 .14656 .71851 .15589 .73237 .15083 .72602 .14148 Mtetra
.72602 .14148 .73237 .15083 .74629 .14577 .73999 .13637 Mtetra
.73999 .13637 .74629 .14577 .76028 .14068 .75403 .13125 Mtetra
.664 .741 .908 r
.75403 .13125 .76028 .14068 .77434 .13558 .76814 .1261 Mtetra
.473 .726 .98 r
.12984 .35182 .13816 .35789 .14917 .35584 .1407 .35113 Mtetra
.152 .606 .931 r
.1407 .35113 .14917 .35584 .16005 .3554 .15134 .35291 Mtetra
.448 0 0 r
.15134 .35291 .16005 .3554 .17071 .35756 .16166 .35829 Mtetra
.721 .221 .049 r
.16166 .35829 .17071 .35756 .18106 .3635 .17158 .36841 Mtetra
.775 .357 .258 r
.17158 .36841 .18106 .3635 .19101 .3744 .18106 .38394 Mtetra
.782 .407 .345 r
.18106 .38394 .19101 .3744 .20054 .39099 .19019 .40463 Mtetra
.777 .421 .382 r
.19019 .40463 .20054 .39099 .20973 .41303 .1992 .42881 Mtetra
.767 .415 .388 r
.1992 .42881 .20973 .41303 .21882 .43882 .20845 .45325 Mtetra
.748 .383 .361 r
.20845 .45325 .21882 .43882 .22813 .46499 .21833 .47355 Mtetra
.696 .271 .235 r
.21833 .47355 .22813 .46499 .23809 .48692 .22923 .4852 Mtetra
.159 .685 .872 r
.22923 .4852 .23809 .48692 .24904 .49986 .2413 .48503 Mtetra
.759 .66 .753 r
.2413 .48503 .24904 .49986 .26115 .50042 .25449 .47236 Mtetra
.756 .58 .658 r
.25449 .47236 .26115 .50042 .27435 .48782 .2685 .44925 Mtetra
.745 .548 .628 r
.2685 .44925 .27435 .48782 .28834 .46417 .2829 .41969 Mtetra
.735 .531 .617 r
.2829 .41969 .28834 .46417 .30271 .43365 .29731 .38825 Mtetra
.725 .522 .616 r
.29731 .38825 .30271 .43365 .31708 .40105 .31143 .35873 Mtetra
.715 .519 .623 r
.31143 .35873 .31708 .40105 .33118 .37036 .32516 .33348 Mtetra
.706 .522 .637 r
.32516 .33348 .33118 .37036 .34488 .34408 .33847 .31333 Mtetra
.697 .531 .659 r
.33847 .31333 .34488 .34408 .35819 .32306 .35146 .29791 Mtetra
.689 .548 .688 r
.35146 .29791 .35819 .32306 .37119 .30696 .36423 .28627 Mtetra
.682 .57 .722 r
.36423 .28627 .37119 .30696 .38397 .29477 .37687 .27723 Mtetra
.678 .593 .754 r
.37687 .27723 .38397 .29477 .39664 .28527 .38946 .26981 Mtetra
.675 .615 .781 r
.38946 .26981 .39664 .28527 .40927 .27744 .40205 .26325 Mtetra
.675 .632 .799 r
.40205 .26325 .40927 .27744 .4219 .27049 .41467 .25708 Mtetra
.676 .645 .811 r
.41467 .25708 .4219 .27049 .43455 .26396 .42733 .25107 Mtetra
.678 .654 .82 r
.42733 .25107 .43455 .26396 .44725 .25759 .44003 .2451 Mtetra
.68 .662 .826 r
.44003 .2451 .44725 .25759 .45998 .25127 .45278 .23914 Mtetra
.681 .67 .833 r
.45278 .23914 .45998 .25127 .47276 .24498 .46558 .2332 Mtetra
.682 .677 .839 r
.46558 .2332 .47276 .24498 .48559 .23873 .47843 .2273 Mtetra
.682 .685 .846 r
.47843 .2273 .48559 .23873 .49846 .23256 .49133 .22147 Mtetra
.682 .692 .853 r
.49133 .22147 .49846 .23256 .51138 .22649 .50428 .21571 Mtetra
.681 .699 .861 r
.50428 .21571 .51138 .22649 .52435 .22054 .51728 .21005 Mtetra
.679 .706 .868 r
.51728 .21005 .52435 .22054 .53736 .21471 .53033 .20449 Mtetra
.678 .712 .874 r
.53033 .20449 .53736 .21471 .55044 .20902 .54344 .19902 Mtetra
.676 .717 .88 r
.54344 .19902 .55044 .20902 .56357 .20344 .55661 .19364 Mtetra
.674 .722 .886 r
.55661 .19364 .56357 .20344 .57675 .19799 .56984 .18834 Mtetra
.672 .726 .89 r
.56984 .18834 .57675 .19799 .59 .19263 .58313 .18311 Mtetra
.671 .73 .894 r
.58313 .18311 .59 .19263 .60331 .18736 .59649 .17793 Mtetra
.669 .733 .897 r
.59649 .17793 .60331 .18736 .61668 .18216 .6099 .17279 Mtetra
.668 .735 .9 r
.6099 .17279 .61668 .18216 .63012 .17702 .62338 .16769 Mtetra
.667 .737 .902 r
.62338 .16769 .63012 .17702 .64362 .17191 .63693 .1626 Mtetra
.666 .738 .904 r
.63693 .1626 .64362 .17191 .65718 .16683 .65054 .15752 Mtetra
.665 .739 .905 r
.65054 .15752 .65718 .16683 .67082 .16176 .66422 .15245 Mtetra
.665 .74 .906 r
.66422 .15245 .67082 .16176 .68451 .1567 .67797 .14737 Mtetra
.664 .74 .906 r
.67797 .14737 .68451 .1567 .69828 .15164 .69178 .14228 Mtetra
.664 .741 .907 r
.69178 .14228 .69828 .15164 .71212 .14656 .70566 .13717 Mtetra
.70566 .13717 .71212 .14656 .72602 .14148 .71961 .13205 Mtetra
.71961 .13205 .72602 .14148 .73999 .13637 .73363 .1269 Mtetra
.664 .741 .908 r
.73363 .1269 .73999 .13637 .75403 .13125 .74772 .12174 Mtetra
.74772 .12174 .75403 .13125 .76814 .1261 .76188 .11655 Mtetra
.215 .638 .953 r
.12128 .3469 .12984 .35182 .1407 .35113 .13192 .34825 Mtetra
.37 0 0 r
.13192 .34825 .1407 .35113 .15134 .35291 .14223 .35299 Mtetra
.697 .179 0 r
.14223 .35299 .15134 .35291 .16166 .35829 .15213 .36216 Mtetra
.769 .337 .225 r
.15213 .36216 .16166 .35829 .17158 .36841 .1616 .3764 Mtetra
.781 .394 .323 r
.1616 .3764 .17158 .36841 .18106 .38394 .17072 .39542 Mtetra
.779 .412 .363 r
.17072 .39542 .18106 .38394 .19019 .40463 .17972 .41765 Mtetra
.77 .407 .368 r
.17972 .41765 .19019 .40463 .1992 .42881 .18894 .44001 Mtetra
.753 .371 .33 r
.18894 .44001 .1992 .42881 .20845 .45325 .1988 .45839 Mtetra
.69 .227 .147 r
.1988 .45839 .20845 .45325 .21833 .47355 .20966 .46861 Mtetra
.425 .758 .995 r
.20966 .46861 .21833 .47355 .22923 .4852 .2217 .46776 Mtetra
.739 .627 .734 r
.2217 .46776 .22923 .4852 .2413 .48503 .23486 .45524 Mtetra
.744 .567 .655 r
.23486 .45524 .2413 .48503 .25449 .47236 .24883 .43303 Mtetra
.737 .541 .628 r
.24883 .43303 .25449 .47236 .2685 .44925 .26321 .40487 Mtetra
.729 .527 .618 r
.26321 .40487 .2685 .44925 .2829 .41969 .2776 .37502 Mtetra
.72 .52 .618 r
.2776 .37502 .2829 .41969 .29731 .38825 .29172 .34703 Mtetra
.712 .518 .626 r
.29172 .34703 .29731 .38825 .31143 .35873 .30543 .3231 Mtetra
.704 .523 .641 r
.30543 .3231 .31143 .35873 .32516 .33348 .31873 .30399 Mtetra
.696 .535 .665 r
.31873 .30399 .32516 .33348 .33847 .31333 .33169 .28937 Mtetra
.689 .554 .696 r
.33169 .28937 .33847 .31333 .35146 .29791 .34443 .2783 Mtetra
.682 .578 .732 r
.34443 .2783 .35146 .29791 .36423 .28627 .35704 .26972 Mtetra
.677 .604 .766 r
.35704 .26972 .36423 .28627 .37687 .27723 .36959 .26265 Mtetra
.674 .626 .794 r
.36959 .26265 .37687 .27723 .38946 .26981 .38214 .25642 Mtetra
.673 .644 .812 r
.38214 .25642 .38946 .26981 .40205 .26325 .39472 .25056 Mtetra
.674 .656 .824 r
.39472 .25056 .40205 .26325 .41467 .25708 .40735 .24485 Mtetra
.675 .665 .832 r
.40735 .24485 .41467 .25708 .42733 .25107 .42002 .23917 Mtetra
.677 .672 .838 r
.42002 .23917 .42733 .25107 .44003 .2451 .43274 .23348 Mtetra
.678 .679 .843 r
.43274 .23348 .44003 .2451 .45278 .23914 .44551 .2278 Mtetra
.679 .685 .849 r
.44551 .2278 .45278 .23914 .46558 .2332 .45834 .22213 Mtetra
.679 .691 .855 r
.45834 .22213 .46558 .2332 .47843 .2273 .47121 .2165 Mtetra
.679 .698 .861 r
.47121 .2165 .47843 .2273 .49133 .22147 .48414 .21092 Mtetra
.678 .704 .867 r
.48414 .21092 .49133 .22147 .50428 .21571 .49712 .20541 Mtetra
.677 .71 .873 r
.49712 .20541 .50428 .21571 .51728 .21005 .51015 .19996 Mtetra
.675 .715 .878 r
.51015 .19996 .51728 .21005 .53033 .20449 .52325 .19459 Mtetra
.674 .72 .884 r
.52325 .19459 .53033 .20449 .54344 .19902 .5364 .18928 Mtetra
.672 .724 .888 r
.5364 .18928 .54344 .19902 .55661 .19364 .54961 .18403 Mtetra
.671 .728 .892 r
.54961 .18403 .55661 .19364 .56984 .18834 .56288 .17883 Mtetra
.67 .731 .896 r
.56288 .17883 .56984 .18834 .58313 .18311 .57621 .17368 Mtetra
.668 .733 .899 r
.57621 .17368 .58313 .18311 .59649 .17793 .58961 .16855 Mtetra
.667 .735 .901 r
.58961 .16855 .59649 .17793 .6099 .17279 .60307 .16345 Mtetra
.666 .737 .903 r
.60307 .16345 .6099 .17279 .62338 .16769 .61659 .15835 Mtetra
.666 .738 .904 r
.61659 .15835 .62338 .16769 .63693 .1626 .63019 .15327 Mtetra
.665 .739 .905 r
.63019 .15327 .63693 .1626 .65054 .15752 .64384 .14818 Mtetra
.665 .74 .906 r
.64384 .14818 .65054 .15752 .66422 .15245 .65757 .14308 Mtetra
.664 .74 .907 r
.65757 .14308 .66422 .15245 .67797 .14737 .67136 .13797 Mtetra
.664 .741 .907 r
.67136 .13797 .67797 .14737 .69178 .14228 .68522 .13285 Mtetra
.68522 .13285 .69178 .14228 .70566 .13717 .69915 .1277 Mtetra
.664 .741 .908 r
.69915 .1277 .70566 .13717 .71961 .13205 .71315 .12254 Mtetra
.71315 .12254 .71961 .13205 .73363 .1269 .72722 .11735 Mtetra
.72722 .11735 .73363 .1269 .74772 .12174 .74135 .11214 Mtetra
.74135 .11214 .74772 .12174 .76188 .11655 .75556 .1069 Mtetra
.265 0 0 r
.11243 .34358 .12128 .3469 .13192 .34825 .12275 .3476 Mtetra
.659 .117 0 r
.12275 .3476 .13192 .34825 .14223 .35299 .13267 .35569 Mtetra
.758 .306 .178 r
.13267 .35569 .14223 .35299 .15213 .36216 .14216 .36843 Mtetra
.778 .376 .291 r
.14216 .36843 .15213 .36216 .1616 .3764 .15132 .38555 Mtetra
.779 .399 .336 r
.15132 .38555 .1616 .3764 .17072 .39542 .16035 .40553 Mtetra
.772 .394 .339 r
.16035 .40553 .17072 .39542 .17972 .41765 .1696 .42555 Mtetra
.756 .351 .285 r
.1696 .42555 .17972 .41765 .18894 .44001 .17948 .44182 Mtetra
.664 .147 .001 r
.17948 .44182 .18894 .44001 .1988 .45839 .19033 .45052 Mtetra
.536 .713 .953 r
.19033 .45052 .1988 .45839 .20966 .46861 .20233 .44903 Mtetra
.723 .602 .722 r
.20233 .44903 .20966 .46861 .2217 .46776 .21543 .43687 Mtetra
.733 .556 .654 r
.21543 .43687 .2217 .46776 .23486 .45524 .22933 .41585 Mtetra
.729 .535 .629 r
.22933 .41585 .23486 .45524 .24883 .43303 .24363 .38944 Mtetra
.723 .524 .62 r
.24363 .38944 .24883 .43303 .26321 .40487 .25796 .36153 Mtetra
.716 .518 .621 r
.25796 .36153 .26321 .40487 .2776 .37502 .27202 .33537 Mtetra
.709 .519 .629 r
.27202 .33537 .2776 .37502 .29172 .34703 .28568 .31299 Mtetra
.702 .525 .646 r
.28568 .31299 .29172 .34703 .30543 .3231 .29895 .29508 Mtetra
.695 .539 .671 r
.29895 .29508 .30543 .3231 .31873 .30399 .31188 .28132 Mtetra
.689 .561 .705 r
.31188 .28132 .31873 .30399 .33169 .28937 .32457 .27086 Mtetra
.682 .587 .743 r
.32457 .27086 .33169 .28937 .34443 .2783 .33714 .2627 Mtetra
.677 .615 .778 r
.33714 .2627 .34443 .2783 .35704 .26972 .34966 .25597 Mtetra
.673 .638 .807 r
.34966 .25597 .35704 .26972 .36959 .26265 .36218 .25 Mtetra
.672 .655 .826 r
.36218 .25 .36959 .26265 .38214 .25642 .37472 .2444 Mtetra
.672 .667 .837 r
.37472 .2444 .38214 .25642 .39472 .25056 .38731 .23892 Mtetra
.673 .675 .844 r
.38731 .23892 .39472 .25056 .40735 .24485 .39994 .23347 Mtetra
.674 .682 .849 r
.39994 .23347 .40735 .24485 .42002 .23917 .41263 .22801 Mtetra
.675 .687 .854 r
.41263 .22801 .42002 .23917 .43274 .23348 .42538 .22254 Mtetra
.676 .693 .858 r
.42538 .22254 .43274 .23348 .44551 .2278 .43817 .21706 Mtetra
.676 .698 .863 r
.43817 .21706 .44551 .2278 .45834 .22213 .45102 .21161 Mtetra
.676 .704 .868 r
.45102 .21161 .45834 .22213 .47121 .2165 .46393 .20618 Mtetra
.675 .709 .873 r
.46393 .20618 .47121 .2165 .48414 .21092 .47689 .20079 Mtetra
.674 .714 .878 r
.47689 .20079 .48414 .21092 .49712 .20541 .4899 .19545 Mtetra
.673 .718 .883 r
.4899 .19545 .49712 .20541 .51015 .19996 .50297 .19016 Mtetra
.672 .722 .887 r
.50297 .19016 .51015 .19996 .52325 .19459 .5161 .18492 Mtetra
.671 .726 .891 r
.5161 .18492 .52325 .19459 .5364 .18928 .52929 .17971 Mtetra
.67 .729 .894 r
.52929 .17971 .5364 .18928 .54961 .18403 .54254 .17454 Mtetra
.669 .732 .897 r
.54254 .17454 .54961 .18403 .56288 .17883 .55585 .16941 Mtetra
.668 .734 .9 r
.55585 .16941 .56288 .17883 .57621 .17368 .56923 .16429 Mtetra
.667 .736 .902 r
.56923 .16429 .57621 .17368 .58961 .16855 .58267 .15918 Mtetra
.666 .737 .903 r
.58267 .15918 .58961 .16855 .60307 .16345 .59617 .15409 Mtetra
.665 .738 .905 r
.59617 .15409 .60307 .16345 .61659 .15835 .60975 .14899 Mtetra
.665 .739 .905 r
.60975 .14899 .61659 .15835 .63019 .15327 .62338 .14389 Mtetra
.664 .74 .906 r
.62338 .14389 .63019 .15327 .64384 .14818 .63709 .13877 Mtetra
.664 .74 .907 r
.63709 .13877 .64384 .14818 .65757 .14308 .65086 .13365 Mtetra
.664 .741 .907 r
.65086 .13365 .65757 .14308 .67136 .13797 .6647 .1285 Mtetra
.6647 .1285 .67136 .13797 .68522 .13285 .6786 .12334 Mtetra
.664 .741 .908 r
.6786 .12334 .68522 .13285 .69915 .1277 .69258 .11815 Mtetra
.69258 .11815 .69915 .1277 .71315 .12254 .70663 .11294 Mtetra
.70663 .11294 .71315 .12254 .72722 .11735 .72074 .10771 Mtetra
.72074 .10771 .72722 .11735 .74135 .11214 .73493 .10245 Mtetra
.73493 .10245 .74135 .11214 .75556 .1069 .74919 .09717 Mtetra
.597 .028 0 r
.10323 .34213 .11243 .34358 .12275 .3476 .11319 .34905 Mtetra
.739 .261 .109 r
.11319 .34905 .12275 .3476 .13267 .35569 .12275 .36016 Mtetra
.772 .349 .245 r
.12275 .36016 .13267 .35569 .14216 .36843 .13198 .37519 Mtetra
.778 .379 .297 r
.13198 .37519 .14216 .36843 .15132 .38555 .1411 .39275 Mtetra
.773 .373 .296 r
.1411 .39275 .15132 .38555 .16035 .40553 .15042 .41025 Mtetra
.754 .318 .217 r
.15042 .41025 .16035 .40553 .1696 .42555 .16035 .42428 Mtetra
.578 .003 0 r
.16035 .42428 .1696 .42555 .17948 .44182 .17121 .43142 Mtetra
.578 .663 .896 r
.17121 .43142 .17948 .44182 .19033 .45052 .18317 .42937 Mtetra
.709 .584 .713 r
.18317 .42937 .19033 .45052 .20233 .44903 .19618 .41771 Mtetra
.723 .549 .654 r
.19618 .41771 .20233 .44903 .21543 .43687 .20997 .39812 Mtetra
.722 .531 .631 r
.20997 .39812 .21543 .43687 .22933 .41585 .22415 .37371 Mtetra
.718 .522 .623 r
.22415 .37371 .22933 .41585 .24363 .38944 .23836 .34798 Mtetra
.712 .518 .625 r
.23836 .34798 .24363 .38944 .25796 .36153 .25233 .32388 Mtetra
.706 .52 .635 r
.25233 .32388 .25796 .36153 .27202 .33537 .26592 .3032 Mtetra
.7 .529 .653 r
.26592 .3032 .27202 .33537 .28568 .31299 .27912 .28659 Mtetra
.694 .545 .68 r
.27912 .28659 .28568 .31299 .29895 .29508 .292 .27375 Mtetra
.688 .569 .715 r
.292 .27375 .29895 .29508 .31188 .28132 .30465 .26391 Mtetra
.683 .598 .755 r
.30465 .26391 .31188 .28132 .32457 .27086 .31718 .25617 Mtetra
.677 .627 .791 r
.31718 .25617 .32457 .27086 .33714 .2627 .32966 .24972 Mtetra
.673 .65 .82 r
.32966 .24972 .33714 .2627 .34966 .25597 .34214 .24399 Mtetra
.67 .667 .838 r
.34214 .24399 .34966 .25597 .36218 .25 .35464 .23858 Mtetra
.67 .678 .849 r
.35464 .23858 .36218 .25 .37472 .2444 .3672 .23329 Mtetra
.671 .686 .855 r
.3672 .23329 .37472 .2444 .38731 .23892 .3798 .22802 Mtetra
.672 .691 .86 r
.3798 .22802 .38731 .23892 .39994 .23347 .39246 .22274 Mtetra
.673 .696 .863 r
.39246 .22274 .39994 .23347 .41263 .22801 .40517 .21743 Mtetra
.673 .7 .867 r
.40517 .21743 .41263 .22801 .42538 .22254 .41794 .21212 Mtetra
.673 .705 .871 r
.41794 .21212 .42538 .22254 .43817 .21706 .43076 .2068 Mtetra
.673 .709 .875 r
.43076 .2068 .43817 .21706 .45102 .21161 .44364 .2015 Mtetra
.673 .713 .879 r
.44364 .2015 .45102 .21161 .46393 .20618 .45658 .19622 Mtetra
.672 .718 .883 r
.45658 .19622 .46393 .20618 .47689 .20079 .46957 .19097 Mtetra
.672 .721 .887 r
.46957 .19097 .47689 .20079 .4899 .19545 .48262 .18575 Mtetra
.671 .725 .89 r
.48262 .18575 .4899 .19545 .50297 .19016 .49573 .18055 Mtetra
.67 .728 .893 r
.49573 .18055 .50297 .19016 .5161 .18492 .50889 .17539 Mtetra
.669 .731 .896 r
.50889 .17539 .5161 .18492 .52929 .17971 .52212 .17025 Mtetra
.668 .733 .899 r
.52212 .17025 .52929 .17971 .54254 .17454 .53541 .16512 Mtetra
.667 .735 .901 r
.53541 .16512 .54254 .17454 .55585 .16941 .54877 .16001 Mtetra
.666 .737 .902 r
.54877 .16001 .55585 .16941 .56923 .16429 .56219 .15491 Mtetra
.666 .738 .904 r
.56219 .15491 .56923 .16429 .58267 .15918 .57567 .1498 Mtetra
.665 .739 .905 r
.57567 .1498 .58267 .15918 .59617 .15409 .58922 .1447 Mtetra
.665 .739 .906 r
.58922 .1447 .59617 .15409 .60975 .14899 .60284 .13958 Mtetra
.664 .74 .906 r
.60284 .13958 .60975 .14899 .62338 .14389 .61652 .13445 Mtetra
.664 .74 .907 r
.61652 .13445 .62338 .14389 .63709 .13877 .63027 .12931 Mtetra
.664 .741 .907 r
.63027 .12931 .63709 .13877 .65086 .13365 .64409 .12414 Mtetra
.64409 .12414 .65086 .13365 .6647 .1285 .65797 .11896 Mtetra
.664 .741 .908 r
.65797 .11896 .6647 .1285 .6786 .12334 .67193 .11375 Mtetra
.67193 .11375 .6786 .12334 .69258 .11815 .68595 .10852 Mtetra
.68595 .10852 .69258 .11815 .70663 .11294 .70004 .10327 Mtetra
.70004 .10327 .70663 .11294 .72074 .10771 .71421 .09799 Mtetra
.71421 .09799 .72074 .10771 .73493 .10245 .72844 .09268 Mtetra
.72844 .09268 .73493 .10245 .74919 .09717 .74275 .08735 Mtetra
.705 .193 .01 r
.09368 .34231 .10323 .34213 .11319 .34905 .10333 .35171 Mtetra
.759 .308 .179 r
.10333 .35171 .11319 .34905 .12275 .36016 .11268 .36456 Mtetra
.772 .347 .241 r
.11268 .36456 .12275 .36016 .13198 .37519 .12192 .3796 Mtetra
.769 .34 .234 r
.12192 .3796 .13198 .37519 .1411 .39275 .13137 .39451 Mtetra
.74 .262 .11 r
.13137 .39451 .1411 .39275 .15042 .41025 .14138 .40626 Mtetra
.364 0 0 r
.14138 .40626 .15042 .41025 .16035 .42428 .15226 .41187 Mtetra
.596 .628 .853 r
.15226 .41187 .16035 .42428 .17121 .43142 .16418 .40931 Mtetra
.698 .571 .709 r
.16418 .40931 .17121 .43142 .18317 .42937 .17709 .39828 Mtetra
.714 .543 .657 r
.17709 .39828 .18317 .42937 .19618 .41771 .19073 .38026 Mtetra
.715 .528 .635 r
.19073 .38026 .19618 .41771 .20997 .39812 .20475 .358 Mtetra
.713 .521 .628 r
.20475 .358 .20997 .39812 .22415 .37371 .2188 .3346 Mtetra
.708 .519 .631 r
.2188 .3346 .22415 .37371 .23836 .34798 .23263 .31266 Mtetra
.704 .523 .642 r
.23263 .31266 .23836 .34798 .25233 .32388 .24611 .29378 Mtetra
.699 .534 .661 r
.24611 .29378 .25233 .32388 .26592 .3032 .25923 .27852 Mtetra
.694 .553 .69 r
.25923 .27852 .26592 .3032 .27912 .28659 .27205 .26663 Mtetra
.688 .579 .727 r
.27205 .26663 .27912 .28659 .292 .27375 .28465 .25741 Mtetra
.683 .609 .768 r
.28465 .25741 .292 .27375 .30465 .26391 .29714 .25006 Mtetra
.677 .639 .804 r
.29714 .25006 .30465 .26391 .31718 .25617 .30958 .24388 Mtetra
.672 .662 .832 r
.30958 .24388 .31718 .25617 .32966 .24972 .32202 .23833 Mtetra
.669 .679 .85 r
.32202 .23833 .32966 .24972 .34214 .24399 .33449 .23307 Mtetra
.669 .689 .86 r
.33449 .23307 .34214 .24399 .35464 .23858 .34701 .22793 Mtetra
.669 .695 .866 r
.34701 .22793 .35464 .23858 .3672 .23329 .35958 .2228 Mtetra
.67 .7 .869 r
.35958 .2228 .3672 .23329 .3798 .22802 .37221 .21765 Mtetra
.671 .704 .872 r
.37221 .21765 .3798 .22802 .39246 .22274 .38489 .21248 Mtetra
.671 .707 .875 r
.38489 .21248 .39246 .22274 .40517 .21743 .39763 .20729 Mtetra
.671 .711 .878 r
.39763 .20729 .40517 .21743 .41794 .21212 .41043 .20209 Mtetra
.671 .714 .881 r
.41043 .20209 .41794 .21212 .43076 .2068 .42328 .19688 Mtetra
.671 .718 .884 r
.42328 .19688 .43076 .2068 .44364 .2015 .43619 .19169 Mtetra
.671 .721 .887 r
.43619 .19169 .44364 .2015 .45658 .19622 .44916 .18651 Mtetra
.67 .725 .89 r
.44916 .18651 .45658 .19622 .46957 .19097 .46218 .18134 Mtetra
.669 .727 .893 r
.46218 .18134 .46957 .19097 .48262 .18575 .47527 .1762 Mtetra
.668 .73 .896 r
.47527 .1762 .48262 .18575 .49573 .18055 .48842 .17106 Mtetra
.668 .732 .898 r
.48842 .17106 .49573 .18055 .50889 .17539 .50162 .16594 Mtetra
.667 .734 .9 r
.50162 .16594 .50889 .17539 .52212 .17025 .51489 .16083 Mtetra
.666 .736 .902 r
.51489 .16083 .52212 .17025 .53541 .16512 .52823 .15572 Mtetra
.666 .737 .903 r
.52823 .15572 .53541 .16512 .54877 .16001 .54162 .15062 Mtetra
.665 .738 .904 r
.54162 .15062 .54877 .16001 .56219 .15491 .55509 .1455 Mtetra
.665 .739 .905 r
.55509 .1455 .56219 .15491 .57567 .1498 .56861 .14039 Mtetra
.664 .74 .906 r
.56861 .14039 .57567 .1498 .58922 .1447 .58221 .13525 Mtetra
.664 .74 .907 r
.58221 .13525 .58922 .1447 .60284 .13958 .59587 .13011 Mtetra
.59587 .13011 .60284 .13958 .61652 .13445 .60959 .12494 Mtetra
.664 .741 .907 r
.60959 .12494 .61652 .13445 .63027 .12931 .62339 .11976 Mtetra
.62339 .11976 .63027 .12931 .64409 .12414 .63725 .11456 Mtetra
.664 .741 .908 r
.63725 .11456 .64409 .12414 .65797 .11896 .65119 .10933 Mtetra
.65119 .10933 .65797 .11896 .67193 .11375 .66519 .10408 Mtetra
.66519 .10408 .67193 .11375 .68595 .10852 .67926 .0988 Mtetra
.67926 .0988 .68595 .10852 .70004 .10327 .6934 .0935 Mtetra
.6934 .0935 .70004 .10327 .71421 .09799 .70762 .08817 Mtetra
.70762 .08817 .71421 .09799 .72844 .09268 .7219 .08282 Mtetra
.7219 .08282 .72844 .09268 .74275 .08735 .73626 .07744 Mtetra
.732 .243 .08 r
.08391 .34323 .09368 .34231 .10333 .35171 .0934 .35388 Mtetra
.756 .296 .157 r
.0934 .35388 .10333 .35171 .11268 .36456 .1028 .36639 Mtetra
.753 .285 .138 r
.1028 .36639 .11268 .36456 .12192 .3796 .1124 .37872 Mtetra
.692 .161 0 r
.1124 .37872 .12192 .3796 .13137 .39451 .12251 .38824 Mtetra
0 .438 .843 r
.12251 .38824 .13137 .39451 .14138 .40626 .13343 .39237 Mtetra
.605 .606 .826 r
.13343 .39237 .14138 .40626 .15226 .41187 .14531 .38938 Mtetra
.689 .564 .709 r
.14531 .38938 .15226 .41187 .16418 .40931 .15809 .37905 Mtetra
.706 .54 .661 r
.15809 .37905 .16418 .40931 .17709 .39828 .17156 .36266 Mtetra
.71 .528 .641 r
.17156 .36266 .17709 .39828 .19073 .38026 .18538 .3426 Mtetra
.708 .522 .635 r
.18538 .3426 .19073 .38026 .20475 .358 .19924 .32158 Mtetra
.705 .522 .639 r
.19924 .32158 .20475 .358 .2188 .3346 .21291 .30184 Mtetra
.701 .528 .651 r
.21291 .30184 .2188 .3346 .23263 .31266 .22626 .28478 Mtetra
.697 .541 .672 r
.22626 .28478 .23263 .31266 .24611 .29378 .23928 .27088 Mtetra
.693 .562 .702 r
.23928 .27088 .24611 .29378 .25923 .27852 .25203 .25993 Mtetra
.688 .59 .741 r
.25203 .25993 .25923 .27852 .27205 .26663 .26458 .25132 Mtetra
.682 .622 .781 r
.26458 .25132 .27205 .26663 .28465 .25741 .27702 .24434 Mtetra
.676 .651 .817 r
.27702 .24434 .28465 .25741 .29714 .25006 .28942 .23839 Mtetra
.671 .674 .844 r
.28942 .23839 .29714 .25006 .30958 .24388 .30182 .23299 Mtetra
.669 .689 .86 r
.30182 .23299 .30958 .24388 .32202 .23833 .31426 .22786 Mtetra
.667 .698 .869 r
.31426 .22786 .32202 .23833 .33449 .23307 .32675 .22282 Mtetra
.668 .704 .874 r
.32675 .22282 .33449 .23307 .34701 .22793 .33929 .21779 Mtetra
.668 .708 .877 r
.33929 .21779 .34701 .22793 .35958 .2228 .35188 .21274 Mtetra
.669 .711 .88 r
.35188 .21274 .35958 .2228 .37221 .21765 .36454 .20767 Mtetra
.669 .714 .882 r
.36454 .20767 .37221 .21765 .38489 .21248 .37725 .20257 Mtetra
.669 .717 .884 r
.37725 .20257 .38489 .21248 .39763 .20729 .39002 .19746 Mtetra
.669 .719 .886 r
.39002 .19746 .39763 .20729 .41043 .20209 .40284 .19233 Mtetra
.669 .722 .889 r
.40284 .19233 .41043 .20209 .42328 .19688 .41573 .18721 Mtetra
.669 .725 .891 r
.41573 .18721 .42328 .19688 .43619 .19169 .42867 .18208 Mtetra
.669 .727 .894 r
.42867 .18208 .43619 .19169 .44916 .18651 .44167 .17696 Mtetra
.668 .73 .896 r
.44167 .17696 .44916 .18651 .46218 .18134 .45473 .17185 Mtetra
.667 .732 .898 r
.45473 .17185 .46218 .18134 .47527 .1762 .46786 .16674 Mtetra
.667 .734 .9 r
.46786 .16674 .47527 .1762 .48842 .17106 .48104 .16163 Mtetra
.666 .735 .901 r
.48104 .16163 .48842 .17106 .50162 .16594 .49429 .15653 Mtetra
.666 .737 .903 r
.49429 .15653 .50162 .16594 .51489 .16083 .5076 .15142 Mtetra
.665 .738 .904 r
.5076 .15142 .51489 .16083 .52823 .15572 .52097 .14631 Mtetra
.665 .739 .905 r
.52097 .14631 .52823 .15572 .54162 .15062 .53441 .14119 Mtetra
.665 .739 .906 r
.53441 .14119 .54162 .15062 .55509 .1455 .54792 .13606 Mtetra
.664 .74 .906 r
.54792 .13606 .55509 .1455 .56861 .14039 .56149 .13091 Mtetra
.664 .74 .907 r
.56149 .13091 .56861 .14039 .58221 .13525 .57513 .12575 Mtetra
.664 .741 .907 r
.57513 .12575 .58221 .13525 .59587 .13011 .58883 .12057 Mtetra
.58883 .12057 .59587 .13011 .60959 .12494 .60261 .11536 Mtetra
.664 .741 .908 r
.60261 .11536 .60959 .12494 .62339 .11976 .61645 .11014 Mtetra
.61645 .11014 .62339 .11976 .63725 .11456 .63036 .10489 Mtetra
.63036 .10489 .63725 .11456 .65119 .10933 .64434 .09962 Mtetra
.64434 .09962 .65119 .10933 .66519 .10408 .65839 .09432 Mtetra
.65839 .09432 .66519 .10408 .67926 .0988 .67251 .08899 Mtetra
.67251 .08899 .67926 .0988 .6934 .0935 .6867 .08364 Mtetra
.6867 .08364 .6934 .0935 .70762 .08817 .70096 .07827 Mtetra
.70096 .07827 .70762 .08817 .7219 .08282 .71529 .07286 Mtetra
.71529 .07286 .7219 .08282 .73626 .07744 .7297 .06743 Mtetra
.719 .213 .028 r
.07411 .34335 .08391 .34323 .0934 .35388 .08369 .35342 Mtetra
.71 .192 0 r
.08369 .35342 .0934 .35388 .1028 .36639 .09345 .36326 Mtetra
.568 0 0 r
.09345 .36326 .1028 .36639 .1124 .37872 .10369 .37065 Mtetra
.214 .55 .931 r
.10369 .37065 .1124 .37872 .12251 .38824 .11466 .37339 Mtetra
.612 .595 .809 r
.11466 .37339 .12251 .38824 .13343 .39237 .12649 .37005 Mtetra
.681 .56 .711 r
.12649 .37005 .13343 .39237 .14531 .38938 .13914 .36044 Mtetra
.7 .54 .668 r
.13914 .36044 .14531 .38938 .15809 .37905 .15241 .34567 Mtetra
.704 .529 .649 r
.15241 .34567 .15809 .37905 .17156 .36266 .16602 .3278 Mtetra
.704 .525 .644 r
.16602 .3278 .17156 .36266 .18538 .3426 .17967 .30911 Mtetra
.702 .527 .648 r
.17967 .30911 .18538 .3426 .19924 .32158 .19315 .29152 Mtetra
.699 .535 .662 r
.19315 .29152 .19924 .32158 .21291 .30184 .20636 .27623 Mtetra
.695 .55 .684 r
.20636 .27623 .21291 .30184 .22626 .28478 .21926 .26366 Mtetra
.692 .573 .716 r
.21926 .26366 .22626 .28478 .23928 .27088 .23192 .25361 Mtetra
.687 .602 .755 r
.23192 .25361 .23928 .27088 .25203 .25993 .24441 .24558 Mtetra
.682 .634 .796 r
.24441 .24558 .25203 .25993 .26458 .25132 .25681 .23895 Mtetra
.676 .663 .83 r
.25681 .23895 .26458 .25132 .27702 .24434 .26917 .2332 Mtetra
.671 .685 .855 r
.26917 .2332 .27702 .24434 .28942 .23839 .28154 .22793 Mtetra
.668 .699 .87 r
.28154 .22793 .28942 .23839 .30182 .23299 .29395 .22288 Mtetra
.667 .707 .878 r
.29395 .22288 .30182 .23299 .31426 .22786 .3064 .21792 Mtetra
.666 .712 .882 r
.3064 .21792 .31426 .22786 .32675 .22282 .31891 .21296 Mtetra
.667 .715 .884 r
.31891 .21296 .32675 .22282 .33929 .21779 .33148 .20799 Mtetra
.667 .717 .886 r
.33148 .20799 .33929 .21779 .35188 .21274 .3441 .20299 Mtetra
.668 .719 .887 r
.3441 .20299 .35188 .21274 .36454 .20767 .35678 .19796 Mtetra
.668 .721 .889 r
.35678 .19796 .36454 .20767 .37725 .20257 .36952 .19291 Mtetra
.668 .724 .891 r
.36952 .19291 .37725 .20257 .39002 .19746 .38232 .18784 Mtetra
.668 .726 .893 r
.38232 .18784 .39002 .19746 .40284 .19233 .39518 .18276 Mtetra
.668 .728 .895 r
.39518 .18276 .40284 .19233 .41573 .18721 .4081 .17768 Mtetra
.667 .73 .896 r
.4081 .17768 .41573 .18721 .42867 .18208 .42108 .1726 Mtetra
.667 .732 .898 r
.42108 .1726 .42867 .18208 .44167 .17696 .43411 .16751 Mtetra
.667 .734 .9 r
.43411 .16751 .44167 .17696 .45473 .17185 .44721 .16241 Mtetra
.666 .735 .901 r
.44721 .16241 .45473 .17185 .46786 .16674 .46038 .15732 Mtetra
.666 .736 .903 r
.46038 .15732 .46786 .16674 .48104 .16163 .4736 .15222 Mtetra
.665 .737 .904 r
.4736 .15222 .48104 .16163 .49429 .15653 .48689 .14711 Mtetra
.665 .738 .905 r
.48689 .14711 .49429 .15653 .5076 .15142 .50024 .14199 Mtetra
.665 .739 .905 r
.50024 .14199 .5076 .15142 .52097 .14631 .51366 .13686 Mtetra
.664 .74 .906 r
.51366 .13686 .52097 .14631 .53441 .14119 .52714 .13171 Mtetra
.664 .74 .907 r
.52714 .13171 .53441 .14119 .54792 .13606 .54069 .12655 Mtetra
.54069 .12655 .54792 .13606 .56149 .13091 .5543 .12137 Mtetra
.664 .741 .907 r
.5543 .12137 .56149 .13091 .57513 .12575 .56798 .11617 Mtetra
.56798 .11617 .57513 .12575 .58883 .12057 .58173 .11095 Mtetra
.664 .741 .908 r
.58173 .11095 .58883 .12057 .60261 .11536 .59555 .1057 Mtetra
.59555 .1057 .60261 .11536 .61645 .11014 .60944 .10043 Mtetra
.60944 .10043 .61645 .11014 .63036 .10489 .6234 .09514 Mtetra
.6234 .09514 .63036 .10489 .64434 .09962 .63743 .08982 Mtetra
.63743 .08982 .64434 .09962 .65839 .09432 .65152 .08447 Mtetra
.65152 .08447 .65839 .09432 .67251 .08899 .66569 .0791 Mtetra
.66569 .0791 .67251 .08899 .6867 .08364 .67993 .0737 Mtetra
.67993 .0737 .6867 .08364 .70096 .07827 .69424 .06827 Mtetra
.69424 .06827 .70096 .07827 .71529 .07286 .70863 .06282 Mtetra
.70863 .06282 .71529 .07286 .7297 .06743 .72309 .05734 Mtetra
.605 .034 0 r
.06456 .34092 .07411 .34335 .08369 .35342 .0745 .34844 Mtetra
0 .251 .639 r
.0745 .34844 .08369 .35342 .09345 .36326 .08486 .35385 Mtetra
.367 .592 .932 r
.08486 .35385 .09345 .36326 .10369 .37065 .09588 .35533 Mtetra
.617 .59 .801 r
.09588 .35533 .10369 .37065 .11466 .37339 .10766 .3517 Mtetra
.676 .56 .717 r
.10766 .3517 .11466 .37339 .12649 .37005 .12018 .3428 Mtetra
.694 .543 .677 r
.12018 .3428 .12649 .37005 .13914 .36044 .13325 .3296 Mtetra
.7 .533 .659 r
.13325 .3296 .13914 .36044 .15241 .34567 .14662 .3138 Mtetra
.7 .53 .654 r
.14662 .3138 .15241 .34567 .16602 .3278 .16005 .29732 Mtetra
.699 .533 .66 r
.16005 .29732 .16602 .3278 .17967 .30911 .17333 .28177 Mtetra
.697 .543 .675 r
.17333 .28177 .17967 .30911 .19315 .29152 .18638 .26816 Mtetra
.694 .56 .699 r
.18638 .26816 .19315 .29152 .20636 .27623 .19916 .25684 Mtetra
.691 .585 .732 r
.19916 .25684 .20636 .27623 .21926 .26366 .21174 .24765 Mtetra
.687 .616 .771 r
.21174 .24765 .21926 .26366 .23192 .25361 .22416 .24015 Mtetra
.681 .647 .81 r
.22416 .24015 .23192 .25361 .24441 .24558 .23651 .23384 Mtetra
.675 .675 .842 r
.23651 .23384 .24441 .24558 .25681 .23895 .24884 .22827 Mtetra
.67 .695 .864 r
.24884 .22827 .25681 .23895 .26917 .2332 .26117 .2231 Mtetra
.667 .707 .877 r
.26117 .2231 .26917 .2332 .28154 .22793 .27355 .21812 Mtetra
.666 .714 .885 r
.27355 .21812 .28154 .22793 .29395 .22288 .28597 .21321 Mtetra
.666 .718 .888 r
.28597 .21321 .29395 .22288 .3064 .21792 .29845 .2083 Mtetra
.666 .721 .89 r
.29845 .2083 .3064 .21792 .31891 .21296 .31099 .20337 Mtetra
.666 .723 .891 r
.31099 .20337 .31891 .21296 .33148 .20799 .32358 .19842 Mtetra
.666 .724 .892 r
.32358 .19842 .33148 .20799 .3441 .20299 .33624 .19344 Mtetra
.667 .726 .893 r
.33624 .19344 .3441 .20299 .35678 .19796 .34895 .18843 Mtetra
.667 .727 .895 r
.34895 .18843 .35678 .19796 .36952 .19291 .36172 .1834 Mtetra
.667 .729 .896 r
.36172 .1834 .36952 .19291 .38232 .18784 .37455 .17836 Mtetra
.667 .731 .898 r
.37455 .17836 .38232 .18784 .39518 .18276 .38745 .17331 Mtetra
.666 .732 .899 r
.38745 .17331 .39518 .18276 .4081 .17768 .4004 .16825 Mtetra
.666 .734 .9 r
.4004 .16825 .4081 .17768 .42108 .1726 .41341 .16317 Mtetra
.666 .735 .901 r
.41341 .16317 .42108 .1726 .43411 .16751 .42649 .15809 Mtetra
.665 .736 .903 r
.42649 .15809 .43411 .16751 .44721 .16241 .43963 .153 Mtetra
.665 .737 .904 r
.43963 .153 .44721 .16241 .46038 .15732 .45283 .1479 Mtetra
.665 .738 .905 r
.45283 .1479 .46038 .15732 .4736 .15222 .46609 .14278 Mtetra
.665 .739 .905 r
.46609 .14278 .4736 .15222 .48689 .14711 .47942 .13766 Mtetra
.664 .739 .906 r
.47942 .13766 .48689 .14711 .50024 .14199 .49281 .13251 Mtetra
.664 .74 .906 r
.49281 .13251 .50024 .14199 .51366 .13686 .50627 .12735 Mtetra
.664 .74 .907 r
.50627 .12735 .51366 .13686 .52714 .13171 .5198 .12217 Mtetra
.664 .741 .907 r
.5198 .12217 .52714 .13171 .54069 .12655 .53339 .11698 Mtetra
.53339 .11698 .54069 .12655 .5543 .12137 .54705 .11176 Mtetra
.54705 .11176 .5543 .12137 .56798 .11617 .56078 .10651 Mtetra
.664 .741 .908 r
.56078 .10651 .56798 .11617 .58173 .11095 .57457 .10125 Mtetra
.57457 .10125 .58173 .11095 .59555 .1057 .58844 .09595 Mtetra
.58844 .09595 .59555 .1057 .60944 .10043 .60237 .09064 Mtetra
.60237 .09064 .60944 .10043 .6234 .09514 .61637 .08529 Mtetra
.61637 .08529 .6234 .09514 .63743 .08982 .63045 .07993 Mtetra
.63045 .07993 .63743 .08982 .65152 .08447 .64459 .07453 Mtetra
.64459 .07453 .65152 .08447 .66569 .0791 .65881 .06911 Mtetra
.65881 .06911 .66569 .0791 .67993 .0737 .6731 .06366 Mtetra
.6731 .06366 .67993 .0737 .69424 .06827 .68746 .05818 Mtetra
.68746 .05818 .69424 .06827 .70863 .06282 .7019 .05267 Mtetra
.7019 .05267 .70863 .06282 .72309 .05734 .71641 .04714 Mtetra
0 .464 .864 r
.05547 .3345 .06456 .34092 .0745 .34844 .06597 .33812 Mtetra
.456 .611 .915 r
.06597 .33812 .0745 .34844 .08486 .35385 .07704 .33848 Mtetra
.622 .592 .799 r
.07704 .33848 .08486 .35385 .09588 .35533 .08878 .3346 Mtetra
.672 .565 .726 r
.08878 .3346 .09588 .35533 .10766 .3517 .10115 .32639 Mtetra
.689 .548 .688 r
.10115 .32639 .10766 .3517 .12018 .3428 .11402 .31464 Mtetra
.696 .54 .671 r
.11402 .31464 .12018 .3428 .13325 .3296 .12716 .30075 Mtetra
.697 .538 .668 r
.12716 .30075 .13325 .3296 .14662 .3138 .14035 .28631 Mtetra
.697 .543 .674 r
.14035 .28631 .14662 .3138 .16005 .29732 .15343 .27265 Mtetra
.695 .554 .69 r
.15343 .27265 .16005 .29732 .17333 .28177 .16631 .26058 Mtetra
.693 .573 .716 r
.16631 .26058 .17333 .28177 .18638 .26816 .17898 .25041 Mtetra
.69 .599 .75 r
.17898 .25041 .18638 .26816 .19916 .25684 .19146 .242 Mtetra
.685 .63 .788 r
.19146 .242 .19916 .25684 .21174 .24765 .20382 .235 Mtetra
.68 .66 .824 r
.20382 .235 .21174 .24765 .22416 .24015 .21613 .22897 Mtetra
.674 .686 .853 r
.21613 .22897 .22416 .24015 .23651 .23384 .22841 .22355 Mtetra
.669 .703 .873 r
.22841 .22355 .23651 .23384 .24884 .22827 .24072 .21846 Mtetra
.666 .714 .884 r
.24072 .21846 .24884 .22827 .26117 .2231 .25306 .21352 Mtetra
.665 .72 .89 r
.25306 .21352 .26117 .2231 .27355 .21812 .26545 .20864 Mtetra
.665 .724 .893 r
.26545 .20864 .27355 .21812 .28597 .21321 .2779 .20377 Mtetra
.665 .726 .895 r
.2779 .20377 .28597 .21321 .29845 .2083 .29041 .19887 Mtetra
.665 .727 .895 r
.29041 .19887 .29845 .2083 .31099 .20337 .30298 .19394 Mtetra
.666 .728 .896 r
.30298 .19394 .31099 .20337 .32358 .19842 .3156 .18899 Mtetra
.666 .729 .897 r
.3156 .18899 .32358 .19842 .33624 .19344 .32829 .18401 Mtetra
.666 .731 .898 r
.32829 .18401 .33624 .19344 .34895 .18843 .34104 .17901 Mtetra
.666 .732 .899 r
.34104 .17901 .34895 .18843 .36172 .1834 .35384 .174 Mtetra
.666 .733 .9 r
.35384 .174 .36172 .1834 .37455 .17836 .36671 .16896 Mtetra
.666 .734 .901 r
.36671 .16896 .37455 .17836 .38745 .17331 .37964 .16391 Mtetra
.665 .735 .902 r
.37964 .16391 .38745 .17331 .4004 .16825 .39263 .15884 Mtetra
.665 .736 .903 r
.39263 .15884 .4004 .16825 .41341 .16317 .40568 .15377 Mtetra
.665 .737 .904 r
.40568 .15377 .41341 .16317 .42649 .15809 .41879 .14867 Mtetra
.665 .738 .905 r
.41879 .14867 .42649 .15809 .43963 .153 .43197 .14357 Mtetra
.665 .739 .905 r
.43197 .14357 .43963 .153 .45283 .1479 .44521 .13845 Mtetra
.664 .739 .906 r
.44521 .13845 .45283 .1479 .46609 .14278 .45851 .13331 Mtetra
.664 .74 .906 r
.45851 .13331 .46609 .14278 .47942 .13766 .47188 .12815 Mtetra
.664 .74 .907 r
.47188 .12815 .47942 .13766 .49281 .13251 .48532 .12298 Mtetra
.48532 .12298 .49281 .13251 .50627 .12735 .49882 .11778 Mtetra
.664 .741 .907 r
.49882 .11778 .50627 .12735 .5198 .12217 .51239 .11256 Mtetra
.51239 .11256 .5198 .12217 .53339 .11698 .52603 .10732 Mtetra
.664 .741 .908 r
.52603 .10732 .53339 .11698 .54705 .11176 .53973 .10206 Mtetra
.53973 .10206 .54705 .11176 .56078 .10651 .5535 .09677 Mtetra
.5535 .09677 .56078 .10651 .57457 .10125 .56734 .09146 Mtetra
.56734 .09146 .57457 .10125 .58844 .09595 .58125 .08612 Mtetra
.58125 .08612 .58844 .09595 .60237 .09064 .59523 .08075 Mtetra
.59523 .08075 .60237 .09064 .61637 .08529 .60929 .07536 Mtetra
.60929 .07536 .61637 .08529 .63045 .07993 .62341 .06994 Mtetra
.62341 .06994 .63045 .07993 .64459 .07453 .6376 .0645 Mtetra
.6376 .0645 .64459 .07453 .65881 .06911 .65187 .05902 Mtetra
.65187 .05902 .65881 .06911 .6731 .06366 .66621 .05352 Mtetra
.66621 .05352 .6731 .06366 .68746 .05818 .68062 .04799 Mtetra
.68062 .04799 .68746 .05818 .7019 .05267 .6951 .04244 Mtetra
.6951 .04244 .7019 .05267 .71641 .04714 .70966 .03685 Mtetra
.512 .624 .899 r
.04697 .32364 .05547 .3345 .06597 .33812 .05808 .32301 Mtetra
.626 .598 .801 r
.05808 .32301 .06597 .33812 .07704 .33848 .06978 .31895 Mtetra
.669 .572 .737 r
.06978 .31895 .07704 .33848 .08878 .3346 .08202 .31137 Mtetra
.686 .556 .702 r
.08202 .31137 .08878 .3346 .10115 .32639 .09469 .30093 Mtetra
.692 .549 .686 r
.09469 .30093 .10115 .32639 .11402 .31464 .1076 .28876 Mtetra
.695 .548 .683 r
.1076 .28876 .11402 .31464 .12716 .30075 .12056 .27615 Mtetra
.695 .554 .691 r
.12056 .27615 .12716 .30075 .14035 .28631 .13344 .26417 Mtetra
.693 .567 .708 r
.13344 .26417 .14035 .28631 .15343 .27265 .14616 .25349 Mtetra
.692 .588 .735 r
.14616 .25349 .15343 .27265 .16631 .26058 .1587 .24435 Mtetra
.688 .615 .768 r
.1587 .24435 .16631 .26058 .17898 .25041 .17109 .23664 Mtetra
.684 .645 .805 r
.17109 .23664 .17898 .25041 .19146 .242 .18339 .23006 Mtetra
.678 .673 .838 r
.18339 .23006 .19146 .242 .20382 .235 .19565 .22428 Mtetra
.673 .696 .863 r
.19565 .22428 .20382 .235 .21613 .22897 .2079 .21899 Mtetra
.668 .711 .88 r
.2079 .21899 .21613 .22897 .22841 .22355 .22017 .21396 Mtetra
.666 .72 .89 r
.22017 .21396 .22841 .22355 .24072 .21846 .23248 .20906 Mtetra
.665 .725 .895 r
.23248 .20906 .24072 .21846 .25306 .21352 .24485 .2042 Mtetra
.664 .728 .897 r
.24485 .2042 .25306 .21352 .26545 .20864 .25727 .19934 Mtetra
.664 .73 .898 r
.25727 .19934 .26545 .20864 .2779 .20377 .26975 .19445 Mtetra
.665 .731 .899 r
.26975 .19445 .2779 .20377 .29041 .19887 .28229 .18954 Mtetra
.28229 .18954 .29041 .19887 .30298 .19394 .29489 .18461 Mtetra
.665 .732 .9 r
.29489 .18461 .30298 .19394 .3156 .18899 .30755 .17965 Mtetra
.665 .733 .9 r
.30755 .17965 .3156 .18899 .32829 .18401 .32027 .17466 Mtetra
.665 .734 .901 r
.32027 .17466 .32829 .18401 .34104 .17901 .33305 .16965 Mtetra
.665 .735 .902 r
.33305 .16965 .34104 .17901 .35384 .174 .34589 .16463 Mtetra
.665 .736 .903 r
.34589 .16463 .35384 .174 .36671 .16896 .35879 .15958 Mtetra
.665 .737 .903 r
.35879 .15958 .36671 .16896 .37964 .16391 .37176 .15452 Mtetra
.665 .737 .904 r
.37176 .15452 .37964 .16391 .39263 .15884 .38478 .14944 Mtetra
.665 .738 .905 r
.38478 .14944 .39263 .15884 .40568 .15377 .39787 .14434 Mtetra
.664 .739 .905 r
.39787 .14434 .40568 .15377 .41879 .14867 .41102 .13923 Mtetra
.664 .739 .906 r
.41102 .13923 .41879 .14867 .43197 .14357 .42424 .1341 Mtetra
.664 .74 .906 r
.42424 .1341 .43197 .14357 .44521 .13845 .43752 .12895 Mtetra
.664 .74 .907 r
.43752 .12895 .44521 .13845 .45851 .13331 .45087 .12378 Mtetra
.45087 .12378 .45851 .13331 .47188 .12815 .46428 .11858 Mtetra
.664 .741 .907 r
.46428 .11858 .47188 .12815 .48532 .12298 .47776 .11337 Mtetra
.47776 .11337 .48532 .12298 .49882 .11778 .4913 .10813 Mtetra
.4913 .10813 .49882 .11778 .51239 .11256 .50491 .10287 Mtetra
.664 .741 .908 r
.50491 .10287 .51239 .11256 .52603 .10732 .51859 .09759 Mtetra
.51859 .09759 .52603 .10732 .53973 .10206 .53234 .09228 Mtetra
.53234 .09228 .53973 .10206 .5535 .09677 .54616 .08694 Mtetra
.54616 .08694 .5535 .09677 .56734 .09146 .56005 .08158 Mtetra
.56005 .08158 .56734 .09146 .58125 .08612 .574 .07619 Mtetra
.574 .07619 .58125 .08612 .59523 .08075 .58803 .07078 Mtetra
.58803 .07078 .59523 .08075 .60929 .07536 .60213 .06534 Mtetra
.60213 .06534 .60929 .07536 .62341 .06994 .6163 .05987 Mtetra
.6163 .05987 .62341 .06994 .6376 .0645 .63054 .05437 Mtetra
.63054 .05437 .6376 .0645 .65187 .05902 .64486 .04885 Mtetra
.64486 .04885 .65187 .05902 .66621 .05352 .65925 .04329 Mtetra
.65925 .04329 .66621 .05352 .68062 .04799 .67371 .03771 Mtetra
.67371 .03771 .68062 .04799 .6951 .04244 .68825 .0321 Mtetra
.68825 .0321 .6951 .04244 .70966 .03685 .70286 .02646 Mtetra
.631 .607 .807 r
.03897 .30903 .04697 .32364 .05808 .32301 .05062 .30482 Mtetra
.667 .583 .751 r
.05062 .30482 .05808 .32301 .06978 .31895 .06274 .29781 Mtetra
.683 .568 .719 r
.06274 .29781 .06978 .31895 .08202 .31137 .07522 .28852 Mtetra
.69 .561 .704 r
.07522 .28852 .08202 .31137 .09469 .30093 .08791 .27786 Mtetra
.692 .561 .702 r
.08791 .27786 .09469 .30093 .1076 .28876 .10066 .26685 Mtetra
.693 .568 .71 r
.10066 .26685 .1076 .28876 .12056 .27615 .11334 .25634 Mtetra
.692 .583 .728 r
.11334 .25634 .12056 .27615 .13344 .26417 .1259 .24687 Mtetra
.69 .604 .755 r
.1259 .24687 .13344 .26417 .14616 .25349 .13832 .23863 Mtetra
.687 .631 .787 r
.13832 .23863 .14616 .25349 .1587 .24435 .15063 .23152 Mtetra
.682 .659 .821 r
.15063 .23152 .1587 .24435 .17109 .23664 .16287 .22531 Mtetra
.677 .685 .85 r
.16287 .22531 .17109 .23664 .18339 .23006 .17508 .21974 Mtetra
.671 .704 .872 r
.17508 .21974 .18339 .23006 .19565 .22428 .18729 .21455 Mtetra
.668 .718 .886 r
.18729 .21455 .19565 .22428 .2079 .21899 .19953 .20958 Mtetra
.665 .725 .894 r
.19953 .20958 .2079 .21899 .22017 .21396 .21182 .2047 Mtetra
.664 .729 .898 r
.21182 .2047 .22017 .21396 .23248 .20906 .22416 .19984 Mtetra
.664 .732 .9 r
.22416 .19984 .23248 .20906 .24485 .2042 .23655 .19499 Mtetra
.664 .733 .901 r
.23655 .19499 .24485 .2042 .25727 .19934 .249 .19011 Mtetra
.249 .19011 .25727 .19934 .26975 .19445 .26152 .1852 Mtetra
.664 .734 .902 r
.26152 .1852 .26975 .19445 .28229 .18954 .27409 .18027 Mtetra
.665 .735 .902 r
.27409 .18027 .28229 .18954 .29489 .18461 .28672 .17532 Mtetra
.28672 .17532 .29489 .18461 .30755 .17965 .29941 .17034 Mtetra
.665 .736 .903 r
.29941 .17034 .30755 .17965 .32027 .17466 .31217 .16533 Mtetra
.31217 .16533 .32027 .17466 .33305 .16965 .32498 .16031 Mtetra
.665 .737 .904 r
.32498 .16031 .33305 .16965 .34589 .16463 .33786 .15526 Mtetra
.665 .738 .905 r
.33786 .15526 .34589 .16463 .35879 .15958 .3508 .1502 Mtetra
.664 .738 .905 r
.3508 .1502 .35879 .15958 .37176 .15452 .3638 .14511 Mtetra
.664 .739 .905 r
.3638 .14511 .37176 .15452 .38478 .14944 .37686 .14001 Mtetra
.664 .739 .906 r
.37686 .14001 .38478 .14944 .39787 .14434 .38999 .13488 Mtetra
.664 .74 .906 r
.38999 .13488 .39787 .14434 .41102 .13923 .40318 .12974 Mtetra
.664 .74 .907 r
.40318 .12974 .41102 .13923 .42424 .1341 .41644 .12457 Mtetra
.41644 .12457 .42424 .1341 .43752 .12895 .42976 .11938 Mtetra
.664 .741 .907 r
.42976 .11938 .43752 .12895 .45087 .12378 .44315 .11417 Mtetra
.44315 .11417 .45087 .12378 .46428 .11858 .4566 .10894 Mtetra
.4566 .10894 .46428 .11858 .47776 .11337 .47012 .10368 Mtetra
.664 .741 .908 r
.47012 .10368 .47776 .11337 .4913 .10813 .48371 .0984 Mtetra
.48371 .0984 .4913 .10813 .50491 .10287 .49737 .0931 Mtetra
.49737 .0931 .50491 .10287 .51859 .09759 .51109 .08777 Mtetra
.51109 .08777 .51859 .09759 .53234 .09228 .52489 .08241 Mtetra
.52489 .08241 .53234 .09228 .54616 .08694 .53875 .07703 Mtetra
.53875 .07703 .54616 .08694 .56005 .08158 .55268 .07161 Mtetra
.55268 .07161 .56005 .08158 .574 .07619 .56669 .06618 Mtetra
.56669 .06618 .574 .07619 .58803 .07078 .58076 .06071 Mtetra
.58076 .06071 .58803 .07078 .60213 .06534 .59491 .05522 Mtetra
.59491 .05522 .60213 .06534 .6163 .05987 .60913 .0497 Mtetra
.60913 .0497 .6163 .05987 .63054 .05437 .62342 .04415 Mtetra
.62342 .04415 .63054 .05437 .64486 .04885 .63778 .03857 Mtetra
.63778 .03857 .64486 .04885 .65925 .04329 .65222 .03297 Mtetra
.65222 .03297 .65925 .04329 .67371 .03771 .66673 .02733 Mtetra
.66673 .02733 .67371 .03771 .68825 .0321 .68132 .02167 Mtetra
.68132 .02167 .68825 .0321 .70286 .02646 .69599 .01598 Mtetra
.666 .596 .767 r
.03128 .29222 .03897 .30903 .05062 .30482 .04328 .2857 Mtetra
.681 .582 .738 r
.04328 .2857 .05062 .30482 .06274 .29781 .05559 .2774 Mtetra
.688 .576 .724 r
.05559 .2774 .06274 .29781 .07522 .28852 .06808 .26803 Mtetra
.69 .577 .723 r
.06808 .26803 .07522 .28852 .08791 .27786 .08062 .25838 Mtetra
.691 .585 .732 r
.08062 .25838 .08791 .27786 .10066 .26685 .09313 .24913 Mtetra
.69 .6 .75 r
.09313 .24913 .10066 .26685 .11334 .25634 .10554 .24069 Mtetra
.688 .622 .776 r
.10554 .24069 .11334 .25634 .1259 .24687 .11785 .2332 Mtetra
.685 .647 .806 r
.11785 .2332 .1259 .24687 .13832 .23863 .13008 .22661 Mtetra
.68 .673 .836 r
.13008 .22661 .13832 .23863 .15063 .23152 .14226 .22072 Mtetra
.675 .695 .862 r
.14226 .22072 .15063 .23152 .16287 .22531 .15442 .21532 Mtetra
.67 .712 .88 r
.15442 .21532 .16287 .22531 .17508 .21974 .1666 .21022 Mtetra
.667 .723 .891 r
.1666 .21022 .17508 .21974 .18729 .21455 .17881 .20528 Mtetra
.665 .729 .897 r
.17881 .20528 .18729 .21455 .19953 .20958 .19106 .20041 Mtetra
.664 .733 .901 r
.19106 .20041 .19953 .20958 .21182 .2047 .20337 .19556 Mtetra
.664 .734 .902 r
.20337 .19556 .21182 .2047 .22416 .19984 .21574 .19069 Mtetra
.664 .735 .903 r
.21574 .19069 .22416 .19984 .23655 .19499 .22817 .18581 Mtetra
.664 .736 .903 r
.22817 .18581 .23655 .19499 .249 .19011 .24065 .18091 Mtetra
.24065 .18091 .249 .19011 .26152 .1852 .2532 .17598 Mtetra
.664 .736 .904 r
.2532 .17598 .26152 .1852 .27409 .18027 .26581 .17102 Mtetra
.664 .737 .904 r
.26581 .17102 .27409 .18027 .28672 .17532 .27847 .16604 Mtetra
.27847 .16604 .28672 .17532 .29941 .17034 .2912 .16103 Mtetra
.664 .738 .905 r
.2912 .16103 .29941 .17034 .31217 .16533 .30399 .156 Mtetra
.30399 .156 .31217 .16533 .32498 .16031 .31684 .15095 Mtetra
.664 .739 .905 r
.31684 .15095 .32498 .16031 .33786 .15526 .32976 .14587 Mtetra
.664 .739 .906 r
.32976 .14587 .33786 .15526 .3508 .1502 .34273 .14078 Mtetra
.34273 .14078 .3508 .1502 .3638 .14511 .35577 .13566 Mtetra
.664 .74 .906 r
.35577 .13566 .3638 .14511 .37686 .14001 .36887 .13052 Mtetra
.664 .74 .907 r
.36887 .13052 .37686 .14001 .38999 .13488 .38204 .12536 Mtetra
.38204 .12536 .38999 .13488 .40318 .12974 .39527 .12018 Mtetra
.664 .741 .907 r
.39527 .12018 .40318 .12974 .41644 .12457 .40857 .11498 Mtetra
.40857 .11498 .41644 .12457 .42976 .11938 .42193 .10975 Mtetra
.42193 .10975 .42976 .11938 .44315 .11417 .43536 .1045 Mtetra
.664 .741 .908 r
.43536 .1045 .44315 .11417 .4566 .10894 .44886 .09922 Mtetra
.44886 .09922 .4566 .10894 .47012 .10368 .46242 .09392 Mtetra
.46242 .09392 .47012 .10368 .48371 .0984 .47605 .08859 Mtetra
.47605 .08859 .48371 .0984 .49737 .0931 .48975 .08324 Mtetra
.48975 .08324 .49737 .0931 .51109 .08777 .50352 .07786 Mtetra
.50352 .07786 .51109 .08777 .52489 .08241 .51736 .07245 Mtetra
.51736 .07245 .52489 .08241 .53875 .07703 .53127 .06702 Mtetra
.53127 .06702 .53875 .07703 .55268 .07161 .54525 .06156 Mtetra
.54525 .06156 .55268 .07161 .56669 .06618 .5593 .05607 Mtetra
.5593 .05607 .56669 .06618 .58076 .06071 .57342 .05055 Mtetra
.57342 .05055 .58076 .06071 .59491 .05522 .58762 .04501 Mtetra
.58762 .04501 .59491 .05522 .60913 .0497 .60188 .03943 Mtetra
.60188 .03943 .60913 .0497 .62342 .04415 .61623 .03383 Mtetra
.61623 .03383 .62342 .04415 .63778 .03857 .63064 .0282 Mtetra
.63064 .0282 .63778 .03857 .65222 .03297 .64513 .02254 Mtetra
.64513 .02254 .65222 .03297 .66673 .02733 .65969 .01685 Mtetra
.65969 .01685 .66673 .02733 .68132 .02167 .67433 .01113 Mtetra
.67433 .01113 .68132 .02167 .69599 .01598 .68905 .00539 Mtetra
0 g
.68874 0 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.68874 0 m
.03716 .25514 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 0.522676 0.477324 0.97619 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.49505 0.5 0.49505 [
[ 0 0 -0.125 0 ]
[ 0 0 -0.125 0 ]
[ 0 1 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
0 0 m
1 0 L
s
0 0 m
0 1 L
s
0 1 m
1 1 L
s
1 0 m
1 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
1 .5 0 r
.015 w
.03175 .1355 Mdot
.03435 .12523 Mdot
.11137 .12765 Mdot
.14107 .18841 Mdot
.16218 .24538 Mdot
.17294 .21053 Mdot
.18267 .18577 Mdot
.18434 .1304 Mdot
.18553 .30956 Mdot
.20401 .239 Mdot
.21247 .27571 Mdot
.21687 .20845 Mdot
.22376 .2799 Mdot
.22832 .27485 Mdot
.29063 .20974 Mdot
.29686 .25079 Mdot
.30487 .22936 Mdot
.30683 .34623 Mdot
.32055 .20902 Mdot
.32574 .21979 Mdot
.34472 .28521 Mdot
.35998 .36393 Mdot
.36335 .24976 Mdot
.3794 .36608 Mdot
.42386 .66992 Mdot
.44391 .74519 Mdot
.45059 .34198 Mdot
.47208 .67586 Mdot
.47436 .71381 Mdot
.49778 .59825 Mdot
.50874 .91643 Mdot
.51516 .76219 Mdot
.53655 .61374 Mdot
.56563 .75219 Mdot
.59189 .65665 Mdot
.59581 .61604 Mdot
.59923 .6556 Mdot
.60292 .68499 Mdot
.62656 .67779 Mdot
.63555 .72451 Mdot
.63919 .652 Mdot
.64169 .6004 Mdot
.64246 .58611 Mdot
.64496 .54267 Mdot
.64608 .77288 Mdot
.65077 .64308 Mdot
.66065 .57816 Mdot
.67474 .59169 Mdot
.69296 .563 Mdot
.72815 .65902 Mdot
.73169 .58879 Mdot
.74669 .61318 Mdot
.74821 .65474 Mdot
.75963 .63781 Mdot
.79673 .57809 Mdot
.80925 .55852 Mdot
.81525 .58444 Mdot
.83417 .62985 Mdot
.83598 .55526 Mdot
.91595 .49319 Mdot
0 0 1 r
.005 w
.13523 .13221 m
.14458 .13523 L
.16128 .13852 L
.18734 .15373 L
.20207 .16128 L
.21339 .16878 L
.23945 .18731 L
.23949 .18734 L
.2655 .20617 L
.27475 .21339 L
.29156 .22672 L
.30634 .23945 L
.31761 .24898 L
.33517 .2655 L
.34367 .27298 L
.36165 .29156 L
.36972 .29883 L
.38581 .31761 L
.39578 .32705 L
.40731 .34367 L
.42183 .36475 L
.42523 .36972 L
.4417 .39578 L
.43862 .42183 L
.42183 .42718 L
.39851 .42183 L
.39578 .42084 L
.36972 .41048 L
.346 .39578 L
.34367 .39481 L
.31761 .37794 L
.30565 .36972 L
.29156 .35957 L
.27125 .34367 L
.2655 .3392 L
.24048 .31761 L
.23945 .31681 L
.21339 .293 L
.2119 .29156 L
.18734 .26739 L
.18557 .2655 L
.16162 .23945 L
.16128 .23898 L
.13972 .21339 L
.13523 .20647 L
.12137 .18734 L
.10955 .16128 L
.11168 .13523 L
.13523 .13221 L
s
.44789 .41113 m
.47394 .40667 L
.5 .40755 L
.52606 .41235 L
.55211 .42041 L
.55609 .42183 L
.57817 .43131 L
.60422 .4451 L
.60897 .44789 L
.63028 .46169 L
.64696 .47394 L
.65633 .48144 L
.67729 .5 L
.68239 .50488 L
.70235 .52606 L
.70844 .53309 L
.72311 .55211 L
.7345 .56885 L
.73995 .57817 L
.75305 .60422 L
.76055 .62312 L
.76213 .63028 L
.76676 .65633 L
.7656 .68239 L
.76055 .69909 L
.7558 .70844 L
.7345 .7296 L
.72735 .7345 L
.70844 .73974 L
.68239 .74254 L
.65633 .74048 L
.63028 .73472 L
.62941 .7345 L
.60422 .72593 L
.57817 .71418 L
.56714 .70844 L
.55211 .69967 L
.52638 .68239 L
.52606 .68215 L
.5 .66148 L
.49417 .65633 L
.47394 .63687 L
.46775 .63028 L
.44789 .60686 L
.44588 .60422 L
.42792 .57817 L
.42183 .5683 L
.41377 .55211 L
.4035 .52606 L
.39758 .5 L
Mistroke
.39694 .47394 L
.40375 .44789 L
.42183 .42453 L
.42524 .42183 L
.44789 .41113 L
Mfstroke
0 g
.03 w
.27425 .27943 Mdot
.58177 .57452 Mdot
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.522676 0.522676 0.97619 0.97619 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.49505 0.5 0.49505 [
[ 0 0 -0.125 0 ]
[ 0 0 -0.125 0 ]
[ 0 1 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
0 0 m
1 0 L
s
0 0 m
0 1 L
s
0 1 m
1 1 L
s
1 0 m
1 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
1 .5 0 r
.015 w
.03175 .1355 Mdot
.03435 .12523 Mdot
.11137 .12765 Mdot
.14107 .18841 Mdot
.16218 .24538 Mdot
.17294 .21053 Mdot
.18267 .18577 Mdot
.18434 .1304 Mdot
.18553 .30956 Mdot
.20401 .239 Mdot
.21247 .27571 Mdot
.21687 .20845 Mdot
.22376 .2799 Mdot
.22832 .27485 Mdot
.29063 .20974 Mdot
.29686 .25079 Mdot
.30487 .22936 Mdot
.30683 .34623 Mdot
.32055 .20902 Mdot
.32574 .21979 Mdot
.34472 .28521 Mdot
.35998 .36393 Mdot
.36335 .24976 Mdot
.3794 .36608 Mdot
.42386 .66992 Mdot
.44391 .74519 Mdot
.45059 .34198 Mdot
.47208 .67586 Mdot
.47436 .71381 Mdot
.49778 .59825 Mdot
.50874 .91643 Mdot
.51516 .76219 Mdot
.53655 .61374 Mdot
.56563 .75219 Mdot
.59189 .65665 Mdot
.59581 .61604 Mdot
.59923 .6556 Mdot
.60292 .68499 Mdot
.62656 .67779 Mdot
.63555 .72451 Mdot
.63919 .652 Mdot
.64169 .6004 Mdot
.64246 .58611 Mdot
.64496 .54267 Mdot
.64608 .77288 Mdot
.65077 .64308 Mdot
.66065 .57816 Mdot
.67474 .59169 Mdot
.69296 .563 Mdot
.72815 .65902 Mdot
.73169 .58879 Mdot
.74669 .61318 Mdot
.74821 .65474 Mdot
.75963 .63781 Mdot
.79673 .57809 Mdot
.80925 .55852 Mdot
.81525 .58444 Mdot
.83417 .62985 Mdot
.83598 .55526 Mdot
.91595 .49319 Mdot
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{400, 400},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40006@0001T2000`400?l00000o`00003ooooooonA
ooooo`00oooooonAooooo`00oooooonAooooo`00oooooonAooooo`00oooooonAooooo`00oooooonA
ooooo`00oooooonAooooo`00oooooonAooooo`00oooooonAooooo`00oooooonAooooo`002Ooooonf
00000=7ooooo0009ooooo`0300000?oooooooooo0;;ooooo00<00000ooooooooool0coooool000Wo
oooo00<00000ooooooooool0/_ooool00`00003oooooooooo`3?ooooo`002Oooool00`00003ooooo
ooooo`2booooo`0300000?oooooooooo0<oooooo0009ooooo`0300000?oooooooooo013ooooo0P00
002Pooooo`0300000?oooooooooo0<oooooo0009ooooo`0400000?ooooooooooooooo`H000002`0I
6AVL000000Cooooo00<00000ooooooooool0coooool000Wooooo00@00000oooooooooooooooo1P0c
<c<3000000X06ATIVP000004ooooo`0300000?oooooooooo0<oooooo0009ooooo`0400000?oooooo
ooooooooo`T0<c<c00<0000001TI6@0I6AT0200I6AT00`00003o00000000002F000000Cooooo00<0
0000ooooooooool0coooool000Wooooo00@00000oooooooooooooooo2P0c<c<00ol0000000000000
000:01TI6IH000001?ooool00`00003oooooooooo`3?ooooo`002Oooool01000003ooooooooooooo
ool=03<c<`<00000200I6AVE000000Cooooo00<00000ooooooooool0coooool000Wooooo00@00000
oooooooooooooooo400c<c<00`0000006ATI01TI6@0601TI6I@000001?ooool00`00003ooooooooo
o`3?ooooo`002Oooool01000003ooooooooooooooolA03<c<`8000001`0I6AT00`00003o00000000
002@000000Cooooo00<00000ooooooooool0coooool000Wooooo00@00000oooooooooooooooo0`0c
<c<:000000H0<c<c00<0000001TI6@0I6AT01`0I6AV@000000Cooooo00<00000ooooooooool0cooo
ool000Wooooo00@00000oooooooooooooooo0`0c<c<00`000000C4a<04a<C00704a<C0<00000100c
<c<3000000L06ATIS`000004ooooo`0300000?oooooooooo0<oooooo0009ooooo`0400000?oooooo
ooooooooo`80<c<c00<0000004a<C01<C4`02`1<C4`00ol00000<c<c03<c<`0403<c<`030000000I
6AT06ATI00D06ATI00<00000o`0000000000R`000004ooooo`0300000?oooooooooo0<oooooo0009
ooooo`0400000?ooooooooooooooo`80<c<c00<0000004a<C01<C4`0301<C4`3000000@0<c<c00?o
00000000000I6AT01P0I6AV<000000Cooooo00<00000ooooooooool0coooool000Wooooo00@00000
oooooooooooooooo0P0c<c<00`000000C4a<04a<C00?04a<C0800000100c<c<00`0000006ATI01TI
6@0501TI6H/000001?ooool00`00003oooooooooo`3?ooooo`002Oooool01000003ooooooooooooo
ool203<c<`030000001<C4`0C4a<00P0C4a<0P00000704a<C0030000000c<c<0<c<c0080<c<c0P00
000701TI6HT000001?ooool00`00003oooooooooo`2;ooooo`;o0000@_ooool000Wooooo00@00000
oooooooooooooooo0P0c<c<00`000000C4a<04a<C00504a<C004o`0000000000000006IVIPD00000
101<C4`00ol0000000000000000303<c<`8000001P0I6AT00`00003o000000000025000000Cooooo
00<00000ooooooooool0R?ooool3o`000003ooooool0003ooooo047ooooo0009ooooo`0400000?oo
ooooooooooooo`80<c<c00<0000004a<C01<C4`01@1<C4`00`000000IVIV06IVIP0606IVIP030000
001<C4`0C4a<00@0C4a<00<0000003<c<`0c<c<00P0c<c<2000000H06ATIQP000004ooooo`030000
0?oooooooooo08Kooooo0_l00003ooooo`03ojVmj?l0003o0000047ooooo0009ooooo`0400000?oo
ooooooooooooo`<0<c<c00<0000004a<C01<C4`00`1<C4`00`000000IVIV06IVIP0806IVIP<00000
101<C4`2000000@0<c<c00<0000001TI6@0I6AT0100I6AV5000000Cooooo00<00000ooooooooool0
Poooool3o`0000;ooooo1?nY_NP00ol0003oooooo`000010ooooo`002Oooool01000003ooooooooo
ooooool303<c<`030000001<C4`0C4a<0080C4a<00<0000006IVIP1VIVH0301VIVH3000000<0C4a<
0P00000303<c<`8000001@0I6AT00`00003o000000000021000000Cooooo00<00000ooooooooool0
P?ooool3o`0000;ooooo1onY_NP00ol0003oooooo`000010ooooo`002Oooool01000003ooooooooo
ooooool303<c<`03o`00001<C4`0C4a<0080C4a<00<0000006IVIP1VIVH01@1VIVH4000000H0IVIV
00<0000004a<C01<C4`00P1<C4`2000000<0<c<c0P00000601TI6H4000001?ooool00`00003ooooo
ooooo`1nooooo`;o00000oooool9ojVmj004o`000?nY_NSoooooo`0003oooooo0009ooooo`040000
0?ooooooooooooooo`<0<c<c00<0000004a<C01<C4`00P1<C4`00`000000IVIV06IVIP0406IVIP03
0000001oOgl0Ogmo0080Ogmo0`00000406IVIP<000000`1<C4`00`000000<c<c03<c<`0203<c<`03
0000000I6AT06ATI00@06ATIP0000004ooooo`0300000?oooooooooo07_ooooo0ol00002ooooo`co
ZKgX00Go0000ojVmj?ooooooooooo`00000nooooo`002Oooool01@00003oooooooooooooool00000
00<0<c<c00D0000004a<C01<C4`0C4a<0000000506IVIP030000001oOgl0Ogmo00H0Ogmo00@00000
o`000000000000000`1VIVH01_l00000C4a<04a<C01<C4co0000000000<0<c<c00?o000001TI6@0I
6AT01@0I6AUn000000Cooooo00<00000ooooooooool0NOooool2o`0000?ooooo3_nY_NP01Ol0003o
ZKgXojVmj?oooooo000003kooooo0009ooooo`0500000?ooooooooooooooo`0000000`0c<c<01@00
0000C4a<04a<C01<C4`0000000D0IVIV00<0000007moO`1oOgl02P1oOgl200000080IVIV0P000003
04a<C0050000000c<c<0<c<c03<c<`0000001`0I6AT00ol0000000000000001j000000Cooooo00<0
0000ooooooooool0M_ooool3o`0000;ooooo4OnY_NP01_l0003oZKgXojVmj?nY_NSoooooo`0003go
oooo0009ooooo`0600000?ooooooooooooooo`0I6AT000000`0c<c<01@000000C4a<04a<C01<C4`0
000000@0IVIV00<0000007moO`1oOgl0301oOgl200000080IVIV00D0000004a<C01<C4`0C4a<0000
000303<c<`8000001`0I6AUk000000Cooooo00<00000ooooooooool0M?ooool2o`0000;ooooo5?nY
_NP00ol0003oZKgXojVmj002ojVmj003o`000?oooooooooo03_ooooo0009ooooo`0600000?oooooo
ooooooooo`0I6AT000000`0c<c<01@000000C4a<04a<C01<C4`0000000@0IVIV00<0000007moO`1o
Ogl00`1oOgl00ol00000000000000004000000@0Ogmo00?o000006IVIP1VIVH00P00000204a<C080
00000`0c<c<00`0000006ATI01TI6@0501TI6GX000001?ooool00`00003oooooooooo`1aooooo`?o
00000_oooolFojVmj003o`000?nY_NSoZKgX00?oZKgX00?o0000ooooooooool0>_ooool000Wooooo
00@00000oooooooooooooooo0P0I6AT01_l00000<c<c03<c<`0c<c<00000o`000080C4a<00D00000
06IVIP1VIVH0IVIV0000000407moO`03o`00002IVIT0VIVI00D0VIVI0P00000307moO`8000000P1V
IVH200000080C4a<00Ko000003<c<`0c<c<0<c<c00000?l0000601TI6GT000001?ooool00`00003o
ooooooooo`1^ooooo`?o00000_oooolIojVmj003o`000?nY_NSoZKgX00?oZKgX00?oooooo`000?oo
ool0>_ooool000Wooooo00@00000oooooooooooooooo0`0I6AT01@000000<c<c03<c<`0c<c<00000
0080C4a<00D0000006IVIP1VIVH0IVIV0000000407moO`030000002IVIT0VIVI00L0VIVI0P000003
07moO`8000000P1VIVH20000000304a<C0000000000000<0<c<c00<0000001TI6@0I6AT01@0I6AUg
000000Cooooo00<00000ooooooooool0K?ooool2o`0000?ooooo7?nY_NP00ol0003oZKgXojVmj003
ojVmj003o`000?oooooooooo03Wooooo0009ooooo`0400000?ooooooooooooooo`@06ATI00D00000
03<c<`0c<c<0<c<c0000000204a<C0050000001VIVH0IVIV06IVIP0000000`1oOgl00`000000VIVI
09VIV@0909VIV@<000000P1oOgl200000080IVIV00<0000004a<C01<C4`00P00000203<c<`030000
000I6AT06ATI00D06ATIMP000004ooooo`0300000?oooooooooo06Wooooo0ol00002oooooaooZKgX
00?o0000ojVmj?nY_NP00onY_NP00ooooooo0000ooooo`0iooooo`002Oooool01000003ooooooooo
ooooool501TI6@050000000c<c<0<c<c03<c<`0000000P1<C4`010000000IVIV06IVIP00000307mo
O`030000002IVIT0VIVI00@0VIVI1000000409VIV@05o`00001oOgl0Ogmo07moO`0000000P1VIVH0
1Ol00000C4a<04a<C01<C4`000000080<c<c00<00000o`00000000001`0I6AUc000000Cooooo00<0
0000ooooooooool0Ioooool2o`0000?ooooo8OnY_NP00ol0003oZKgXojVmj004ojVmj003ooooool0
003ooooo03Sooooo0009ooooo`0400000?ooooooooooooooo`D06ATI00D0000003<c<`0c<c<0<c<c
0000000204a<C0040000001VIVH0IVIV000000<0Ogmo00<0000009VIV@2IVIT00`2IVIT00`000000
/k>c0;>c/`020;>c/`<0000000<0VIVI0000000000000`1oOgl010000000IVIV00000000000304a<
C0030000000c<c<0<c<c0080<c<c00<0000001TI6@0I6AT01@0I6AT00ol0000000000000001_0000
00Cooooo00<00000ooooooooool0I?ooool3o`0000;ooooo9?nY_NP00ol0003oZKgXojVmj004ojVm
j003ooooool0003ooooo03Sooooo0009ooooo`0500000?ooooooooooooooo`0000001@0I6AT01@00
0000<c<c03<c<`0c<c<000000080C4a<00@0000006IVIP1VIVH000000P1oOgl00`000000VIVI09VI
V@0209VIV@030000002c/k<0/k>c00H0/k>c00<0000009VIV@2IVIT00P00000207moO`030000001V
IVH0IVIV008000000P1<C4`00`000000<c<c03<c<`0203<c<`030000000I6AT06ATI00H06ATIL000
0004ooooo`0300000?oooooooooo06;ooooo0_l00003ooooobKoZKgX00?o0000ojVmj?nY_NP01OnY
_NP00ooooooo0000ooooo`0gooooo`002Oooool01@00003oooooooooooooool0000000H06ATI00Co
000003<c<`0c<c<000000`1<C4`010000000IVIV06IVIP00000207moO`050000002IVIT0VIVI09VI
V@0000002@2c/k<200000080VIVI0P0000000`1oOgl000000000000206IVIP03o`00001<C4`0C4a<
008000000`0c<c<00`0000006ATI01TI6@0601TI6Fl000001?ooool00`00003oooooooooo`1Ooooo
o`?o00000_oooolYojVmj003o`000?nY_NSoZKgX00KoZKgX00?oooooo`000?ooool0=_ooool000Wo
oooo00@00000oooooooooooooooo0P00000501TI6@050000000c<c<0<c<c03<c<`0000000P1<C4`0
1?l00000IVIV06IVI_l0000207moO`050000002IVIT0VIVI09VIV@0000002`2c/k<200000080VIVI
00?o000007moO`1oOgl00P0000000`1VIVH000000000000204a<C08000000P0c<c<00`0000006ATI
01TI6@0701TI6Fd000001?ooool00`00003oooooooooo`1Mooooo`;o00000oooool[ojVmj003o`00
0?nY_NSoZKgX00OoZKgX00?o0000ooooooooool0=Oooool000Wooooo00@00000oooooooooooooooo
0`00000501TI6@050000000c<c<0<c<c03<c<`0000000P1<C4`01P000000IVIV06IVIP000000Ogmo
000000<0VIVI00<000000;>c/`2c/k<0102c/k<500000080/k>c0P0000000`2IVIT0000000000002
07moO`80000000<0IVIV0000000000000P1<C4`01@000000<c<c03<c<ol00000000000T06ATIJ`00
0004ooooo`0300000?oooooooooo05[ooooo0ol00002ooooobkoZKgX00?o0000ojVmj?nY_NP02?nY
_NP00ol0003oooooooooo`0dooooo`002Oooool01000003oooooooooooooool300000003o`00000I
6AT06ATI00<06ATI00D0000003<c<`0c<c<0<c<c0000000204a<C0060000001VIVH0IVIV0000001o
Ogl000000`2IVIT00`000000/k>c0;>c/`020;>c/`030000003<c<`0c<c<00<0c<c<0P0000020;>c
/`030000002IVIT0VIVI008000000P1oOgl010000000IVIV06IVIP00000204a<C0040000000c<c<0
<c<c03<c<`8000002@0I6AUY000000Cooooo00<00000ooooooooool0Eoooool3o`0000?ooooo<?nY
_NP00ol0003oZKgXojVmj008ojVmj003ooooool0003ooooo03Cooooo0009ooooo`0400000?oooooo
ooooooooo`D000001@0I6AT01@000000<c<c03<c<`0c<c<000000080C4a<00H0000006IVIP1VIVH0
000007moO`00000209VIV@050000002c/k<0/k>c0;>c/`000000203<c<`2000000060;>c/ol00000
00000000002IVIT000000P1oOgl01?l00000IVIV06IVI_l0000204a<C003o`00000c<c<0<c<c0080
<c<c0P00000801TI6FP000001?ooool00`00003oooooooooo`1Eooooo`;o00000ooooolcojVmj003
o`000?nY_NSoZKgX00WoZKgX00?o0000ooooooooool0<oooool000Wooooo00@00000oooooooooooo
oooo1P00000401TI6@050000000c<c<0<c<c03<c<`0000000P1<C4`01_l00000IVIV06IVIP000000
Ogmo00000080VIVI00D000000;>c/`2c/k<0/k>c0000000:0<c<c0080000002c/k<0/k>c0;>c/`00
0000VIVI0000001oOgl200000080IVIV0P0000000`1<C4`000000000000403<c<`030000000I6AT0
6ATI00T06ATII0000004ooooo`0300000?oooooooooo05;ooooo0ol00003ooooocGoZKgX00?o0000
ojVmj?nY_NP02OnY_NP00ooooooo0000ooooo`0cooooo`002Oooool01000003oooooooooooooool7
000000@06ATI00D0000003<c<`0c<c<0<c<c0000000204a<C0030000001VIVH000000080Ogmo00@0
000009VIV@2IVIT000000P2c/k<00`000000c<c<0<c<c0090<c<c08000000P2c/k<00`000000VIVI
0000000207moO`8000000P1VIVH00`000000C4a<04a<C002000000<0<c<c00<0000001TI6@0I6AT0
2`0I6AUQ000000Cooooo00<00000ooooooooool0D?ooool2o`0000Cooooo=onY_NP00ol0003oZKgX
ojVmj00:ojVmj003o`000?oooooooooo03;ooooo0009ooooo`0400000?ooooooooooooooo`L00000
00?o000001TI6@0I6AT00P0I6AT01@000000<c<c03<c<`0c<c<000000080C4a<00<0000006IVIP00
00000P1oOgl00`000000VIVI000000030;>c/`030000003<c<`0c<c<00@0c<c<0P0000040<c<c005
0000002c/k<0/k>c0000002IVIT00P00000207moO`04o`00001VIVH0IVIVo`0000<0C4a<00Go0000
03<c<`0c<c<0<c<c0000000>01TI6El000001?ooool00`00003oooooooooo`1=ooooo`?o00000ooo
ool:ojVmj0;oZKgW1?nY_NP2ojVmi`GoZKgX00?oZKgWojVmj?nY_NP08?nY_NP00ol0003oZKgXojVm
j00:ojVmj003ooooool0003ooooo03;ooooo0009ooooo`0400000?ooooooooooooooo`P000001@0I
6AT01Ol00000<c<c03<c<`0c<c<000000080C4a<00<0000006IVIP0000000P1oOgl00ol00000VIVI
000000020;>c/`030000003<c<`0c<c<00<0c<c<00<000000>KViP3Vi^H00P0000030<c<c004o`00
00000000/k>co`000080VIVI0P000000101oOgl0000006IVIP1VIVH20000000304a<C00000000000
00<0<c<c0P00000>01TI6Ed000001?ooool00`00003oooooooooo`1;ooooo`;o00001?ooool2ojVm
i`CoZKgX0_nY_NL2ojVmj0GoZKgW00?oZKgXojVmionY_NL00onY_NL00onY_NSoZKgWojVmi`03ojVm
i`03ojVmj?nY_NOoZKgW00GoZKgX00?oZKgWojVmj?nY_NP01onY_NP00onY_NOoZKgXojVmj00<ojVm
j003o`000?nY_NSoZKgX00_oZKgX00?oooooo`000?ooool0<Oooool000Wooooo00@00000oooooooo
oooooooo2@00000501TI6@070000000c<c<0<c<c03<c<`000000C4a<o`00000206IVIP030000001o
Ogl000000080VIVI00@000000;>c/`2c/k?o0000103<c<`00`000000i^KV0>KViP020>KViP800000
0`3<c<`010000000/k>c00000000000209VIV@<000000`1VIVH010000000C4a<04a<C000000403<c
<`8000003`0I6AUJ000000Cooooo00<00000ooooooooool0B?ooool3o`0000?ooooo4OnY_NL00onZ
_NOoZKgWojVmi`03ojVmi`03ojZmionY_NOoZKgW00?oZKgW00?oZ[gWojVmionY_NL00_nY_NL00onY
_NSoZ[gWojZmi`03ojVmi`06ojVmj?nY_NOoZKgWojVmionY_NSoZ[gW1?nY_NL00onY_NSoZKgWojVm
j00:ojVmj003o`000?nY_NSoZKgX00coZKgX00?o0000ooooooooool0<?ooool000Wooooo00@00000
oooooooooooooooo2P00000501TI6@070000000c<c<0<c<c03<c<`000000C4a<0000000206IVIP03
0000001oOgl000000080VIVI00<000000;>c/`000000103<c<`00`000000i^KV0>KViP040>KViP80
00000P3<c<`00`000000/k>c0;>c/`0200000080VIVI0`00000206IVIP03o`00001<C4`0C4a<0080
0000100c<c<00`0000006ATI01TI6@0?01TI6EL000001?ooool00`00003oooooooooo`15ooooo`?o
00001?ooool4ojVmi`03ojVlionY_NOoZKgW00?oZKgW00?oZ[cWojVmionY_NL00onY_NL2ojZli`?o
Z[gW00?oZKgWojZlionZ_>L00onZ_NL2ojVmi`04ojZlionZ_NOoZ[gWojZmi`;oZKgW0onZ_NL2ojZl
i`?oZ[gW0_nY_NL4ojZmi`;oZKgW00CoZ[gWojVmionY_NOoZKgW0_nY_NP00onZ_NOoZKgXojVmj003
ojVmj003ojVmionY_NSo000000koZKgX00?oooooo`000?ooool0<?ooool000Wooooo00@00000oooo
oooooooooooo2`00000501TI6@070000000c<c<0<c<c03<c<`000000C4a<0000000206IVIP03o`00
001oOgl000000080VIVI00<000000;>c/`0000000`3<c<`00`000000i^KV0>KViP060>KViP04o`00
00000000c<c<o`000080000000H0/k>c0000002IVIT0VIVIo`00001oOgl20000000306IVIP000000
C4a<0080C4a<0P00000303<c<`0300000?l00000000001406ATIE0000004ooooo`0300000?oooooo
oooo04?ooooo0_l00002ooooo`;oZKcW1?nY_NL2ojZli`?oZKcW0_nY_NL4ojZli`;oZKgW1OnZ_>L0
0onZ_NOoZ[cWojZli`03ojZli`03ojZmionZ_>OoZ[cW00?oZ[cW00GoZ[gWojZlionZ_>OoZ[cWojZm
i`05ojZli`03ojZmionZ_>OoZ[gW00CoZ[gW0_nZ_>L3ojZmi`03ojVmionZ_NOoZ[gW00?oZ[gW0_nY
_NP2ojZmi`;oZKgW00Co0000ojVmj?nY_NOoZKgW0_nY_NP00onZ_NOoZKgXojVmj007ojVmj003oooo
ool0003ooooo02oooooo0009ooooo`0400000?ooooooooooooooo`/000001@0I6AT01@000000<c<c
03<c<`0c<c?o00000080C4a<00D0000006IVIP000000Ogmo0000000209VIV@030000002c/k<00000
00<0c<c<00<000000>KViP3Vi^H0203Vi^H020000000c<c<0<c<c03<c<`000000;>c/`000000VIVI
0P00000207moO`030000001VIVH0000000@0C4a<00<0000003<c<`0c<c<00`0c<c<00`0000006ATI
01TI6@0A01TI6E4000001?ooool00`00003oooooooooo`10ooooo`?o00000_ooool5ojVli`03ojVm
ionZ_>OoZ[cW00?oZ[cW00?oZKcWojZlionZ_>L05?nZ_>L2ojZliPGoZ[cW00?oZ[cVojZlionZ_>L0
0onZ_>L01?nZ_>KoZ[cWojZlionZ_>L2ojZmi`GoZ[cW00?oZ[gWojZlionZ_NL02onZ_NL00ol0003o
Z[gWojVmi`05ojZmi`03ojVmj?nZ_NOoZKgX00GoZKgX00?oooooo`000?ooool0;oooool000Wooooo
00@00000oooooooooooooooo3000000501TI6@050000000c<c<0<c<c03<c<`0000000P1<C4`01@00
0000IVIV0000001oOgl000000080VIVI00<000000;>c/`0000000`3<c<`00`000000i^KV0>KViP08
0>KViP8000000P3<c<`00`000000/k>c0000000209VIV@80000000<0Ogmo0000001VIVH00P000003
04a<C0030000000c<c<0<c<c00<0<c<c0P00000B01TI6E0000001?ooool00`00003oooooooooo`0n
ooooo`;o00000oooool6ojVli`coZ[cW00?oZ[cVojZlionZ_>L00onZ_>L3ojZliP?oZ[cW0onZ_>H0
0onZ_>OoZ[_VojZliP03ojZliP03ojZlionZ^nKoZ[cV00?oZ[cV00?oZ[cWojZli_nZ_>H00onZ_>H0
0onZ_>OoZ[cVojZliP09ojZli`;oZ[gW0_nZ_>L00onZ_NOoZ[cWojZli`04ojZmi`03o`000?nZ_NOo
Z[gW00SoZ[gW0_nY_NP01_nZ_NOoZKgXojVmj?nY_NSoooooo`0002oooooo0009ooooo`0400000?oo
ooooooooooooo`d000001@0I6AT01`000000<c<c03<c<`0c<c<0000004a<C00000000P1VIVH00`00
0000Ogmo0000000209VIV@030000002c/k<000000080c<c<00<000000>KViP3Vi^H02P3Vi^H01@00
0000c<c<0<c<c0000000/k>c008000000P2IVIT00ol00000Ogmo0000000206IVIP050000001<C4`0
C4a<04a<C00000001P0c<c<00`0000006ATI01TI6@0B01TI6Dd000001?ooool00`00003ooooooooo
o`0kooooo`?o00000_ooool6ojVli`OoZ[cW00?oZ[cVojZlionZ_>L00onZ_>L2ojZkiP;oZ[cV0_nZ
_>L2ojZkiP;oZ[cV00CoZ[_UojZki_nZ^nKoZ[_V0_nZ_>H01?nZ^nGoZ[_VojZki_nZ^nH2ojZliP04
oj^kiOnZ^nKoZ[_VojZkiP;oZ[cV00?oZk_VojZli_nZ_>H00onZ_>H00on[^nKoZ[cVojZliP02ojZl
iP03ojZlionZ_>KoZ[cV00;oZ[cW00CoZkcVojZli_nZ_>KoZ[cV0_nZ_>L00onZ_>KoZ[cWojZli`02
ojZli`04ojZmionZ_>OoZ[gWo`0000koZ[gW00GoZKgXojZmionZ_NOoooooo`00000^ooooo`002Ooo
ool01000003oooooooooooooool=00000003o`00000000006ATI00<06ATI00Oo000003<c<`0c<c<0
<c<c0000001<C4`000000080IVIV00So000007moO`00003o000009VIV@000000/k>co`000080c<c<
00<000000>KViP3Vi^H00P3Vi^H5o`0000<0i^KV00Co00000000003<c<co00000P2c/k<400000006
07moO`000000000006IVI_l0000000000P1<C4`2000000D0<c<c0P00000D01TI6@03o`0000000000
000004P000001?ooool00`00003oooooooooo`0iooooo`;o00000oooool6ojVli`;oZ[cV1?nZ_>L2
ojZkiP?oZ[cV00?oZ[cWojZki_nZ^nH00_nZ^nH2ojZki@CoZ[_V0_nZ^^D3ojZki@03ojZki_n[^^Go
Zk[U00?oZ[_U00?oZ[_Voj^jiOn[^^D00on[^nD00onZ^nKoZk_Uoj^ki@03oj^kiP;oZ[cV0_n[^nD2
oj^kiP;oZ[cV0_n[^nH00onZ_>KoZk_Uoj^ki@03oj^liP03ojZli_n[^nKoZk_V00?oZ[cV0_nZ_>L0
1on[_>KoZ[cWojZlionZ_>Oo0000ojZmionZ_>L04?nZ_NL00ol0003oooooooooo`0/ooooo`002Ooo
ool01000003oooooooooooooool?000000D06ATI00L0000003<c<`0c<c<0<c<co`00001<C4`00000
0080IVIV00D0000007moO`000000VIVI000000020;>c/`040000003<c<`0c<c<000000<0i^KV00?o
00000?ooo`3oool00P3oool2o`0000<0i^KV00@000000<c<c000000000000P2c/k<00`000000VIVI
0000000207moO`040000001VIVH0IVIV000000<0C4a<0P00000503<c<`800000500I6AU9000000Co
oooo00<00000ooooooooool0=_ooool3o`0000?ooooo1_nY_>L5ojZliP03ojZlionZ^nKoZ[_V00?o
Z[_V00?oZ[cVojZki_nZ^nH00_nZ^nH00onZ^^GoZ[_UojZki@02ojZki@03ojZki_n[^^GoZ[[U00?o
Z[[U00?oZ[_Uoj^ji?n[^^D00on[^^D00onZ^nGoZk[Toj^ji@03oj^ji@03oj^kiOn[^^CoZk_U00?o
Zk_U00?oZk_Voj^ji?n[^^@00_n[^nD00on[^^CoZk_Uoj^ki@02oj^ki@03oj^ki_n[^^CoZk_U00?o
Zk_U00?oZkcVoj^kiOn[^nH00on[^nH00onZ_>KoZk_Voj^liP03oj^liP03ojZlion[_>Ko000000?o
Z[cW00?oZ[gWojZlionZ_>L00_nZ_NL00onZ_>OoZ[gWojZmi`08ojZmi`03o`000?oooooooooo02_o
oooo0009ooooo`0400000?oooooooooooooooa0000001@0I6AT01P000000<c<c03<c<`0c<c<00000
04a<C080000000D0IVIV0000001oOgl0000009VIV@02000000050;>c/`000000c<c<0<c<c0000000
0`3Vi^H00ol00000oooo0?ooo`030?ooo`;o00000P3Vi^H010000000c<c<0<c<c00000020;>c/`06
0000002IVIT000000000001oOgl000000P1VIVH00`000000C4a<04a<C00204a<C003o`00000c<c<0
<c<c00@0<c<c0`00000C01TI6DL000001?ooool00`00003oooooooooo`0cooooo`?o00001?ooool6
ojVli`;oZK_V1?nZ_>H3ojZkiP;oZ[[U0onZ^nD00onZ^nKoZ[[UojZji@03ojZji@;oZ[_U00CoZkWT
oj^jiOn[^^GoZk[U0_nZ^^D01?n[^NCoZk[Toj^ji?n[^^@2oj^ji@04oj^ihon[^^CoZk[Toj^ji0;o
Zk[U00CoZkWSoj^ji?n[^^CoZk[T0_n[^nD2oj^ii003oj^ji?n/^N?o[;WS00?oZk[T0_n[^nD01?n/
^N?oZk[Toj^ji?n[^^@2oj^ki@04ojbji?n[^nGoZk_Uoj^ki@;oZk_V00CoZk_Uoj^ki_n[^nKoZk_V
0_n[_>H2oj^ki@03oj^li_l0003oZkcV00?oZkcV00?oZ[cWoj^li_n[_>H00onZ_>L00onZ_NOoZ[cW
ojZli`06ojZmi`03o`000?oooooooooo02_ooooo0009ooooo`0400000?oooooooooooooooa000000
00?o000001TI6@0I6AT00`0I6AT01@000000<c<c03<c<`0c<c<000000080C4a<00D0000006IVIP00
0000Ogmo0000000209VIV@030000002c/k<000000080c<c<00@000000>KViP3Vi^Ko00001`3oool2
o`0000080>KVi_l0000000000<c<c?l0000000000;>c/ol0000209VIV@060000001oOgl000000000
001VIVKo00000P00000204a<C08000001`0c<c<2000001<06ATI00<00000o`0000000000@P000004
ooooo`0300000?oooooooooo037ooooo0_l00004ooooo`KoZKcW1?nY^nH6ojZkiPGoZ[[U00?oZ[_U
ojZii?nZ^N@01?nZ^^D5oj^ii003oj^jiOn[^>?oZkSS00?oZkWT00?oZk[Toj^hhon[^><00on[^N<0
1?n[^^Co[;SSojbhhon/^><2oj^ih`06oj^ji?n/^>?o[;SSojbhhon[^NCo[;SR1?n/^N<00on[^^Co
[;SRojbih`03ojbih`03oj^ji?n/^N?o[;[T00?o[;[T00?oZk_Uojbji?n[^nD00on[^nD00on[^nKo
Zk_Uoj^ki@02oj^ki@04ojbki?n[^nGoZk_Uo`0000;oZkcV00?oZk_Uoj^li_n[_>H00_n[_>H00onZ
_>OoZkcVojZli`03ojZli`03ojZmionZ_>OoZ[gW00?oZ[gW00?o0000ooooooooool0:_ooool000Wo
oooo00@00000oooooooooooooooo4P00000501TI6@040000000c<c<0<c<c00000080C4a<00<00000
06IVIP0000000P1oOgl01Ol00000VIVI0000002c/k<000000080c<c<00Go00000>KViP3Vi^H0i^KV
o`0000080?ooo`04o`00003Vi^H0i^KV00000080c<c<00<000000;>c/`0000000P2IVIT010000000
Ogmo07moO`00000306IVIP040000001<C4`0C4a<04a<C08000001`0c<c<00`0000006ATI01TI6@0B
01TI6D<000001?ooool00`00003oooooooooo`0^ooooo`?o00000_ooool5ojVkiP03ojVlionY^nKo
ZK_V00CoZK_V00?oZK[UojZki_nZ^nH00onZ^nH6ojZji@GoZ[WT00?oZ[[Uoj^hhon[^N@01?n[^N@0
0on[^>;oZkSSoj^hh`02oj^hh`03oj^ii?n[]n;oZkSS00?oZkSS00?oZkWSojbgh_n/]n800_n/^><0
1?n/]^3o[;ORojbgh_n/]n82ojbhh`04ojbgh?n/^>;o[;SRojbhhP;o[;WS00Co[KOQojbhh_n/^>;o
[;SR0_n/^N<01?n]^>;o[;WSojbihon/^N<2ojbji004ojbihon/^^Co[;[Tojbji0;oZk_U0_n/^^<0
0on[^nGo[;[Sojbjh`03ojbki003oj^kiOl0003o[;_T00?oZk_U0_n[_>H01?n[^nGoZkcVoj^li_n[
_>H2ojZli`;oZkcV0_nZ_>L2ojZmi`;oZ[cW00?o0000ooooooooool0:Oooool000Wooooo00@00000
oooooooooooooooo4P00000601TI6@040000000c<c<0<c<c00000080C4a<00<0000006IVIP000000
0P1oOgl01@000000VIVI0000002c/k<000000080c<c<00@000000>KViP3Vi^Ko00002@3oool01?l0
0000i^KV0>KViP0000020<c<c0030000002c/k<000000080VIVI00@0000007moO`1oOgl000000`1V
IVH00`000000C4a<04a<C00204a<C0030000000c<c<0<c<c00D0<c<c0P00000C01TI6D8000001?oo
ool00`00003oooooooooo`0/ooooo`;o00000oooool00onZ^^GoZK_VojVkiP03ojVkiP03ojVjiOnY
^nKoZK_V00?oZK_V1?nY^^D2ojZkiP03ojZiiOnZ^^GoZ[[U00?oZ[[U1_nZ^N@4oj^hh`;oZkWT00Co
ZkORoj^hh_n[^>;oZkSR0_n[^><01?n[]^7oZkORoj^gh_n[]n82oj^hh`;o[;KQ00?o[;ORojbegon/
]Ml00on/]^000on/]n;o[KGOojfeg`03ojbgh003ojbhh_n]]]oo[KKO00?o[KOQ00?o[;SRojfgh?n]
]n000on]^>801?n/^N?o[KSQojfhhOn]^>42ojbih`06ojbji?n]^N;o[KWRojfih_n/^^?o[KWR1?n/
^^<01?n/^nCo[;[Sojbki?l00002ojbki003oj^kiOn/^nCoZk_U00?oZk_U00?oZkcVoj^kiOn[^nD0
0_n[_>H01?n[_>GoZkcVoj^li_n[_>H2ojZli`03oj^li_l0003ooooo02[ooooo0009ooooo`040000
0?oooooooooooooooa<000001@0I6AT01@000000<c<c03<c<`0c<c<000000080C4a<00<0000006IV
IP0000000P1oOgl01@000000VIVI0000002c/k<000000080c<c<00@000000>KViP3Vi^Ko00002@3o
ool01?l00000i^KV0>KVi_l000020<c<c003o`00002c/k<000000080VIVI00@0000007moO`1oOgl0
00000`1VIVH00`000000C4a<04a<C00204a<C0030000000c<c<0<c<c00H0<c<c0P00000C01TI6D00
00001?ooool00`00003oooooooooo`0Yooooo`?o00000_ooool2ojZii0?oZ[[U00?oZK_VojZii?nZ
^N@00onY^^D00onY^nKoZ[WUojZii@04ojVji@;oZ[WT0onZ^ND00onZ^^GoZ[SSojZhh`04ojZii0;o
Z[OR1?n[^><2oj^fh@?oZkOR00CoZkSRoj^fh?n[]^3oZkKP0_n[]^401_n[]n;o[;GOojbegon/]Moo
[;KQojfdgPCo[;GO00?o[;KPojfdgOn]]Ml00on]]Ml00on/]n3o[KCNojffg`03ojffg`03ojfghOn^
]Mko[KOP00?o[KOP00?o[KSRojjfgon]^>400_n]^>401?n^]]ko[KOPojfgh?n]]n02ojfihP04ojjg
h?n]^N;o[KWRojfihP;o[;[S00Oo[KWRojbjhon/^^?o[;[So`000?n/^nCo[K[S00?o[;_T0_n[^nD2
ojbki003oj^kiOn/^nCoZkcU00?oZkcU1_n[_>H00ol0003oooooooooo`0Xooooo`002Oooool01000
003ooooooooooooooolD000000D06ATI00D0000003<c<`0c<c<0<c<c0000000204a<C00:o`00001V
IVH000000000001oOgl0000009VIVOl00000/k>c00000080c<c<00@000000>KVi_l0003o00002@3o
ool2o`0000040>KViP00000000000<c<c080000000Co00000000002IVIWo00000P1oOgl200000080
IVIV00?o000004a<C01<C4`00P1<C4`2000000P0<c<c0`00000B01TI6Ch000001?ooool00`00003o
ooooooooo`0Wooooo`;o00000oooool2oj^fh@?oZ[WT00?oZ[[Uoj^gh_n[]n800onZ^N@00onY^^Go
Z[SSojZhh`03ojZii@03ojVjiOnZ^>?oZ[WT00?oZ[WT00?oZ[WUojZghonZ^><00onZ^><00onZ^NCo
Z[ORojZghP03ojZghP03oj^hhon[]^7oZkKQ00?oZkKQ00?oZkORoj^dgon[]=l00_n[]^001?n//mgo
[;CNojbdg_n/]=h2ojbeg`04ojfbg?n]]=ko[KCNojfdgP;o[;GO00Co[K;LojfdgOn]]=go[KCM0_n]
]Ml01?n^/]co[KCNojfdg_n]]=h2ojffg`04ojjcg?n^]Mko[[GNojjegP;o[KOP00Go[[CMojjfgon^
]]oo[[KOojfhh@03ojjfgP03ojfgh?n_]]ko[[OP00?o[[OP00?o[KWRojjggon]^N800on]^N800on/
^^?o[[WQo`000003ojfjh`03ojbki?n]^^?o[K[S00;o[;_T00Co[K[Sojbki?n/^nCo[;_T0_n[_>D0
0on/^nGoZkcVoj^liP04oj^liP03ooooool0003ooooo02Sooooo0009ooooo`0400000?oooooooooo
oooooa@000001P0I6AT01`000000<c<c03<c<`0c<c<0000004a<C00000000`1VIVH01`000000Ogmo
o`00002IVIT000000;>c/`0000000P3<c<`01?l00000i^KV0>KVi_l0000:0?ooo`04o`00003Vi^H0
i^KV00000080c<c<00@000000;>c/`000000VIVI0P00000207moO`80000000<0IVIV000000000000
101<C4`00`000000<c<c03<c<`0803<c<`8000004P0I6ATl000000Cooooo00<00000ooooooooool0
9?ooool3o`0000?ooooo00?o[;7Loj^fhOn[]^400_n[]^400onZ^NCoZkCOoj^ghP03oj^ghP03ojZi
i?n[]^7oZ[SS00?oZ[SS00?oZ[WUojZfh_nZ]^800_nZ^><2ojZii0;oZ[KR0_nZ]n<2ojZhh`;oZ[KQ
1?nZ]n82oj^eh003oj^fhOn[/mkoZk?N00CoZkCO0_n//]`3ojbcg@03ojbdg_n]/M_o[K7K00?o[K;L
00?o[KCNojf`f_n]/=X00on]/]`00on]]=go[[7JojjafP03ojjbg003ojfdg_n_/M[o[[?L00?o[[?L
00?o[[GNojnbfon^]=d00on^]=d00on^]]oo[kCLojndg002ojjfgP04ojncfon_]]ko[kKNojnfgP;o
[[OP00Co[kGMojjggon^]moo[[OO0_n]^N801?n^]moo[[WQojjihOl00002ojfjh`;o[[WQ00?o[K[S
ojjihOn]^^<00on]^^<00on/^nCo[K[Sojbki@03ojbki@03oj^li_n/^nGo[;_U00?oZkcV00?o0000
ooooooooool09oooool000Wooooo00@00000oooooooooooooooo500000000ol000006ATI01TI6@04
01TI6@07o`00000c<c<0<c<c03<c<`000000C4a<0000000306IVIP070000001oOgl0000009VIV@00
0000/k>c000000020<c<c0040000003Vi^H0i^KVo`0000X0oooo00Co00000>KViP3Vi^H000000P3<
c<`00ol00000/k>c0000000209VIV@050000001oOgl0Ogmo07moO`0000000P1VIVH2000000<0C4a<
0`00000903<c<`8000004@0I6ATk000000Cooooo00<00000ooooooooool08_ooool2o`0000Cooooo
00Co[ZcFojbag?n//Mco[;7L0_n[]^401?n][mWoZkCOoj^dgon[]=l2oj^ghP04ojbbg?n[]^7oZkKQ
oj^fh@;oZ[SS0_n[/ml00onZ]^;oZk7Moj^ag@03ojZdh003ojZfh_n[/]koZk;N00?oZ[CP00?oZ[KQ
ojZbg_nZ/]h00on[]=l00on[]N3oZk7Moj^cgP03oj^cgP03oj^dgon//=co[;;L00?o[;;L00?o[;?M
ojb_f_n]/M/00on]/M/00on]/]co[JoIojf`fP03ojf`fP03ojfbg?n^[mSo[[7J00?o[[7J00?o[[;L
ojn_f?n_/MX00_n_/MX2ojjcg004ojn`fOn_/]_o[k;Kojnbf`;o[[CM0_n`/]X00on_]=co/;7Iok2a
f@03ojncf`03ojnfg_n`/m_o/;?K00?o[kGM00?o[[OOok2egOn`]Md00on^]ml00on^^N7o0000ojng
g`02ojjih@04ojnggon^^N7o[[WQojjih@;o[K[S00Co[[WRojfjhon]^^?o[K[S0_n/^nD2ojfki003
ojbkiOn]^nCo[;cU00?o[;cU00?o0000ooooooooool09_ooool000Wooooo00@00000oooooooooooo
oooo5P00000601TI6@080000000c<c<0<c<c03<c<ol00000C4a<00000?l0000206IVIP070000001o
Ogl0000009VIVOl00000/k>c000000020<c<c0040000003Vi^H0i^KVo`0000X0oooo00?o00000>KV
iP3Vi^H00P000000203<c<`000000;>c/ol00000000009VIVOl0000000000P1oOgl01Ol00000IVIV
06IVIP1VIVH0000000D0C4a<00?o000003<c<`0c<c<0200c<c<2000001806ATI>0000004ooooo`03
00000?oooooooooo01oooooo0ol00004ooooo`05ojnUc_n^[=Ko[ZcFojj/e_n//M`00_n^Z=83ojf_
f@03oj^dgon][=Ko[JcF00?o[;;L00KoZkKQojb_f_n/[m[o[:oJoj^cgon/[=L4oj^ag@03ojZdh?n[
[m[oZk;N00?oZk;N00?oZ[CPoj^`g?nZ/]h00onZ/]h00on[]=ooZk3Loj^ag@02oj^ag@;oZk?N00Co
ZjoJojb`g?n//=co[;3L0_n//]`01?n/[]Wo[:oJojb_f_n/[mX2ojfaf`04ojf]eon][mWo[JoIojf_
f@;o[K3J00Co[ZgFojj_f?n^[mSo[ZoH0_n^/MX01On_[MKo[joHojn_f?n_[mSo[k7J00;o/:kF0on_
/=T00on_/]_o/:oGok2_e`03ok2bfPCo/;7I00?o[k?Kok6af?n`/m/00on`/m/00on_]Mgo/K?Jok2e
g@03ok2eg@04ojjggon`]Mgo/;GMo`0000;o/;KM0on_]ml00on^^N7o[kSOojnhg`03ojjihP03ojfj
hon^^^;o[[[R00;o[K_T00Co[[[Rojfki?n]^nCo[K_T0_n/_>D00on]^nCoooooo`00000Wooooo`00
2Oooool01000003ooooooooooooooolF000000L06ATI00@0000003<c<`0c<c<000000`1<C4`01@00
0000IVIVo`00001oOgl000000080VIVI00D000000;>c/ol00000c<c<000000030>KViP03o`00003o
ool0oooo00P0oooo00Oo00000>KViP3Vi^H0i^KV0000003<c<`000000080/k>c00D0000009VIV@2I
VIT0000007moO`02000000<0IVIV00<0000004a<C01<C4`00P1<C4`2000000/0<c<c00<0000001TI
6@0I6AT0400I6AT00ol0000000000000000d000000Cooooo00<00000ooooooooool07?ooool3o`00
00Gooooo1?n_YLh00on^[=Ko[j79ojnQb@03ojjXdP03ojf_fOn_YLko[jG>00?o[JcF00?o[;;LojjX
d_n^Z=800on/[mX3ojb/e`;oZk7M00Co[JWDoj^_f_n[[m[oZjoJ0_n[/]h01?n[[=SoZk3Loj^`g?n[
/=`2ojZbgP05oj^]fOn[/=coZk3Loj^`g?n[/Md00_n[[MT3oj^_fP03ojb`g?n/[=So[:cH00?o[:kI
00?o[:oJojf/e_n][=H00on][ML00on][mWo[Z_Eojj[e@03ojj]eP03ojj_f?n_ZmCo[jgF00?o[jgF
00?o[joHok2/e?n`[]H00on`[]H00on_/=Wo/JgDok2_e`03ok2_e`03ok2bf_na[mKo/JoF00;o/;7I
00Co/ZkEok6af?na/MSo/K7H0_n`/m/01?nb/MOo/K?Jok6cf_na/mX2ok2eg@;o/K?J00?o/;GMok:c
f_l000000on`]]d00on_]moo/KKMojnhg`03ojnhg`04ojjih_n_^>3o[kSPojjjhP;o[kWP0on^^^80
0on]^nCo[[[Sojfki003ojfki003o`000?oooooooooo02Gooooo0009ooooo`0400000?oooooooooo
oooooaL000001`0I6AT010000000<c<c03<c<`00000304a<C0050000001VIVH0000007moO`000000
0P2IVIT01@000000/k>c0000003<c<`0000000<0i^KV00?o00000?ooo`3oool0203oool01?l00000
i^KV0>KViP0000020<c<c0040000002c/k<0/k>c00000080VIVI00<0000007moO`1oOgl00P000002
06IVIP030000001<C4`0C4a<00<0C4a<0P00000:03<c<`8000004P0I6ATe000000Cooooo00<00000
ooooooooool06_ooool2o`0000Oooooo0_n`WlH3ojnUcPCo[j7900?o[ZSBok2Ma?n_YLh00on_YLh0
0on][=Ko[j79ojjXdP03ojjXdP03ojb_f_n^YLoo[ZG?00;o[:cG1?n]ZM@00on[[m[o[JKAojfVd@03
oj^/f003oj^`g?n/ZMCo[:WD00?oZjgI00?oZk3Loj^Ze_n[Z]H00on[[MT00on[[m[o[:[Fojb/f003
ojb/f003ojb^fOn/Z]Co[JcF00?o[JcF00?o[JgGojjYdon^ZmD00on^ZmD00on^[MKo[jWBojn[e002
ojn[e0;o[jgF00Co/:WAok2/e?n`[=Co/:cD0_n`[]H01?naZm;o/JgDok6]e?na[M@2ok2_e`04ok6/
dona[mKo/JoFok6_ePCo/ZkE00?o/K7Hok>^e?nb/ML00onb/ML00ona/m[o/[7Gok6cfP02ok6cfP04
ok>aeonb/m[o/[?Jo`0000;o/;KM00Co/[CJok6fgOna]]go/KKM0_n_^=l2ok6gg@03ojnhh?na]mko
[kWP00?o[kWP00?o[[[RojnihOn^^^<00_n^^^<2ojfki0;o[[_S00?o0000ooooooooool09?ooool0
00Wooooo00@00000oooooooooooooooo600000000ol000006ATI01TI6@0401TI6@04o`00000c<c<0
<c<c000000<0C4a<00D0000006IVIP000000Ogmo0000000209VIV@050000002c/k<000000<c<c000
00000P3Vi^H00ol00000oooo0?ooo`090?ooo`04o`00003Vi^H0i^KV00000080c<c<00@000000;>c
/`2c/k?o00000P2IVIT01Ol00000Ogmo07moO`1oOgoo00000080IVIV0P00000504a<C08000002P0c
<c<2000001406ATI=0000004ooooo`0300000?oooooooooo01Oooooo0ol00007ooooo`;o/9Vo0on`
WlH00on_YLko/9[1ok2J`@02ojnQb@04ok6F_?n`WLCo/9g4ok2Ma0;o[jG>00Co/9VoojnQbOn_XLWo
[j790_n^Z=801On_WLGo[ZG?ojjUcon^YLoo[:cG00;o[Z;;0on]ZM@4ojfVd@03oj^/f?n]Xlgo[:WD
00?o[:WD00?oZjgIojbVdOn[Z]H00on[Z]H00on[[MWo[:OCojbZeP02ojbZeP;o[:cH00Co[:OBojbZ
e?n/Z]Co[:[D0_n][=H01?n]Ym7o[ZWCojjYdon^ZM<2ojj[e@04ojjWd?n_ZM;o[jWBojnYdP;o[j_D
1?n`ZM400on`[=Co/JS?ok6Xc`03ok6[dP03ok6]e?nbZM3o/ZW@00?o/JcC00?o/JoFok:/dOnb[=40
0_nb[]D01?ncZm3o/jkDok>^e?nc[]@2ok:ae`05ok>^donb/MOo/[7Gok:aeona/mX00onc/ML2o`00
00Co/[CJ00?o/KKMok:df_na]md00_na]md01?nb]M_o/KONok6gg_na]mh2ojnih005ok6hg_n_^N7o
[kWQojnihOn^^^<00_n_^^42ojjkh`03ojnjh_oooooo000002Gooooo0009ooooo`0400000?oooooo
oooooooooaT000001P0I6AT01@000000<c<c03<c<`0c<c?o00000080C4a<00Go000006IVIP1VIVH0
000007moO`0200000005o`0000000000/k>c0000003<c<`00P0000000`3Vi^Ko00000?ooo`0:0?oo
o`;o000000@0i^KVo`0000000000c<c<0P000000102c/k<000000000002IVIT20000000307moO`00
0000000000<0IVIV00?o000004a<C01<C4`0101<C4`00ol00000<c<c03<c<`0903<c<`800000400I
6AT00ol0000000000000000`000000Cooooo00<00000ooooooooool05_ooool2o`0000Sooooo1?n`
VKl00on`WlKo/IFjok2J`@02ok2J`@04ojnQbOnaU[co/IJlok6F_0;o/9g41?n`VKl2ojnQb@Co[ig5
00?o[ZG?ojnJ`On_V/400on^X//00on]ZMCo[Yo7ojjOa`03ojfVd@?o[J?=0_n/ZM@01?n]X<[o[:KA
ojbVdOn/Y]42oj^ZeP04ojbSc_n/Ym?o[:OCojbWd`;o[:[F1?n/Ym82ojbZe004ojf/e_n]Ym7o[JOA
ojfWd@;o[ZWC00Co[Z_EojjWd?n^Ym3o[ZO@0_n_ZM800on_ZmCo/:O?ok2Wc`03ok2Yd@Co/JS?00?o
/J_Bok:WcOnbZM000onbZM000ona[=?o/jW>ok:/d@02ok:/d@05ok:^eOncZm3o/j_@ok>[d?nc[]@0
0_ndZll3ok>^d`03ok:aeond[]?o/k7G00?o000000?o/k;Go`000?nc/]L00_nb]=X01Ond/]Oo/[CJ
ok:df_nb]=[o/KOM00?o/[GK00?o/KONok:fg?na^=h00ona^=h01On_^N7o/;WOok2igon_^^7o/;WP
00Co[k[R00?o0000ooooooooool08oooool000Wooooo00@00000oooooooooooooooo6@00000701TI
6@050000000c<c<0<c<c03<c<`0000000P1<C4`010000000IVIV06IVIP00000207moO`050000002I
VIT000000;>c/`0000000P3<c<`00`000000i^KVo`00000<0?ooo`04o`00003Vi^H0i^KV00000080
c<c<00@000000;>c/`2c/k<000000P2IVIT010000000Ogmo07moO`00000306IVIP8000001@1<C4`3
000000X0<c<c00<0000001TI6@0I6AT03`0I6ATa000000Cooooo00<00000ooooooooool05_ooool0
0ol0003oooooo`000006ooooo`;o/9Fk0_n`VKl01?naTKGo/IFjok6E^_naUKX2ok2J`@Co/IJl00?o
/9g4ok6B]onaT[L00on`VKl00on_XLWo/9Fkok2E^`03ojnMa@Co[i[100?o[Z;;ok2G_On^WlL00on^
WlL00on]Y]7o[Y_4ojjKa002ojfSc@Co[J3:0_n/Y]44ojbScP;o[:OC00?o[:[FojbTcon/Y<l00on/
Ym800on/Z]Co[JG?ojfUc`03ojfWd@03ojjYdon^Y<ko[ZC>00?o[ZO@00?o[jWBojnUcOn`Yll00on`
Yll00on`ZM7o/JG=ok6Uc@02ok6Xc`04ok:Tb_nbYlgo/ZO=ok:Wc@;o/ZW@00Go/jK;ok>Yc_ncZLko
/jW>ok:/d@02okBXc@?o/j_@1?ndZll00onc[]?o]J_?o`000002o`000006ok>aeone[m?o]JoCokF_
donc/]Oo00001?nd/]L00onb]=[o];?HokBcf002ok:ef`04okBdf?nb]]co/[KLok:fg0;o/KSN0_nb
]m`00on`^Moo/[SMok2ih002ok2ih0;o[k[R00?o/;[Qooooool000009?ooool000Wooooo00@00000
oooooooooooooooo6P00000701TI6@050000000c<c<0<c<c03<c<`0000000P1<C4`010000000IVIV
06IVIP00000207moO`050000002IVIT000000;>c/`0000000P3<c<`010000000i^KVo`000?l0000;
0?ooo`04o`00003Vi^H0i^KV00000080c<c<00@000000;>c/`2c/k<000000P2IVIT00ol00000Ogmo
07moO`02000000<0IVIV0P00000604a<C00300000?l00000<c<c00P0<c<c0`00000?01TI6C000000
1?ooool00`00003oooooooooo`0Fooooo`04o`000?ooooooooooo`0000?ooooo00Go/9>iok2E^on`
UK_o/9Fkok2I_`02ok6A]@?o/IFj00?o/9[1ok6A]OnaTKD00onaU[`3ok6B]`?o/9Vo1?n`UK/00on_
WLGo/I:gok6B]`02ojnJ`@04ok6?/on`Ukgo/9Nmok2G_@;o[Yo700Go/9BjojjKa?n^VlCo[Y_4ojfS
c@02ojjI`@?o[J3:00?o[:KAojfMaon]WLL00on/Xlh00on/Ym?o[:3;ojbTc`03ojbTc`03ojbWd_n/
XLco[JG?00?o[JG?00?o[JOAojfRc?n^Y<h00on^Y<h00on^Ym3o[j;;ojnUc@02ojnUc@;o/:O?00Go
/:?:ok6UcOnaYLgo/JG=ok6Xc`03ok:TbP;o/ZO=1?ncY//00oncZLko]:G9okBXc@03okBXc@03ok>[
d?neZ<co]JS<00;o]:_?0ol000001?neZloo]:kCokJ/conf[<l3okF_d`;o][3C00Co0000okBbeond
/]Oo][7D0ond/mP4okBdf003ok:fg?nd]MWo/[OL00;o/[OL00Ko];KJok:hgOnb^=go/[SMok2ih?nb
^Mh4ok2jh@03o`000?oooooooooo02;ooooo0009ooooo`0400000?oooooooooooooooa/000001`0I
6AT01Ol00000<c<c03<c<`0c<c<000000080C4a<00@0000006IVIP1VIVH000000P1oOgl01@000000
VIVIo`00002c/k<000000080c<c<00@000000>KViP3Vi^Ko00002`3oool01ol00000i^KV0>KVi_l0
000000000<c<c?l000000P2c/k<20000000309VIV@00000000000080Ogmo00?o000006IVIP1VIVH0
0P1VIVH2000000H0C4a<0P00000:03<c<`030000000I6AT06ATI00d06ATI00?o0000000000000000
;0000004ooooo`0300000?oooooooooo01Kooooo00Ko0000ooooooooooooooooo`000?ooool3ok2C
^@;o/9Fk1?naTKD2ok6E^PCo/I6e00?o/IJlok6=/?naT[L00onaT[L00on`VKoo/Hnbok6?/P02ok2E
^`05ok6<[onaT[Oo/I:gok6B]on_V/400_naSk<3ok2G_@Co/9Bj0_n^Vl@4ojjI`@03ojfPb_n^U[ko
[Ig700?o[Ig700?o[:?>ojfJa?n/X</00_n/X</2ojbTc`04ojbMaon/XLco[:7<ojbQc0;o[JG?00Co
[Ik9ojfRc?n]X/co[J;<0_n^Y<h01_n^WlSo[j;;ojnRbon_X/_o[jG=ok2Pb0Co/:?:00?o/JG=ok6Q
aonaXLL00onbY<X00onbYlgo/j?8ok>Sb002ok>Vb`04okBRa_ndYLWo]:G9okBUb@;o]:S=00?o]JG8
okFXc?neZ<`00ol00002okJXb`;o]J_?1?nf[<l01_ne[m?o]jg?okN]conf/=?o^:k@o`0000?o][7D
00?o];?HokJbe?nf/]@00_nd]=P01Onf/mKo];GIokBefOnd]MWo/[OL00?o];KJ00?o/[SMokBgg?nb
^Mh00_nb^Mh2ok2jh@;o/K[P00?o0000ooooooooool08Oooool000Wooooo00@00000oooooooooooo
oooo6`00000701TI6@050000000c<c<0<c<c03<c<`0000000`1<C4`01P000000IVIV06IVI_l00000
Ogmo00000080VIVI00<000000;>c/ol000000P3<c<`01?l00000i^KV0>KVi_l0000:0?ooo`05o`00
003Vi^H0i^KV0>KViP0000000P3<c<`01@000000/k>c0;>c/`2c/k<000000080VIVI00<0000007mo
O`1oOgl00P00000406IVIP030000001<C4`0C4a<00D0C4a<0P00000903<c<`03o`00000000006ATI
00d06ATI;P000004ooooo`0300000?oooooooooo01Gooooo00?o0000ooooooooool00_ooool5ok2C
^@03ok2E^onaSk?o/I6e00?o/I6e00?o/IFjok6=/?naTKD00onaTKD3ok6=/0;o/I:g00Go/X^/ok6?
/_naSk;o/Hnbok2E^`02ok6<[`?o/I:g1?naSk<2ok2G_@05ok6=/?n`U;[o/9Bjok2D^_n^Vl@00_n`
TKL2ojjI`@04ok2?]?n^U[ko[YJnojjF_P;o[Ig700Ko[Y>kojfJa?n]V/Co[I[4ojbPbon]Ul44ojbM
a`03ojbQc?n]V/Co[Ik900?o[Ik900?o[J;<ojjLaOn^WlP00on^WlP2ojnRb`?o/:380on`XlX4ok6Q
a`03ok:Tb_ncX<Go/j?800;o/j?800Co/jK;okBRa_ndX/Ko]:;60_ndYLT2okFUb0?o000000?o]jG7
okJXbonfZ</00_nfZ</00oneZloo]jW;okNYb`02okJ/c`04okRZbong[Loo]jg?okN]c`;o^:k@00Co
0000okR^d?nf/MCo^:o@0onf/]@01Onh/M;o][?FokJce_nf/mKo];GI00;o][CG0_nd]]X01Onf]]So
];OLokBgg?nd]mco/[WN00;o/kWM0_na^^000onc^]koooooo`00000Rooooo`002Oooool01000003o
oooooooooooooolL000000L06ATI00D0000003<c<`0c<c<0<c<c0000000304a<C0030000001VIVH0
00000080Ogmo00H0000009VIV@2IVIT000000;>c/`0000020<c<c0040000003Vi^H0i^KVo`0000X0
oooo00Go00000>KViP3Vi^H0i^KV000000020<c<c0050000002c/k<0/k>c0;>c/`0000000P2IVIT0
10000000Ogmo07moO`1oOgl2000000<0IVIV0P00000704a<C08000002@0c<c<00`0000006ATI01TI
6@0<01TI6Bd000001?ooool00`00003oooooooooo`0Eooooo`04o`000?ooooooooooooooo`Ko/9>i
0onaSk<2ok6A]@04ok6<[_naSK3o/Hf`ok6=/0;o/I6e00Go/X^/ok6=/?naSK3o/Hf`ok6B]`02ok:;
[0?o/Hnb1?naS:l2ok6B]`05ok::[?naSk?o/Hncok6?/on`Ukd00_naSK03ok2D^P?o/96g00Co[YW1
ok2?]?n`SkCo/8nd0_n^U[h4ojjC^`;o[I[40on]Ul43ojbMa`?o[I[40on]W/T3ojjLa@?o[Yo800?o
[j;;ojnMaOn_WLD00on`X<P00on`Xl[o/Ik5ok6Na@02ok6Qa`06ok:M`oncX<Go/j35ok>PaOncXlSo
]9o31?ndX/H01?ndYLWo0000o`000?l00002okFUb0?o]jG70_nfZ</01?nhY/Oo]jW;okNYbongZL/4
okRZb`03okN]coniZl_o^J_;00;o^:k@00Go0000okR_d?nh[m3o^:o@okJbe003okRadP03okJce_ni
/]?o][CG00;o][CG1?nf]]P00ond]mco][OJok>ig@02ok>ig@Co/k[N00?o0000ooooooooool08?oo
ool000Wooooo00@00000oooooooooooooooo6`0000000ol000006ATI01TI6@0601TI6@050000000c
<c<0<c<c03<c<`0000000`1<C4`00`000000IVIV0000000207moO`060000002IVIT0VIVI0000002c
/k<000000P3<c<`010000000i^KV0>KVi_l0000:0?ooo`05o`00003Vi^H0i^KV0>KViP0000000P3<
c<`01@000000/k>c0;>c/`2c/k<000000080VIVI00<0000007moO`1oOgl00P1oOgl00ol00000IVIV
06IVIP0206IVIP030000001<C4`0C4a<00H0C4a<00?o000003<c<`0c<c<01`0c<c<00`0000006ATI
01TI6@0<01TI6B`000001?ooool00`00003oooooooooo`0Eooooo`04o`000?ooooooooooojjD_0Go
/9>i00Go/8ndok6?/onaSk?o/Hncok6A]@02ok6<[P?o/Hf`00Co/I6eok:;[?nbRjco/X^/0_naSK04
ok:;[0;o/Hnb00Go/XRYok6<[onaS:oo/Hb_ok6B]`02ok::[0?o/Hnc1?naSK000on`U;[o/H^^ok2A
]`02ok2A]`Co/8nd00?o[YJnok2=/_n`SK800on^Tk/00on]V/Co[Y6hojjA^003ojfG`@03ojbMaon]
UKko[IFn00?o[I[400?o[Ik9ojfH`On]V<400_n^W<D2ojjOb004ojjJ`_n_WLGo[ig5ojnMa@;o/:38
00Go/9c3ok6NaOnaW/Go/Ik5ok6Qa`03ok:M``;o/j350ondWl<01?ndX/Ko0000o`000?l00003okJR
a@03okFUb?ngX/Co]j;400;o]jG71?nhY/L00ongZL_o^JO7okVWa`02okRZb`05okZXaoniZl_o^J_;
okV[bonh[]000_nj[<`00ol0003o^:o@okZ^c@03okRadP05ok^`coni/]?o^K;CokVbdonf]=L00_nh
]=D2okJff005okRfeonf]m[o][OJokJgf_nc^Md00_ne^=`2ok>jgP03okBjgOoooooo0000027ooooo
0009ooooo`0400000?oooooooooooooooad00000200I6AT01Ol00000<c<c03<c<`0c<c<0000000<0
C4a<00<0000006IVIP0000000P1oOgl200000004o`0000000000/k>c00000080c<c<00@000000>KV
iP3Vi^Ko00002P3oool2o`000080i^KV0P0000000`3<c<co0000000000020;>c/`030000002IVIT0
VIVI008000000P1oOgl2000000@0IVIV00?o00000000000000001@1<C4`3000000P0<c<c00?o0000
000000000000300I6AT[000000Cooooo00<00000ooooooooool05Oooool00ol0003oZYS4ojjD_002
ojjD_0;o/9>i00Co[Y6hok2?]?n`SkCo/8nd0_naSk<4ok6<[P;o/Hf`1?nbRj`2ok6=/005ok:8Z?nb
Rjco/X^/ok:;[?naSk800_nbR:T3ok6<[`Co/XZ/00?o/Hncok:8ZOnaSK000onaSK03ok6;[P;o/96g
00Co/HV[ok2?]?n`SkCo/8nd0on`SK83ojjC^`?o[Y6h0_n]Ul401?n^T;Ko[IFnojfE__n]UKh2ojfJ
a006ojfC^on]V<7o[IS1ojfH`On^W<Go[YJn1?n^V/800on_WLGo[iRook2L``03ok2L``03ok6NaOna
V/3o/Yg300?o/Yg300?o/j35ok>M`OncWL400ol000000ondX/Ko]Io2okFO`P02okJRa@05okNO`Ong
X/Co]j;4okNRa?ngYLL00_nhXl<3okRVa`?o^JO700Ko^:[;okZXaonjZ<Oo^ZS7okV[bonkZLP3okZ/
c005okb[bOl0003o^Zk=okZ^cOnh/M800onk/<l00oni/]?o^k;AokRde@02okRde@Co^;KG00Go][OJ
okRgf?nh]mSo]KSLokNifP04okBjg@03ooooool0003ooooo01oooooo0009ooooo`0400000?oooooo
oooooooooad000002@0I6AT01@000000<c<c03<c<`0c<c<0000000<0C4a<00@0000006IVI_l00000
00000P1oOgl01@000000VIVI0000002c/k<000000080c<c<00?o00000>KViP3Vi^H00_l0000:0?oo
o`05o`00003Vi^H0i^KV0>KViP0000000P3<c<`010000000/k>c0;>c/`00000309VIV@050000001o
Ogl0Ogmo07moO`0000001P1VIVH00`000000C4a<04a<C00504a<C08000002@0c<c<00`0000006ATI
01TI6@0;01TI6BT000001?ooool00`00003oooooooooo`0Eooooo`03o`000?nZV<CoZYS400;o[YBl
00?o/9>iojjA^?n^TKP00on`Sk@2ok6?/`04ok6<[onaS:ko/Hb^ok6<[P;o/Hf`00Go/XV[ok:;[?nb
Rjco/X^/ok6=/002ok:8Z0?o/X^/0onbR:T3ok6<[`Co/XZ/0onbR:T2ok6=/005ok>7YonaRjko/H^^
ok6;[_n`TKL00_naRJ/3ok2?]0Co/8fb00?o[Y>kok2</?n^TKP00_n^TKP4ojj@]P;o[IFn1?n]Tk/2
ojfH`@?o[YJn0on^V/83ojnH_`?o/9c30onaV/03ok:M``03ok>M`Ol0003o000000;o]9o300Go]Ibo
okFO`_neWl;o]Io2okJRa@03okNO`@;o]j;41?nhXl<00onhY/Oo^JC3okVT``02okVWa`04ok^U`onj
Z<Oo^ZS7okZXa`?o^jW800Ko^Zc<okb[bOnlZlWo0000okZ^cOnl[L/3ok^`c`05okf_c?nk/]7o^k;A
ok^bdOnh]=D00_nk/m<2okRfe`04okZfeOnh]mSo^;OHokRgf0?o]kWJ0_nd^]d2okJjg003o`000?oo
oooooooo01kooooo0009ooooo`0400000?oooooooooooooooah00000200I6AT00`000000<c<c03<c
<`0203<c<`050000001<C4`0C4a<04a<C00000000P1VIVH00`000000Ogmo0000000209VIV@030000
002c/k<000000080c<c<00D000000>KViP3Vi^H0i^KVo`00000:0?ooo`05o`00003Vi^H0i^KV0>KV
iP0000000P3<c<`010000000/k>c0;>c/`00000309VIV@040000001oOgl0Ogmo07moO`8000001@1V
IVH2000000L0C4a<00<0000003<c<`0c<c<01`0c<c<00`0000006ATI01TI6@0;01TI6BP000001?oo
ool00`00003oooooooooo`0Eooooo`05o`000?nZV<CoZYS4ojjD_?nZUL001?n^TKP2ok2?]003ok6?
/onaS:oo/Hb_00?o/Hb^00?o/Hf`ok:9ZonbRJ/00onbRj`3ok:8Z0?o/X^/1?nbR:T00onaS:oo/hNV
ok>7YP03ok::[0?o/XRY00Co/Hf`ok>7YoncQjOo/hNW0_naRjh4ok69Z`03ok2?]?nbR:[o/XRZ00?o
/8fb0on`S;02ojjA^005ok2;[_n^T;Ko[Y2fojj@]_n]UKh00_n_S[@3ojfC^`03ojfH`On^T[Wo[YJn
00?o[YJn00?o[Y[2ojnE_?n_V;l00on_V;l00on`W<?o/9Nmok2G_@03ok6J`0?o00000_ncWL44okFL
_`;o]Io21?ngWl400ongX/Co^:30okRP`002okRS``05okZQ_oniY<?o^JC3okVT`oniYlL00onkYL<0
0onjZ<Oo_:O4okbWa002ok^Yb005okfXaOnlZlWo_:_9okb[bOl000000_nl[L/01_nk/<oo_Jo<okf_
c?nm[lco^k;Aokfac`?o^k?C1?nj]]D01?nh]mSo^[OGokZgeong^MX2okVif@;o][[L00?o^;[Loooo
ool000007oooool000Wooooo00@00000oooooooooooooooo7P00000901TI6@030000000c<c<0<c<c
0080<c<c00D0000004a<C01<C4`0C4a<0000000206IVIP030000001oOgl000000080VIVI00Ko0000
0;>c/`00003o00000<c<c00000030>KViP03o`00003oool0oooo00P0oooo00Go00000>KViP3Vi^H0
i^KV000000020<c<c0050000002c/k<0/k>co`00000000000P2IVIT00ol00000000007moO`0207mo
O`8000001@1VIVH00`000000C4a<04a<C00504a<C003o`00000c<c<0<c<c00L0<c<c00<0000001TI
6@0I6AT02`0I6ATW000000Cooooo00<00000ooooooooool05?ooool01?l0003oooooojZHa?nQVlh3
ojZE`0?o[Y6h00?o/8ndojn>/onaS:l00_naS:l3ok6<[P?o/XV[0onbRj`4ok:8Z003ok:;[?ncQZGo
/hJU00?o/XRY0oncQjH2ok::[004okB5Y?nbR:Wo/XRYok:8Z@Co/hNW0_naRjh4ok69Z`?o/XRZ0_n`
SK801OnbQjSo/8b`ok2</?n`S;3o[Y6h00;o/8^^0on^T;H3ojn>]0?o[I>k0on^T[T2ojjF_P04ojn@
]on_UKco[iFlojnE_0;o[iRo00Co/9Bjok2G_On`Ukgo/9Nm0ol00003ok>J_P03ok>M`OndVKco]9Vl
00?o]Ibo00?o]Io2okJL_OnfW;d00_ngWl401OnhWKgo^:30okRP`?nhX<3o^:?300?o^Z6o00?o^JC3
ok^R_onkYL<00_nkYL<01OnmY<3o_:O4okbWa?nlYlCo^jW800?o_JS500Go_:_9okj[a_nnZlKo0000
okb]b`03okf_c005okn_b_nm/Loo_K7?okfaconk/m<00_nm]=42okZfe@;o_;KC00?o^[OGokbhe_ni
^MT00_ni^MT4okRjg003ooooool0003ooooo01gooooo0009ooooo`0400000?oooooooooooooooah0
00002@0I6AT00`000000<c<c03<c<`0303<c<`04o`00001<C4`0C4a<o`0000<0IVIV00?o000007mo
O`0000000P2IVIT00`000000/k>c000000020<c<c004o`00003Vi^H0i^KV0>KViP;o0000203oool0
0ol00000i^KV0>KViP020>KViP040000003<c<`0c<c<000000<0/k>c00D0000009VIV@2IVIT0VIVI
0000000407moO`030000001VIVH0IVIV00<0IVIV00<0000004a<C01<C4`01@1<C4`2000000P0<c<c
00?o000001TI6@0I6AT02`0I6AT00ol0000000000000000S000000Cooooo00<00000ooooooooool0
5?ooool00ol0003ooooooj6KcP02oj6KcP;oZYG00on^TKP2ojn>/`Co/Hb_00?o/Hb^ok::ZonbRJ/0
0onbRJ/00onbRjco/hNWok>7Y`03ok:8Z0?o/hJU0_nbR:T01OndQJ?o/hNVok>7Y_ncQjKo/XZ/00?o
]8FT0_nbR:T4ok>7Y`03ok6;[_ncQZGo/hJU00?o/HV[0onbR:X01?n`SK;o/XNXok:7Z?nbQjP2ok2<
/0Co/8^^00?o[Y2fok2:[On_S[@00on_S[@00on]Tk_o[hfbojjB^@02ojjB^@04ojjF__n_T;Oo[i2g
ojn@]`;o[iFl00?o[iRook2D^_n`U;X00ol00004ok:G^`;o/iZn1?ndVK`00oneW;oo]YZkokJL_@02
okJL_@04okNO`OnhWKgo^9fmokRM_@;o^:301?njXKl3ok^R_`04ok^U`onmY<3o_JC0okfT`0;o_:O4
0onmZ<D02?noZ<;o_Z_6okj[a_nnZlKo_:g;o`000?no[LSo_Jo<0ono[lX00onm/Loo_k;=okfdd@02
okfdd@04okndd?nl]]?o_;KCokbfd`?o_;SF00?o^KWIokZjfOnj^]T00_nh^]`2okVkf`03o`000?oo
oooooooo01cooooo0009ooooo`0400000?oooooooooooooooal000002@0I6AT00`000000<c<c03<c
<`0203<c<`050000001<C4`0C4a<04a<C00000000P1VIVH010000000Ogmo07moO`00000209VIV@03
0000002c/k<000000080c<c<00<000000>KViP3Vi^H00P3Vi^H00ol00000oooo0?ooo`060?ooo`03
o`00003Vi^H0i^KV0080i^KV00@000000<c<c03<c<`000000`2c/k<01@000000VIVI09VIV@2IVIT0
000000@0Ogmo00<0000006IVIP1VIVH00`1VIVH2000000L0C4a<00<0000003<c<`0c<c<01P0c<c<0
0`0000006ATI01TI6@0;01TI6BD000001?ooool00`00003oooooooooo`0Dooooo`03o`000?oooooo
oooo00;oXI_>0onZUL000on^TKSoZi:lojn>/`02ojn>/`;o/Hb_00Co/8b`ok::ZonbRZ_o/XZ[0onb
RJ/3ok>7Y`;o/XRX00Go]8JTok>6YOncQZGo/hJUok:8Z@02okB5X`?o/hNV1?ndQJ@00onbR:Wo]8FR
ok>7Y`03ok>7Y`?o/hJU0_naRJ/2okB5Y0;o/XRZ1?nbQjP2ok2</0Co/8^^0on`RZd2ojn>]004ok29
[?n_SK;o[hfbojn=/P;o[Y:i1?n_T;L00on_UKco[i2eo`000002o`000003ok2D^_n`Ukgo/I>h00Co
/YNk00?o/iZnok>F^OncU[T00_ndVK`01?neUkSo]YZkokJJ^onfV[/2okJL_@Co^9fm00?o^:30okZN
_?njW[`00onjXKl00onkWkco^j:ook^R_`04okfT`004okbWa?nnY/7o_ZK1okfXa@?o_jS20_nnZlH0
1?no[LSo0000okn]b?o1[LH3okn_bP?o_k;=00Go_KCAokndd?no]=3o_kC@okbfd`02okjgdP03okbh
e_nm^MGo^[[I00;o^[[I0oni^m/00onk_=_oooooo`00000Mooooo`002Oooool01000003ooooooooo
oooooolO000000T06ATI00<0000003<c<`0c<c<00`0c<c<01@000000C4a<04a<C01<C4`000000080
IVIV00@0000007moO`1oOgl000000P2IVIT00`000000/k>c000000020<c<c0030000003Vi^H0i^KV
0080i^KV00?o00000?ooo`3oool01P3oool00ol00000i^KV0>KViP020>KViP04o`00003<c<`0c<c<
o`0000<0/k>c00Go000009VIV@2IVIT0VIVI0000000407moO`030000001VIVH0IVIV00@0IVIV00<0
000004a<C01<C4`01@1<C4`00ol00000<c<c03<c<`0603<c<`030000000I6AT06ATI00/06ATI9000
0004ooooo`0300000?oooooooooo01Cooooo00Co0000oooooooooooooooo0_nQVlh00onZUL3oX9W=
oj^B_002oj^B_0;o[hjc00?o/Hb_ok2</?n`S;000onbRZ/2ok:9Z`05ok>8Z?ncQjOo/hNWok>7Yonb
R:P00_ndQZ@3ok>6Y@Co]8FS0_ncQjH4okB5Y003ok:8ZOndQJ;o]8FR00?o/hNW0oncQZD01?naRJ_o
]8FTokB5Y?ndQJ@2ok:8ZPCo/XNX00?o/8b`ok:7YonbQjL00_n`Rjh01OnbQjKo/8Z]ok2:[On`RZgo
[hjd00;o/8V/0on_SK800on^T[Wo[hbaojn</@02ojn@]`?o000000Co[i2eok2D^_n`U;[o/9Bj0ona
TkP2ok:G^`05ok:C]_ncU[Wo/iJiok>F^OndVK`00_neUkP3okJJ^`03okJL_OnhV[[o^9Zj00?o^9fm
1?njW[`01?njXKoo^inlok^O_?nkX[l2okfQ_@?o_JC00onnY/44oknX`P05okj[a_o0ZlCo`:_4okn]
b?l000000_o1[LH00ono[l[o`[39ol:`b@02oknbc@?o_kC@00Co`KK?okjgd_nn]m;o_[OB0onm^MD0
1?nj^]Wo_;_Hokbkf?ni^m/3ok^lf`03ooooool0003ooooo01_ooooo0009ooooo`0400000?oooooo
ooooooooob0000002@0I6AT00`000000<c<c03<c<`0303<c<`050000001<C4`0C4a<04a<C0000000
0P1VIVH01P000000Ogmo07moO`000000VIVIo`000080/k>c0P0000000`3<c<`00000o`0000020>KV
iP;o0000203oool2o`0000<0i^KV00<000000<c<c03<c<`00P0000020;>c/`8000000P2IVIT20000
00<0Ogmo0P00000506IVIP8000001P1<C4`2000000L0<c<c00<00000o`00000I6AT02`0I6AT00`00
003o00000000000P000000Cooooo00<00000ooooooooool05?ooool01?l0003oooooooooooooool2
oh>OiP?oX9W=0_n[T[`2ojn>/`Co/8b`0_nbRZ/00onbRJ_o/hRXok>8Z003ok>7Y`Co]8JT0_ncQZD4
okB5X`03ok>7Y_neQ:7o]8FT00?o]8FT0ondQJ82ok>7Y`04okF4XOncQZGo/hJUok>6Y@Co]8FT00?o
/XRZokB5XondQJ<00onbQjP3ok:7Y`04ok2;[_nbQjKo/XNVok:7YP;o/8Z]1?n`RJ`2ojn=/P;o[hba
0ol000000on`S;3o[i2eojn@]@02ojn@]@03ok2D^_naT;Co/I>h00;o/I>h00Co/YNkok:C]_nbTkKo
/Y>f0_ncU[T4okFG^0;o]YZk1?nhV[X00onhWKgo^I^iokVK^@02okZN_004ok^M^OnkWkco^inlok^O
_0Co_J6m00?o_JC0oknS_OnoXkd00_nnY/401?o0Y[oo_jS2oknX`_o2Z<03ol2[a0;o`Jg600?o0000
olB^aOo2/<T00_o2/<T01?no//go`[?<ol:cc?no]=03ol6fc`04okjgd_o1^=;o`KSBokfie@;o_k[E
00?o_;_Hokjlf?nn_=P00_nk_=/00onl_]_oooooo`00000Looooo`002Oooool01000003ooooooooo
oooooolP000000T06ATI00<0000003<c<`0c<c<00`0c<c<00`000000C4a<04a<C00204a<C004o`00
001VIVH0IVIVo`000080Ogmo00<0000009VIV@0000000`2c/k<010000000c<c<0<c<c00000030>KV
iP;o00001`3oool00ol00000i^KV0>KViP020>KViP050000003<c<`0c<c<0<c<c00000000`2c/k<2
00000080VIVI0P00000307moO`8000001@1VIVH2000000H0C4a<00<0000003<c<`0c<c<01P0c<c<0
0`0000006ATI01TI6@0;01TI6B4000001?ooool00`00003oooooooooo`0Dooooo`03o`000?oooooo
oooo00;ooooo0_n3WnH2oj2Ic@;oZi:l00?o[hjcojb@^On`S;000on`S;02ok::Z`Co/hRX0_ncQjL4
okB6Y003ok>6YOneQJ;o]8FS00?o]8FS00?o/hNVokF4XOneQ:400ondQJ@3okB5XP04ok>7YoneQ:7o
]HBQokF4X@;o/hJU1?ndQJ@3okB5X`;o/XNX00Co]HFRok:7YonbQjOo/XNW1?nbQjH2ok2:[@Co/8V/
00Co[hfbo`000?l0003o00000_n_S;43ok2</0;o[i2e00Co/Hb_ok6@]?naT;Co/I2d0_naTkP4ok:C
]P03ok>F^OndTkGo]9>e00?o]INh00?o]YZkokNG]ongUkL00_nhV[X01OniVKOo^I^iokVK^OniVkWo
^Yjl00?o^ifi0_nkWk`01?nmWk[o_J6mokfQ_OnoXKX3oknS_@04okjV`Oo0Y[oo`:JooknX`P?o`ZS0
00Go`:_4ol>[`oo3Zl?o`Jg6o`000002olB^a@;o`[390oo2/l`3ol6fc`04olBhc_o1^=;o`KSBol6h
dP?o_k[E0onn_=P4okbnf`03ooooool0003ooooo01[ooooo0009ooooo`0400000?oooooooooooooo
ob4000002@0I6AT00`000000<c<c03<c<`0303<c<`050000001<C4`0C4a<04a<C00000000`1VIVH0
1P000000Ogmo07moO`000000VIVI000000<0/k>c00@000000<c<c03<c<`00000103Vi^H00ol00000
oooo0?ooo`050?ooo`03o`00003Vi^H0i^KV0080i^KV00Go00000<c<c03<c<`0c<c<o`0000040;>c
/`050000002IVIT0VIVI09VIV@000000101oOgl00ol00000IVIV06IVIP0406IVIP03o`00001<C4`0
C4a<00@0C4a<00?o000003<c<`0c<c<01P0c<c<00`0000006ATI01TI6@0;01TI6B0000001?ooool0
0`00003oooooooooo`0Cooooo`03o`000?oooooooooo00Gooooo0_mdW>X2oinGc0?o[92i0on`S;00
0onbRZ_o/H^]ok>8Z003ok>8Z003ok>7YondQjKo]8JT00?o]8JT00?o/hJUokF5X_neQJ800ondQJ<3
okF4X@;o]8FT00Co]XBOokB5X_ndQJ;o]8FR1?neQ:400oncQZGo]XBPokB5Y003okB5Y0?o]8FS00Co
/XNXokF5X_neQJ;o]HFR0_nbQjL01OneQJ;o/XNVok:7Y_nbQjKo/8Z]00;o/hJV00Co/8V/o`000?l0
003o00000_naRJ/2ojn</@05ok69Zon`S;3o/8b`ok2</?n_T;D00_naS:l3ok6@]003ok6C^?nbT;?o
/Y2c00?o/Y>f0ondTkD3okFG^0?o]iNg00Co^9ZjokVI]oniVKOo^IVg0_niVkT4ok^M^@04ok^O_?nm
Wk[o_InjokfQ_@?o_j6j0_noXkd3ol2V_`Co`ZS00oo3Zl<2olB^a@03o`000?o4[/Go`[3900;oa;78
00Co`[?<olBdboo4]<_o`KK?0oo4^<h01?o1^=;o`k[Bol>jd_no^]D2ol6le@03okjlf?no_]Wo_kkI
00;o_;kK0_nm`=`00ol0003oooooooooo`0Iooooo`002Oooool01000003ooooooooooooooolQ0000
00X06ATI00<0000003<c<`0c<c<00`0c<c<01Ol00000C4a<04a<C01<C4`0000000<0IVIV00L00000
07moO`1oOgoo000009VIV@00003o00000080/k>c00@000000<c<c03<c<`00000103Vi^H00ol00000
oooo0?ooo`050?ooo`03o`00003Vi^H0i^KV0080i^KV0P0000020<c<c0030000002c/k<0/k>c0080
/k>c00Co000009VIV@2IVIT0VIVI0P00000307moO`030000001VIVH0IVIV00@0IVIV00<0000004a<
C01<C4`0101<C4`00`000000<c<c03<c<`0603<c<`800000300I6ATO000000Cooooo00<00000oooo
ooooool04oooool00ol0003oooooooooo`06ooooo`;oM9cZ0_nOUl`2ojb@^@;o/8b`00Co[Hngok6;
[OnaRjgo/H^]0oncR:P00oncQjOo]8NVokB7YP03okB6Y0?o]HFR0ondQJ<3okF4X@04okB5Y?nfQ9oo
]XBOokJ4W`;o]8FR1?neQ:400oncQZGo]XBPokJ4X002okB5Y004okN4WondQJ?o]8FSokB5X`Co]HFR
00?o/XNWokF5X_neQJ800onbQjH2ok>6YP;o000000?o/8V/ok>7Y_naRJ/00_naRJ/01?n_S;7o/HV[
ok69ZonaRJ/2ok2</0Co/Hb_0_naT;@3ok:@/`?o/Y>f1?ndTkD00oneUkSo]YBdokJD]002okNG]`Co
^IVg00?o^I^iok^J]onkV[L00_nkWKT01?nmW;Oo_InjokfO^_nmWkX4oknQ^P04oknS_Oo1Xk_o`J>k
ol2V_`;o`jJm0oo2Z<001?o4ZKoo`j_3ol>[`oo5[L82olB^a@04o`000?o4/LSoa;78olBab0?oa;C;
0oo4^<h01_o6^/oo`k[Bol>jd_o3^];oaKgBol6le@;o`koF00?o_kkIol71fOnm`=`00_nm`=`00onn
`]goooooo`00000Jooooo`002Oooool01000003ooooooooooooooolQ000000X06ATI00<0000003<c
<`0c<c<00`0c<c<01@000000C4a<04a<C01<C4`0000000<0IVIV00@0000007moO`1oOgl000000`2I
VIT00`000000/k>c000000030<c<c0030000003Vi^H0i^KV0080i^KV00?o00000?ooo`3oool01@3o
ool00ol00000i^KV0>KViP030>KViP040000003<c<`0c<c<000000@0/k>c00<0000009VIV@2IVIT0
0P2IVIT01@000000Ogmo07moO`1oOgl0000000H0IVIV00<0000004a<C01<C4`0101<C4`00`000000
<c<c03<c<`0703<c<`030000000I6AT06ATI00T06ATI00?o000000000000000070000004ooooo`03
00000?oooooooooo01?ooooo00?o0000ooooooooool02?ooool2oinGc0;o[92i00?o/8b`ojf?]on]
SkL00onaRjd2ok>8Z004ok>:ZondQjKo]8NVokB7YP?o]8JT0oneQJ82okB5X`04okJ5X?neQ:7o]HBQ
okF4X@Co]XBO00?o]8FRokN4W_neQ:400oneQ:43okJ4X004okB5Y?ngQ9oo]hBOokN4W`;o]8FS1?ne
QJ800onbQjOo]HFRokF5XP02ok:7YP?o000000?o/hJVok29[?ncQjH00_ncQjH6ok69Z`;o/8b`00Ko
/XV[ok6<[onaS:oo/Hb_ok6@]?nbSJl4ok:@/`03ok:C]_ncT;;o/i2b00;o]9>e00Go]Y6aokJD]?nf
U;Co]YBdokNG]`02okRF]0?o^IVg0onkV[L01?nkWKWo_IbgokfL]onmW;L2okfO^P04oknN]onoXK[o
_j6jol6Q^@?o`J>k1?o3Y[d01?o2Z<3oa:VoolBY_oo3Zl<2olF]`P05olB^aOo6/<Coa[34o`000?o4
/LP00_o7/lL01?o4]<_oakO;olNgboo4^<h3olJjc`03ol>jd_o5_M;oaKgB00?o`koF0oo1`MT01_nm
`=co_/;Mokk2gOnn`]goooooo`0001Wooooo0009ooooo`0400000?ooooooooooooooob4000002`0I
6AT00`000000<c<c03<c<`0303<c<`050000001<C4`0C4a<04a<C00000000`1VIVH010000000Ogmo
07moO`00000309VIV@030000002c/k<0000000<0c<c<00<000000>KViP3Vi^H00P3Vi^H00ol00000
oooo0?ooo`040?ooo`03o`00003Vi^H0i^KV00@0i^KV00@000000<c<c03<c<`00000102c/k<00`00
0000VIVI09VIV@0209VIV@040000001oOgl0Ogmo07moO`8000001@1VIVH00`000000C4a<04a<C004
04a<C0030000000c<c<0<c<c00L0<c<c00<0000001TI6@0I6AT02@0I6ATN000000Cooooo00<00000
ooooooooool04oooool00ol0003oooooooooo`09ooooo`03oefGk_nMUlgoWIO=00Co[Hng0_naRjd0
0oncR:So/hZ[ok>:Z`03okB7YP;o]8JT00Go]HNTokF5X_neQJ;o]HFRokB5X`03okJ5X0;o]HBQ1?nf
Q9l00ondQJ;o]hBNokN4WP03okF4X@?o]XBP00Go]8FTokN4WongQ9oo]hBOokB5X`02okN5WPGo]HFR
0ol000001?nfQJ;o/hJVok>6Y_ncQZH4ok>7YP;o/HV[00Go]8NVok69ZonaRJ_o/HV[ok2</002ok:9
Z`?o/Hb_0onbSJl2ok:@/`05ok>>[_ncT;;o/i2bok>@/_ndTkD00_nfTK43okJD]0?o^9Jd0oniVKL3
ok^J]`Co_Ibg00Co_InjoknN]onoW[Oo_j6j0oo1XKT2ol6S^`04ol>T^_o3Y[go`jJmolFX_0?oa:Vo
0oo5[L83olJ`a004o`000?o7/lOoak?7olNca`?oakO;00?obK[<olJjcoo6^/l00_o8_M001?o5_M;o
akoColNodoo3_mH2olC2e`03ol71fOo2`m_o`/?K00;o_/;M00?o_lCNooooool000006Oooool000Wo
oooo00@00000oooooooooooooooo8P00000:01TI6@030000000c<c<0<c<c00<0<c<c00<0000004a<
C01<C4`00P1<C4`01@000000IVIV06IVIP1VIVH000000080Ogmo00L0000009VIV@2IVIT0VIVI0000
002c/k<0000000<0c<c<00<00000o`00003Vi^H00P3Vi^H00ol00000oooo0?ooo`040?ooo`03o`00
003Vi^H0i^KV00<0i^KV00D000000<c<c03<c<`0c<c<000000040;>c/`030000002IVIT0VIVI0080
VIVI00?o000007moO`1oOgl00P1oOgl00`000000IVIV06IVIP0306IVIP030000001<C4`0C4a<00@0
C4a<00<0000003<c<`0c<c<01`0c<c<00`0000006ATI01TI6@0901TI6Ad000001?ooool00`00003o
ooooooooo`0Cooooo`03o`000?oooooooooo00[ooooo00?oGIO^oifGcOnMUld00on]SkL2ok6;[@?o
/hZ[0ondQjH01?ndQZCo]HNTokF7Y?neQj@2okF5XPCo]XFP00?o]HBQokN5WonfQ9l00onfQ9l00ond
QJ;o]hBNokN4WP02okF4X@04okR5W_nfQ:3o]XBPokJ4X0Co]hBO00?o]8FSokN5W_ngQIh00_neQJ83
o`0000;o]HFR00?o/XNVokJ5X_nfQJ800_ncQZH01OnfQZ;o/hNVok>7Y_ncQjKo/HV[00;o]8NV0ona
RJ/3ok:9Z`?o/Hb_0onbSJl00onbT;?o/hj^ok>>[P03ok>@/PCo]Y6a0_nfU;@4okRF]003okVI]onj
V;Co^YRd00;o^iZg00Co_IZdokfL]onmW;Oo_Ibg0onoW[L4ol6Q^@04ol6S^oo3Y;[o`jBjol>V_@?o
aJRl00Coa:VoolN[__o7ZkkoaJg20_o8[l401Oo6/<CobK?4olVca?l0003oak?700;obKK800?oakO;
olVjc?o9^/`00oo8_M001?o:`M7oakoColNodoo7_m<3olC2e`?o`/?K00?o`lKLoko4g_noa]l00_oo
ool00ol0003oooooooooo`0Fooooo`002Oooool01000003ooooooooooooooolR000000/06ATI00<0
000003<c<`0c<c<00`0c<c<00`000000C4a<04a<C00204a<C004o`00001VIVH0IVIVo`0000<0Ogmo
00Co000009VIV@2IVIWo00000P2c/k<01@000000c<c<0<c<c03<c<`0000000@0i^KV1?l000030?oo
o`03o`00003Vi^H0i^KV00<0i^KV00@000000<c<c03<c<`0c<c<0P0000030;>c/`8000000P2IVIT2
000000@0Ogmo00?o00000000001VIVH00`1VIVH2000000D0C4a<0P00000703<c<`03o`00000I6AT0
6ATI00X06ATI00<00000o`00000000006@000004ooooo`0300000?oooooooooo01?ooooo00?o0000
ooooooooool03?ooool01_nMUlgo[Hngojf?]on]SkOo/H^]ojj?]PCo/hZ[0_ndQjH4okF7Y0;o]HFR
1?nfQJ000oneQ:7o]hFOokJ4W`03okJ4W`?o]hBN00Co]HBQokR5W_nhQIko^8FN0_nfQ:04okN4W`03
okB5XongQIko000000;o000000?o^8FNokF5X_neQJ800_neQJ83okJ5XP03ok>6Y_nfQZ;o]XJR00?o
/hNV0ondQjH3ok69Z`Co/XV[00?o/Hb_ok>:Z_ncRZX00_nbSJl4ok>>[P;o/i2b00Go]Hn^okJA/Onf
TK7o]Y6aokJD]002okRC/@;o^9Jd00Go^YFaokZH]?njV;Co^YRdok^J]`02okfJ]0?o_Ibg00Co_ibe
oknN]onoW[Oo`Inf0oo1XKT3ol>T^PCoaJRl0oo7Zkh3olR_`@05ol^b`_o9/lCobK?4olVca?l00000
0_o9]/P01Oo<^/WobK[<olbncOo<_/gob;g@00?ob/7A00CoakoColS3eOo8`mGoa<;G0_o6aMT00oo2
`m_o`lKLol?6g003oko6g`;ooooo00?o0000ooooooooool05Oooool000Wooooo00@00000oooooooo
oooooooo8P00000;01TI6@030000000c<c<0<c<c00@0<c<c00Go000004a<C01<C4`0C4a<00000003
06IVIP050000001oOgl0Ogmo07moO`0000000P2IVIT010000000/k>c0;>c/`0000030<c<c0030000
003Vi^H0i^KV00D0i^KV00?o00000?ooool000001`3Vi^H00`000000c<c<0<c<c0020<c<c0030000
002c/k<0/k>c0080/k>c00D0000009VIV@2IVIT0VIVI0000000507moO`030000001VIVH0IVIV00<0
IVIV00<0000004a<C01<C4`0101<C4`00`000000<c<c03<c<`0503<c<`030000000I6AT06ATI00X0
6ATI6`000004ooooo`0300000?oooooooooo01;ooooo00?o0000ooooooooool03Oooool2ocJ<kP04
ojf?]onLV<oo[Xnfojj?]PCo/hZ[0_ndQjH4okF7Y003okF5X_ngQj;o]XFP00?o]XFP00?o]HBQokN5
WongQIl00onfQ9l3okN4WP06okF4XOnhQIko^8FNokR5W_nfQ:3o^HFM0ongQ9l3o`0000;o]hFN00?o
]HFRokR5W_nhQIh00oneQJ83okJ5XP03ok>6Y_nfQZ;o]XJR00?o/hNV1?ndQjH00onaRJ_o]8RVokB8
YP03ok:9Z`?o/hZZ0_nbSJl01OndRj_o/hj^ok>>[_ncSZko/i2b00;o]Hn^0onfTK43okRC/@04okRF
]?njUK7o^YFaokZE/@;o^YRd1?nmV[@01?nmW;Oo_ibeoknL]OnoW[L2ol6O]P?o`J6i00Coa:>gol>T
^_o3Y;[oaZJi0oo5Z;`01?o8Z[coaj^nolN[__o:[[h2olR_`@;obk;200CobK?4olbfaOo<]/Go0000
0_o<^/T3olbnc@?ob/7A0_o<aM<01?o8`mGobLOHolW7f?o6aMT2olK8f`04ol?6g?o3b=oo`lSOoko6
g`;o_lSQ00?oooooo`000?ooool05_ooool000Wooooo00@00000oooooooooooooooo8`00000;01TI
6@030000000c<c<0<c<c00<0<c<c00<0000004a<C01<C4`00P1<C4`01@000000IVIV06IVIP1VIVH0
000000<0Ogmo00@0000009VIV@2IVIT000000P2c/k<01@000000c<c<0<c<c03<c<`0000000L0i^KV
00?o00000>KViP3Vi^H01`3Vi^H00ol00000c<c<0<c<c0020<c<c0030000002c/k<0/k>c0080/k>c
00D0000009VIV@2IVIT0VIVIo`00000507moO`030000001VIVH0IVIV00<0IVIV00<0000004a<C01<
C4`0101<C4`00`000000<c<c03<c<`0503<c<`030000000I6AT06ATI00X06ATI6P000004ooooo`03
00000?oooooooooo01;ooooo00?o0000ooooooooool03_ooool00olfS>koW9S?oibHc`03ojj?]P?o
/hZ[00?o]8NVokB:ZOneQj@00oneQj@00oneQJ;o]hNRokN7XP03okJ5X0?o]hFO0_nfQ9l01?niQYko
]hBNokN4W_ngQ9h4okR5WP03okJ4X?niQIgo000000;o000000?o]hBOokN5W_ngQIh00_ngQIh00one
QJ;o^8FNokR5WP02okF5XP04okV6WonfQJ;o]XFRokJ5XPCo]XJR00?o/hNVokN7X_ndQjH00ondQjH3
okB8YP;o/XV[00Go]HVVok>:Z_ncRZ[o/hZZok:=[`02okB;Z`?o/hj^0oneSjh3okJA/@?o^9>a1?nj
UK400onjV;Co_9RbokbH/P02okfJ]004oknJ/_noW;Go_ibeoknL]@Co`Inf00Co`J6iolBS]oo4XkOo
`jBj0oo6Y[T01?o5Z;cob:ZlolRZ_?o7Zkh2olZ^_P04olR_`Oo;//;obk;2ol^b`P?oc;K500Go0000
olbjbOo<^/Wocko;olbnc@02olk2c`04ol[1dOo<aM?oc<GColg:eP?obLOH00Gob/_JolK8foo6c=ko
a/cNol?8g`02ol?;h@05oko8hOnnb^?o_/[Sooooool000005_ooool000Wooooo00@00000oooooooo
oooooooo8P0000000ol000006ATI01TI6@0901TI6@030000000c<c<0<c<c00@0<c<c00<0000004a<
C01<C4`00P1<C4`01@000000IVIV06IVIP1VIVH0000000<0Ogmo00@0000009VIV@2IVIT000000P2c
/k<01000003o00000<c<c03<c<`200000100i^KV00<000000<c<c03<c<`00P3<c<`00ol00000/k>c
0;>c/`020;>c/`040000002IVIT0VIVI09VIV@800000101oOgl00`000000IVIV06IVIP0306IVIP03
o`00001<C4`0C4a<00@0C4a<00?o000003<c<`0c<c<01@0c<c<00`0000006ATI01TI6@0:01TI6AT0
00001?ooool00`00003oooooooooo`0Booooo`03o`000?oooooooooo013ooooo0_nLV<l2ojj?]P;o
/hZ[00Co/92eokB:ZOndRZWo]8ZY0oneQj@3okN7XP?o]XFP0ongQIl01?nfQ9oo^HJNokV6W_niQYh2
okN4WP?o^8FN0ol000001?niQIgo]hBOokN4WonjQYd4okN5WP?o^8FN00Co]HFRokV6WoniQYoo^HJO
0_nfQJ84okJ6XP03ok>7Y_ngQj;o]hNR00?o]8NV0ondR:H01?nbRJ_o]HVVokF9Y_neRJH2ok>:ZP?o
]8^[0oncSZh4okF?[P03okJA/OngTJko]i6^00;o^9>a00Co^I>_okZE/OnjUK7o^YFa0onlV;801?nm
V[Co_iZboknJ/_noV[82oknL]@04ol6M]?o1WkKo`InfolBQ]@?oa:>g1?o6Y[T3olRZ_0?obZjn0oo;
//82oljf``04olbfaOo?^lOock_7o`0000;ocko;0oo>`/l00oo@am;oc<GColg:eP02olg:eP03olW7
f?o:bm[ob/oN00?oa/cN00Goa/oQol?;hOo2c^Co`/kTokk:h`02okg<i@03ooooool0003ooooo01Co
oooo0009ooooo`0400000?ooooooooooooooob<000002`0I6AT00`000000<c<c03<c<`0403<c<`03
0000001<C4`0C4a<00<0C4a<00Go000006IVIP1VIVH0IVIV0000000207moO`050000002IVIT0VIVI
09VIV@0000000`2c/k<01@000000c<c<0<c<c03<c<`000000100i^KV00<000000<c<c03<c<`00P3<
c<`2000000<0/k>c00<0000009VIV@2IVIT00P2IVIT00`000000Ogmo07moO`0207moO`030000001V
IVH0IVIV00<0IVIV00<0000004a<C01<C4`0101<C4`00`000000<c<c03<c<`0503<c<`030000000I
6AT06ATI00X06ATI00?o00000000000000005@000004ooooo`0300000?oooooooooo01;ooooo00?o
0000ooooooooool04_ooool2ojj?]P03ok>:Zon`T;Go/92e00?o]8ZY0_neQj@01?nfRjSo]hNRokN7
X_ngQj82okJ5X005okR7XOngQIoo]hFOokN5WonfQ9l00oniQYh00ongQ9ko^XJNokR5WP02o`000004
okR5W_niQIgo^HFMokV5W@;o]hBO00?o^XJMokN5W_ngQIh00_ngQIh3okR5WP06okF5X_niQYoo^HJO
okV6WonfQJ;o^XNO1?nfQZ83okN7XP;o]8NV00Co]hRSokB8Y_ndR:Ko]8RV1?neRJH2ok>:ZPCo]8^[
00?o/hj^okJ=ZonfSJ/00_neSjh01OnhSjco]i6^okNA[_ngTJko^9>a00;o^I>_0onjUK43okbH/PCo
_iZb00Co_ibeol6M]?o1WKCo`Inf0oo4XKD2olBS]`03olJU]oo6Y[WoaZJi00;obJVi0_o8Z[`01Oo;
[KcobZjnolfb_oo=/[oobk;200?oc[K30oo?^lL01OoB`<Wo0000om74c_oAa<koc/;?00;od<OB0oo=
b]H00oo>cm[ob/_Jol[?gP02ol[?gP03olK<g_o6cn7oaM;T00?o`/kT0onmc>D00ooooooo0000oooo
o`0Dooooo`002Oooool01000003ooooooooooooooolS000000`06ATI00<0000003<c<`0c<c<0100c
<c<00`000000C4a<04a<C00204a<C0030000001VIVH0IVIV0080IVIV00@0000007moO`1oOgl00000
0`2IVIT01@000000/k>c0;>c/`2c/k<0000000<0c<c<00<000000>KViP3Vi^H03P3Vi^H00`000000
c<c<0<c<c0030<c<c0050000002c/k<0/k>c0;>c/`000000102IVIT00ol00000Ogmo07moO`0207mo
O`030000001VIVH0IVIV00<0IVIV00<0000004a<C01<C4`0101<C4`00`000000<c<c03<c<`0503<c
<`030000000I6AT06ATI00X06ATI5`000004ooooo`0300000?oooooooooo01;ooooo00?o0000oooo
ooooool04_ooool2oiZKd`Co/92e0_ndRZT00oneQjCo]X^XokJ;Z003okN7XP03okJ5X?nhQj7o^8NQ
00?o]hFO1?niQYh3o`0000?o^8FN0oniQId01?ngQ9oo^XJMokZ6WOnjQYd2okN5WP04ok^7WOnhQIko
^8FNokR5WPCo^HJO00?o]XFRokZ7WonjQil00onfQZ83okN7XP04okB7Y_ngR:?o]hRSokN8X`;o]8RV
1?neRJH00oncRZ[o]XZWokJ:Y`03okB;Z`?o]Xf[00?o]Hn^okR?[?nhSj`00ongTJh4okVC[`03okZE
/OnlUJoo_9F_00;o_9Rb00Co_YR`oknJ/_noV[;o_iZb0oo1WK@4olBQ]@04olBS]oo6YKOoaZFgolJV
^@?obJVi00?ob:Zlol^]_?o;[K`00oo=/[l3oljf``;od[c500Sock_7om;0bOoB`<WodLC>o`000?oA
a<koe<_Aom37dP;odLgF00CocL[Folk?f_o>cm[oc]CN0_o:cmh00oo9dn7oa/oQolGBi002olGBi004
ol;>i?o0d>Ko`=3Vokg<i@;o_<gW00?oooooo`000?ooool04oooool000Wooooo00@00000oooooooo
oooooooo9000000;01TI6@030000000c<c<0<c<c00D0<c<c00<0000004a<C01<C4`00P1<C4`00`00
0000IVIV06IVIP0206IVIP040000001oOgl0Ogmo000000<0VIVI00D000000;>c/`2c/k<0/k>c0000
00030<c<c0030000003Vi^H0i^KV00h0i^KV00<000000<c<c03<c<`00`3<c<`01@000000/k>c0;>c
/`2c/k?o000000@0VIVI00<0000007moO`1oOgl00P1oOgl00ol00000IVIV06IVIP0306IVIP030000
001<C4`0C4a<00@0C4a<00<0000003<c<`0c<c<01@0c<c<00`0000006ATI01TI6@0:01TI6AH00000
1?ooool00`00003oooooooooo`0Booooo`03o`000?oooooooooo01?ooooo0_nJVm<3ok2@]@;o]8ZY
0onfRjP3okN7XP?o^8NQ0ongQIl01OniQYko0000o`000?l0003o]hBN00;o^XJN0_nhQIh01OnlQigo
^HFMokV5WOniQIgo]hBO00?o^XJM0_ngQIh01?nkQigo^8FNokR5W_nhQIh4okV6W`03okJ5X_njQioo
^XNO00;o]XJR00Co^XRPokN7X_ngQj;o]hNR1?ngR:<00ondR:Ko^8VSokF9YP03okF9YP?o]XZW0_nd
Rj/01?ngS:So]Xf[okJ=ZonfSJ/4okR?[0;o]i6^1?niTjl3okbE[`03okbH/_nnV;3o_YR`00?o_iZb
0oo1WK@01?o4X;?oa:6eolBQ]Oo4XKD3olJU]`?obJVi00Koc:fjol^]_?o;[Kcobjflolnb_Oo=/[l2
om2g`@04oljf`ooB_<God[c5om:la@?od/3900CoeLO=o`000?oDbm7oe<_A0ooAcMH01_oBdm[oc/oJ
olkDg_o>e=kocMWRolWCh@;ob=OU0_o5d^@00oo3e>Oo`=3Vol3@iP02okkAj004okc=ionjc^Wo^/kY
o`0001Cooooo0009ooooo`0400000?ooooooooooooooob@000002`0I6AT00`000000<c<c03<c<`05
03<c<`03o`00001<C4`0C4a<0080C4a<00<0000006IVIP1VIVH00P1VIVH01@000000Ogmo07moO`1o
Ogoo000000<0VIVI00Co00000;>c/`2c/k?o0000103<c<`00`000000i^KV0>KViP0=0>KViP030000
003<c<`0c<c<00<0c<c<00@000000;>c/`2c/k<0/k>c0P00000309VIV@030000001oOgl0Ogmo00<0
Ogmo00<0000006IVIP1VIVH00`1VIVH00`000000C4a<04a<C00404a<C0030000000c<c<0<c<c00D0
<c<c00?o000001TI6@0I6AT02@0I6ATF000000Cooooo00<00000ooooooooool04_ooool00ol0003o
ooooooooo`0Dooooo`06oiZKdon`T;Go/92eok2@]OndRZWo/Y:e0onfRjP3okN7XP?o^8NQ00Co]hFO
o`000?l0003o00000oniQYh3okZ6WP;o^8FN00Co_8NMokV5WOniQIgo^HFM1?njQYd01_ngQIko^hNM
ok^7WOnkQigo^8FNokb8W@Co^HJO0onjQil01?nfQZ;o^XRPokZ8X?njR:02okN7XPCo]hRS00?o]8RV
okR9XonhRJ<00oneRJH3okJ:Y`04okB;ZongS:So]hbXokN<Z0;o]Xf[1?nhSj`00ongTJko^Y6/okZA
[002okVC[`04okbD[OnlUJoo_9F_okbE[`Co_YR`00Co_iZbol6L/_o1W;;o`Ifd0_o4X;<3olBQ]@05
olNT]Oo6YKOoaZFgolZX^?o9ZKT00oo<[KX00oo;[Kcock:molnb_@03om2g`@?od[c50_oE`lP01OoB
`<WoeLO=omG7cOoGcm7o000000;oeM;F00GodLgFom;Cf_oBdm[od][OolkDgP02olgIhP05ol_Mi_o8
enGoaMWXolGIj?o3e>L00_o0e^X2okkAj003okcBjonjc^Wo^/kY00;o^<k[00?o0000ooooooooool0
4Oooool000Wooooo00@00000oooooooooooooooo9@00000;01TI6@030000000c<c<0<c<c00@0<c<c
00<0000004a<C01<C4`00`1<C4`00`000000IVIV06IVIP0206IVIP040000001oOgl0Ogmo000000<0
VIVI00D000000;>c/`2c/k<0/k>c000000040<c<c0030000003Vi^H0i^KV00d0i^KV00<000000<c<
c03<c<`00`3<c<`00`000000/k>c0;>c/`020;>c/`050000002IVIT0VIVI09VIV@0000001@1oOgl0
0`000000IVIV06IVIP0306IVIP030000001<C4`0C4a<00@0C4a<00<0000003<c<`0c<c<0100c<c<0
0`0000006ATI01TI6@0:01TI6AD000001?ooool00`00003oooooooooo`0Aooooo`03o`000?oooooo
oooo01Kooooo00?oG@00ok2@]OnHX=X00_nbT[D3okJ;Z0;o]hNR00?o^HbWokR7XOl000000_l00003
okZ8X@?o^HJN0onjQYh01?nhQIko_8NMokb7WOnlQid2okV5W@Co^XJM00Ko]hFNok^7WOnkQigo^hNM
okR5W_nlR9d4okV6W`?o^XNO00Ko]XJRokZ8X?njR:3o^XRPokN7X_nkRJ44okN8X`?o^8VS0_neRJH0
1?niRZCo]XZWokJ:YonfRZL4okN<Z003okJ=ZoniSZWo^HjY00?o^8n/0onjTJ`01?niTjoo_9B]okbD
[OnlU:d2okbE[`Co_YR`0oo1W;801Oo1WKCoa:2colBP/oo4X;?oa:6e00;oajBe00?oaZFgolZX^?o:
Z;P01?o<[KX3olnb_@05om>h`?o@]l7od;O1omBna?oB_<D00ooE`lP02OoHblcoeLO=omO?dOoGcm7o
eM;Fo`000?oEd]Koe]WKom;CfP02om;Jg`06om3Oi?o=fN;obmgVol_Mi_o7gn[oaMWX0_o2fn`01?o0
e^[o_MK/okgFk?nld^/2okWBk0;o^<k[00?o]/k/ooooool000004_ooool000Wooooo00@00000oooo
oooooooooooo9@00000;01TI6@030000000c<c<0<c<c00D0<c<c00<0000004a<C01<C4`00P1<C4`0
0`000000IVIV06IVIP0206IVIP050000001oOgl0Ogmo07moO`0000000`2IVIT01@000000/k>c0;>c
/`2c/k<0000000@0c<c<00<000000>KViP3Vi^H03@3Vi^H00`000000c<c<0<c<c0030<c<c0030000
002c/k<0/k>c0080/k>c00D0000009VIV@2IVIT0VIVIo`00000507moO`030000001VIVH0IVIV0080
IVIV00<0000004a<C01<C4`0101<C4`00`000000<c<c03<c<`0503<c<`030000000I6AT06ATI00T0
6ATI5@000004ooooo`0300000?oooooooooo017ooooo00?o0000ooooooooool05oooool2oiRPfP?o
/Y:e0_nfRjP01?ngQj;o0000o`000?l00002okR7X@Co^XRQ0_niQYh01OnlRZ3o^XJNokZ6W_njQYko
^8FN00?o_8NM00?o^HFMokf9WOnjQYd00onjQYd4ok^7W@03okR5W_nlR9go_8RM00;o^HJO00Co_HVN
okZ7WonjQioo^XNO1?njR:000ongQj;o^hVQok^9X@03okN8X`?o^8VS00Co]HVVokV:Y?niRZCo^HZT
0_nfRZL01OnjS:Ko]hbXokN<Z?ngS:So]Xf[00;o^HjY0_nhSj`01?nkT:[o^Y6/okZA[?njTJ`4okbD
[@03okbE[onoUjoo_iN_00;o_YR`00Co`Y^`ol6L/_o1W;;o`Ibb1?o4X;<3olNT]@?obZRh00KocZfi
olb]^_o<[K[oc:fjom2c_?o?/[d2om>h`003om2g`OoD_/Coe;k400;of<K800?oeL?8omS;c?oHbl`0
0ooGcm401ooIf=KoeM;Fo`000?oFfM_oe>7Pom;Jgoo@gn@00_o<i>P01Oo;gNKoamoZolOOj_o3hNko
`]_/00;o_]_^00Co_MK/ok[Fk_nje^ko^M;/0_ngdNd01?nfc^co/lg]ok?=kOl0000Booooo`002Ooo
ool01000003ooooooooooooooolV000000/06ATI00<0000003<c<`0c<c<01@0c<c<00`000000C4a<
04a<C00204a<C0030000001VIVH0IVIV0080IVIV00D0000007moO`1oOgl0Ogmo0000000309VIV@06
0000002c/k<0/k>c0;>c/`00003o00000`3<c<`00ol00000i^KV0>KViP0=0>KViP030000003<c<`0
c<c<00<0c<c<00<000000;>c/`2c/k<00P2c/k<01@000000VIVI09VIV@2IVIT0000000D0Ogmo00?o
000006IVIP1VIVH00P1VIVH00`000000C4a<04a<C00404a<C0030000000c<c<0<c<c00D0<c<c00<0
000001TI6@0I6AT02@0I6AT00ol0000000000000000A000000Cooooo00<00000ooooooooool04Ooo
ool00ol0003oooooooooo`0Hooooo`;oV:3J0_nbT[D3o`0000?o^HbW0_nhQj44okZ8X@03okV6W_nl
RZ3o_8ZP00?o^XJN1?nlQid00oniQIgo_HVMokZ6W@03okZ6W@Co^hNM0onlR9d2okV6W`04okf9W_nj
Qioo^XNOokZ7W`Co^XRP00?o]hNRok^9XOnkRJ400_ngR:<01?nlRj;o^8VSokR9XonhRJ<4okV:Y003
okJ:YonjS:Ko^XbV00?o]hbX0oniSZT01?nhSjco^i2Zok^@Z_nkT:X2okZA[004okfCZonlU:go_9B]
okbD[@?o_iN_00Co_YR`ol:K/?o2Vk3o`Y^`0_o1W;800oo5Wk;oa:2colBP/`02olRS]0;oajBe00?o
bjRfolZX^?o>[KT00_o>[KT00oo<[K[od;>lom2c_003om>h`003omO1`ooD_/Cof<K800;of<K80ooH
bl`01ooKe=;oeloAomWHe_oIf=KofN7Lo`000?oDhN000_oAinD01_o=jn[oc>CXolSVkOo8i^goamoZ
ol?QkP;o_^7`00Co_]_^ok[Jl?njf_3o^]K^0_nge>l01?ngdNgo]=3^okC@k_nccNd2ok7;k@03o`00
0?oooooooooo00oooooo0009ooooo`0400000?ooooooooooooooobH000002`0I6AT00`000000<c<c
03<c<`0503<c<`030000001<C4`0C4a<0080C4a<00<0000006IVIP1VIVH00P1VIVH00`000000Ogmo
07moO`0207moO`050000002IVIT0VIVI09VIVOl00000102c/k<01@000000c<c<0<c<c03<c<`00000
00h0i^KV00<000000<c<c03<c<`00`3<c<`00`000000/k>c0;>c/`020;>c/`030000002IVIT0VIVI
0080VIVI00<0000007moO`1oOgl00P1oOgl2000000@0IVIV00<0000004a<C01<C4`00`1<C4`00`00
0000<c<c03<c<`0603<c<`03o`00000I6AT06ATI00T06ATI4`000004ooooo`0300000?oooooooooo
017ooooo00?o0000ooooooooool06Oooool3o`000003okJ;Z?neUKKo]IFf00?o^HbW00?o^8NQok^>
YonjR:400onjR:401?niQYko_8ZPokb:X?nlRZ02okZ6WPCo_8NM00?o^HFMokf9WOnmRId00_njQYd0
0onoRYko^hNMok^7W@02ok^7W@?o_8RM00Ko^HJOokf9W_nmRIko_HVNokZ7WonnRil4okZ8X0?o^hVQ
00Co]hRSokb;X_nlRj;o_8^R0_nhRJ<01OnlS:?o^HZTokV:Y?niRZCo]XZW00;o^XbV0ongS:P3okV>
Z@Co^i2Z00?o^Y6/okfCZonmTj/00onlU:d3oknG[`Co`Y^`00Co`IbbolFO/_o5Wk;oa:2c0oo8Xk@0
1?o7Y;GobjRfol^X]_o:Z;P3olj]^@?od;>l00CoeK^oom>h`?oG`L?oel730ooHa/P2omc@c@06omS;
c?oKe=;ofmCBomcOf?oIf=KofN7L0_oGj>800ol0003odNOUolg[jP02olK]k`03olSVkOo2io3o_NKc
00;o_^7`0_njgo801?njf_3o]mWaokOIlOnge>l2okCCl004okC@k_nbc^ko//k^ok7;k@;o/<[]00?o
0000ooooooooool03_ooool000Wooooo00@00000oooooooooooooooo9P0000000ol000006ATI01TI
6@0901TI6@030000000c<c<0<c<c00D0<c<c00<0000004a<C01<C4`00P1<C4`00`000000IVIV06IV
IP0206IVIP030000001oOgl0Ogmo0080Ogmo00D0000009VIV@2IVIT0VIVI000000040;>c/`040000
003<c<`0c<c<0<c<c08000003@3Vi^H00`000000c<c<0<c<c0030<c<c003o`00002c/k<0/k>c0080
/k>c00<0000009VIV@2IVIT00P2IVIT00`000000Ogmo07moO`0307moO`030000001VIVH0IVIV0080
IVIV00?o000004a<C01<C4`00`1<C4`00`000000<c<c03<c<`0603<c<`030000000I6AT06ATI00T0
6ATI4P000004ooooo`0300000?oooooooooo017ooooo00?o0000ooooooooool05_ooool3o`000003
oooooonCZNGoTjWU00?o]IFf0oniS:L00onhQj7o^hjWok^>Y`03okZ8X@Co_8ZP00?o^XJNokj<X?nl
Qid00onlQid3okf9W@;o^XJM00?o_hZNok^7WOnkQid00_nkQid3okb8W@05okV6WonmRIko_HVNokf9
W_njQil00_nnRil3okZ8X0?o^hVQ00Go]hRSokb;X_nlRj;o_8^RokR9X`02okb<X`?o^HZT1?njS:H0
0ongS:So^hjWok^>Y`02okV>Z@05okf@Z?nkT:[o^i2Zok^@Z_njTJ`00_nmTj/2okbD[@;o_iJ]0_no
Ujl01?o2VZoo`Y^`ol:K/?o2Vk03olFO/PCob:>d0oo;Z;H3olj]^@;od[Bl00?od;>lomFk_ooE^kl0
0ooG`L<01?oLblSof<K8omc@cOoLd<d2omkLd`03om_Dd_oLgmSofnWN00;oe_7T00CoenSRom7_ioo:
l^co00000_o6kNl00onokO;o`^O`okgVl`02okSTm@;o^]ob00Co]]cdokOIlOngfO7o/mKb0_nddo00
0onad?3o//k^ok;>kP02ok3<kP03ok3:kOn^b>go0000013ooooo0009ooooo`0400000?oooooooooo
ooooobL00000300I6AT00`000000<c<c03<c<`0403<c<`030000001<C4`0C4a<00<0C4a<00<00000
06IVIP1VIVH00P1VIVH00`000000Ogmo07moO`0207moO`05o`00002IVIT0VIVI09VIV@000000102c
/k<00`000000c<c<0<c<c0020<c<c0030000003Vi^H0i^KV00/0i^KV00<000000<c<c03<c<`00`3<
c<`00`000000/k>c0;>c/`020;>c/`030000002IVIT0VIVI0080VIVI00<0000007moO`1oOgl00`1o
Ogl00`000000IVIV06IVIP0206IVIP030000001<C4`0C4a<00<0C4a<00?o00000000000c<c<01P0c
<c<00`0000006ATI01TI6@0901TI6A4000001?ooool00`00003oooooooooo`0Aooooo`03o`000?oo
oooooooo01Cooooo0_l00005ooooo`04oi>YiOneUKKo]IFfokFE]P?o^HbW0onkSZL3okZ8X@Co_8ZP
00?o^XJNokj<X?nlQid00onlQid3okf9W@04okZ6WOnoRYko_hZNokn:WP;o^hNM00Co`8bNokb8WOnl
R9go_8RM1?nmRIh00onjQioo_X^Ookj;W`02okZ8X004okn=X?nkRJ7o^hVQok^9X@Co_8^R00?o^8VS
okb<XonlS:<00oniRZ@4okZ<YP?o^hjW00?o^HjYokf@Z?nmT:P00onkT:X4okfCZ`04okbD[OnoUZgo
_iJ]oknG[`;o`YZ_0oo2Vk001?o5Wk7oaInbolFO/_o9Y;<3olRS]005olbY]_o;Z;KobjRfoln_^Oo>
[KT00ooB];`3omFk_`06om[5a?oG`L?og<_8omc;b?oOeloog=3=0_oNg=<00ooNj=[og=oHom_YgP02
omKai008olggj?oAknOob_;/ol;cl?nil_?o0000oko]l_nijoD2okCXm`04okSTmOnch?Ko/n3fokKL
m0;o/]Wd00Co/mKbok7Cl_nado;o/M3`0_n_c_02ok3<kP04ojk:k_n^b>go[/S]o`00013ooooo0009
ooooo`0400000?ooooooooooooooobL00000300I6AT00`000000<c<c03<c<`0503<c<`03o`00001<
C4`0C4a<0080C4a<00<0000006IVIP1VIVH00P1VIVH00`000000Ogmo07moO`0207moO`030000002I
VIT0VIVI0080VIVI00D000000;>c/`2c/k<0/k>co`0000050<c<c0030000003Vi^H0i^KV00X0i^KV
00<000000<c<c03<c<`00`3<c<`00`000000/k>c0;>c/`020;>c/`030000002IVIT0VIVI0080VIVI
00<0000007moO`1oOgl00`1oOgl00`000000IVIV06IVIP0206IVIP030000001<C4`0C4a<00@0C4a<
00<0000003<c<`0c<c<01@0c<c<00`0000006ATI01TI6@0901TI6@03o`0000000000000000h00000
1?ooool00`00003oooooooooo`0@ooooo`03o`000?oooooooooo01;ooooo0ol00008ooooo`06oi>Y
iOneUKKo]IFfokFE]_niS:Oo^IZh0onkSZL2okZ8X@03okjAYonlRZ3o_8ZP00;o_8ZP00?o^XJNokj<
X?nnS:000onlQid3okf9W@04okZ6WOnoRYko_hZNokn:WP;o^hNM00Co`8bNokb8WOnlR9go_8RM1?nm
RIh3okj;W`04okZ8X?noSJ3o_hfPokn=X0;o^hVQ00Go`8jQokb;X_nlRj;o_8^RokR9X`03okb<X`03
okV:Y?nmSZCo^XbV00?o^XbV0onkSZL00oniSZWo_I2Xokf@Z003ok^@ZPCo_I>[0onoUZd01OnoUjoo
`YZ_ol:J[oo2VZoo`Y^`00;oaIna00GoaInbolVT/oo9Y;?obJBcolRS]002olbY]P04ol^X]_o?[kWo
cjniomFh_@?od[Bl00Cof;k0omFk_ooJaLCof/G40ooLblP00ooOeloohNGFomkLd`02omkXfP05om[b
h?o@n^Coe_7Tolggj?o3nN`00_nhmnl00on_mO;o^O;co`000002ojk[n005okCXmon`i?So/>Chok?P
m_n`g?H00_n^f?H00on`e_Co[];cojkBl`02ojo@l@04ojo>l?n^bnoo[/__ojk:kP?ooooo00?o0000
ooooooooool03_ooool000Wooooo00@00000oooooooooooooooo:000000<01TI6@030000000c<c<0
<c<c00@0<c<c00<0000004a<C01<C4`00`1<C4`00`000000IVIV06IVIP0206IVIP030000001oOgl0
Ogmo0080Ogmo00<0000009VIV@2IVIT00P2IVIT01@000000/k>c0;>c/`2c/k<0000000D0c<c<0P00
000:0>KViP030000003<c<`0c<c<00@0c<c<00<000000;>c/`2c/k<00P2c/k<00`000000VIVI09VI
V@0209VIV@030000001oOgl0Ogmo00<0Ogmo00<0000006IVIP1VIVH00P1VIVH00`000000C4a<04a<
C00404a<C0030000000c<c<0<c<c00D0<c<c00<0000001TI6@0I6AT0200I6ATA000000Cooooo00<0
0000ooooooooool04?ooool00ol0003oooooooooo`0?ooooo`?o00003?ooool2okFE]P03ohVfloni
V[So^IZh00?o^hjW00?o^XRQokjAYonnTJL01?nlRZ03okj<X0;o_8NM00Co`HjQokf9WOnmRIgo_HVM
1?noRYh01_nkQigo`8bNol2<W_o0S9ko_8RMol:>W`Co_HVN0onnRil01OnjR:3o_hfPokn=X?noSJ3o
^hVQ00;o`8jQ0onlRj84okb<X`03okV:Y?nmSZCo_HjT00;o^XbV00Co_Y2Vok^>YonkSZOo^hjW1?nm
T:P00onkT:[o_Y>ZokjCZP02okfCZ`04ol6G[?noUZgo_iJ]oknF[@Co`YZ_0oo5Wk44olVT/`?oc:Vf
0oo?[kT2omFh_@03om:d_?oH_/3of;k000?of/G400Wogm7;omc;b?oOeloogmO?on7Ue_oNl]gog^SJ
om[bh?o@n^@00_o3o>H01Oncn^OoY_OYokSgkon_mO;oZ?7f00;oYNgi00Go0000oj_Vn_nYhO[oZN7j
ojgOn002ojcJn004ojkHm_n/doCo[=?dojkBl`;o[<kb0_n]cO000on^bnooooooooooo`04ooooo`03
o`000?oooooooooo00gooooo0009ooooo`0400000?ooooooooooooooobP00000300I6AT00ol00000
<c<c03<c<`0503<c<`030000001<C4`0C4a<00<0C4a<00<0000006IVIP1VIVH00P1VIVH00`000000
Ogmo07moO`0207moO`050000002IVIT0VIVI09VIV@000000102c/k<00`000000c<c<0<c<c0040<c<
c0030000003Vi^H0i^KV00P0i^KV00<000000<c<c03<c<`00`3<c<`00`000000/k>c0;>c/`030;>c
/`030000002IVIT0VIVI0080VIVI00<0000007moO`1oOgl00P1oOgl00`000000IVIV06IVIP0306IV
IP030000001<C4`0C4a<00<0C4a<00<0000003<c<`0c<c<01P0c<c<00`0000006ATI01TI6@0801TI
6A0000001?ooool00`00003oooooooooo`0@ooooo`03o`000?oooooooooo00cooooo0ol0000Aoooo
o`04ohVfloniV[So^IZhokVJ^0;o^hjW1?nnTJL3okb:X0?o_XbP00?o_8NMol6>XOo1SZ400onmRId4
okn:WP06ok^7WOo0S9ko`8bNol2<W_nlR9go`XjO1?nmRIh3okj;W`Co_hfP00?o^hVQol2>XOo0SZ40
0onlRj84okb<X`?o_HjT00Co^XbVokj@Y_nnT:Ko_Y2V0_nkSZL4okf@Z0?o_Y>Z00Co_I>[ol6G[?o1
Ujco`IN/0_noUZd4ol:J[`?oaIna1?o9Y;<01Oo>ZkKoc:VfolbY]_oA/KWocjni00?oeKRm0ooH_/00
1ooMblOof/G4omoAbooOdL_oh^7BomoGcooQiMH00_oNl]d02OoCnn7o`_kPojgjgOo3o>Ko/o[WojKg
jOnNlngoV_3boi[/n002ojG]n@05ojCWnonTh__o0000ojWQn_nXfoT00_n/f_P01?nZe?Ko[=?dojcC
m?n[co<2ojc>lP[ooooo00?o0000ooooooooool03Oooool000Wooooo00@00000oooooooooooooooo
:@00000;01TI6@030000000c<c<0<c<c00D0<c<c00<0000004a<C01<C4`00`1<C4`00ol00000IVIV
06IVIP0306IVIP050000001oOgl0Ogmo07moOol00000102IVIT00`000000/k>c0;>c/`020;>c/`80
00001@3<c<`2000000L0i^KV0P0000060<c<c003o`00002c/k<0/k>c00<0/k>c00<0000009VIV@2I
VIT00P2IVIT00`000000Ogmo07moO`0207moO`030000001VIVH0IVIV00<0IVIV00<0000004a<C01<
C4`00`1<C4`00ol00000<c<c03<c<`0503<c<`03o`00000I6AT06ATI00T06ATI3`000004ooooo`03
00000?oooooooooo013ooooo00?o0000ooooooooool02Oooool3o`0001Gooooo00?oRKKcokVJ^?ni
V[P00_nkSZL01?nmX;_o_Y6WokjAYonnTJL2okb:X005ol6DZ?nnS:3o_XbPokj<X?nlQid00oo1SZ40
0onmRIgo`i2Qokn:WP03okn:WPCo`8bN00?o_8RMol:>Woo2SYl00_nmRIh01?o3T:7o_X^Ookj;Wonn
Ril4okn=X006ok^9XOo0SZ7o`8jQol2>XOnlRj;o`I2S1?nlS:<3okf>Y005okZ<Y_nnT:Ko_Y2Vokj@
Y_nkSZL00_o0TjP3okf@Z0?o_Y>Z1?o1Uj`00onoUZgoa9^^olBK[P02ol:J[`;oaj2a00?oaInaolZU
/oo:YK<00_o9Y;<2olj[]P03olbY]_oA/KWodK6i00?oeKRm0_oKa<<01OoH_/3ogL_7omg;aooRfloo
gm7;00;oh^7B00[ohO3JomKlgOoNl]godo_Qol;nh?n]n]goV_?Kohg^gOn7k>CoSNWe0_nCi_/01onL
io_oWn;moioRoOnTh__oYMcko`000?nXfoT00_nXe_L01?nZe?KoZM3dojW@m?n[co<=ooooo`03o`00
0?oooooooooo00gooooo0009ooooo`0400000?ooooooooooooooobT000002`0I6AT00`000000<c<c
03<c<`0503<c<`030000001<C4`0C4a<00@0C4a<00<0000006IVIP1VIVH00`1VIVH01Ol00000Ogmo
07moO`1oOgl0000000@0VIVI00<000000;>c/`2c/k<00`2c/k<00`000000c<c<0<c<c0040<c<c080
0000103Vi^H00`000000c<c<0<c<c0070<c<c0030000002c/k<0/k>c0080/k>c00<0000009VIV@2I
VIT00P2IVIT00`000000Ogmo07moO`0207moO`030000001VIVH0IVIV00<0IVIV00<0000004a<C01<
C4`0101<C4`00`000000<c<c03<c<`0403<c<`030000000I6AT06ATI00T06ATI3`000004ooooo`03
00000?oooooooooo013ooooo00?o0000ooooooooool01_ooool3o`0001Wooooo0_niV[P00onkSZOo
_J2kokfP^`03okjAY`04okb:X?o1U:So`IBXol6DZ0;o_XbP1?o1SZ400onmRIgo`i2Qokn:WP03okn:
WPCo`8bN0oo2SYl2okf9WP;o`i2Q00?o_X^OolBBX_o4TZ800onoSJ04ol2>X@03okb;X_o1T:?o`I2S
00;o_8bS00Co`Y:Uokf>Y?nmSZCo_HjT1?nnT:H00onkSZOo`9>Xol2CZ002okf@Z0;o`IJZ0_nnTjX0
1?o4VZgo`IN/ol6G[?o1Uj`3olBK[P05ol:J[oo7X;7oaj2aolNP/Oo5Wk400_o:YK<01?o9Y;?ocZ^f
olj[]_o>ZkH3om6a^@03omRm_ooE^;goflC300;oflC30ooMblL03OoRfloohngGon;Qd_oQl=[oe_cM
ol7nf_nTmm;oRN_9ogKQa_mOem_oM>;TogoTlOn:i?X00_nCh?h01?nIhOgoW]_moikKoOnQg?`2oj?F
n@04ojKFnOl0003oY]7fojSAmA7ooooo00?o0000ooooooooool03Oooool000Wooooo00@00000oooo
oooooooooooo:@0000000ol000006ATI01TI6@0901TI6@030000000c<c<0<c<c00D0<c<c00<00000
04a<C01<C4`0101<C4`00`000000IVIV06IVIP0206IVIP030000001oOgl0Ogmo0080Ogmo00<00000
09VIV@2IVIT00P2IVIT00`000000/k>c0;>c/`030;>c/`030000003<c<`0c<c<00D0c<c<1000000:
0<c<c0030000002c/k<0/k>c00<0/k>c00<0000009VIV@2IVIT00P2IVIT00`000000Ogmo07moO`02
07moO`030000001VIVH0IVIV00<0IVIV00<0000004a<C01<C4`00`1<C4`00`000000<c<c03<c<`05
03<c<`030000000I6AT06ATI00T06ATI3P000004ooooo`0300000?oooooooooo013ooooo00?o0000
ooooooooool00oooool3o`0001kooooo0onmX;/3okjAY`04okb:X?o1U:So`IBXol6DZ0;o_XbP1?o1
SZ400onmRIgo`i2Qol>@X@02okn:WP03olFCX_o0S9ko`8bN00;o`8bN0oo2SYl01OnmRIko`i2Qol>@
XOo3T:7o_X^O00;oa9:R0onoSJ04ol2>X@?o`I2S00Co_8bSol:BYOo2TZGo`Y:U0_nmSZ@01?o3UJOo
_Y2Vokj@Y_nnT:H3ol2CZ005okf@Z?o1UZ[o`IJZol6FZ_nnTjX00_o4VZd3ol6G[0?oa9^^1?o7X;43
olZU/`06om2_^?o>ZkKocZ^folj[]_oD][_odK6i0_oH_Kl3om_4``;ohMC;00[ogL_7on;KcooSkMOo
hngGomWkfoo0o]KoVo;6oe[=Z_m<bm;oIMS[0_mkgOT00on2hO[oSmknoiSIoP03oi[Ko@04oikKoOnQ
e_[oXMKjoj?Fn@;oYM7g00?oY]7fo`000?ooool04Oooool00ol0003oooooooooo`0=ooooo`002Ooo
ool01000003oooooooooooooool[000000/06ATI00<0000003<c<`0c<c<01@0c<c<00`000000C4a<
04a<C00404a<C0030000001VIVH0IVIV0080IVIV00<0000007moO`1oOgl00P1oOgl00`000000VIVI
09VIV@0209VIV@03o`00002c/k<0/k>c00<0/k>c00<000000<c<c03<c<`04`3<c<`00`000000/k>c
0;>c/`030;>c/`030000002IVIT0VIVI0080VIVI00<0000007moO`1oOgl00P1oOgl00`000000IVIV
06IVIP0306IVIP030000001<C4`0C4a<00<0C4a<00<0000003<c<`0c<c<01@0c<c<00`0000006ATI
01TI6@0901TI6@03o`0000000000000000X000001?ooool00`00003oooooooooo`0?ooooo`04o`00
0?ooooooooooooooo`?o00008Oooool01?m/`_ko_J2kokfP^onmX;/2okjAY`Co`IBX00?o_XbPolBH
ZOo1SZ400oo1SZ43ol>@X@;o_hZN0_o5Tj83ol2<WP?o`XjO00Go_HVNol>@XOo3T:7o`i2Qokj;W`02
olBBXP;o_hfP00?oaYFTol2>XOo0SZ400_o0SZ43ol6@X`05okb<Xoo2TZGo`Y:Uol:BYOnmSZ@00_o3
UJL3okj@YP?o`9>X1?o1UZX00onnTj[oa9Z]olBJ[@02ol6G[0;oaYj_0_o4Vjh01Oo9Xk;oaj2aolNP
/Oo7X;7ocJVe00;obZFc0_o@[kP00oo>ZkKoe;JkomBf^`03omRm_`04omk=aooKa<?ohMC;on7Db`;o
hnSD00Oog?[Kon?]eooInm_o`?kFoi_ba_mef?_oMm[j00;oRM[o00CoRmcnoiKGo_nFeokoV=Wn0_nM
do/01?nOe?_oX/ogoj;?monSd?L6ooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool0
3Oooool000Wooooo00@00000oooooooooooooooo:`00000;01TI6@030000000c<c<0<c<c00D0<c<c
00<0000004a<C01<C4`0101<C4`00ol00000IVIV06IVIP0206IVIP030000001oOgl0Ogmo00<0Ogmo
00Go000009VIV@2IVIT0VIVI000000060;>c/`030000003<c<`0c<c<0180c<c<00<000000;>c/`2c
/k<00`2c/k<00`000000VIVI09VIV@0209VIV@030000001oOgl0Ogmo0080Ogmo00<0000006IVIP1V
IVH00`1VIVH00`000000C4a<04a<C00304a<C0030000000c<c<0<c<c00D0<c<c00<0000001TI6@0I
6AT02@0I6AT=000000Cooooo00<00000ooooooooool03oooool4o`0002Gooooo0onmX;/00onnTJOo
`ZS0ol6DZ003ol6DZ003okj<X?o4V:Woa9RY00?o`HjQ0oo3T:401?noRYkoaI>RolFCX_o5Tj82ol2<
WP04olNGY?o2SYoo`XjOol:>W`Co`i2Q1?o4TZ800onoSJ3oaYFTolJEY002ol2>X@04olNHY_o1T:?o
`I2Sol6@X`Co`Y:U00?o_HjTol>EYoo3UJL00_nnT:H2olBHZ@;o`9>X00CoaI^/ol6FZ_o1UZ[o`IJZ
1?o4VZd01?o1UjcoaYj_olJN[oo4Vjh3olVS/P04olNP/Oo=ZKGocJVeolZU/`?od:nh0ooD][/01_oK
aLCof;foomk=aooNcLOohn;Bon7Db`?ohnSD00?o`OkDoi;/_OmRcj400_n:eOl01?n9f?ooUM?moiGC
oOnEeOh2oic@nP03oicBn_nQcOOoXLgg00;oXLkg00?oX/ogooooooooool01_ooool00ol0003ooooo
ooooo`0?ooooo`03o`000?oooooooooo00gooooo0009ooooo`0400000?ooooooooooooooob`00000
2`0I6AT00`000000<c<c03<c<`0503<c<`030000001<C4`0C4a<00<0C4a<00<0000006IVIP1VIVH0
0`1VIVH00`000000Ogmo07moO`0207moO`030000002IVIT0VIVI0080VIVI00<000000;>c/`2c/k<0
102c/k<00`000000c<c<0<c<c00A0<c<c0030000002c/k<0/k>c00<0/k>c00<0000009VIV@2IVIT0
0`2IVIT00`000000Ogmo07moO`0207moO`030000001VIVH0IVIV00<0IVIV00<0000004a<C01<C4`0
0`1<C4`00`000000<c<c03<c<`0503<c<`030000000I6AT06ATI00T06ATI30000004ooooo`030000
0?oooooooooo00oooooo0_l0000Yooooo`04obR_goo2Z<3o`ZS0ol:X`0?o`IBX0oo4V:T3ol6>X@?o
`i2Q00Go_hZNolFCX_o5Tj;oaI>Rol2<WP03olNGY0;o`XjO1?o3T:44olBBXP04okn=X?o6UJCoaYFT
ol2>X@?oaiRV0_o1T:<01?o8VZSo`Y:Uol:BYOo2TZD4ol>EY`04okj@Y_o4V:Woa9RYol2CZ0;oaI^/
0oo1UZX4olBJ[@?oaYj_1?o9Xk83olfY]@?od:nh0_oG_L000ooD][_oflG4om_5a003omk=a`05on?R
d_oNmm_og_OKon?Xe?o1o]@00_nIcOX2oiO?n`04oiKAo?nLc?SoW<choic>n@;oXL[e0_nQboH00onQ
cOOoooooooooo`0;ooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool03?ooool000Wo
oooo00@00000oooooooooooooooo;@00000;01TI6@030000000c<c<0<c<c00D0<c<c00<0000004a<
C01<C4`00`1<C4`00`000000IVIV06IVIP0306IVIP030000001oOgl0Ogmo0080Ogmo00<0000009VI
V@2IVIT00P2IVIT2000000D0/k>c0P00000A0<c<c0030000002c/k<0/k>c00@0/k>c00<0000009VI
V@2IVIT00P2IVIT00`000000Ogmo07moO`0207moO`030000001VIVH0IVIV00<0IVIV00?o000004a<
C01<C4`00`1<C4`00`000000<c<c03<c<`0503<c<`030000000I6AT06ATI00T06ATI30000004oooo
o`0300000?oooooooooo017ooooo00?o0000ooooooooool09oooool00olX[moo`ZS0ol:X`002ol6D
Z004olNdaoo4V:Woa9RYolBHZ@;o`HjQ00Cob9f[ol>@XOo3T:7o`i2Q1?o5Tj801_o0S9koaiNTolNG
Y?o7UjCo`XjOolVJYPCo`i2Q1?o4TZ83olJEY005ol2>XOo7V:KoaiRVolNHY_o1T:<00_o8VZP3ol:B
Y@Co`iFW0oo4V:T00oo0TjSoaI^/olFK[002ol6FZP;oain_0_o4VZd2olZT/P;oaYj_00?ocJVeolVS
/_o9Xk800_o@[kT2olfY]@03om>f_?o@[kSoekg000;oekg000Koe;Jkom_5a?oKaLCohM[?omk=aooS
h]82omkgf`05oh[W]onJb_SoVLgjoiW=n_nNbOH00onMboL01?nLc?SoXLSdoj78m?nQb_DBooooo`03
o`000?oooooooooo00kooooo00?o0000ooooooooool03?ooool000Wooooo00@00000oooooooooooo
oooo;P00000;01TI6@030000000c<c<0<c<c00D0<c<c00<0000004a<C01<C4`00`1<C4`00`000000
IVIV06IVIP0306IVIP03o`00001oOgl0Ogmo0080Ogmo00<0000009VIV@2IVIT00`2IVIT00`000000
/k>c0;>c/`040;>c/`8000003`3<c<`00`000000/k>c0;>c/`040;>c/`030000002IVIT0VIVI00<0
VIVI00<0000007moO`1oOgl00P1oOgl00`000000IVIV06IVIP0306IVIP030000001<C4`0C4a<00<0
C4a<00<0000003<c<`0c<c<01@0c<c<00`0000006ATI01TI6@0901TI6@/000001?ooool00`00003o
ooooooooo`0Booooo`03o`000?oooooooooo02Oooooo0_o2Z<001?o1U:SoakC7olNdaoo7]<L2olBH
Z@04ol6>XOo8WJ_ob9f[olRMZ`;o`i2Q00Coc::^olFCX_o5Tj;oaI>R1?o7Uj@00oo2SYoobIZVolVJ
YP02ol>@X@03olbMZ?o4TZ;oa9:R00;oa9:R0oo6UJ@4olNHYP03ol6@Xoo8VZSob9ZX00;o`Y:U0_o9
WJ/3ol>EY`?oa9RY1?o5Vj`01?o1UZ[oain_olNO[oo4VZd3olZT/P04olJN[oo=ZKGocJVeolVS/P?o
d:ni00?ocJVeom>f_?oC][`00ooG_L02omkBc006om_5a?oQf/oohM[?omocfoo4omOog_OK0_nQaO82
oj37m004oik9m_nRaO;oX/Gboj;7laSooooo00?o0000ooooooooool03Oooool00ol0003ooooooooo
o`0<ooooo`002Oooool01000003oooooooooooooool^000000/06ATI00<0000003<c<`0c<c<01P0c
<c<00ol00000C4a<04a<C00304a<C0030000001VIVH0IVIV00<0IVIV00<0000007moO`1oOgl00P1o
Ogl00ol00000000009VIV@0309VIV@030000002c/k<0/k>c00D0/k>c0P00000=0<c<c0030000002c
/k<0/k>c00@0/k>c00<0000009VIV@2IVIT00`2IVIT00`000000Ogmo07moO`0207moO`030000001V
IVH0IVIV00<0IVIV00<0000004a<C01<C4`00`1<C4`00`000000<c<c03<c<`0503<c<`030000000I
6AT06ATI00X06ATI00?o00000000000000001`000004ooooo`0300000?oooooooooo01?ooooo00?o
0000ooooooooool0:Oooool3olNda`;oa9RY1?o8WJ/00oo3T:7oc::^olbR[P03olFCXPCoaiNT00Co
`XjOolVJY_o9VZKo`i2Q0oo<WJP2olBBXP05olfRZoo6UJCoaYFTolJEY?o?YJh00oo7V:H4olRJZ003
ol:BYOo9WJ_obIf[00;o`iFW0_o:XJh2olBHZ@CoaI^/0oo7Wjl4olZT/P?ocJVe1?o@[kT3om>f_003
om_:b?oG_L3og];<00;og];<00OognkJon7JcooOlm_oa?oGoh?S/onRa?7oXLGb00;oY<?_0_nSa?00
0onRaO;oooooooooo`0Hooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03?ooool0
00Wooooo00@00000oooooooooooooooo;`00000;01TI6@030000000c<c<0<c<c00D0<c<c00<00000
04a<C01<C4`0101<C4`00`000000IVIV06IVIP0306IVIP030000001oOgl0Ogmo00<0Ogmo00<00000
09VIV@2IVIT00P2IVIT2000000L0/k>c00<000000<c<c03<c<`02@3<c<`00`000000/k>c0;>c/`06
0;>c/`030000002IVIT0VIVI00<0VIVI00<0000007moO`1oOgl00P1oOgl00`000000IVIV06IVIP03
06IVIP030000001<C4`0C4a<00<0C4a<00<0000003<c<`0c<c<01@0c<c<00`0000006ATI01TI6@09
01TI6@X000001?ooool00`00003oooooooooo`0Dooooo`;o0000:_ooool2olNda`03olBHZOo>`/oo
c/;?00?ob9f[00?o`i2QolbR[_o<XZh00_o5Tj800oo@ZK7oaiNTolNGY002olNGY0?obIZV00Go`i2Q
olbMZ?o<WJSoc9fXolBBXP03olfRZ`03olJEY?o?YJkocjF^00?oaiRV1?o8VZP3olVMZ`05ol>EYoo:
XJkobZ6^olZQ[_o4V:T00_o;YK82olFK[0;ocJVe0_o7Wjl01Oo?[[WobZBbolZT/_o:Y;;odKBm00;o
cJVe00Koe;_1om2_^Oo@[kWod:niomS2aOoC][`2om_:b0;og^OI00Gog];<omo^f_oOk][oa_kLo`00
0002ojG1k@;oYL;^00?oY<?_ooooooooool07Oooool00ol0003oooooooooo`0<ooooo`03o`000?oo
oooooooo00cooooo0009ooooo`0400000?oooooooooooooooc0000002`0I6AT00`000000<c<c03<c
<`0503<c<`030000001<C4`0C4a<00@0C4a<00?o000006IVIP1VIVH00`1VIVH00`000000Ogmo07mo
O`0307moO`030000002IVIT0VIVI00<0VIVI00<000000;>c/`2c/k<01@2c/k<01000003o00000000
000000060<c<c0800000202c/k<00`000000VIVI09VIV@0309VIV@030000001oOgl0Ogmo0080Ogmo
00?o000006IVIP1VIVH00`1VIVH00`000000C4a<04a<C00404a<C0030000000c<c<0<c<c00D0<c<c
00<0000001TI6@0I6AT02@0I6AT9000000Cooooo00<00000ooooooooool05_ooool00ol0003ooooo
ooooo`0Yooooo`?oc/;?0oo8WJ/4olbR[P03olFCX_o@ZK7od:Va00?oaiNT0oo9VZH4olbMZ005olBB
X_o=XZ_ocJ:[olfRZoo6UJ@00_o?YJh2olNHYP;od:Zb0oo8VZP3olVMZ`CobZ6^00Coa9RYol^U/_o;
YK;oaI^/0oo=ZKD00oo7Wjoocjjioln^^@02olZT/P;odKBm00GocJVeomBk`OoD^l7oe;_1om2_^@02
omS2a@?ofl[800Gog^OIolSnhOo8o^7ognkJolKng002ojK0k003ojG1kOoooooooooo02;ooooo00?o
0000ooooooooool02oooool00ol0003oooooooooo`0<ooooo`002Oooool01000003ooooooooooooo
ool`000000/06ATI00<0000003<c<`0c<c<01@0c<c<00`000000C4a<04a<C00404a<C0030000001V
IVH0IVIV00<0IVIV00<0000007moO`1oOgl00`1oOgl00ol00000VIVI09VIV@0309VIV@030000002c
/k<0/k>c00T0/k>c0`0000000`3<c<`000000000000:0;>c/`030000002IVIT0VIVI00<0VIVI00<0
000007moO`1oOgl00`1oOgl00`000000IVIV06IVIP0206IVIP030000001<C4`0C4a<00@0C4a<00<0
000003<c<`0c<c<01@0c<c<00`0000006ATI01TI6@0901TI6@T000001?ooool00`00003ooooooooo
o`0Gooooo`03o`000?oooooooooo02Wooooo0oo>`/l00oo8WJ_odmCIolbR[P03olbR[P03olFCX_o@
ZK7od:Va00;oaiNT0_oD/;D2olVJYP04omNh^_o<WJSoc9fXolbMZ0CocJ:[00GoaYFTolnU[_o?YJko
cjF^olNHYP02om2Z/P;ob9ZX0_oA[[H2olVMZ`CobZ6^0oo;YK84olfY]@Cocjji00?obZBbom6d_OoA
];d00ooD^l401ooJemCof<;5omS2aOoH`/GogMoHom_:b?oNimT00_o8o^400omegKCoYko[ooooo`0X
ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool03?ooool000Wooooo00@00000oooo
oooooooooooo<@00000;01TI6@030000000c<c<0<c<c00D0<c<c00<0000004a<C01<C4`0101<C4`0
0`000000IVIV06IVIP0306IVIP030000001oOgl0Ogmo00<0Ogmo00<0000009VIV@2IVIT00`2IVIT2
000000`0/k>c00<000000;>c/`2c/k<02P2c/k<00`000000VIVI09VIV@0309VIV@030000001oOgl0
Ogmo00<0Ogmo00<0000006IVIP1VIVH00P1VIVH00`000000C4a<04a<C00404a<C0030000000c<c<0
<c<c00D0<c<c00<0000001TI6@0I6AT02P0I6AT8000000Cooooo00<00000ooooooooool06?ooool0
0ol0003oooooooooo`0/ooooo`;odmCI0_o<XZh01OoEjN?od:Vaom2Y/Oo@ZK7oaiNT00?oe;2e00?o
bIZVomNh^_oG^;X00oo<WJP4olfRZ`CocjF^0oo@Z[801Oo8VZSodJjfom6^]_oA[[KobIf[00;od[>j
0_o:XJh2om>h_`;objFb00Godkg4olfY]Oo=ZKGocJVeomC3b002oln^^@06omK9cOoA];godKBmom6d
_OoHd=7oe;_10ooJem@01OoH`/GogMoHolWliOm]f[OoZ;kZ02gooooo00?o0000ooooooooool02ooo
ool00ol0003oooooooooo`0;ooooo`002Oooool01000003ooooooooooooooola000000`06ATI00<0
000003<c<`0c<c<01@0c<c<00`000000C4a<04a<C00404a<C0030000001VIVH0IVIV00<0IVIV00<0
000007moO`1oOgl00`1oOgl00`000000VIVI09VIV@0409VIV@8000005P2c/k<00`000000VIVI09VI
V@0409VIV@030000001oOgl0Ogmo00<0Ogmo00<0000006IVIP1VIVH00`1VIVH00`000000C4a<04a<
C00404a<C0030000000c<c<0<c<c00@0<c<c00<0000001TI6@0I6AT02P0I6AT8000000Cooooo00<0
0000ooooooooool06Oooool2o`0002kooooo00Coc::^omGYhooEjN?oeNWS0_o@ZK401Oo;n^Ooe;2e
omB`]OoD/;GobIZV00?oekRj00?oc9fXom[0_ooJ`;l00_o=XZ/2omc9aP;ocjF^00CogM7=om2Z/_o@
Z[;od:Zb1?oA[[H3om:c^P05olZQ[_oC^;oodkRoom>h_oo;YK800ooC_L@01?o=ZKGoe<?8omC3b?o?
[[T3omK9c@04om6d_OoHd=7of=3Aol[fj`;of]OD00Cob_WXof?E^OnX_^WoZ;kY<?ooool00ol0003o
ooooooooo`0:ooooo`03o`000?oooooooooo00_ooooo0009ooooo`0400000?oooooooooooooooc80
0000300I6AT00`000000<c<c03<c<`0503<c<`03o`00001<C4`0C4a<00@0C4a<00?o000006IVIP1V
IVH00`1VIVH00`000000Ogmo07moO`0307moO`0300000?l00000VIVI00D0VIVI0P00000D0;>c/`03
0000002IVIT0VIVI00@0VIVI00<0000007moO`1oOgl00`1oOgl00`000000IVIV06IVIP0306IVIP03
o`0000000000C4a<00@0C4a<00?o000003<c<`0c<c<01@0c<c<00`0000006ATI01TI6@0:01TI6@L0
00001?ooool00`00003oooooooooo`0Kooooo`03o`000?oooooooooo02kooooo00?oZKgXom2Y/Oo;
n^L00_o;n^L00ooD/;Go[_[KomNh^P02omNh^P05ogkT_OoJ`;oof/2oom[0_oo=XZ/00ooLbLH01?o?
YJkogM7=omgAcOoMdLd2om2Z/P03omcIe?oA[[KodJjf00;ofMoK0_oB/kX01?oFi>7odkRoom>h_ooC
^;l3om>ma005olk/jOoD`lSoe<?8omC3b?o<kn/00_oFbLd2ol_bk005omS@dOo:m^_oE/jhoeK>^?nX
_^T0=Oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00_ooooo0009ooooo`040000
0?oooooooooooooooc<00000300I6AT00`000000<c<c03<c<`0503<c<`030000001<C4`0C4a<00@0
C4a<00<0000006IVIP1VIVH00`1VIVH00`000000Ogmo07moO`0407moO`030000002IVIT0VIVI00D0
VIVI00<000000;>c/`2c/k<04@2c/k<00`000000VIVI09VIV@0409VIV@030000001oOgl0Ogmo00<0
Ogmo00<0000006IVIP1VIVH0101VIVH00`000000C4a<04a<C00404a<C0030000000c<c<0<c<c00@0
<c<c00<0000001TI6@0I6AT02P0I6AT7000000Cooooo00<00000ooooooooool07?ooool00ol0003o
ooooooooo`0^ooooo`OoZKgX00GoekRjojVmj?nY_NSoZKgXom[0_`03ojVmj003omc9a_nY_NSoZKgX
00?ogM7=00Cod:ZbomcIe?oLfMCodJjf0ooIgm/01OoB/k[oe^CQomKThOoFi>7odkRo00;od^SV00Ko
dkg4olk/jOo>k>Woc^cYomC3b?o<kn/3o`000003ol_bk?nY_NSoZKgX03[ooooo00?o0000oooooooo
ool02?ooool00ol0003oooooooooo`0;ooooo`002Oooool01000003ooooooooooooooold000000`0
6ATI00<0000003<c<`0c<c<01@0c<c<00`000000C4a<04a<C00404a<C0030000001VIVH0IVIV00<0
IVIV00<0000007moO`1oOgl0101oOgl00`000000VIVI09VIV@0509VIV@<000003`2c/k<00`000000
VIVI09VIV@0509VIV@030000001oOgl0Ogmo00@0Ogmo00<0000006IVIP1VIVH00`1VIVH00`000000
C4a<04a<C00404a<C0030000000c<c<0<c<c00D0<c<c00<0000001TI6@0I6AT02@0I6AT7000000Co
oooo00<00000ooooooooool07Oooool00ol0003oooooooooo`0^ooooobcoZKgX??ooool00ol0003o
ooooooooo`08ooooo`03o`000?oooooooooo00_ooooo0009ooooo`0400000?ooooooooooooooocD0
0000300I6AT00ol00000<c<c03<c<`0503<c<`030000001<C4`0C4a<00@0C4a<00<0000006IVIP1V
IVH00`1VIVH00`00003o000007moO`0407moO`0300000?l00000000000L0VIVI100000090;>c/`80
000000?o000009VIV@2IVIT01@2IVIT00`000000Ogmo07moO`0407moO`030000001VIVH0IVIV00<0
IVIV00<0000004a<C01<C4`0101<C4`00`000000<c<c03<c<`0503<c<`030000000I6AT06ATI00X0
6ATI00?o00000000000000000`000004ooooo`0300000?oooooooooo01kooooo0_l0000_ooooobOo
ZKgX@Oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00_ooooo0009ooooo`040000
0?ooooooooooooooocD000003@0I6AT00`000000<c<c03<c<`0503<c<`030000001<C4`0C4a<00@0
C4a<00<0000006IVIP1VIVH0101VIVH00`000000Ogmo07moO`0507moO`030000002IVIT0VIVI00P0
VIVI0`0000030;>c/`<000002P2IVIT00`000000Ogmo07moO`0407moO`030000001VIVH0IVIV00<0
IVIV00<0000004a<C01<C4`0101<C4`00`000000<c<c03<c<`0503<c<`030000000I6AT06ATI00X0
6ATI1P000004ooooo`0300000?oooooooooo023ooooo00?o0000ooooooooool0;OoooolRojVmj4Ko
oooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0:ooooo`002Oooool01000003ooooo
oooooooooolf000000`06ATI00<0000003<c<`0c<c<01P0c<c<00`000000C4a<04a<C00404a<C003
0000001VIVH0IVIV00@0IVIV00<0000007moO`1oOgl01@1oOgl2000000/0VIVI0`00000=09VIV@03
0000001oOgl0Ogmo00@0Ogmo00<0000006IVIP1VIVH00`1VIVH00`000000C4a<04a<C00404a<C003
0000000c<c<0<c<c00D0<c<c00<0000001TI6@0I6AT02P0I6AT6000000Cooooo00<00000oooooooo
ool08Oooool00ol0003oooooooooo`0^oooooakoZKgXBOooool00ol0003oooooooooo`06ooooo`03
o`000?oooooooooo00[ooooo0009ooooo`0400000?ooooooooooooooocL00000300I6AT00`000000
<c<c03<c<`0603<c<`030000001<C4`0C4a<00@0C4a<00<0000006IVIP1VIVH0101VIVH00`000000
Ogmo07moO`0607moO`030000002IVIT0VIVI01L0VIVI00<0000007moO`1oOgl01@1oOgl00`000000
IVIV06IVIP0406IVIP030000001<C4`0C4a<00@0C4a<00<0000003<c<`0c<c<01@0c<c<00`000000
6ATI01TI6@0:01TI6@D000001?ooool00`00003oooooooooo`0Rooooo`03o`000?oooooooooo02ko
oooo6OnY_NQ=ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool02_ooool000Wooooo
00@00000oooooooooooooooo>000000<01TI6@03o`00000c<c<0<c<c00H0<c<c00?o00000000001<
C4`0101<C4`00ol00000IVIV06IVIP0406IVIP03o`0000000000Ogmo00H0Ogmo0P00000F09VIV@80
00001`1oOgl00`000000IVIV06IVIP0406IVIP030000001<C4`0C4a<00@0C4a<00<0000003<c<`0c
<c<01@0c<c<00`0000006ATI01TI6@0:01TI6@D000001?ooool00`00003oooooooooo`0Sooooo`03
o`000?oooooooooo02kooooo5?nY_NQBooooo`03o`000?oooooooooo00Gooooo00?o0000oooooooo
ool02_ooool000Wooooo00@00000oooooooooooooooo>@00000<01TI6@030000000c<c<0<c<c00L0
<c<c00<0000004a<C01<C4`00`1<C4`00`000000IVIV06IVIP0506IVIP8000001`1oOgl2000001<0
VIVI00<0000007moO`1oOgl01`1oOgl00`000000IVIV06IVIP0406IVIP030000001<C4`0C4a<00@0
C4a<00<0000003<c<`0c<c<01@0c<c<00`0000006ATI01TI6@0:01TI6@D000001?ooool00`00003o
ooooooooo`0Tooooo`;o0000;oooool@ojVmj5Kooooo00?o0000ooooooooool01?ooool00ol0003o
ooooooooo`0:ooooo`002Oooool01000003ooooooooooooooolj000000`06ATI00<0000003<c<`0c
<c<01`0c<c<00`000000C4a<04a<C00304a<C08000001`1VIVH2000000L0Ogmo0`00000?09VIV@03
0000001oOgl0Ogmo00L0Ogmo00<0000006IVIP1VIVH01@1VIVH00`000000C4a<04a<C00404a<C003
0000000c<c<0<c<c00H0<c<c00<0000001TI6@0I6AT02P0I6AT4000000Cooooo00<00000oooooooo
ool09_ooool00ol0003oooooooooo`0]ooooo`goZKgXF?ooool00ol0003oooooooooo`04ooooo`03
o`000?oooooooooo00[ooooo0009ooooo`0400000?ooooooooooooooocX0000000?o000001TI6@0I
6AT02P0I6AT2000000L0<c<c00?o00000000001<C4`01@1<C4`2000000L0IVIV0P00000807moO`04
00000?l000000000000000P0VIVI0P0000000ol00000Ogmo07moO`0807moO`030000001VIVH0IVIV
00D0IVIV00<0000004a<C01<C4`0101<C4`00`000000<c<c03<c<`0603<c<`030000000I6AT06ATI
00X06ATI10000004ooooo`0300000?oooooooooo02Oooooo00?o0000ooooooooool0;Oooool8ojVm
j5gooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0:ooooo`002Oooool01000003o
ooooooooooooooll000000d06ATI00<0000003<c<`0c<c<01P0c<c<00`000000C4a<04a<C00504a<
C0030000001VIVH0IVIV00H0IVIV00<0000007moO`1oOgl02@1oOgl8000000d0Ogmo00<0000006IV
IP1VIVH01@1VIVH00`000000C4a<04a<C00404a<C0030000000c<c<0<c<c00H0<c<c00<0000001TI
6@0I6AT02P0I6AT4000000Cooooo00<00000ooooooooool0:?ooool00ol0003oooooooooo`0]oooo
o`?oZKgXH_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Wooooo0009ooooo`04
00000?ooooooooooooooocd00000300I6AT00`000000<c<c03<c<`0703<c<`030000001<C4`0C4a<
00D0C4a<00<0000006IVIP1VIVH01P1VIVH2000001d0Ogmo00<0000006IVIP1VIVH01P1VIVH00`00
0000C4a<04a<C00404a<C0030000000c<c<0<c<c00H0<c<c00<0000001TI6@0I6AT02`0I6AT30000
00Cooooo00<00000ooooooooool0:Oooool2o`0002gooooo00?o0000ooooooooool0Hoooool00ol0
003oooooooooo`02ooooo`03o`000?oooooooooo00Wooooo0009ooooo`0400000?oooooooooooooo
och00000300I6AT00`000000<c<c03<c<`0703<c<`030000001<C4`0C4a<00D0C4a<00<0000006IV
I_l000001`1VIVH00`000000Ogmo07moO`0I07moO`030000001VIVH0IVIV00H0IVIV00<0000004a<
C01<C4`01@1<C4`00`000000<c<c03<c<`0603<c<`030000000I6AT06ATI00/06ATI0`000004oooo
o`0300000?oooooooooo02_ooooo00?o0000ooooooooool0:_ooool00ol0003oooooooooo`1Soooo
o`03o`000?oooooooooo00;ooooo00?o0000ooooooooool02Oooool000Wooooo00@00000oooooooo
oooooooo?`00000<01TI6@03o`0000000000<c<c00L0<c<c00<0000004a<C01<C4`01@1<C4`20000
00P0IVIV00@00000o`00000000000000501oOgl200000003o`00001VIVH0IVIV00L0IVIV00<00000
04a<C01<C4`01@1<C4`00`000000<c<c03<c<`0603<c<`030000000I6AT06ATI00/06ATI00?o0000
0000000000001?ooool00`00003oooooooooo`0/ooooo`03o`000?oooooooooo02Wooooo00?o0000
ooooooooool0I?ooool01Ol0003ooooooooooooooooo000000_ooooo0009ooooo`0400000?oooooo
oooooooood0000003@0I6AT00`000000<c<c03<c<`0603<c<`03o`0000000000C4a<00H0C4a<0P00
000:06IVIP<00000401oOgl00`000000IVIV06IVIP0:06IVIP030000001<C4`0C4a<00D0C4a<00<0
000003<c<`0c<c<01P0c<c<00`0000006ATI01TI6@0;01TI6@<000001?ooool00`00003ooooooooo
o`0]ooooo`03o`000?oooooooooo02Sooooo00?o0000ooooooooool0IOooool01?l0003ooooooooo
ool0000;ooooo`002Oooool01000003ooooooooooooooom1000000d06ATI00<0000003<c<`0c<c<0
1`0c<c<00`000000C4a<04a<C00604a<C08000002`1VIVH4000000T0Ogmo0`00000<06IVIP030000
001<C4`0C4a<00D0C4a<00<0000003<c<`0c<c<01`0c<c<00`0000006ATI01TI6@0;01TI6@<00000
1?ooool00`00003oooooooooo`0^ooooo`;o0000:?ooool00ol0003oooooooooo`1Vooooo`03o`00
0?oooooo000000_ooooo0009ooooo`0400000?oooooooooooooood40000000?o000001TI6@0I6AT0
2`0I6AT00ol00000000003<c<`0703<c<`030000001<C4`0C4a<00L0C4a<00<0000006IVIP1VIVH0
301VIVH9000000h0IVIV00<0000004a<C01<C4`01P1<C4`00`000000<c<c03<c<`0703<c<`030000
000I6AT06ATI00/06ATI0`000004ooooo`0300000?oooooooooo033ooooo00?o0000ooooooooool0
9Oooool00ol0003oooooooooo`1Vooooo`03o`000?oooooo000000_ooooo0009ooooo`0400000?oo
oooooooooooood<000003P0I6AT00`000000<c<c03<c<`0603<c<`03o`0000000000C4a<00L0C4a<
00?o00000000000000008@1VIVH00`000000C4a<04a<C00704a<C0030000000c<c<0<c<c00L0<c<c
00<0000001TI6@0I6AT02`0I6AT3000000Cooooo00<00000ooooooooool0<Oooool00ol0003ooooo
ooooo`0Tooooo`03o`000?oooooooooo06Oooooo00?o0000ooooool000002_ooool000Wooooo00@0
0000ooooooooooooooooA000000>01TI6@030000000c<c<0<c<c00L0<c<c00<0000004a<C01<C4`0
201<C4`3000001d0IVIV00<0000004a<C01<C4`0201<C4`00`000000<c<c03<c<`0703<c<`030000
000I6AT06ATI00/06ATI0`000004ooooo`0300000?oooooooooo03;ooooo00?o0000ooooooooool0
8oooool00ol0003oooooooooo`1Xooooo`;o00002_ooool000Wooooo00@00000oooooooooooooooo
A@00000>01TI6@03o`00000c<c<0<c<c00L0<c<c0P00000;04a<C0030000001VIVH0IVIV01T0IVIV
00<0000004a<C01<C4`02@1<C4`00ol00000<c<c03<c<`0703<c<`030000000I6AT06ATI00`06ATI
0P000004ooooo`0300000?oooooooooo03?ooooo0_l0000Sooooo`03o`000?oooooooooo06Oooooo
0ol0000:ooooo`002Oooool01000003ooooooooooooooom7000000d06ATI00<0000003<c<`0c<c<0
200c<c<2000000X0C4a<0`00000G06IVIP03o`00001<C4`0C4a<00T0C4a<00<0000003<c<`0c<c<0
200c<c<00`0000006ATI01TI6@0<01TI6@8000001?ooool00`00003oooooooooo`0eooooo`03o`00
0?oooooooooo023ooooo00?o0000ooooooooool0Hoooool4o`0000gooooo0009ooooo`0400000?oo
ooooooooooooodP000003@0I6AT00`000000<c<c03<c<`0903<c<`8000002`1<C4`400000100IVIV
0`00000<04a<C0030000000c<c<0<c<c00P0<c<c00?o000001TI6@0I6AT0300I6AT2000000Cooooo
00<00000ooooooooool0=_ooool00ol0003oooooooooo`0Oooooo`03o`000?oooooooooo063ooooo
0ol0000Aooooo`002Oooool01000003ooooooooooooooom9000000d06ATI0`00000:03<c<`030000
001<C4`0C4a<00`0C4a<1`00000206IVIPL000003P1<C4`00`000000<c<c03<c<`0903<c<`030000
000I6AT06ATI00`06ATI0P000004ooooo`0300000?oooooooooo03Oooooo00?o0000ooooooooool0
7_ooool00ol0003oooooooooo`1Looooo`Co00005?ooool000Wooooo00@00000oooooooooooooooo
B`00000>01TI6@03o`00000c<c<0<c<c00P0<c<c00@00000o`000000000000004@1<C4`2000001@0
C4a<00?o000003<c<`0c<c<02@0c<c<00`0000006ATI01TI6@0=01TI6@8000001?ooool00`00003o
ooooooooo`0hooooo`;o00007_ooool00ol0003oooooooooo`1Hooooo`Co00006?ooool000Wooooo
00@00000ooooooooooooooooC000000>01TI6@800000300c<c<2000002@0C4a<00<0000003<c<`0c
<c<02P0c<c<00`0000006ATI01TI6@0=01TI6@8000001?ooool00`00003oooooooooo`0jooooo`03
o`000?oooooooooo01_ooooo00?o0000ooooooooool0E?ooool4o`0001cooooo0009ooooo`040000
0?ooooooooooooooodd000003`0I6AT00`000000<c<c03<c<`0;03<c<`030000001<C4`0C4a<0200
C4a<00<0000003<c<`0c<c<02`0c<c<00`0000006ATI01TI6@0=01TI6@8000001?ooool00`00003o
ooooooooo`0kooooo`03o`000?oooooooooo01[ooooo00?o0000ooooooooool0DOooool3o`00023o
oooo0009ooooo`0400000?ooooooooooooooodh000003`0I6AT00ol00000<c<c03<c<`0;03<c<`<0
00007P1<C4`00`000000<c<c03<c<`0;03<c<`030000000I6AT06ATI00h06ATI0P000004ooooo`03
00000?oooooooooo03cooooo00?o0000ooooooooool06Oooool00ol0003oooooooooo`1=ooooo`Co
00008oooool000Wooooo00@00000ooooooooooooooooD000000>01TI6@<000003@0c<c<01000003o
000000000000000G04a<C080000000?o000003<c<`0c<c<0300c<c<00`0000006ATI01TI6@0>01TI
6@8000001?ooool00`00003oooooooooo`0mooooo`;o00006Oooool00ol0003oooooooooo`19oooo
o`Co00009oooool000Wooooo00@00000ooooooooooooooooD@00000@01TI6@8000003`0c<c<30000
0140C4a<0`00000@03<c<`030000000I6AT06ATI00l06ATI0P000004ooooo`0300000?oooooooooo
03oooooo00?o0000ooooooooool05_ooool00ol0003oooooooooo`15ooooo`Co0000:oooool000Wo
oooo00@00000ooooooooooooooooDP00000A01TI6@030000000c<c<0<c<c00l0<c<c4@00000B03<c
<`030000000I6AT06ATI00l06ATI0`000004ooooo`0300000?oooooooooo043ooooo00?o0000oooo
ooooool05?ooool00ol0003oooooooooo`13ooooo`?o0000;oooool000Wooooo00@00000oooooooo
ooooooooDP0000000ol000006ATI01TI6@0?01TI6@04o`00000000000000000002l0<c<c00?o0000
01TI6@0I6AT0400I6AT3000000Cooooo00<00000ooooooooool0@Oooool00ol0003oooooooooo`0C
ooooo`03o`000?oooooooooo03oooooo1?l0000booooo`002Oooool01000003ooooooooooooooomE
000001<06ATI0P00000/03<c<`030000000I6AT06ATI01406ATI0`000004ooooo`0300000?oooooo
oooo04;ooooo0_l0000Cooooo`03o`000?oooooooooo03_ooooo1?l0000fooooo`002Oooool01000
003ooooooooooooooomF000001@06ATI00<0000003<c<`0c<c<0:00c<c<00`0000006ATI01TI6@0B
01TI6@<000001?ooool00`00003oooooooooo`14ooooo`03o`000?oooooooooo013ooooo00?o0000
ooooooooool0=oooool4o`0003[ooooo0009ooooo`0400000?oooooooooooooooeP000004`0I6AT2
000002P0<c<c00<0000001TI6@0I6AT04@0I6AT4000000Cooooo00<00000ooooooooool0AOooool0
0ol0003oooooooooo`0?ooooo`03o`000?oooooooooo03?ooooo1?l0000nooooo`002Oooool01000
003ooooooooooooooomJ000001<06ATI1@00000Q03<c<`800000500I6AT4000000Cooooo00<00000
ooooooooool0A_ooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo033ooooo0ol00012
ooooo`002Oooool01000003ooooooooooooooomL000001H06ATI0`00000K03<c<`<000005P0I6AT4
000000Cooooo00<00000ooooooooool0Aoooool00ol0003oooooooooo`0=ooooo`03o`000?oooooo
oooo02cooooo1?l00015ooooo`002Oooool01000003ooooooooooooooomM000001P06ATI1000000D
03<c<`<00000600I6AT5000000Cooooo00<00000ooooooooool0B?ooool2o`0000gooooo00?o0000
ooooooooool0:?ooool4o`0004Wooooo0009ooooo`0400000?oooooooooooooooel000006P0I6AT3
000000d0<c<c1000000J01TI6@H000001?ooool00`00003oooooooooo`1:ooooo`03o`000?oooooo
oooo00[ooooo00?o0000ooooooooool09?ooool4o`0004gooooo0009ooooo`0400000?oooooooooo
ooooof4000006`0I6AT=000001d06ATI00?o000000000000000010000004ooooo`0300000?oooooo
oooo04_ooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`0Qooooo`?o0000DOooool0
00Wooooo00@00000ooooooooooooooooH`00001301TI6@L000001?ooool00`00003oooooooooo`1<
ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool07Oooool4o`0005Cooooo0009oooo
o`0400000?ooooooooooooooof@00000@@0I6AT8000000Cooooo00<00000ooooooooool0COooool2
o`0000Sooooo00?o0000ooooooooool06Oooool4o`0005Sooooo0009ooooo`0400000?oooooooooo
ooooofL00000?P0I6AT8000000Cooooo00<00000ooooooooool0Coooool00ol0003oooooooooo`05
ooooo`03o`000?oooooooooo01Gooooo1?l0001Looooo`002Oooool01000003ooooooooooooooomZ
000003X06ATI2@000004ooooo`0300000?oooooooooo053ooooo00?o0000ooooooooool01?ooool0
0ol0003oooooooooo`0Booooo`?o0000H?ooool000Wooooo00@00000ooooooooooooooooJ`00000g
01TI6@/000001?ooool00`00003oooooooooo`1Aooooo`03o`000?oooooooooo00?ooooo00?o0000
ooooooooool03_ooool4o`0006?ooooo0009ooooo`0400000?ooooooooooooooofh00000<`0I6AT<
000000Cooooo00<00000ooooooooool0D_ooool2o`0000?ooooo00?o0000ooooooooool02_ooool4
o`0006Oooooo0009ooooo`0400000?ooooooooooooooog400000;`0I6AT=000000Cooooo00<00000
ooooooooool0E?ooool01?l0003oooooooooool00008ooooo`Co0000Joooool000Wooooo00@00000
ooooooooooooooooLP00000/01TI6@l000001?ooool00`00003oooooooooo`1Eooooo`03o`000?oo
oooo000000Gooooo0ol0001_ooooo`002Oooool01000003ooooooooooooooome00000003o`00000I
6AT06ATI02@06ATI4@000004ooooo`0300000?oooooooooo05Kooooo0_l000000ooooooo0000o`00
0002o`0007;ooooo0009ooooo`0400000?ooooooooooooooogT000008@0I6AT200000003o`000000
0000000000h000001?ooool00`00003oooooooooo`1Gooooo`;o0000M_ooool000Wooooo00@00000
ooooooooooooooooP000000G01TI6AH000001?ooool00`00003oooooooooo`3?ooooo`002Oooool0
1000003ooooooooooooooon3000001406ATI6@000004ooooo`0300000?oooooooooo0<oooooo0009
ooooo`0400000?ooooooooooooooojd000001?ooool00`00003oooooooooo`3?ooooo`002Oooool0
1000003ooooooooooooooon]000000Cooooo00<00000ooooooooool0coooool000Wooooo00@00000
oooooooooooooooo[@000004ooooo`0300000?oooooooooo0<oooooo0009ooooo`0400000?oooooo
ooooooooojd000001?ooool00`00003oooooooooo`3?ooooo`002Oooool01000003ooooooooooooo
oon]000000Cooooo00<00000ooooooooool0coooool000Wooooo00@00000oooooooooooooooo[@00
0004ooooo`0300000?oooooooooo0<oooooo0009ooooo`0400000?ooooooooooooooojd000001?oo
ool00`00003oooooooooo`3?ooooo`002Oooool01000003ooooooooooooooon]000000Cooooo00<0
0000ooooooooool0coooool000Wooooo00@00000oooooooooooooooo[@000004ooooo`0300000?oo
oooooooo0<oooooo0009ooooo`0400000?ooooooooooooooojd000001?ooool00`00003ooooooooo
o`3?ooooo`002Oooool01000003ooooooooooooooon]000000Cooooo00<00000ooooooooool0cooo
ool000Wooooo00<00000ooooooooool0/_ooool00`00003oooooooooo`3?ooooo`002Oooool00`00
003oooooooooo`2booooo`0300000?oooooooooo0<oooooo0009ooooo`0300000?oooooooooo0;;o
oooo00<00000ooooooooool0coooool000Wooooo]P00003Aooooo`00oooooonAooooo`00oooooonA
ooooo`00oooooonAooooo`00oooooonAooooo`00oooooonAooooo`00oooooonAooooo`00oooooonA
ooooo`00oooooonAooooo`00oooooonAooooo`00oooooonAooooo`00oooooonAooooo`00oooooonA
ooooo`00oooooonAooooo`00oooooonAooooo`00oooooonAooooo`00oooooonAooooo`00oooooonA
ooooo`002Ooooonfo`00017ooooo]P00000:ooooo`002Oooool00ol0003oooooooooo`2booooo`03
o`000?oooooooooo00oooooo00<00000ooooooooool0/_ooool00`00003oooooooooo`08ooooo`00
2Oooool00ol0003oooooooooo`2booooo`03o`000?oooooooooo00oooooo00<00000ooooooooool0
/_ooool00`00003oooooooooo`08ooooo`002Oooool00ol0003oooooooooo`2booooo`03o`000?oo
oooooooo00oooooo00<00000ooooooooool0/_ooool00`00003oooooooooo`08ooooo`002Oooool0
0ol0003oooooooooo`2booooo`03o`000?oooooooooo00oooooo00<00000ooooooooool0/_ooool0
0`00003oooooooooo`08ooooo`002Oooool00ol0003oooooooooo`2booooo`03o`000?oooooooooo
00oooooo00<00000ooooooooool0/_ooool00`00003oooooooooo`08ooooo`002Oooool00ol0003o
ooooooooo`2booooo`03o`000?oooooooooo00oooooo00<00000ooooooooool0/_ooool00`00003o
ooooooooo`08ooooo`002Oooool00ol0003oooooooooo`2booooo`03o`000?oooooooooo00oooooo
00<00000ooooooooool0/_ooool00`00003oooooooooo`08ooooo`002Oooool00ol0003ooooooooo
o`2booooo`03o`000?oooooooooo00oooooo00<00000ooooooooool0/_ooool00`00003ooooooooo
o`08ooooo`002Oooool00ol0003oooooooooo`2booooo`03o`000?oooooooooo00oooooo00<00000
ooooooooool0/_ooool00`00003oooooooooo`08ooooo`002Oooool00ol0003oooooooooo`2boooo
o`03o`000?oooooooooo00oooooo00<00000ooooooooool0/_ooool00`00003oooooooooo`08oooo
o`002Oooool00ol0003oooooooooo`2booooo`03o`000?oooooooooo00oooooo00<00000oooooooo
ool0/_ooool00`00003oooooooooo`08ooooo`002Oooool00ol0003oooooooooo`2booooo`03o`00
0?oooooooooo00oooooo00<00000ooooooooool0/_ooool00`00003oooooooooo`08ooooo`002Ooo
ool00ol0003oooooooooo`2booooo`03o`000?oooooooooo00oooooo00<00000ooooooooool0/_oo
ool00`00003oooooooooo`08ooooo`002Oooool00ol0003oooooooooo`2booooo`03o`000?oooooo
oooo00oooooo00<00000ooooooooool0/_ooool00`00003oooooooooo`08ooooo`002Oooool00ol0
003oooooooooo`2booooo`03o`000?oooooooooo00oooooo00<00000ooooooooool0/_ooool00`00
003oooooooooo`08ooooo`002Oooool00ol0003oooooooooo`2booooo`03o`000?oooooooooo00oo
oooo00<00000ooooooooool0/_ooool00`00003oooooooooo`08ooooo`002Oooool00ol0003ooooo
ooooo`2booooo`03o`000?oooooooooo00oooooo00<00000ooooooooool0/_ooool00`00003ooooo
ooooo`08ooooo`002Oooool00ol0003oooooooooo`2booooo`03o`000?oooooooooo00oooooo00<0
0000ooooooooool0/_ooool00`00003oooooooooo`08ooooo`002Oooool00ol0003oooooooooo`2b
ooooo`03o`000?oooooooooo00oooooo00<00000ooooooooool0/_ooool00`00003oooooooooo`08
ooooo`002Oooool00ol0003oooooooooo`2booooo`03o`000?oooooooooo00oooooo00<00000oooo
ooooool0/_ooool00`00003oooooooooo`08ooooo`002Oooool00ol0003oooooooooo`2booooo`03
o`000?oooooooooo00oooooo00<00000ooooooooool0/_ooool00`00003oooooooooo`08ooooo`00
2Oooool00ol0003oooooooooo`2booooo`03o`000?oooooooooo00oooooo00<00000ooooooooool0
/_ooool00`00003oooooooooo`08ooooo`002Oooool00ol0003oooooooooo`03ooooo`;oogl02ooo
ool2oomo0:3ooooo00?o0000ooooooooool03oooool00`00003oooooooooo`03ooooo`;oogl02ooo
ool2oomo0:3ooooo00<00000ooooooooool02?ooool000Wooooo00?o0000ooooooooool00_ooool3
oomo00_ooooo0_ooO`02ooooo`<0003o1oooool2oomo09;ooooo00?o0000ooooooooool03oooool0
0`00003oooooooooo`02ooooo`?oogl02oooool2oomo00cooooo0_ooO`2Booooo`0300000?oooooo
oooo00Sooooo0009ooooo`03o`000?oooooooooo00;ooooo0_ooO`0=ooooo`<0003o0oooool50000
o`;ooooo0_ooO`2Booooo`03o`000?oooooooooo00oooooo00<00000ooooooooool00_ooool2oomo
01[ooooo0_ooO`2Booooo`0300000?oooooooooo00Sooooo0009ooooo`03o`000?oooooooooo017o
oooo00<0003oooooooooool02?ooool20000oiCooooo00?o0000ooooooooool03oooool00`00003o
ooooooooo`2booooo`0300000?oooooooooo00Sooooo0009ooooo`03o`000?oooooooooo017ooooo
00<0003oooooooooool02_ooool00`000?ooooooooooo`2Aooooo`03o`000?oooooooooo00oooooo
00<00000ooooooooool0/_ooool00`00003oooooooooo`08ooooo`002Oooool00ol0003ooooooooo
o`0Aooooo`030000oooooooooooo00_ooooo0`000?n@ooooo`03o`000?oooooooooo00oooooo00<0
0000ooooooooool0/_ooool00`00003oooooooooo`08ooooo`002Oooool00ol0003oooooooooo`0A
ooooo`030000oooooooooooo00kooooo00<0003oooooooooool0SOooool00ol0003oooooooooo`0?
ooooo`0300000?oooooooooo0;;ooooo00<00000ooooooooool02?ooool000Wooooo00?o0000oooo
ooooool04Oooool00`000?ooooooooooo`0?ooooo`030000oooooooooooo08cooooo00?o0000oooo
ooooool03oooool00`00003oooooooooo`2booooo`0300000?oooooooooo00Sooooo0009ooooo`03
o`000?oooooooooo01;ooooo00<0003oooooooooool03oooool20000ohcooooo00?o0000oooooooo
ool03oooool00`00003oooooooooo`2booooo`0300000?oooooooooo00Sooooo0009ooooo`03o`00
0?oooooooooo01;ooooo00<0003oooooooooool04Oooool00`000?ooooooooooo`29ooooo`03o`00
0?oooooooooo00oooooo00<00000ooooooooool0/_ooool00`00003oooooooooo`08ooooo`002Ooo
ool00ol0003oooooooooo`0Booooo`030000oooooooooooo01;ooooo00<0003oooooooooool0R?oo
ool00ol0003oooooooooo`0?ooooo`0300000?oooooooooo0;;ooooo00<00000ooooooooool02?oo
ool000Wooooo00?o0000ooooooooool04oooool00`000?ooooooooooo`02oomo00Gooooo0_ooO`09
ooooo`80003oR?ooool00ol0003oooooooooo`0?ooooo`0300000?oooooooooo01Kooooo0_ooO`05
ooooo`;oogl0Toooool00`00003oooooooooo`08ooooo`002Oooool00ol0003oooooooooo`0Doooo
o`040000ooooooooogl0oomo00Gooooo0_ooO`0;ooooo`80003oQ_ooool00ol0003oooooooooo`0?
ooooo`0300000?oooooooooo01Kooooo0_ooO`05ooooo`;oogl0Toooool00`00003oooooooooo`08
ooooo`002Oooool00ol0003oooooooooo`0Eooooo`030000oooooooooooo01Cooooo00<0003ooooo
ooooool0Poooool00ol0003oooooooooo`0?ooooo`0300000?oooooooooo0;;ooooo00<00000oooo
ooooool02?ooool000Wooooo00?o0000ooooooooool05_ooool00`000?ooooooooooo`0Dooooo`03
0000oooooooooooo08;ooooo00?o0000ooooooooool03oooool00`00003oooooooooo`2booooo`03
00000?oooooooooo00Sooooo0009ooooo`03o`000?oooooooooo01Kooooo00<0003oooooooooool0
0oooool2oomo00Kooooo0_ooO`08ooooo`030000oooooooooooo00;oogl00oooool2oomo07[ooooo
00?o0000ooooooooool03oooool00`00003oooooooooo`0Looooo`;oogl01_ooool2oomo00_ooooo
0_ooO`03ooooo`;oogl0N_ooool00`00003oooooooooo`08ooooo`002Oooool00ol0003ooooooooo
o`0Fooooo`030000oooooooooooo00?ooooo0_ooO`06ooooo`;oogl02Oooool20000o`;oogl00ooo
ool2oomo07[ooooo00?o0000ooooooooool03oooool00`00003oooooooooo`0Looooo`;oogl01_oo
ool2oomo00_ooooo0_ooO`03ooooo`;oogl0N_ooool00`00003oooooooooo`08ooooo`002Oooool0
0ol0003oooooooooo`0Gooooo`030000oooooooooooo01Oooooo00<0003oooooooooool00oooool2
oomo07Wooooo00?o0000ooooooooool03oooool00`00003oooooooooo`0gooooo`;oogl0NOooool0
0`00003oooooooooo`08ooooo`002Oooool00ol0003oooooooooo`0Hooooo`030000oooooooooooo
01Oooooo00<0003ooomo0?ooO`000_ooool2oomo07Wooooo00?o0000ooooooooool03oooool00`00
003oooooooooo`0cooooo`;oogl00_ooool2oomo07Wooooo00<00000ooooooooool02?ooool000Wo
oooo00?o0000ooooooooool06Oooool00`000?ooooooooooo`0Gooooo`030000ooooO`3ooooo07co
oooo00?o0000ooooooooool03oooool00`00003oooooooooo`0cooooo`;oogl0OOooool00`00003o
ooooooooo`08ooooo`002Oooool00ol0003oooooooooo`0Jooooo`030000oooooooooooo00Cooooo
0_ooO`0Aooooo`80003oO?ooool00ol0003oooooooooo`0?ooooo`0300000?oooooooooo027ooooo
0_ooO`2?ooooo`0300000?oooooooooo00Sooooo0009ooooo`03o`000?oooooooooo01[ooooo00?o
ogl00000ooooool01?ooool2oomo01?ooooo00<0003oooooooooool0NOooool00ol0003ooooooooo
o`0?ooooo`0300000?oooooooooo01[ooooo0_ooO`05ooooo`;oogl0Soooool00`00003ooooooooo
o`08ooooo`002Oooool00ol0003oooooooooo`0Jooooo`;oogl000<0003oooooooooool04oooool2
oomo00?ooooo00<0003oooooooooool01?ooool2oomo07;ooooo00?o0000ooooooooool03oooool0
0`00003oooooooooo`0Jooooo`;oogl05_ooool2oomo00[ooooo0_ooO`1booooo`0300000?oooooo
oooo00Sooooo0009ooooo`03o`000?oooooooooo01gooooo00<0003oooooooooool04_ooool2oomo
00Cooooo00<0003oooooooooool00oooool2oomo07;ooooo00?o0000ooooooooool03oooool00`00
003oooooooooo`0booooo`;oogl02_ooool2oomo07;ooooo00<00000ooooooooool02?ooool000Wo
oooo00?o0000ooooooooool07_ooool00`000?ooooooooooo`0Hooooo`030000oooooooooooo07Ko
oooo00?o0000ooooooooool03oooool00`00003oooooooooo`2booooo`0300000?oooooooooo00So
oooo0009ooooo`03o`000?oooooooooo01oooooo00<0003oooooooooool06?ooool00`000?oooooo
ooooo`1eooooo`03o`000?oooooooooo00oooooo00<00000ooooooooool0/_ooool00`00003ooooo
ooooo`08ooooo`002Oooool00ol0003oooooooooo`0Oooooo`030000oooooooooooo00_ooooo0ol0
000:ooooo`030000oooooooooooo07Gooooo00?o0000ooooooooool03oooool00`00003ooooooooo
o`2booooo`0300000?oooooooooo00Sooooo0009ooooo`03o`000?oooooooooo023ooooo00<0003o
ooooooooool00_ooO`000oooooooogl0oomo0004ooooo`Go00002_ooool00`000?ooooooooooo`1d
ooooo`03o`000?oooooooooo00oooooo00<00000ooooooooool08oooool2oomo0003ooooooooO`3o
ogl008[ooooo00<00000ooooooooool02?ooool000Wooooo00?o0000ooooooooool08Oooool00`00
0?oooooooomo0004oomo00Cooooo1Ol0000;ooooo`030000oooooooooooo07?ooooo00?o0000oooo
ooooool03oooool00`00003oooooooooo`0Sooooo`Googl0R_ooool00`00003oooooooooo`08oooo
o`002Oooool00ol0003oooooooooo`0Rooooo`030000oooooooooooo00;oogl01Oooool5o`0000[o
oooo0_ooO`000`000?ooooooooooo`1booooo`03o`000?oooooooooo00oooooo00<00000oooooooo
ool09Oooool2oomo01Cooooo0_ooO`1eooooo`0300000?oooooooooo00Sooooo0009ooooo`03o`00
0?oooooooooo02?ooooo00<0003oo`00ooooool01oooool3o`0000_ooooo0_ooO`000oooool0003o
0000o`1booooo`03o`000?oooooooooo00oooooo00<00000ooooooooool0>oooool2oomo07Gooooo
00<00000ooooooooool02?ooool000Wooooo00?o0000ooooooooool09Oooool00`000?oooooooooo
o`0Hooooo`030000oooooooooooo06oooooo00?o0000ooooooooool03oooool00`00003ooooooooo
o`2booooo`0300000?oooooooooo00Sooooo0009ooooo`03o`000?oooooooooo02Kooooo00<0003o
ooooooooool05oooool00`000?ooooooooooo`1_ooooo`03o`000?oooooooooo00oooooo00<00000
ooooooooool0/_ooool00`00003oooooooooo`08ooooo`002Oooool00ol0003oooooooooo`0Noooo
o`;oogl01oooool00`000?ooooooooooo`0Gooooo`030000oooooooooooo06kooooo00?o0000oooo
ooooool03oooool00`00003oooooooooo`0Nooooo`;oogl0T_ooool00`00003oooooooooo`08oooo
o`002Oooool00ol0003oooooooooo`0Nooooo`;oogl02?ooool00`000?ooooooooooo`0Gooooo`03
0000oooooooooooo06gooooo00?o0000ooooooooool03oooool00`00003oooooooooo`0Nooooo`;o
ogl0T_ooool00`00003oooooooooo`08ooooo`002Oooool00ol0003oooooooooo`0Yooooo`03o`00
o`000?oooooo01Oooooo0P000?m]ooooo`03o`000?oooooooooo00oooooo00<00000ooooooooool0
/_ooool00`00003oooooooooo`08ooooo`002Oooool00ol0003oooooooooo`0[ooooo`030000oooo
oooooooo01Oooooo00<0003oooooooooool0J_ooool00ol0003oooooooooo`0?ooooo`0300000?oo
oooooooo0;;ooooo00<00000ooooooooool02?ooool000Wooooo00?o0000ooooooooool0;?ooool0
0`000?ooooooooooo`0Fooooo`030000oooooooooooo06[ooooo00?o0000ooooooooool03oooool0
0`00003oooooooooo`2booooo`0300000?oooooooooo00Sooooo0009ooooo`03o`000?oooooooooo
02gooooo00<0003oooooooooool05_ooool00`000?ooooooooooo`1Yooooo`03o`000?oooooooooo
00oooooo00<00000ooooooooool0/_ooool00`00003oooooooooo`08ooooo`002Oooool00ol0003o
ooooooooo`0^ooooo`03o`00o`000?oooooo01Kooooo00<0003oooooooooool01?ooool2oomo06;o
oooo00?o0000ooooooooool03oooool00`00003oooooooooo`1>ooooo`;oogl0H_ooool00`00003o
ooooooooo`08ooooo`002Oooool00ol0003oooooooooo`0`ooooo`040000ooooooooooooooooo`;o
ogl04Oooool00`000?ooooooooooo`04ooooo`;oogl0H_ooool00ol0003oooooooooo`0?ooooo`03
00000?oooooooooo03Cooooo0_ooO`0Hooooo`;oogl0H_ooool00`00003oooooooooo`08ooooo`00
2Oooool00ol0003oooooooooo`0aooooo`030000oooooooooooo00;oogl04_ooool00`000?oooooo
ooooo`1Wooooo`03o`000?oooooooooo00oooooo00<00000ooooooooool0=?ooool2oomo07cooooo
00<00000ooooooooool02?ooool000Wooooo00?o0000ooooooooool0<_ooool00`000?oooooooooo
o`0Cooooo`030000oooooooooooo06Oooooo00?o0000ooooooooool03oooool00`00003ooooooooo
o`2booooo`0300000?oooooooooo00Sooooo0009ooooo`03o`000?oooooooooo03?ooooo00<0003o
ooooooooool01oooool2oomo00;ooooo0_ooO`06ooooo`03o`00oooooooooooo06Kooooo00?o0000
ooooooooool03oooool00`00003oooooooooo`0mooooo`;oogl00_ooool2oomo06oooooo00<00000
ooooooooool02?ooool000Wooooo00?o0000ooooooooool0=?ooool30000o`Kooooo0_ooO`02oooo
o`;oogl01oooool00`000?ooooooooooo`1Uooooo`03o`000?oooooooooo00oooooo00<00000oooo
ooooool0?Oooool2oomo00;ooooo0_ooO`1_ooooo`0300000?oooooooooo00Sooooo0009ooooo`03
o`000?oooooooooo03Oooooo00<0003oooooooooool04?ooool00`000?ooooooooooo`1Uooooo`03
o`000?oooooooooo00oooooo00<00000ooooooooool0/_ooool00`00003oooooooooo`08ooooo`00
2Oooool00ol0003oooooooooo`0hooooo`030000oooooooooooo013ooooo00<0003oooooooooool0
I?ooool00ol0003oooooooooo`0?ooooo`0300000?oooooooooo0;;ooooo00<00000ooooooooool0
2?ooool000Wooooo00?o0000ooooooooool0>Oooool00`000?ooooooooooo`0@ooooo`030000oooo
oooooooo06?ooooo00?o0000ooooooooool03oooool00`00003oooooooooo`2booooo`0300000?oo
oooooooo00Sooooo0009ooooo`03o`000?oooooooooo03[ooooo00<0003oooooooooool03oooool0
0`000?ooooooooooo`1Sooooo`03o`000?oooooooooo00oooooo00<00000ooooooooool0/_ooool0
0`00003oooooooooo`08ooooo`002Oooool00ol0003oooooooooo`0kooooo`030000ool00?l0003o
00oooooo00<0003oooooooooool0H_ooool00ol0003oooooooooo`0?ooooo`0300000?oooooooooo
0;;ooooo00<00000ooooooooool02?ooool000Wooooo00?o0000ooooooooool0?_ooool20000o`go
oooo00<0003oooooooooool0H_ooool00ol0003oooooooooo`0?ooooo`0300000?oooooooooo0;;o
oooo00<00000ooooooooool02?ooool000Wooooo00?o0000ooooooooool0@?ooool20000o`_ooooo
3P000?mGooooo`03o`000?oooooooooo00oooooo00<00000ooooooooool0/_ooool00`00003ooooo
ooooo`08ooooo`002Oooool00ol0003oooooooooo`12ooooo`<0003o1_ooool20000o`kooooo1@00
0?mBooooo`03o`000?oooooooooo00oooooo00<00000ooooooooool0/_ooool00`00003ooooooooo
o`08ooooo`002Oooool00ol0003oooooooooo`15ooooo`<0003o0_ooool30000oa?ooooo00@0003o
o`00o`000?l0003oC_ooool00ol0003oooooooooo`0?ooooo`0300000?oooooooooo0;;ooooo00<0
0000ooooooooool02?ooool000Wooooo00?o0000ooooooooool0B?ooool00`000?oo003o0000o`0I
ooooo`80003oC?ooool00ol0003oooooooooo`0?ooooo`0300000?oooooooooo0;;ooooo00<00000
ooooooooool02?ooool000Wooooo00?o0000ooooooooool0BOooool00`000?ooooooooooo`0Joooo
o`80003oB_ooool00ol0003oooooooooo`0?ooooo`0300000?oooooooooo0;;ooooo00<00000oooo
ooooool02?ooool000Wooooo00?o0000ooooooooool0B?ooool00`000?ooooooooooo`0Mooooo`03
0000oooooooooooo04Oooooo00?o0000ooooooooool03oooool00`00003oooooooooo`2booooo`03
00000?oooooooooo00Sooooo0009ooooo`03o`000?oooooooooo04Oooooo00<0003oooooooooool0
7oooool00`000?ooooooooooo`16ooooo`03o`000?oooooooooo00oooooo00<00000ooooooooool0
/_ooool00`00003oooooooooo`08ooooo`002Oooool00ol0003oooooooooo`16ooooo`030000oooo
oooooooo027ooooo00?o003o0000o`000?l0AOooool00ol0003oooooooooo`0?ooooo`0300000?oo
oooooooo0;;ooooo00<00000ooooooooool02?ooool000Wooooo00?o0000ooooooooool0A_ooool0
0`000?ooooooooooo`0Tooooo`030000oooooooooooo04;ooooo00?o0000ooooooooool03oooool0
0`00003oooooooooo`2booooo`0300000?oooooooooo00Sooooo0009ooooo`03o`000?oooooooooo
04Kooooo00<0003oooooooooool09Oooool00`000?ooooooooooo`11ooooo`03o`000?oooooooooo
00oooooo00<00000ooooooooool0/_ooool00`00003oooooooooo`08ooooo`002Oooool00ol0003o
ooooooooo`15ooooo`030000oooooooooooo02Oooooo0P000?m1ooooo`03o`000?oooooooooo00oo
oooo00<00000ooooooooool0/_ooool00`00003oooooooooo`08ooooo`002Oooool00ol0003ooooo
ooooo`15ooooo`030000oooooooooooo02Wooooo00<0003oooooooooool0?_ooool00ol0003ooooo
ooooo`0?ooooo`0300000?oooooooooo0;;ooooo00<00000ooooooooool02?ooool000Wooooo00?o
0000ooooooooool0AOooool00`000?ooooooooooo`0Zooooo`80003o?_ooool00ol0003ooooooooo
o`0?ooooo`0300000?oooooooooo0;;ooooo00<00000ooooooooool02?ooool000Wooooo00?o0000
ooooooooool0AOooool00`000?ooooooooooo`0/ooooo`030000oooooooooooo03_ooooo00?o0000
ooooooooool03oooool00`00003oooooooooo`2booooo`0300000?oooooooooo00Sooooo0009oooo
o`03o`000?oooooooooo04Gooooo00<0003oooooooooool0;Oooool00`000?ooooooooooo`0joooo
o`03o`000?oooooooooo00oooooo00<00000ooooooooool0/_ooool00`00003oooooooooo`08oooo
o`002Oooool00ol0003oooooooooo`15ooooo`030000oooooooooooo02kooooo00<0003ooooooooo
ool0:Oooool2oomo00kooooo00?o0000ooooooooool03oooool00`00003oooooooooo`2Rooooo`;o
ogl03_ooool00`00003oooooooooo`08ooooo`002Oooool00ol0003oooooooooo`15ooooo`030000
oooooooooooo02oooooo00<0003oooooooooool0:?ooool2oomo00kooooo00?o0000ooooooooool0
3oooool00`00003oooooooooo`2Rooooo`;oogl03_ooool00`00003oooooooooo`08ooooo`002Ooo
ool00ol0003oooooooooo`15ooooo`030000oooooooooooo033ooooo00<0003oooooooooool0=ooo
ool00ol0003oooooooooo`0?ooooo`0300000?oooooooooo0;;ooooo00<00000ooooooooool02?oo
ool000Wooooo00?o0000ooooooooool0AOooool00`000?ooooooooooo`0aooooo`030000oooooooo
oooo03Kooooo00?o0000ooooooooool03oooool00`00003oooooooooo`2booooo`0300000?oooooo
oooo00Sooooo0009ooooo`03o`000?oooooooooo04Gooooo00<0003oooooooooool0<_ooool00`00
0?ooooooooooo`0eooooo`03o`000?oooooooooo00oooooo00<00000ooooooooool0/_ooool00`00
003oooooooooo`08ooooo`002Oooool00ol0003oooooooooo`16ooooo`030000oooooooooooo03;o
oooo00<0003oooooooooool0=?ooool00ol0003oooooooooo`0?ooooo`0300000?oooooooooo0;;o
oooo00<00000ooooooooool02?ooool000Wooooo00?o0000ooooooooool0A_ooool00`000?oooooo
ooooo`0cooooo`030000oooooooooooo03?ooooo00?o0000ooooooooool03oooool00`00003ooooo
ooooo`2booooo`0300000?oooooooooo00Sooooo0009ooooo`03o`000?oooooooooo04Kooooo00<0
003oooooooooool0<oooool00`000?ooooooooooo`0cooooo`03o`000?oooooooooo00oooooo00<0
0000ooooooooool0/_ooool00`00003oooooooooo`08ooooo`002Oooool00ol0003oooooooooo`17
ooooo`030000oooooooooooo03?ooooo00<0003oooooooooool0<_ooool00ol0003oooooooooo`0?
ooooo`0300000?oooooooooo0;;ooooo00<00000ooooooooool02?ooool000Wooooo00?o0000oooo
ooooool0Aoooool00`000?ooooooooooo`0Wooooo`;oogl02oooool00`000?ooooooooooo`0aoooo
o`03o`000?oooooooooo00oooooo00<00000ooooooooool0LOooool2oomo03oooooo00<00000oooo
ooooool02?ooool000Wooooo00?o0000ooooooooool0Aoooool00`000?ooooooooooo`0Wooooo`;o
ogl03?ooool00`000?ooooooooooo`0`ooooo`03o`000?oooooooooo00oooooo00<00000oooooooo
ool0LOooool2oomo03oooooo00<00000ooooooooool02?ooool000Wooooo00?o0000ooooooooool0
B?ooool00`000?ooooooooooo`0eooooo`030000oooooooooooo013ooooo0_ooO`0Mooooo`03o`00
0?oooooooooo00oooooo00<00000ooooooooool0Toooool2oomo01gooooo00<00000ooooooooool0
2?ooool000Wooooo00?o0000ooooooooool0B?ooool00`000?ooooooooooo`0eooooo`030000oooo
oooooooo00cooooo0_ooO`02ooooo`;oogl07Oooool00ol0003oooooooooo`0?ooooo`0300000?oo
oooooooo08oooooo0_ooO`02ooooo`;oogl07Oooool00`00003oooooooooo`08ooooo`002Oooool0
0ol0003oooooooooo`19ooooo`030000oooooooooooo01Wooooo0ol0000Booooo`;oogl01Oooool0
0`000?ooooooooooo`0;ooooo`;oogl08Oooool00ol0003oooooooooo`0?ooooo`0300000?oooooo
oooo07[ooooo0_ooO`0Cooooo`;oogl08Oooool00`00003oooooooooo`08ooooo`002Oooool00ol0
003oooooooooo`19ooooo`030000oooooooooooo01Sooooo1Ol0000Aooooo`;oogl01_ooool00`00
0?ooooooooooo`0]ooooo`03o`000?oooooooooo00oooooo00<00000ooooooooool0N_ooool2oomo
03Kooooo00<00000ooooooooool02?ooool000Wooooo00?o0000ooooooooool0BOooool00`000?oo
ooooooooo`0Hooooo`Go00002oooool2oomo00cooooo00<0003oooooooooool01oooool2oomo02Co
oooo00?o0000ooooooooool03oooool00`00003oooooooooo`1dooooo`;oogl05_ooool2oomo02Co
oooo00<00000ooooooooool02?ooool000Wooooo00?o0000ooooooooool0B_ooool00`000?oooooo
ooooo`0Gooooo`Go00002oooool2oomo00gooooo00<0003oooooooooool01_ooool2oomo02Cooooo
00?o0000ooooooooool03oooool00`00003oooooooooo`1dooooo`;oogl05_ooool2oomo02Cooooo
00<00000ooooooooool02?ooool000Wooooo00?o0000ooooooooool0Boooool00`000?oooooooooo
o`0Gooooo`?o00002?ooool2oomo00oooooo0_ooO`000`000?ooooooooooo`0:ooooo`;oogl08?oo
ool00ol0003oooooooooo`0?ooooo`0300000?oooooooooo073ooooo0_ooO`0?ooooo`;oogl03Ooo
ool2oomo023ooooo00<00000ooooooooool02?ooool000Wooooo00?o0000ooooooooool0C?ooool0
0`000?ooooooooooo`0Qooooo`;oogl01?ooool2oomo00Wooooo0_ooO`000oooool0003oooooo`0:
ooooo`;oogl08?ooool00ol0003oooooooooo`0?ooooo`0300000?oooooooooo073ooooo0_ooO`04
ooooo`;oogl02Oooool2oomo00gooooo0_ooO`0Pooooo`0300000?oooooooooo00Sooooo0009oooo
o`03o`000?oooooooooo04gooooo00<0003oooooooooool01_ooool2oomo01Sooooo0_ooO`04oooo
o`;oogl03?ooool00`000?ooooooooooo`0[ooooo`03o`000?oooooooooo00oooooo00<00000oooo
ooooool0E_ooool2oomo01Sooooo0_ooO`04ooooo`;oogl0>_ooool00`00003oooooooooo`08oooo
o`002Oooool00ol0003oooooooooo`1>ooooo`030000oooooooooooo00Gooooo0_ooO`0Hooooo`;o
ogl04oooool00`000?ooooooooooo`0Zooooo`03o`000?oooooooooo00oooooo00<00000oooooooo
ool0E_ooool2oomo01Sooooo0_ooO`10ooooo`0300000?oooooooooo00Sooooo0009ooooo`03o`00
0?oooooooooo04kooooo00?o003oooooooooool0=?ooool00`000?ooooooooooo`0Zooooo`03o`00
0?oooooooooo00oooooo00<00000ooooooooool0/_ooool00`00003oooooooooo`08ooooo`002Ooo
ool00ol0003oooooooooo`1?ooooo`030000oooooooooooo00_ooooo0_ooO`09ooooo`;oogl06Ooo
ool2oomo0003ooooo`000?oooooo02[ooooo00?o0000ooooooooool03oooool00`00003ooooooooo
o`1Mooooo`;oogl02Oooool2oomo01Wooooo0_ooO`0]ooooo`0300000?oooooooooo00Sooooo0009
ooooo`03o`000?oooooooooo053ooooo00<0003oooooooooool02_ooool2oomo00Wooooo0_ooO`0I
ooooo`;oogl000?ooooo0000ooooool0:_ooool00ol0003oooooooooo`0?ooooo`0300000?oooooo
oooo05gooooo0_ooO`09ooooo`;oogl06Oooool2oomo02gooooo00<00000ooooooooool02?ooool0
00Wooooo00?o0000ooooooooool0DOooool00`000?ooooooooooo`0cooooo`03o`00oooooooooooo
02Sooooo00?o0000ooooooooool03oooool00`00003oooooooooo`2booooo`0300000?oooooooooo
00Sooooo0009ooooo`03o`000?oooooooooo05;ooooo00<0003oooooooooool0<_ooool00`000?oo
ooooooooo`09ooooo`;oogl07Oooool00ol0003oooooooooo`0?ooooo`0300000?oooooooooo09?o
oooo0_ooO`0Mooooo`0300000?oooooooooo00Sooooo0009ooooo`03o`000?oooooooooo05?ooooo
00?o003oooooooooool0<?ooool00oooO`00003oooooo`0:ooooo`;oogl07Oooool00ol0003ooooo
ooooo`0?ooooo`0300000?oooooooooo08Kooooo0_ooO`0;ooooo`;oogl07Oooool00`00003ooooo
ooooo`08ooooo`002Oooool00ol0003oooooooooo`1Cooooo`030000oooooooooooo01cooooo0_oo
O`0Booooo`03oomo00000?oooooo02Wooooo00?o0000ooooooooool03oooool00`00003ooooooooo
o`1booooo`;oogl04_ooool2oomo02[ooooo00<00000ooooooooool02?ooool000Wooooo00?o0000
ooooooooool0E?ooool00`000?ooooooooooo`0Kooooo`;oogl05?ooool00`000?ooooooooooo`0W
ooooo`03o`000?oooooooooo00oooooo00<00000ooooooooool0L_ooool2oomo03kooooo00<00000
ooooooooool02?ooool000Wooooo00?o0000ooooooooool0EOooool00`000?ooooooooooo`0Aoooo
o`;oogl01Oooool2oomo01;ooooo0_ooO`02ooooo`030000oooooooooooo02Oooooo00?o0000oooo
ooooool03oooool00`00003oooooooooo`1Yooooo`;oogl01Oooool2oomo01;ooooo0_ooO`0/oooo
o`0300000?oooooooooo00Sooooo0009ooooo`03o`000?oooooooooo05Kooooo00<0003ooooooooo
ool03_ooool4oomo00Gooooo0_ooO`0>ooooo`;oogl00_ooool2oomo00;ooooo00<0003ooooooooo
ool09oooool00ol0003oooooooooo`0?ooooo`0300000?oooooooooo06Oooooo1?ooO`05ooooo`;o
ogl03_ooool2oomo00;ooooo0_ooO`0/ooooo`0300000?oooooooooo00Sooooo0009ooooo`03o`00
0?oooooooooo05Oooooo00?o003o0000ooooool03Oooool2oomo01Oooooo0_ooO`06ooooo`030000
oooooooooooo02Oooooo00?o0000ooooooooool03oooool00`00003oooooooooo`1Wooooo`;oogl0
5oooool2oomo033ooooo00<00000ooooooooool02?ooool000Wooooo00?o0000ooooooooool0BOoo
ool2oomo00kooooo0P000?l]ooooo`030000oooooooooooo02Oooooo00?o0000ooooooooool03ooo
ool00`00003oooooooooo`19ooooo`;oogl0Ioooool00`00003oooooooooo`08ooooo`002Oooool0
0ol0003oooooooooo`19ooooo`;oogl01oooool2oomo00Oooooo00<0003oooooooooool04?ooool2
oomo01Oooooo00<0003oooooooooool0:?ooool00ol0003oooooooooo`0?ooooo`0300000?oooooo
oooo04Wooooo0_ooO`07ooooo`;oogl06_ooool2oomo04;ooooo00<00000ooooooooool02?ooool0
00Wooooo00?o0000ooooooooool0D_ooool2oomo00Sooooo0P000?l@ooooo`;oogl05oooool00`00
0?ooooooooooo`0Xooooo`03o`000?oooooooooo00oooooo00<00000ooooooooool0D_ooool2oomo
01[ooooo0_ooO`12ooooo`0300000?oooooooooo00Sooooo0009ooooo`03o`000?oooooooooo05ko
oooo00<0003oooooooooool02?ooool2oomo01cooooo00<0003oooooooooool0:?ooool00ol0003o
ooooooooo`0?ooooo`0300000?oooooooooo06Wooooo0_ooO`17ooooo`0300000?oooooooooo00So
oooo0009ooooo`03o`000?oooooooooo05oooooo00<0003oooooooooool01oooool2oomo01cooooo
00<0003oooooooooool0:?ooool00ol0003oooooooooo`0?ooooo`0300000?oooooooooo06Wooooo
0_ooO`17ooooo`0300000?oooooooooo00Sooooo0009ooooo`03o`000?oooooooooo063ooooo00<0
003oooooooooool09?ooool00`000?ooooooooooo`0Xooooo`03o`000?oooooooooo00oooooo00<0
0000ooooooooool0/_ooool00`00003oooooooooo`08ooooo`002Oooool00ol0003oooooooooo`1Q
ooooo`<0003o8oooool00ol00?ooooooooooo`0Xooooo`03o`000?oooooooooo00oooooo00<00000
ooooooooool0/_ooool00`00003oooooooooo`08ooooo`002Oooool00ol0003oooooooooo`1Toooo
o`80003o8?ooool00`000?ooooooooooo`0Yooooo`03o`000?oooooooooo00oooooo00<00000oooo
ooooool0/_ooool00`00003oooooooooo`08ooooo`002Oooool00ol0003oooooooooo`1Booooo`;o
ogl04_ooool20000oagooooo00<0003oooooooooool0:_ooool00ol0003oooooooooo`0?ooooo`03
00000?oooooooooo05;ooooo0_ooO`1Nooooo`0300000?oooooooooo00Sooooo0009ooooo`03o`00
0?oooooooooo05;ooooo0_ooO`0Dooooo`80003o6_ooool00`000?ooooooooooo`0[ooooo`03o`00
0?oooooooooo00oooooo00<00000ooooooooool0D_ooool2oomo05kooooo00<00000ooooooooool0
2?ooool000Wooooo00?o0000ooooooooool0J_ooool20000o`?ooooo0_ooO`0Booooo`030000oooo
oooooooo02cooooo00?o0000ooooooooool03oooool00`00003oooooooooo`1_ooooo`;oogl0@Ooo
ool00`00003oooooooooo`08ooooo`002Oooool00ol0003oooooooooo`1/ooooo`<0003o0_ooO`0A
ooooo`03o`00oooooooooooo02gooooo00?o0000ooooooooool03oooool00`00003oooooooooo`1_
ooooo`;oogl0@Oooool00`00003oooooooooo`08ooooo`002Oooool00ol0003oooooooooo`1_oooo
o`@0003o3?ooool30000oc3ooooo00?o0000ooooooooool03oooool00`00003oooooooooo`2boooo
o`0300000?oooooooooo00Sooooo0009ooooo`03o`000?oooooooooo07?ooooo30000?lcooooo`03
o`000?oooooooooo00oooooo00<00000ooooooooool0/_ooool00`00003oooooooooo`08ooooo`00
2Oooool00ol0003oooooooooo`1=ooooo`;oogl0Hoooool00ol0003oooooooooo`0?ooooo`030000
0?oooooooooo04gooooo0_ooO`1Sooooo`0300000?oooooooooo00Sooooo0009ooooo`03o`000?oo
oooooooo04gooooo0_ooO`0Dooooo`;oogl0COooool00ol0003oooooooooo`0?ooooo`0300000?oo
oooooooo04gooooo0_ooO`0Dooooo`;oogl0COooool00`00003oooooooooo`08ooooo`002Oooool0
0ol0003oooooooooo`1Sooooo`;oogl0COooool00ol0003oooooooooo`0?ooooo`0300000?oooooo
oooo06?ooooo0_ooO`1=ooooo`0300000?oooooooooo00Sooooo0009ooooo`03o`000?oooooooooo
05Wooooo0_ooO`1Gooooo`03o`000?oooooooooo00oooooo00<00000ooooooooool0FOooool2oomo
05Oooooo00<00000ooooooooool02?ooool000Wooooo00?o0000ooooooooool0FOooool2oomo05Oo
oooo00?o0000ooooooooool03oooool00`00003oooooooooo`1Iooooo`;oogl0Eoooool00`00003o
ooooooooo`08ooooo`002Oooool00ol0003oooooooooo`1aooooo`;oogl0?oooool00ol0003ooooo
ooooo`0?ooooo`0300000?oooooooooo077ooooo0_ooO`0oooooo`0300000?oooooooooo00Sooooo
0009ooooo`03o`000?oooooooooo077ooooo0_ooO`0oooooo`03o`000?oooooooooo00oooooo00<0
0000ooooooooool0LOooool2oomo03oooooo00<00000ooooooooool02?ooool000Wooooo00?o0000
ooooooooool0/_ooool00ol0003oooooooooo`0?ooooo`0300000?oooooooooo0;;ooooo00<00000
ooooooooool02?ooool000Wooooo00?o0000ooooooooool0/_ooool00ol0003oooooooooo`0?oooo
o`0300000?oooooooooo0;;ooooo00<00000ooooooooool02?ooool000Wooooo00?o0000oooooooo
ool0/_ooool00ol0003oooooooooo`0?ooooo`0300000?oooooooooo0;;ooooo00<00000oooooooo
ool02?ooool000Wooooo00?o0000ooooooooool0/_ooool00ol0003oooooooooo`0?ooooo`030000
0?oooooooooo0;;ooooo00<00000ooooooooool02?ooool000Wooooo00?o0000ooooooooool0/_oo
ool00ol0003oooooooooo`0?ooooo`0300000?oooooooooo0;;ooooo00<00000ooooooooool02?oo
ool000Wooooo00?o0000ooooooooool0/_ooool00ol0003oooooooooo`0?ooooo`0300000?oooooo
oooo0;;ooooo00<00000ooooooooool02?ooool000Wooooo00?o0000ooooooooool0/_ooool00ol0
003oooooooooo`0?ooooo`0300000?oooooooooo0;;ooooo00<00000ooooooooool02?ooool000Wo
oooo00?o0000ooooooooool0/_ooool00ol0003oooooooooo`0?ooooo`0300000?oooooooooo0;;o
oooo00<00000ooooooooool02?ooool000Wooooo00?o0000ooooooooool0/_ooool00ol0003ooooo
ooooo`0?ooooo`0300000?oooooooooo0;;ooooo00<00000ooooooooool02?ooool000Wooooo00?o
0000ooooooooool0/_ooool00ol0003oooooooooo`0?ooooo`0300000?oooooooooo0;;ooooo00<0
0000ooooooooool02?ooool000Wooooo00?o0000ooooooooool0/_ooool00ol0003oooooooooo`0?
ooooo`0300000?oooooooooo0;;ooooo00<00000ooooooooool02?ooool000Wooooo00?o0000oooo
ooooool0/_ooool00ol0003oooooooooo`0?ooooo`0300000?oooooooooo0;;ooooo00<00000oooo
ooooool02?ooool000Wooooo00?o0000ooooooooool0/_ooool00ol0003oooooooooo`0?ooooo`03
00000?oooooooooo0;;ooooo00<00000ooooooooool02?ooool000Wooooo00?o0000ooooooooool0
/_ooool00ol0003oooooooooo`0?ooooo`0300000?oooooooooo0;;ooooo00<00000ooooooooool0
2?ooool000Wooooo00?o0000ooooooooool0/_ooool00ol0003oooooooooo`0?ooooo`0300000?oo
oooooooo0;;ooooo00<00000ooooooooool02?ooool000Wooooo00?o0000ooooooooool0/_ooool0
0ol0003oooooooooo`0?ooooo`0300000?oooooooooo0;;ooooo00<00000ooooooooool02?ooool0
00Wooooo00?o0000ooooooooool0/_ooool00ol0003oooooooooo`0?ooooo`0300000?oooooooooo
0;;ooooo00<00000ooooooooool02?ooool000Wooooo00?o0000ooooooooool0/_ooool00ol0003o
ooooooooo`0?ooooo`0300000?oooooooooo0;;ooooo00<00000ooooooooool02?ooool000Wooooo
00?o0000ooooooooool0/_ooool00ol0003oooooooooo`0?ooooo`0300000?oooooooooo0;;ooooo
00<00000ooooooooool02?ooool000Wooooo00?o0000ooooooooool0/_ooool00ol0003ooooooooo
o`0?ooooo`0300000?oooooooooo0;;ooooo00<00000ooooooooool02?ooool000Wooooo00?o0000
ooooooooool0/_ooool00ol0003oooooooooo`0?ooooo`0300000?oooooooooo0;;ooooo00<00000
ooooooooool02?ooool000Wooooo00?o0000ooooooooool0/_ooool00ol0003oooooooooo`0?oooo
o`0300000?oooooooooo0;;ooooo00<00000ooooooooool02?ooool000Wooooo00?o0000oooooooo
ool0/_ooool00ol0003oooooooooo`0?ooooo`0300000?oooooooooo0;;ooooo00<00000oooooooo
ool02?ooool000Wooooo00?o0000ooooooooool0/_ooool00ol0003oooooooooo`0?ooooo`030000
0?oooooooooo0;;ooooo00<00000ooooooooool02?ooool000Wooooo00?o0000ooooooooool0F?oo
ool2oomo05Sooooo00?o0000ooooooooool03oooool00`00003oooooooooo`1Hooooo`;oogl0F?oo
ool00`00003oooooooooo`08ooooo`002Oooool00ol0003oooooooooo`1Hooooo`;oogl0F?ooool0
0ol0003oooooooooo`0?ooooo`0300000?oooooooooo05Sooooo0_ooO`1Hooooo`0300000?oooooo
oooo00Sooooo0009ooooo`03o`000?oooooooooo0;;ooooo00?o0000ooooooooool03oooool00`00
003oooooooooo`2booooo`0300000?oooooooooo00Sooooo0009ooooo`03o`000?oooooooooo0;;o
oooo00?o0000ooooooooool03oooool00`00003oooooooooo`2booooo`0300000?oooooooooo00So
oooo0009ooooo`03o`000?oooooooooo0;;ooooo00?o0000ooooooooool03oooool00`00003ooooo
ooooo`2booooo`0300000?oooooooooo00Sooooo0009ooooo`03o`000?oooooooooo0;;ooooo00?o
0000ooooooooool03oooool00`00003oooooooooo`2booooo`0300000?oooooooooo00Sooooo0009
ooooo`03o`000?oooooooooo0;;ooooo00?o0000ooooooooool03oooool00`00003oooooooooo`2b
ooooo`0300000?oooooooooo00Sooooo0009ooooo`03o`000?oooooooooo0;;ooooo00?o0000oooo
ooooool03oooool00`00003oooooooooo`2booooo`0300000?oooooooooo00Sooooo0009ooooo`03
o`000?oooooooooo0;;ooooo00?o0000ooooooooool03oooool00`00003oooooooooo`2booooo`03
00000?oooooooooo00Sooooo0009ooooo`03o`000?oooooooooo0;;ooooo00?o0000ooooooooool0
3oooool00`00003oooooooooo`2booooo`0300000?oooooooooo00Sooooo0009ooooo`03o`000?oo
oooooooo0;;ooooo00?o0000ooooooooool03oooool00`00003oooooooooo`2booooo`0300000?oo
oooooooo00Sooooo0009ooooo`03o`000?oooooooooo0;;ooooo00?o0000ooooooooool03oooool0
0`00003oooooooooo`2booooo`0300000?oooooooooo00Sooooo0009ooooo`03o`000?oooooooooo
0;;ooooo00?o0000ooooooooool03oooool00`00003oooooooooo`2booooo`0300000?oooooooooo
00Sooooo0009ooooo`03o`000?oooooooooo0;;ooooo00?o0000ooooooooool03oooool00`00003o
ooooooooo`2booooo`0300000?oooooooooo00Sooooo0009ooooo`03o`000?oooooooooo0;;ooooo
00?o0000ooooooooool03oooool00`00003oooooooooo`2booooo`0300000?oooooooooo00Sooooo
0009oooookKo00004Ooooonf000000[ooooo003ooooooi7ooooo003ooooooi7ooooo003ooooooi7o
oooo003ooooooi7ooooo003ooooooi7ooooo003ooooooi7ooooo003ooooooi7ooooo003ooooooi7o
oooo003ooooooi7ooooo0000\
\>"],
  ImageRangeCache->{{{0, 399}, {399, 0}} -> {-0.0500105, -0.0500105, \
0.00526322, 0.00526322}, {{9.5, 190.438}, {389.5, 208.5}} -> {-1.15081, \
-1.15117, 0.0115117, 0.0115117}, {{208.5, 389.438}, {389.5, 208.5}} -> \
{-1.09771, -0.0754011, 0.0052648, 0.0052648}, {{9.5, 190.438}, {190.438, \
9.5}} -> {-1.11761, -3.34306, 0.0111796, 0.0111796}, {{208.5, 389.438}, \
{190.438, 9.5}} -> {-3.34236, -3.34306, 0.0111796, 0.0111796}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
%%ImageSize: 400 400 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.47619 0.0238095 0.47619 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.0238095 0.477324 0.477324 MathSubStart
%% ContourGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.480769 0.5 0.480769 [
[ 0 0 -0.125 0 ]
[ 0 0 -0.125 0 ]
[ 0 1 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
0 0 m
1 0 L
s
0 0 m
0 1 L
s
0 1 m
1 1 L
s
1 0 m
1 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
.01923 .98077 m
.98077 .98077 L
.98077 .01923 L
.01923 .01923 L
F
.5 Mabswid
.1 g
.01923 .17338 m
.03523 .19231 L
.03846 .19552 L
.05346 .21154 L
.05769 .21611 L
.07216 .23077 L
.07692 .23551 L
.09184 .25 L
.09615 .25398 L
.11241 .26923 L
.11538 .27174 L
.13375 .28846 L
.13462 .28911 L
.15385 .30561 L
.15622 .30769 L
.17308 .32118 L
.1797 .32692 L
.19231 .33632 L
.20363 .34615 L
.21154 .35139 L
.22748 .36538 L
.23077 .36705 L
.25 .38395 L
.25071 .38462 L
.26923 .40015 L
.27256 .40385 L
.28846 .42039 L
.29074 .42308 L
.30314 .44231 L
.30769 .45759 L
.30807 .46154 L
.30769 .47706 L
.3072 .48077 L
.30432 .5 L
.30208 .51923 L
.30134 .53846 L
.30223 .55769 L
.30472 .57692 L
.30769 .59207 L
.30877 .59615 L
.31441 .61538 L
.32156 .63462 L
.32692 .64694 L
.33026 .65385 L
.34061 .67308 L
.34615 .68236 L
.35262 .69231 L
.36538 .7102 L
.36641 .71154 L
.3822 .73077 L
.38462 .7335 L
.40019 .75 L
.40385 .75362 L
.42069 .76923 L
.42308 .7713 L
.44231 .78699 L
.44423 .78846 L
.46154 .80094 L
.47161 .80769 L
.48077 .81343 L
.5 .82462 L
.50423 .82692 L
.51923 .83452 L
.53846 .84335 L
.5451 .84615 L
.55769 .85103 L
.57692 .8577 L
.59615 .86341 L
.60366 .86538 L
.61538 .86807 L
.63462 .87173 L
.65385 .87442 L
.67308 .87611 L
.69231 .87674 L
.71154 .87629 L
.73077 .87468 L
.75 .87183 L
.76923 .86765 L
.77758 .86538 L
.78846 .86192 L
.80769 .85443 L
.82467 .84615 L
.82692 .84491 L
.84615 .8328 L
.85406 .82692 L
.86538 .81734 L
.8752 .80769 L
.88462 .79697 L
.8911 .78846 L
.90318 .76923 L
.90385 .768 L
.91219 .75 L
.9187 .73077 L
.92302 .71154 L
.92308 .71119 L
.92534 .69231 L
.92587 .67308 L
.92473 .65385 L
.92308 .63891 L
.92197 .63462 L
.91762 .61538 L
.91175 .59615 L
.90437 .57692 L
.90385 .57569 L
.89536 .55769 L
.88479 .53846 L
.88462 .53816 L
.87245 .51923 L
.86538 .50925 L
.85833 .5 L
.84615 .48524 L
.84221 .48077 L
.82692 .4646 L
.82384 .46154 L
.80769 .44652 L
.80286 .44231 L
.78846 .43051 L
.77875 .42308 L
.76923 .41624 L
.75063 .40385 L
.75 .40345 L
.73077 .39209 L
.71691 .38462 L
.71154 .38192 L
.69231 .37294 L
.67416 .36538 L
.67308 .36497 L
.65385 .35813 L
.63462 .3522 L
.61538 .34714 L
.61121 .34615 L
.59615 .34291 L
.57692 .33916 L
.55769 .33536 L
.53846 .33072 L
.52598 .32692 L
.51923 .32445 L
.5 .31605 L
.48452 .30769 L
.48077 .30517 L
.46154 .29234 L
.45592 .28846 L
.44231 .27839 L
.43039 .26923 L
.42308 .26344 L
.40667 .25 L
.40385 .24777 L
.38462 .23176 L
.38341 .23077 L
.36538 .21667 L
.35914 .21154 L
.34615 .20188 L
.33443 .19231 L
.32692 .18722 L
.30932 .17308 L
.30769 .17215 L
.28846 .1582 L
.28276 .15385 L
.26923 .14531 L
.25486 .13462 L
.25 .1321 L
.23077 .119 L
.22556 .11538 L
.21154 .10767 L
.19414 .09615 L
.19231 .09539 L
.17308 .08481 L
.15994 .07692 L
.15385 .07436 L
.13462 .0644 L
.1218 .05769 L
.11538 .05525 L
.09615 .04687 L
.07692 .03882 L
.07604 .03846 L
.05769 .03208 L
.03846 .02685 L
.01923 .02337 L
F
0 g
.01923 .17338 m
.03523 .19231 L
.03846 .19552 L
.05346 .21154 L
.05769 .21611 L
.07216 .23077 L
.07692 .23551 L
.09184 .25 L
.09615 .25398 L
.11241 .26923 L
.11538 .27174 L
.13375 .28846 L
.13462 .28911 L
.15385 .30561 L
.15622 .30769 L
.17308 .32118 L
.1797 .32692 L
.19231 .33632 L
.20363 .34615 L
.21154 .35139 L
.22748 .36538 L
.23077 .36705 L
.25 .38395 L
.25071 .38462 L
.26923 .40015 L
.27256 .40385 L
.28846 .42039 L
.29074 .42308 L
.30314 .44231 L
.30769 .45759 L
.30807 .46154 L
.30769 .47706 L
.3072 .48077 L
.30432 .5 L
.30208 .51923 L
.30134 .53846 L
.30223 .55769 L
.30472 .57692 L
.30769 .59207 L
.30877 .59615 L
.31441 .61538 L
.32156 .63462 L
.32692 .64694 L
.33026 .65385 L
.34061 .67308 L
.34615 .68236 L
.35262 .69231 L
.36538 .7102 L
.36641 .71154 L
.3822 .73077 L
Mistroke
.38462 .7335 L
.40019 .75 L
.40385 .75362 L
.42069 .76923 L
.42308 .7713 L
.44231 .78699 L
.44423 .78846 L
.46154 .80094 L
.47161 .80769 L
.48077 .81343 L
.5 .82462 L
.50423 .82692 L
.51923 .83452 L
.53846 .84335 L
.5451 .84615 L
.55769 .85103 L
.57692 .8577 L
.59615 .86341 L
.60366 .86538 L
.61538 .86807 L
.63462 .87173 L
.65385 .87442 L
.67308 .87611 L
.69231 .87674 L
.71154 .87629 L
.73077 .87468 L
.75 .87183 L
.76923 .86765 L
.77758 .86538 L
.78846 .86192 L
.80769 .85443 L
.82467 .84615 L
.82692 .84491 L
.84615 .8328 L
.85406 .82692 L
.86538 .81734 L
.8752 .80769 L
.88462 .79697 L
.8911 .78846 L
.90318 .76923 L
.90385 .768 L
.91219 .75 L
.9187 .73077 L
.92302 .71154 L
.92308 .71119 L
.92534 .69231 L
.92587 .67308 L
.92473 .65385 L
.92308 .63891 L
.92197 .63462 L
Mistroke
.91762 .61538 L
.91175 .59615 L
.90437 .57692 L
.90385 .57569 L
.89536 .55769 L
.88479 .53846 L
.88462 .53816 L
.87245 .51923 L
.86538 .50925 L
.85833 .5 L
.84615 .48524 L
.84221 .48077 L
.82692 .4646 L
.82384 .46154 L
.80769 .44652 L
.80286 .44231 L
.78846 .43051 L
.77875 .42308 L
.76923 .41624 L
.75063 .40385 L
.75 .40345 L
.73077 .39209 L
.71691 .38462 L
.71154 .38192 L
.69231 .37294 L
.67416 .36538 L
.67308 .36497 L
.65385 .35813 L
.63462 .3522 L
.61538 .34714 L
.61121 .34615 L
.59615 .34291 L
.57692 .33916 L
.55769 .33536 L
.53846 .33072 L
.52598 .32692 L
.51923 .32445 L
.5 .31605 L
.48452 .30769 L
.48077 .30517 L
.46154 .29234 L
.45592 .28846 L
.44231 .27839 L
.43039 .26923 L
.42308 .26344 L
.40667 .25 L
.40385 .24777 L
.38462 .23176 L
.38341 .23077 L
.36538 .21667 L
Mistroke
.35914 .21154 L
.34615 .20188 L
.33443 .19231 L
.32692 .18722 L
.30932 .17308 L
.30769 .17215 L
.28846 .1582 L
.28276 .15385 L
.26923 .14531 L
.25486 .13462 L
.25 .1321 L
.23077 .119 L
.22556 .11538 L
.21154 .10767 L
.19414 .09615 L
.19231 .09539 L
.17308 .08481 L
.15994 .07692 L
.15385 .07436 L
.13462 .0644 L
.1218 .05769 L
.11538 .05525 L
.09615 .04687 L
.07692 .03882 L
.07604 .03846 L
.05769 .03208 L
.03846 .02685 L
.01923 .02337 L
Mfstroke
.2 g
.01923 .12978 m
.02387 .13462 L
.03537 .15385 L
.03846 .15846 L
.04924 .17308 L
.05769 .18416 L
.06456 .19231 L
.07692 .20672 L
.08136 .21154 L
.09615 .22733 L
.09955 .23077 L
.11538 .2465 L
.11904 .25 L
.13462 .26451 L
.13977 .26923 L
.15385 .28156 L
.16171 .28846 L
.17308 .2978 L
.18476 .30769 L
.19231 .31345 L
.20877 .32692 L
.21154 .32883 L
.23077 .34374 L
.23383 .34615 L
.25 .3577 L
.25984 .36538 L
.26923 .37155 L
.28601 .38462 L
.28846 .386 L
.30769 .40051 L
.3117 .40385 L
.32692 .41501 L
.33543 .42308 L
.34615 .43121 L
.35509 .44231 L
.36538 .45602 L
.36857 .46154 L
.3749 .48077 L
.37527 .5 L
.37297 .51923 L
.37095 .53846 L
.37057 .55769 L
.37217 .57692 L
.37577 .59615 L
.38135 .61538 L
.38462 .62447 L
.3889 .63462 L
.3985 .65385 L
.40385 .66311 L
.41022 .67308 L
.42308 .69082 L
.42426 .69231 L
.4409 .71154 L
.44231 .71303 L
.46058 .73077 L
.46154 .73163 L
.48077 .74752 L
.48405 .75 L
.5 .76122 L
.51264 .76923 L
.51923 .7731 L
.53846 .78334 L
.54927 .78846 L
.55769 .7921 L
.57692 .79948 L
.59615 .80557 L
.6039 .80769 L
.61538 .81035 L
.63462 .81386 L
.65385 .8161 L
.67308 .81701 L
.69231 .81653 L
.71154 .81454 L
.73077 .8109 L
.74292 .80769 L
.75 .80537 L
.76923 .79757 L
.78606 .78846 L
.78846 .78695 L
.80769 .77246 L
.81123 .76923 L
.82692 .75189 L
.82834 .75 L
.84033 .73077 L
.84615 .71814 L
.84854 .71154 L
.85369 .69231 L
.85625 .67308 L
.8565 .65385 L
.85461 .63462 L
.85069 .61538 L
.84615 .59985 L
.8448 .59615 L
.83689 .57692 L
.82697 .55769 L
.82692 .55761 L
.81486 .53846 L
.80769 .52849 L
.80041 .51923 L
.78846 .50545 L
.78331 .5 L
.76923 .48628 L
.76307 .48077 L
.75 .46994 L
.7389 .46154 L
.73077 .45584 L
.71154 .4436 L
.70933 .44231 L
.69231 .43303 L
.67308 .42386 L
.67128 .42308 L
.65385 .41602 L
.63462 .40923 L
.61736 .40385 L
.61538 .40327 L
.59615 .39779 L
.57692 .39217 L
.55769 .3857 L
.55477 .38462 L
.53846 .3778 L
.51923 .36774 L
.51512 .36538 L
.5 .35551 L
.48696 .34615 L
.48077 .34115 L
.46349 .32692 L
.46154 .32516 L
.44231 .30821 L
.44172 .30769 L
.42308 .29099 L
.42022 .28846 L
.40385 .27383 L
.39863 .26923 L
.38462 .257 L
.37656 .25 L
.36538 .24063 L
.35377 .23077 L
.34615 .22473 L
.33015 .21154 L
.32692 .20917 L
.30769 .1941 L
.30539 .19231 L
.28846 .18016 L
.27899 .17308 L
.26923 .16669 L
.25121 .15385 L
.25 .15316 L
.23077 .14092 L
.22116 .13462 L
.21154 .12926 L
.19231 .11762 L
.18851 .11538 L
.17308 .10748 L
.15385 .09727 L
.15165 .09615 L
.13462 .08865 L
.11538 .0804 L
.10673 .07692 L
.09615 .07361 L
.07692 .06816 L
.05769 .06459 L
.03846 .06408 L
.01923 .06995 L
F
0 g
.01923 .12978 m
.02387 .13462 L
.03537 .15385 L
.03846 .15846 L
.04924 .17308 L
.05769 .18416 L
.06456 .19231 L
.07692 .20672 L
.08136 .21154 L
.09615 .22733 L
.09955 .23077 L
.11538 .2465 L
.11904 .25 L
.13462 .26451 L
.13977 .26923 L
.15385 .28156 L
.16171 .28846 L
.17308 .2978 L
.18476 .30769 L
.19231 .31345 L
.20877 .32692 L
.21154 .32883 L
.23077 .34374 L
.23383 .34615 L
.25 .3577 L
.25984 .36538 L
.26923 .37155 L
.28601 .38462 L
.28846 .386 L
.30769 .40051 L
.3117 .40385 L
.32692 .41501 L
.33543 .42308 L
.34615 .43121 L
.35509 .44231 L
.36538 .45602 L
.36857 .46154 L
.3749 .48077 L
.37527 .5 L
.37297 .51923 L
.37095 .53846 L
.37057 .55769 L
.37217 .57692 L
.37577 .59615 L
.38135 .61538 L
.38462 .62447 L
.3889 .63462 L
.3985 .65385 L
.40385 .66311 L
.41022 .67308 L
Mistroke
.42308 .69082 L
.42426 .69231 L
.4409 .71154 L
.44231 .71303 L
.46058 .73077 L
.46154 .73163 L
.48077 .74752 L
.48405 .75 L
.5 .76122 L
.51264 .76923 L
.51923 .7731 L
.53846 .78334 L
.54927 .78846 L
.55769 .7921 L
.57692 .79948 L
.59615 .80557 L
.6039 .80769 L
.61538 .81035 L
.63462 .81386 L
.65385 .8161 L
.67308 .81701 L
.69231 .81653 L
.71154 .81454 L
.73077 .8109 L
.74292 .80769 L
.75 .80537 L
.76923 .79757 L
.78606 .78846 L
.78846 .78695 L
.80769 .77246 L
.81123 .76923 L
.82692 .75189 L
.82834 .75 L
.84033 .73077 L
.84615 .71814 L
.84854 .71154 L
.85369 .69231 L
.85625 .67308 L
.8565 .65385 L
.85461 .63462 L
.85069 .61538 L
.84615 .59985 L
.8448 .59615 L
.83689 .57692 L
.82697 .55769 L
.82692 .55761 L
.81486 .53846 L
.80769 .52849 L
.80041 .51923 L
.78846 .50545 L
Mistroke
.78331 .5 L
.76923 .48628 L
.76307 .48077 L
.75 .46994 L
.7389 .46154 L
.73077 .45584 L
.71154 .4436 L
.70933 .44231 L
.69231 .43303 L
.67308 .42386 L
.67128 .42308 L
.65385 .41602 L
.63462 .40923 L
.61736 .40385 L
.61538 .40327 L
.59615 .39779 L
.57692 .39217 L
.55769 .3857 L
.55477 .38462 L
.53846 .3778 L
.51923 .36774 L
.51512 .36538 L
.5 .35551 L
.48696 .34615 L
.48077 .34115 L
.46349 .32692 L
.46154 .32516 L
.44231 .30821 L
.44172 .30769 L
.42308 .29099 L
.42022 .28846 L
.40385 .27383 L
.39863 .26923 L
.38462 .257 L
.37656 .25 L
.36538 .24063 L
.35377 .23077 L
.34615 .22473 L
.33015 .21154 L
.32692 .20917 L
.30769 .1941 L
.30539 .19231 L
.28846 .18016 L
.27899 .17308 L
.26923 .16669 L
.25121 .15385 L
.25 .15316 L
.23077 .14092 L
.22116 .13462 L
.21154 .12926 L
Mistroke
.19231 .11762 L
.18851 .11538 L
.17308 .10748 L
.15385 .09727 L
.15165 .09615 L
.13462 .08865 L
.11538 .0804 L
.10673 .07692 L
.09615 .07361 L
.07692 .06816 L
.05769 .06459 L
.03846 .06408 L
.01923 .06995 L
Mfstroke
.3 g
.05769 .0929 m
.07692 .09032 L
.09615 .09283 L
.10977 .09615 L
.11538 .09782 L
.13462 .1047 L
.15385 .11278 L
.15991 .11538 L
.17308 .12196 L
.19231 .13204 L
.19731 .13462 L
.21154 .14302 L
.22988 .15385 L
.23077 .15442 L
.25 .16714 L
.25929 .17308 L
.26923 .18012 L
.28661 .19231 L
.28846 .19369 L
.30769 .20836 L
.31198 .21154 L
.32692 .22359 L
.3359 .23077 L
.34615 .23942 L
.35859 .25 L
.36538 .25597 L
.38016 .26923 L
.38462 .27329 L
.40077 .28846 L
.40385 .29137 L
.42059 .30769 L
.42308 .31009 L
.43992 .32692 L
.44231 .32925 L
.45918 .34615 L
.46154 .3484 L
.47916 .36538 L
.48077 .36682 L
.5 .38355 L
.50129 .38462 L
.51923 .39776 L
.52873 .40385 L
.53846 .40932 L
.55769 .41864 L
.56845 .42308 L
.57692 .42633 L
.59615 .43315 L
.61538 .43973 L
.62271 .44231 L
.63462 .44669 L
.65385 .45451 L
.66906 .46154 L
.67308 .46355 L
.69231 .47416 L
.70286 .48077 L
.71154 .48668 L
.72892 .5 L
.73077 .50155 L
.7498 .51923 L
.75 .51944 L
.76677 .53846 L
.76923 .5416 L
.78053 .55769 L
.78846 .57104 L
.79151 .57692 L
.79991 .59615 L
.80585 .61538 L
.80769 .62389 L
.80933 .63462 L
.81026 .65385 L
.80844 .67308 L
.80769 .67825 L
.80347 .69231 L
.79469 .71154 L
.78846 .72131 L
.78084 .73077 L
.76923 .74217 L
.75907 .75 L
.75 .75575 L
.73077 .76504 L
.71898 .76923 L
.71154 .77126 L
.69231 .77506 L
.67308 .77681 L
.65385 .77674 L
.63462 .775 L
.61538 .77166 L
.60481 .76923 L
.59615 .76675 L
.57692 .76024 L
.55769 .75208 L
.55333 .75 L
.53846 .74213 L
.52008 .73077 L
.51923 .73019 L
.5 .7159 L
.49476 .71154 L
.48077 .6987 L
.47451 .69231 L
.46154 .67749 L
.45807 .67308 L
.44477 .65385 L
.44231 .64981 L
.43423 .63462 L
.42623 .61538 L
.42308 .60628 L
.42067 .59615 L
.41753 .57692 L
.41676 .55769 L
.41808 .53846 L
.42042 .51923 L
.42137 .5 L
.41779 .48077 L
.40735 .46154 L
.40385 .45626 L
.38951 .44231 L
.38462 .4376 L
.3656 .42308 L
.36538 .42291 L
.34615 .40875 L
.33814 .40385 L
.32692 .3959 L
.30945 .38462 L
.30769 .38338 L
.28846 .37003 L
.2811 .36538 L
.26923 .35686 L
.25361 .34615 L
.25 .34348 L
.23077 .32923 L
.22747 .32692 L
.21154 .31443 L
.20269 .30769 L
.19231 .29918 L
.1792 .28846 L
.17308 .2832 L
.15707 .26923 L
.15385 .26631 L
.13634 .25 L
.13462 .24834 L
.11706 .23077 L
.11538 .22906 L
.09929 .21154 L
.09615 .20807 L
.08315 .19231 L
.07692 .18462 L
.06887 .17308 L
.05769 .15569 L
.05678 .15385 L
.04784 .13462 L
.04372 .11538 L
.05119 .09615 L
F
0 g
.05769 .0929 m
.07692 .09032 L
.09615 .09283 L
.10977 .09615 L
.11538 .09782 L
.13462 .1047 L
.15385 .11278 L
.15991 .11538 L
.17308 .12196 L
.19231 .13204 L
.19731 .13462 L
.21154 .14302 L
.22988 .15385 L
.23077 .15442 L
.25 .16714 L
.25929 .17308 L
.26923 .18012 L
.28661 .19231 L
.28846 .19369 L
.30769 .20836 L
.31198 .21154 L
.32692 .22359 L
.3359 .23077 L
.34615 .23942 L
.35859 .25 L
.36538 .25597 L
.38016 .26923 L
.38462 .27329 L
.40077 .28846 L
.40385 .29137 L
.42059 .30769 L
.42308 .31009 L
.43992 .32692 L
.44231 .32925 L
.45918 .34615 L
.46154 .3484 L
.47916 .36538 L
.48077 .36682 L
.5 .38355 L
.50129 .38462 L
.51923 .39776 L
.52873 .40385 L
.53846 .40932 L
.55769 .41864 L
.56845 .42308 L
.57692 .42633 L
.59615 .43315 L
.61538 .43973 L
.62271 .44231 L
.63462 .44669 L
Mistroke
.65385 .45451 L
.66906 .46154 L
.67308 .46355 L
.69231 .47416 L
.70286 .48077 L
.71154 .48668 L
.72892 .5 L
.73077 .50155 L
.7498 .51923 L
.75 .51944 L
.76677 .53846 L
.76923 .5416 L
.78053 .55769 L
.78846 .57104 L
.79151 .57692 L
.79991 .59615 L
.80585 .61538 L
.80769 .62389 L
.80933 .63462 L
.81026 .65385 L
.80844 .67308 L
.80769 .67825 L
.80347 .69231 L
.79469 .71154 L
.78846 .72131 L
.78084 .73077 L
.76923 .74217 L
.75907 .75 L
.75 .75575 L
.73077 .76504 L
.71898 .76923 L
.71154 .77126 L
.69231 .77506 L
.67308 .77681 L
.65385 .77674 L
.63462 .775 L
.61538 .77166 L
.60481 .76923 L
.59615 .76675 L
.57692 .76024 L
.55769 .75208 L
.55333 .75 L
.53846 .74213 L
.52008 .73077 L
.51923 .73019 L
.5 .7159 L
.49476 .71154 L
.48077 .6987 L
.47451 .69231 L
.46154 .67749 L
Mistroke
.45807 .67308 L
.44477 .65385 L
.44231 .64981 L
.43423 .63462 L
.42623 .61538 L
.42308 .60628 L
.42067 .59615 L
.41753 .57692 L
.41676 .55769 L
.41808 .53846 L
.42042 .51923 L
.42137 .5 L
.41779 .48077 L
.40735 .46154 L
.40385 .45626 L
.38951 .44231 L
.38462 .4376 L
.3656 .42308 L
.36538 .42291 L
.34615 .40875 L
.33814 .40385 L
.32692 .3959 L
.30945 .38462 L
.30769 .38338 L
.28846 .37003 L
.2811 .36538 L
.26923 .35686 L
.25361 .34615 L
.25 .34348 L
.23077 .32923 L
.22747 .32692 L
.21154 .31443 L
.20269 .30769 L
.19231 .29918 L
.1792 .28846 L
.17308 .2832 L
.15707 .26923 L
.15385 .26631 L
.13634 .25 L
.13462 .24834 L
.11706 .23077 L
.11538 .22906 L
.09929 .21154 L
.09615 .20807 L
.08315 .19231 L
.07692 .18462 L
.06887 .17308 L
.05769 .15569 L
.05678 .15385 L
.04784 .13462 L
Mistroke
.04372 .11538 L
.05119 .09615 L
.05769 .0929 L
Mfstroke
.4 g
.09615 .11104 m
.11538 .11321 L
.12462 .11538 L
.13462 .11825 L
.15385 .12537 L
.17308 .13376 L
.17499 .13462 L
.19231 .14344 L
.2115 .15385 L
.21154 .15387 L
.23077 .16554 L
.24301 .17308 L
.25 .17773 L
.26923 .19081 L
.27145 .19231 L
.28846 .20482 L
.29757 .21154 L
.30769 .21946 L
.32191 .23077 L
.32692 .23491 L
.34469 .25 L
.34615 .25128 L
.36538 .26865 L
.36601 .26923 L
.38462 .28705 L
.38603 .28846 L
.40385 .30654 L
.40492 .30769 L
.42277 .32692 L
.42308 .32723 L
.4397 .34615 L
.44231 .3488 L
.45601 .36538 L
.46154 .37114 L
.47226 .38462 L
.48077 .39357 L
.48967 .40385 L
.5 .41342 L
.51117 .42308 L
.51923 .42872 L
.53846 .44005 L
.54301 .44231 L
.55769 .44886 L
.57692 .45641 L
.59092 .46154 L
.59615 .46344 L
.61538 .47058 L
.63462 .47837 L
.64008 .48077 L
.65385 .48729 L
.67308 .49782 L
.67666 .5 L
.69231 .51048 L
.70364 .51923 L
.71154 .52599 L
.72432 .53846 L
.73077 .54556 L
.74039 .55769 L
.75 .57212 L
.75272 .57692 L
.76176 .59615 L
.76772 .61538 L
.76923 .62302 L
.7706 .63462 L
.77021 .65385 L
.76923 .66052 L
.7661 .67308 L
.75734 .69231 L
.75 .70288 L
.7419 .71154 L
.73077 .72072 L
.71329 .73077 L
.71154 .73155 L
.69231 .73822 L
.67308 .74181 L
.65385 .74291 L
.63462 .74183 L
.61538 .73872 L
.59615 .73364 L
.5875 .73077 L
.57692 .72656 L
.55769 .71733 L
.54756 .71154 L
.53846 .70569 L
.52067 .69231 L
.51923 .6911 L
.50046 .67308 L
.5 .67258 L
.48489 .65385 L
.48077 .64788 L
.47304 .63462 L
.46444 .61538 L
.46154 .60818 L
.45888 .59615 L
.45625 .57692 L
.45635 .55769 L
.45853 .53846 L
.46111 .51923 L
.46154 .5 L
.45711 .48077 L
.44526 .46154 L
.44231 .45781 L
.42415 .44231 L
.42308 .44138 L
.40385 .42821 L
.39482 .42308 L
.38462 .41667 L
.36538 .40544 L
.36242 .40385 L
.34615 .39405 L
.32992 .38462 L
.32692 .38273 L
.30769 .37067 L
.29897 .36538 L
.28846 .35842 L
.26979 .34615 L
.26923 .34576 L
.25 .33213 L
.24253 .32692 L
.23077 .31809 L
.21695 .30769 L
.21154 .30341 L
.19301 .28846 L
.19231 .28788 L
.17308 .27127 L
.17077 .26923 L
.15385 .25361 L
.15009 .25 L
.13462 .23459 L
.131 .23077 L
.11538 .21365 L
.11361 .21154 L
.09817 .19231 L
.09615 .19031 L
.08511 .17308 L
.07692 .15788 L
.07513 .15385 L
.07006 .13462 L
.07692 .11689 L
.07903 .11538 L
F
0 g
.09615 .11104 m
.11538 .11321 L
.12462 .11538 L
.13462 .11825 L
.15385 .12537 L
.17308 .13376 L
.17499 .13462 L
.19231 .14344 L
.2115 .15385 L
.21154 .15387 L
.23077 .16554 L
.24301 .17308 L
.25 .17773 L
.26923 .19081 L
.27145 .19231 L
.28846 .20482 L
.29757 .21154 L
.30769 .21946 L
.32191 .23077 L
.32692 .23491 L
.34469 .25 L
.34615 .25128 L
.36538 .26865 L
.36601 .26923 L
.38462 .28705 L
.38603 .28846 L
.40385 .30654 L
.40492 .30769 L
.42277 .32692 L
.42308 .32723 L
.4397 .34615 L
.44231 .3488 L
.45601 .36538 L
.46154 .37114 L
.47226 .38462 L
.48077 .39357 L
.48967 .40385 L
.5 .41342 L
.51117 .42308 L
.51923 .42872 L
.53846 .44005 L
.54301 .44231 L
.55769 .44886 L
.57692 .45641 L
.59092 .46154 L
.59615 .46344 L
.61538 .47058 L
.63462 .47837 L
.64008 .48077 L
.65385 .48729 L
Mistroke
.67308 .49782 L
.67666 .5 L
.69231 .51048 L
.70364 .51923 L
.71154 .52599 L
.72432 .53846 L
.73077 .54556 L
.74039 .55769 L
.75 .57212 L
.75272 .57692 L
.76176 .59615 L
.76772 .61538 L
.76923 .62302 L
.7706 .63462 L
.77021 .65385 L
.76923 .66052 L
.7661 .67308 L
.75734 .69231 L
.75 .70288 L
.7419 .71154 L
.73077 .72072 L
.71329 .73077 L
.71154 .73155 L
.69231 .73822 L
.67308 .74181 L
.65385 .74291 L
.63462 .74183 L
.61538 .73872 L
.59615 .73364 L
.5875 .73077 L
.57692 .72656 L
.55769 .71733 L
.54756 .71154 L
.53846 .70569 L
.52067 .69231 L
.51923 .6911 L
.50046 .67308 L
.5 .67258 L
.48489 .65385 L
.48077 .64788 L
.47304 .63462 L
.46444 .61538 L
.46154 .60818 L
.45888 .59615 L
.45625 .57692 L
.45635 .55769 L
.45853 .53846 L
.46111 .51923 L
.46154 .5 L
.45711 .48077 L
Mistroke
.44526 .46154 L
.44231 .45781 L
.42415 .44231 L
.42308 .44138 L
.40385 .42821 L
.39482 .42308 L
.38462 .41667 L
.36538 .40544 L
.36242 .40385 L
.34615 .39405 L
.32992 .38462 L
.32692 .38273 L
.30769 .37067 L
.29897 .36538 L
.28846 .35842 L
.26979 .34615 L
.26923 .34576 L
.25 .33213 L
.24253 .32692 L
.23077 .31809 L
.21695 .30769 L
.21154 .30341 L
.19301 .28846 L
.19231 .28788 L
.17308 .27127 L
.17077 .26923 L
.15385 .25361 L
.15009 .25 L
.13462 .23459 L
.131 .23077 L
.11538 .21365 L
.11361 .21154 L
.09817 .19231 L
.09615 .19031 L
.08511 .17308 L
.07692 .15788 L
.07513 .15385 L
.07006 .13462 L
.07692 .11689 L
.07903 .11538 L
.09615 .11104 L
Mfstroke
.5 g
.11538 .12882 m
.13462 .13141 L
.14659 .13462 L
.15385 .13685 L
.17308 .14445 L
.19231 .15344 L
.19316 .15385 L
.21154 .16369 L
.2279 .17308 L
.23077 .17485 L
.25 .18715 L
.25788 .19231 L
.26923 .20023 L
.28494 .21154 L
.28846 .21419 L
.30769 .22917 L
.3097 .23077 L
.32692 .24514 L
.33256 .25 L
.34615 .26213 L
.35376 .26923 L
.36538 .28033 L
.37339 .28846 L
.38462 .29998 L
.3915 .30769 L
.40385 .32156 L
.40807 .32692 L
.42302 .34615 L
.42308 .34624 L
.43613 .36538 L
.44231 .37623 L
.44674 .38462 L
.4552 .40385 L
.44231 .41708 L
.42308 .41534 L
.40385 .40829 L
.39273 .40385 L
.38462 .40052 L
.36538 .39153 L
.3509 .38462 L
.34615 .38192 L
.32692 .37139 L
.31607 .36538 L
.30769 .36033 L
.28846 .34847 L
.28469 .34615 L
.26923 .33589 L
.25596 .32692 L
.25 .32268 L
.23077 .30859 L
.22955 .30769 L
.21154 .29356 L
.20518 .28846 L
.19231 .27764 L
.18266 .26923 L
.17308 .26059 L
.16195 .25 L
.15385 .24211 L
.1431 .23077 L
.13462 .22171 L
.12625 .21154 L
.11538 .19803 L
.11173 .19231 L
.10019 .17308 L
.09615 .16343 L
.09341 .15385 L
.09615 .13728 L
.09852 .13462 L
F
0 g
.11538 .12882 m
.13462 .13141 L
.14659 .13462 L
.15385 .13685 L
.17308 .14445 L
.19231 .15344 L
.19316 .15385 L
.21154 .16369 L
.2279 .17308 L
.23077 .17485 L
.25 .18715 L
.25788 .19231 L
.26923 .20023 L
.28494 .21154 L
.28846 .21419 L
.30769 .22917 L
.3097 .23077 L
.32692 .24514 L
.33256 .25 L
.34615 .26213 L
.35376 .26923 L
.36538 .28033 L
.37339 .28846 L
.38462 .29998 L
.3915 .30769 L
.40385 .32156 L
.40807 .32692 L
.42302 .34615 L
.42308 .34624 L
.43613 .36538 L
.44231 .37623 L
.44674 .38462 L
.4552 .40385 L
.44231 .41708 L
.42308 .41534 L
.40385 .40829 L
.39273 .40385 L
.38462 .40052 L
.36538 .39153 L
.3509 .38462 L
.34615 .38192 L
.32692 .37139 L
.31607 .36538 L
.30769 .36033 L
.28846 .34847 L
.28469 .34615 L
.26923 .33589 L
.25596 .32692 L
.25 .32268 L
.23077 .30859 L
Mistroke
.22955 .30769 L
.21154 .29356 L
.20518 .28846 L
.19231 .27764 L
.18266 .26923 L
.17308 .26059 L
.16195 .25 L
.15385 .24211 L
.1431 .23077 L
.13462 .22171 L
.12625 .21154 L
.11538 .19803 L
.11173 .19231 L
.10019 .17308 L
.09615 .16343 L
.09341 .15385 L
.09615 .13728 L
.09852 .13462 L
.11538 .12882 L
Mfstroke
.6 g
.13462 .14448 m
.15385 .1485 L
.17039 .15385 L
.17308 .15473 L
.19231 .16292 L
.21154 .17271 L
.21224 .17308 L
.23077 .18367 L
.24481 .19231 L
.25 .1957 L
.26923 .20889 L
.27298 .21154 L
.28846 .22305 L
.29838 .23077 L
.30769 .23825 L
.32151 .25 L
.32692 .25464 L
.34264 .26923 L
.34615 .2724 L
.36187 .28846 L
.36538 .29167 L
.37919 .30769 L
.38462 .31247 L
.39438 .32692 L
.40385 .34115 L
.40688 .34615 L
.41589 .36538 L
.40969 .38462 L
.40385 .38673 L
.3857 .38462 L
.38462 .38458 L
.36538 .37879 L
.34615 .37049 L
.33448 .36538 L
.32692 .36124 L
.30769 .35072 L
.29957 .34615 L
.28846 .33939 L
.26923 .32709 L
.26898 .32692 L
.25 .31384 L
.24141 .30769 L
.23077 .29973 L
.21639 .28846 L
.21154 .28457 L
.1936 .26923 L
.19231 .26814 L
.17308 .25017 L
.1729 .25 L
.15433 .23077 L
.15385 .2304 L
.13811 .21154 L
.13462 .20682 L
.12479 .19231 L
.1158 .17308 L
.1162 .15385 L
F
0 g
.13462 .14448 m
.15385 .1485 L
.17039 .15385 L
.17308 .15473 L
.19231 .16292 L
.21154 .17271 L
.21224 .17308 L
.23077 .18367 L
.24481 .19231 L
.25 .1957 L
.26923 .20889 L
.27298 .21154 L
.28846 .22305 L
.29838 .23077 L
.30769 .23825 L
.32151 .25 L
.32692 .25464 L
.34264 .26923 L
.34615 .2724 L
.36187 .28846 L
.36538 .29167 L
.37919 .30769 L
.38462 .31247 L
.39438 .32692 L
.40385 .34115 L
.40688 .34615 L
.41589 .36538 L
.40969 .38462 L
.40385 .38673 L
.3857 .38462 L
.38462 .38458 L
.36538 .37879 L
.34615 .37049 L
.33448 .36538 L
.32692 .36124 L
.30769 .35072 L
.29957 .34615 L
.28846 .33939 L
.26923 .32709 L
.26898 .32692 L
.25 .31384 L
.24141 .30769 L
.23077 .29973 L
.21639 .28846 L
.21154 .28457 L
.1936 .26923 L
.19231 .26814 L
.17308 .25017 L
.1729 .25 L
.15433 .23077 L
Mistroke
.15385 .2304 L
.13811 .21154 L
.13462 .20682 L
.12479 .19231 L
.1158 .17308 L
.1162 .15385 L
.13462 .14448 L
Mfstroke
.7 g
.15385 .16234 m
.17308 .16517 L
.19231 .17267 L
.1934 .17308 L
.21154 .18145 L
.23077 .19226 L
.23085 .19231 L
.25 .20409 L
.26115 .21154 L
.26923 .21715 L
.28731 .23077 L
.28846 .23162 L
.30769 .24734 L
.31075 .25 L
.32692 .26442 L
.33184 .26923 L
.34615 .28336 L
.35063 .28846 L
.36538 .30541 L
.36695 .30769 L
.38054 .32692 L
.38462 .33523 L
.38914 .34615 L
.38462 .36228 L
.36538 .36399 L
.34615 .35966 L
.32692 .35102 L
.31573 .34615 L
.30769 .34161 L
.28846 .33053 L
.28236 .32692 L
.26923 .31862 L
.25318 .30769 L
.25 .30547 L
.23077 .29107 L
.22742 .28846 L
.21154 .27561 L
.20424 .26923 L
.19231 .2587 L
.18352 .25 L
.17308 .23994 L
.16533 .23077 L
.15385 .21799 L
.15005 .21154 L
.1383 .19231 L
.13482 .17308 L
F
0 g
.15385 .16234 m
.17308 .16517 L
.19231 .17267 L
.1934 .17308 L
.21154 .18145 L
.23077 .19226 L
.23085 .19231 L
.25 .20409 L
.26115 .21154 L
.26923 .21715 L
.28731 .23077 L
.28846 .23162 L
.30769 .24734 L
.31075 .25 L
.32692 .26442 L
.33184 .26923 L
.34615 .28336 L
.35063 .28846 L
.36538 .30541 L
.36695 .30769 L
.38054 .32692 L
.38462 .33523 L
.38914 .34615 L
.38462 .36228 L
.36538 .36399 L
.34615 .35966 L
.32692 .35102 L
.31573 .34615 L
.30769 .34161 L
.28846 .33053 L
.28236 .32692 L
.26923 .31862 L
.25318 .30769 L
.25 .30547 L
.23077 .29107 L
.22742 .28846 L
.21154 .27561 L
.20424 .26923 L
.19231 .2587 L
.18352 .25 L
.17308 .23994 L
.16533 .23077 L
.15385 .21799 L
.15005 .21154 L
.1383 .19231 L
.13482 .17308 L
.15385 .16234 L
s
.8 g
.17308 .17899 m
.19231 .18177 L
.21154 .19104 L
.2145 .19231 L
.23077 .20056 L
.24851 .21154 L
.25 .21249 L
.26923 .22577 L
.27594 .23077 L
.28846 .24011 L
.29998 .25 L
.30769 .25588 L
.32103 .26923 L
.32692 .27263 L
.33928 .28846 L
.34615 .29718 L
.35426 .30769 L
.3639 .32692 L
.34615 .34487 L
.32692 .34217 L
.30769 .33186 L
.29679 .32692 L
.28846 .32209 L
.26923 .30981 L
.26594 .30769 L
.25 .29701 L
.2386 .28846 L
.23077 .28282 L
.21498 .26923 L
.21154 .26707 L
.19434 .25 L
.19231 .24778 L
.17658 .23077 L
.17308 .226 L
.16246 .21154 L
.15551 .19231 L
F
0 g
.17308 .17899 m
.19231 .18177 L
.21154 .19104 L
.2145 .19231 L
.23077 .20056 L
.24851 .21154 L
.25 .21249 L
.26923 .22577 L
.27594 .23077 L
.28846 .24011 L
.29998 .25 L
.30769 .25588 L
.32103 .26923 L
.32692 .27263 L
.33928 .28846 L
.34615 .29718 L
.35426 .30769 L
.3639 .32692 L
.34615 .34487 L
.32692 .34217 L
.30769 .33186 L
.29679 .32692 L
.28846 .32209 L
.26923 .30981 L
.26594 .30769 L
.25 .29701 L
.2386 .28846 L
.23077 .28282 L
.21498 .26923 L
.21154 .26707 L
.19434 .25 L
.19231 .24778 L
.17658 .23077 L
.17308 .226 L
.16246 .21154 L
.15551 .19231 L
.17308 .17899 L
s
.9 g
.19231 .19707 m
.21154 .19742 L
.23077 .21084 L
.2322 .21154 L
.25 .22086 L
.26424 .23077 L
.26923 .23253 L
.28805 .25 L
.28846 .25056 L
.30769 .26787 L
.30888 .26923 L
.32663 .28846 L
.32692 .28965 L
.33802 .30769 L
.32692 .32523 L
.30769 .32017 L
.28846 .31189 L
.27973 .30769 L
.26923 .30233 L
.25073 .28846 L
.25 .28721 L
.23077 .27273 L
.22688 .26923 L
.21154 .25658 L
.2061 .25 L
.19231 .23402 L
.18958 .23077 L
.17916 .21154 L
F
0 g
.19231 .19707 m
.21154 .19742 L
.23077 .21084 L
.2322 .21154 L
.25 .22086 L
.26424 .23077 L
.26923 .23253 L
.28805 .25 L
.28846 .25056 L
.30769 .26787 L
.30888 .26923 L
.32663 .28846 L
.32692 .28965 L
.33802 .30769 L
.32692 .32523 L
.30769 .32017 L
.28846 .31189 L
.27973 .30769 L
.26923 .30233 L
.25073 .28846 L
.25 .28721 L
.23077 .27273 L
.22688 .26923 L
.21154 .25658 L
.2061 .25 L
.19231 .23402 L
.18958 .23077 L
.17916 .21154 L
.19231 .19707 L
s
1 g
.21154 .21978 m
.23077 .22385 L
.24469 .23077 L
.25 .23394 L
.26923 .24546 L
.27392 .25 L
.28846 .26385 L
.29581 .26923 L
.30769 .2874 L
.3086 .28846 L
.30769 .30043 L
.28846 .29794 L
.26937 .28846 L
.26923 .28838 L
.25 .2754 L
.23803 .26923 L
.23077 .25934 L
.2214 .25 L
.21154 .23737 L
.20785 .23077 L
F
0 g
.21154 .21978 m
.23077 .22385 L
.24469 .23077 L
.25 .23394 L
.26923 .24546 L
.27392 .25 L
.28846 .26385 L
.29581 .26923 L
.30769 .2874 L
.3086 .28846 L
.30769 .30043 L
.28846 .29794 L
.26937 .28846 L
.26923 .28838 L
.25 .2754 L
.23803 .26923 L
.23077 .25934 L
.2214 .25 L
.21154 .23737 L
.20785 .23077 L
.21154 .21978 L
s
.5 g
.51923 .48678 m
.53846 .48191 L
.55769 .48432 L
.57692 .48879 L
.59615 .49451 L
.61191 .5 L
.61538 .50142 L
.63462 .50975 L
.65252 .51923 L
.65385 .52002 L
.67308 .5328 L
.68026 .53846 L
.69231 .54927 L
.70021 .55769 L
.71154 .57207 L
.71465 .57692 L
.72465 .59615 L
.73056 .61538 L
.73077 .61647 L
.7324 .63462 L
.73077 .64933 L
.72968 .65385 L
.72112 .67308 L
.71154 .68511 L
.70292 .69231 L
.69231 .69879 L
.67308 .70607 L
.65385 .70923 L
.63462 .70925 L
.61538 .70654 L
.59615 .7012 L
.57692 .69313 L
.57526 .69231 L
.55769 .68206 L
.54549 .67308 L
.53846 .6671 L
.52549 .65385 L
.51923 .64631 L
.51136 .63462 L
.50176 .61538 L
.5 .61055 L
.49613 .59615 L
.49418 .57692 L
.49554 .55769 L
.49938 .53846 L
.5 .53597 L
.50432 .51923 L
.50998 .5 L
F
0 g
.51923 .48678 m
.53846 .48191 L
.55769 .48432 L
.57692 .48879 L
.59615 .49451 L
.61191 .5 L
.61538 .50142 L
.63462 .50975 L
.65252 .51923 L
.65385 .52002 L
.67308 .5328 L
.68026 .53846 L
.69231 .54927 L
.70021 .55769 L
.71154 .57207 L
.71465 .57692 L
.72465 .59615 L
.73056 .61538 L
.73077 .61647 L
.7324 .63462 L
.73077 .64933 L
.72968 .65385 L
.72112 .67308 L
.71154 .68511 L
.70292 .69231 L
.69231 .69879 L
.67308 .70607 L
.65385 .70923 L
.63462 .70925 L
.61538 .70654 L
.59615 .7012 L
.57692 .69313 L
.57526 .69231 L
.55769 .68206 L
.54549 .67308 L
.53846 .6671 L
.52549 .65385 L
.51923 .64631 L
.51136 .63462 L
.50176 .61538 L
.5 .61055 L
.49613 .59615 L
.49418 .57692 L
.49554 .55769 L
.49938 .53846 L
.5 .53597 L
.50432 .51923 L
.50998 .5 L
.51923 .48678 L
s
.6 g
.57692 .5326 m
.59615 .53332 L
.61495 .53846 L
.61538 .53861 L
.63462 .54733 L
.65038 .55769 L
.65385 .56041 L
.67013 .57692 L
.67308 .57943 L
.68216 .59615 L
.68784 .61538 L
.687 .63462 L
.67679 .65385 L
.67308 .65768 L
.65385 .66832 L
.63462 .67116 L
.61538 .66943 L
.59615 .66345 L
.57841 .65385 L
.57692 .65274 L
.55769 .6353 L
.55714 .63462 L
.54474 .61538 L
.5389 .59615 L
.53859 .57692 L
.54378 .55769 L
.55769 .54004 L
.56026 .53846 L
F
0 g
.57692 .5326 m
.59615 .53332 L
.61495 .53846 L
.61538 .53861 L
.63462 .54733 L
.65038 .55769 L
.65385 .56041 L
.67013 .57692 L
.67308 .57943 L
.68216 .59615 L
.68784 .61538 L
.687 .63462 L
.67679 .65385 L
.67308 .65768 L
.65385 .66832 L
.63462 .67116 L
.61538 .66943 L
.59615 .66345 L
.57841 .65385 L
.57692 .65274 L
.55769 .6353 L
.55714 .63462 L
.54474 .61538 L
.5389 .59615 L
.53859 .57692 L
.54378 .55769 L
.55769 .54004 L
.56026 .53846 L
.57692 .5326 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.522676 0.0238095 0.97619 0.477324 MathSubStart
%% SurfaceGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.11022e-16 1.04977 -0.0679587 1.04977 [
[ 0 0 0 0 ]
[ 1 .81114 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.39787 .81114 L
s
.39787 .81114 m
.40529 .59895 L
s
.40529 .59895 m
.03716 .25514 L
s
.68874 0 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.68874 0 m
.03716 .25514 L
s
.40529 .59895 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.39787 .81114 L
s
.39787 .81114 m
.40529 .59895 L
s
0 0 m
1 0 L
1 .81114 L
0 .81114 L
closepath
clip
newpath
.664 .741 .908 r
.39902 .59803 .40512 .60371 .41537 .60064 .40929 .59494 Mtetra
.40929 .59494 .41537 .60064 .42565 .59755 .4196 .59183 Mtetra
.4196 .59183 .42565 .59755 .43597 .59446 .42994 .58871 Mtetra
.42994 .58871 .43597 .59446 .44633 .59135 .44033 .58558 Mtetra
.44033 .58558 .44633 .59135 .45674 .58823 .45076 .58244 Mtetra
.45076 .58244 .45674 .58823 .46718 .5851 .46122 .57928 Mtetra
.46122 .57928 .46718 .5851 .47766 .58195 .47173 .57612 Mtetra
.47173 .57612 .47766 .58195 .48818 .5788 .48228 .57294 Mtetra
.663 .741 .908 r
.48228 .57294 .48818 .5788 .49874 .57563 .49287 .56975 Mtetra
.49287 .56975 .49874 .57563 .50935 .57245 .5035 .56655 Mtetra
.5035 .56655 .50935 .57245 .51999 .56926 .51417 .56333 Mtetra
.51417 .56333 .51999 .56926 .53068 .56605 .52489 .56011 Mtetra
.52489 .56011 .53068 .56605 .54141 .56284 .53564 .55687 Mtetra
.53564 .55687 .54141 .56284 .55218 .55962 .54644 .55363 Mtetra
.663 .742 .908 r
.54644 .55363 .55218 .55962 .56299 .55638 .55728 .55038 Mtetra
.663 .742 .909 r
.55728 .55038 .56299 .55638 .57385 .55314 .56816 .54712 Mtetra
.662 .742 .909 r
.56816 .54712 .57385 .55314 .58474 .54989 .57909 .54386 Mtetra
.662 .742 .91 r
.57909 .54386 .58474 .54989 .59569 .54663 .59006 .54059 Mtetra
.662 .743 .91 r
.59006 .54059 .59569 .54663 .60667 .54337 .60107 .53733 Mtetra
.661 .743 .911 r
.60107 .53733 .60667 .54337 .6177 .5401 .61213 .53406 Mtetra
.66 .744 .912 r
.61213 .53406 .6177 .5401 .62877 .53683 .62324 .5308 Mtetra
.66 .745 .913 r
.62324 .5308 .62877 .53683 .63989 .53356 .63439 .52755 Mtetra
.659 .746 .914 r
.63439 .52755 .63989 .53356 .65105 .53029 .64558 .5243 Mtetra
.658 .747 .916 r
.64558 .5243 .65105 .53029 .66226 .52703 .65682 .52107 Mtetra
.657 .749 .918 r
.65682 .52107 .66226 .52703 .67351 .52376 .66811 .51784 Mtetra
.656 .751 .919 r
.66811 .51784 .67351 .52376 .68481 .5205 .67945 .51462 Mtetra
.655 .753 .922 r
.67945 .51462 .68481 .5205 .69616 .51723 .69083 .5114 Mtetra
.655 .755 .924 r
.69083 .5114 .69616 .51723 .70755 .51396 .70226 .50819 Mtetra
.654 .758 .926 r
.70226 .50819 .70755 .51396 .719 .51068 .71374 .50496 Mtetra
.654 .76 .928 r
.71374 .50496 .719 .51068 .73048 .50739 .72527 .50173 Mtetra
.654 .763 .93 r
.72527 .50173 .73048 .50739 .74202 .50408 .73684 .49846 Mtetra
.654 .766 .932 r
.73684 .49846 .74202 .50408 .7536 .50075 .74846 .49517 Mtetra
.655 .769 .933 r
.74846 .49517 .7536 .50075 .76523 .49738 .76013 .49183 Mtetra
.656 .771 .934 r
.76013 .49183 .76523 .49738 .77691 .49398 .77185 .48845 Mtetra
.657 .773 .934 r
.77185 .48845 .77691 .49398 .78863 .49054 .78361 .485 Mtetra
.659 .774 .934 r
.78361 .485 .78863 .49054 .8004 .48706 .79542 .4815 Mtetra
.661 .775 .934 r
.79542 .4815 .8004 .48706 .81221 .48352 .80727 .47793 Mtetra
.663 .775 .933 r
.80727 .47793 .81221 .48352 .82407 .47994 .81916 .47429 Mtetra
.664 .775 .932 r
.81916 .47429 .82407 .47994 .83597 .47632 .8311 .47059 Mtetra
.666 .774 .93 r
.8311 .47059 .83597 .47632 .84792 .47265 .84308 .46684 Mtetra
.667 .772 .928 r
.84308 .46684 .84792 .47265 .85992 .46893 .85511 .46304 Mtetra
.669 .77 .926 r
.85511 .46304 .85992 .46893 .87196 .46519 .86719 .45919 Mtetra
.669 .768 .924 r
.86719 .45919 .87196 .46519 .88405 .46142 .87931 .45531 Mtetra
.67 .765 .922 r
.87931 .45531 .88405 .46142 .89619 .45762 .89148 .4514 Mtetra
.67 .763 .92 r
.89148 .4514 .89619 .45762 .90838 .45381 .90369 .44749 Mtetra
.67 .76 .918 r
.90369 .44749 .90838 .45381 .92062 .44999 .91596 .44356 Mtetra
.67 .757 .916 r
.91596 .44356 .92062 .44999 .93291 .44616 .92828 .43963 Mtetra
.669 .755 .915 r
.92828 .43963 .93291 .44616 .94525 .44232 .94065 .4357 Mtetra
.668 .752 .913 r
.94065 .4357 .94525 .44232 .95764 .43848 .95308 .43178 Mtetra
.668 .75 .912 r
.95308 .43178 .95764 .43848 .97009 .43464 .96556 .42787 Mtetra
.664 .741 .908 r
.39287 .59231 .39902 .59803 .40929 .59494 .40317 .58919 Mtetra
.40317 .58919 .40929 .59494 .4196 .59183 .4135 .58606 Mtetra
.4135 .58606 .4196 .59183 .42994 .58871 .42387 .58292 Mtetra
.42387 .58292 .42994 .58871 .44033 .58558 .43428 .57977 Mtetra
.43428 .57977 .44033 .58558 .45076 .58244 .44474 .5766 Mtetra
.44474 .5766 .45076 .58244 .46122 .57928 .45523 .57343 Mtetra
.45523 .57343 .46122 .57928 .47173 .57612 .46576 .57024 Mtetra
.663 .741 .908 r
.46576 .57024 .47173 .57612 .48228 .57294 .47634 .56704 Mtetra
.47634 .56704 .48228 .57294 .49287 .56975 .48695 .56382 Mtetra
.48695 .56382 .49287 .56975 .5035 .56655 .49761 .5606 Mtetra
.49761 .5606 .5035 .56655 .51417 .56333 .50831 .55737 Mtetra
.50831 .55737 .51417 .56333 .52489 .56011 .51905 .55412 Mtetra
.663 .742 .908 r
.51905 .55412 .52489 .56011 .53564 .55687 .52983 .55087 Mtetra
.663 .742 .909 r
.52983 .55087 .53564 .55687 .54644 .55363 .54066 .54761 Mtetra
.54066 .54761 .54644 .55363 .55728 .55038 .55153 .54435 Mtetra
.662 .742 .909 r
.55153 .54435 .55728 .55038 .56816 .54712 .56244 .54108 Mtetra
.662 .742 .91 r
.56244 .54108 .56816 .54712 .57909 .54386 .5734 .53781 Mtetra
.661 .743 .911 r
.5734 .53781 .57909 .54386 .59006 .54059 .5844 .53455 Mtetra
.5844 .53455 .59006 .54059 .60107 .53733 .59544 .53129 Mtetra
.66 .744 .913 r
.59544 .53129 .60107 .53733 .61213 .53406 .60653 .52804 Mtetra
.659 .745 .914 r
.60653 .52804 .61213 .53406 .62324 .5308 .61766 .52481 Mtetra
.657 .747 .916 r
.61766 .52481 .62324 .5308 .63439 .52755 .62884 .52159 Mtetra
.656 .748 .918 r
.62884 .52159 .63439 .52755 .64558 .5243 .64007 .51839 Mtetra
.655 .75 .92 r
.64007 .51839 .64558 .5243 .65682 .52107 .65135 .51521 Mtetra
.653 .753 .923 r
.65135 .51521 .65682 .52107 .66811 .51784 .66267 .51205 Mtetra
.652 .755 .926 r
.66267 .51205 .66811 .51784 .67945 .51462 .67405 .50891 Mtetra
.65 .759 .929 r
.67405 .50891 .67945 .51462 .69083 .5114 .68547 .50578 Mtetra
.649 .762 .932 r
.68547 .50578 .69083 .5114 .70226 .50819 .69694 .50265 Mtetra
.648 .766 .935 r
.69694 .50265 .70226 .50819 .71374 .50496 .70846 .49951 Mtetra
.648 .77 .938 r
.70846 .49951 .71374 .50496 .72527 .50173 .72003 .49636 Mtetra
.648 .774 .94 r
.72003 .49636 .72527 .50173 .73684 .49846 .73165 .49317 Mtetra
.648 .778 .943 r
.73165 .49317 .73684 .49846 .74846 .49517 .74331 .48994 Mtetra
.649 .782 .944 r
.74331 .48994 .74846 .49517 .76013 .49183 .75502 .48665 Mtetra
.651 .785 .945 r
.75502 .48665 .76013 .49183 .77185 .48845 .76678 .48329 Mtetra
.653 .788 .946 r
.76678 .48329 .77185 .48845 .78361 .485 .77858 .47984 Mtetra
.656 .79 .946 r
.77858 .47984 .78361 .485 .79542 .4815 .79043 .47631 Mtetra
.659 .791 .945 r
.79043 .47631 .79542 .4815 .80727 .47793 .80232 .47269 Mtetra
.662 .791 .943 r
.80232 .47269 .80727 .47793 .81916 .47429 .81425 .46898 Mtetra
.665 .79 .941 r
.81425 .46898 .81916 .47429 .8311 .47059 .82622 .46519 Mtetra
.667 .788 .938 r
.82622 .46519 .8311 .47059 .84308 .46684 .83824 .46132 Mtetra
.67 .785 .936 r
.83824 .46132 .84308 .46684 .85511 .46304 .85029 .45738 Mtetra
.671 .782 .933 r
.85029 .45738 .85511 .46304 .86719 .45919 .8624 .4534 Mtetra
.672 .779 .93 r
.8624 .4534 .86719 .45919 .87931 .45531 .87455 .44938 Mtetra
.673 .775 .926 r
.87455 .44938 .87931 .45531 .89148 .4514 .88674 .44533 Mtetra
.673 .771 .924 r
.88674 .44533 .89148 .4514 .90369 .44749 .89899 .44127 Mtetra
.673 .767 .921 r
.89899 .44127 .90369 .44749 .91596 .44356 .91129 .43721 Mtetra
.672 .763 .919 r
.91129 .43721 .91596 .44356 .92828 .43963 .92364 .43316 Mtetra
.672 .759 .916 r
.92364 .43316 .92828 .43963 .94065 .4357 .93604 .42912 Mtetra
.671 .756 .915 r
.93604 .42912 .94065 .4357 .95308 .43178 .94849 .4251 Mtetra
.67 .753 .913 r
.94849 .4251 .95308 .43178 .96556 .42787 .96101 .42109 Mtetra
.664 .741 .908 r
.38668 .58654 .39287 .59231 .40317 .58919 .397 .5834 Mtetra
.397 .5834 .40317 .58919 .4135 .58606 .40736 .58025 Mtetra
.40736 .58025 .4135 .58606 .42387 .58292 .41776 .57709 Mtetra
.41776 .57709 .42387 .58292 .43428 .57977 .42819 .57392 Mtetra
.42819 .57392 .43428 .57977 .44474 .5766 .43867 .57073 Mtetra
.43867 .57073 .44474 .5766 .45523 .57343 .44919 .56753 Mtetra
.663 .741 .908 r
.44919 .56753 .45523 .57343 .46576 .57024 .45975 .56432 Mtetra
.45975 .56432 .46576 .57024 .47634 .56704 .47035 .5611 Mtetra
.47035 .5611 .47634 .56704 .48695 .56382 .48099 .55786 Mtetra
.48099 .55786 .48695 .56382 .49761 .5606 .49168 .55462 Mtetra
.49168 .55462 .49761 .5606 .50831 .55737 .5024 .55136 Mtetra
.663 .742 .908 r
.5024 .55136 .50831 .55737 .51905 .55412 .51317 .5481 Mtetra
.663 .742 .909 r
.51317 .5481 .51905 .55412 .52983 .55087 .52398 .54483 Mtetra
.662 .742 .909 r
.52398 .54483 .52983 .55087 .54066 .54761 .53484 .54156 Mtetra
.53484 .54156 .54066 .54761 .55153 .54435 .54573 .53829 Mtetra
.661 .742 .91 r
.54573 .53829 .55153 .54435 .56244 .54108 .55668 .53502 Mtetra
.661 .743 .911 r
.55668 .53502 .56244 .54108 .5734 .53781 .56766 .53176 Mtetra
.66 .744 .912 r
.56766 .53176 .5734 .53781 .5844 .53455 .57869 .5285 Mtetra
.659 .744 .913 r
.57869 .5285 .5844 .53455 .59544 .53129 .58976 .52527 Mtetra
.657 .746 .915 r
.58976 .52527 .59544 .53129 .60653 .52804 .60088 .52206 Mtetra
.656 .747 .917 r
.60088 .52206 .60653 .52804 .61766 .52481 .61205 .51887 Mtetra
.654 .749 .92 r
.61205 .51887 .61766 .52481 .62884 .52159 .62327 .51572 Mtetra
.652 .752 .923 r
.62327 .51572 .62884 .52159 .64007 .51839 .63453 .5126 Mtetra
.65 .755 .926 r
.63453 .5126 .64007 .51839 .65135 .51521 .64584 .50952 Mtetra
.647 .758 .93 r
.64584 .50952 .65135 .51521 .66267 .51205 .6572 .50647 Mtetra
.645 .762 .934 r
.6572 .50647 .66267 .51205 .67405 .50891 .66862 .50345 Mtetra
.643 .767 .938 r
.66862 .50345 .67405 .50891 .68547 .50578 .68008 .50045 Mtetra
.641 .772 .943 r
.68008 .50045 .68547 .50578 .69694 .50265 .69159 .49745 Mtetra
.639 .777 .947 r
.69159 .49745 .69694 .50265 .70846 .49951 .70316 .49445 Mtetra
.638 .783 .951 r
.70316 .49445 .70846 .49951 .72003 .49636 .71477 .49141 Mtetra
.638 .789 .954 r
.71477 .49141 .72003 .49636 .73165 .49317 .72644 .48834 Mtetra
.639 .794 .957 r
.72644 .48834 .73165 .49317 .74331 .48994 .73815 .48519 Mtetra
.641 .8 .959 r
.73815 .48519 .74331 .48994 .75502 .48665 .74991 .48196 Mtetra
.643 .804 .96 r
.74991 .48196 .75502 .48665 .76678 .48329 .76171 .47863 Mtetra
.647 .808 .96 r
.76171 .47863 .76678 .48329 .77858 .47984 .77355 .47519 Mtetra
.651 .81 .96 r
.77355 .47519 .77858 .47984 .79043 .47631 .78544 .47162 Mtetra
.656 .811 .958 r
.78544 .47162 .79043 .47631 .80232 .47269 .79737 .46793 Mtetra
.661 .811 .955 r
.79737 .46793 .80232 .47269 .81425 .46898 .80933 .46411 Mtetra
.665 .809 .952 r
.80933 .46411 .81425 .46898 .82622 .46519 .82134 .46019 Mtetra
.669 .806 .948 r
.82134 .46019 .82622 .46519 .83824 .46132 .83339 .45616 Mtetra
.673 .802 .944 r
.83339 .45616 .83824 .46132 .85029 .45738 .84547 .45205 Mtetra
.675 .798 .94 r
.84547 .45205 .85029 .45738 .8624 .4534 .8576 .44789 Mtetra
.677 .792 .936 r
.8576 .44789 .8624 .4534 .87455 .44938 .86978 .44368 Mtetra
.678 .787 .932 r
.86978 .44368 .87455 .44938 .88674 .44533 .882 .43944 Mtetra
.678 .781 .928 r
.882 .43944 .88674 .44533 .89899 .44127 .89427 .43521 Mtetra
.677 .775 .924 r
.89427 .43521 .89899 .44127 .91129 .43721 .90659 .43098 Mtetra
.676 .77 .921 r
.90659 .43098 .91129 .43721 .92364 .43316 .91897 .42677 Mtetra
.675 .765 .918 r
.91897 .42677 .92364 .43316 .93604 .42912 .9314 .42259 Mtetra
.674 .761 .916 r
.9314 .42259 .93604 .42912 .94849 .4251 .94388 .41844 Mtetra
.672 .757 .914 r
.94388 .41844 .94849 .4251 .96101 .42109 .95642 .41432 Mtetra
.664 .741 .908 r
.38045 .58074 .38668 .58654 .397 .5834 .39079 .57758 Mtetra
.39079 .57758 .397 .5834 .40736 .58025 .40117 .5744 Mtetra
.40117 .5744 .40736 .58025 .41776 .57709 .4116 .57122 Mtetra
.4116 .57122 .41776 .57709 .42819 .57392 .42206 .56802 Mtetra
.42206 .56802 .42819 .57392 .43867 .57073 .43256 .56481 Mtetra
.663 .741 .908 r
.43256 .56481 .43867 .57073 .44919 .56753 .44311 .56159 Mtetra
.44311 .56159 .44919 .56753 .45975 .56432 .45369 .55836 Mtetra
.45369 .55836 .45975 .56432 .47035 .5611 .46432 .55511 Mtetra
.46432 .55511 .47035 .5611 .48099 .55786 .47499 .55186 Mtetra
.47499 .55186 .48099 .55786 .49168 .55462 .4857 .54859 Mtetra
.4857 .54859 .49168 .55462 .5024 .55136 .49646 .54532 Mtetra
.663 .742 .909 r
.49646 .54532 .5024 .55136 .51317 .5481 .50725 .54205 Mtetra
.662 .742 .909 r
.50725 .54205 .51317 .5481 .52398 .54483 .51809 .53877 Mtetra
.662 .742 .91 r
.51809 .53877 .52398 .54483 .53484 .54156 .52897 .53549 Mtetra
.661 .742 .91 r
.52897 .53549 .53484 .54156 .54573 .53829 .5399 .53221 Mtetra
.66 .743 .911 r
.5399 .53221 .54573 .53829 .55668 .53502 .55087 .52895 Mtetra
.659 .744 .912 r
.55087 .52895 .55668 .53502 .56766 .53176 .56188 .52571 Mtetra
.658 .745 .914 r
.56188 .52571 .56766 .53176 .57869 .5285 .57294 .52249 Mtetra
.656 .746 .916 r
.57294 .52249 .57869 .5285 .58976 .52527 .58405 .5193 Mtetra
.654 .748 .919 r
.58405 .5193 .58976 .52527 .60088 .52206 .5952 .51615 Mtetra
.651 .75 .922 r
.5952 .51615 .60088 .52206 .61205 .51887 .6064 .51305 Mtetra
.649 .753 .926 r
.6064 .51305 .61205 .51887 .62327 .51572 .61765 .51 Mtetra
.645 .756 .93 r
.61765 .51 .62327 .51572 .63453 .5126 .62895 .50701 Mtetra
.642 .761 .935 r
.62895 .50701 .63453 .5126 .64584 .50952 .6403 .50407 Mtetra
.638 .766 .94 r
.6403 .50407 .64584 .50952 .6572 .50647 .6517 .50118 Mtetra
.634 .771 .946 r
.6517 .50118 .6572 .50647 .66862 .50345 .66316 .49834 Mtetra
.63 .778 .952 r
.66316 .49834 .66862 .50345 .68008 .50045 .67467 .49552 Mtetra
.627 .785 .957 r
.67467 .49552 .68008 .50045 .69159 .49745 .68623 .49272 Mtetra
.624 .792 .963 r
.68623 .49272 .69159 .49745 .70316 .49445 .69784 .4899 Mtetra
.622 .8 .968 r
.69784 .4899 .70316 .49445 .71477 .49141 .70951 .48704 Mtetra
.621 .808 .972 r
.70951 .48704 .71477 .49141 .72644 .48834 .72122 .48411 Mtetra
.622 .816 .975 r
.72122 .48411 .72644 .48834 .73815 .48519 .73299 .48108 Mtetra
.625 .823 .976 r
.73299 .48108 .73815 .48519 .74991 .48196 .74479 .47793 Mtetra
.629 .828 .977 r
.74479 .47793 .74991 .48196 .76171 .47863 .75664 .47464 Mtetra
.635 .833 .977 r
.75664 .47464 .76171 .47863 .77355 .47519 .76853 .47119 Mtetra
.642 .836 .975 r
.76853 .47119 .77355 .47519 .78544 .47162 .78046 .46756 Mtetra
.65 .837 .972 r
.78046 .46756 .78544 .47162 .79737 .46793 .79243 .46376 Mtetra
.658 .837 .969 r
.79243 .46376 .79737 .46793 .80933 .46411 .80443 .4598 Mtetra
.665 .834 .964 r
.80443 .4598 .80933 .46411 .82134 .46019 .81646 .45569 Mtetra
.672 .829 .959 r
.81646 .45569 .82134 .46019 .83339 .45616 .82854 .45146 Mtetra
.677 .824 .954 r
.82854 .45146 .83339 .45616 .84547 .45205 .84065 .44712 Mtetra
.68 .817 .948 r
.84065 .44712 .84547 .45205 .8576 .44789 .85281 .44271 Mtetra
.683 .809 .943 r
.85281 .44271 .8576 .44789 .86978 .44368 .865 .43826 Mtetra
.684 .801 .937 r
.865 .43826 .86978 .44368 .882 .43944 .87725 .43378 Mtetra
.684 .793 .932 r
.87725 .43378 .882 .43944 .89427 .43521 .88954 .42932 Mtetra
.683 .785 .928 r
.88954 .42932 .89427 .43521 .90659 .43098 .90188 .42487 Mtetra
.681 .778 .924 r
.90188 .42487 .90659 .43098 .91897 .42677 .91428 .42047 Mtetra
.679 .772 .921 r
.91428 .42047 .91897 .42677 .9314 .42259 .92673 .41611 Mtetra
.677 .766 .918 r
.92673 .41611 .9314 .42259 .94388 .41844 .93924 .41181 Mtetra
.675 .761 .915 r
.93924 .41181 .94388 .41844 .95642 .41432 .95181 .40756 Mtetra
.664 .741 .908 r
.37417 .57489 .38045 .58074 .39079 .57758 .38454 .57171 Mtetra
.38454 .57171 .39079 .57758 .40117 .5744 .39494 .56851 Mtetra
.39494 .56851 .40117 .5744 .4116 .57122 .40539 .5653 Mtetra
.40539 .5653 .4116 .57122 .42206 .56802 .41588 .56208 Mtetra
.663 .741 .908 r
.41588 .56208 .42206 .56802 .43256 .56481 .42641 .55885 Mtetra
.42641 .55885 .43256 .56481 .44311 .56159 .43698 .55561 Mtetra
.43698 .55561 .44311 .56159 .45369 .55836 .44759 .55235 Mtetra
.44759 .55235 .45369 .55836 .46432 .55511 .45825 .54909 Mtetra
.45825 .54909 .46432 .55511 .47499 .55186 .46895 .54581 Mtetra
.46895 .54581 .47499 .55186 .4857 .54859 .47968 .54253 Mtetra
.663 .742 .909 r
.47968 .54253 .4857 .54859 .49646 .54532 .49046 .53924 Mtetra
.662 .742 .909 r
.49046 .53924 .49646 .54532 .50725 .54205 .50129 .53596 Mtetra
.662 .742 .91 r
.50129 .53596 .50725 .54205 .51809 .53877 .51215 .53267 Mtetra
.661 .742 .91 r
.51215 .53267 .51809 .53877 .52897 .53549 .52306 .52939 Mtetra
.66 .743 .911 r
.52306 .52939 .52897 .53549 .5399 .53221 .53402 .52613 Mtetra
.659 .744 .913 r
.53402 .52613 .5399 .53221 .55087 .52895 .54502 .52289 Mtetra
.657 .745 .915 r
.54502 .52289 .55087 .52895 .56188 .52571 .55606 .51968 Mtetra
.655 .746 .917 r
.55606 .51968 .56188 .52571 .57294 .52249 .56715 .51652 Mtetra
.652 .748 .92 r
.56715 .51652 .57294 .52249 .58405 .5193 .57829 .51341 Mtetra
.649 .751 .924 r
.57829 .51341 .58405 .5193 .5952 .51615 .58948 .51036 Mtetra
.645 .754 .928 r
.58948 .51036 .5952 .51615 .6064 .51305 .60071 .50739 Mtetra
.641 .758 .933 r
.60071 .50739 .6064 .51305 .61765 .51 .612 .50449 Mtetra
.635 .763 .939 r
.612 .50449 .61765 .51 .62895 .50701 .62334 .50168 Mtetra
.63 .768 .946 r
.62334 .50168 .62895 .50701 .6403 .50407 .63473 .49895 Mtetra
.623 .775 .953 r
.63473 .49895 .6403 .50407 .6517 .50118 .64618 .4963 Mtetra
.617 .783 .961 r
.64618 .4963 .6517 .50118 .66316 .49834 .65768 .4937 Mtetra
.61 .791 .968 r
.65768 .4937 .66316 .49834 .67467 .49552 .66924 .49114 Mtetra
.603 .801 .975 r
.66924 .49114 .67467 .49552 .68623 .49272 .68085 .48859 Mtetra
.598 .81 .981 r
.68085 .48859 .68623 .49272 .69784 .4899 .69252 .48602 Mtetra
.593 .82 .986 r
.69252 .48602 .69784 .4899 .70951 .48704 .70424 .48339 Mtetra
.591 .83 .99 r
.70424 .48339 .70951 .48704 .72122 .48411 .71601 .48066 Mtetra
.592 .84 .992 r
.71601 .48066 .72122 .48411 .73299 .48108 .72783 .47778 Mtetra
.596 .848 .992 r
.72783 .47778 .73299 .48108 .74479 .47793 .73969 .47473 Mtetra
.603 .856 .992 r
.73969 .47473 .74479 .47793 .75664 .47464 .75159 .47147 Mtetra
.613 .862 .99 r
.75159 .47147 .75664 .47464 .76853 .47119 .76352 .46799 Mtetra
.625 .866 .988 r
.76352 .46799 .76853 .47119 .78046 .46756 .7755 .46427 Mtetra
.638 .868 .985 r
.7755 .46427 .78046 .46756 .79243 .46376 .7875 .46033 Mtetra
.652 .867 .98 r
.7875 .46033 .79243 .46376 .80443 .4598 .79954 .45617 Mtetra
.664 .863 .975 r
.79954 .45617 .80443 .4598 .81646 .45569 .8116 .45181 Mtetra
.674 .857 .969 r
.8116 .45181 .81646 .45569 .82854 .45146 .8237 .44729 Mtetra
.682 .849 .963 r
.8237 .44729 .82854 .45146 .84065 .44712 .83584 .44265 Mtetra
.687 .839 .956 r
.83584 .44265 .84065 .44712 .85281 .44271 .84801 .43793 Mtetra
.691 .829 .949 r
.84801 .43793 .85281 .44271 .865 .43826 .86022 .43316 Mtetra
.692 .818 .943 r
.86022 .43316 .865 .43826 .87725 .43378 .87248 .42838 Mtetra
.691 .807 .937 r
.87248 .42838 .87725 .43378 .88954 .42932 .88479 .42362 Mtetra
.69 .797 .931 r
.88479 .42362 .88954 .42932 .90188 .42487 .89715 .41891 Mtetra
.688 .788 .926 r
.89715 .41891 .90188 .42487 .91428 .42047 .90957 .41427 Mtetra
.685 .779 .922 r
.90957 .41427 .91428 .42047 .92673 .41611 .92204 .4097 Mtetra
.682 .772 .919 r
.92204 .4097 .92673 .41611 .93924 .41181 .93457 .40521 Mtetra
.679 .765 .916 r
.93457 .40521 .93924 .41181 .95181 .40756 .94717 .40081 Mtetra
.664 .741 .908 r
.36785 .56901 .37417 .57489 .38454 .57171 .37824 .5658 Mtetra
.37824 .5658 .38454 .57171 .39494 .56851 .38867 .56258 Mtetra
.38867 .56258 .39494 .56851 .40539 .5653 .39914 .55935 Mtetra
.663 .741 .908 r
.39914 .55935 .40539 .5653 .41588 .56208 .40966 .55611 Mtetra
.40966 .55611 .41588 .56208 .42641 .55885 .42022 .55285 Mtetra
.42022 .55285 .42641 .55885 .43698 .55561 .43081 .54958 Mtetra
.43081 .54958 .43698 .55561 .44759 .55235 .44145 .54631 Mtetra
.44145 .54631 .44759 .55235 .45825 .54909 .45213 .54302 Mtetra
.45213 .54302 .45825 .54909 .46895 .54581 .46285 .53973 Mtetra
.663 .742 .909 r
.46285 .53973 .46895 .54581 .47968 .54253 .47362 .53643 Mtetra
.662 .742 .909 r
.47362 .53643 .47968 .54253 .49046 .53924 .48443 .53314 Mtetra
.662 .742 .91 r
.48443 .53314 .49046 .53924 .50129 .53596 .49528 .52984 Mtetra
.661 .742 .91 r
.49528 .52984 .50129 .53596 .51215 .53267 .50617 .52656 Mtetra
.66 .743 .912 r
.50617 .52656 .51215 .53267 .52306 .52939 .51711 .52329 Mtetra
.658 .744 .913 r
.51711 .52329 .52306 .52939 .53402 .52613 .52809 .52005 Mtetra
.656 .745 .915 r
.52809 .52005 .53402 .52613 .54502 .52289 .53912 .51686 Mtetra
.654 .746 .918 r
.53912 .51686 .54502 .52289 .55606 .51968 .5502 .51371 Mtetra
.65 .748 .921 r
.5502 .51371 .55606 .51968 .56715 .51652 .56132 .51064 Mtetra
.646 .751 .925 r
.56132 .51064 .56715 .51652 .57829 .51341 .57249 .50764 Mtetra
.641 .754 .93 r
.57249 .50764 .57829 .51341 .58948 .51036 .58371 .50474 Mtetra
.636 .758 .937 r
.58371 .50474 .58948 .51036 .60071 .50739 .59498 .50195 Mtetra
.628 .764 .944 r
.59498 .50195 .60071 .50739 .612 .50449 .60631 .49927 Mtetra
.62 .77 .952 r
.60631 .49927 .612 .50449 .62334 .50168 .61769 .49672 Mtetra
.611 .778 .961 r
.61769 .49672 .62334 .50168 .63473 .49895 .62913 .49428 Mtetra
.6 .786 .97 r
.62913 .49428 .63473 .49895 .64618 .4963 .64062 .49193 Mtetra
.588 .796 .979 r
.64062 .49193 .64618 .4963 .65768 .4937 .65218 .48967 Mtetra
.575 .806 .987 r
.65218 .48967 .65768 .4937 .66924 .49114 .66379 .48746 Mtetra
.563 .817 .993 r
.66379 .48746 .66924 .49114 .68085 .48859 .67546 .48525 Mtetra
.551 .828 .997 r
.67546 .48525 .68085 .48859 .69252 .48602 .68719 .483 Mtetra
.541 .838 .999 r
.68719 .483 .69252 .48602 .70424 .48339 .69897 .48065 Mtetra
.536 .848 .998 r
.69897 .48065 .70424 .48339 .71601 .48066 .7108 .47816 Mtetra
.536 .859 .996 r
.7108 .47816 .71601 .48066 .72783 .47778 .72268 .47546 Mtetra
.542 .869 .994 r
.72268 .47546 .72783 .47778 .73969 .47473 .7346 .47251 Mtetra
.554 .878 .991 r
.7346 .47251 .73969 .47473 .75159 .47147 .74655 .46928 Mtetra
.572 .887 .99 r
.74655 .46928 .75159 .47147 .76352 .46799 .75854 .46574 Mtetra
.593 .894 .988 r
.75854 .46574 .76352 .46799 .7755 .46427 .77055 .46189 Mtetra
.616 .898 .987 r
.77055 .46189 .7755 .46427 .7875 .46033 .7826 .45774 Mtetra
.639 .899 .984 r
.7826 .45774 .7875 .46033 .79954 .45617 .79466 .4533 Mtetra
.659 .895 .981 r
.79466 .4533 .79954 .45617 .8116 .45181 .80676 .44861 Mtetra
.676 .888 .976 r
.80676 .44861 .8116 .45181 .8237 .44729 .81888 .44372 Mtetra
.688 .877 .969 r
.81888 .44372 .8237 .44729 .83584 .44265 .83103 .43869 Mtetra
.696 .865 .962 r
.83103 .43869 .83584 .44265 .84801 .43793 .84322 .43357 Mtetra
.701 .851 .954 r
.84322 .43357 .84801 .43793 .86022 .43316 .85544 .4284 Mtetra
.702 .837 .947 r
.85544 .4284 .86022 .43316 .87248 .42838 .86771 .42324 Mtetra
.701 .823 .94 r
.86771 .42324 .87248 .42838 .88479 .42362 .88003 .41813 Mtetra
.699 .81 .934 r
.88003 .41813 .88479 .42362 .89715 .41891 .8924 .4131 Mtetra
.696 .798 .928 r
.8924 .4131 .89715 .41891 .90957 .41427 .90483 .40817 Mtetra
.692 .787 .924 r
.90483 .40817 .90957 .41427 .92204 .4097 .91733 .40335 Mtetra
.688 .778 .92 r
.91733 .40335 .92204 .4097 .93457 .40521 .92988 .39865 Mtetra
.684 .77 .917 r
.92988 .39865 .93457 .40521 .94717 .40081 .9425 .39406 Mtetra
.664 .741 .908 r
.36148 .56308 .36785 .56901 .37824 .5658 .37189 .55985 Mtetra
.37189 .55985 .37824 .5658 .38867 .56258 .38235 .5566 Mtetra
.663 .741 .908 r
.38235 .5566 .38867 .56258 .39914 .55935 .39285 .55335 Mtetra
.39285 .55335 .39914 .55935 .40966 .55611 .40339 .55008 Mtetra
.40339 .55008 .40966 .55611 .42022 .55285 .41397 .54681 Mtetra
.41397 .54681 .42022 .55285 .43081 .54958 .4246 .54352 Mtetra
.4246 .54352 .43081 .54958 .44145 .54631 .43526 .54022 Mtetra
.43526 .54022 .44145 .54631 .45213 .54302 .44597 .53692 Mtetra
.663 .742 .909 r
.44597 .53692 .45213 .54302 .46285 .53973 .45672 .53361 Mtetra
.662 .742 .909 r
.45672 .53361 .46285 .53973 .47362 .53643 .46751 .5303 Mtetra
.662 .742 .91 r
.46751 .5303 .47362 .53643 .48443 .53314 .47835 .527 Mtetra
.661 .742 .91 r
.47835 .527 .48443 .53314 .49528 .52984 .48923 .5237 Mtetra
.659 .743 .912 r
.48923 .5237 .49528 .52984 .50617 .52656 .50015 .52043 Mtetra
.658 .744 .913 r
.50015 .52043 .50617 .52656 .51711 .52329 .51111 .5172 Mtetra
.656 .745 .915 r
.51111 .5172 .51711 .52329 .52809 .52005 .52213 .514 Mtetra
.653 .746 .918 r
.52213 .514 .52809 .52005 .53912 .51686 .53318 .51087 Mtetra
.649 .748 .922 r
.53318 .51087 .53912 .51686 .5502 .51371 .54429 .50782 Mtetra
.644 .751 .926 r
.54429 .50782 .5502 .51371 .56132 .51064 .55544 .50488 Mtetra
.638 .754 .932 r
.55544 .50488 .56132 .51064 .57249 .50764 .56665 .50205 Mtetra
.631 .758 .939 r
.56665 .50205 .57249 .50764 .58371 .50474 .5779 .49935 Mtetra
.621 .764 .948 r
.5779 .49935 .58371 .50474 .59498 .50195 .58921 .49681 Mtetra
.61 .771 .957 r
.58921 .49681 .59498 .50195 .60631 .49927 .60058 .49444 Mtetra
.596 .778 .967 r
.60058 .49444 .60631 .49927 .61769 .49672 .612 .49222 Mtetra
.58 .787 .978 r
.612 .49222 .61769 .49672 .62913 .49428 .62349 .49016 Mtetra
.561 .797 .987 r
.62349 .49016 .62913 .49428 .64062 .49193 .63504 .48823 Mtetra
.539 .807 .995 r
.63504 .48823 .64062 .49193 .65218 .48967 .64665 .4864 Mtetra
.515 .816 1 r
.64665 .4864 .65218 .48967 .66379 .48746 .65832 .48462 Mtetra
.49 .824 .999 r
.65832 .48462 .66379 .48746 .67546 .48525 .67006 .48284 Mtetra
.466 .83 .994 r
.67006 .48284 .67546 .48525 .68719 .483 .68185 .48098 Mtetra
.447 .836 .984 r
.68185 .48098 .68719 .483 .69897 .48065 .6937 .47899 Mtetra
.435 .842 .972 r
.6937 .47899 .69897 .48065 .7108 .47816 .7056 .47677 Mtetra
.434 .85 .961 r
.7056 .47677 .7108 .47816 .72268 .47546 .71754 .47427 Mtetra
.444 .861 .953 r
.71754 .47427 .72268 .47546 .7346 .47251 .72952 .47143 Mtetra
.466 .875 .951 r
.72952 .47143 .7346 .47251 .74655 .46928 .74154 .46821 Mtetra
.498 .89 .953 r
.74154 .46821 .74655 .46928 .75854 .46574 .75357 .46457 Mtetra
.537 .906 .959 r
.75357 .46457 .75854 .46574 .77055 .46189 .76563 .46052 Mtetra
.578 .918 .966 r
.76563 .46052 .77055 .46189 .7826 .45774 .77771 .45607 Mtetra
.616 .925 .972 r
.77771 .45607 .7826 .45774 .79466 .4533 .78981 .45126 Mtetra
.65 .925 .975 r
.78981 .45126 .79466 .4533 .80676 .44861 .80193 .44615 Mtetra
.677 .918 .974 r
.80193 .44615 .80676 .44861 .81888 .44372 .81406 .44079 Mtetra
.695 .906 .97 r
.81406 .44079 .81888 .44372 .83103 .43869 .82623 .43527 Mtetra
.707 .891 .964 r
.82623 .43527 .83103 .43869 .84322 .43357 .83842 .42964 Mtetra
.713 .874 .957 r
.83842 .42964 .84322 .43357 .85544 .4284 .85065 .42399 Mtetra
.715 .856 .949 r
.85065 .42399 .85544 .4284 .86771 .42324 .86293 .41838 Mtetra
.713 .839 .942 r
.86293 .41838 .86771 .42324 .88003 .41813 .87525 .41284 Mtetra
.71 .822 .935 r
.87525 .41284 .88003 .41813 .8924 .4131 .88764 .40743 Mtetra
.705 .808 .929 r
.88764 .40743 .8924 .4131 .90483 .40817 .90008 .40217 Mtetra
.7 .795 .924 r
.90008 .40217 .90483 .40817 .91733 .40335 .91258 .39706 Mtetra
.694 .784 .92 r
.91258 .39706 .91733 .40335 .92988 .39865 .92516 .39211 Mtetra
.689 .775 .917 r
.92516 .39211 .92988 .39865 .9425 .39406 .9378 .38732 Mtetra
.664 .741 .908 r
.35506 .5571 .36148 .56308 .37189 .55985 .3655 .55385 Mtetra
.3655 .55385 .37189 .55985 .38235 .5566 .37599 .55058 Mtetra
.663 .741 .908 r
.37599 .55058 .38235 .5566 .39285 .55335 .38651 .54731 Mtetra
.38651 .54731 .39285 .55335 .40339 .55008 .39708 .54402 Mtetra
.39708 .54402 .40339 .55008 .41397 .54681 .40769 .54072 Mtetra
.40769 .54072 .41397 .54681 .4246 .54352 .41834 .53741 Mtetra
.41834 .53741 .4246 .54352 .43526 .54022 .42903 .5341 Mtetra
.663 .741 .909 r
.42903 .5341 .43526 .54022 .44597 .53692 .43976 .53078 Mtetra
.662 .742 .909 r
.43976 .53078 .44597 .53692 .45672 .53361 .45054 .52745 Mtetra
.662 .742 .91 r
.45054 .52745 .45672 .53361 .46751 .5303 .46136 .52414 Mtetra
.661 .742 .91 r
.46136 .52414 .46751 .5303 .47835 .527 .47222 .52084 Mtetra
.659 .743 .912 r
.47222 .52084 .47835 .527 .48923 .5237 .48313 .51755 Mtetra
.658 .743 .913 r
.48313 .51755 .48923 .5237 .50015 .52043 .49408 .51431 Mtetra
.655 .744 .915 r
.49408 .51431 .50015 .52043 .51111 .5172 .50507 .51112 Mtetra
.652 .746 .918 r
.50507 .51112 .51111 .5172 .52213 .514 .51611 .50799 Mtetra
.648 .748 .922 r
.51611 .50799 .52213 .514 .53318 .51087 .5272 .50496 Mtetra
.642 .75 .927 r
.5272 .50496 .53318 .51087 .54429 .50782 .53834 .50205 Mtetra
.635 .753 .933 r
.53834 .50205 .54429 .50782 .55544 .50488 .54952 .49928 Mtetra
.626 .758 .941 r
.54952 .49928 .55544 .50488 .56665 .50205 .56076 .49667 Mtetra
.615 .763 .95 r
.56076 .49667 .56665 .50205 .5779 .49935 .57205 .49426 Mtetra
.6 .77 .961 r
.57205 .49426 .5779 .49935 .58921 .49681 .5834 .49205 Mtetra
.582 .777 .972 r
.5834 .49205 .58921 .49681 .60058 .49444 .59481 .49006 Mtetra
.559 .786 .984 r
.59481 .49006 .60058 .49444 .612 .49222 .60629 .48829 Mtetra
.531 .794 .993 r
.60629 .48829 .612 .49222 .62349 .49016 .61783 .48671 Mtetra
.496 .801 .999 r
.61783 .48671 .62349 .49016 .63504 .48823 .62943 .4853 Mtetra
.455 .804 .998 r
.62943 .4853 .63504 .48823 .64665 .4864 .64111 .48401 Mtetra
.41 .803 .987 r
.64111 .48401 .64665 .4864 .65832 .48462 .65285 .48277 Mtetra
.363 .797 .965 r
.65285 .48277 .65832 .48462 .67006 .48284 .66465 .48151 Mtetra
.321 .788 .934 r
.66465 .48151 .67006 .48284 .68185 .48098 .67652 .48013 Mtetra
.289 .778 .9 r
.67652 .48013 .68185 .48098 .6937 .47899 .68844 .47854 Mtetra
.272 .774 .868 r
.68844 .47854 .6937 .47899 .7056 .47677 .70041 .47664 Mtetra
.274 .778 .846 r
.70041 .47664 .7056 .47677 .71754 .47427 .71242 .47435 Mtetra
.295 .792 .837 r
.71242 .47435 .71754 .47427 .72952 .47143 .72447 .4716 Mtetra
.334 .817 .842 r
.72447 .4716 .72952 .47143 .74154 .46821 .73654 .46833 Mtetra
.389 .849 .859 r
.73654 .46833 .74154 .46821 .75357 .46457 .74863 .46453 Mtetra
.453 .884 .884 r
.74863 .46453 .75357 .46457 .76563 .46052 .76074 .4602 Mtetra
.52 .914 .911 r
.76074 .4602 .76563 .46052 .77771 .45607 .77285 .45536 Mtetra
.583 .936 .935 r
.77285 .45536 .77771 .45607 .78981 .45126 .78497 .45007 Mtetra
.636 .946 .952 r
.78497 .45007 .78981 .45126 .80193 .44615 .79711 .44442 Mtetra
.677 .944 .961 r
.79711 .44442 .80193 .44615 .81406 .44079 .80926 .43848 Mtetra
.705 .933 .963 r
.80926 .43848 .81406 .44079 .82623 .43527 .82143 .43235 Mtetra
.721 .916 .961 r
.82143 .43235 .82623 .43527 .83842 .42964 .83362 .42613 Mtetra
.729 .896 .955 r
.83362 .42613 .83842 .42964 .85065 .42399 .84586 .4199 Mtetra
.73 .874 .948 r
.84586 .4199 .85065 .42399 .86293 .41838 .85813 .41375 Mtetra
.728 .854 .941 r
.85813 .41375 .86293 .41838 .87525 .41284 .87046 .40772 Mtetra
.722 .835 .934 r
.87046 .40772 .87525 .41284 .88764 .40743 .88284 .40187 Mtetra
.716 .817 .928 r
.88284 .40187 .88764 .40743 .90008 .40217 .89529 .39623 Mtetra
.709 .802 .923 r
.89529 .39623 .90008 .40217 .91258 .39706 .90781 .39079 Mtetra
.702 .79 .919 r
.90781 .39079 .91258 .39706 .92516 .39211 .9204 .38557 Mtetra
.695 .779 .916 r
.9204 .38557 .92516 .39211 .9378 .38732 .93306 .38055 Mtetra
.664 .741 .908 r
.3486 .55109 .35506 .5571 .3655 .55385 .35907 .54781 Mtetra
.663 .741 .908 r
.35907 .54781 .3655 .55385 .37599 .55058 .36958 .54452 Mtetra
.36958 .54452 .37599 .55058 .38651 .54731 .38013 .54122 Mtetra
.38013 .54122 .38651 .54731 .39708 .54402 .39072 .53791 Mtetra
.39072 .53791 .39708 .54402 .40769 .54072 .40135 .53459 Mtetra
.40135 .53459 .40769 .54072 .41834 .53741 .41203 .53126 Mtetra
.663 .741 .909 r
.41203 .53126 .41834 .53741 .42903 .5341 .42275 .52793 Mtetra
.662 .742 .909 r
.42275 .52793 .42903 .5341 .43976 .53078 .43351 .5246 Mtetra
.43351 .5246 .43976 .53078 .45054 .52745 .44431 .52127 Mtetra
.661 .742 .91 r
.44431 .52127 .45054 .52745 .46136 .52414 .45516 .51795 Mtetra
.659 .742 .911 r
.45516 .51795 .46136 .52414 .47222 .52084 .46605 .51466 Mtetra
.658 .743 .913 r
.46605 .51466 .47222 .52084 .48313 .51755 .47698 .5114 Mtetra
.655 .744 .915 r
.47698 .5114 .48313 .51755 .49408 .51431 .48796 .5082 Mtetra
.652 .745 .918 r
.48796 .5082 .49408 .51431 .50507 .51112 .49898 .50507 Mtetra
.647 .747 .922 r
.49898 .50507 .50507 .51112 .51611 .50799 .51005 .50205 Mtetra
.641 .749 .927 r
.51005 .50205 .51611 .50799 .5272 .50496 .52117 .49915 Mtetra
.633 .752 .934 r
.52117 .49915 .5272 .50496 .53834 .50205 .53234 .49642 Mtetra
.623 .756 .942 r
.53234 .49642 .53834 .50205 .54952 .49928 .54356 .49389 Mtetra
.609 .761 .952 r
.54356 .49389 .54952 .49928 .56076 .49667 .55483 .49158 Mtetra
.592 .768 .963 r
.55483 .49158 .56076 .49667 .57205 .49426 .56616 .48952 Mtetra
.569 .774 .976 r
.56616 .48952 .57205 .49426 .5834 .49205 .57755 .48774 Mtetra
.539 .781 .987 r
.57755 .48774 .5834 .49205 .59481 .49006 .58901 .48624 Mtetra
.5 .786 .996 r
.58901 .48624 .59481 .49006 .60629 .48829 .60053 .48501 Mtetra
.45 .788 .998 r
.60053 .48501 .60629 .48829 .61783 .48671 .61213 .48404 Mtetra
.388 .782 .988 r
.61213 .48404 .61783 .48671 .62943 .4853 .6238 .48326 Mtetra
.317 .765 .959 r
.6238 .48326 .62943 .4853 .64111 .48401 .63554 .48262 Mtetra
.241 .737 .911 r
.63554 .48262 .64111 .48401 .65285 .48277 .64735 .48202 Mtetra
.17 .702 .847 r
.64735 .48202 .65285 .48277 .66465 .48151 .65923 .48137 Mtetra
.114 .666 .78 r
.65923 .48137 .66465 .48151 .67652 .48013 .67118 .48053 Mtetra
.08 .64 .719 r
.67118 .48053 .67652 .48013 .68844 .47854 .68318 .47939 Mtetra
0 0 0 r
.68318 .47939 .68844 .47854 .70041 .47664 .69523 .47783 Mtetra
.69523 .47783 .70041 .47664 .71242 .47435 .70732 .47575 Mtetra
.70732 .47575 .71242 .47435 .72447 .4716 .71943 .47305 Mtetra
.71943 .47305 .72447 .4716 .73654 .46833 .73157 .46968 Mtetra
.262 .762 .714 r
.73157 .46968 .73654 .46833 .74863 .46453 .74371 .46563 Mtetra
.356 .825 .767 r
.74371 .46563 .74863 .46453 .76074 .4602 .75585 .46091 Mtetra
.454 .884 .824 r
.75585 .46091 .76074 .4602 .77285 .45536 .768 .45557 Mtetra
.546 .93 .875 r
.768 .45557 .77285 .45536 .78497 .45007 .78015 .44968 Mtetra
.623 .956 .914 r
.78015 .44968 .78497 .45007 .79711 .44442 .79229 .44336 Mtetra
.68 .963 .938 r
.79229 .44336 .79711 .44442 .80926 .43848 .80445 .43672 Mtetra
.718 .955 .949 r
.80445 .43672 .80926 .43848 .82143 .43235 .81662 .42988 Mtetra
.738 .937 .952 r
.81662 .42988 .82143 .43235 .83362 .42613 .82881 .42296 Mtetra
.747 .914 .949 r
.82881 .42296 .83362 .42613 .84586 .4199 .84104 .41606 Mtetra
.748 .89 .943 r
.84104 .41606 .84586 .4199 .85813 .41375 .85331 .40929 Mtetra
.744 .866 .937 r
.85331 .40929 .85813 .41375 .87046 .40772 .86564 .40272 Mtetra
.736 .844 .931 r
.86564 .40272 .87046 .40772 .88284 .40187 .87802 .39638 Mtetra
.728 .825 .925 r
.87802 .39638 .88284 .40187 .89529 .39623 .89048 .39031 Mtetra
.718 .808 .921 r
.89048 .39031 .89529 .39623 .90781 .39079 .903 .38452 Mtetra
.709 .794 .917 r
.903 .38452 .90781 .39079 .9204 .38557 .91561 .37901 Mtetra
.701 .782 .914 r
.91561 .37901 .9204 .38557 .93306 .38055 .92829 .37375 Mtetra
.663 .741 .908 r
.34209 .54503 .3486 .55109 .35907 .54781 .35259 .54173 Mtetra
.35259 .54173 .35907 .54781 .36958 .54452 .36312 .53842 Mtetra
.36312 .53842 .36958 .54452 .38013 .54122 .3737 .53509 Mtetra
.3737 .53509 .38013 .54122 .39072 .53791 .38431 .53176 Mtetra
.38431 .53176 .39072 .53791 .40135 .53459 .39497 .52842 Mtetra
.39497 .52842 .40135 .53459 .41203 .53126 .40568 .52507 Mtetra
.662 .742 .909 r
.40568 .52507 .41203 .53126 .42275 .52793 .41642 .52173 Mtetra
.41642 .52173 .42275 .52793 .43351 .5246 .42721 .51838 Mtetra
.661 .742 .91 r
.42721 .51838 .43351 .5246 .44431 .52127 .43804 .51505 Mtetra
.66 .742 .911 r
.43804 .51505 .44431 .52127 .45516 .51795 .44891 .51174 Mtetra
.658 .743 .913 r
.44891 .51174 .45516 .51795 .46605 .51466 .45983 .50846 Mtetra
.655 .743 .915 r
.45983 .50846 .46605 .51466 .47698 .5114 .47079 .50525 Mtetra
.652 .745 .918 r
.47079 .50525 .47698 .5114 .48796 .5082 .4818 .50211 Mtetra
.647 .746 .922 r
.4818 .50211 .48796 .5082 .49898 .50507 .49285 .49908 Mtetra
.641 .748 .927 r
.49285 .49908 .49898 .50507 .51005 .50205 .50394 .49618 Mtetra
.632 .751 .933 r
.50394 .49618 .51005 .50205 .52117 .49915 .51509 .49347 Mtetra
.621 .755 .942 r
.51509 .49347 .52117 .49915 .53234 .49642 .52629 .49098 Mtetra
.606 .759 .952 r
.52629 .49098 .53234 .49642 .54356 .49389 .53754 .48874 Mtetra
.586 .764 .964 r
.53754 .48874 .54356 .49389 .55483 .49158 .54885 .4868 Mtetra
.559 .77 .977 r
.54885 .4868 .55483 .49158 .56616 .48952 .56022 .48519 Mtetra
.522 .775 .989 r
.56022 .48519 .56616 .48952 .57755 .48774 .57165 .48393 Mtetra
.473 .776 .997 r
.57165 .48393 .57755 .48774 .58901 .48624 .58316 .48303 Mtetra
.407 .771 .994 r
.58316 .48303 .58901 .48624 .60053 .48501 .59474 .48247 Mtetra
.324 .752 .972 r
.59474 .48247 .60053 .48501 .61213 .48404 .60639 .4822 Mtetra
.225 .715 .922 r
.60639 .4822 .61213 .48404 .6238 .48326 .61813 .48218 Mtetra
.119 .66 .843 r
.61813 .48218 .6238 .48326 .63554 .48262 .62994 .48229 Mtetra
.023 .595 .744 r
.62994 .48229 .63554 .48262 .64735 .48202 .64183 .48243 Mtetra
.051 0 0 r
.64183 .48243 .64735 .48202 .65923 .48137 .6538 .48246 Mtetra
.098 0 0 r
.6538 .48246 .65923 .48137 .67118 .48053 .66583 .48222 Mtetra
.117 0 0 r
.66583 .48222 .67118 .48053 .68318 .47939 .67791 .48156 Mtetra
.11 0 0 r
.67791 .48156 .68318 .47939 .69523 .47783 .69005 .48034 Mtetra
.079 0 0 r
.69005 .48034 .69523 .47783 .70732 .47575 .70221 .47842 Mtetra
.023 0 0 r
.70221 .47842 .70732 .47575 .71943 .47305 .7144 .47572 Mtetra
0 0 0 r
.7144 .47572 .71943 .47305 .73157 .46968 .72659 .47217 Mtetra
.72659 .47217 .73157 .46968 .74371 .46563 .73879 .46777 Mtetra
.73879 .46777 .74371 .46563 .75585 .46091 .75097 .46255 Mtetra
.402 .844 .732 r
.75097 .46255 .75585 .46091 .768 .45557 .76315 .45657 Mtetra
.522 .915 .81 r
.76315 .45657 .768 .45557 .78015 .44968 .77531 .44996 Mtetra
.621 .96 .871 r
.77531 .44996 .78015 .44968 .79229 .44336 .78747 .44284 Mtetra
.692 .976 .91 r
.78747 .44284 .79229 .44336 .80445 .43672 .79962 .43538 Mtetra
.737 .971 .931 r
.79962 .43538 .80445 .43672 .81662 .42988 .81179 .42772 Mtetra
.76 .952 .938 r
.81179 .42772 .81662 .42988 .82881 .42296 .82397 .42 Mtetra
.769 .927 .938 r
.82397 .42 .82881 .42296 .84104 .41606 .83619 .41237 Mtetra
.767 .9 .935 r
.83619 .41237 .84104 .41606 .85331 .40929 .84846 .40492 Mtetra
.761 .875 .93 r
.84846 .40492 .85331 .40929 .86564 .40272 .86078 .39774 Mtetra
.751 .851 .925 r
.86078 .39774 .86564 .40272 .87802 .39638 .87316 .39088 Mtetra
.74 .83 .921 r
.87316 .39088 .87802 .39638 .89048 .39031 .88562 .38436 Mtetra
.728 .812 .917 r
.88562 .38436 .89048 .39031 .903 .38452 .89816 .3782 Mtetra
.717 .797 .914 r
.89816 .3782 .903 .38452 .91561 .37901 .91077 .37238 Mtetra
.707 .784 .912 r
.91077 .37238 .91561 .37901 .92829 .37375 .92347 .36688 Mtetra
.663 .741 .908 r
.33554 .53892 .34209 .54503 .35259 .54173 .34605 .5356 Mtetra
.34605 .5356 .35259 .54173 .36312 .53842 .35661 .53227 Mtetra
.35661 .53227 .36312 .53842 .3737 .53509 .36722 .52892 Mtetra
.36722 .52892 .3737 .53509 .38431 .53176 .37786 .52557 Mtetra
.37786 .52557 .38431 .53176 .39497 .52842 .38855 .52221 Mtetra
.663 .741 .909 r
.38855 .52221 .39497 .52842 .40568 .52507 .39927 .51884 Mtetra
.662 .742 .909 r
.39927 .51884 .40568 .52507 .41642 .52173 .41005 .51548 Mtetra
.661 .742 .91 r
.41005 .51548 .41642 .52173 .42721 .51838 .42086 .51213 Mtetra
.66 .742 .911 r
.42086 .51213 .42721 .51838 .43804 .51505 .43172 .5088 Mtetra
.658 .742 .912 r
.43172 .5088 .43804 .51505 .44891 .51174 .44262 .50551 Mtetra
.656 .743 .914 r
.44262 .50551 .44891 .51174 .45983 .50846 .45356 .50227 Mtetra
.652 .744 .917 r
.45356 .50227 .45983 .50846 .47079 .50525 .46455 .4991 Mtetra
.648 .745 .921 r
.46455 .4991 .47079 .50525 .4818 .50211 .47558 .49605 Mtetra
.641 .747 .926 r
.47558 .49605 .4818 .50211 .49285 .49908 .48666 .49314 Mtetra
.632 .749 .932 r
.48666 .49314 .49285 .49908 .50394 .49618 .49779 .49042 Mtetra
.62 .752 .941 r
.49779 .49042 .50394 .49618 .51509 .49347 .50896 .48794 Mtetra
.604 .756 .951 r
.50896 .48794 .51509 .49347 .52629 .49098 .52019 .48573 Mtetra
.583 .76 .963 r
.52019 .48573 .52629 .49098 .53754 .48874 .53148 .48387 Mtetra
.553 .765 .976 r
.53148 .48387 .53754 .48874 .54885 .4868 .54282 .48238 Mtetra
.511 .767 .989 r
.54282 .48238 .54885 .4868 .56022 .48519 .55423 .48131 Mtetra
.454 .765 .996 r
.55423 .48131 .56022 .48519 .57165 .48393 .56571 .48067 Mtetra
.375 .753 .99 r
.56571 .48067 .57165 .48393 .58316 .48303 .57726 .48047 Mtetra
.272 .722 .958 r
.57726 .48047 .58316 .48303 .59474 .48247 .5889 .48068 Mtetra
.148 .666 .889 r
.5889 .48068 .59474 .48247 .60639 .4822 .60062 .48124 Mtetra
.018 .586 .782 r
.60062 .48124 .60639 .4822 .61813 .48218 .61242 .48206 Mtetra
.097 0 0 r
.61242 .48206 .61813 .48218 .62994 .48229 .62431 .48303 Mtetra
.183 0 0 r
.62431 .48303 .62994 .48229 .64183 .48243 .63629 .48398 Mtetra
.236 0 0 r
.63629 .48398 .64183 .48243 .6538 .48246 .64834 .48474 Mtetra
.259 0 0 r
.64834 .48474 .6538 .48246 .66583 .48222 .66046 .48513 Mtetra
.257 0 0 r
.66046 .48513 .66583 .48222 .67791 .48156 .67263 .48495 Mtetra
.233 0 0 r
.67263 .48495 .67791 .48156 .69005 .48034 .68485 .48403 Mtetra
.186 0 0 r
.68485 .48403 .69005 .48034 .70221 .47842 .69709 .48223 Mtetra
.117 0 0 r
.69709 .48223 .70221 .47842 .7144 .47572 .70935 .47944 Mtetra
.024 0 0 r
.70935 .47944 .7144 .47572 .72659 .47217 .72161 .47561 Mtetra
0 0 0 r
.72161 .47561 .72659 .47217 .73879 .46777 .73385 .47074 Mtetra
.73385 .47074 .73879 .46777 .75097 .46255 .74607 .46488 Mtetra
.385 .82 .666 r
.74607 .46488 .75097 .46255 .76315 .45657 .75827 .45814 Mtetra
.526 .91 .764 r
.75827 .45814 .76315 .45657 .77531 .44996 .77045 .45067 Mtetra
.64 .965 .839 r
.77045 .45067 .77531 .44996 .78747 .44284 .78261 .44265 Mtetra
.719 .986 .887 r
.78261 .44265 .78747 .44284 .79962 .43538 .79476 .43426 Mtetra
.765 .98 .913 r
.79476 .43426 .79962 .43538 .81179 .42772 .80692 .42569 Mtetra
.786 .96 .923 r
.80692 .42569 .81179 .42772 .82397 .42 .81909 .41711 Mtetra
.791 .933 .925 r
.81909 .41711 .82397 .42 .83619 .41237 .8313 .40867 Mtetra
.787 .905 .923 r
.8313 .40867 .83619 .41237 .84846 .40492 .84355 .4005 Mtetra
.777 .878 .92 r
.84355 .4005 .84846 .40492 .86078 .39774 .85587 .39269 Mtetra
.765 .853 .917 r
.85587 .39269 .86078 .39774 .87316 .39088 .86825 .38529 Mtetra
.751 .832 .914 r
.86825 .38529 .87316 .39088 .88562 .38436 .88071 .37832 Mtetra
.737 .813 .911 r
.88071 .37832 .88562 .38436 .89816 .3782 .89326 .37178 Mtetra
.725 .798 .91 r
.89326 .37178 .89816 .3782 .91077 .37238 .90589 .36566 Mtetra
.713 .785 .908 r
.90589 .36566 .91077 .37238 .92347 .36688 .91861 .35991 Mtetra
.663 .741 .908 r
.32893 .53278 .33554 .53892 .34605 .5356 .33948 .52943 Mtetra
.33948 .52943 .34605 .5356 .35661 .53227 .35006 .52607 Mtetra
.35006 .52607 .35661 .53227 .36722 .52892 .36069 .52271 Mtetra
.36069 .52271 .36722 .52892 .37786 .52557 .37136 .51933 Mtetra
.663 .741 .909 r
.37136 .51933 .37786 .52557 .38855 .52221 .38207 .51595 Mtetra
.662 .741 .909 r
.38207 .51595 .38855 .52221 .39927 .51884 .39283 .51257 Mtetra
.661 .742 .909 r
.39283 .51257 .39927 .51884 .41005 .51548 .40362 .5092 Mtetra
.66 .742 .91 r
.40362 .5092 .41005 .51548 .42086 .51213 .41446 .50585 Mtetra
.659 .742 .912 r
.41446 .50585 .42086 .51213 .43172 .5088 .42535 .50253 Mtetra
.656 .743 .913 r
.42535 .50253 .43172 .5088 .44262 .50551 .43628 .49926 Mtetra
.653 .743 .916 r
.43628 .49926 .44262 .50551 .45356 .50227 .44725 .49607 Mtetra
.648 .744 .919 r
.44725 .49607 .45356 .50227 .46455 .4991 .45826 .49298 Mtetra
.642 .746 .924 r
.45826 .49298 .46455 .4991 .47558 .49605 .46932 .49003 Mtetra
.633 .748 .93 r
.46932 .49003 .47558 .49605 .48666 .49314 .48043 .48728 Mtetra
.622 .75 .938 r
.48043 .48728 .48666 .49314 .49779 .49042 .49158 .48477 Mtetra
.605 .753 .949 r
.49158 .48477 .49779 .49042 .50896 .48794 .50278 .48256 Mtetra
.583 .756 .961 r
.50278 .48256 .50896 .48794 .52019 .48573 .51404 .48071 Mtetra
.552 .759 .974 r
.51404 .48071 .52019 .48573 .53148 .48387 .52536 .47928 Mtetra
.508 .76 .987 r
.52536 .47928 .53148 .48387 .54282 .48238 .53674 .47832 Mtetra
.446 .755 .995 r
.53674 .47832 .54282 .48238 .55423 .48131 .54819 .47787 Mtetra
.359 .738 .988 r
.54819 .47787 .55423 .48131 .56571 .48067 .55971 .47795 Mtetra
.242 .699 .951 r
.55971 .47795 .56571 .48067 .57726 .48047 .57132 .47854 Mtetra
.099 .628 .871 r
.57132 .47854 .57726 .48047 .5889 .48068 .58301 .47962 Mtetra
0 .529 .745 r
.58301 .47962 .5889 .48068 .60062 .48124 .5948 .48109 Mtetra
.181 0 0 r
.5948 .48109 .60062 .48124 .61242 .48206 .60667 .48285 Mtetra
.275 0 0 r
.60667 .48285 .61242 .48206 .62431 .48303 .61864 .48473 Mtetra
.333 0 0 r
.61864 .48473 .62431 .48303 .63629 .48398 .6307 .48653 Mtetra
.359 0 0 r
.6307 .48653 .63629 .48398 .64834 .48474 .64284 .48805 Mtetra
.361 0 0 r
.64284 .48805 .64834 .48474 .66046 .48513 .65505 .48906 Mtetra
.342 0 0 r
.65505 .48906 .66046 .48513 .67263 .48495 .66731 .48933 Mtetra
.304 0 0 r
.66731 .48933 .67263 .48495 .68485 .48403 .67962 .48866 Mtetra
.244 0 0 r
.67962 .48866 .68485 .48403 .69709 .48223 .69194 .48689 Mtetra
.162 0 0 r
.69194 .48689 .69709 .48223 .70935 .47944 .70427 .48391 Mtetra
.052 0 0 r
.70427 .48391 .70935 .47944 .72161 .47561 .71658 .47967 Mtetra
0 0 0 r
.71658 .47967 .72161 .47561 .73385 .47074 .72887 .4742 Mtetra
.72887 .4742 .73385 .47074 .74607 .46488 .74113 .46758 Mtetra
.418 .831 .646 r
.74113 .46758 .74607 .46488 .75827 .45814 .75335 .45996 Mtetra
.57 .927 .752 r
.75335 .45996 .75827 .45814 .77045 .45067 .76553 .45152 Mtetra
.686 .979 .829 r
.76553 .45152 .77045 .45067 .78261 .44265 .77769 .44249 Mtetra
.76 .993 .875 r
.77769 .44249 .78261 .44265 .79476 .43426 .78984 .43309 Mtetra
.798 .982 .898 r
.78984 .43309 .79476 .43426 .80692 .42569 .80198 .42355 Mtetra
.813 .958 .907 r
.80198 .42355 .80692 .42569 .81909 .41711 .81415 .41406 Mtetra
.814 .93 .91 r
.81415 .41406 .81909 .41711 .8313 .40867 .82634 .4048 Mtetra
.805 .902 .909 r
.82634 .4048 .8313 .40867 .84355 .4005 .83859 .3959 Mtetra
.792 .875 .908 r
.83859 .3959 .84355 .4005 .85587 .39269 .8509 .38745 Mtetra
.777 .851 .907 r
.8509 .38745 .85587 .39269 .86825 .38529 .86328 .37951 Mtetra
.761 .83 .905 r
.86328 .37951 .86825 .38529 .88071 .37832 .87575 .3721 Mtetra
.745 .812 .905 r
.87575 .3721 .88071 .37832 .89326 .37178 .88831 .3652 Mtetra
.731 .797 .904 r
.88831 .3652 .89326 .37178 .90589 .36566 .90096 .35879 Mtetra
.718 .784 .904 r
.90096 .35879 .90589 .36566 .91861 .35991 .9137 .35281 Mtetra
.663 .741 .908 r
.32228 .52658 .32893 .53278 .33948 .52943 .33285 .52321 Mtetra
.33285 .52321 .33948 .52943 .35006 .52607 .34346 .51983 Mtetra
.34346 .51983 .35006 .52607 .36069 .52271 .35411 .51644 Mtetra
.35411 .51644 .36069 .52271 .37136 .51933 .36481 .51305 Mtetra
.662 .741 .909 r
.36481 .51305 .37136 .51933 .38207 .51595 .37555 .50965 Mtetra
.662 .742 .909 r
.37555 .50965 .38207 .51595 .39283 .51257 .38633 .50626 Mtetra
.661 .742 .91 r
.38633 .50626 .39283 .51257 .40362 .5092 .39715 .50289 Mtetra
.659 .742 .911 r
.39715 .50289 .40362 .5092 .41446 .50585 .40802 .49954 Mtetra
.657 .742 .913 r
.40802 .49954 .41446 .50585 .42535 .50253 .41893 .49623 Mtetra
.654 .743 .915 r
.41893 .49623 .42535 .50253 .43628 .49926 .42988 .493 Mtetra
.65 .743 .918 r
.42988 .493 .43628 .49926 .44725 .49607 .44088 .48987 Mtetra
.644 .745 .922 r
.44088 .48987 .44725 .49607 .45826 .49298 .45192 .48687 Mtetra
.636 .746 .928 r
.45192 .48687 .45826 .49298 .46932 .49003 .46301 .48406 Mtetra
.624 .748 .936 r
.46301 .48406 .46932 .49003 .48043 .48728 .47414 .4815 Mtetra
.608 .75 .945 r
.47414 .4815 .48043 .48728 .49158 .48477 .48532 .47923 Mtetra
.586 .752 .957 r
.48532 .47923 .49158 .48477 .50278 .48256 .49655 .47735 Mtetra
.555 .754 .97 r
.49655 .47735 .50278 .48256 .51404 .48071 .50784 .4759 Mtetra
.512 .754 .983 r
.50784 .4759 .51404 .48071 .52536 .47928 .51919 .47497 Mtetra
.449 .748 .992 r
.51919 .47497 .52536 .47928 .53674 .47832 .5306 .47461 Mtetra
.36 .729 .988 r
.5306 .47461 .53674 .47832 .54819 .47787 .54209 .47485 Mtetra
.237 .686 .954 r
.54209 .47485 .54819 .47787 .55971 .47795 .55366 .47572 Mtetra
.083 .609 .873 r
.55366 .47572 .55971 .47795 .57132 .47854 .56532 .47719 Mtetra
0 .5 .741 r
.56532 .47719 .57132 .47854 .58301 .47962 .57707 .4792 Mtetra
.227 0 0 r
.57707 .4792 .58301 .47962 .5948 .48109 .58892 .48164 Mtetra
.332 0 0 r
.58892 .48164 .5948 .48109 .60667 .48285 .60087 .48438 Mtetra
.396 0 0 r
.60087 .48438 .60667 .48285 .61864 .48473 .61292 .48719 Mtetra
.428 0 0 r
.61292 .48719 .61864 .48473 .6307 .48653 .62506 .48986 Mtetra
.434 0 0 r
.62506 .48986 .6307 .48653 .64284 .48805 .63729 .49212 Mtetra
.421 0 0 r
.63729 .49212 .64284 .48805 .65505 .48906 .64959 .4937 Mtetra
.389 0 0 r
.64959 .4937 .65505 .48906 .66731 .48933 .66194 .49435 Mtetra
.337 0 0 r
.66194 .49435 .66731 .48933 .67962 .48866 .67433 .49383 Mtetra
.264 0 0 r
.67433 .49383 .67962 .48866 .69194 .48689 .68673 .49198 Mtetra
.164 0 0 r
.68673 .49198 .69194 .48689 .70427 .48391 .69912 .48868 Mtetra
.031 0 0 r
.69912 .48868 .70427 .48391 .71658 .47967 .71149 .48391 Mtetra
0 0 0 r
.71149 .48391 .71658 .47967 .72887 .4742 .72382 .47771 Mtetra
.72382 .47771 .72887 .4742 .74113 .46758 .7361 .47021 Mtetra
.503 .88 .678 r
.7361 .47021 .74113 .46758 .75335 .45996 .74834 .46161 Mtetra
.652 .961 .775 r
.74834 .46161 .75335 .45996 .76553 .45152 .76053 .45212 Mtetra
.752 .994 .837 r
.76053 .45212 .76553 .45152 .77769 .44249 .77269 .44202 Mtetra
.808 .993 .87 r
.77269 .44202 .77769 .44249 .78984 .43309 .78483 .43157 Mtetra
.833 .974 .885 r
.78483 .43157 .78984 .43309 .80198 .42355 .79697 .42104 Mtetra
.838 .947 .891 r
.79697 .42104 .80198 .42355 .81415 .41406 .80912 .41064 Mtetra
.832 .918 .893 r
.80912 .41064 .81415 .41406 .82634 .4048 .82131 .40056 Mtetra
.82 .891 .894 r
.82131 .40056 .82634 .4048 .83859 .3959 .83355 .39095 Mtetra
.804 .866 .894 r
.83355 .39095 .83859 .3959 .8509 .38745 .84585 .3819 Mtetra
.786 .843 .895 r
.84585 .3819 .8509 .38745 .86328 .37951 .85824 .37345 Mtetra
.769 .824 .896 r
.85824 .37345 .86328 .37951 .87575 .3721 .87072 .36563 Mtetra
.752 .807 .897 r
.87072 .36563 .87575 .3721 .88831 .3652 .8833 .3584 Mtetra
.736 .793 .898 r
.8833 .3584 .88831 .3652 .90096 .35879 .89597 .35173 Mtetra
.722 .781 .9 r
.89597 .35173 .90096 .35879 .9137 .35281 .90873 .34555 Mtetra
.663 .741 .908 r
.31558 .52035 .32228 .52658 .33285 .52321 .32617 .51695 Mtetra
.32617 .51695 .33285 .52321 .34346 .51983 .33681 .51355 Mtetra
.33681 .51355 .34346 .51983 .35411 .51644 .34749 .51014 Mtetra
.663 .741 .909 r
.34749 .51014 .35411 .51644 .36481 .51305 .35821 .50673 Mtetra
.662 .741 .909 r
.35821 .50673 .36481 .51305 .37555 .50965 .36898 .50331 Mtetra
.661 .742 .91 r
.36898 .50331 .37555 .50965 .38633 .50626 .37978 .49991 Mtetra
.66 .742 .91 r
.37978 .49991 .38633 .50626 .39715 .50289 .39063 .49654 Mtetra
.658 .742 .912 r
.39063 .49654 .39715 .50289 .40802 .49954 .40153 .4932 Mtetra
.655 .742 .914 r
.40153 .4932 .40802 .49954 .41893 .49623 .41246 .48992 Mtetra
.651 .743 .916 r
.41246 .48992 .41893 .49623 .42988 .493 .42344 .48673 Mtetra
.646 .744 .92 r
.42344 .48673 .42988 .493 .44088 .48987 .43446 .48367 Mtetra
.638 .745 .925 r
.43446 .48367 .44088 .48987 .45192 .48687 .44553 .48078 Mtetra
.628 .746 .932 r
.44553 .48078 .45192 .48687 .46301 .48406 .45664 .47813 Mtetra
.613 .747 .941 r
.45664 .47813 .46301 .48406 .47414 .4815 .4678 .47578 Mtetra
.592 .749 .952 r
.4678 .47578 .47414 .4815 .48532 .47923 .479 .4738 Mtetra
.563 .75 .965 r
.479 .4738 .48532 .47923 .49655 .47735 .49026 .47228 Mtetra
.522 .749 .978 r
.49026 .47228 .49655 .47735 .50784 .4759 .50158 .47129 Mtetra
.463 .742 .989 r
.50158 .47129 .50784 .4759 .51919 .47497 .51296 .4709 Mtetra
.377 .724 .989 r
.51296 .4709 .51919 .47497 .5306 .47461 .52441 .47119 Mtetra
.257 .684 .964 r
.52441 .47119 .5306 .47461 .54209 .47485 .53594 .47218 Mtetra
.1 .609 .893 r
.53594 .47218 .54209 .47485 .55366 .47572 .54755 .47388 Mtetra
0 .498 .768 r
.54755 .47388 .55366 .47572 .56532 .47719 .55926 .47626 Mtetra
.235 0 0 r
.55926 .47626 .56532 .47719 .57707 .4792 .57106 .47924 Mtetra
.355 0 0 r
.57106 .47924 .57707 .4792 .58892 .48164 .58298 .48268 Mtetra
.431 0 0 r
.58298 .48268 .58892 .48164 .60087 .48438 .595 .48638 Mtetra
.472 0 0 r
.595 .48638 .60087 .48438 .61292 .48719 .60713 .49012 Mtetra
.485 0 0 r
.60713 .49012 .61292 .48719 .62506 .48986 .61935 .4936 Mtetra
.478 0 0 r
.61935 .4936 .62506 .48986 .63729 .49212 .63167 .49653 Mtetra
.452 0 0 r
.63167 .49653 .63729 .49212 .64959 .4937 .64405 .49859 Mtetra
.407 0 0 r
.64405 .49859 .64959 .4937 .66194 .49435 .65649 .4995 Mtetra
.341 0 0 r
.65649 .4995 .66194 .49435 .67433 .49383 .66895 .49901 Mtetra
.247 0 0 r
.66895 .49901 .67433 .49383 .68673 .49198 .68143 .49695 Mtetra
.119 0 0 r
.68143 .49695 .68673 .49198 .69912 .48868 .69388 .4932 Mtetra
0 0 0 r
.69388 .4932 .69912 .48868 .71149 .48391 .7063 .48777 Mtetra
.7063 .48777 .71149 .48391 .72382 .47771 .71866 .48074 Mtetra
.456 .847 .64 r
.71866 .48074 .72382 .47771 .7361 .47021 .73097 .47228 Mtetra
.631 .949 .748 r
.73097 .47228 .7361 .47021 .74834 .46161 .74322 .46261 Mtetra
.751 .993 .816 r
.74322 .46261 .74834 .46161 .76053 .45212 .75542 .45204 Mtetra
.819 .997 .851 r
.75542 .45204 .76053 .45212 .77269 .44202 .76758 .44085 Mtetra
.85 .979 .866 r
.76758 .44085 .77269 .44202 .78483 .43157 .77971 .42937 Mtetra
.859 .953 .872 r
.77971 .42937 .78483 .43157 .79697 .42104 .79184 .41786 Mtetra
.855 .925 .874 r
.79184 .41786 .79697 .42104 .80912 .41064 .80399 .4066 Mtetra
.844 .898 .876 r
.80399 .4066 .80912 .41064 .82131 .40056 .81617 .39576 Mtetra
.829 .873 .877 r
.81617 .39576 .82131 .40056 .83355 .39095 .82841 .3855 Mtetra
.811 .851 .88 r
.82841 .3855 .83355 .39095 .84585 .3819 .84073 .3759 Mtetra
.792 .832 .882 r
.84073 .3759 .84585 .3819 .85824 .37345 .85313 .36702 Mtetra
.774 .815 .885 r
.85313 .36702 .85824 .37345 .87072 .36563 .86562 .35884 Mtetra
.756 .8 .889 r
.86562 .35884 .87072 .36563 .8833 .3584 .87822 .35134 Mtetra
.739 .788 .892 r
.87822 .35134 .8833 .3584 .89597 .35173 .89091 .34445 Mtetra
.724 .777 .895 r
.89091 .34445 .89597 .35173 .90873 .34555 .90371 .3381 Mtetra
.663 .741 .908 r
.30883 .51406 .31558 .52035 .32617 .51695 .31945 .51065 Mtetra
.31945 .51065 .32617 .51695 .33681 .51355 .33011 .50722 Mtetra
.33011 .50722 .33681 .51355 .34749 .51014 .34081 .50379 Mtetra
.662 .741 .909 r
.34081 .50379 .34749 .51014 .35821 .50673 .35156 .50036 Mtetra
.35156 .50036 .35821 .50673 .36898 .50331 .36235 .49693 Mtetra
.661 .742 .91 r
.36235 .49693 .36898 .50331 .37978 .49991 .37319 .49352 Mtetra
.659 .742 .911 r
.37319 .49352 .37978 .49991 .39063 .49654 .38406 .49015 Mtetra
.657 .742 .913 r
.38406 .49015 .39063 .49654 .40153 .4932 .39498 .48682 Mtetra
.653 .742 .915 r
.39498 .48682 .40153 .4932 .41246 .48992 .40595 .48357 Mtetra
.648 .743 .918 r
.40595 .48357 .41246 .48992 .42344 .48673 .41695 .48044 Mtetra
.642 .743 .923 r
.41695 .48044 .42344 .48673 .43446 .48367 .428 .47747 Mtetra
.632 .744 .929 r
.428 .47747 .43446 .48367 .44553 .48078 .43909 .47471 Mtetra
.619 .745 .936 r
.43909 .47471 .44553 .48078 .45664 .47813 .45022 .47223 Mtetra
.6 .746 .946 r
.45022 .47223 .45664 .47813 .4678 .47578 .4614 .47012 Mtetra
.574 .746 .958 r
.4614 .47012 .4678 .47578 .479 .4738 .47264 .46845 Mtetra
.537 .745 .972 r
.47264 .46845 .479 .4738 .49026 .47228 .48392 .46732 Mtetra
.483 .739 .984 r
.48392 .46732 .49026 .47228 .50158 .47129 .49526 .46681 Mtetra
.406 .723 .989 r
.49526 .46681 .50158 .47129 .51296 .4709 .50667 .467 Mtetra
.296 .689 .975 r
.50667 .467 .51296 .4709 .52441 .47119 .51815 .46796 Mtetra
.148 .624 .924 r
.51815 .46796 .52441 .47119 .53594 .47218 .52972 .46972 Mtetra
0 .521 .818 r
.52972 .46972 .53594 .47218 .54755 .47388 .54137 .47227 Mtetra
.203 0 0 r
.54137 .47227 .54755 .47388 .55926 .47626 .55312 .47557 Mtetra
.344 0 0 r
.55312 .47557 .55926 .47626 .57106 .47924 .56499 .47949 Mtetra
.438 0 0 r
.56499 .47949 .57106 .47924 .58298 .48268 .57696 .48388 Mtetra
.493 0 0 r
.57696 .48388 .58298 .48268 .595 .48638 .58905 .48851 Mtetra
.516 0 0 r
.58905 .48851 .595 .48638 .60713 .49012 .60125 .49308 Mtetra
.517 0 0 r
.60125 .49308 .60713 .49012 .61935 .4936 .61356 .49728 Mtetra
.498 0 0 r
.61356 .49728 .61935 .4936 .63167 .49653 .62595 .50075 Mtetra
.46 0 0 r
.62595 .50075 .63167 .49653 .64405 .49859 .63842 .50316 Mtetra
.4 0 0 r
.63842 .50316 .64405 .49859 .65649 .4995 .65093 .50419 Mtetra
.311 0 0 r
.65093 .50419 .65649 .4995 .66895 .49901 .66347 .50359 Mtetra
.184 0 0 r
.66347 .50359 .66895 .49901 .68143 .49695 .676 .50117 Mtetra
.01 0 0 r
.676 .50117 .68143 .49695 .69388 .4932 .68851 .49685 Mtetra
0 0 0 r
.68851 .49685 .69388 .4932 .7063 .48777 .70097 .49065 Mtetra
.439 .844 .656 r
.70097 .49065 .7063 .48777 .71866 .48074 .71337 .48271 Mtetra
.633 .952 .763 r
.71337 .48271 .71866 .48074 .73097 .47228 .7257 .47323 Mtetra
.763 .996 .822 r
.7257 .47323 .73097 .47228 .74322 .46261 .73796 .46249 Mtetra
.834 .995 .847 r
.73796 .46249 .74322 .46261 .75542 .45204 .75017 .45083 Mtetra
.866 .974 .855 r
.75017 .45083 .75542 .45204 .76758 .44085 .76233 .43861 Mtetra
.876 .947 .856 r
.76233 .43861 .76758 .44085 .77971 .42937 .77446 .42615 Mtetra
.873 .919 .855 r
.77446 .42615 .77971 .42937 .79184 .41786 .78659 .41376 Mtetra
.863 .894 .856 r
.78659 .41376 .79184 .41786 .80399 .4066 .79873 .40172 Mtetra
.848 .871 .857 r
.79873 .40172 .80399 .4066 .81617 .39576 .81092 .39022 Mtetra
.831 .85 .861 r
.81092 .39022 .81617 .39576 .82841 .3855 .82317 .37941 Mtetra
.813 .833 .865 r
.82317 .37941 .82841 .3855 .84073 .3759 .8355 .36937 Mtetra
.794 .817 .87 r
.8355 .36937 .84073 .3759 .85313 .36702 .84792 .36013 Mtetra
.775 .803 .875 r
.84792 .36013 .85313 .36702 .86562 .35884 .86044 .35167 Mtetra
.757 .791 .88 r
.86044 .35167 .86562 .35884 .87822 .35134 .87307 .34396 Mtetra
.74 .781 .885 r
.87307 .34396 .87822 .35134 .89091 .34445 .8858 .33691 Mtetra
.725 .772 .89 r
.8858 .33691 .89091 .34445 .90371 .3381 .89863 .33045 Mtetra
.663 .741 .908 r
.30202 .50773 .30883 .51406 .31945 .51065 .31267 .50429 Mtetra
.31267 .50429 .31945 .51065 .33011 .50722 .32336 .50084 Mtetra
.663 .741 .909 r
.32336 .50084 .33011 .50722 .34081 .50379 .33409 .49739 Mtetra
.662 .741 .909 r
.33409 .49739 .34081 .50379 .35156 .50036 .34487 .49394 Mtetra
.661 .741 .909 r
.34487 .49394 .35156 .50036 .36235 .49693 .35568 .49051 Mtetra
.66 .741 .91 r
.35568 .49051 .36235 .49693 .37319 .49352 .36654 .48709 Mtetra
.658 .742 .912 r
.36654 .48709 .37319 .49352 .38406 .49015 .37744 .48372 Mtetra
.655 .742 .914 r
.37744 .48372 .38406 .49015 .39498 .48682 .38839 .48041 Mtetra
.651 .742 .916 r
.38839 .48041 .39498 .48682 .40595 .48357 .39938 .4772 Mtetra
.645 .742 .92 r
.39938 .4772 .40595 .48357 .41695 .48044 .41041 .47413 Mtetra
.637 .743 .925 r
.41041 .47413 .41695 .48044 .428 .47747 .42148 .47126 Mtetra
.625 .743 .932 r
.42148 .47126 .428 .47747 .43909 .47471 .43259 .46863 Mtetra
.609 .744 .94 r
.43259 .46863 .43909 .47471 .45022 .47223 .44375 .46635 Mtetra
.586 .743 .951 r
.44375 .46635 .45022 .47223 .4614 .47012 .45496 .46448 Mtetra
.554 .742 .964 r
.45496 .46448 .4614 .47012 .47264 .46845 .46621 .46314 Mtetra
.508 .736 .976 r
.46621 .46314 .47264 .46845 .48392 .46732 .47752 .46241 Mtetra
.442 .724 .986 r
.47752 .46241 .48392 .46732 .49526 .46681 .48889 .46239 Mtetra
.347 .697 .983 r
.48889 .46239 .49526 .46681 .50667 .467 .50032 .46316 Mtetra
.216 .646 .953 r
.50032 .46316 .50667 .467 .51815 .46796 .51183 .46479 Mtetra
.05 .56 .878 r
.51183 .46479 .51815 .46796 .52972 .46972 .52343 .4673 Mtetra
0 .439 .751 r
.52343 .4673 .52972 .46972 .54137 .47227 .53512 .47067 Mtetra
.293 0 0 r
.53512 .47067 .54137 .47227 .55312 .47557 .54692 .47483 Mtetra
.412 0 0 r
.54692 .47483 .55312 .47557 .56499 .47949 .55884 .47963 Mtetra
.486 0 0 r
.55884 .47963 .56499 .47949 .57696 .48388 .57087 .48489 Mtetra
.526 0 0 r
.57087 .48489 .57696 .48388 .58905 .48851 .58302 .49031 Mtetra
.538 0 0 r
.58302 .49031 .58905 .48851 .60125 .49308 .59529 .49558 Mtetra
.529 0 0 r
.59529 .49558 .60125 .49308 .61356 .49728 .60766 .50034 Mtetra
.498 0 0 r
.60766 .50034 .61356 .49728 .62595 .50075 .62013 .50419 Mtetra
.444 0 0 r
.62013 .50419 .62595 .50075 .63842 .50316 .63266 .50678 Mtetra
.358 0 0 r
.63266 .50678 .63842 .50316 .65093 .50419 .64525 .50776 Mtetra
.229 0 0 r
.64525 .50776 .65093 .50419 .66347 .50359 .65785 .50688 Mtetra
.043 0 0 r
.65785 .50688 .66347 .50359 .676 .50117 .67043 .50397 Mtetra
0 0 0 r
.67043 .50397 .676 .50117 .68851 .49685 .68299 .49896 Mtetra
.453 .869 .728 r
.68299 .49896 .68851 .49685 .70097 .49065 .69548 .49193 Mtetra
.657 .97 .82 r
.69548 .49193 .70097 .49065 .71337 .48271 .70791 .48303 Mtetra
.784 .997 .855 r
.70791 .48303 .71337 .48271 .7257 .47323 .72026 .47253 Mtetra
.849 .985 .859 r
.72026 .47253 .7257 .47323 .73796 .46249 .73254 .46077 Mtetra
.877 .958 .853 r
.73254 .46077 .73796 .46249 .75017 .45083 .74475 .44811 Mtetra
.885 .929 .844 r
.74475 .44811 .75017 .45083 .76233 .43861 .75691 .43494 Mtetra
.882 .902 .838 r
.75691 .43494 .76233 .43861 .77446 .42615 .76905 .42163 Mtetra
.873 .878 .836 r
.76905 .42163 .77446 .42615 .78659 .41376 .78119 .4085 Mtetra
.861 .858 .836 r
.78119 .4085 .78659 .41376 .79873 .40172 .79335 .39583 Mtetra
.846 .84 .839 r
.79335 .39583 .79873 .40172 .81092 .39022 .80555 .38381 Mtetra
.829 .825 .845 r
.80555 .38381 .81092 .39022 .82317 .37941 .81782 .37258 Mtetra
.811 .812 .851 r
.81782 .37258 .82317 .37941 .8355 .36937 .83018 .36222 Mtetra
.793 .8 .858 r
.83018 .36222 .8355 .36937 .84792 .36013 .84263 .35273 Mtetra
.774 .79 .866 r
.84263 .35273 .84792 .36013 .86044 .35167 .85518 .3441 Mtetra
.757 .781 .873 r
.85518 .3441 .86044 .35167 .87307 .34396 .86784 .33625 Mtetra
.74 .773 .879 r
.86784 .33625 .87307 .34396 .8858 .33691 .88061 .32911 Mtetra
.725 .766 .885 r
.88061 .32911 .8858 .33691 .89863 .33045 .89349 .32258 Mtetra
.663 .741 .908 r
.29517 .50136 .30202 .50773 .31267 .50429 .30584 .49789 Mtetra
.30584 .49789 .31267 .50429 .32336 .50084 .31656 .49442 Mtetra
.662 .741 .909 r
.31656 .49442 .32336 .50084 .33409 .49739 .32732 .49095 Mtetra
.32732 .49095 .33409 .49739 .34487 .49394 .33812 .48749 Mtetra
.661 .741 .91 r
.33812 .48749 .34487 .49394 .35568 .49051 .34896 .48404 Mtetra
.659 .741 .911 r
.34896 .48404 .35568 .49051 .36654 .48709 .35985 .48062 Mtetra
.657 .741 .912 r
.35985 .48062 .36654 .48709 .37744 .48372 .37077 .47725 Mtetra
.653 .742 .914 r
.37077 .47725 .37744 .48372 .38839 .48041 .38174 .47397 Mtetra
.648 .742 .917 r
.38174 .47397 .38839 .48041 .39938 .4772 .39276 .4708 Mtetra
.641 .742 .922 r
.39276 .4708 .39938 .4772 .41041 .47413 .40381 .4678 Mtetra
.632 .742 .927 r
.40381 .4678 .41041 .47413 .42148 .47126 .41491 .46502 Mtetra
.618 .742 .935 r
.41491 .46502 .42148 .47126 .43259 .46863 .42604 .46254 Mtetra
.599 .741 .944 r
.42604 .46254 .43259 .46863 .44375 .46635 .43723 .46045 Mtetra
.572 .739 .955 r
.43723 .46045 .44375 .46635 .45496 .46448 .44845 .45884 Mtetra
.534 .735 .967 r
.44845 .45884 .45496 .46448 .46621 .46314 .45973 .45781 Mtetra
.479 .725 .979 r
.45973 .45781 .46621 .46314 .47752 .46241 .47106 .45747 Mtetra
.402 .706 .984 r
.47106 .45747 .47752 .46241 .48889 .46239 .48245 .45793 Mtetra
.293 .668 .973 r
.48245 .45793 .48889 .46239 .50032 .46316 .49391 .45925 Mtetra
.148 .602 .93 r
.49391 .45925 .50032 .46316 .51183 .46479 .50545 .46151 Mtetra
0 .503 .841 r
.50545 .46151 .51183 .46479 .52343 .4673 .51708 .46471 Mtetra
0 .38 .71 r
.51708 .46471 .52343 .4673 .53512 .47067 .52881 .46881 Mtetra
.341 0 0 r
.52881 .46881 .53512 .47067 .54692 .47483 .54065 .47373 Mtetra
.443 0 0 r
.54065 .47373 .54692 .47483 .55884 .47963 .5526 .47929 Mtetra
.505 0 0 r
.5526 .47929 .55884 .47963 .57087 .48489 .56469 .48525 Mtetra
.534 0 0 r
.56469 .48525 .57087 .48489 .58302 .49031 .57689 .4913 Mtetra
.537 0 0 r
.57689 .4913 .58302 .49031 .59529 .49558 .58922 .49708 Mtetra
.515 0 0 r
.58922 .49708 .59529 .49558 .60766 .50034 .60165 .50219 Mtetra
.468 0 0 r
.60165 .50219 .60766 .50034 .62013 .50419 .61418 .50623 Mtetra
.384 0 0 r
.61418 .50623 .62013 .50419 .63266 .50678 .62678 .50879 Mtetra
.25 0 0 r
.62678 .50879 .63266 .50678 .64525 .50776 .63941 .50954 Mtetra
.048 0 0 r
.63941 .50954 .64525 .50776 .65785 .50688 .65206 .50823 Mtetra
.218 .735 .714 r
.65206 .50823 .65785 .50688 .67043 .50397 .6647 .50471 Mtetra
.49 .903 .845 r
.6647 .50471 .67043 .50397 .68299 .49896 .67729 .49895 Mtetra
.688 .977 .898 r
.67729 .49895 .68299 .49896 .69548 .49193 .68982 .49104 Mtetra
.8 .982 .897 r
.68982 .49104 .69548 .49193 .70791 .48303 .70227 .48121 Mtetra
.854 .957 .876 r
.70227 .48121 .70791 .48303 .72026 .47253 .71463 .46975 Mtetra
.876 .926 .854 r
.71463 .46975 .72026 .47253 .73254 .46077 .72693 .45706 Mtetra
.883 .897 .836 r
.72693 .45706 .73254 .46077 .74475 .44811 .73915 .44353 Mtetra
.881 .872 .824 r
.73915 .44353 .74475 .44811 .75691 .43494 .75133 .42958 Mtetra
.874 .851 .818 r
.75133 .42958 .75691 .43494 .76905 .42163 .76349 .4156 Mtetra
.864 .835 .816 r
.76349 .4156 .76905 .42163 .78119 .4085 .77564 .40191 Mtetra
.851 .821 .818 r
.77564 .40191 .78119 .4085 .79335 .39583 .78783 .3888 Mtetra
.837 .809 .823 r
.78783 .3888 .79335 .39583 .80555 .38381 .80006 .37644 Mtetra
.822 .799 .83 r
.80006 .37644 .80555 .38381 .81782 .37258 .81236 .36496 Mtetra
.805 .791 .839 r
.81236 .36496 .81782 .37258 .83018 .36222 .82475 .35441 Mtetra
.788 .783 .848 r
.82475 .35441 .83018 .36222 .84263 .35273 .83724 .34481 Mtetra
.771 .776 .857 r
.83724 .34481 .84263 .35273 .85518 .3441 .84984 .3361 Mtetra
.754 .77 .866 r
.84984 .3361 .85518 .3441 .86784 .33625 .86255 .32821 Mtetra
.738 .765 .874 r
.86255 .32821 .86784 .33625 .88061 .32911 .87536 .32105 Mtetra
.723 .76 .882 r
.87536 .32105 .88061 .32911 .89349 .32258 .88829 .31451 Mtetra
.663 .741 .908 r
.28827 .49493 .29517 .50136 .30584 .49789 .29897 .49144 Mtetra
.29897 .49144 .30584 .49789 .31656 .49442 .30971 .48795 Mtetra
.662 .741 .909 r
.30971 .48795 .31656 .49442 .32732 .49095 .32049 .48446 Mtetra
.661 .741 .909 r
.32049 .48446 .32732 .49095 .33812 .48749 .33132 .48098 Mtetra
.66 .741 .91 r
.33132 .48098 .33812 .48749 .34896 .48404 .34219 .47752 Mtetra
.658 .741 .911 r
.34219 .47752 .34896 .48404 .35985 .48062 .3531 .4741 Mtetra
.655 .741 .913 r
.3531 .4741 .35985 .48062 .37077 .47725 .36405 .47074 Mtetra
.652 .741 .915 r
.36405 .47074 .37077 .47725 .38174 .47397 .37505 .46748 Mtetra
.646 .741 .919 r
.37505 .46748 .38174 .47397 .39276 .4708 .38609 .46435 Mtetra
.638 .741 .923 r
.38609 .46435 .39276 .4708 .40381 .4678 .39716 .46142 Mtetra
.627 .741 .929 r
.39716 .46142 .40381 .4678 .41491 .46502 .40828 .45874 Mtetra
.611 .74 .937 r
.40828 .45874 .41491 .46502 .42604 .46254 .41944 .4564 Mtetra
.589 .738 .947 r
.41944 .4564 .42604 .46254 .43723 .46045 .43065 .45449 Mtetra
.558 .734 .958 r
.43065 .45449 .43723 .46045 .44845 .45884 .4419 .45312 Mtetra
.515 .727 .969 r
.4419 .45312 .44845 .45884 .45973 .45781 .4532 .45239 Mtetra
.453 .712 .979 r
.4532 .45239 .45973 .45781 .47106 .45747 .46455 .45242 Mtetra
.368 .686 .98 r
.46455 .45242 .47106 .45747 .48245 .45793 .47596 .4533 Mtetra
.251 .64 .962 r
.47596 .4533 .48245 .45793 .49391 .45925 .48744 .45512 Mtetra
.104 .566 .913 r
.48744 .45512 .49391 .45925 .50545 .46151 .49901 .45792 Mtetra
0 .465 .823 r
.49901 .45792 .50545 .46151 .51708 .46471 .51066 .46171 Mtetra
0 .35 .703 r
.51066 .46171 .51708 .46471 .52881 .46881 .52242 .46642 Mtetra
.349 0 0 r
.52242 .46642 .52881 .46881 .54065 .47373 .5343 .47194 Mtetra
.438 0 0 r
.5343 .47194 .54065 .47373 .5526 .47929 .54629 .47806 Mtetra
.49 0 0 r
.54629 .47806 .5526 .47929 .56469 .48525 .55842 .48453 Mtetra
.509 0 0 r
.55842 .48453 .56469 .48525 .57689 .4913 .57067 .49098 Mtetra
.5 0 0 r
.57067 .49098 .57689 .4913 .58922 .49708 .58304 .49704 Mtetra
.459 0 0 r
.58304 .49704 .58922 .49708 .60165 .50219 .59553 .50228 Mtetra
.377 0 0 r
.59553 .50228 .60165 .50219 .61418 .50623 .6081 .50627 Mtetra
.236 0 0 r
.6081 .50627 .61418 .50623 .62678 .50879 .62074 .50861 Mtetra
0 .562 .708 r
.62074 .50861 .62678 .50879 .63941 .50954 .63342 .50897 Mtetra
.26 .765 .868 r
.63342 .50897 .63941 .50954 .65206 .50823 .64611 .5071 Mtetra
.522 .901 .955 r
.64611 .5071 .65206 .50823 .6647 .50471 .65878 .50288 Mtetra
.698 .945 .959 r
.65878 .50288 .6647 .50471 .67729 .49895 .6714 .49632 Mtetra
.793 .935 .924 r
.6714 .49632 .67729 .49895 .68982 .49104 .68395 .48756 Mtetra
.839 .907 .884 r
.68395 .48756 .68982 .49104 .70227 .48121 .69642 .47685 Mtetra
.859 .878 .851 r
.69642 .47685 .70227 .48121 .71463 .46975 .70881 .46455 Mtetra
.867 .853 .826 r
.70881 .46455 .71463 .46975 .72693 .45706 .72112 .45108 Mtetra
.867 .832 .81 r
.72112 .45108 .72693 .45706 .73915 .44353 .73337 .43688 Mtetra
.864 .816 .801 r
.73337 .43688 .73915 .44353 .75133 .42958 .74557 .42237 Mtetra
.857 .804 .797 r
.74557 .42237 .75133 .42958 .76349 .4156 .75775 .40795 Mtetra
.848 .794 .798 r
.75775 .40795 .76349 .4156 .77564 .40191 .76994 .39393 Mtetra
.838 .786 .802 r
.76994 .39393 .77564 .40191 .78783 .3888 .78216 .38059 Mtetra
.826 .78 .809 r
.78216 .38059 .78783 .3888 .80006 .37644 .79444 .36808 Mtetra
.812 .775 .818 r
.79444 .36808 .80006 .37644 .81236 .36496 .80679 .35653 Mtetra
.797 .77 .829 r
.80679 .35653 .81236 .36496 .82475 .35441 .81923 .34596 Mtetra
.781 .767 .84 r
.81923 .34596 .82475 .35441 .83724 .34481 .83177 .33637 Mtetra
.765 .763 .851 r
.83177 .33637 .83724 .34481 .84984 .3361 .84442 .3277 Mtetra
.749 .76 .861 r
.84442 .3277 .84984 .3361 .86255 .32821 .85718 .31985 Mtetra
.734 .756 .87 r
.85718 .31985 .86255 .32821 .87536 .32105 .87005 .31273 Mtetra
.72 .753 .879 r
.87005 .31273 .87536 .32105 .88829 .31451 .88303 .30623 Mtetra
.663 .741 .908 r
.28131 .48846 .28827 .49493 .29897 .49144 .29204 .48495 Mtetra
.663 .741 .909 r
.29204 .48495 .29897 .49144 .30971 .48795 .3028 .48144 Mtetra
.662 .741 .909 r
.3028 .48144 .30971 .48795 .32049 .48446 .31361 .47793 Mtetra
.661 .741 .909 r
.31361 .47793 .32049 .48446 .33132 .48098 .32447 .47443 Mtetra
.66 .741 .91 r
.32447 .47443 .33132 .48098 .34219 .47752 .33536 .47096 Mtetra
.657 .741 .912 r
.33536 .47096 .34219 .47752 .3531 .4741 .3463 .46753 Mtetra
.654 .741 .913 r
.3463 .46753 .3531 .4741 .36405 .47074 .35728 .46418 Mtetra
.65 .741 .916 r
.35728 .46418 .36405 .47074 .37505 .46748 .3683 .46094 Mtetra
.643 .74 .92 r
.3683 .46094 .37505 .46748 .38609 .46435 .37936 .45785 Mtetra
.634 .74 .924 r
.37936 .45785 .38609 .46435 .39716 .46142 .39046 .45498 Mtetra
.622 .739 .931 r
.39046 .45498 .39716 .46142 .40828 .45874 .40161 .45239 Mtetra
.604 .737 .938 r
.40161 .45239 .40828 .45874 .41944 .4564 .41279 .45018 Mtetra
.58 .734 .948 r
.41279 .45018 .41944 .4564 .43065 .45449 .42402 .44844 Mtetra
.546 .728 .959 r
.42402 .44844 .43065 .45449 .4419 .45312 .43529 .44728 Mtetra
.499 .717 .969 r
.43529 .44728 .4419 .45312 .4532 .45239 .44661 .44682 Mtetra
.433 .699 .976 r
.44661 .44682 .4532 .45239 .46455 .45242 .45798 .44715 Mtetra
.345 .667 .975 r
.45798 .44715 .46455 .45242 .47596 .4533 .46941 .44839 Mtetra
.229 .617 .954 r
.46941 .44839 .47596 .4533 .48744 .45512 .48092 .45061 Mtetra
.088 .543 .907 r
.48092 .45061 .48744 .45512 .49901 .45792 .49251 .45383 Mtetra
0 .449 .829 r
.49251 .45383 .49901 .45792 .51066 .46171 .50419 .45806 Mtetra
0 .349 .731 r
.50419 .45806 .51066 .46171 .52242 .46642 .51597 .4632 Mtetra
0 .26 .634 r
.51597 .4632 .52242 .46642 .5343 .47194 .52787 .46912 Mtetra
.389 0 0 r
.52787 .46912 .5343 .47194 .54629 .47806 .5399 .47559 Mtetra
.428 0 0 r
.5399 .47559 .54629 .47806 .55842 .48453 .55206 .48232 Mtetra
.431 0 0 r
.55206 .48232 .55842 .48453 .57067 .49098 .56435 .48893 Mtetra
.397 0 0 r
.56435 .48893 .57067 .49098 .58304 .49704 .57676 .49502 Mtetra
.316 0 0 r
.57676 .49502 .58304 .49704 .59553 .50228 .58928 .50015 Mtetra
0 .409 .71 r
.58928 .50015 .59553 .50228 .6081 .50627 .60189 .50388 Mtetra
.041 .579 .851 r
.60189 .50388 .6081 .50627 .62074 .50861 .61457 .50582 Mtetra
.297 .74 .963 r
.61457 .50582 .62074 .50861 .63342 .50897 .62728 .50563 Mtetra
.522 .838 .999 r
.62728 .50563 .63342 .50897 .64611 .5071 .63999 .5031 Mtetra
.673 .867 .973 r
.63999 .5031 .64611 .5071 .65878 .50288 .65269 .49813 Mtetra
.758 .86 .925 r
.65269 .49813 .65878 .50288 .6714 .49632 .66533 .49077 Mtetra
.804 .84 .878 r
.66533 .49077 .6714 .49632 .68395 .48756 .6779 .4812 Mtetra
.827 .819 .841 r
.6779 .4812 .68395 .48756 .69642 .47685 .69039 .46973 Mtetra
.839 .801 .815 r
.69039 .46973 .69642 .47685 .70881 .46455 .70279 .45675 Mtetra
.844 .787 .796 r
.70279 .45675 .70881 .46455 .72112 .45108 .71513 .44272 Mtetra
.844 .775 .785 r
.71513 .44272 .72112 .45108 .73337 .43688 .7274 .42809 Mtetra
.842 .767 .78 r
.7274 .42809 .73337 .43688 .74557 .42237 .73964 .41328 Mtetra
.837 .761 .779 r
.73964 .41328 .74557 .42237 .75775 .40795 .75187 .39867 Mtetra
.83 .758 .782 r
.75187 .39867 .75775 .40795 .76994 .39393 .7641 .38458 Mtetra
.822 .755 .789 r
.7641 .38458 .76994 .39393 .78216 .38059 .77637 .37124 Mtetra
.812 .754 .798 r
.77637 .37124 .78216 .38059 .79444 .36808 .78871 .3588 Mtetra
.8 .753 .809 r
.78871 .3588 .79444 .36808 .80679 .35653 .80111 .34735 Mtetra
.787 .752 .821 r
.80111 .34735 .80679 .35653 .81923 .34596 .81362 .33691 Mtetra
.773 .752 .833 r
.81362 .33691 .81923 .34596 .83177 .33637 .82622 .32746 Mtetra
.758 .751 .846 r
.82622 .32746 .83177 .33637 .84442 .3277 .83893 .31892 Mtetra
.744 .75 .857 r
.83893 .31892 .84442 .3277 .85718 .31985 .85175 .3112 Mtetra
.729 .749 .868 r
.85175 .3112 .85718 .31985 .87005 .31273 .86468 .30419 Mtetra
.716 .748 .877 r
.86468 .30419 .87005 .31273 .88303 .30623 .87772 .29778 Mtetra
.663 .741 .908 r
.2743 .48194 .28131 .48846 .29204 .48495 .28505 .4784 Mtetra
.662 .741 .909 r
.28505 .4784 .29204 .48495 .3028 .48144 .29585 .47487 Mtetra
.29585 .47487 .3028 .48144 .31361 .47793 .30668 .47134 Mtetra
.661 .741 .91 r
.30668 .47134 .31361 .47793 .32447 .47443 .31756 .46782 Mtetra
.659 .741 .911 r
.31756 .46782 .32447 .47443 .33536 .47096 .32848 .46434 Mtetra
.657 .741 .912 r
.32848 .46434 .33536 .47096 .3463 .46753 .33945 .46091 Mtetra
.653 .741 .914 r
.33945 .46091 .3463 .46753 .35728 .46418 .35045 .45757 Mtetra
.648 .74 .917 r
.35045 .45757 .35728 .46418 .3683 .46094 .3615 .45434 Mtetra
.641 .74 .92 r
.3615 .45434 .3683 .46094 .37936 .45785 .37259 .45129 Mtetra
.631 .738 .925 r
.37259 .45129 .37936 .45785 .39046 .45498 .38371 .44847 Mtetra
.618 .737 .931 r
.38371 .44847 .39046 .45498 .40161 .45239 .39488 .44596 Mtetra
.599 .734 .939 r
.39488 .44596 .40161 .45239 .41279 .45018 .40609 .44385 Mtetra
.573 .729 .948 r
.40609 .44385 .41279 .45018 .42402 .44844 .41733 .44225 Mtetra
.537 .721 .958 r
.41733 .44225 .42402 .44844 .43529 .44728 .42863 .44126 Mtetra
.488 .708 .967 r
.42863 .44126 .43529 .44728 .44661 .44682 .43996 .441 Mtetra
.422 .686 .973 r
.43996 .441 .44661 .44682 .45798 .44715 .45136 .44157 Mtetra
.336 .652 .969 r
.45136 .44157 .45798 .44715 .46941 .44839 .46281 .44307 Mtetra
.228 .602 .951 r
.46281 .44307 .46941 .44839 .48092 .45061 .47434 .44555 Mtetra
.103 .534 .912 r
.47434 .44555 .48092 .45061 .49251 .45383 .48595 .44905 Mtetra
0 .454 .853 r
.48595 .44905 .49251 .45383 .50419 .45806 .49765 .45354 Mtetra
0 .374 .784 r
.49765 .45354 .50419 .45806 .51597 .4632 .50946 .45891 Mtetra
0 .307 .72 r
.50946 .45891 .51597 .4632 .52787 .46912 .52138 .465 Mtetra
0 .264 .676 r
.52138 .465 .52787 .46912 .5399 .47559 .53344 .47158 Mtetra
0 .251 .661 r
.53344 .47158 .5399 .47559 .55206 .48232 .54562 .47832 Mtetra
0 .274 .68 r
.54562 .47832 .55206 .48232 .56435 .48893 .55793 .48484 Mtetra
0 .335 .737 r
.55793 .48484 .56435 .48893 .57676 .49502 .57037 .49074 Mtetra
0 .434 .823 r
.57037 .49074 .57676 .49502 .58928 .50015 .58292 .49555 Mtetra
.107 .556 .914 r
.58292 .49555 .58928 .50015 .60189 .50388 .59555 .49885 Mtetra
.313 .67 .975 r
.59555 .49885 .60189 .50388 .61457 .50582 .60825 .50023 Mtetra
.496 .743 .983 r
.60825 .50023 .61457 .50582 .62728 .50563 .62098 .49938 Mtetra
.627 .773 .951 r
.62098 .49938 .62728 .50563 .63999 .5031 .63371 .49609 Mtetra
.709 .777 .905 r
.63371 .49609 .63999 .5031 .65269 .49813 .64642 .49032 Mtetra
.758 .769 .862 r
.64642 .49032 .65269 .49813 .66533 .49077 .65907 .48217 Mtetra
.787 .758 .827 r
.65907 .48217 .66533 .49077 .6779 .4812 .67166 .47188 Mtetra
.804 .748 .8 r
.67166 .47188 .6779 .4812 .69039 .46973 .68416 .4598 Mtetra
.813 .739 .782 r
.68416 .4598 .69039 .46973 .70279 .45675 .6966 .44636 Mtetra
.818 .733 .771 r
.6966 .44636 .70279 .45675 .71513 .44272 .70896 .43202 Mtetra
.82 .729 .764 r
.70896 .43202 .71513 .44272 .7274 .42809 .72127 .41723 Mtetra
.819 .727 .763 r
.72127 .41723 .7274 .42809 .73964 .41328 .73356 .40241 Mtetra
.817 .727 .765 r
.73356 .40241 .73964 .41328 .75187 .39867 .74583 .38789 Mtetra
.812 .727 .771 r
.74583 .38789 .75187 .39867 .7641 .38458 .75813 .37397 Mtetra
.806 .729 .779 r
.75813 .37397 .7641 .38458 .77637 .37124 .77047 .36086 Mtetra
.798 .731 .79 r
.77047 .36086 .77637 .37124 .78871 .3588 .78287 .34868 Mtetra
.788 .734 .803 r
.78287 .34868 .78871 .3588 .80111 .34735 .79535 .33751 Mtetra
.776 .736 .816 r
.79535 .33751 .80111 .34735 .81362 .33691 .80792 .32735 Mtetra
.764 .739 .83 r
.80792 .32735 .81362 .33691 .82622 .32746 .82059 .31815 Mtetra
.75 .74 .843 r
.82059 .31815 .82622 .32746 .83893 .31892 .83337 .30984 Mtetra
.737 .742 .855 r
.83337 .30984 .83893 .31892 .85175 .3112 .84626 .30231 Mtetra
.724 .743 .867 r
.84626 .30231 .85175 .3112 .86468 .30419 .85925 .29546 Mtetra
.712 .743 .876 r
.85925 .29546 .86468 .30419 .87772 .29778 .87235 .28917 Mtetra
.663 .741 .908 r
.26724 .47537 .2743 .48194 .28505 .4784 .27802 .47181 Mtetra
.662 .741 .909 r
.27802 .47181 .28505 .4784 .29585 .47487 .28884 .46825 Mtetra
.661 .741 .909 r
.28884 .46825 .29585 .47487 .30668 .47134 .2997 .4647 Mtetra
.66 .741 .91 r
.2997 .4647 .30668 .47134 .31756 .46782 .3106 .46117 Mtetra
.658 .741 .911 r
.3106 .46117 .31756 .46782 .32848 .46434 .32155 .45767 Mtetra
.656 .741 .912 r
.32155 .45767 .32848 .46434 .33945 .46091 .33254 .45424 Mtetra
.652 .74 .914 r
.33254 .45424 .33945 .46091 .35045 .45757 .34357 .45089 Mtetra
.647 .74 .917 r
.34357 .45089 .35045 .45757 .3615 .45434 .35465 .44768 Mtetra
.639 .738 .921 r
.35465 .44768 .3615 .45434 .37259 .45129 .36576 .44465 Mtetra
.629 .737 .925 r
.36576 .44465 .37259 .45129 .38371 .44847 .37691 .44187 Mtetra
.614 .734 .931 r
.37691 .44187 .38371 .44847 .39488 .44596 .3881 .43942 Mtetra
.595 .73 .939 r
.3881 .43942 .39488 .44596 .40609 .44385 .39933 .43738 Mtetra
.568 .724 .947 r
.39933 .43738 .40609 .44385 .41733 .44225 .4106 .43588 Mtetra
.532 .714 .956 r
.4106 .43588 .41733 .44225 .42863 .44126 .42191 .435 Mtetra
.484 .699 .964 r
.42191 .435 .42863 .44126 .43996 .441 .43327 .43487 Mtetra
.421 .676 .968 r
.43327 .43487 .43996 .441 .45136 .44157 .44469 .43558 Mtetra
.341 .641 .964 r
.44469 .43558 .45136 .44157 .46281 .44307 .45616 .43721 Mtetra
.247 .595 .95 r
.45616 .43721 .46281 .44307 .47434 .44555 .46771 .43983 Mtetra
.143 .537 .921 r
.46771 .43983 .47434 .44555 .48595 .44905 .47934 .44344 Mtetra
.04 .473 .882 r
.47934 .44344 .48595 .44905 .49765 .45354 .49106 .44799 Mtetra
0 .413 .84 r
.49106 .44799 .49765 .45354 .50946 .45891 .50289 .45338 Mtetra
0 .367 .805 r
.50289 .45338 .50946 .45891 .52138 .465 .51484 .45942 Mtetra
0 .342 .788 r
.51484 .45942 .52138 .465 .53344 .47158 .52691 .46588 Mtetra
0 .346 .793 r
.52691 .46588 .53344 .47158 .54562 .47832 .53911 .47242 Mtetra
0 .379 .822 r
.53911 .47242 .54562 .47832 .55793 .48484 .55144 .47867 Mtetra
.019 .44 .868 r
.55144 .47867 .55793 .48484 .57037 .49074 .56389 .48419 Mtetra
.156 .519 .917 r
.56389 .48419 .57037 .49074 .58292 .49555 .57646 .48853 Mtetra
.313 .598 .947 r
.57646 .48853 .58292 .49555 .59555 .49885 .5891 .49124 Mtetra
.461 .657 .946 r
.5891 .49124 .59555 .49885 .60825 .50023 .60181 .49191 Mtetra
.578 .691 .919 r
.60181 .49191 .60825 .50023 .62098 .49938 .61455 .49025 Mtetra
.659 .704 .88 r
.61455 .49025 .62098 .49938 .63371 .49609 .62729 .48611 Mtetra
.712 .706 .842 r
.62729 .48611 .63371 .49609 .64642 .49032 .64 .4795 Mtetra
.746 .702 .811 r
.64 .4795 .64642 .49032 .65907 .48217 .65266 .4706 Mtetra
.767 .698 .786 r
.65266 .4706 .65907 .48217 .67166 .47188 .66525 .4597 Mtetra
.781 .694 .769 r
.66525 .4597 .67166 .47188 .68416 .4598 .67778 .44721 Mtetra
.789 .692 .757 r
.67778 .44721 .68416 .4598 .6966 .44636 .69024 .43356 Mtetra
.795 .692 .751 r
.69024 .43356 .6966 .44636 .70896 .43202 .70264 .4192 Mtetra
.798 .693 .749 r
.70264 .4192 .70896 .43202 .72127 .41723 .715 .40454 Mtetra
.799 .695 .751 r
.715 .40454 .72127 .41723 .73356 .40241 .72734 .38998 Mtetra
.798 .699 .756 r
.72734 .38998 .73356 .40241 .74583 .38789 .73968 .37581 Mtetra
.795 .703 .763 r
.73968 .37581 .74583 .38789 .75813 .37397 .75205 .3623 Mtetra
.79 .708 .773 r
.75205 .3623 .75813 .37397 .77047 .36086 .76446 .34963 Mtetra
.784 .713 .786 r
.76446 .34963 .77047 .36086 .78287 .34868 .77694 .33789 Mtetra
.775 .718 .799 r
.77694 .33789 .78287 .34868 .79535 .33751 .7895 .32714 Mtetra
.765 .723 .814 r
.7895 .32714 .79535 .33751 .80792 .32735 .80215 .31737 Mtetra
.754 .728 .828 r
.80215 .31737 .80792 .32735 .82059 .31815 .8149 .30852 Mtetra
.742 .732 .842 r
.8149 .30852 .82059 .31815 .83337 .30984 .82775 .3005 Mtetra
.73 .735 .855 r
.82775 .3005 .83337 .30984 .84626 .30231 .84071 .29323 Mtetra
.718 .737 .867 r
.84071 .29323 .84626 .30231 .85925 .29546 .85377 .28658 Mtetra
.707 .739 .876 r
.85377 .28658 .85925 .29546 .87235 .28917 .86693 .28044 Mtetra
.663 .741 .908 r
.26013 .46875 .26724 .47537 .27802 .47181 .27093 .46516 Mtetra
.662 .741 .909 r
.27093 .46516 .27802 .47181 .28884 .46825 .28177 .46158 Mtetra
.661 .741 .909 r
.28177 .46158 .28884 .46825 .2997 .4647 .29266 .45801 Mtetra
.66 .741 .91 r
.29266 .45801 .2997 .4647 .3106 .46117 .30359 .45446 Mtetra
.658 .741 .911 r
.30359 .45446 .3106 .46117 .32155 .45767 .31457 .45095 Mtetra
.655 .74 .912 r
.31457 .45095 .32155 .45767 .33254 .45424 .32559 .4475 Mtetra
.651 .74 .914 r
.32559 .4475 .33254 .45424 .34357 .45089 .33664 .44415 Mtetra
.646 .739 .917 r
.33664 .44415 .34357 .45089 .35465 .44768 .34774 .44094 Mtetra
.638 .737 .92 r
.34774 .44094 .35465 .44768 .36576 .44465 .35888 .43792 Mtetra
.627 .735 .925 r
.35888 .43792 .36576 .44465 .37691 .44187 .37006 .43516 Mtetra
.612 .732 .931 r
.37006 .43516 .37691 .44187 .3881 .43942 .38127 .43273 Mtetra
.592 .727 .938 r
.38127 .43273 .3881 .43942 .39933 .43738 .39253 .43074 Mtetra
.566 .72 .945 r
.39253 .43074 .39933 .43738 .4106 .43588 .40382 .42928 Mtetra
.531 .708 .953 r
.40382 .42928 .4106 .43588 .42191 .435 .41515 .42845 Mtetra
.485 .692 .959 r
.41515 .42845 .42191 .435 .43327 .43487 .42654 .42836 Mtetra
.428 .668 .962 r
.42654 .42836 .43327 .43487 .44469 .43558 .43797 .42911 Mtetra
.359 .635 .959 r
.43797 .42911 .44469 .43558 .45616 .43721 .44947 .43076 Mtetra
.281 .594 .948 r
.44947 .43076 .45616 .43721 .46771 .43983 .46104 .43335 Mtetra
.199 .545 .929 r
.46104 .43335 .46771 .43983 .47934 .44344 .47268 .4369 Mtetra
.122 .495 .904 r
.47268 .4369 .47934 .44344 .49106 .44799 .48443 .44134 Mtetra
.059 .45 .88 r
.48443 .44134 .49106 .44799 .50289 .45338 .49627 .44656 Mtetra
.019 .418 .861 r
.49627 .44656 .50289 .45338 .51484 .45942 .50823 .4524 Mtetra
.008 .403 .853 r
.50823 .4524 .51484 .45942 .52691 .46588 .52032 .45859 Mtetra
.031 .41 .859 r
.52032 .45859 .52691 .46588 .53911 .47242 .53254 .46482 Mtetra
.09 .439 .877 r
.53254 .46482 .53911 .47242 .55144 .47867 .54488 .47068 Mtetra
.184 .488 .901 r
.54488 .47068 .55144 .47867 .56389 .48419 .55734 .47572 Mtetra
.303 .545 .917 r
.55734 .47572 .56389 .48419 .57646 .48853 .56991 .47943 Mtetra
.427 .596 .915 r
.56991 .47943 .57646 .48853 .5891 .49124 .58257 .48137 Mtetra
.535 .632 .893 r
.58257 .48137 .5891 .49124 .60181 .49191 .59528 .48113 Mtetra
.616 .65 .86 r
.59528 .48113 .60181 .49191 .61455 .49025 .60801 .47847 Mtetra
.672 .657 .826 r
.60801 .47847 .61455 .49025 .62729 .48611 .62074 .47335 Mtetra
.709 .657 .797 r
.62074 .47335 .62729 .48611 .64 .4795 .63345 .46586 Mtetra
.733 .656 .774 r
.63345 .46586 .64 .4795 .65266 .4706 .64611 .45627 Mtetra
.749 .655 .757 r
.64611 .45627 .65266 .4706 .66525 .4597 .65871 .44494 Mtetra
.761 .656 .746 r
.65871 .44494 .66525 .4597 .67778 .44721 .67126 .43228 Mtetra
.769 .658 .74 r
.67126 .43228 .67778 .44721 .69024 .43356 .68375 .4187 Mtetra
.775 .661 .738 r
.68375 .4187 .69024 .43356 .70264 .4192 .69619 .4046 Mtetra
.778 .666 .739 r
.69619 .4046 .70264 .4192 .715 .40454 .70861 .39036 Mtetra
.781 .671 .743 r
.70861 .39036 .715 .40454 .72734 .38998 .72102 .37631 Mtetra
.781 .678 .75 r
.72102 .37631 .72734 .38998 .73968 .37581 .73343 .36273 Mtetra
.779 .685 .759 r
.73343 .36273 .73968 .37581 .75205 .3623 .74588 .34983 Mtetra
.776 .692 .771 r
.74588 .34983 .75205 .3623 .76446 .34963 .75838 .33776 Mtetra
.77 .699 .784 r
.75838 .33776 .76446 .34963 .77694 .33789 .77094 .32661 Mtetra
.763 .707 .799 r
.77094 .32661 .77694 .33789 .7895 .32714 .78358 .31639 Mtetra
.754 .714 .814 r
.78358 .31639 .7895 .32714 .80215 .31737 .79632 .3071 Mtetra
.744 .72 .829 r
.79632 .3071 .80215 .31737 .8149 .30852 .80915 .29867 Mtetra
.733 .725 .844 r
.80915 .29867 .8149 .30852 .82775 .3005 .82208 .291 Mtetra
.722 .73 .857 r
.82208 .291 .82775 .3005 .84071 .29323 .83511 .28401 Mtetra
.711 .733 .868 r
.83511 .28401 .84071 .29323 .85377 .28658 .84824 .27759 Mtetra
.701 .736 .878 r
.84824 .27759 .85377 .28658 .86693 .28044 .86147 .27162 Mtetra
.663 .741 .908 r
.25296 .46208 .26013 .46875 .27093 .46516 .26379 .45847 Mtetra
.662 .741 .909 r
.26379 .45847 .27093 .46516 .28177 .46158 .27466 .45486 Mtetra
.661 .741 .909 r
.27466 .45486 .28177 .46158 .29266 .45801 .28557 .45126 Mtetra
.66 .741 .91 r
.28557 .45126 .29266 .45801 .30359 .45446 .29653 .44769 Mtetra
.658 .74 .911 r
.29653 .44769 .30359 .45446 .31457 .45095 .30753 .44416 Mtetra
.655 .74 .912 r
.30753 .44416 .31457 .45095 .32559 .4475 .31858 .4407 Mtetra
.651 .739 .914 r
.31858 .4407 .32559 .4475 .33664 .44415 .32966 .43733 Mtetra
.645 .738 .917 r
.32966 .43733 .33664 .44415 .34774 .44094 .34079 .43411 Mtetra
.637 .736 .92 r
.34079 .43411 .34774 .44094 .35888 .43792 .35195 .43109 Mtetra
.626 .734 .924 r
.35195 .43109 .35888 .43792 .37006 .43516 .36315 .42833 Mtetra
.612 .73 .929 r
.36315 .42833 .37006 .43516 .38127 .43273 .37439 .4259 Mtetra
.592 .724 .935 r
.37439 .4259 .38127 .43273 .39253 .43074 .38567 .42391 Mtetra
.567 .715 .942 r
.38567 .42391 .39253 .43074 .40382 .42928 .39699 .42243 Mtetra
.534 .703 .948 r
.39699 .42243 .40382 .42928 .41515 .42845 .40835 .42158 Mtetra
.493 .686 .953 r
.40835 .42158 .41515 .42845 .42654 .42836 .41976 .42145 Mtetra
.443 .662 .955 r
.41976 .42145 .42654 .42836 .43797 .42911 .43122 .42213 Mtetra
.385 .632 .952 r
.43122 .42213 .43797 .42911 .44947 .43076 .44273 .42367 Mtetra
.322 .595 .944 r
.44273 .42367 .44947 .43076 .46104 .43335 .45432 .42611 Mtetra
.257 .554 .93 r
.45432 .42611 .46104 .43335 .47268 .4369 .46599 .42947 Mtetra
.197 .512 .913 r
.46599 .42947 .47268 .4369 .48443 .44134 .47775 .43369 Mtetra
.148 .475 .896 r
.47775 .43369 .48443 .44134 .49627 .44656 .48961 .43867 Mtetra
.116 .447 .881 r
.48961 .43867 .49627 .44656 .50823 .4524 .50159 .44426 Mtetra
.108 .434 .874 r
.50159 .44426 .50823 .4524 .52032 .45859 .51368 .45018 Mtetra
.13 .441 .877 r
.51368 .45018 .52032 .45859 .53254 .46482 .52591 .45609 Mtetra
.188 .468 .888 r
.52591 .45609 .53254 .46482 .54488 .47068 .53826 .46151 Mtetra
.28 .512 .9 r
.53826 .46151 .54488 .47068 .55734 .47572 .55073 .46593 Mtetra
.392 .559 .9 r
.55073 .46593 .55734 .47572 .56991 .47943 .56331 .4688 Mtetra
.499 .596 .882 r
.56331 .4688 .56991 .47943 .58257 .48137 .57596 .46966 Mtetra
.583 .616 .851 r
.57596 .46966 .58257 .48137 .59528 .48113 .58866 .4682 Mtetra
.642 .624 .817 r
.58866 .4682 .59528 .48113 .60801 .47847 .60138 .4643 Mtetra
.68 .625 .787 r
.60138 .4643 .60801 .47847 .62074 .47335 .6141 .45805 Mtetra
.705 .625 .764 r
.6141 .45805 .62074 .47335 .63345 .46586 .62679 .4497 Mtetra
.722 .624 .748 r
.62679 .4497 .63345 .46586 .64611 .45627 .63945 .43958 Mtetra
.734 .625 .737 r
.63945 .43958 .64611 .45627 .65871 .44494 .65206 .42805 Mtetra
.744 .628 .731 r
.65206 .42805 .65871 .44494 .67126 .43228 .66463 .41549 Mtetra
.751 .633 .729 r
.66463 .41549 .67126 .43228 .68375 .4187 .67716 .40226 Mtetra
.757 .639 .73 r
.67716 .40226 .68375 .4187 .69619 .4046 .68966 .38869 Mtetra
.762 .646 .733 r
.68966 .38869 .69619 .4046 .70861 .39036 .70214 .37511 Mtetra
.765 .654 .74 r
.70214 .37511 .70861 .39036 .72102 .37631 .71462 .36179 Mtetra
.766 .662 .748 r
.71462 .36179 .72102 .37631 .73343 .36273 .72712 .34897 Mtetra
.765 .671 .759 r
.72712 .34897 .73343 .36273 .74588 .34983 .73965 .33683 Mtetra
.762 .68 .772 r
.73965 .33683 .74588 .34983 .75838 .33776 .75223 .3255 Mtetra
.758 .689 .786 r
.75223 .3255 .75838 .33776 .77094 .32661 .76489 .31502 Mtetra
.751 .698 .801 r
.76489 .31502 .77094 .32661 .78358 .31639 .77762 .30543 Mtetra
.744 .707 .817 r
.77762 .30543 .78358 .31639 .79632 .3071 .79044 .29667 Mtetra
.734 .714 .832 r
.79044 .29667 .79632 .3071 .80915 .29867 .80335 .28869 Mtetra
.725 .721 .846 r
.80335 .28869 .80915 .29867 .82208 .291 .81636 .28141 Mtetra
.715 .726 .859 r
.81636 .28141 .82208 .291 .83511 .28401 .82947 .27472 Mtetra
.705 .73 .871 r
.82947 .27472 .83511 .28401 .84824 .27759 .84267 .26853 Mtetra
.696 .734 .88 r
.84267 .26853 .84824 .27759 .86147 .27162 .85597 .26274 Mtetra
.663 .741 .908 r
.24573 .45535 .25296 .46208 .26379 .45847 .25659 .45172 Mtetra
.662 .741 .909 r
.25659 .45172 .26379 .45847 .27466 .45486 .26749 .44809 Mtetra
.661 .741 .909 r
.26749 .44809 .27466 .45486 .28557 .45126 .27843 .44446 Mtetra
.66 .741 .91 r
.27843 .44446 .28557 .45126 .29653 .44769 .28941 .44087 Mtetra
.658 .74 .911 r
.28941 .44087 .29653 .44769 .30753 .44416 .30044 .43731 Mtetra
.655 .74 .912 r
.30044 .43731 .30753 .44416 .31858 .4407 .31151 .43383 Mtetra
.651 .739 .914 r
.31151 .43383 .31858 .4407 .32966 .43733 .32262 .43044 Mtetra
.645 .737 .916 r
.32262 .43044 .32966 .43733 .34079 .43411 .33378 .4272 Mtetra
.637 .735 .919 r
.33378 .4272 .34079 .43411 .35195 .43109 .34497 .42415 Mtetra
.626 .732 .923 r
.34497 .42415 .35195 .43109 .36315 .42833 .3562 .42136 Mtetra
.612 .727 .927 r
.3562 .42136 .36315 .42833 .37439 .4259 .36746 .4189 Mtetra
.594 .721 .932 r
.36746 .4189 .37439 .4259 .38567 .42391 .37877 .41686 Mtetra
.57 .712 .938 r
.37877 .41686 .38567 .42391 .39699 .42243 .39011 .41533 Mtetra
.541 .699 .942 r
.39011 .41533 .39699 .42243 .40835 .42158 .4015 .41439 Mtetra
.504 .682 .946 r
.4015 .41439 .40835 .42158 .41976 .42145 .41293 .41413 Mtetra
.461 .659 .947 r
.41293 .41413 .41976 .42145 .43122 .42213 .42442 .41465 Mtetra
.412 .631 .944 r
.42442 .41465 .43122 .42213 .44273 .42367 .43596 .416 Mtetra
.357 .597 .937 r
.43596 .416 .44273 .42367 .45432 .42611 .44757 .41824 Mtetra
.3 .559 .927 r
.44757 .41824 .45432 .42611 .46599 .42947 .45925 .42139 Mtetra
.242 .52 .913 r
.45925 .42139 .46599 .42947 .47775 .43369 .47103 .42544 Mtetra
.189 .483 .897 r
.47103 .42544 .47775 .43369 .48961 .43867 .4829 .4303 Mtetra
.149 .455 .884 r
.4829 .4303 .48961 .43867 .50159 .44426 .49489 .43578 Mtetra
.135 .443 .878 r
.49489 .43578 .50159 .44426 .51368 .45018 .507 .44156 Mtetra
.159 .455 .883 r
.507 .44156 .51368 .45018 .52591 .45609 .51924 .44718 Mtetra
.232 .492 .896 r
.51924 .44718 .52591 .45609 .53826 .46151 .5316 .45205 Mtetra
.344 .542 .903 r
.5316 .45205 .53826 .46151 .55073 .46593 .54408 .45554 Mtetra
.463 .584 .889 r
.54408 .45554 .55073 .46593 .56331 .4688 .55665 .45712 Mtetra
.559 .606 .856 r
.55665 .45712 .56331 .4688 .57596 .46966 .56929 .45642 Mtetra
.623 .611 .817 r
.56929 .45642 .57596 .46966 .58866 .4682 .58197 .45332 Mtetra
.662 .608 .784 r
.58197 .45332 .58866 .4682 .60138 .4643 .59467 .44794 Mtetra
.686 .604 .759 r
.59467 .44794 .60138 .4643 .6141 .45805 .60737 .44054 Mtetra
.701 .602 .742 r
.60737 .44054 .6141 .45805 .62679 .4497 .62005 .43146 Mtetra
.712 .602 .731 r
.62005 .43146 .62679 .4497 .63945 .43958 .63271 .42105 Mtetra
.722 .604 .725 r
.63271 .42105 .63945 .43958 .65206 .42805 .64534 .40961 Mtetra
.73 .609 .723 r
.64534 .40961 .65206 .42805 .66463 .41549 .65794 .39744 Mtetra
.737 .616 .723 r
.65794 .39744 .66463 .41549 .67716 .40226 .67051 .38481 Mtetra
.743 .624 .727 r
.67051 .38481 .67716 .40226 .68966 .38869 .68307 .37199 Mtetra
.748 .632 .732 r
.68307 .37199 .68966 .38869 .70214 .37511 .69561 .35924 Mtetra
.751 .642 .74 r
.69561 .35924 .70214 .37511 .71462 .36179 .70817 .34681 Mtetra
.752 .652 .75 r
.70817 .34681 .71462 .36179 .72712 .34897 .72075 .33487 Mtetra
.752 .662 .762 r
.72075 .33487 .72712 .34897 .73965 .33683 .73337 .32359 Mtetra
.75 .673 .775 r
.73337 .32359 .73965 .33683 .75223 .3255 .74605 .31306 Mtetra
.746 .683 .79 r
.74605 .31306 .75223 .3255 .76489 .31502 .75879 .30333 Mtetra
.74 .693 .806 r
.75879 .30333 .76489 .31502 .77762 .30543 .77161 .29438 Mtetra
.733 .703 .822 r
.77161 .29438 .77762 .30543 .79044 .29667 .78452 .28619 Mtetra
.725 .711 .837 r
.78452 .28619 .79044 .29667 .80335 .28869 .79752 .27868 Mtetra
.716 .718 .851 r
.79752 .27868 .80335 .28869 .81636 .28141 .81061 .27178 Mtetra
.707 .724 .863 r
.81061 .27178 .81636 .28141 .82947 .27472 .82379 .26539 Mtetra
.699 .729 .874 r
.82379 .26539 .82947 .27472 .84267 .26853 .83706 .25944 Mtetra
.691 .733 .882 r
.83706 .25944 .84267 .26853 .85597 .26274 .85042 .25382 Mtetra
.662 .741 .908 r
.23845 .44858 .24573 .45535 .25659 .45172 .24933 .44491 Mtetra
.662 .741 .909 r
.24933 .44491 .25659 .45172 .26749 .44809 .26026 .44125 Mtetra
.661 .741 .909 r
.26026 .44125 .26749 .44809 .27843 .44446 .27123 .43761 Mtetra
.66 .74 .91 r
.27123 .43761 .27843 .44446 .28941 .44087 .28224 .43398 Mtetra
.658 .74 .911 r
.28224 .43398 .28941 .44087 .30044 .43731 .2933 .4304 Mtetra
.655 .739 .912 r
.2933 .4304 .30044 .43731 .31151 .43383 .30439 .42689 Mtetra
.651 .738 .913 r
.30439 .42689 .31151 .43383 .32262 .43044 .31553 .42347 Mtetra
.645 .736 .916 r
.31553 .42347 .32262 .43044 .33378 .4272 .32671 .42019 Mtetra
.638 .734 .918 r
.32671 .42019 .33378 .4272 .34497 .42415 .33793 .4171 Mtetra
.627 .731 .921 r
.33793 .4171 .34497 .42415 .3562 .42136 .34919 .41426 Mtetra
.614 .726 .925 r
.34919 .41426 .3562 .42136 .36746 .4189 .36049 .41174 Mtetra
.597 .719 .929 r
.36049 .41174 .36746 .4189 .37877 .41686 .37182 .40961 Mtetra
.576 .709 .933 r
.37182 .40961 .37877 .41686 .39011 .41533 .38319 .40796 Mtetra
.549 .696 .936 r
.38319 .40796 .39011 .41533 .4015 .41439 .39461 .40688 Mtetra
.517 .679 .939 r
.39461 .40688 .4015 .41439 .41293 .41413 .40607 .40647 Mtetra
.477 .657 .939 r
.40607 .40647 .41293 .41413 .42442 .41465 .41758 .4068 Mtetra
.43 .629 .938 r
.41758 .4068 .42442 .41465 .43596 .416 .42914 .408 Mtetra
.372 .596 .933 r
.42914 .408 .43596 .416 .44757 .41824 .44077 .41014 Mtetra
.305 .557 .924 r
.44077 .41014 .44757 .41824 .45925 .42139 .45247 .4133 Mtetra
.228 .513 .91 r
.45247 .4133 .45925 .42139 .47103 .42544 .46425 .41748 Mtetra
.149 .469 .892 r
.46425 .41748 .47103 .42544 .4829 .4303 .47614 .42256 Mtetra
.086 .437 .876 r
.47614 .42256 .4829 .4303 .49489 .43578 .48813 .42823 Mtetra
.068 .432 .873 r
.48813 .42823 .49489 .43578 .507 .44156 .50026 .434 Mtetra
.124 .469 .893 r
.50026 .434 .507 .44156 .51924 .44718 .51251 .43918 Mtetra
.256 .537 .921 r
.51251 .43918 .51924 .44718 .5316 .45205 .52489 .44304 Mtetra
.417 .597 .919 r
.52489 .44304 .5316 .45205 .54408 .45554 .53737 .44494 Mtetra
.544 .621 .879 r
.53737 .44494 .54408 .45554 .55665 .45712 .54994 .4445 Mtetra
.618 .619 .829 r
.54994 .4445 .55665 .45712 .56929 .45642 .56257 .44164 Mtetra
.657 .607 .787 r
.56257 .44164 .56929 .45642 .58197 .45332 .57523 .43656 Mtetra
.677 .596 .757 r
.57523 .43656 .58197 .45332 .59467 .44794 .58791 .42963 Mtetra
.688 .588 .738 r
.58791 .42963 .59467 .44794 .60737 .44054 .60059 .42124 Mtetra
.696 .585 .727 r
.60059 .42124 .60737 .44054 .62005 .43146 .61326 .41173 Mtetra
.704 .586 .721 r
.61326 .41173 .62005 .43146 .63271 .42105 .62592 .40134 Mtetra
.711 .59 .719 r
.62592 .40134 .63271 .42105 .64534 .40961 .63857 .39029 Mtetra
.718 .597 .72 r
.63857 .39029 .64534 .40961 .65794 .39744 .65121 .37875 Mtetra
.725 .605 .723 r
.65121 .37875 .65794 .39744 .67051 .38481 .66383 .36691 Mtetra
.731 .614 .728 r
.66383 .36691 .67051 .38481 .68307 .37199 .67644 .35499 Mtetra
.736 .624 .735 r
.67644 .35499 .68307 .37199 .69561 .35924 .68906 .34319 Mtetra
.739 .635 .744 r
.68906 .34319 .69561 .35924 .70817 .34681 .70169 .33172 Mtetra
.741 .646 .755 r
.70169 .33172 .70817 .34681 .72075 .33487 .71436 .32074 Mtetra
.741 .658 .768 r
.71436 .32074 .72075 .33487 .73337 .32359 .72707 .31036 Mtetra
.739 .669 .782 r
.72707 .31036 .73337 .32359 .74605 .31306 .73983 .30067 Mtetra
.735 .68 .797 r
.73983 .30067 .74605 .31306 .75879 .30333 .75267 .29168 Mtetra
.73 .691 .813 r
.75267 .29168 .75879 .30333 .77161 .29438 .76558 .28339 Mtetra
.724 .701 .829 r
.76558 .28339 .77161 .29438 .78452 .28619 .77857 .27575 Mtetra
.716 .71 .843 r
.77857 .27575 .78452 .28619 .79752 .27868 .79165 .2687 Mtetra
.708 .717 .856 r
.79165 .2687 .79752 .27868 .81061 .27178 .80482 .26217 Mtetra
.7 .724 .868 r
.80482 .26217 .81061 .27178 .82379 .26539 .81807 .25607 Mtetra
.693 .728 .878 r
.81807 .25607 .82379 .26539 .83706 .25944 .83141 .25033 Mtetra
.686 .732 .886 r
.83141 .25033 .83706 .25944 .85042 .25382 .84483 .24487 Mtetra
.662 .741 .908 r
.23112 .44175 .23845 .44858 .24933 .44491 .24203 .43806 Mtetra
.662 .741 .909 r
.24203 .43806 .24933 .44491 .26026 .44125 .25298 .43437 Mtetra
.661 .741 .909 r
.25298 .43437 .26026 .44125 .27123 .43761 .26397 .43069 Mtetra
.66 .74 .91 r
.26397 .43069 .27123 .43761 .28224 .43398 .27501 .42704 Mtetra
.658 .74 .91 r
.27501 .42704 .28224 .43398 .2933 .4304 .2861 .42342 Mtetra
.655 .739 .911 r
.2861 .42342 .2933 .4304 .30439 .42689 .29722 .41987 Mtetra
.651 .738 .913 r
.29722 .41987 .30439 .42689 .31553 .42347 .30839 .41642 Mtetra
.646 .736 .915 r
.30839 .41642 .31553 .42347 .32671 .42019 .3196 .41309 Mtetra
.639 .733 .917 r
.3196 .41309 .32671 .42019 .33793 .4171 .33085 .40995 Mtetra
.629 .73 .92 r
.33085 .40995 .33793 .4171 .34919 .41426 .34213 .40703 Mtetra
.617 .724 .922 r
.34213 .40703 .34919 .41426 .36049 .41174 .35346 .40442 Mtetra
.602 .717 .926 r
.35346 .40442 .36049 .41174 .37182 .40961 .36482 .40218 Mtetra
.582 .707 .929 r
.36482 .40218 .37182 .40961 .38319 .40796 .37623 .4004 Mtetra
.557 .694 .932 r
.37623 .4004 .38319 .40796 .39461 .40688 .38767 .39918 Mtetra
.524 .677 .935 r
.38767 .39918 .39461 .40688 .40607 .40647 .39915 .39864 Mtetra
.48 .655 .937 r
.39915 .39864 .40607 .40647 .41758 .4068 .41068 .39894 Mtetra
.42 .626 .938 r
.41068 .39894 .41758 .4068 .42914 .408 .42226 .40024 Mtetra
.337 .587 .936 r
.42226 .40024 .42914 .408 .44077 .41014 .43389 .4027 Mtetra
.223 .533 .923 r
.43389 .4027 .44077 .41014 .45247 .4133 .4456 .40642 Mtetra
.082 .464 .888 r
.4456 .40642 .45247 .4133 .46425 .41748 .45738 .41132 Mtetra
0 .392 .832 r
.45738 .41132 .46425 .41748 .47614 .42256 .46927 .4171 Mtetra
0 .351 .786 r
.46927 .4171 .47614 .42256 .48813 .42823 .48129 .42316 Mtetra
0 .384 .801 r
.48129 .42316 .48813 .42823 .50026 .434 .49343 .42867 Mtetra
.056 .503 .892 r
.49343 .42867 .50026 .434 .51251 .43918 .50572 .43273 Mtetra
.328 .633 .962 r
.50572 .43273 .51251 .43918 .52489 .44304 .51812 .43459 Mtetra
.535 .673 .926 r
.51812 .43459 .52489 .44304 .53737 .44494 .53063 .43385 Mtetra
.631 .653 .853 r
.53063 .43385 .53737 .44494 .54994 .4445 .5432 .43056 Mtetra
.668 .623 .796 r
.5432 .43056 .54994 .4445 .56257 .44164 .55581 .42509 Mtetra
.68 .6 .759 r
.55581 .42509 .56257 .44164 .57523 .43656 .56845 .41799 Mtetra
.685 .584 .737 r
.56845 .41799 .57523 .43656 .58791 .42963 .58111 .40976 Mtetra
.688 .576 .725 r
.58111 .40976 .58791 .42963 .60059 .42124 .59377 .40076 Mtetra
.691 .574 .719 r
.59377 .40076 .60059 .42124 .61326 .41173 .60645 .39121 Mtetra
.696 .576 .717 r
.60645 .39121 .61326 .41173 .62592 .40134 .61912 .38119 Mtetra
.702 .582 .718 r
.61912 .38119 .62592 .40134 .63857 .39029 .63179 .37076 Mtetra
.709 .59 .721 r
.63179 .37076 .63857 .39029 .65121 .37875 .64446 .36002 Mtetra
.715 .6 .726 r
.64446 .36002 .65121 .37875 .66383 .36691 .65713 .34908 Mtetra
.721 .61 .733 r
.65713 .34908 .66383 .36691 .67644 .35499 .66981 .33813 Mtetra
.726 .621 .741 r
.66981 .33813 .67644 .35499 .68906 .34319 .68249 .32733 Mtetra
.729 .633 .751 r
.68249 .32733 .68906 .34319 .70169 .33172 .6952 .31685 Mtetra
.731 .645 .763 r
.6952 .31685 .70169 .33172 .71436 .32074 .70795 .30683 Mtetra
.73 .657 .777 r
.70795 .30683 .71436 .32074 .72707 .31036 .72075 .29735 Mtetra
.729 .669 .791 r
.72075 .29735 .72707 .31036 .73983 .30067 .7336 .28848 Mtetra
.725 .681 .807 r
.7336 .28848 .73983 .30067 .75267 .29168 .74652 .28021 Mtetra
.72 .692 .822 r
.74652 .28021 .75267 .29168 .76558 .28339 .75952 .27255 Mtetra
.714 .702 .837 r
.75952 .27255 .76558 .28339 .77857 .27575 .77259 .26543 Mtetra
.708 .711 .851 r
.77259 .26543 .77857 .27575 .79165 .2687 .78575 .25881 Mtetra
.701 .718 .863 r
.78575 .25881 .79165 .2687 .80482 .26217 .79899 .25262 Mtetra
.694 .724 .873 r
.79899 .25262 .80482 .26217 .81807 .25607 .81231 .24679 Mtetra
.687 .729 .882 r
.81231 .24679 .81807 .25607 .83141 .25033 .82572 .24124 Mtetra
.682 .732 .889 r
.82572 .24124 .83141 .25033 .84483 .24487 .8392 .23592 Mtetra
.663 .741 .908 r
.22373 .43486 .23112 .44175 .24203 .43806 .23466 .43114 Mtetra
.662 .741 .909 r
.23466 .43114 .24203 .43806 .25298 .43437 .24564 .42742 Mtetra
.661 .741 .909 r
.24564 .42742 .25298 .43437 .26397 .43069 .25666 .42372 Mtetra
.66 .74 .909 r
.25666 .42372 .26397 .43069 .27501 .42704 .26773 .42003 Mtetra
.658 .74 .91 r
.26773 .42003 .27501 .42704 .2861 .42342 .27884 .41638 Mtetra
.655 .739 .911 r
.27884 .41638 .2861 .42342 .29722 .41987 .29 .41279 Mtetra
.652 .737 .912 r
.29 .41279 .29722 .41987 .30839 .41642 .30119 .40929 Mtetra
.647 .735 .914 r
.30119 .40929 .30839 .41642 .3196 .41309 .31243 .4059 Mtetra
.64 .733 .916 r
.31243 .4059 .3196 .41309 .33085 .40995 .32371 .40269 Mtetra
.632 .729 .918 r
.32371 .40269 .33085 .40995 .34213 .40703 .33502 .39969 Mtetra
.62 .723 .92 r
.33502 .39969 .34213 .40703 .35346 .40442 .34638 .39697 Mtetra
.605 .716 .923 r
.34638 .39697 .35346 .40442 .36482 .40218 .35777 .39462 Mtetra
.585 .707 .927 r
.35777 .39462 .36482 .40218 .37623 .4004 .3692 .39276 Mtetra
.556 .694 .932 r
.3692 .39276 .37623 .4004 .38767 .39918 .38067 .39153 Mtetra
.512 .676 .939 r
.38067 .39153 .38767 .39918 .39915 .39864 .39217 .39115 Mtetra
.444 .651 .947 r
.39217 .39115 .39915 .39864 .41068 .39894 .4037 .39187 Mtetra
.333 .609 .95 r
.4037 .39187 .41068 .39894 .42226 .40024 .41527 .39394 Mtetra
.152 .532 .921 r
.41527 .39394 .42226 .40024 .43389 .4027 .42689 .39756 Mtetra
0 .397 .812 r
.42689 .39756 .43389 .4027 .4456 .40642 .43858 .4027 Mtetra
.335 0 0 r
.43858 .4027 .4456 .40642 .45738 .41132 .45036 .40899 Mtetra
.458 0 0 r
.45036 .40899 .45738 .41132 .46927 .4171 .46227 .41568 Mtetra
.455 0 0 r
.46227 .41568 .46927 .4171 .48129 .42316 .47432 .42169 Mtetra
.304 0 0 r
.47432 .42169 .48129 .42316 .49343 .42867 .48652 .42589 Mtetra
.099 .616 .886 r
.48652 .42589 .49343 .42867 .50572 .43273 .49886 .42738 Mtetra
.522 .77 .987 r
.49886 .42738 .50572 .43273 .51812 .43459 .51131 .42579 Mtetra
.667 .718 .887 r
.51131 .42579 .51812 .43459 .53063 .43385 .52384 .42133 Mtetra
.696 .657 .807 r
.52384 .42133 .53063 .43385 .5432 .43056 .53642 .41467 Mtetra
.697 .615 .761 r
.53642 .41467 .5432 .43056 .55581 .42509 .54902 .40662 Mtetra
.692 .589 .736 r
.54902 .40662 .55581 .42509 .56845 .41799 .56164 .3979 Mtetra
.686 .574 .723 r
.56164 .3979 .56845 .41799 .58111 .40976 .57429 .38893 Mtetra
.684 .568 .718 r
.57429 .38893 .58111 .40976 .59377 .40076 .58695 .37986 Mtetra
.685 .568 .717 r
.58695 .37986 .59377 .40076 .60645 .39121 .59962 .37067 Mtetra
.689 .572 .719 r
.59962 .37067 .60645 .39121 .61912 .38119 .61232 .36127 Mtetra
.694 .58 .723 r
.61232 .36127 .61912 .38119 .63179 .37076 .62502 .35162 Mtetra
.701 .589 .727 r
.62502 .35162 .63179 .37076 .64446 .36002 .63773 .34174 Mtetra
.708 .6 .734 r
.63773 .34174 .64446 .36002 .65713 .34908 .65044 .33175 Mtetra
.713 .611 .741 r
.65044 .33175 .65713 .34908 .66981 .33813 .66318 .32177 Mtetra
.717 .622 .751 r
.66318 .32177 .66981 .33813 .68249 .32733 .67593 .31195 Mtetra
.72 .634 .761 r
.67593 .31195 .68249 .32733 .6952 .31685 .68872 .30244 Mtetra
.721 .647 .774 r
.68872 .30244 .6952 .31685 .70795 .30683 .70154 .29334 Mtetra
.721 .659 .788 r
.70154 .29334 .70795 .30683 .72075 .29735 .71442 .28471 Mtetra
.719 .672 .802 r
.71442 .28471 .72075 .29735 .7336 .28848 .72736 .2766 Mtetra
.716 .683 .817 r
.72736 .2766 .7336 .28848 .74652 .28021 .74036 .26901 Mtetra
.711 .694 .832 r
.74036 .26901 .74652 .28021 .75952 .27255 .75344 .26192 Mtetra
.706 .704 .846 r
.75344 .26192 .75952 .27255 .77259 .26543 .76659 .25528 Mtetra
.7 .713 .858 r
.76659 .25528 .77259 .26543 .78575 .25881 .77982 .24904 Mtetra
.694 .72 .869 r
.77982 .24904 .78575 .25881 .79899 .25262 .79313 .24315 Mtetra
.688 .725 .879 r
.79313 .24315 .79899 .25262 .81231 .24679 .80652 .23754 Mtetra
.682 .73 .886 r
.80652 .23754 .81231 .24679 .82572 .24124 .81999 .23216 Mtetra
.678 .733 .892 r
.81999 .23216 .82572 .24124 .8392 .23592 .83354 .22695 Mtetra
.663 .741 .908 r
.21628 .42793 .22373 .43486 .23466 .43114 .22724 .42418 Mtetra
.662 .741 .909 r
.22724 .42418 .23466 .43114 .24564 .42742 .23824 .42042 Mtetra
.661 .741 .909 r
.23824 .42042 .24564 .42742 .25666 .42372 .24929 .41668 Mtetra
.66 .74 .909 r
.24929 .41668 .25666 .42372 .26773 .42003 .26039 .41296 Mtetra
.658 .74 .91 r
.26039 .41296 .26773 .42003 .27884 .41638 .27153 .40927 Mtetra
.656 .739 .911 r
.27153 .40927 .27884 .41638 .29 .41279 .28271 .40563 Mtetra
.653 .737 .912 r
.28271 .40563 .29 .41279 .30119 .40929 .29394 .40208 Mtetra
.648 .735 .913 r
.29394 .40208 .30119 .40929 .31243 .4059 .30521 .39863 Mtetra
.642 .732 .914 r
.30521 .39863 .31243 .4059 .32371 .40269 .31651 .39534 Mtetra
.634 .729 .916 r
.31651 .39534 .32371 .40269 .33502 .39969 .32786 .39226 Mtetra
.622 .723 .919 r
.32786 .39226 .33502 .39969 .34638 .39697 .33925 .38949 Mtetra
.604 .716 .924 r
.33925 .38949 .34638 .39697 .35777 .39462 .35066 .38714 Mtetra
.576 .707 .932 r
.35066 .38714 .35777 .39462 .3692 .39276 .36211 .38543 Mtetra
.529 .694 .944 r
.36211 .38543 .3692 .39276 .38067 .39153 .37358 .38462 Mtetra
.443 .671 .96 r
.37358 .38462 .38067 .39153 .39217 .39115 .38506 .38507 Mtetra
.276 .615 .957 r
.38506 .38507 .39217 .39115 .4037 .39187 .39657 .38717 Mtetra
0 .465 .849 r
.39657 .38717 .4037 .39187 .41527 .39394 .4081 .39119 Mtetra
.392 0 0 r
.4081 .39119 .41527 .39394 .42689 .39756 .41967 .39712 Mtetra
.586 .014 0 r
.41967 .39712 .42689 .39756 .43858 .4027 .43133 .40449 Mtetra
.634 .101 0 r
.43133 .40449 .43858 .4027 .45036 .40899 .44312 .4123 Mtetra
.61 .092 0 r
.44312 .4123 .45036 .40899 .46227 .41568 .45507 .41913 Mtetra
.517 0 0 r
.45507 .41913 .46227 .41568 .47432 .42169 .4672 .42351 Mtetra
.229 0 0 r
.4672 .42351 .47432 .42169 .48652 .42589 .4795 .42435 Mtetra
.456 .861 .964 r
.4795 .42435 .48652 .42589 .49886 .42738 .49194 .42133 Mtetra
.728 .813 .917 r
.49194 .42133 .49886 .42738 .51131 .42579 .50446 .41494 Mtetra
.742 .702 .813 r
.50446 .41494 .51131 .42579 .52384 .42133 .51702 .40624 Mtetra
.725 .637 .759 r
.51702 .40624 .52384 .42133 .53642 .41467 .52961 .39644 Mtetra
.707 .599 .733 r
.52961 .39644 .53642 .41467 .54902 .40662 .54221 .38652 Mtetra
.692 .577 .721 r
.54221 .38652 .54902 .40662 .56164 .3979 .55482 .377 Mtetra
.683 .566 .718 r
.55482 .377 .56164 .3979 .57429 .38893 .56746 .36799 Mtetra
.678 .564 .719 r
.56746 .36799 .57429 .38893 .58695 .37986 .58012 .35933 Mtetra
.679 .567 .722 r
.58012 .35933 .58695 .37986 .59962 .37067 .59281 .35077 Mtetra
.683 .574 .726 r
.59281 .35077 .59962 .37067 .61232 .36127 .60553 .34212 Mtetra
.689 .583 .731 r
.60553 .34212 .61232 .36127 .62502 .35162 .61826 .33329 Mtetra
.695 .593 .737 r
.61826 .33329 .62502 .35162 .63773 .34174 .631 .32428 Mtetra
.701 .604 .744 r
.631 .32428 .63773 .34174 .65044 .33175 .64377 .31519 Mtetra
.706 .615 .753 r
.64377 .31519 .65044 .33175 .66318 .32177 .65656 .30614 Mtetra
.71 .627 .763 r
.65656 .30614 .66318 .32177 .67593 .31195 .66938 .29726 Mtetra
.712 .64 .774 r
.66938 .29726 .67593 .31195 .68872 .30244 .68223 .28865 Mtetra
.713 .652 .787 r
.68223 .28865 .68872 .30244 .70154 .29334 .69514 .28039 Mtetra
.713 .665 .801 r
.69514 .28039 .70154 .29334 .71442 .28471 .70809 .27254 Mtetra
.711 .677 .815 r
.70809 .27254 .71442 .28471 .72736 .2766 .72111 .26512 Mtetra
.707 .688 .829 r
.72111 .26512 .72736 .2766 .74036 .26901 .73419 .25813 Mtetra
.703 .699 .843 r
.73419 .25813 .74036 .26901 .75344 .26192 .74734 .25154 Mtetra
.698 .708 .855 r
.74734 .25154 .75344 .26192 .76659 .25528 .76057 .24531 Mtetra
.693 .716 .866 r
.76057 .24531 .76659 .25528 .77982 .24904 .77387 .2394 Mtetra
.687 .722 .876 r
.77387 .2394 .77982 .24904 .79313 .24315 .78724 .23376 Mtetra
.683 .727 .884 r
.78724 .23376 .79313 .24315 .80652 .23754 .8007 .22834 Mtetra
.678 .731 .89 r
.8007 .22834 .80652 .23754 .81999 .23216 .81423 .2231 Mtetra
.675 .734 .895 r
.81423 .2231 .81999 .23216 .83354 .22695 .82783 .21798 Mtetra
.663 .741 .908 r
.20877 .42093 .21628 .42793 .22724 .42418 .21976 .41715 Mtetra
.662 .741 .908 r
.21976 .41715 .22724 .42418 .23824 .42042 .23079 .41337 Mtetra
.661 .741 .909 r
.23079 .41337 .23824 .42042 .24929 .41668 .24187 .40959 Mtetra
.66 .74 .909 r
.24187 .40959 .24929 .41668 .26039 .41296 .25299 .40583 Mtetra
.659 .739 .91 r
.25299 .40583 .26039 .41296 .27153 .40927 .26416 .4021 Mtetra
.656 .739 .91 r
.26416 .4021 .27153 .40927 .28271 .40563 .27537 .39841 Mtetra
.653 .737 .911 r
.27537 .39841 .28271 .40563 .29394 .40208 .28663 .3948 Mtetra
.649 .735 .912 r
.28663 .3948 .29394 .40208 .30521 .39863 .29793 .3913 Mtetra
.643 .732 .914 r
.29793 .3913 .30521 .39863 .31651 .39534 .30926 .38796 Mtetra
.632 .729 .917 r
.30926 .38796 .31651 .39534 .32786 .39226 .32064 .38488 Mtetra
.616 .724 .923 r
.32064 .38488 .32786 .39226 .33925 .38949 .33204 .38222 Mtetra
.586 .718 .935 r
.33204 .38222 .33925 .38949 .35066 .38714 .34346 .38022 Mtetra
.529 .708 .953 r
.34346 .38022 .35066 .38714 .36211 .38543 .35489 .37925 Mtetra
.407 .681 .973 r
.35489 .37925 .36211 .38543 .37358 .38462 .36632 .37981 Mtetra
.131 .575 .924 r
.36632 .37981 .37358 .38462 .38506 .38507 .37774 .3824 Mtetra
.327 0 0 r
.37774 .3824 .38506 .38507 .39657 .38717 .38915 .3874 Mtetra
.608 .05 0 r
.38915 .3874 .39657 .38717 .4081 .39119 .40059 .3948 Mtetra
.679 .191 .082 r
.40059 .3948 .4081 .39119 .41967 .39712 .4121 .40395 Mtetra
.677 .23 .183 r
.4121 .40395 .41967 .39712 .43133 .40449 .42376 .41349 Mtetra
.641 .21 .207 r
.42376 .41349 .43133 .40449 .44312 .4123 .43561 .42153 Mtetra
.565 .123 .159 r
.43561 .42153 .44312 .4123 .45507 .41913 .44768 .42618 Mtetra
.374 0 0 r
.44768 .42618 .45507 .41913 .4672 .42351 .45997 .42613 Mtetra
.291 .774 .688 r
.45997 .42613 .4672 .42351 .4795 .42435 .47243 .42112 Mtetra
.802 .907 .914 r
.47243 .42112 .4795 .42435 .49194 .42133 .48499 .41203 Mtetra
.796 .745 .805 r
.48499 .41203 .49194 .42133 .50446 .41494 .49759 .40045 Mtetra
.759 .658 .75 r
.49759 .40045 .50446 .41494 .51702 .40624 .51019 .38809 Mtetra
.728 .61 .726 r
.51019 .38809 .51702 .40624 .52961 .39644 .52279 .37626 Mtetra
.704 .583 .717 r
.52279 .37626 .52961 .39644 .54221 .38652 .53538 .36562 Mtetra
.687 .569 .716 r
.53538 .36562 .54221 .38652 .55482 .377 .548 .35622 Mtetra
.677 .564 .72 r
.548 .35622 .55482 .377 .56746 .36799 .56064 .34777 Mtetra
.673 .566 .726 r
.56064 .34777 .56746 .36799 .58012 .35933 .57331 .33982 Mtetra
.674 .572 .732 r
.57331 .33982 .58012 .35933 .59281 .35077 .58602 .33201 Mtetra
.679 .581 .738 r
.58602 .33201 .59281 .35077 .60553 .34212 .59875 .32412 Mtetra
.685 .59 .744 r
.59875 .32412 .60553 .34212 .61826 .33329 .61151 .31606 Mtetra
.691 .601 .751 r
.61151 .31606 .61826 .33329 .631 .32428 .6243 .30786 Mtetra
.696 .612 .758 r
.6243 .30786 .631 .32428 .64377 .31519 .63711 .29961 Mtetra
.701 .623 .767 r
.63711 .29961 .64377 .31519 .65656 .30614 .64996 .29141 Mtetra
.704 .635 .778 r
.64996 .29141 .65656 .30614 .66938 .29726 .66284 .28336 Mtetra
.705 .648 .789 r
.66284 .28336 .66938 .29726 .68223 .28865 .67576 .27556 Mtetra
.706 .66 .802 r
.67576 .27556 .68223 .28865 .69514 .28039 .68873 .26806 Mtetra
.705 .672 .815 r
.68873 .26806 .69514 .28039 .70809 .27254 .70175 .26089 Mtetra
.703 .684 .829 r
.70175 .26089 .70809 .27254 .72111 .26512 .71484 .25407 Mtetra
.7 .694 .842 r
.71484 .25407 .72111 .26512 .73419 .25813 .728 .24758 Mtetra
.696 .704 .854 r
.728 .24758 .73419 .25813 .74734 .25154 .74122 .24142 Mtetra
.691 .712 .865 r
.74122 .24142 .74734 .25154 .76057 .24531 .75451 .23553 Mtetra
.686 .719 .874 r
.75451 .23553 .76057 .24531 .77387 .2394 .76788 .2299 Mtetra
.682 .725 .882 r
.76788 .2299 .77387 .2394 .78724 .23376 .78132 .22446 Mtetra
.678 .729 .889 r
.78132 .22446 .78724 .23376 .8007 .22834 .79483 .21919 Mtetra
.675 .733 .894 r
.79483 .21919 .8007 .22834 .81423 .2231 .80842 .21404 Mtetra
.672 .735 .898 r
.80842 .21404 .81423 .2231 .82783 .21798 .82208 .20899 Mtetra
.663 .741 .908 r
.2012 .41388 .20877 .42093 .21976 .41715 .21222 .41007 Mtetra
.662 .741 .908 r
.21222 .41007 .21976 .41715 .23079 .41337 .22328 .40625 Mtetra
.662 .741 .909 r
.22328 .40625 .23079 .41337 .24187 .40959 .23438 .40244 Mtetra
.661 .74 .909 r
.23438 .40244 .24187 .40959 .25299 .40583 .24554 .39864 Mtetra
.659 .739 .909 r
.24554 .39864 .25299 .40583 .26416 .4021 .25673 .39486 Mtetra
.657 .739 .91 r
.25673 .39486 .26416 .4021 .27537 .39841 .26798 .39113 Mtetra
.654 .737 .911 r
.26798 .39113 .27537 .39841 .28663 .3948 .27926 .38748 Mtetra
.648 .735 .913 r
.27926 .38748 .28663 .3948 .29793 .3913 .29058 .38397 Mtetra
.639 .733 .917 r
.29058 .38397 .29793 .3913 .30926 .38796 .30194 .38069 Mtetra
.621 .731 .925 r
.30194 .38069 .30926 .38796 .32064 .38488 .31332 .37786 Mtetra
.587 .727 .941 r
.31332 .37786 .32064 .38488 .33204 .38222 .32472 .37577 Mtetra
.511 .718 .966 r
.32472 .37577 .33204 .38222 .34346 .38022 .3361 .37493 Mtetra
.321 .671 .976 r
.3361 .37493 .34346 .38022 .35489 .37925 .34745 .37596 Mtetra
0 .429 .764 r
.34745 .37596 .35489 .37925 .36632 .37981 .35875 .37955 Mtetra
.567 0 0 r
.35875 .37955 .36632 .37981 .37774 .3824 .37002 .38615 Mtetra
.691 .211 .105 r
.37002 .38615 .37774 .3824 .38915 .3874 .38128 .39573 Mtetra
.704 .284 .246 r
.38128 .39573 .38915 .3874 .40059 .3948 .39261 .40739 Mtetra
.685 .295 .303 r
.39261 .40739 .40059 .3948 .4121 .40395 .40409 .4193 Mtetra
.645 .268 .314 r
.40409 .4193 .4121 .40395 .42376 .41349 .41583 .429 Mtetra
.574 .191 .277 r
.41583 .429 .42376 .41349 .43561 .42153 .42786 .43403 Mtetra
.411 0 .138 r
.42786 .43403 .43561 .42153 .44768 .42618 .44018 .43284 Mtetra
0 0 0 r
.44018 .43284 .44768 .42618 .45997 .42613 .45272 .4253 Mtetra
.868 .958 .862 r
.45272 .4253 .45997 .42613 .47243 .42112 .46538 .41279 Mtetra
.843 .769 .78 r
.46538 .41279 .47243 .42112 .48499 .41203 .47807 .39755 Mtetra
.79 .67 .732 r
.47807 .39755 .48499 .41203 .49759 .40045 .49074 .3819 Mtetra
.749 .618 .713 r
.49074 .3819 .49759 .40045 .51019 .38809 .50337 .36754 Mtetra
.718 .588 .709 r
.50337 .36754 .51019 .38809 .52279 .37626 .51597 .35526 Mtetra
.695 .572 .713 r
.51597 .35526 .52279 .37626 .53538 .36562 .52856 .34507 Mtetra
.679 .567 .721 r
.52856 .34507 .53538 .36562 .548 .35622 .54118 .33649 Mtetra
.671 .568 .731 r
.54118 .33649 .548 .35622 .56064 .34777 .55383 .3289 Mtetra
.669 .574 .74 r
.55383 .3289 .56064 .34777 .57331 .33982 .56651 .32173 Mtetra
.671 .582 .747 r
.56651 .32173 .57331 .33982 .58602 .33201 .57924 .31463 Mtetra
.676 .592 .753 r
.57924 .31463 .58602 .33201 .59875 .32412 .592 .30742 Mtetra
.682 .602 .76 r
.592 .30742 .59875 .32412 .61151 .31606 .60479 .30005 Mtetra
.688 .612 .767 r
.60479 .30005 .61151 .31606 .6243 .30786 .61761 .29257 Mtetra
.692 .623 .775 r
.61761 .29257 .6243 .30786 .63711 .29961 .63047 .28507 Mtetra
.696 .634 .784 r
.63047 .28507 .63711 .29961 .64996 .29141 .64336 .27762 Mtetra
.698 .646 .794 r
.64336 .27762 .64996 .29141 .66284 .28336 .6563 .27031 Mtetra
.699 .658 .806 r
.6563 .27031 .66284 .28336 .67576 .27556 .66928 .2632 Mtetra
.699 .67 .818 r
.66928 .2632 .67576 .27556 .68873 .26806 .68232 .25633 Mtetra
.698 .681 .83 r
.68232 .25633 .68873 .26806 .70175 .26089 .69541 .24974 Mtetra
.695 .692 .842 r
.69541 .24974 .70175 .26089 .71484 .25407 .70857 .24342 Mtetra
.692 .701 .854 r
.70857 .24342 .71484 .25407 .728 .24758 .72179 .23735 Mtetra
.689 .71 .864 r
.72179 .23735 .728 .24758 .74122 .24142 .73507 .23153 Mtetra
.685 .717 .873 r
.73507 .23153 .74122 .24142 .75451 .23553 .74843 .22593 Mtetra
.681 .723 .881 r
.74843 .22593 .75451 .23553 .76788 .2299 .76186 .2205 Mtetra
.678 .728 .888 r
.76186 .2205 .76788 .2299 .78132 .22446 .77536 .21522 Mtetra
.674 .731 .893 r
.77536 .21522 .78132 .22446 .79483 .21919 .78893 .21006 Mtetra
.672 .734 .897 r
.78893 .21006 .79483 .21919 .80842 .21404 .80257 .20499 Mtetra
.67 .736 .9 r
.80257 .20499 .80842 .21404 .82208 .20899 .81628 .19998 Mtetra
.663 .741 .908 r
.19357 .40678 .2012 .41388 .21222 .41007 .20462 .40293 Mtetra
.662 .741 .908 r
.20462 .40293 .21222 .41007 .22328 .40625 .21571 .39908 Mtetra
.21571 .39908 .22328 .40625 .23438 .40244 .22684 .39523 Mtetra
.661 .74 .909 r
.22684 .39523 .23438 .40244 .24554 .39864 .23802 .39139 Mtetra
.659 .74 .909 r
.23802 .39139 .24554 .39864 .25673 .39486 .24925 .38758 Mtetra
.657 .739 .91 r
.24925 .38758 .25673 .39486 .26798 .39113 .26052 .38383 Mtetra
.652 .738 .912 r
.26052 .38383 .26798 .39113 .27926 .38748 .27182 .3802 Mtetra
.642 .737 .917 r
.27182 .3802 .27926 .38748 .29058 .38397 .28316 .37683 Mtetra
.622 .736 .928 r
.28316 .37683 .29058 .38397 .30194 .38069 .29452 .37395 Mtetra
.578 .734 .949 r
.29452 .37395 .30194 .38069 .31332 .37786 .30587 .37196 Mtetra
.469 .721 .979 r
.30587 .37196 .31332 .37786 .32472 .37577 .31719 .3715 Mtetra
.158 .613 .933 r
.31719 .3715 .32472 .37577 .3361 .37493 .32843 .37336 Mtetra
.42 0 0 r
.32843 .37336 .3361 .37493 .34745 .37596 .33959 .37841 Mtetra
.677 .174 .04 r
.33959 .37841 .34745 .37596 .35875 .37955 .35066 .38721 Mtetra
.719 .299 .247 r
.35066 .38721 .35875 .37955 .37002 .38615 .36169 .39964 Mtetra
.712 .335 .334 r
.36169 .39964 .37002 .38615 .38128 .39573 .37278 .4145 Mtetra
.687 .333 .368 r
.37278 .4145 .38128 .39573 .39261 .40739 .38406 .42938 Mtetra
.646 .3 .371 r
.38406 .42938 .39261 .40739 .40409 .4193 .39566 .4411 Mtetra
.575 .225 .338 r
.39566 .4411 .40409 .4193 .41583 .429 .40765 .4466 Mtetra
.414 .042 .221 r
.40765 .4466 .41583 .429 .42786 .43403 .42004 .44401 Mtetra
0 0 0 r
.42004 .44401 .42786 .43403 .44018 .43284 .43272 .43345 Mtetra
.918 .958 .797 r
.43272 .43345 .44018 .43284 .45272 .4253 .44555 .41688 Mtetra
.871 .766 .743 r
.44555 .41688 .45272 .4253 .46538 .41279 .45841 .39735 Mtetra
.81 .669 .708 r
.45841 .39735 .46538 .41279 .47807 .39755 .4712 .37783 Mtetra
.766 .618 .696 r
.4712 .37783 .47807 .39755 .49074 .3819 .48391 .36046 Mtetra
.731 .59 .698 r
.48391 .36046 .49074 .3819 .50337 .36754 .49654 .34616 Mtetra
.704 .575 .707 r
.49654 .34616 .50337 .36754 .51597 .35526 .50914 .33486 Mtetra
.684 .571 .721 r
.50914 .33486 .51597 .35526 .52856 .34507 .52173 .32589 Mtetra
.671 .573 .736 r
.52173 .32589 .52856 .34507 .54118 .33649 .53436 .31841 Mtetra
.666 .579 .748 r
.53436 .31841 .54118 .33649 .55383 .3289 .54702 .31169 Mtetra
.666 .588 .758 r
.54702 .31169 .55383 .3289 .56651 .32173 .55972 .30521 Mtetra
.67 .597 .765 r
.55972 .30521 .56651 .32173 .57924 .31463 .57246 .29871 Mtetra
.675 .607 .771 r
.57246 .29871 .57924 .31463 .592 .30742 .58524 .29207 Mtetra
.68 .616 .778 r
.58524 .29207 .592 .30742 .60479 .30005 .59807 .28529 Mtetra
.685 .626 .784 r
.59807 .28529 .60479 .30005 .61761 .29257 .61093 .27843 Mtetra
.688 .637 .792 r
.61093 .27843 .61761 .29257 .63047 .28507 .62383 .27156 Mtetra
.691 .648 .802 r
.62383 .27156 .63047 .28507 .64336 .27762 .63677 .26475 Mtetra
.693 .659 .812 r
.63677 .26475 .64336 .27762 .6563 .27031 .64976 .25806 Mtetra
.693 .67 .822 r
.64976 .25806 .6563 .27031 .66928 .2632 .6628 .25153 Mtetra
.693 .68 .834 r
.6628 .25153 .66928 .2632 .68232 .25633 .6759 .24519 Mtetra
.691 .691 .845 r
.6759 .24519 .68232 .25633 .69541 .24974 .68905 .23906 Mtetra
.689 .7 .855 r
.68905 .23906 .69541 .24974 .70857 .24342 .70227 .23314 Mtetra
.686 .708 .865 r
.70227 .23314 .70857 .24342 .72179 .23735 .71555 .22741 Mtetra
.683 .716 .874 r
.71555 .22741 .72179 .23735 .73507 .23153 .7289 .22186 Mtetra
.68 .722 .881 r
.7289 .22186 .73507 .23153 .74843 .22593 .74232 .21647 Mtetra
.677 .727 .887 r
.74232 .21647 .74843 .22593 .76186 .2205 .7558 .2112 Mtetra
.674 .73 .893 r
.7558 .2112 .76186 .2205 .77536 .21522 .76936 .20604 Mtetra
.671 .734 .897 r
.76936 .20604 .77536 .21522 .78893 .21006 .78298 .20096 Mtetra
.669 .736 .9 r
.78298 .20096 .78893 .21006 .80257 .20499 .79668 .19593 Mtetra
.668 .737 .902 r
.79668 .19593 .80257 .20499 .81628 .19998 .81044 .19095 Mtetra
.663 .741 .908 r
.18589 .39962 .19357 .40678 .20462 .40293 .19696 .39574 Mtetra
.662 .741 .908 r
.19696 .39574 .20462 .40293 .21571 .39908 .20807 .39185 Mtetra
.20807 .39185 .21571 .39908 .22684 .39523 .21924 .38797 Mtetra
.661 .74 .909 r
.21924 .38797 .22684 .39523 .23802 .39139 .23045 .3841 Mtetra
.658 .74 .91 r
.23045 .3841 .23802 .39139 .24925 .38758 .2417 .38029 Mtetra
.653 .739 .913 r
.2417 .38029 .24925 .38758 .26052 .38383 .25299 .37661 Mtetra
.642 .739 .919 r
.25299 .37661 .26052 .38383 .27182 .3802 .2643 .3732 Mtetra
.618 .739 .933 r
.2643 .3732 .27182 .3802 .28316 .37683 .27562 .37038 Mtetra
.56 .738 .959 r
.27562 .37038 .28316 .37683 .29452 .37395 .28692 .36864 Mtetra
.398 .711 .986 r
.28692 .36864 .29452 .37395 .30587 .37196 .29815 .36877 Mtetra
0 .47 .789 r
.29815 .36877 .30587 .37196 .31719 .3715 .30927 .37177 Mtetra
.601 .043 0 r
.30927 .37177 .31719 .3715 .32843 .37336 .32024 .37868 Mtetra
.721 .276 .194 r
.32024 .37868 .32843 .37336 .33959 .37841 .33106 .39016 Mtetra
.731 .349 .327 r
.33106 .39016 .33959 .37841 .35066 .38721 .3418 .40599 Mtetra
.717 .367 .384 r
.3418 .40599 .35066 .38721 .36169 .39964 .35259 .42459 Mtetra
.69 .356 .406 r
.35259 .42459 .36169 .39964 .37278 .4145 .36361 .44289 Mtetra
.647 .32 .404 r
.36361 .44289 .37278 .4145 .38406 .42938 .37505 .45688 Mtetra
.574 .243 .371 r
.37505 .45688 .38406 .42938 .39566 .4411 .38702 .46282 Mtetra
.399 .052 .256 r
.38702 .46282 .39566 .4411 .40765 .4466 .39951 .45859 Mtetra
0 0 0 r
.39951 .45859 .40765 .4466 .42004 .44401 .41239 .44458 Mtetra
.949 .92 .748 r
.41239 .44458 .42004 .44401 .43272 .43345 .42548 .42348 Mtetra
.878 .741 .707 r
.42548 .42348 .43272 .43345 .44555 .41688 .43857 .39922 Mtetra
.817 .656 .683 r
.43857 .39922 .44555 .41688 .45841 .39735 .45156 .3755 Mtetra
.774 .611 .678 r
.45156 .3755 .45841 .39735 .4712 .37783 .46439 .35485 Mtetra
.741 .587 .685 r
.46439 .35485 .4712 .37783 .48391 .36046 .47709 .33832 Mtetra
.713 .576 .699 r
.47709 .33832 .48391 .36046 .49654 .34616 .48971 .32572 Mtetra
.69 .574 .719 r
.48971 .32572 .49654 .34616 .50914 .33486 .50229 .31618 Mtetra
.675 .579 .74 r
.50229 .31618 .50914 .33486 .52173 .32589 .51489 .30863 Mtetra
.666 .587 .757 r
.51489 .30863 .52173 .32589 .53436 .31841 .52752 .30217 Mtetra
.664 .597 .77 r
.52752 .30217 .53436 .31841 .54702 .31169 .5402 .29615 Mtetra
.666 .606 .779 r
.5402 .29615 .54702 .31169 .55972 .30521 .55292 .29021 Mtetra
.67 .615 .785 r
.55292 .29021 .55972 .30521 .57246 .29871 .56568 .28417 Mtetra
.674 .624 .791 r
.56568 .28417 .57246 .29871 .58524 .29207 .57849 .27799 Mtetra
.679 .633 .797 r
.57849 .27799 .58524 .29207 .59807 .28529 .59134 .27171 Mtetra
.682 .642 .803 r
.59134 .27171 .59807 .28529 .61093 .27843 .60424 .26537 Mtetra
.685 .652 .811 r
.60424 .26537 .61093 .27843 .62383 .27156 .61718 .25902 Mtetra
.687 .662 .82 r
.61718 .25902 .62383 .27156 .63677 .26475 .63017 .25273 Mtetra
.688 .672 .829 r
.63017 .25273 .63677 .26475 .64976 .25806 .64322 .24654 Mtetra
.688 .682 .839 r
.64322 .24654 .64976 .25806 .6628 .25153 .65631 .24048 Mtetra
.687 .691 .849 r
.65631 .24048 .6628 .25153 .6759 .24519 .66946 .23456 Mtetra
.685 .7 .858 r
.66946 .23456 .6759 .24519 .68905 .23906 .68267 .22879 Mtetra
.683 .708 .867 r
.68267 .22879 .68905 .23906 .70227 .23314 .69595 .22318 Mtetra
.681 .715 .875 r
.69595 .22318 .70227 .23314 .71555 .22741 .70929 .2177 Mtetra
.678 .721 .882 r
.70929 .2177 .71555 .22741 .7289 .22186 .72269 .21236 Mtetra
.675 .726 .888 r
.72269 .21236 .7289 .22186 .74232 .21647 .73617 .20712 Mtetra
.673 .73 .893 r
.73617 .20712 .74232 .21647 .7558 .2112 .74971 .20196 Mtetra
.671 .733 .897 r
.74971 .20196 .7558 .2112 .76936 .20604 .76331 .19688 Mtetra
.669 .735 .9 r
.76331 .19688 .76936 .20604 .78298 .20096 .77699 .19185 Mtetra
.668 .737 .902 r
.77699 .19185 .78298 .20096 .79668 .19593 .79074 .18685 Mtetra
.666 .738 .904 r
.79074 .18685 .79668 .19593 .81044 .19095 .80455 .18187 Mtetra
.663 .741 .908 r
.17814 .3924 .18589 .39962 .19696 .39574 .18924 .38849 Mtetra
.662 .741 .908 r
.18924 .38849 .19696 .39574 .20807 .39185 .20038 .38457 Mtetra
.661 .741 .909 r
.20038 .38457 .20807 .39185 .21924 .38797 .21157 .38067 Mtetra
.659 .74 .91 r
.21157 .38067 .21924 .38797 .23045 .3841 .2228 .37682 Mtetra
.654 .74 .913 r
.2228 .37682 .23045 .3841 .2417 .38029 .23407 .37311 Mtetra
.641 .741 .921 r
.23407 .37311 .2417 .38029 .25299 .37661 .24536 .36974 Mtetra
.611 .742 .939 r
.24536 .36974 .25299 .37661 .2643 .3732 .25664 .36705 Mtetra
.533 .74 .97 r
.25664 .36705 .2643 .3732 .27562 .37038 .26787 .36568 Mtetra
.288 .678 .973 r
.26787 .36568 .27562 .37038 .28692 .36864 .279 .36656 Mtetra
.339 0 0 r
.279 .36656 .28692 .36864 .29815 .36877 .28996 .37091 Mtetra
.687 .185 .046 r
.28996 .37091 .29815 .36877 .30927 .37177 .3007 .37995 Mtetra
.741 .335 .281 r
.3007 .37995 .30927 .37177 .32024 .37868 .31122 .39443 Mtetra
.739 .381 .374 r
.31122 .39443 .32024 .37868 .33106 .39016 .32161 .414 Mtetra
.721 .388 .414 r
.32161 .414 .33106 .39016 .3418 .40599 .33204 .43662 Mtetra
.693 .372 .428 r
.33204 .43662 .3418 .40599 .35259 .42459 .34276 .45851 Mtetra
.65 .333 .423 r
.34276 .45851 .35259 .42459 .36361 .44289 .35402 .47481 Mtetra
.572 .251 .387 r
.35402 .47481 .36361 .44289 .37505 .45688 .36597 .48106 Mtetra
.369 .034 .259 r
.36597 .48106 .37505 .45688 .38702 .46282 .3786 .47492 Mtetra
0 0 0 r
.3786 .47492 .38702 .46282 .39951 .45859 .39175 .45717 Mtetra
.951 .859 .713 r
.39175 .45717 .39951 .45859 .41239 .44458 .40515 .43133 Mtetra
.869 .705 .677 r
.40515 .43133 .41239 .44458 .42548 .42348 .41855 .40221 Mtetra
.814 .635 .66 r
.41855 .40221 .42548 .42348 .43857 .39922 .43179 .37425 Mtetra
.775 .599 .66 r
.43179 .37425 .43857 .39922 .45156 .3755 .44479 .35033 Mtetra
.745 .58 .671 r
.44479 .35033 .45156 .3755 .46439 .35485 .45759 .33157 Mtetra
.719 .573 .69 r
.45759 .33157 .46439 .35485 .47709 .33832 .47025 .31763 Mtetra
.696 .576 .715 r
.47025 .31763 .47709 .33832 .48971 .32572 .48284 .30744 Mtetra
.679 .584 .743 r
.48284 .30744 .48971 .32572 .50229 .31618 .49542 .29972 Mtetra
.668 .596 .766 r
.49542 .29972 .50229 .31618 .51489 .30863 .50802 .29338 Mtetra
.663 .608 .783 r
.50802 .29338 .51489 .30863 .52752 .30217 .52066 .28767 Mtetra
.663 .618 .794 r
.52066 .28767 .52752 .30217 .5402 .29615 .53335 .28213 Mtetra
.666 .627 .801 r
.53335 .28213 .5402 .29615 .55292 .29021 .54609 .27656 Mtetra
.67 .635 .806 r
.54609 .27656 .55292 .29021 .56568 .28417 .55888 .27087 Mtetra
.674 .642 .811 r
.55888 .27087 .56568 .28417 .57849 .27799 .57172 .26507 Mtetra
.677 .65 .816 r
.57172 .26507 .57849 .27799 .59134 .27171 .58461 .25918 Mtetra
.68 .659 .823 r
.58461 .25918 .59134 .27171 .60424 .26537 .59754 .25325 Mtetra
.682 .668 .83 r
.59754 .25325 .60424 .26537 .61718 .25902 .61053 .24733 Mtetra
.683 .676 .838 r
.61053 .24733 .61718 .25902 .63017 .25273 .62356 .24146 Mtetra
.683 .685 .846 r
.62356 .24146 .63017 .25273 .64322 .24654 .63665 .23566 Mtetra
.683 .694 .854 r
.63665 .23566 .64322 .24654 .65631 .24048 .6498 .22995 Mtetra
.682 .702 .862 r
.6498 .22995 .65631 .24048 .66946 .23456 .663 .22435 Mtetra
.68 .709 .87 r
.663 .22435 .66946 .23456 .68267 .22879 .67627 .21886 Mtetra
.678 .716 .877 r
.67627 .21886 .68267 .22879 .69595 .22318 .6896 .21347 Mtetra
.676 .721 .883 r
.6896 .21347 .69595 .22318 .70929 .2177 .70299 .20819 Mtetra
.674 .726 .889 r
.70299 .20819 .70929 .2177 .72269 .21236 .71645 .20298 Mtetra
.672 .73 .893 r
.71645 .20298 .72269 .21236 .73617 .20712 .72997 .19785 Mtetra
.67 .733 .897 r
.72997 .19785 .73617 .20712 .74971 .20196 .74356 .19277 Mtetra
.669 .735 .9 r
.74356 .19277 .74971 .20196 .76331 .19688 .75722 .18773 Mtetra
.667 .737 .902 r
.75722 .18773 .76331 .19688 .77699 .19185 .77095 .18272 Mtetra
.666 .738 .904 r
.77095 .18272 .77699 .19185 .79074 .18685 .78475 .17773 Mtetra
.666 .739 .905 r
.78475 .17773 .79074 .18685 .80455 .18187 .79861 .17274 Mtetra
.663 .741 .908 r
.17033 .38513 .17814 .3924 .18924 .38849 .18145 .38119 Mtetra
.662 .741 .909 r
.18145 .38119 .18924 .38849 .20038 .38457 .19262 .37726 Mtetra
.659 .741 .91 r
.19262 .37726 .20038 .38457 .21157 .38067 .20383 .37339 Mtetra
.653 .741 .914 r
.20383 .37339 .21157 .38067 .2228 .37682 .21508 .36969 Mtetra
.638 .742 .924 r
.21508 .36969 .2228 .37682 .23407 .37311 .22633 .36637 Mtetra
.6 .744 .945 r
.22633 .36637 .23407 .37311 .24536 .36974 .23757 .36387 Mtetra
.496 .737 .98 r
.23757 .36387 .24536 .36974 .25664 .36705 .24873 .36293 Mtetra
.143 .612 .925 r
.24873 .36293 .25664 .36705 .26787 .36568 .25974 .36466 Mtetra
.517 0 0 r
.25974 .36466 .26787 .36568 .279 .36656 .27051 .37046 Mtetra
.727 .269 .163 r
.27051 .37046 .279 .36656 .28996 .37091 .28099 .38173 Mtetra
.752 .372 .333 r
.28099 .38173 .28996 .37091 .3007 .37995 .29117 .39929 Mtetra
.744 .402 .403 r
.29117 .39929 .3007 .37995 .31122 .39443 .30116 .4226 Mtetra
.725 .403 .433 r
.30116 .4226 .31122 .39443 .32161 .414 .31119 .44919 Mtetra
.697 .384 .442 r
.31119 .44919 .32161 .414 .33204 .43662 .32158 .47452 Mtetra
.653 .342 .433 r
.32158 .47452 .33204 .43662 .34276 .45851 .33264 .49288 Mtetra
.569 .252 .393 r
.33264 .49288 .34276 .45851 .35402 .47481 .34458 .49917 Mtetra
.315 0 .231 r
.34458 .49917 .35402 .47481 .36597 .48106 .35739 .49092 Mtetra
.807 .935 .567 r
.35739 .49092 .36597 .48106 .3786 .47492 .37085 .46937 Mtetra
.928 .787 .686 r
.37085 .46937 .3786 .47492 .39175 .45717 .38462 .43887 Mtetra
.85 .667 .653 r
.38462 .43887 .39175 .45717 .40515 .43133 .39838 .40515 Mtetra
.804 .612 .642 r
.39838 .40515 .40515 .43133 .41855 .40221 .4119 .37325 Mtetra
.771 .583 .645 r
.4119 .37325 .41855 .40221 .43179 .37425 .42511 .34636 Mtetra
.744 .57 .658 r
.42511 .34636 .43179 .37425 .44479 .35033 .43804 .32559 Mtetra
.721 .568 .681 r
.43804 .32559 .44479 .35033 .45759 .33157 .45075 .31044 Mtetra
.701 .575 .711 r
.45075 .31044 .45759 .33157 .47025 .31763 .46336 .29963 Mtetra
.683 .589 .744 r
.46336 .29963 .47025 .31763 .48284 .30744 .47592 .29169 Mtetra
.67 .606 .774 r
.47592 .29169 .48284 .30744 .49542 .29972 .4885 .28539 Mtetra
.664 .621 .796 r
.4885 .28539 .49542 .29972 .50802 .29338 .50111 .27987 Mtetra
.662 .632 .81 r
.50111 .27987 .50802 .29338 .52066 .28767 .51377 .27462 Mtetra
.664 .641 .817 r
.51377 .27462 .52066 .28767 .53335 .28213 .52648 .26939 Mtetra
.667 .648 .822 r
.52648 .26939 .53335 .28213 .54609 .27656 .53924 .26407 Mtetra
.67 .654 .826 r
.53924 .26407 .54609 .27656 .55888 .27087 .55206 .25864 Mtetra
.673 .661 .83 r
.55206 .25864 .55888 .27087 .57172 .26507 .56493 .25313 Mtetra
.675 .668 .835 r
.56493 .25313 .57172 .26507 .58461 .25918 .57785 .24755 Mtetra
.677 .675 .841 r
.57785 .24755 .58461 .25918 .59754 .25325 .59082 .24195 Mtetra
.678 .683 .847 r
.59082 .24195 .59754 .25325 .61053 .24733 .60385 .23636 Mtetra
.679 .69 .854 r
.60385 .23636 .61053 .24733 .62356 .24146 .61693 .2308 Mtetra
.679 .698 .861 r
.61693 .2308 .62356 .24146 .63665 .23566 .63006 .22529 Mtetra
.678 .705 .867 r
.63006 .22529 .63665 .23566 .6498 .22995 .64326 .21985 Mtetra
.677 .711 .874 r
.64326 .21985 .6498 .22995 .663 .22435 .65651 .21448 Mtetra
.676 .717 .88 r
.65651 .21448 .663 .22435 .67627 .21886 .66983 .20919 Mtetra
.674 .722 .885 r
.66983 .20919 .67627 .21886 .6896 .21347 .68321 .20396 Mtetra
.672 .726 .89 r
.68321 .20396 .6896 .21347 .70299 .20819 .69665 .1988 Mtetra
.671 .73 .894 r
.69665 .1988 .70299 .20819 .71645 .20298 .71016 .19369 Mtetra
.669 .733 .897 r
.71016 .19369 .71645 .20298 .72997 .19785 .72374 .18862 Mtetra
.668 .735 .9 r
.72374 .18862 .72997 .19785 .74356 .19277 .73738 .18358 Mtetra
.667 .737 .902 r
.73738 .18358 .74356 .19277 .75722 .18773 .75109 .17857 Mtetra
.666 .738 .904 r
.75109 .17857 .75722 .18773 .77095 .18272 .76487 .17356 Mtetra
.665 .739 .905 r
.76487 .17356 .77095 .18272 .78475 .17773 .77871 .16856 Mtetra
.665 .74 .906 r
.77871 .16856 .78475 .17773 .79861 .17274 .79262 .16355 Mtetra
.662 .741 .909 r
.16246 .37781 .17033 .38513 .18145 .38119 .1736 .37386 Mtetra
.659 .741 .911 r
.1736 .37386 .18145 .38119 .19262 .37726 .18479 .36999 Mtetra
.652 .742 .915 r
.18479 .36999 .19262 .37726 .20383 .37339 .19601 .3663 Mtetra
.634 .743 .927 r
.19601 .3663 .20383 .37339 .21508 .36969 .20723 .36306 Mtetra
.588 .744 .951 r
.20723 .36306 .21508 .36969 .22633 .36637 .21842 .36077 Mtetra
.452 .729 .986 r
.21842 .36077 .22633 .36637 .23757 .36387 .22949 .36029 Mtetra
0 .517 .838 r
.22949 .36029 .23757 .36387 .24873 .36293 .24037 .36286 Mtetra
.618 .064 0 r
.24037 .36286 .24873 .36293 .25974 .36466 .25095 .37008 Mtetra
.748 .319 .232 r
.25095 .37008 .25974 .36466 .27051 .37046 .26114 .38347 Mtetra
.76 .395 .365 r
.26114 .38347 .27051 .37046 .28099 .38173 .27097 .40388 Mtetra
.749 .417 .42 r
.27097 .40388 .28099 .38173 .29117 .39929 .28054 .4306 Mtetra
.73 .414 .444 r
.28054 .4306 .29117 .39929 .30116 .4226 .29015 .46069 Mtetra
.702 .393 .45 r
.29015 .46069 .30116 .4226 .31119 .44919 .30019 .48891 Mtetra
.657 .348 .437 r
.30019 .48891 .31119 .44919 .32158 .47452 .31105 .50881 Mtetra
.564 .246 .388 r
.31105 .50881 .32158 .47452 .33264 .49288 .32299 .51477 Mtetra
.209 0 .151 r
.32299 .51477 .33264 .49288 .34458 .49917 .336 .5043 Mtetra
.96 .945 .691 r
.336 .5043 .34458 .49917 .35739 .49092 .3498 .47914 Mtetra
.891 .72 .662 r
.3498 .47914 .35739 .49092 .37085 .46937 .36397 .44448 Mtetra
.828 .63 .635 r
.36397 .44448 .37085 .46937 .38462 .43887 .3781 .4068 Mtetra
.79 .588 .628 r
.3781 .4068 .38462 .43887 .39838 .40515 .39193 .37164 Mtetra
.762 .567 .633 r
.39193 .37164 .39838 .40515 .4119 .37325 .40536 .34236 Mtetra
.74 .558 .648 r
.40536 .34236 .4119 .37325 .42511 .34636 .41842 .32001 Mtetra
.721 .561 .672 r
.41842 .32001 .42511 .34636 .43804 .32559 .4312 .30393 Mtetra
.703 .573 .706 r
.4312 .30393 .43804 .32559 .45075 .31044 .44383 .29264 Mtetra
.687 .593 .746 r
.44383 .29264 .45075 .31044 .46336 .29963 .45638 .2845 Mtetra
.674 .615 .782 r
.45638 .2845 .46336 .29963 .47592 .29169 .46893 .27819 Mtetra
.665 .634 .809 r
.46893 .27819 .47592 .29169 .4885 .28539 .48152 .27278 Mtetra
.662 .647 .825 r
.48152 .27278 .4885 .28539 .50111 .27987 .49414 .26772 Mtetra
.662 .656 .833 r
.49414 .26772 .50111 .27987 .51377 .27462 .50683 .26272 Mtetra
.665 .662 .838 r
.50683 .26272 .51377 .27462 .52648 .26939 .51956 .25767 Mtetra
.667 .668 .841 r
.51956 .25767 .52648 .26939 .53924 .26407 .53236 .25253 Mtetra
.67 .673 .844 r
.53236 .25253 .53924 .26407 .55206 .25864 .5452 .2473 Mtetra
.672 .678 .848 r
.5452 .2473 .55206 .25864 .56493 .25313 .5581 .242 Mtetra
.673 .684 .852 r
.5581 .242 .56493 .25313 .57785 .24755 .57106 .23666 Mtetra
.675 .69 .857 r
.57106 .23666 .57785 .24755 .59082 .24195 .58407 .2313 Mtetra
.675 .696 .862 r
.58407 .2313 .59082 .24195 .60385 .23636 .59713 .22595 Mtetra
.675 .703 .867 r
.59713 .22595 .60385 .23636 .61693 .2308 .61026 .22062 Mtetra
.675 .708 .873 r
.61026 .22062 .61693 .2308 .63006 .22529 .62344 .21532 Mtetra
.674 .714 .878 r
.62344 .21532 .63006 .22529 .64326 .21985 .63668 .21007 Mtetra
.673 .719 .883 r
.63668 .21007 .64326 .21985 .65651 .21448 .64998 .20486 Mtetra
.672 .723 .888 r
.64998 .20486 .65651 .21448 .66983 .20919 .66334 .1997 Mtetra
.671 .727 .892 r
.66334 .1997 .66983 .20919 .68321 .20396 .67677 .19458 Mtetra
.67 .73 .895 r
.67677 .19458 .68321 .20396 .69665 .1988 .69027 .1895 Mtetra
.668 .733 .898 r
.69027 .1895 .69665 .1988 .71016 .19369 .70382 .18444 Mtetra
.667 .735 .901 r
.70382 .18444 .71016 .19369 .72374 .18862 .71745 .17941 Mtetra
.667 .737 .903 r
.71745 .17941 .72374 .18862 .73738 .18358 .73114 .17439 Mtetra
.666 .738 .904 r
.73114 .17439 .73738 .18358 .75109 .17857 .7449 .16937 Mtetra
.665 .739 .905 r
.7449 .16937 .75109 .17857 .76487 .17356 .75873 .16436 Mtetra
.665 .74 .906 r
.75873 .16436 .76487 .17356 .77871 .16856 .77262 .15934 Mtetra
.664 .74 .907 r
.77262 .15934 .77871 .16856 .79262 .16355 .78658 .1543 Mtetra
.659 .741 .911 r
.15451 .37047 .16246 .37781 .1736 .37386 .16568 .36659 Mtetra
.65 .742 .917 r
.16568 .36659 .1736 .37386 .18479 .36999 .17687 .36292 Mtetra
.63 .743 .929 r
.17687 .36292 .18479 .36999 .19601 .3663 .18806 .35977 Mtetra
.576 .744 .957 r
.18806 .35977 .19601 .3663 .20723 .36306 .19919 .35768 Mtetra
.406 .717 .987 r
.19919 .35768 .20723 .36306 .21842 .36077 .21018 .35761 Mtetra
0 .414 .733 r
.21018 .35761 .21842 .36077 .22949 .36029 .22092 .36094 Mtetra
.672 .147 0 r
.22092 .36094 .22949 .36029 .24037 .36286 .2313 .36939 Mtetra
.76 .35 .273 r
.2313 .36939 .24037 .36286 .25095 .37008 .24122 .38458 Mtetra
.766 .411 .383 r
.24122 .38458 .25095 .37008 .26114 .38347 .25068 .40734 Mtetra
.754 .427 .43 r
.25068 .40734 .26114 .38347 .27097 .40388 .25984 .43676 Mtetra
.736 .422 .449 r
.25984 .43676 .27097 .40388 .28054 .4306 .26905 .46947 Mtetra
.708 .399 .452 r
.26905 .46947 .28054 .4306 .29015 .46069 .27876 .49968 Mtetra
.663 .352 .436 r
.27876 .49968 .29015 .46069 .30019 .48891 .28945 .52034 Mtetra
.557 .231 .371 r
.28945 .52034 .30019 .48891 .31105 .50881 .30141 .52552 Mtetra
0 0 0 r
.30141 .52552 .31105 .50881 .32299 .51477 .31462 .51286 Mtetra
.946 .838 .705 r
.31462 .51286 .32299 .51477 .336 .5043 .32876 .48463 Mtetra
.853 .662 .644 r
.32876 .48463 .336 .5043 .3498 .47914 .34331 .44669 Mtetra
.805 .598 .623 r
.34331 .44669 .3498 .47914 .36397 .44448 .3578 .40609 Mtetra
.774 .567 .618 r
.3578 .40609 .36397 .44448 .3781 .4068 .37192 .36866 Mtetra
.752 .551 .624 r
.37192 .36866 .3781 .4068 .39193 .37164 .38556 .33782 Mtetra
.734 .547 .64 r
.38556 .33782 .39193 .37164 .40536 .34236 .39874 .31448 Mtetra
.718 .553 .666 r
.39874 .31448 .40536 .34236 .41842 .32001 .41159 .29785 Mtetra
.703 .57 .703 r
.41159 .29785 .41842 .32001 .4312 .30393 .42424 .28628 Mtetra
.689 .596 .747 r
.42424 .28628 .4312 .30393 .44383 .29264 .43679 .27804 Mtetra
.676 .624 .789 r
.43679 .27804 .44383 .29264 .45638 .2845 .44932 .27173 Mtetra
.667 .647 .82 r
.44932 .27173 .45638 .2845 .46893 .27819 .46188 .26638 Mtetra
.663 .662 .839 r
.46188 .26638 .46893 .27819 .48152 .27278 .47447 .26143 Mtetra
.662 .671 .848 r
.47447 .26143 .48152 .27278 .49414 .26772 .48713 .25658 Mtetra
.663 .677 .853 r
.48713 .25658 .49414 .26772 .50683 .26272 .49983 .25171 Mtetra
.665 .681 .855 r
.49983 .25171 .50683 .26272 .51956 .25767 .5126 .24676 Mtetra
.667 .685 .857 r
.5126 .24676 .51956 .25767 .53236 .25253 .52542 .24174 Mtetra
.669 .689 .86 r
.52542 .24174 .53236 .25253 .5452 .2473 .5383 .23665 Mtetra
.67 .693 .863 r
.5383 .23665 .5452 .2473 .5581 .242 .55124 .23151 Mtetra
.671 .698 .866 r
.55124 .23151 .5581 .242 .57106 .23666 .56423 .22634 Mtetra
.672 .703 .87 r
.56423 .22634 .57106 .23666 .58407 .2313 .57727 .22116 Mtetra
.672 .708 .875 r
.57727 .22116 .58407 .2313 .59713 .22595 .59038 .21598 Mtetra
.672 .713 .879 r
.59038 .21598 .59713 .22595 .61026 .22062 .60355 .2108 Mtetra
.672 .717 .883 r
.60355 .2108 .61026 .22062 .62344 .21532 .61677 .20565 Mtetra
.671 .722 .887 r
.61677 .20565 .62344 .21532 .63668 .21007 .63006 .20052 Mtetra
.67 .725 .891 r
.63006 .20052 .63668 .21007 .64998 .20486 .64341 .19542 Mtetra
.669 .729 .894 r
.64341 .19542 .64998 .20486 .66334 .1997 .65682 .19034 Mtetra
.669 .731 .897 r
.65682 .19034 .66334 .1997 .67677 .19458 .67029 .18528 Mtetra
.668 .734 .899 r
.67029 .18528 .67677 .19458 .69027 .1895 .68383 .18024 Mtetra
.667 .736 .901 r
.68383 .18024 .69027 .1895 .70382 .18444 .69744 .17521 Mtetra
.666 .737 .903 r
.69744 .17521 .70382 .18444 .71745 .17941 .71111 .17019 Mtetra
.665 .738 .904 r
.71111 .17019 .71745 .17941 .73114 .17439 .72485 .16516 Mtetra
.665 .739 .905 r
.72485 .16516 .73114 .17439 .7449 .16937 .73866 .16014 Mtetra
.665 .74 .906 r
.73866 .16014 .7449 .16937 .75873 .16436 .75254 .1551 Mtetra
.664 .74 .907 r
.75254 .1551 .75873 .16436 .77262 .15934 .76648 .15005 Mtetra
.664 .741 .907 r
.76648 .15005 .77262 .15934 .78658 .1543 .78049 .14498 Mtetra
.649 .742 .918 r
.1465 .36318 .15451 .37047 .16568 .36659 .15766 .35953 Mtetra
.626 .744 .932 r
.15766 .35953 .16568 .36659 .17687 .36292 .16881 .35645 Mtetra
.565 .744 .961 r
.16881 .35645 .17687 .36292 .18806 .35977 .17989 .35453 Mtetra
.365 .704 .985 r
.17989 .35453 .18806 .35977 .19919 .35768 .1908 .35479 Mtetra
.261 0 0 r
.1908 .35479 .19919 .35768 .21018 .35761 .20141 .35871 Mtetra
.7 .194 .031 r
.20141 .35871 .21018 .35761 .22092 .36094 .2116 .36807 Mtetra
.768 .367 .294 r
.2116 .36807 .22092 .36094 .2313 .36939 .22126 .38454 Mtetra
.771 .42 .392 r
.22126 .38454 .2313 .36939 .24122 .38458 .23041 .40887 Mtetra
.76 .434 .434 r
.23041 .40887 .24122 .38458 .25068 .40734 .23921 .43995 Mtetra
.742 .428 .451 r
.23921 .43995 .25068 .40734 .25984 .43676 .24806 .47409 Mtetra
.715 .404 .45 r
.24806 .47409 .25984 .43676 .26905 .46947 .2575 .50507 Mtetra
.669 .352 .428 r
.2575 .50507 .26905 .46947 .27876 .49968 .26806 .52555 Mtetra
.543 .199 .334 r
.26806 .52555 .27876 .49968 .28945 .52034 .28005 .52953 Mtetra
.594 .872 .548 r
.28005 .52953 .28945 .52034 .30141 .52552 .29346 .51491 Mtetra
.887 .731 .683 r
.29346 .51491 .30141 .52552 .31462 .51286 .30789 .48444 Mtetra
.818 .616 .63 r
.30789 .48444 .31462 .51286 .32876 .48463 .32277 .44444 Mtetra
.783 .571 .613 r
.32277 .44444 .32876 .48463 .34331 .44669 .33757 .40225 Mtetra
.759 .548 .611 r
.33757 .40225 .34331 .44669 .3578 .40609 .35193 .36378 Mtetra
.741 .537 .618 r
.35193 .36378 .3578 .40609 .37192 .36866 .36574 .33235 Mtetra
.726 .536 .634 r
.36574 .33235 .37192 .36866 .38556 .33782 .37902 .30874 Mtetra
.713 .546 .662 r
.37902 .30874 .38556 .33782 .39874 .31448 .39193 .292 Mtetra
.701 .568 .701 r
.39193 .292 .39874 .31448 .41159 .29785 .40459 .2804 Mtetra
.69 .599 .749 r
.40459 .2804 .41159 .29785 .42424 .28628 .41713 .27217 Mtetra
.678 .632 .796 r
.41713 .27217 .42424 .28628 .43679 .27804 .42965 .26588 Mtetra
.669 .659 .831 r
.42965 .26588 .43679 .27804 .44932 .27173 .44218 .26057 Mtetra
.664 .676 .852 r
.44218 .26057 .44932 .27173 .46188 .26638 .45475 .25569 Mtetra
.662 .686 .862 r
.45475 .25569 .46188 .26638 .47447 .26143 .46737 .25093 Mtetra
.663 .691 .866 r
.46737 .25093 .47447 .26143 .48713 .25658 .48005 .24617 Mtetra
.664 .694 .868 r
.48005 .24617 .48713 .25658 .49983 .25171 .49279 .24135 Mtetra
.665 .697 .869 r
.49279 .24135 .49983 .25171 .5126 .24676 .50558 .23647 Mtetra
.667 .7 .871 r
.50558 .23647 .5126 .24676 .52542 .24174 .51844 .23153 Mtetra
.668 .703 .873 r
.51844 .23153 .52542 .24174 .5383 .23665 .53135 .22654 Mtetra
.669 .706 .875 r
.53135 .22654 .5383 .23665 .55124 .23151 .54432 .22151 Mtetra
.67 .71 .878 r
.54432 .22151 .55124 .23151 .56423 .22634 .55735 .21645 Mtetra
.67 .714 .881 r
.55735 .21645 .56423 .22634 .57727 .22116 .57044 .21139 Mtetra
.67 .718 .884 r
.57044 .21139 .57727 .22116 .59038 .21598 .58358 .20631 Mtetra
.67 .721 .888 r
.58358 .20631 .59038 .21598 .60355 .2108 .59679 .20124 Mtetra
.669 .724 .891 r
.59679 .20124 .60355 .2108 .61677 .20565 .61006 .19618 Mtetra
.669 .728 .894 r
.61006 .19618 .61677 .20565 .63006 .20052 .62339 .19113 Mtetra
.668 .73 .896 r
.62339 .19113 .63006 .20052 .64341 .19542 .63678 .18608 Mtetra
.667 .733 .899 r
.63678 .18608 .64341 .19542 .65682 .19034 .65024 .18105 Mtetra
.667 .735 .901 r
.65024 .18105 .65682 .19034 .67029 .18528 .66376 .17602 Mtetra
.666 .736 .902 r
.66376 .17602 .67029 .18528 .68383 .18024 .67735 .17099 Mtetra
.666 .737 .904 r
.67735 .17099 .68383 .18024 .69744 .17521 .691 .16597 Mtetra
.665 .738 .905 r
.691 .16597 .69744 .17521 .71111 .17019 .70472 .16093 Mtetra
.665 .739 .906 r
.70472 .16093 .71111 .17019 .72485 .16516 .71851 .15589 Mtetra
.664 .74 .906 r
.71851 .15589 .72485 .16516 .73866 .16014 .73237 .15084 Mtetra
.664 .74 .907 r
.73237 .15084 .73866 .16014 .75254 .1551 .74629 .14577 Mtetra
.664 .741 .907 r
.74629 .14577 .75254 .1551 .76648 .15005 .76028 .14069 Mtetra
.76028 .14069 .76648 .15005 .78049 .14498 .77434 .13558 Mtetra
.623 .744 .933 r
.13838 .35613 .1465 .36318 .15766 .35953 .14949 .35309 Mtetra
.557 .743 .963 r
.14949 .35309 .15766 .35953 .16881 .35645 .16052 .35128 Mtetra
.338 .694 .982 r
.16052 .35128 .16881 .35645 .17989 .35453 .17136 .35175 Mtetra
.314 0 0 r
.17136 .35175 .17989 .35453 .1908 .35479 .18187 .35602 Mtetra
.713 .216 .056 r
.18187 .35602 .1908 .35479 .20141 .35871 .1919 .36587 Mtetra
.773 .376 .301 r
.1919 .36587 .20141 .35871 .2116 .36807 .20135 .38294 Mtetra
.775 .425 .393 r
.20135 .38294 .2116 .36807 .22126 .38454 .21024 .40787 Mtetra
.765 .438 .433 r
.21024 .40787 .22126 .38454 .23041 .40887 .21877 .43936 Mtetra
.749 .432 .447 r
.21877 .43936 .23041 .40887 .23921 .43995 .22736 .47351 Mtetra
.724 .408 .444 r
.22736 .47351 .23921 .43995 .24806 .47409 .23662 .50392 Mtetra
.678 .35 .412 r
.23662 .50392 .24806 .47409 .2575 .50507 .24709 .52323 Mtetra
.513 .13 .251 r
.24709 .52323 .2575 .50507 .26806 .52555 .25914 .52568 Mtetra
.905 .939 .82 r
.25914 .52568 .26806 .52555 .28005 .52953 .2727 .50953 Mtetra
.832 .653 .66 r
.2727 .50953 .28005 .52953 .29346 .51491 .28735 .47787 Mtetra
.788 .58 .619 r
.28735 .47787 .29346 .51491 .30789 .48444 .30247 .43724 Mtetra
.763 .548 .607 r
.30247 .43724 .30789 .48444 .32277 .44444 .31747 .39495 Mtetra
.745 .532 .606 r
.31747 .39495 .32277 .44444 .33757 .40225 .332 .35676 Mtetra
.73 .525 .614 r
.332 .35676 .33757 .40225 .35193 .36378 .34592 .32577 Mtetra
.718 .528 .631 r
.34592 .32577 .35193 .36378 .36574 .33235 .35927 .30261 Mtetra
.708 .541 .66 r
.35927 .30261 .36574 .33235 .37902 .30874 .37221 .28622 Mtetra
.699 .566 .702 r
.37221 .28622 .37902 .30874 .39193 .292 .38487 .27486 Mtetra
.69 .602 .753 r
.38487 .27486 .39193 .292 .40459 .2804 .39741 .26676 Mtetra
.68 .639 .803 r
.39741 .26676 .40459 .2804 .41713 .27217 .4099 .26054 Mtetra
.671 .669 .84 r
.4099 .26054 .41713 .27217 .42965 .26588 .42241 .25527 Mtetra
.665 .688 .862 r
.42241 .25527 .42965 .26588 .44218 .26057 .43495 .25042 Mtetra
.663 .698 .873 r
.43495 .25042 .44218 .26057 .45475 .25569 .44755 .24571 Mtetra
.662 .703 .877 r
.44755 .24571 .45475 .25569 .46737 .25093 .4602 .24101 Mtetra
.663 .706 .879 r
.4602 .24101 .46737 .25093 .48005 .24617 .47291 .23627 Mtetra
.664 .708 .88 r
.47291 .23627 .48005 .24617 .49279 .24135 .48568 .23148 Mtetra
.665 .709 .881 r
.48568 .23148 .49279 .24135 .50558 .23647 .49851 .22664 Mtetra
.666 .712 .882 r
.49851 .22664 .50558 .23647 .51844 .23153 .5114 .22174 Mtetra
.667 .714 .883 r
.5114 .22174 .51844 .23153 .53135 .22654 .52435 .21681 Mtetra
.668 .717 .885 r
.52435 .21681 .53135 .22654 .54432 .22151 .53735 .21185 Mtetra
.668 .719 .887 r
.53735 .21185 .54432 .22151 .55735 .21645 .55042 .20687 Mtetra
.668 .722 .89 r
.55042 .20687 .55735 .21645 .57044 .21139 .56355 .20187 Mtetra
.668 .725 .892 r
.56355 .20187 .57044 .21139 .58358 .20631 .57673 .19686 Mtetra
.668 .727 .894 r
.57673 .19686 .58358 .20631 .59679 .20124 .58998 .19185 Mtetra
.667 .73 .896 r
.58998 .19185 .59679 .20124 .61006 .19618 .6033 .18683 Mtetra
.667 .732 .898 r
.6033 .18683 .61006 .19618 .62339 .19113 .61667 .18182 Mtetra
.666 .734 .9 r
.61667 .18182 .62339 .19113 .63678 .18608 .63011 .1768 Mtetra
.666 .735 .902 r
.63011 .1768 .63678 .18608 .65024 .18105 .64361 .17178 Mtetra
.666 .737 .903 r
.64361 .17178 .65024 .18105 .66376 .17602 .65718 .16676 Mtetra
.665 .738 .904 r
.65718 .16676 .66376 .17602 .67735 .17099 .67081 .16173 Mtetra
.665 .739 .905 r
.67081 .16173 .67735 .17099 .691 .16597 .68451 .15669 Mtetra
.665 .739 .906 r
.68451 .15669 .691 .16597 .70472 .16093 .69828 .15163 Mtetra
.664 .74 .906 r
.69828 .15163 .70472 .16093 .71851 .15589 .71212 .14657 Mtetra
.664 .74 .907 r
.71212 .14657 .71851 .15589 .73237 .15084 .72602 .14148 Mtetra
.664 .741 .907 r
.72602 .14148 .73237 .15084 .74629 .14577 .73999 .13638 Mtetra
.73999 .13638 .74629 .14577 .76028 .14069 .75403 .13125 Mtetra
.664 .741 .908 r
.75403 .13125 .76028 .14069 .77434 .13558 .76814 .12611 Mtetra
.553 .742 .964 r
.13011 .34967 .13838 .35613 .14949 .35309 .14109 .34789 Mtetra
.329 .69 .98 r
.14109 .34789 .14949 .35309 .16052 .35128 .15187 .34842 Mtetra
.321 0 0 r
.15187 .34842 .16052 .35128 .17136 .35175 .1623 .35275 Mtetra
.714 .215 .051 r
.1623 .35275 .17136 .35175 .18187 .35602 .17222 .3626 Mtetra
.776 .375 .295 r
.17222 .3626 .18187 .35602 .1919 .36587 .18153 .37952 Mtetra
.779 .426 .387 r
.18153 .37952 .1919 .36587 .20135 .38294 .19026 .40399 Mtetra
.771 .439 .426 r
.19026 .40399 .20135 .38294 .21024 .40787 .19863 .43459 Mtetra
.756 .434 .439 r
.19863 .43459 .21024 .40787 .21877 .43936 .20709 .46729 Mtetra
.734 .409 .43 r
.20709 .46729 .21877 .43936 .22736 .47351 .21626 .49582 Mtetra
.689 .341 .381 r
.21626 .49582 .22736 .47351 .23662 .50392 .22673 .51311 Mtetra
.414 0 .019 r
.22673 .51311 .23662 .50392 .24709 .52323 .23883 .51384 Mtetra
.84 .749 .763 r
.23883 .51384 .24709 .52323 .25914 .52568 .2525 .49671 Mtetra
.789 .598 .643 r
.2525 .49671 .25914 .52568 .2727 .50953 .26726 .46504 Mtetra
.763 .552 .612 r
.26726 .46504 .2727 .50953 .28735 .47787 .28249 .42525 Mtetra
.745 .53 .603 r
.28249 .42525 .28735 .47787 .30247 .43724 .29758 .38435 Mtetra
.731 .519 .603 r
.29758 .38435 .30247 .43724 .31747 .39495 .31217 .3477 Mtetra
.72 .515 .613 r
.31217 .3477 .31747 .39495 .332 .35676 .32613 .31812 Mtetra
.711 .521 .631 r
.32613 .31812 .332 .35676 .34592 .32577 .3395 .29606 Mtetra
.703 .538 .661 r
.3395 .29606 .34592 .32577 .35927 .30261 .35243 .28043 Mtetra
.696 .567 .705 r
.35243 .28043 .35927 .30261 .37221 .28622 .36509 .26953 Mtetra
.689 .606 .759 r
.36509 .26953 .37221 .28622 .38487 .27486 .37761 .26168 Mtetra
.68 .647 .811 r
.37761 .26168 .38487 .27486 .39741 .26676 .39008 .25558 Mtetra
.671 .679 .849 r
.39008 .25558 .39741 .26676 .4099 .26054 .40256 .25036 Mtetra
.666 .699 .871 r
.40256 .25036 .4099 .26054 .42241 .25527 .41508 .24554 Mtetra
.663 .709 .882 r
.41508 .24554 .42241 .25527 .43495 .25042 .42765 .24085 Mtetra
.662 .713 .886 r
.42765 .24085 .43495 .25042 .44755 .24571 .44028 .23617 Mtetra
.663 .715 .887 r
.44028 .23617 .44755 .24571 .4602 .24101 .45296 .23147 Mtetra
.664 .717 .888 r
.45296 .23147 .4602 .24101 .47291 .23627 .46571 .22673 Mtetra
.664 .718 .888 r
.46571 .22673 .47291 .23627 .48568 .23148 .47851 .22194 Mtetra
.665 .719 .889 r
.47851 .22194 .48568 .23148 .49851 .22664 .49138 .21711 Mtetra
.666 .721 .89 r
.49138 .21711 .49851 .22664 .5114 .22174 .5043 .21225 Mtetra
.666 .722 .891 r
.5043 .21225 .5114 .22174 .52435 .21681 .51728 .20735 Mtetra
.666 .724 .893 r
.51728 .20735 .52435 .21681 .53735 .21185 .53033 .20242 Mtetra
.667 .726 .894 r
.53033 .20242 .53735 .21185 .55042 .20687 .54344 .19747 Mtetra
.667 .728 .896 r
.54344 .19747 .55042 .20687 .56355 .20187 .5566 .19251 Mtetra
.666 .73 .897 r
.5566 .19251 .56355 .20187 .57673 .19686 .56983 .18754 Mtetra
.666 .732 .899 r
.56983 .18754 .57673 .19686 .58998 .19185 .58312 .18255 Mtetra
.666 .734 .9 r
.58312 .18255 .58998 .19185 .6033 .18683 .59648 .17755 Mtetra
.666 .735 .902 r
.59648 .17755 .6033 .18683 .61667 .18182 .6099 .17255 Mtetra
.665 .736 .903 r
.6099 .17255 .61667 .18182 .63011 .1768 .62338 .16753 Mtetra
.665 .738 .904 r
.62338 .16753 .63011 .1768 .64361 .17178 .63693 .16251 Mtetra
.665 .738 .905 r
.63693 .16251 .64361 .17178 .65718 .16676 .65054 .15747 Mtetra
.665 .739 .906 r
.65054 .15747 .65718 .16676 .67081 .16173 .66422 .15242 Mtetra
.664 .74 .906 r
.66422 .15242 .67081 .16173 .68451 .15669 .67797 .14736 Mtetra
.664 .74 .907 r
.67797 .14736 .68451 .15669 .69828 .15163 .69178 .14227 Mtetra
.69178 .14227 .69828 .15163 .71212 .14657 .70566 .13717 Mtetra
.664 .741 .907 r
.70566 .13717 .71212 .14657 .72602 .14148 .71961 .13205 Mtetra
.71961 .13205 .72602 .14148 .73999 .13638 .73363 .12691 Mtetra
.664 .741 .908 r
.73363 .12691 .73999 .13638 .75403 .13125 .74772 .12174 Mtetra
.74772 .12174 .75403 .13125 .76814 .12611 .76188 .11655 Mtetra
.342 .694 .982 r
.12161 .34436 .13011 .34967 .14109 .34789 .13235 .34478 Mtetra
.282 0 0 r
.13235 .34478 .14109 .34789 .15187 .34842 .14272 .34886 Mtetra
.703 .192 .014 r
.14272 .34886 .15187 .34842 .1623 .35275 .15259 .35823 Mtetra
.776 .365 .274 r
.15259 .35823 .1623 .35275 .17222 .3626 .16184 .37425 Mtetra
.783 .421 .372 r
.16184 .37425 .17222 .3626 .18153 .37952 .17052 .39726 Mtetra
.777 .437 .412 r
.17052 .39726 .18153 .37952 .19026 .40399 .17886 .42571 Mtetra
.765 .432 .423 r
.17886 .42571 .19026 .40399 .19863 .43459 .18732 .45569 Mtetra
.746 .406 .407 r
.18732 .45569 .19863 .43459 .20709 .46729 .19653 .48122 Mtetra
.703 .32 .32 r
.19653 .48122 .20709 .46729 .21626 .49582 .20705 .49583 Mtetra
.116 .668 .777 r
.20705 .49583 .21626 .49582 .22673 .51311 .21921 .49484 Mtetra
.774 .637 .71 r
.21921 .49484 .22673 .51311 .23883 .51384 .2329 .4774 Mtetra
.756 .56 .631 r
.2329 .4774 .23883 .51384 .2525 .49671 .24766 .44684 Mtetra
.742 .53 .608 r
.24766 .44684 .2525 .49671 .26726 .46504 .26286 .40923 Mtetra
.73 .515 .601 r
.26286 .40923 .26726 .46504 .28249 .42525 .27791 .37099 Mtetra
.719 .508 .603 r
.27791 .37099 .28249 .42525 .29758 .38435 .29246 .33696 Mtetra
.711 .508 .613 r
.29246 .33696 .29758 .38435 .31217 .3477 .30637 .30958 Mtetra
.703 .517 .633 r
.30637 .30958 .31217 .3477 .32613 .31812 .31971 .28915 Mtetra
.698 .537 .666 r
.31971 .28915 .32613 .31812 .3395 .29606 .33261 .27462 Mtetra
.693 .57 .712 r
.33261 .27462 .3395 .29606 .35243 .28043 .34524 .26437 Mtetra
.687 .613 .767 r
.34524 .26437 .35243 .28043 .36509 .26953 .35773 .25686 Mtetra
.679 .656 .819 r
.35773 .25686 .36509 .26953 .37761 .26168 .37018 .25091 Mtetra
.672 .688 .857 r
.37018 .25091 .37761 .26168 .39008 .25558 .38264 .24575 Mtetra
.666 .708 .879 r
.38264 .24575 .39008 .25558 .40256 .25036 .39513 .24094 Mtetra
.663 .717 .889 r
.39513 .24094 .40256 .25036 .41508 .24554 .40768 .23626 Mtetra
.663 .721 .893 r
.40768 .23626 .41508 .24554 .42765 .24085 .42028 .23159 Mtetra
.663 .723 .894 r
.42028 .23159 .42765 .24085 .44028 .23617 .43294 .2269 Mtetra
.663 .724 .894 r
.43294 .2269 .44028 .23617 .45296 .23147 .44566 .22218 Mtetra
.664 .725 .894 r
.44566 .22218 .45296 .23147 .46571 .22673 .45844 .21743 Mtetra
.664 .725 .895 r
.45844 .21743 .46571 .22673 .47851 .22194 .47128 .21263 Mtetra
.665 .726 .895 r
.47128 .21263 .47851 .22194 .49138 .21711 .48418 .2078 Mtetra
.665 .727 .896 r
.48418 .2078 .49138 .21711 .5043 .21225 .49714 .20294 Mtetra
.665 .729 .897 r
.49714 .20294 .5043 .21225 .51728 .20735 .51016 .19805 Mtetra
.665 .73 .898 r
.51016 .19805 .51728 .20735 .53033 .20242 .52325 .19313 Mtetra
.665 .731 .899 r
.52325 .19313 .53033 .20242 .54344 .19747 .53639 .1882 Mtetra
.665 .733 .9 r
.53639 .1882 .54344 .19747 .5566 .19251 .5496 .18324 Mtetra
.665 .734 .901 r
.5496 .18324 .5566 .19251 .56983 .18754 .56287 .17827 Mtetra
.665 .735 .902 r
.56287 .17827 .56983 .18754 .58312 .18255 .5762 .17329 Mtetra
.665 .736 .903 r
.5762 .17329 .58312 .18255 .59648 .17755 .5896 .16829 Mtetra
.665 .737 .904 r
.5896 .16829 .59648 .17755 .6099 .17255 .60306 .16328 Mtetra
.665 .738 .905 r
.60306 .16328 .6099 .17255 .62338 .16753 .61659 .15825 Mtetra
.664 .739 .905 r
.61659 .15825 .62338 .16753 .63693 .16251 .63018 .1532 Mtetra
.664 .739 .906 r
.63018 .1532 .63693 .16251 .65054 .15747 .64384 .14814 Mtetra
.664 .74 .906 r
.64384 .14814 .65054 .15747 .66422 .15242 .65757 .14306 Mtetra
.664 .74 .907 r
.65757 .14306 .66422 .15242 .67797 .14736 .67136 .13796 Mtetra
.664 .741 .907 r
.67136 .13796 .67797 .14736 .69178 .14227 .68522 .13284 Mtetra
.68522 .13284 .69178 .14227 .70566 .13717 .69915 .1277 Mtetra
.664 .741 .908 r
.69915 .1277 .70566 .13717 .71961 .13205 .71315 .12254 Mtetra
.71315 .12254 .71961 .13205 .73363 .12691 .72722 .11735 Mtetra
.72722 .11735 .73363 .12691 .74772 .12174 .74135 .11214 Mtetra
.74135 .11214 .74772 .12174 .76188 .11655 .75556 .1069 Mtetra
0 .382 .712 r
.11279 .34083 .12161 .34436 .13235 .34478 .12315 .3444 Mtetra
.674 .14 0 r
.12315 .3444 .13235 .34478 .14272 .34886 .13302 .35283 Mtetra
.771 .343 .233 r
.13302 .35283 .14272 .34886 .15259 .35823 .1423 .3673 Mtetra
.785 .409 .344 r
.1423 .3673 .15259 .35823 .16184 .37425 .15104 .38798 Mtetra
.782 .43 .388 r
.15104 .38798 .16184 .37425 .17052 .39726 .15947 .4133 Mtetra
.774 .427 .397 r
.15947 .4133 .17052 .39726 .17886 .42571 .16807 .43955 Mtetra
.761 .397 .366 r
.16807 .43955 .17886 .42571 .18732 .45569 .17742 .46131 Mtetra
.711 .262 .183 r
.17742 .46131 .18732 .45569 .19653 .48122 .18804 .47287 Mtetra
.589 .72 .934 r
.18804 .47287 .19653 .48122 .20705 .49583 .20023 .47033 Mtetra
.732 .575 .679 r
.20023 .47033 .20705 .49583 .21921 .49484 .21388 .45321 Mtetra
.731 .534 .624 r
.21388 .45321 .21921 .49484 .2329 .4774 .22852 .42472 Mtetra
.724 .514 .606 r
.22852 .42472 .2329 .4774 .24766 .44684 .24355 .39033 Mtetra
.716 .504 .601 r
.24355 .39033 .24766 .44684 .26286 .40923 .25844 .35573 Mtetra
.709 .501 .605 r
.25844 .35573 .26286 .40923 .27791 .37099 .27284 .32508 Mtetra
.702 .504 .617 r
.27284 .32508 .27791 .37099 .29246 .33696 .28664 .30047 Mtetra
.697 .516 .639 r
.28664 .30047 .29246 .33696 .30637 .30958 .29989 .28204 Mtetra
.693 .539 .674 r
.29989 .28204 .30637 .30958 .31971 .28915 .31273 .26881 Mtetra
.69 .576 .722 r
.31273 .26881 .31971 .28915 .33261 .27462 .32532 .25933 Mtetra
.685 .621 .778 r
.32532 .25933 .33261 .27462 .34524 .26437 .33778 .25222 Mtetra
.678 .665 .829 r
.33778 .25222 .34524 .26437 .35773 .25686 .3502 .24645 Mtetra
.671 .696 .865 r
.3502 .24645 .35773 .25686 .37018 .25091 .36263 .24136 Mtetra
.666 .715 .885 r
.36263 .24136 .37018 .25091 .38264 .24575 .3751 .23656 Mtetra
.664 .724 .894 r
.3751 .23656 .38264 .24575 .39513 .24094 .38762 .23187 Mtetra
.663 .728 .897 r
.38762 .23187 .39513 .24094 .40768 .23626 .4002 .2272 Mtetra
.663 .729 .899 r
.4002 .2272 .40768 .23626 .42028 .23159 .41284 .22251 Mtetra
.41284 .22251 .42028 .23159 .43294 .2269 .42553 .2178 Mtetra
.663 .73 .899 r
.42553 .2178 .43294 .2269 .44566 .22218 .43829 .21305 Mtetra
.664 .73 .899 r
.43829 .21305 .44566 .22218 .45844 .21743 .4511 .20826 Mtetra
.664 .731 .899 r
.4511 .20826 .45844 .21743 .47128 .21263 .46398 .20345 Mtetra
.664 .731 .9 r
.46398 .20345 .47128 .21263 .48418 .2078 .47692 .1986 Mtetra
.665 .732 .9 r
.47692 .1986 .48418 .2078 .49714 .20294 .48992 .19373 Mtetra
.665 .733 .901 r
.48992 .19373 .49714 .20294 .51016 .19805 .50298 .18883 Mtetra
.665 .734 .901 r
.50298 .18883 .51016 .19805 .52325 .19313 .5161 .18391 Mtetra
.665 .735 .902 r
.5161 .18391 .52325 .19313 .53639 .1882 .52929 .17897 Mtetra
.665 .736 .903 r
.52929 .17897 .53639 .1882 .5496 .18324 .54254 .17401 Mtetra
.665 .737 .904 r
.54254 .17401 .5496 .18324 .56287 .17827 .55585 .16903 Mtetra
.665 .738 .904 r
.55585 .16903 .56287 .17827 .5762 .17329 .56923 .16403 Mtetra
.664 .738 .905 r
.56923 .16403 .5762 .17329 .5896 .16829 .58267 .15901 Mtetra
.664 .739 .906 r
.58267 .15901 .5896 .16829 .60306 .16328 .59617 .15397 Mtetra
.59617 .15397 .60306 .16328 .61659 .15825 .60974 .14892 Mtetra
.664 .74 .906 r
.60974 .14892 .61659 .15825 .63018 .1532 .62338 .14384 Mtetra
.664 .74 .907 r
.62338 .14384 .63018 .1532 .64384 .14814 .63709 .13875 Mtetra
.63709 .13875 .64384 .14814 .65757 .14306 .65086 .13363 Mtetra
.664 .741 .907 r
.65086 .13363 .65757 .14306 .67136 .13796 .6647 .1285 Mtetra
.6647 .1285 .67136 .13796 .68522 .13284 .6786 .12334 Mtetra
.664 .741 .908 r
.6786 .12334 .68522 .13284 .69915 .1277 .69258 .11815 Mtetra
.69258 .11815 .69915 .1277 .71315 .12254 .70663 .11294 Mtetra
.70663 .11294 .71315 .12254 .72722 .11735 .72074 .10771 Mtetra
.72074 .10771 .72722 .11735 .74135 .11214 .73493 .10246 Mtetra
.73493 .10246 .74135 .11214 .75556 .1069 .74919 .09717 Mtetra
.611 .046 0 r
.10359 .33944 .11279 .34083 .12315 .3444 .11351 .34659 Mtetra
.757 .3 .162 r
.11351 .34659 .12315 .3444 .13302 .35283 .12289 .35901 Mtetra
.784 .385 .298 r
.12289 .35901 .13302 .35283 .1423 .3673 .13179 .37673 Mtetra
.787 .413 .349 r
.13179 .37673 .1423 .3673 .15104 .38798 .14044 .39824 Mtetra
.784 .412 .352 r
.14044 .39824 .15104 .38798 .15947 .4133 .14928 .42016 Mtetra
.775 .371 .288 r
.14928 .42016 .15947 .4133 .16807 .43955 .15884 .43775 Mtetra
.63 .067 0 r
.15884 .43775 .16807 .43955 .17742 .46131 .1696 .4462 Mtetra
.624 .598 .804 r
.1696 .4462 .17742 .46131 .18804 .47287 .18181 .44237 Mtetra
.704 .54 .662 r
.18181 .44237 .18804 .47287 .20023 .47033 .19533 .42613 Mtetra
.712 .515 .622 r
.19533 .42613 .20023 .47033 .21388 .45321 .20975 .40039 Mtetra
.71 .503 .607 r
.20975 .40039 .21388 .45321 .22852 .42472 .22451 .36992 Mtetra
.705 .497 .604 r
.22451 .36992 .22852 .42472 .24355 .39033 .23913 .33953 Mtetra
.7 .496 .609 r
.23913 .33953 .24355 .39033 .25844 .35573 .25329 .31272 Mtetra
.695 .502 .623 r
.25329 .31272 .25844 .35573 .27284 .32508 .26692 .29115 Mtetra
.691 .518 .648 r
.26692 .29115 .27284 .32508 .28664 .30047 .28004 .27491 Mtetra
.689 .545 .685 r
.28004 .27491 .28664 .30047 .29989 .28204 .2928 .26308 Mtetra
.687 .585 .736 r
.2928 .26308 .29989 .28204 .31273 .26881 .30533 .2544 Mtetra
.683 .632 .792 r
.30533 .2544 .31273 .26881 .32532 .25933 .31775 .24771 Mtetra
.677 .674 .84 r
.31775 .24771 .32532 .25933 .33778 .25222 .33014 .24214 Mtetra
.67 .704 .872 r
.33014 .24214 .33778 .25222 .3502 .24645 .34255 .23711 Mtetra
.666 .721 .89 r
.34255 .23711 .3502 .24645 .36263 .24136 .35499 .23233 Mtetra
.664 .729 .898 r
.35499 .23233 .36263 .24136 .3751 .23656 .36749 .22763 Mtetra
.663 .732 .901 r
.36749 .22763 .3751 .23656 .38762 .23187 .38004 .22295 Mtetra
.663 .733 .902 r
.38004 .22295 .38762 .23187 .4002 .2272 .39265 .21825 Mtetra
.663 .734 .902 r
.39265 .21825 .4002 .2272 .41284 .22251 .40533 .21352 Mtetra
.40533 .21352 .41284 .22251 .42553 .2178 .41806 .20877 Mtetra
.664 .734 .902 r
.41806 .20877 .42553 .2178 .43829 .21305 .43085 .20399 Mtetra
.43085 .20399 .43829 .21305 .4511 .20826 .4437 .19917 Mtetra
.664 .735 .902 r
.4437 .19917 .4511 .20826 .46398 .20345 .45662 .19433 Mtetra
.664 .735 .903 r
.45662 .19433 .46398 .20345 .47692 .1986 .4696 .18946 Mtetra
.664 .736 .903 r
.4696 .18946 .47692 .1986 .48992 .19373 .48263 .18457 Mtetra
.48263 .18457 .48992 .19373 .50298 .18883 .49573 .17965 Mtetra
.664 .737 .904 r
.49573 .17965 .50298 .18883 .5161 .18391 .5089 .17471 Mtetra
.5089 .17471 .5161 .18391 .52929 .17897 .52212 .16975 Mtetra
.664 .738 .905 r
.52212 .16975 .52929 .17897 .54254 .17401 .53541 .16477 Mtetra
.53541 .16477 .54254 .17401 .55585 .16903 .54877 .15976 Mtetra
.664 .739 .906 r
.54877 .15976 .55585 .16903 .56923 .16403 .56219 .15474 Mtetra
.56219 .15474 .56923 .16403 .58267 .15901 .57567 .14969 Mtetra
.664 .74 .906 r
.57567 .14969 .58267 .15901 .59617 .15397 .58922 .14462 Mtetra
.664 .74 .907 r
.58922 .14462 .59617 .15397 .60974 .14892 .60284 .13953 Mtetra
.60284 .13953 .60974 .14892 .62338 .14384 .61652 .13442 Mtetra
.664 .741 .907 r
.61652 .13442 .62338 .14384 .63709 .13875 .63027 .12929 Mtetra
.63027 .12929 .63709 .13875 .65086 .13363 .64409 .12413 Mtetra
.664 .741 .908 r
.64409 .12413 .65086 .13363 .6647 .1285 .65797 .11895 Mtetra
.65797 .11895 .6647 .1285 .6786 .12334 .67193 .11375 Mtetra
.67193 .11375 .6786 .12334 .69258 .11815 .68595 .10852 Mtetra
.68595 .10852 .69258 .11815 .70663 .11294 .70004 .10327 Mtetra
.70004 .10327 .70663 .11294 .72074 .10771 .71421 .09799 Mtetra
.71421 .09799 .72074 .10771 .73493 .10246 .72844 .09268 Mtetra
.72844 .09268 .73493 .10246 .74919 .09717 .74275 .08735 Mtetra
.722 .221 .041 r
.09403 .33975 .10359 .33944 .11351 .34659 .10359 .34982 Mtetra
.775 .341 .219 r
.10359 .34982 .11351 .34659 .12289 .35901 .11272 .36425 Mtetra
.787 .38 .281 r
.11272 .36425 .12289 .35901 .13179 .37673 .12167 .38161 Mtetra
.789 .377 .271 r
.12167 .38161 .13179 .37673 .14044 .39824 .13082 .39899 Mtetra
.771 .3 .123 r
.13082 .39899 .14044 .39824 .14928 .42016 .14065 .41239 Mtetra
0 .363 .816 r
.14065 .41239 .14928 .42016 .15884 .43775 .15157 .41791 Mtetra
.625 .547 .746 r
.15157 .41791 .15884 .43775 .1696 .4462 .16376 .41313 Mtetra
.686 .519 .655 r
.16376 .41313 .1696 .4462 .18181 .44237 .1771 .39817 Mtetra
.697 .504 .623 r
.1771 .39817 .18181 .44237 .19533 .42613 .19121 .37557 Mtetra
.698 .496 .611 r
.19121 .37557 .19533 .42613 .20975 .40039 .20562 .34931 Mtetra
.695 .493 .609 r
.20562 .34931 .20975 .40039 .22451 .36992 .21989 .32333 Mtetra
.692 .495 .616 r
.21989 .32333 .22451 .36992 .23913 .33953 .23377 .30045 Mtetra
.689 .505 .633 r
.23377 .30045 .23913 .33953 .25329 .31272 .24717 .28199 Mtetra
.687 .524 .66 r
.24717 .28199 .25329 .31272 .26692 .29115 .26014 .26792 Mtetra
.686 .555 .701 r
.26014 .26792 .26692 .29115 .28004 .27491 .2728 .25748 Mtetra
.684 .598 .753 r
.2728 .25748 .28004 .27491 .2928 .26308 .28526 .2496 Mtetra
.681 .645 .807 r
.28526 .2496 .2928 .26308 .30533 .2544 .29764 .24331 Mtetra
.675 .685 .851 r
.29764 .24331 .30533 .2544 .31775 .24771 .31 .23792 Mtetra
.669 .711 .879 r
.31 .23792 .31775 .24771 .33014 .24214 .32238 .23296 Mtetra
.666 .726 .894 r
.32238 .23296 .33014 .24214 .34255 .23711 .3348 .22819 Mtetra
.664 .732 .901 r
.3348 .22819 .34255 .23711 .35499 .23233 .34727 .22348 Mtetra
.663 .735 .903 r
.34727 .22348 .35499 .23233 .36749 .22763 .3598 .21878 Mtetra
.663 .736 .904 r
.3598 .21878 .36749 .22763 .38004 .22295 .37239 .21407 Mtetra
.37239 .21407 .38004 .22295 .39265 .21825 .38504 .20933 Mtetra
.38504 .20933 .39265 .21825 .40533 .21352 .39775 .20456 Mtetra
.663 .737 .904 r
.39775 .20456 .40533 .21352 .41806 .20877 .41052 .19977 Mtetra
.664 .737 .904 r
.41052 .19977 .41806 .20877 .43085 .20399 .42335 .19495 Mtetra
.42335 .19495 .43085 .20399 .4437 .19917 .43624 .19011 Mtetra
.43624 .19011 .4437 .19917 .45662 .19433 .44919 .18523 Mtetra
.664 .737 .905 r
.44919 .18523 .45662 .19433 .4696 .18946 .46221 .18034 Mtetra
.664 .738 .905 r
.46221 .18034 .4696 .18946 .48263 .18457 .47528 .17541 Mtetra
.47528 .17541 .48263 .18457 .49573 .17965 .48842 .17047 Mtetra
.664 .739 .905 r
.48842 .17047 .49573 .17965 .5089 .17471 .50163 .1655 Mtetra
.664 .739 .906 r
.50163 .1655 .5089 .17471 .52212 .16975 .51489 .16051 Mtetra
.51489 .16051 .52212 .16975 .53541 .16477 .52823 .15549 Mtetra
.664 .74 .906 r
.52823 .15549 .53541 .16477 .54877 .15976 .54162 .15045 Mtetra
.664 .74 .907 r
.54162 .15045 .54877 .15976 .56219 .15474 .55508 .14539 Mtetra
.55508 .14539 .56219 .15474 .57567 .14969 .56861 .14031 Mtetra
.56861 .14031 .57567 .14969 .58922 .14462 .58221 .13521 Mtetra
.664 .741 .907 r
.58221 .13521 .58922 .14462 .60284 .13953 .59587 .13008 Mtetra
.59587 .13008 .60284 .13953 .61652 .13442 .60959 .12493 Mtetra
.664 .741 .908 r
.60959 .12493 .61652 .13442 .63027 .12929 .62339 .11975 Mtetra
.62339 .11975 .63027 .12929 .64409 .12413 .63725 .11455 Mtetra
.63725 .11455 .64409 .12413 .65797 .11895 .65119 .10933 Mtetra
.65119 .10933 .65797 .11895 .67193 .11375 .66519 .10408 Mtetra
.66519 .10408 .67193 .11375 .68595 .10852 .67926 .0988 Mtetra
.67926 .0988 .68595 .10852 .70004 .10327 .6934 .0935 Mtetra
.6934 .0935 .70004 .10327 .71421 .09799 .70762 .08817 Mtetra
.70762 .08817 .71421 .09799 .72844 .09268 .7219 .08282 Mtetra
.7219 .08282 .72844 .09268 .74275 .08735 .73626 .07744 Mtetra
.742 .253 .078 r
.08433 .34022 .09403 .33975 .10359 .34982 .09376 .35128 Mtetra
.771 .312 .157 r
.09376 .35128 .10359 .34982 .11272 .36425 .10305 .36452 Mtetra
.771 .297 .113 r
.10305 .36452 .11272 .36425 .12167 .38161 .11255 .37749 Mtetra
.65 .095 0 r
.11255 .37749 .12167 .38161 .13082 .39899 .12267 .38697 Mtetra
.339 .508 .878 r
.12267 .38697 .13082 .39899 .14065 .41239 .13373 .38991 Mtetra
.625 .526 .722 r
.13373 .38991 .14065 .41239 .15157 .41791 .14588 .38453 Mtetra
.673 .509 .655 r
.14588 .38453 .15157 .41791 .16376 .41313 .159 .37108 Mtetra
.686 .499 .628 r
.159 .37108 .16376 .41313 .1771 .39817 .17277 .35171 Mtetra
.689 .493 .618 r
.17277 .35171 .1771 .39817 .19121 .37557 .18677 .32961 Mtetra
.688 .493 .618 r
.18677 .32961 .19121 .37557 .20562 .34931 .20066 .30791 Mtetra
.686 .498 .628 r
.20066 .30791 .20562 .34931 .21989 .32333 .21422 .2888 Mtetra
.684 .512 .647 r
.21422 .2888 .21989 .32333 .23377 .30045 .22737 .27325 Mtetra
.684 .535 .678 r
.22737 .27325 .23377 .30045 .24717 .28199 .24017 .26123 Mtetra
.683 .57 .721 r
.24017 .26123 .24717 .28199 .26014 .26792 .25272 .25207 Mtetra
.682 .614 .773 r
.25272 .25207 .26014 .26792 .2728 .25748 .26512 .24492 Mtetra
.679 .659 .824 r
.26512 .24492 .2728 .25748 .28526 .2496 .27745 .23901 Mtetra
.673 .695 .862 r
.27745 .23901 .28526 .2496 .29764 .24331 .28977 .23377 Mtetra
.668 .718 .886 r
.28977 .23377 .29764 .24331 .31 .23792 .30212 .22888 Mtetra
.665 .73 .898 r
.30212 .22888 .31 .23792 .32238 .23296 .31452 .22411 Mtetra
.664 .735 .903 r
.31452 .22411 .32238 .23296 .3348 .22819 .32697 .2194 Mtetra
.663 .737 .905 r
.32697 .2194 .3348 .22819 .34727 .22348 .33948 .21468 Mtetra
.663 .738 .906 r
.33948 .21468 .34727 .22348 .3598 .21878 .35204 .20994 Mtetra
.35204 .20994 .3598 .21878 .37239 .21407 .36467 .20519 Mtetra
.36467 .20519 .37239 .21407 .38504 .20933 .37735 .20041 Mtetra
.37735 .20041 .38504 .20933 .39775 .20456 .3901 .1956 Mtetra
.3901 .1956 .39775 .20456 .41052 .19977 .40291 .19077 Mtetra
.664 .738 .906 r
.40291 .19077 .41052 .19977 .42335 .19495 .41577 .18591 Mtetra
.664 .739 .906 r
.41577 .18591 .42335 .19495 .43624 .19011 .4287 .18103 Mtetra
.4287 .18103 .43624 .19011 .44919 .18523 .44169 .17612 Mtetra
.44169 .17612 .44919 .18523 .46221 .18034 .45475 .17119 Mtetra
.45475 .17119 .46221 .18034 .47528 .17541 .46787 .16623 Mtetra
.46787 .16623 .47528 .17541 .48842 .17047 .48105 .16125 Mtetra
.664 .74 .906 r
.48105 .16125 .48842 .17047 .50163 .1655 .49429 .15624 Mtetra
.664 .74 .907 r
.49429 .15624 .50163 .1655 .51489 .16051 .5076 .15121 Mtetra
.5076 .15121 .51489 .16051 .52823 .15549 .52097 .14616 Mtetra
.52097 .14616 .52823 .15549 .54162 .15045 .53441 .14109 Mtetra
.53441 .14109 .54162 .15045 .55508 .14539 .54792 .13599 Mtetra
.664 .741 .907 r
.54792 .13599 .55508 .14539 .56861 .14031 .56149 .13087 Mtetra
.56149 .13087 .56861 .14031 .58221 .13521 .57513 .12572 Mtetra
.664 .741 .908 r
.57513 .12572 .58221 .13521 .59587 .13008 .58883 .12055 Mtetra
.58883 .12055 .59587 .13008 .60959 .12493 .60261 .11535 Mtetra
.60261 .11535 .60959 .12493 .62339 .11975 .61645 .11013 Mtetra
.61645 .11013 .62339 .11975 .63725 .11455 .63036 .10489 Mtetra
.63036 .10489 .63725 .11455 .65119 .10933 .64434 .09961 Mtetra
.64434 .09961 .65119 .10933 .66519 .10408 .65839 .09432 Mtetra
.65839 .09432 .66519 .10408 .67926 .0988 .67251 .08899 Mtetra
.67251 .08899 .67926 .0988 .6934 .0935 .6867 .08364 Mtetra
.6867 .08364 .6934 .0935 .70762 .08817 .70096 .07827 Mtetra
.70096 .07827 .70762 .08817 .7219 .08282 .71529 .07286 Mtetra
.71529 .07286 .7219 .08282 .73626 .07744 .7297 .06743 Mtetra
.697 .162 0 r
.0748 .3385 .08433 .34022 .09376 .35128 .08446 .3479 Mtetra
.655 .098 0 r
.08446 .3479 .09376 .35128 .10305 .36452 .09432 .35687 Mtetra
0 .293 .757 r
.09432 .35687 .10305 .36452 .11255 .37749 .10471 .36291 Mtetra
.48 .531 .832 r
.10471 .36291 .11255 .37749 .12267 .38697 .1159 .3637 Mtetra
.627 .521 .714 r
.1159 .3637 .12267 .38697 .13373 .38991 .12799 .35801 Mtetra
.665 .507 .661 r
.12799 .35801 .13373 .38991 .14588 .38453 .14087 .34615 Mtetra
.677 .499 .637 r
.14087 .34615 .14588 .38453 .159 .37108 .15427 .32986 Mtetra
.681 .496 .629 r
.15427 .32986 .159 .37108 .17277 .35171 .16786 .31162 Mtetra
.682 .498 .631 r
.16786 .31162 .17277 .35171 .18677 .32961 .18136 .29381 Mtetra
.681 .506 .643 r
.18136 .29381 .18677 .32961 .20066 .30791 .19458 .27809 Mtetra
.681 .523 .665 r
.19458 .27809 .20066 .30791 .21422 .2888 .20749 .26515 Mtetra
.681 .551 .7 r
.20749 .26515 .21422 .2888 .22737 .27325 .22013 .25493 Mtetra
.682 .589 .745 r
.22013 .25493 .22737 .27325 .24017 .26123 .23256 .24689 Mtetra
.68 .633 .795 r
.23256 .24689 .24017 .26123 .25272 .25207 .24489 .24036 Mtetra
.676 .674 .84 r
.24489 .24036 .25272 .25207 .26512 .24492 .25718 .23477 Mtetra
.671 .705 .872 r
.25718 .23477 .26512 .24492 .27745 .23901 .26947 .22968 Mtetra
.667 .723 .891 r
.26947 .22968 .27745 .23901 .28977 .23377 .28179 .22483 Mtetra
.665 .733 .9 r
.28179 .22483 .28977 .23377 .30212 .22888 .29416 .22007 Mtetra
.664 .737 .904 r
.29416 .22007 .30212 .22888 .31452 .22411 .30659 .21534 Mtetra
.663 .739 .906 r
.30659 .21534 .31452 .22411 .32697 .2194 .31907 .2106 Mtetra
.663 .739 .907 r
.31907 .2106 .32697 .2194 .33948 .21468 .33161 .20585 Mtetra
.33161 .20585 .33948 .21468 .35204 .20994 .34421 .20107 Mtetra
.663 .74 .907 r
.34421 .20107 .35204 .20994 .36467 .20519 .35688 .19627 Mtetra
.663 .739 .907 r
.35688 .19627 .36467 .20519 .37735 .20041 .3696 .19145 Mtetra
.663 .74 .907 r
.3696 .19145 .37735 .20041 .3901 .1956 .38238 .1866 Mtetra
.664 .74 .907 r
.38238 .1866 .3901 .1956 .40291 .19077 .39523 .18173 Mtetra
.39523 .18173 .40291 .19077 .41577 .18591 .40813 .17683 Mtetra
.40813 .17683 .41577 .18591 .4287 .18103 .4211 .17191 Mtetra
.4211 .17191 .4287 .18103 .44169 .17612 .43413 .16696 Mtetra
.43413 .16696 .44169 .17612 .45475 .17119 .44723 .16199 Mtetra
.44723 .16199 .45475 .17119 .46787 .16623 .46038 .15699 Mtetra
.46038 .15699 .46787 .16623 .48105 .16125 .4736 .15197 Mtetra
.4736 .15197 .48105 .16125 .49429 .15624 .48689 .14693 Mtetra
.48689 .14693 .49429 .15624 .5076 .15121 .50024 .14186 Mtetra
.664 .741 .907 r
.50024 .14186 .5076 .15121 .52097 .14616 .51366 .13677 Mtetra
.51366 .13677 .52097 .14616 .53441 .14109 .52714 .13165 Mtetra
.52714 .13165 .53441 .14109 .54792 .13599 .54069 .12651 Mtetra
.664 .741 .908 r
.54069 .12651 .54792 .13599 .56149 .13087 .5543 .12134 Mtetra
.5543 .12134 .56149 .13087 .57513 .12572 .56798 .11615 Mtetra
.56798 .11615 .57513 .12572 .58883 .12055 .58173 .11094 Mtetra
.58173 .11094 .58883 .12055 .60261 .11535 .59555 .10569 Mtetra
.59555 .10569 .60261 .11535 .61645 .11013 .60944 .10043 Mtetra
.60944 .10043 .61645 .11013 .63036 .10489 .6234 .09513 Mtetra
.6234 .09513 .63036 .10489 .64434 .09961 .63743 .08982 Mtetra
.63743 .08982 .64434 .09961 .65839 .09432 .65152 .08447 Mtetra
.65152 .08447 .65839 .09432 .67251 .08899 .66569 .0791 Mtetra
.66569 .0791 .67251 .08899 .6867 .08364 .67993 .0737 Mtetra
.67993 .0737 .6867 .08364 .70096 .07827 .69424 .06827 Mtetra
.69424 .06827 .70096 .07827 .71529 .07286 .70863 .06282 Mtetra
.70863 .06282 .71529 .07286 .7297 .06743 .72309 .05734 Mtetra
0 .273 .697 r
.06579 .33248 .0748 .3385 .08446 .3479 .07598 .33802 Mtetra
.246 .511 .906 r
.07598 .33802 .08446 .3479 .09432 .35687 .08662 .34117 Mtetra
.541 .546 .808 r
.08662 .34117 .09432 .35687 .10471 .36291 .09791 .34029 Mtetra
.63 .527 .718 r
.09791 .34029 .10471 .36291 .1159 .3637 .10992 .33452 Mtetra
.66 .513 .673 r
.10992 .33452 .1159 .3637 .12799 .35801 .12256 .32419 Mtetra
.672 .505 .651 r
.12256 .32419 .12799 .35801 .14087 .34615 .1356 .31066 Mtetra
.676 .504 .645 r
.1356 .31066 .14087 .34615 .15427 .32986 .1488 .29579 Mtetra
.678 .508 .649 r
.1488 .29579 .15427 .32986 .16786 .31162 .16192 .28134 Mtetra
.678 .52 .664 r
.16192 .28134 .16786 .31162 .18136 .29381 .17483 .2685 Mtetra
.679 .541 .689 r
.17483 .2685 .18136 .29381 .19458 .27809 .18751 .25776 Mtetra
.68 .571 .726 r
.18751 .25776 .19458 .27809 .20749 .26515 .19999 .24905 Mtetra
.68 .611 .772 r
.19999 .24905 .20749 .26515 .22013 .25493 .21232 .24194 Mtetra
.678 .653 .818 r
.21232 .24194 .22013 .25493 .23256 .24689 .22458 .23593 Mtetra
.674 .688 .856 r
.22458 .23593 .23256 .24689 .24489 .24036 .23682 .23059 Mtetra
.669 .713 .881 r
.23682 .23059 .24489 .24036 .25718 .23477 .24908 .22561 Mtetra
.666 .728 .896 r
.24908 .22561 .25718 .23477 .26947 .22968 .26137 .22079 Mtetra
.665 .735 .902 r
.26137 .22079 .26947 .22968 .28179 .22483 .27372 .21604 Mtetra
.664 .738 .906 r
.27372 .21604 .28179 .22483 .29416 .22007 .28612 .21129 Mtetra
.664 .74 .907 r
.28612 .21129 .29416 .22007 .30659 .21534 .29858 .20654 Mtetra
.663 .74 .907 r
.29858 .20654 .30659 .21534 .31907 .2106 .3111 .20177 Mtetra
.3111 .20177 .31907 .2106 .33161 .20585 .32368 .19697 Mtetra
.32368 .19697 .33161 .20585 .34421 .20107 .33632 .19215 Mtetra
.33632 .19215 .34421 .20107 .35688 .19627 .34901 .18731 Mtetra
.34901 .18731 .35688 .19627 .3696 .19145 .36177 .18244 Mtetra
.664 .74 .907 r
.36177 .18244 .3696 .19145 .38238 .1866 .37459 .17755 Mtetra
.37459 .17755 .38238 .1866 .39523 .18173 .38748 .17264 Mtetra
.38748 .17264 .39523 .18173 .40813 .17683 .40042 .1677 Mtetra
.40042 .1677 .40813 .17683 .4211 .17191 .41343 .16273 Mtetra
.41343 .16273 .4211 .17191 .43413 .16696 .4265 .15774 Mtetra
.664 .741 .907 r
.4265 .15774 .43413 .16696 .44723 .16199 .43963 .15273 Mtetra
.43963 .15273 .44723 .16199 .46038 .15699 .45283 .14769 Mtetra
.45283 .14769 .46038 .15699 .4736 .15197 .46609 .14263 Mtetra
.46609 .14263 .4736 .15197 .48689 .14693 .47942 .13755 Mtetra
.47942 .13755 .48689 .14693 .50024 .14186 .49281 .13243 Mtetra
.664 .741 .908 r
.49281 .13243 .50024 .14186 .51366 .13677 .50627 .1273 Mtetra
.50627 .1273 .51366 .13677 .52714 .13165 .5198 .12214 Mtetra
.5198 .12214 .52714 .13165 .54069 .12651 .53339 .11695 Mtetra
.53339 .11695 .54069 .12651 .5543 .12134 .54705 .11174 Mtetra
.54705 .11174 .5543 .12134 .56798 .11615 .56078 .1065 Mtetra
.56078 .1065 .56798 .11615 .58173 .11094 .57457 .10124 Mtetra
.57457 .10124 .58173 .11094 .59555 .10569 .58844 .09595 Mtetra
.58844 .09595 .59555 .10569 .60944 .10043 .60237 .09064 Mtetra
.60237 .09064 .60944 .10043 .6234 .09513 .61637 .08529 Mtetra
.61637 .08529 .6234 .09513 .63743 .08982 .63045 .07993 Mtetra
.63045 .07993 .63743 .08982 .65152 .08447 .64459 .07453 Mtetra
.64459 .07453 .65152 .08447 .66569 .0791 .65881 .06911 Mtetra
.65881 .06911 .66569 .0791 .67993 .0737 .6731 .06366 Mtetra
.6731 .06366 .67993 .0737 .69424 .06827 .68746 .05818 Mtetra
.68746 .05818 .69424 .06827 .70863 .06282 .7019 .05267 Mtetra
.7019 .05267 .70863 .06282 .72309 .05734 .71641 .04714 Mtetra
.437 .581 .899 r
.05742 .32142 .06579 .33248 .07598 .33802 .06827 .32229 Mtetra
.577 .563 .802 r
.06827 .32229 .07598 .33802 .08662 .34117 .07963 .32016 Mtetra
.634 .54 .73 r
.07963 .32016 .08662 .34117 .09791 .34029 .09156 .31447 Mtetra
.658 .525 .691 r
.09156 .31447 .09791 .34029 .10992 .33452 .10396 .30552 Mtetra
.669 .518 .671 r
.10396 .30552 .10992 .33452 .12256 .32419 .11668 .29433 Mtetra
.673 .518 .667 r
.11668 .29433 .12256 .32419 .1356 .31066 .12952 .28226 Mtetra
.676 .525 .673 r
.12952 .28226 .1356 .31066 .1488 .29579 .1423 .27056 Mtetra
.677 .54 .69 r
.1423 .27056 .1488 .29579 .16192 .28134 .15494 .26006 Mtetra
.678 .564 .719 r
.15494 .26006 .16192 .28134 .17483 .2685 .16742 .2511 Mtetra
.679 .597 .756 r
.16742 .2511 .17483 .2685 .18751 .25776 .17975 .24359 Mtetra
.678 .635 .799 r
.17975 .24359 .18751 .25776 .19999 .24905 .19198 .23721 Mtetra
.675 .672 .839 r
.19198 .23721 .19999 .24905 .21232 .24194 .20418 .23161 Mtetra
.671 .702 .869 r
.20418 .23161 .21232 .24194 .22458 .23593 .21638 .22646 Mtetra
.668 .721 .889 r
.21638 .22646 .22458 .23593 .23682 .23059 .2286 .22156 Mtetra
.665 .732 .899 r
.2286 .22156 .23682 .23059 .24908 .22561 .24087 .21677 Mtetra
.664 .737 .904 r
.24087 .21677 .24908 .22561 .26137 .22079 .2532 .21201 Mtetra
.664 .739 .906 r
.2532 .21201 .26137 .22079 .27372 .21604 .26557 .20725 Mtetra
.664 .74 .907 r
.26557 .20725 .27372 .21604 .28612 .21129 .27801 .20248 Mtetra
.663 .741 .907 r
.27801 .20248 .28612 .21129 .29858 .20654 .2905 .19769 Mtetra
.2905 .19769 .29858 .20654 .3111 .20177 .30306 .19287 Mtetra
.30306 .19287 .3111 .20177 .32368 .19697 .31567 .18803 Mtetra
.31567 .18803 .32368 .19697 .33632 .19215 .32835 .18317 Mtetra
.32835 .18317 .33632 .19215 .34901 .18731 .34108 .17828 Mtetra
.664 .741 .907 r
.34108 .17828 .34901 .18731 .36177 .18244 .35388 .17337 Mtetra
.35388 .17337 .36177 .18244 .37459 .17755 .36674 .16844 Mtetra
.36674 .16844 .37459 .17755 .38748 .17264 .37966 .16348 Mtetra
.37966 .16348 .38748 .17264 .40042 .1677 .39264 .1585 Mtetra
.39264 .1585 .40042 .1677 .41343 .16273 .40569 .15349 Mtetra
.664 .741 .908 r
.40569 .15349 .41343 .16273 .4265 .15774 .4188 .14846 Mtetra
.4188 .14846 .4265 .15774 .43963 .15273 .43197 .1434 Mtetra
.43197 .1434 .43963 .15273 .45283 .14769 .44521 .13832 Mtetra
.44521 .13832 .45283 .14769 .46609 .14263 .45852 .13322 Mtetra
.45852 .13322 .46609 .14263 .47942 .13755 .47188 .12809 Mtetra
.47188 .12809 .47942 .13755 .49281 .13243 .48532 .12293 Mtetra
.48532 .12293 .49281 .13243 .50627 .1273 .49882 .11775 Mtetra
.49882 .11775 .50627 .1273 .5198 .12214 .51239 .11254 Mtetra
.51239 .11254 .5198 .12214 .53339 .11695 .52603 .10731 Mtetra
.52603 .10731 .53339 .11695 .54705 .11174 .53973 .10205 Mtetra
.53973 .10205 .54705 .11174 .56078 .1065 .5535 .09677 Mtetra
.5535 .09677 .56078 .1065 .57457 .10124 .56734 .09145 Mtetra
.56734 .09145 .57457 .10124 .58844 .09595 .58125 .08612 Mtetra
.58125 .08612 .58844 .09595 .60237 .09064 .59523 .08075 Mtetra
.59523 .08075 .60237 .09064 .61637 .08529 .60929 .07536 Mtetra
.60929 .07536 .61637 .08529 .63045 .07993 .62341 .06994 Mtetra
.62341 .06994 .63045 .07993 .64459 .07453 .6376 .0645 Mtetra
.6376 .0645 .64459 .07453 .65881 .06911 .65187 .05902 Mtetra
.65187 .05902 .65881 .06911 .6731 .06366 .66621 .05352 Mtetra
.66621 .05352 .6731 .06366 .68746 .05818 .68062 .04799 Mtetra
.68062 .04799 .68746 .05818 .7019 .05267 .6951 .04244 Mtetra
.6951 .04244 .7019 .05267 .71641 .04714 .70966 .03685 Mtetra
.602 .585 .807 r
.04959 .3064 .05742 .32142 .06827 .32229 .061 .30337 Mtetra
.64 .56 .749 r
.061 .30337 .06827 .32229 .07963 .32016 .07283 .29785 Mtetra
.659 .545 .714 r
.07283 .29785 .07963 .32016 .09156 .31447 .08503 .29007 Mtetra
.668 .538 .697 r
.08503 .29007 .09156 .31447 .10396 .30552 .09746 .28077 Mtetra
.672 .539 .694 r
.09746 .28077 .10396 .30552 .11668 .29433 .10999 .27092 Mtetra
.675 .548 .703 r
.10999 .27092 .11668 .29433 .12952 .28226 .12249 .26138 Mtetra
.676 .566 .722 r
.12249 .26138 .12952 .28226 .1423 .27056 .13489 .25271 Mtetra
.678 .591 .752 r
.13489 .25271 .1423 .27056 .15494 .26006 .14719 .2451 Mtetra
.678 .624 .788 r
.14719 .2451 .15494 .26006 .16742 .2511 .1594 .2385 Mtetra
.676 .659 .826 r
.1594 .2385 .16742 .2511 .17975 .24359 .17155 .23268 Mtetra
.673 .69 .858 r
.17155 .23268 .17975 .24359 .19198 .23721 .18369 .22737 Mtetra
.669 .713 .881 r
.18369 .22737 .19198 .23721 .20418 .23161 .19585 .22237 Mtetra
.666 .727 .895 r
.19585 .22237 .20418 .23161 .21638 .22646 .20805 .21753 Mtetra
.665 .735 .902 r
.20805 .21753 .21638 .22646 .2286 .22156 .22029 .21274 Mtetra
.664 .738 .905 r
.22029 .21274 .2286 .22156 .24087 .21677 .23259 .20798 Mtetra
.664 .74 .907 r
.23259 .20798 .24087 .21677 .2532 .21201 .24494 .2032 Mtetra
.664 .741 .907 r
.24494 .2032 .2532 .21201 .26557 .20725 .25735 .19841 Mtetra
.664 .741 .908 r
.25735 .19841 .26557 .20725 .27801 .20248 .26982 .1936 Mtetra
.663 .741 .908 r
.26982 .1936 .27801 .20248 .2905 .19769 .28235 .18876 Mtetra
.28235 .18876 .2905 .19769 .30306 .19287 .29494 .18391 Mtetra
.664 .741 .908 r
.29494 .18391 .30306 .19287 .31567 .18803 .30759 .17902 Mtetra
.30759 .17902 .31567 .18803 .32835 .18317 .32031 .17412 Mtetra
.32031 .17412 .32835 .18317 .34108 .17828 .33308 .16919 Mtetra
.33308 .16919 .34108 .17828 .35388 .17337 .34591 .16424 Mtetra
.34591 .16424 .35388 .17337 .36674 .16844 .35881 .15926 Mtetra
.35881 .15926 .36674 .16844 .37966 .16348 .37177 .15426 Mtetra
.37177 .15426 .37966 .16348 .39264 .1585 .38479 .14923 Mtetra
.38479 .14923 .39264 .1585 .40569 .15349 .39788 .14418 Mtetra
.39788 .14418 .40569 .15349 .4188 .14846 .41103 .1391 Mtetra
.41103 .1391 .4188 .14846 .43197 .1434 .42424 .134 Mtetra
.42424 .134 .43197 .1434 .44521 .13832 .43752 .12887 Mtetra
.43752 .12887 .44521 .13832 .45852 .13322 .45087 .12372 Mtetra
.45087 .12372 .45852 .13322 .47188 .12809 .46428 .11854 Mtetra
.46428 .11854 .47188 .12809 .48532 .12293 .47776 .11334 Mtetra
.47776 .11334 .48532 .12293 .49882 .11775 .4913 .10811 Mtetra
.4913 .10811 .49882 .11775 .51239 .11254 .50491 .10286 Mtetra
.50491 .10286 .51239 .11254 .52603 .10731 .51859 .09758 Mtetra
.51859 .09758 .52603 .10731 .53973 .10205 .53234 .09227 Mtetra
.53234 .09227 .53973 .10205 .5535 .09677 .54616 .08694 Mtetra
.54616 .08694 .5535 .09677 .56734 .09145 .56005 .08158 Mtetra
.56005 .08158 .56734 .09145 .58125 .08612 .574 .07619 Mtetra
.574 .07619 .58125 .08612 .59523 .08075 .58803 .07078 Mtetra
.58803 .07078 .59523 .08075 .60929 .07536 .60213 .06534 Mtetra
.60213 .06534 .60929 .07536 .62341 .06994 .6163 .05987 Mtetra
.6163 .05987 .62341 .06994 .6376 .0645 .63054 .05437 Mtetra
.63054 .05437 .6376 .0645 .65187 .05902 .64486 .04885 Mtetra
.64486 .04885 .65187 .05902 .66621 .05352 .65925 .04329 Mtetra
.65925 .04329 .66621 .05352 .68062 .04799 .67371 .03771 Mtetra
.67371 .03771 .68062 .04799 .6951 .04244 .68825 .0321 Mtetra
.68825 .0321 .6951 .04244 .70966 .03685 .70286 .02646 Mtetra
.646 .586 .773 r
.04198 .28969 .04959 .3064 .061 .30337 .05373 .28436 Mtetra
.66 .571 .743 r
.05373 .28436 .061 .30337 .07283 .29785 .06574 .27752 Mtetra
.668 .564 .729 r
.06574 .27752 .07283 .29785 .08503 .29007 .07794 .2697 Mtetra
.672 .567 .728 r
.07794 .2697 .08503 .29007 .09746 .28077 .09021 .26153 Mtetra
.675 .577 .738 r
.09021 .26153 .09746 .28077 .10999 .27092 .10248 .2536 Mtetra
.676 .596 .758 r
.10248 .2536 .10999 .27092 .12249 .26138 .11469 .24628 Mtetra
.677 .622 .786 r
.11469 .24628 .12249 .26138 .13489 .25271 .12684 .23967 Mtetra
.676 .652 .819 r
.12684 .23967 .13489 .25271 .14719 .2451 .13894 .23373 Mtetra
.674 .681 .849 r
.13894 .23373 .14719 .2451 .1594 .2385 .15103 .2283 Mtetra
.67 .705 .873 r
.15103 .2283 .1594 .2385 .17155 .23268 .16312 .22321 Mtetra
.667 .721 .889 r
.16312 .22321 .17155 .23268 .18369 .22737 .17524 .21831 Mtetra
.665 .732 .899 r
.17524 .21831 .18369 .22737 .19585 .22237 .18741 .21349 Mtetra
.664 .737 .904 r
.18741 .21349 .19585 .22237 .20805 .21753 .19963 .20871 Mtetra
.664 .739 .906 r
.19963 .20871 .20805 .21753 .22029 .21274 .2119 .20394 Mtetra
.664 .741 .907 r
.2119 .20394 .22029 .21274 .23259 .20798 .22423 .19914 Mtetra
.664 .741 .908 r
.22423 .19914 .23259 .20798 .24494 .2032 .23661 .19433 Mtetra
.23661 .19433 .24494 .2032 .25735 .19841 .24906 .1895 Mtetra
.24906 .1895 .25735 .19841 .26982 .1936 .26156 .18465 Mtetra
.26156 .18465 .26982 .1936 .28235 .18876 .27413 .17977 Mtetra
.27413 .17977 .28235 .18876 .29494 .18391 .28676 .17487 Mtetra
.28676 .17487 .29494 .18391 .30759 .17902 .29944 .16994 Mtetra
.29944 .16994 .30759 .17902 .32031 .17412 .31219 .16499 Mtetra
.31219 .16499 .32031 .17412 .33308 .16919 .325 .16002 Mtetra
.325 .16002 .33308 .16919 .34591 .16424 .33788 .15502 Mtetra
.33788 .15502 .34591 .16424 .35881 .15926 .35081 .15 Mtetra
.35081 .15 .35881 .15926 .37177 .15426 .36381 .14495 Mtetra
.36381 .14495 .37177 .15426 .38479 .14923 .37687 .13988 Mtetra
.37687 .13988 .38479 .14923 .39788 .14418 .39 .13478 Mtetra
.39 .13478 .39788 .14418 .41103 .1391 .40319 .12966 Mtetra
.40319 .12966 .41103 .1391 .42424 .134 .41644 .12451 Mtetra
.41644 .12451 .42424 .134 .43752 .12887 .42976 .11934 Mtetra
.42976 .11934 .43752 .12887 .45087 .12372 .44315 .11414 Mtetra
.44315 .11414 .45087 .12372 .46428 .11854 .4566 .10892 Mtetra
.4566 .10892 .46428 .11854 .47776 .11334 .47012 .10367 Mtetra
.47012 .10367 .47776 .11334 .4913 .10811 .48371 .09839 Mtetra
.48371 .09839 .4913 .10811 .50491 .10286 .49737 .09309 Mtetra
.49737 .09309 .50491 .10286 .51859 .09758 .51109 .08776 Mtetra
.51109 .08776 .51859 .09758 .53234 .09227 .52489 .08241 Mtetra
.52489 .08241 .53234 .09227 .54616 .08694 .53875 .07702 Mtetra
.53875 .07702 .54616 .08694 .56005 .08158 .55268 .07161 Mtetra
.55268 .07161 .56005 .08158 .574 .07619 .56669 .06618 Mtetra
.56669 .06618 .574 .07619 .58803 .07078 .58076 .06071 Mtetra
.58076 .06071 .58803 .07078 .60213 .06534 .59491 .05522 Mtetra
.59491 .05522 .60213 .06534 .6163 .05987 .60913 .0497 Mtetra
.60913 .0497 .6163 .05987 .63054 .05437 .62342 .04415 Mtetra
.62342 .04415 .63054 .05437 .64486 .04885 .63778 .03857 Mtetra
.63778 .03857 .64486 .04885 .65925 .04329 .65222 .03297 Mtetra
.65222 .03297 .65925 .04329 .67371 .03771 .66673 .02733 Mtetra
.66673 .02733 .67371 .03771 .68825 .0321 .68132 .02167 Mtetra
.68132 .02167 .68825 .0321 .70286 .02646 .69599 .01598 Mtetra
.663 .601 .775 r
.03424 .27353 .04198 .28969 .05373 .28436 .04611 .26742 Mtetra
.669 .596 .764 r
.04611 .26742 .05373 .28436 .06574 .27752 .05812 .26068 Mtetra
.673 .599 .764 r
.05812 .26068 .06574 .27752 .07794 .2697 .07019 .25374 Mtetra
.675 .61 .775 r
.07019 .25374 .07794 .2697 .09021 .26153 .08227 .24697 Mtetra
.676 .629 .794 r
.08227 .24697 .09021 .26153 .10248 .2536 .09433 .2406 Mtetra
.675 .652 .819 r
.09433 .2406 .10248 .2536 .11469 .24628 .10636 .23469 Mtetra
.674 .677 .845 r
.10636 .23469 .11469 .24628 .12684 .23967 .11838 .22921 Mtetra
.671 .699 .868 r
.11838 .22921 .12684 .23967 .13894 .23373 .13041 .22405 Mtetra
.668 .717 .885 r
.13041 .22405 .13894 .23373 .15103 .2283 .14246 .2191 Mtetra
.666 .728 .896 r
.14246 .2191 .15103 .2283 .16312 .22321 .15455 .21425 Mtetra
.665 .735 .902 r
.15455 .21425 .16312 .22321 .17524 .21831 .16669 .20946 Mtetra
.664 .738 .905 r
.16669 .20946 .17524 .21831 .18741 .21349 .17888 .20467 Mtetra
.664 .74 .907 r
.17888 .20467 .18741 .21349 .19963 .20871 .19112 .19988 Mtetra
.664 .741 .907 r
.19112 .19988 .19963 .20871 .2119 .20394 .20343 .19507 Mtetra
.664 .741 .908 r
.20343 .19507 .2119 .20394 .22423 .19914 .21579 .19024 Mtetra
.21579 .19024 .22423 .19914 .23661 .19433 .22821 .18539 Mtetra
.22821 .18539 .23661 .19433 .24906 .1895 .24069 .18052 Mtetra
.24069 .18052 .24906 .1895 .26156 .18465 .25323 .17562 Mtetra
.25323 .17562 .26156 .18465 .27413 .17977 .26583 .1707 Mtetra
.26583 .1707 .27413 .17977 .28676 .17487 .2785 .16575 Mtetra
.2785 .16575 .28676 .17487 .29944 .16994 .29122 .16078 Mtetra
.29122 .16078 .29944 .16994 .31219 .16499 .30401 .15579 Mtetra
.30401 .15579 .31219 .16499 .325 .16002 .31685 .15077 Mtetra
.31685 .15077 .325 .16002 .33788 .15502 .32976 .14573 Mtetra
.32976 .14573 .33788 .15502 .35081 .15 .34274 .14066 Mtetra
.34274 .14066 .35081 .15 .36381 .14495 .35578 .13557 Mtetra
.35578 .13557 .36381 .14495 .37687 .13988 .36888 .13045 Mtetra
.36888 .13045 .37687 .13988 .39 .13478 .38204 .1253 Mtetra
.38204 .1253 .39 .13478 .40319 .12966 .39527 .12014 Mtetra
.39527 .12014 .40319 .12966 .41644 .12451 .40857 .11494 Mtetra
.40857 .11494 .41644 .12451 .42976 .11934 .42193 .10972 Mtetra
.42193 .10972 .42976 .11934 .44315 .11414 .43536 .10448 Mtetra
.43536 .10448 .44315 .11414 .4566 .10892 .44886 .09921 Mtetra
.44886 .09921 .4566 .10892 .47012 .10367 .46242 .09391 Mtetra
.46242 .09391 .47012 .10367 .48371 .09839 .47605 .08858 Mtetra
.47605 .08858 .48371 .09839 .49737 .09309 .48975 .08323 Mtetra
.48975 .08323 .49737 .09309 .51109 .08776 .50352 .07785 Mtetra
.50352 .07785 .51109 .08776 .52489 .08241 .51736 .07245 Mtetra
.51736 .07245 .52489 .08241 .53875 .07702 .53127 .06701 Mtetra
.53127 .06701 .53875 .07702 .55268 .07161 .54525 .06155 Mtetra
.54525 .06155 .55268 .07161 .56669 .06618 .5593 .05607 Mtetra
.5593 .05607 .56669 .06618 .58076 .06071 .57342 .05055 Mtetra
.57342 .05055 .58076 .06071 .59491 .05522 .58762 .04501 Mtetra
.58762 .04501 .59491 .05522 .60913 .0497 .60188 .03943 Mtetra
.60188 .03943 .60913 .0497 .62342 .04415 .61623 .03383 Mtetra
.61623 .03383 .62342 .04415 .63778 .03857 .63064 .0282 Mtetra
.63064 .0282 .63778 .03857 .65222 .03297 .64513 .02254 Mtetra
.64513 .02254 .65222 .03297 .66673 .02733 .65969 .01685 Mtetra
.65969 .01685 .66673 .02733 .68132 .02167 .67433 .01113 Mtetra
.67433 .01113 .68132 .02167 .69599 .01598 .68905 .00539 Mtetra
0 g
.68874 0 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.68874 0 m
.03716 .25514 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 0.522676 0.477324 0.97619 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.49505 0.5 0.49505 [
[ 0 0 -0.125 0 ]
[ 0 0 -0.125 0 ]
[ 0 1 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
0 0 m
1 0 L
s
0 0 m
0 1 L
s
0 1 m
1 1 L
s
1 0 m
1 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
1 .5 0 r
.015 w
.03175 .1355 Mdot
.03435 .12523 Mdot
.11137 .12765 Mdot
.14107 .18841 Mdot
.16218 .24538 Mdot
.17294 .21053 Mdot
.18267 .18577 Mdot
.18434 .1304 Mdot
.18553 .30956 Mdot
.20401 .239 Mdot
.21247 .27571 Mdot
.21687 .20845 Mdot
.22376 .2799 Mdot
.22832 .27485 Mdot
.29063 .20974 Mdot
.29686 .25079 Mdot
.30487 .22936 Mdot
.30683 .34623 Mdot
.32055 .20902 Mdot
.32574 .21979 Mdot
.34472 .28521 Mdot
.35998 .36393 Mdot
.36335 .24976 Mdot
.3794 .36608 Mdot
.42386 .66992 Mdot
.44391 .74519 Mdot
.45059 .34198 Mdot
.47208 .67586 Mdot
.47436 .71381 Mdot
.49778 .59825 Mdot
.50874 .91643 Mdot
.51516 .76219 Mdot
.53655 .61374 Mdot
.56563 .75219 Mdot
.59189 .65665 Mdot
.59581 .61604 Mdot
.59923 .6556 Mdot
.60292 .68499 Mdot
.62656 .67779 Mdot
.63555 .72451 Mdot
.63919 .652 Mdot
.64169 .6004 Mdot
.64246 .58611 Mdot
.64496 .54267 Mdot
.64608 .77288 Mdot
.65077 .64308 Mdot
.66065 .57816 Mdot
.67474 .59169 Mdot
.69296 .563 Mdot
.72815 .65902 Mdot
.73169 .58879 Mdot
.74669 .61318 Mdot
.74821 .65474 Mdot
.75963 .63781 Mdot
.79673 .57809 Mdot
.80925 .55852 Mdot
.81525 .58444 Mdot
.83417 .62985 Mdot
.83598 .55526 Mdot
.91595 .49319 Mdot
0 0 1 r
.005 w
.13523 .14586 m
.16128 .14788 L
.18734 .16098 L
.18807 .16128 L
.21339 .17292 L
.23652 .18734 L
.23945 .18896 L
.2655 .20753 L
.27319 .21339 L
.29156 .22673 L
.30572 .23945 L
.31761 .24793 L
.33374 .2655 L
.34367 .27656 L
.35741 .29156 L
.36972 .30927 L
.37525 .31761 L
.38301 .34367 L
.36972 .35726 L
.34367 .35861 L
.31761 .3456 L
.31237 .34367 L
.29156 .33447 L
.2656 .31761 L
.2655 .31755 L
.23945 .30089 L
.22704 .29156 L
.21339 .28226 L
.19447 .2655 L
.18734 .26157 L
.16634 .23945 L
.16128 .23368 L
.14228 .21339 L
.13523 .20329 L
.12365 .18734 L
.11565 .16128 L
.13523 .14586 L
s
.52606 .48629 m
.55211 .47935 L
.57817 .47739 L
.60422 .47947 L
.63028 .48527 L
.65633 .49488 L
.66732 .5 L
.68239 .50847 L
.70701 .52606 L
.70844 .52723 L
.73352 .55211 L
.7345 .5532 L
.752 .57817 L
.76055 .59387 L
.76405 .60422 L
.77038 .63028 L
.77071 .65633 L
.76399 .68239 L
.76055 .69068 L
.74742 .70844 L
.7345 .72032 L
.70844 .73448 L
.70842 .7345 L
.68239 .74166 L
.65633 .74374 L
.63028 .74171 L
.60422 .73592 L
.59918 .7345 L
.57817 .72651 L
.55211 .71289 L
.54506 .70844 L
.52606 .69441 L
.51282 .68239 L
.5 .66872 L
.49061 .65633 L
.47542 .63028 L
.47394 .62698 L
.46615 .60422 L
.46267 .57817 L
.46555 .55211 L
.47394 .52757 L
.47652 .52606 L
.5 .50066 L
.50089 .5 L
.52606 .48629 L
s
0 g
.03 w
.24935 .25181 Mdot
.617 .61056 Mdot
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.522676 0.522676 0.97619 0.97619 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.49505 0.5 0.49505 [
[ 0 0 -0.125 0 ]
[ 0 0 -0.125 0 ]
[ 0 1 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
0 0 m
1 0 L
s
0 0 m
0 1 L
s
0 1 m
1 1 L
s
1 0 m
1 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
1 .5 0 r
.015 w
.03175 .1355 Mdot
.03435 .12523 Mdot
.11137 .12765 Mdot
.14107 .18841 Mdot
.16218 .24538 Mdot
.17294 .21053 Mdot
.18267 .18577 Mdot
.18434 .1304 Mdot
.18553 .30956 Mdot
.20401 .239 Mdot
.21247 .27571 Mdot
.21687 .20845 Mdot
.22376 .2799 Mdot
.22832 .27485 Mdot
.29063 .20974 Mdot
.29686 .25079 Mdot
.30487 .22936 Mdot
.30683 .34623 Mdot
.32055 .20902 Mdot
.32574 .21979 Mdot
.34472 .28521 Mdot
.35998 .36393 Mdot
.36335 .24976 Mdot
.3794 .36608 Mdot
.42386 .66992 Mdot
.44391 .74519 Mdot
.45059 .34198 Mdot
.47208 .67586 Mdot
.47436 .71381 Mdot
.49778 .59825 Mdot
.50874 .91643 Mdot
.51516 .76219 Mdot
.53655 .61374 Mdot
.56563 .75219 Mdot
.59189 .65665 Mdot
.59581 .61604 Mdot
.59923 .6556 Mdot
.60292 .68499 Mdot
.62656 .67779 Mdot
.63555 .72451 Mdot
.63919 .652 Mdot
.64169 .6004 Mdot
.64246 .58611 Mdot
.64496 .54267 Mdot
.64608 .77288 Mdot
.65077 .64308 Mdot
.66065 .57816 Mdot
.67474 .59169 Mdot
.69296 .563 Mdot
.72815 .65902 Mdot
.73169 .58879 Mdot
.74669 .61318 Mdot
.74821 .65474 Mdot
.75963 .63781 Mdot
.79673 .57809 Mdot
.80925 .55852 Mdot
.81525 .58444 Mdot
.83417 .62985 Mdot
.83598 .55526 Mdot
.91595 .49319 Mdot
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{400, 400},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40006@0001T2000`400?l00000o`00003ooooooonA
ooooo`00oooooonAooooo`00oooooonAooooo`00oooooonAooooo`00oooooonAooooo`00oooooonA
ooooo`00oooooonAooooo`00oooooonAooooo`00oooooonAooooo`00oooooonAooooo`002Ooooonf
00000=7ooooo0009ooooo`0300000?oooooooooo0;;ooooo00<00000ooooooooool0coooool000Wo
oooo00<00000ooooooooool0/_ooool00`00003oooooooooo`3?ooooo`002Oooool00`00003ooooo
ooooo`2booooo`0300000?oooooooooo0<oooooo0009ooooo`0400000?ooooooooooooooo`<00000
[_ooool00`00003oooooooooo`3?ooooo`002Oooool01000003oooooooooooooool301TI6JX00000
1?ooool00`00003oooooooooo`3?ooooo`002Oooool01000003oooooooooooooool601TI6JL00000
1?ooool00`00003oooooooooo`3?ooooo`002Oooool01000003oooooooooooooool:01TI6J<00000
1?ooool00`00003oooooooooo`3?ooooo`002Oooool01000003oooooooooooooool<01TI6J400000
1?ooool00`00003oooooooooo`3?ooooo`002Oooool01000003oooooooooooooool>01TI6Il00000
1?ooool00`00003oooooooooo`3?ooooo`002Oooool01000003ooooooooooooooolA01TI6I`00000
1?ooool00`00003oooooooooo`3?ooooo`002Oooool01000003ooooooooooooooolB01TI6@03o`00
00000000000009P000001?ooool00`00003oooooooooo`3?ooooo`002Oooool01000003ooooooooo
ooooool201TI6@/000001`0I6AVI000000Cooooo00<00000ooooooooool0coooool000Wooooo00@0
0000oooooooooooooooo0P00000;03<c<`8000001`0I6AVG000000Cooooo00<00000ooooooooool0
coooool000Wooooo00@00000oooooooooooooooo3`0c<c<00ol00000000001TI6@0601TI6@030000
0?l000000000098000001?ooool00`00003oooooooooo`3?ooooo`002Oooool01000003ooooooooo
oooooolA03<c<`<000001`0I6AVB000000Cooooo00<00000ooooooooool0coooool000Wooooo00@0
0000oooooooooooooooo2@0c<c<4000000L0<c<c0P00000701TI6I0000001?ooool00`00003ooooo
ooooo`3?ooooo`002Oooool01000003oooooooooooooool603<c<`<00000101<C4`3000000H0<c<c
0P00000701TI6Hh000001?ooool00`00003oooooooooo`2;ooooo`;o0000@_ooool000Wooooo00@0
0000oooooooooooooooo1@0c<c<00`000000C4a<04a<C00804a<C004o`00000000000000000000@0
<c<c0P00000501TI6@03o`0000000000000008/000001?ooool00`00003oooooooooo`28ooooo`?o
000000?oooooo`000?ooool0@Oooool000Wooooo00@00000oooooooooooooooo1@0c<c<00`000000
C4a<04a<C00<04a<C0800000100c<c<00`0000006ATI01TI6@0401TI6H`000001?ooool00`00003o
ooooooooo`26ooooo`;o00000oooool00onY_NSo0000o`000011ooooo`002Oooool01000003ooooo
ooooooooool403<c<`030000001<C4`0C4a<00D0C4a<1@00000504a<C08000000`0c<c<3000000@0
6ATIR`000004ooooo`0300000?oooooooooo08?ooooo0ol00002ooooo`CoZKgX00?o0000ooooool0
0000@?ooool000Wooooo00@00000oooooooooooooooo100c<c<00`000000C4a<04a<C00304a<C080
00001@1VIVH200000003o`00001<C4`0C4a<0080C4a<00?o00000000000000000`0c<c<00`00003o
000001TI6@0401TI6HP000001?ooool00`00003oooooooooo`20ooooo`?o00000_ooool7ojVmj003
o`000?oooooo0000043ooooo0009ooooo`0400000?ooooooooooooooo`@0<c<c00<0000004a<C01<
C4`00`1<C4`00`000000IVIV06IVIP0706IVIP<00000101<C4`2000000<0<c<c00<0000001TI6@0I
6AT00`0I6AT00ol00000000000000024000000Cooooo00<00000ooooooooool0O_ooool2o`0000?o
oooo2OnY_NP01?l0003oZKgXooooool0000oooooo`002Oooool01000003oooooooooooooool503<c
<`050000001<C4`0C4a<04a<C00000001P1VIVH4000000<0IVIV1000000204a<C08000000P0c<c<0
0`0000006ATI01TI6@0401TI6HD000001?ooool00`00003oooooooooo`1kooooo`?o00000_ooool<
ojVmj005o`000?nY_NSoooooooooool00000?_ooool000Wooooo00D00000oooooooooooooooo0000
000403<c<`050000001<C4`0C4a<04a<C0000000101VIVH2000000@0Ogmo0`0000001Ol00000IVIV
06IVIP1VIVKo00000080000000@0C4a<o`0000000000<c<c0`00000401TI6@0300000?l000000000
084000001?ooool00`00003oooooooooo`1iooooo`;o00000oooool>ojVmj005o`000?nY_NSoZKgX
ooooool00000?_ooool000Wooooo00D00000oooooooooooooooo0000000403<c<`050000001<C4`0
C4a<04a<C0000000101VIVH00ol00000Ogmo07moO`0707moO`<000000`1VIVH010000000C4a<04a<
C000000303<c<`030000000I6AT06ATI00@06ATIP@000004ooooo`0300000?oooooooooo07Kooooo
0ol00002oooooa7oZKgX00Ko0000ojVmj?nY_NSoZKgXooooool0000mooooo`002Oooool01P00003o
ooooooooooooool06ATI000000<0<c<c00D0000004a<C01<C4`0C4a<0000000406IVIP030000001o
Ogl0Ogmo0080Ogmo1000000407moO`8000000P1VIVH20000000304a<C000000000000080<c<c0P00
000501TI6H0000001?ooool00`00003oooooooooo`1dooooo`;o00000_oooolDojVmj003o`000?nY
_NSoZKgX00;oZKgX00?o0000ooooooooool0>oooool000Wooooo00@00000oooooooooooooooo0P0I
6AT01@000000<c<c03<c<`0c<c<0000000<0C4a<00@0000006IVIP1VIVH00000101oOgl00`000000
VIVI09VIV@0209VIV@@000000P1oOgl200000080IVIV00<0000004a<C01<C4`00P00000203<c<`03
0000000I6AT06ATI00<06ATIO`000004ooooo`0300000?oooooooooo077ooooo0ol00002oooooaKo
ZKgX00?o0000ojVmj?nY_NP00onY_NP00ol0003oooooooooo`0jooooo`002Oooool01000003ooooo
ooooooooool301TI6@05o`00000c<c<0<c<c00000?l000000P1<C4`010000000IVIV06IVIP000003
07moO`030000002IVIT0VIVI00L0VIVI0P00000207moO`80000000<0IVIV0000000000000P1<C4`2
0000000403<c<`00003o0000000000<06ATIOP000004ooooo`0300000?oooooooooo06kooooo0ol0
0002oooooaWoZKgX00?o0000ojVmj?nY_NP00onY_NP00ooooooo0000ooooo`0jooooo`002Oooool0
1000003oooooooooooooool301TI6@050000000c<c<0<c<c03<c<`0000000P1<C4`01?l00000IVIV
06IVIP00000307moO`030000002IVIT0VIVI00<0VIVI1000000209VIV@8000000P1oOgl00`000000
IVIV06IVIP0200000080C4a<00D0000003<c<`0c<c<0<c<c0000000301TI6@03o`00000000000000
07X000001?ooool00`00003oooooooooo`1/ooooo`;o00000ooooolLojVmj003o`000?nY_NSoZKgX
00?oZKgX00?o0000ooooooooool0>Oooool000Wooooo00@00000oooooooooooooooo100I6AT01@00
0000<c<c03<c<`0c<c<000000080C4a<00@0000006IVIP1VIVH000000P1oOgl010000000VIVI09VI
V@2IVIT2000000@0/k>c0`0000000`2IVIT00000000000040000000406IVIP000000000004a<C080
00000P0c<c<2000000<06ATIN`000004ooooo`0300000?oooooooooo06Wooooo0ol00002oooooaoo
ZKgX00?o0000ojVmj?nY_NP00onY_NP00ooooooo0000ooooo`0iooooo`002Oooool01@00003ooooo
ooooooooool0000000@06ATI00D0000003<c<`0c<c<0<c<c0000000204a<C0030000001VIVKo0000
0080Ogmo00@0000009VIV@2IVIT000002@2c/k<30000000509VIV@000000000007moOol000000P1V
IVH01?l00000C4a<04a<C000000303<c<`030000000I6AT06ATI00806ATIN@000004ooooo`030000
0?oooooooooo06Oooooo0_l00003ooooob7oZKgX00?o0000ojVmj?nY_NP01?nY_NP00ooooooo0000
ooooo`0hooooo`002Oooool01@00003oooooooooooooool0000000D06ATI00@0000003<c<`0c<c<0
00000P1<C4`00`000000IVIV0000000207moO`040000002IVIT0VIVI000000H0/k>c0ol000030;>c
/`030000002IVIT0VIVI00@0000000D0IVIV000000000000C4a<0000000203<c<`030000000I6AT0
6ATI00<06ATIN0000004ooooo`0300000?oooooooooo06Cooooo0ol00002ooooobCoZKgX00?o0000
ojVmj?nY_NP01?nY_NP00ooooooo0000ooooo`0hooooo`002Oooool01000003oooooooooooooool2
000000D06ATI00@0000003<c<`0c<c<000000P1<C4`00`000000IVIV0000000207moO`030000002I
VIT0000000D0/k>c00Co00000<c<c03<c<`0c<c<0ol000000`2c/k<000000000000209VIV@030000
001oOgl000000080IVIV00D0000004a<C0000000000003<c<`02000000@06ATIM`000004ooooo`03
00000?oooooooooo06;ooooo0_l00003ooooobKoZKgX00?o0000ojVmj?nY_NP01OnY_NP00ooooooo
0000ooooo`0gooooo`002Oooool01000003oooooooooooooool2000000D06ATI00@0000003<c<`0c
<c<000000P1<C4`00`000000IVIV0000000207moO`040000002IVIT0VIVI000000<0/k>c00?o0000
0<c<c03<c<`01@3<c<`00ol00000/k>c0;>c/`020000000309VIV@000000Ogmo0080000000D0IVIV
0000001<C4`0C4a<0000000203<c<`030000000I6AT06ATI00806ATIMP000004ooooo`0300000?oo
oooooooo05oooooo0ol00002ooooobWoZKgX00?o0000ojVmj?nY_NP01_nY_NP00ooooooo0000oooo
o`0fooooo`002Oooool01000003oooooooooooooool200000003o`00000000006ATI00<06ATI00@0
000003<c<`0c<c?o00000P1<C4`00`000000IVIV0000000207moO`030000002IVIT000000080/k>c
00?o00000<c<c03<c<`01`3<c<`4o`000080000000?o000007moO`1oOgl0100000001P1<C4`00000
0000000c<c<00000o`0000@06ATIM0000004ooooo`0300000?oooooooooo05gooooo0_l00003oooo
ob_oZKgX00?o0000ojVmj?nY_NP01onY_NP00ol0003oooooooooo`0eooooo`002Oooool01000003o
ooooooooooooool5000000<06ATI00D0000003<c<`0c<c<0<c<c0000000204a<C0070000001VIVKo
000007moO`000000VIVI000000020;>c/`03o`00003<c<`0c<c<00<0c<c<1_l000020<c<c0;o0000
0`00000207moO`<000000P1<C4`010000000<c<c03<c<`00000401TI6G<000001?ooool00`00003o
ooooooooo`1Jooooo`?o00000_ooool^ojVmj003o`000?nY_NSoZKgX00SoZKgX00?o0000oooooooo
ool0=?ooool000Wooooo00@00000oooooooooooooooo1P00000301TI6@050000000c<c<0<c<c03<c
<`0000000P1<C4`01`000000IVIV0000001oOgl0000009VIV@0000000P2c/k<01Ol00000c<c<0<c<
c03<c<co000000H0i^KV0_l000020<c<c003o`00000000000000008000000P1oOgl30000000504a<
C0000000<c<c03<c<`000000100I6AUb000000Cooooo00<00000ooooooooool0Eoooool3o`0000?o
oooo<?nY_NP00ol0003oZKgXojVmj008ojVmj003ooooool0003ooooo03Cooooo0009ooooo`040000
0?ooooooooooooooo`H0000000Ko000001TI6@0I6AT06ATIo`000000000203<c<`050000001<C4`0
C4a<0000001VIVH00P0000001Ol00000VIVI0000002c/k?o00000080c<c<00?o00000>KViP3Vi^H0
1`3Vi^H2o`0000030<c<c?l00000/k>c00@0000000H0Ogmoo`00001VIVH0000004a<C000000203<c
<`0300000?l000006ATI00<06ATIL0000004ooooo`0300000?oooooooooo05Gooooo0_l00003oooo
oc?oZKgX00?o0000ojVmj?nY_NP02OnY_NP00ol0003oooooooooo`0cooooo`002Oooool01000003o
ooooooooooooool8000000@06ATI00<0000003<c<`0000000P1<C4`02Ol00000IVIV0000001oOgl0
000009VIV@000000/k>co`0000020<c<c003o`00003Vi^H0i^KV00T0i^KV0ol000020;>c/`030000
002IVIT000000080000000@0IVIV0000001<C4`000000`0c<c<00`0000006ATI01TI6@0201TI6@03
o`0000000000000006`000001?ooool00`00003oooooooooo`1Booooo`?o00000oooooleojVmj003
o`000?nY_NSoZKgX00WoZKgX00?oooooo`000?ooool0<oooool000Wooooo00@00000oooooooooooo
oooo2000000501TI6@030000000c<c<000000080C4a<00T0000006IVIP000000Ogmo0000002IVIT0
00000;>c/ol000000P3<c<`00ol00000i^KV0>KViP020>KViP<00000103Vi^H4o`00000:0;>c/`00
0000VIVI0000001oOgl0000006IVIP000000C4a<000000<0<c<c00<0000001TI6@0I6AT00P0I6AU^
000000Cooooo00<00000ooooooooool0D?ooool2o`0000Cooooo=onY_NP00ol0003oZKgXojVmj00:
ojVmj003o`000?oooooooooo03;ooooo0009ooooo`0400000?ooooooooooooooo`T000001@0I6AT0
0ol00000<c<c0000000204a<C00;0000001VIVH0000007moO`000000VIVI0000002c/k?o00000<c<
c?l00000103Vi^H00`000000oooo0?ooo`03000000<0i^KV00co00000<c<c?l00000/k>c0000002I
VIT0000007moO`000000IVIV0000001<C4`200000080<c<c00<0000001TI6@0I6AT00P0I6AU]0000
00Cooooo00<00000ooooooooool0COooool3o`0000?ooooo>_nY_NP00ol0003oZKgXojVmj00:ojVm
j003ooooool0003ooooo03;ooooo0009ooooo`0400000?ooooooooooooooo`T0000000?o000001TI
6@0I6AT00P0I6AT010000000<c<c03<c<`00000204a<C00:0000001VIVH0000007moO`000000VIVI
0000002c/k?o00000<c<c0;o00000P3Vi^H00`000000oooo0?ooo`030?ooo`04o`00000000000000
0>KViP?o000000<0/k>c000000000000100000000ol00000C4a<04a<C0020000000303<c<ol00000
6ATI00<06ATI00<00000o`0000000000J@000004ooooo`0300000?oooooooooo04_ooooo0_l00004
oooooccoZKgX00?o0000ojVmj?nY_NP02onY_NP00ooooooo0000ooooo`0aooooo`002Oooool01000
003oooooooooooooool<000000<06ATI00X0000003<c<`0c<c<0000004a<C?l00000000006IVIP00
0000Ogmo0P0000020;>c/`03o`00003<c<co00000080i^KV00?o00000?ooo`3oool01P3oool00`00
0000i^KV0>KViP02o`000080/k>c00@0000009VIV@000000Ogmo0`00000204a<C0030000000c<c<0
000000D06ATIJP000004ooooo`0300000?oooooooooo04Sooooo0ol00003ooooocooZKgX00?o0000
ojVmj?nY_NP03?nY_NP00ol0003oooooooooo`0`ooooo`002Oooool01000003oooooooooooooool=
000000<06ATI00@0000003<c<`0c<c<000000P1<C4`010000000IVIV0000001oOgl3000000040;>c
/ol00000c<c<o`000080i^KV00<000000?ooo`3oool01P3oool00`000000i^KV0>KViP03o`000008
0;>c/`000000VIVI0000001oOgoo000006IVIP00000204a<C0040000000c<c<00000000000@06ATI
J@000004ooooo`0300000?oooooooooo04Gooooo0ol00002ooooobooZKgX00?oZKgWojVmj?nY_NP0
0onY_NP00onY_NOoZKgXojVmj003ojVmj003ojVmionY_NSoZKgX00GoZKgX00?o0000ojVmj?nY_NP0
3?nY_NP00ooooooo0000ooooo`0`ooooo`002Oooool01000003oooooooooooooool=0000000Eo`00
000I6AT06ATI01TI6Ol00000000003<c<`00003o000004a<C0000000IVIVo`00001oOgl0000009VI
V@000000/k>co`00003<c<co00000080i^KV00<000000?ooo`3oool01P3oool01Ol0000000000>KV
i_l00000c<c<00;o000000L0000009VIVOl00000Ogmo0000001VIVKo00000080C4a<00Co000003<c
<`0c<c<00000100I6AT00`00003o00000000001U000000Cooooo00<00000ooooooooool0@oooool2
o`0000;ooooo:OnY_NP00onY_NOoZKgXojVmj003ojVmj0GoZKgW00?oZKgXojVmionY_NL00onY_NL0
0onY_NSoZKgWojVmi`03ojVmi`;oZKgX0_nY_NL2ojVmj004o`000?nY_NSoZKgWojVmi`;oZKgX00?o
ZKgWojVmj?nY_NP01onY_NP00ooooooo0000ooooo`0_ooooo`002Oooool01000003ooooooooooooo
ool?000000<06ATI00h0000003<c<`0c<c<0<c<c0000001<C4co000006IVIP000000Ogmo0000002I
VIT000000;>c/`;o00000`3Vi^H00`000000oooo0?ooo`060?ooo`040000003Vi^H0i^KVo`000080
c<c<00So00000000002IVIT0000007moO`000000IVIV00000080C4a<00@0000003<c<`0c<c<00000
1@0I6AUV000000Cooooo00<00000ooooooooool0@?ooool3o`0000;ooooo8_nY_NP2ojVmi`GoZKgX
1?nY_NL2ojVmj1;oZKgW0_nZ_NL2ojVmi`?oZ[gW00Co0000ojZmionY_NOoZ[gW1?nY_NL00onY_NSo
Z[gWojVmj005ojVmj003ooooool0003ooooo02oooooo0009ooooo`0400000?ooooooooooooooo`l0
0000100I6AT03P000000<c<c03<c<`0c<c<0000004a<C0000000IVIV0000001oOgl0000009VIV@00
0000/k>c0ol000020>KViP030000003oool0oooo00H0oooo00h000000>KViP3Vi^Ko00000<c<c?l0
0000/k>c0000002IVIT0000007moO`000000IVIV00000080C4a<00@0000003<c<`0c<c<000001@0I
6AUU000000Cooooo00<00000ooooooooool0?_ooool2o`0000?ooooo8_nY_NP5ojVmi`03ojVmj?nY
_NOoZKgW00CoZKgW0_nY_>L4ojVmi`;oZKcW1OnY_NL2ojZli`CoZKgW0_nZ_>L00onZ_NOoZ[cWojZl
i`04ojZmi`03o`000?nZ_>OoZ[gW00;oZ[gW0_nY_NL4ojZmi`;oZKgX00KoZ[gWojVmj?nY_NSoZKgX
ooooool0000_ooooo`002Oooool01000003oooooooooooooool@000000@06ATI01?o000003<c<`0c
<c<0<c<c0000001<C4`0000006IVIP000000Ogmo0000002IVIT000000;>c/ol00000c<c<o`00003V
i^H0000000T0oooo0P000000303Vi^Ko00000<c<c?l00000/k>co`00002IVIT0000007moOol00000
IVIV00000080C4a<00@0000003<c<`0c<c<000001@0I6AUT000000Cooooo00<00000ooooooooool0
>oooool3o`0000;ooooo8onY_NP<ojVmi`GoZKcW00?oZKgWojZlionZ_>L00onY_>L00onY_NOoZ[cW
ojZli`0=ojZli`04ojZmionZ_>OoZ[cWo`0000;oZ[cW00?oZ[gWojZlionZ_NL02OnZ_NL01OnY_NSo
Z[gWojZmiooooooo000002kooooo0009ooooo`0400000?oooooooooooooooa00000000?o00000000
000I6AT00P0I6AT200000080<c<c00?o000004a<C0000000100000000`2IVIT000000;>c/`04o`00
008000002@3oool010000000i^KVo`00003<c<`2o`000080000000Co0000000000000000IVIV0P00
00001@1<C4co000003<c<`0c<c<0000000D06ATI00?o0000000000000000H0000004ooooo`030000
0?oooooooooo03Wooooo0_l00003ooooob;oZKgX1_nY_NL2ojVli`CoZKgW1onY_>L3ojZli`;oZ[cV
1?nZ_>L2ojZliPCoZ[cW0_nZ_>H5ojZli`05ojZli_nZ_>OoZ[cWojZliol000001OnZ_>L2ojZmi`;o
Z[cW2OnZ_NL00ol0003oooooooooo`0/ooooo`002Oooool01000003ooooooooooooooolC000000@0
6ATI00@0000003<c<`0c<c<000000P1<C4`030000000IVIV000000000000VIVIo`0000000000/k>c
o`00003<c<co00000>KViP8000001`3oool01P000000i^KV0>KVi_l00000c<c<o`000080/k>c00@0
000009VIV@00000000000P1VIVH01`000000C4a<000000000000<c<co`00000000001@0I6AUQ0000
00Cooooo00<00000ooooooooool0=_ooool3o`0000?ooooo8_nY_NP6ojVmi`GoZKcW00?oZKgWojVl
ionY_>L00_nY_>L00onZ_>KoZ[cWojZli`03ojZli`03ojZki_nZ_>KoZ[cV00;oZ[cV00?oZ[cWojZk
i_nZ_>H00onZ_>H00onZ_>OoZ[_VojZliP03ojZliP03ojZlionZ_>KoZ[cV00?oZ[cV00?oZ[cWojZl
i_l000002?nZ_>L01?nZ_>KoZ[cWojZlionZ_>L2ojZmi`03ojZlionZ_NOoZ[gW00;oZ[gW00?o0000
ooooooooool0:oooool000Wooooo00@00000oooooooooooooooo5000000401TI6@03o`00000c<c<0
<c<c0080000000<0C4a<0000001VIVH00P00000209VIV@050000002c/k?o00000<c<c?l000000P3V
i^H2000000H0oooo00H000000>KViP3Vi^Ko00000<c<c?l000020;>c/`03o`00002IVIT000000080
000000D0IVIV0000001<C4`0C4a<0000000203<c<`030000000I6AT06ATI00@06ATIG`000004oooo
o`0300000?oooooooooo03?ooooo0ol00004ooooob;oZKgX1_nY_NL9ojVli`;oZ[_V0onZ_>H00onZ
_>OoZ[_VojZkiP03ojZkiP;oZ[cV1?nZ^nH2ojZliP04ojZkiOnZ^nKoZ[_VojZkiP;oZ[cV00?oZ[_V
ojZli_nZ_>H00onZ_>H2oj^kiP03ojZli_l0003oZ[cV00?oZ[cV00?oZ[cWoj^li_n[_>H00onZ_>H0
0onZ_>OoZ[cVojZliP03ojZli`;oZ[gW00?oZ[cWo`000?ooool0;?ooool000Wooooo00@00000oooo
oooooooooooo5P00000301TI6@080000000c<c<0<c<c03<c<`000000C4a<0000001VIVH200000006
o`000000000000000;>c/ol00000c<c<0_l000020>KViP8000001@3oool020000000i^KV0>KVi_l0
0000c<c<o`00002c/k<000000P2IVIT01Ol00000Ogmo0000001VIVH000000080C4a<00Co000003<c
<`0c<c<000001P0I6AUN000000Cooooo00<00000ooooooooool0<Oooool2o`0000Cooooo8_nY_NP3
ojVli`?oZKgW2_nY_>L5ojZkiP03ojZli_nZ^nKoZ[_V00CoZ[_V00?oZ[[UojZki_nZ^nH00onZ^nH0
0onZ^^GoZ[_UojZki@02ojZki@03ojZki_n[^^GoZk[U00?oZ[_V00?oZ[cVoj^kiOn[^nD00_n[^nH0
1?n[^^GoZk_Uoj^kiOl00002ojZliP03oj^kiOn[_>KoZkcV00;oZkcV00?oZ[cVoj^li_nZ_>H00onZ
_>H00onZ_>OoZkcVojZli`03ojZli`03o`000?oooooooooo02[ooooo0009ooooo`0400000?oooooo
oooooooooaL000000`0I6AT03`000000<c<c03<c<`0c<c<0000004a<C0000000IVIVo`0000000000
Ogmo00000?l000000000o`0000020<c<c005o`00003Vi^H0i^KV0>KViP000000103oool010000000
i^KV0>KVi_l000020<c<c005o`00002c/k<0000009VIV@0000000P1oOgl200000080C4a<00D00000
03<c<`0c<c<0<c<co`00000601TI6@03o`0000000000000005X000001?ooool00`00003ooooooooo
o`0^ooooo`?o00000_oooolTojVmj0[oZKcW00?oZKcVojVlionY_>L00onY_>L6ojZkiP03ojZjiOnZ
^nKoZ[_V00?oZ[_V1?nZ^^D2ojZkiP04oj^ji?nZ^^GoZ[[UojZji@;oZ[_U0_n[^^@00on[^^GoZkWT
oj^ii003oj^ji003oj^kiOn[^^CoZk[T00?oZk[U00?oZk_Uo`000?n[^^@00on[^nD2oj^liP04oj^k
iOn[_>KoZkcVoj^liP;oZ[cV1?n[_>H2ojZli`;oZkcV00?o0000ooooooooool0:Oooool000Wooooo
00@00000oooooooooooooooo6000000301TI6@8000000P0c<c<00`000000C4a<0000000206IVIP05
0000001oOgl0000009VIV@0000000_l000000`3<c<co00000>KViP020>KViPD000000`3Vi^H02?l0
0000c<c<0<c<c?l00000/k>c0000002IVIT000000P1oOgl200000080C4a<00D0000003<c<`0c<c<0
<c<c0000000701TI6E/000001?ooool00`00003oooooooooo`0/ooooo`;o00000ooooolQojVmj0co
ZKcW0_nY^nH3ojVliP03ojVlionY^nKoZK_V00CoZ[_V1OnZ^^D00onZ^nKoZ[WTojZii004ojZji@?o
ZkWT0_n[^^@01_nZ^^GoZkWToj^ii?n[^NCoZk[Toj^hh`CoZkWT00?oZk[Tojbihon[^^@00on[^^@0
1?n[^^Go[;WSoj^ji?l00002oj^ji003oj^kiOn/^^CoZk_U00?oZk_U00?oZkcVoj^kiOn[^nD00_n[
_>H00on[^nGoZkcVoj^liP04oj^liP03o`000?oooooooooo02Wooooo0009ooooo`0400000?oooooo
oooooooooaP0000000?o000001TI6@0I6AT00P0I6AT01P000000<c<c03<c<`000000C4a<00000080
IVIV00P0000007moO`000000VIVI0000002c/k?o00000<c<c0;o00002@3Vi^H01?l00000c<c<0<c<
c?l000020;>c/`07o`00002IVIT0000007moO`000000IVIV0000000204a<C0050000000c<c<0<c<c
03<c<`0000001`0I6AUJ000000Cooooo00<00000ooooooooool0:Oooool3o`0000;ooooo0_nY_>L4
ojVmj0;oZKgW6_nY_NP<ojVli`GoZK_V00?oZKcVojVki_nY^nH00onY^nH00onZ^nKoZ[[UojZji@04
ojZji@GoZ[WT00?oZ[[Uoj^hhon[^><00_n[^N@01?n[]n;oZkSSoj^hhon[^><2oj^ii004ojbgh_n[
^>?oZkSSoj^hh`;oZkWT00Co[;SRojbihon/^N?o[;WS0_n[^^@01on/^>;o[;WSojbihon/^N?o0000
oj^ji?n/^N<00on/^^@2oj^ki@;o[;[T00?oZk_Uojbji?n[^nD00on[^nD00on[_>Ko[;_Uoj^liP03
oj^liP03o`000?oooooooooo02Sooooo0009ooooo`0400000?oooooooooooooooaX00000100I6AT0
2?l00000<c<c03<c<`000000C4a<o`0000000000IVIV0`0000000`2IVIWo000000000004o`0000T0
i^KV00Ko00000<c<c03<c<co00000;>c/`00000209VIV@04o`00001oOgl0000006IVIP80000000<0
C4a<o`00000000000P0c<c<2000000H06ATI00?o0000000000000000EP000004ooooo`0300000?oo
oooooooo02Oooooo0_l00003ooooo`;oZ[cV0onY_>L01?nY_NSoZKcWojVlionY_>L2ojVmi`06ojVm
j?nY_>OoZKcWojVlionY_NSoZKcW1?nY_NL00onY_NSoZKcWojVmj004ojVmj003ojVmionY_NSoZKgX
00?oZKgX3?nY_>L6ojVkiP;oZK[V1?nY^nH2ojZii@CoZ[[U0_nZ^>@00onZ^NCoZkORoj^hh`04oj^h
h`03oj^fhOn[]n;oZkOR00;oZkOR00?oZkSSojbfhOn/]n800on/]n800on[^>?o[;KPojbhhP03ojbh
hP03ojbihon]]n7o[;SR00?o[;SR00?o[;WSojfhh_l000000on/^N<00on/^^Co[;WSojbih`02ojbj
i004ojfjhon/^^Co[;[Tojbji0;oZk_U00Co[;_TojbkiOn/^nGo[;_U0_n[_>H00on/_>Goooooo`00
000Yooooo`002Oooool01000003ooooooooooooooolK000000@06ATI0P0000001@0c<c?o00000000
001<C4`000000080IVIV00D00000o`0000000000VIVI000000020;>c/`Co00001P3Vi^H01?l00000
c<c<0<c<c?l000020;>c/`060000002IVIT0VIVI0000001oOgl000000P1VIVH010000000C4a<04a<
C000000303<c<`030000000I6AT06ATI00D06ATIE`000004ooooo`0300000?oooooooooo02Cooooo
0ol00003ooooo`;oZ[[U0onZ_>H00onY_>OoZ[_VojZkiP02ojVli`04ojZjiOnZ_>KoZ[cVojZliP;o
ZKcW00CoZ[_VojVlionY_>OoZKcW0_nY_NL01OnZ_>KoZKcWojVlionY_>OoZKgX00;oZKcW0onY_NL0
0onY_NSoZKcWojVli`0:ojVli`KoZK_V1?nY^^H00onY^NCoZKWUojVii@02ojVii@03ojZiiOnZ^>?o
Z[SS00?oZ[SS00?oZ[STojZfh_n[]n800_n[]n82oj^hh`04oj^eh?n[]^7oZkKQoj^fh@;oZkOR00Co
[;GOojbfhOn/]^7o[;KQ0_n/]n801?n/]Moo[;KPojbfh?n/]^02ojbhhP04ojffgon]]n7o[KOQojfg
h@;o[;SR0_n]]n001?n]^>;o0000ojbihon/^N<2ojfhh@03ojbihon^^>7o[K[S00?o[K[S00?o[;[T
ojfjhon/^n@00on/^n@00on/^nGo[;_Tojbki003ojbli@03o`000?oooooooooo02Oooooo0009oooo
o`0400000?oooooooooooooooad00000100I6AT01@000000<c<c03<c<`000000C4a<0080000000<0
IVIV0000001oOgl010000000102c/k?o0000o`00003<c<`4o`0000030>KVi_l00000c<c<00<0c<c<
00Ko00000;>c/`2c/k<0000009VIV@00000207moO`04o`00001VIVH0IVIV00000080C4a<00D00000
03<c<`0c<c<0<c<c0000000801TI6ED000001?ooool00`00003oooooooooo`0Rooooo`;o00001?oo
ool2oj^ghP?oZ[[U00CoZ[cVojZhhonZ^>?oZ[_V0_n[]^43ojZji@03ojZli_n[^>?oZkSS00?oZ[_V
00?oZKcWojZjiOnZ^^D00onZ_>H00onY_>OoZ[_VojZkiP03ojVli`03ojVmionY_>OoZKcW00SoZKcW
1_nY^nH6ojVjiPCoZKWT0_nY^ND00onY]n?oZ[SSojZhh`03ojZhh`05ojZfhOnZ]^;oZ[KRojZfh_n[
]n800_n[]=l3oj^eh003oj^fhOn//mko[;?N00?o[;GO00?o[;KQojbcgOn//md00on/]Ml00on/]^3o
[KCMojfdg@03ojffg`03ojfghOn^]Mko[[GN00?o[KOP00?o[[OOo`000?n^]ml00_n]^>401?n^]moo
[[SQojjhhOn^^>42ojfjh`04ojjihOn]^^?o[K[Sojfjh`;o[;_T0_n]^^<00on/^nCo[K_Sojbki@03
ojbki@03o`000?oooooooooo02Kooooo0009ooooo`0400000?oooooooooooooooah00000100I6AT0
1?l00000<c<c03<c<`00000204a<C0050000001VIVKo00000000001oOgl00`0000020;>c/`;o0000
0`3<c<`00ol00000c<c<0<c<c0040<c<c006o`00002c/k<0/k>c0000002IVIT000000P1oOgl01000
0000IVIV06IVIP00000204a<C005o`00000c<c<0<c<c03<c<`0000002@0I6AT00`00003o00000000
001@000000Cooooo00<00000ooooooooool07oooool3o`0000Cooooo0_n[/]h00on[]n;o[:kIojb^
f@03oj^dg`03ojZhhon//=_o[;3K00?oZkKQ00?oZ[[Uoj^cg_n[/mh00on[^><00onZ^nKoZkKQoj^f
h@03ojZji@03ojZli_nZ^NCoZ[WT00?oZ[_V00?oZKcWojZjiOnZ^^D00_nY_>L01OnZ^NCoZK_VojVk
i_nY^nKoZKcW00;oZK[U1?nY^nH2ojVji@CoZK[V1_nY^N@5ojVgh`03ojZhhonZ]N7oZ[KQ00?oZ[KQ
00?oZ[KRoj^cgon[]=l00on[]=l00on[]N3oZk;MojbcgP03ojbcgP03ojbegon//]co[;?M00?o[;?M
00?o[;GOojfbg?n]]=d00on]]=d00on]]]oo[[?LojjegP03ojjegP04ojfgh?n^]Mgo[[GMo`0000;o
[kGM0on^]ml00on^^>7o[kOOojngg`03ojjih@03ojfjhon^^N7o[[WQ00;o[K[S00Co[[[Rojfkhon]
^n?o[K_S0_n/^nD00on]^nCoooooo`00000Wooooo`002Oooool01000003ooooooooooooooolO0000
00<06ATI0P00000203<c<`07o`0000000000C4a<o`0000000000IVIV0000000207moO`0300000?l0
000000000080/k>c0_l000070<c<c007o`00002c/k<0/k>c0;>c/`000000VIVI0000000207moO`04
0000001VIVH0IVIV00000080C4a<00<0000003<c<`0c<c<00P0c<c<00`0000006ATI01TI6@0901TI
6E0000001?ooool00`00003oooooooooo`0Looooo`?o00001?ooool3ojb]f003oj^bg_n]Y]7o[JKA
00?o[:kI00?oZkCOojfXdon]Z=<00on//=/00on[]^7o[:cFoj^cgP03oj^cgP03oj^hhon//=_oZkKQ
00?oZkKQ00CoZ[[Uoj^dgon[]=ooZ[WT0_n//M`3oj^ghP03ojZjiOn[]^7oZkKQ00?oZ[WT00?oZK_V
ojZhhonZ^><00onY^^D00onY^nKoZKWTojVji@03ojVji@03ojVji_nY^>CoZKWT00CoZKWT1_nY]n<0
1?nY]N7oZ[GQojZehOnZ]N42ojZfh@04ojZcg_n[/mooZk?Ooj^cg`;oZkCO00CoZk7Loj^bgOn[/]go
Zk;M0_n//mh01?n//=_o[;;Lojbbg?n//]`2ojbcg@04ojf`f_n]/]co[K;Lojfbg0;o[KCM00Co[[7J
ojjcg?n^/mco[[?L0_n^]Mh2ojncf`03ojjegOn`/m[o000000?o[kGM00?o[[OOok2egOn_]ml00on_
]ml01?n^^N7o[kSOojnhgon^^N42ojnhh0?o[[[R00?o[K_Sojjjh_n]^n@00on]^n@00ol0003ooooo
ooooo`0Uooooo`002Oooool01000003ooooooooooooooolP000000@06ATI0P00000203<c<`050000
001<C4`0C4a<0000001VIVH00P0000000`1oOgl0000009VIV@0200000080/k>c00?o00000<c<c03<
c<`00`3<c<`00ol00000/k>c0;>c/`030;>c/`030000002IVIT000000080Ogmo00@0000006IVIP1V
IVH000000P1<C4`00`000000<c<c03<c<`0203<c<`030000000I6AT06ATI00/06ATIC@000004oooo
o`0300000?oooooooooo01[ooooo0_l00005ooooo`;o[:KA0on/[MP4ojfVd@03ojb^fOn]WlWo[JSC
00?o[JSC00?o[;3KojfRc?n/[=H00_n/[=H2oj^cgP04ojfWdOn//=_o[;3Kojb`f`;oZkKQ0_n][=L0
0on[]=oo[JSBojfXdP03ojbag003oj^gh_n/[mWoZkKQ00?oZkKQ00?oZ[WToj^dgonZ^><00onZ^><0
0onY^^GoZ[ORojVii002ojVii0;oZK[U00CoZKOSojVhi?nY^>CoZKST0_nY^N@00onY]^;oZKOSojVg
h`03ojVgh`05ojVdhOnY]N7oZKGQojVehOnZ]N400_nZ/]h3ojZcgP03oj^cgon[/=coZk3L00?oZk7L
00?oZk;Mojb_f_n/[mX00on//=/00on//]co[JkHojf`fP03ojf`fP03ojfbg?n^[mSo[[7J00?o[[7J
00?o[[?Lojn`fOn_/=T00_n_/m/01?n`/=So/;?Jok2cf_l00002ojneg@04ok6cf_n`]Mgo/;GMok2e
g@;o[kOO00Co/;KMojnhgon_^=oo[kSO1?n_^>000on^^^;o/;WQojjjhP02ojjjhP;o[K_T0_n^^n<0
0ol0003oooooooooo`0Tooooo`002Oooool01000003ooooooooooooooolQ000000D06ATI00Co0000
03<c<`0c<c<000000P1<C4`01P000000IVIV06IVIP000000Ogmo00000080VIVI00<000000;>c/`2c
/k<01Ol000060;>c/`040000002IVIT0VIVIo`000080Ogmo00@0000006IVIP1VIVH000000P1<C4`0
0`000000<c<c03<c<`0203<c<`030000000I6AT06ATI01406ATIAP000004ooooo`0300000?oooooo
oooo01Oooooo0ol00005ooooo`;o[J7;0on/Y]400on/[MSo[Io9ojfOb@02ojfVd@04ojfG`?n]WlWo
[Io9ojfOb@;o[JSC00Go[IS1ojfRc?n]X/co[J;<ojb/eP02ojjLa@?o[JOA00?o[;3KojjRbon^X//0
0on][=L4ojfXdP03ojbag?n^YLko[:oI00;o[:oI0_n[]^401?n][=OoZkCOoj^dgon[]=l2ojZhh`05
oj^bgOnZ]n;oZ[ORojZgh_nY^N@00onZ]N42ojVgh`04ojVhi?nY]N7oZKGQojVeh@;oZKKR00?oZKOS
ojVch?nY/n000onY]>400onY]N7oZK7NojZbgP03ojZbgP03ojZcg_nZ[m_oZk3L00?oZk3L00?oZk7L
ojb]fOn/[mX00on/[mX00on//=_o[JcGojf^f002ojf^f0;o[K3J00Co[ZgFojj_f?n^[mSo[ZoH0_n^
/MX01?n`[]Ko[k3Iojn`fOn_/=T4ok2`f0;o00001?na/mX00on`]Mgo/[CJok2fg@03ok2fg@03ojnh
gona]mgo/KOM00;o[kSP00Go/KSNok2ihOn`^N7o/;WQojjjhP02ojnjh@;o[[_S00?o[k_Rooooool0
00009Oooool000Wooooo00@00000oooooooooooooooo8@0000000ol000006ATI01TI6@0201TI6@80
00000P0c<c<00ol00000000004a<C0020000000306IVIP00000000000080000000<0VIVIo`000000
00002`2c/k<01@000000VIVI09VIV@2IVIT000000080Ogmo00@0000006IVIP1VIVH000000P1<C4`0
0ol00000000003<c<`0203<c<`03o`00000000006ATI01@06ATI@P000004ooooo`0300000?oooooo
oooo01Kooooo0_l00005ooooo`03ojbLa_n]XL_o[J7;00;o[J7;00?o[:KAojfH`_n]WlT00_n]WlT0
1?n]Y]7o[IO0ojfG`?n]Ul02ojfOb@04ojfXdon]V<7o[IS1ojfH`@;o[J;<1?n^W<D00on]Ym7o[YJn
ojjRb`03ojjRb`03ojf/eon^WLGo[Yg500;o[JSB00Go[iW0ojjUc_n^YLko[ZG>ojb_f@02ojjQbP?o
[JcG00?oZkCOojfZe?n]Z]@00on[/]d01_nZ]n;o[;3Kojb`fon//=_oZ[GQoj^]f@?oZ[;N0_nY]N40
1?nZ/=coZK;OojVbgonY/]l3ojVch003ojVdhOnY/=goZK7N00;oZK7N0_nZ/]h01?nZ[][oZZoKojZ_
fonZ[m/2oj^`g004oj^/f?n/[MWo[:gIojb]f@;o[:oJ00Go[:_Eojf/eon][=Oo[JcGojf^f002ojj[
e0?o[ZgF00?o[ZoHok2/e?n`[=@00on`[]H00on_/=Wo/JkEok6^e@03o`000003ok6aeol0003o/K7G
00;o/K?J00Co/k7Gok:df_nb]=[o/[CJ0_n`]]d2ok:efP03ok6ggOnc]]_o/KSN00?o/KSN00Go/;WQ
ok6igona^Moo[k[Qok6jh004ojnkhP03o`000?oooooooooo02?ooooo0009ooooo`0400000?oooooo
ooooooooob@00000100I6AT01@000000<c<c03<c<`0c<c<000000080C4a<00<0000006IVIP1VIVH0
200000080;>c/`050000002IVIT0VIVI09VIV@0000000P1oOgl01@000000IVIV06IVIP1VIVH00000
00<0C4a<00<0000003<c<`0c<c<00P0c<c<2000001H06ATI?`000004ooooo`0300000?oooooooooo
01Kooooo00?o0000ooooool000000_ooool01?n/VL?o[9c6ojbLa_n/W<H2ojfQb`06ojbC_?n]V<;o
[IS2ojfH`_n]WlWo[I2h1?n]Ul000on]WlWo[I2hojfH`@03ojfH`@03ojfRc?n^T[Wo[Y:i00?o[Yc5
0on^U[h2ojjRb`05ojjA^?n^WLGo[Yg5ojjMaOn]Z=800on_VL02ojjUcPCo[Z7:00?o[JcGojnNaon]
Z]@00on]Z]@00on[/]go[JOAojfWd@02ojb`f`05ojjUcon[[MWoZjgIoj^]fOnZ/]h00_n[ZmL3ojZ`
g003ojVbgonY[M[oZJgJ00?oZJoL0_nY/=d00onY/MkoZJgJojV]fP03ojZ^fP03ojZ_fonZZmOoZZ_G
00?oZjcH00?o[:gIojbYe?n/ZmD00on/ZmD00on][=Oo[ZSBojj[e003ojj[e003ojj]e_n_ZM7o/:cD
00?o/:cD00?o/:kFok6[d_l000000_l00004ok:^e003ok6aeol0003o/k7G00?o/k7G00?o/[CJok>b
eonb]MX00_nb]MX01?nd]=So/kKKok>ffonc]]/2ok6hgP04ok>gg?na^Moo/KWOok6ig`?o/K[P0_n_
^n800on`^n7oooooo`00000Tooooo`002Oooool01000003ooooooooooooooolU000000@06ATI0P00
000203<c<`80000000<0C4a<0000000000000P1VIVH00`000000Ogmo07moO`020000000309VIV@00
0000000000800000102c/k<00`000000VIVI09VIV@0209VIV@040000001oOgl0Ogmo000000<0IVIV
00D0000004a<C01<C4`0C4a<0000000503<c<`030000000I6AT06ATI01L06ATI>`000004ooooo`03
00000?oooooooooo01Kooooo00Co0000ooooooooooooZiS30on/VL<2ojbLaPCo[9>l0_n]V<83ojf@
^0?o[IO00on]T;P3ojfH`@Co[Y:i00?o[Yc5ojj=/on^U[h00_n^U[h4ojjA^0;o[Yg51?n_VL000on^
YLko[iFlojnE_003ojjQbP?o[ik70_n]Z]@01?n_W<Co[JOAojfWdOn]Ym44ojjUc`03oj^]fOn^Xlgo
Zj_G00?oZj_G00?oZ[3Loj^Xe?nY[MX00onY[MX01?nY[mcoZJWFojV[fOnYZmT4ojV]fP03ojZ^f_nZ
ZMKoZZ_G00?oZZ_G00?oZjcHoj^Wdon/ZM@00_n/ZM@2ojb[e@04ojfVd?n^Z=;o[ZSBojjXdP;o[Z_D
00Co[jK?ojnYdOn_ZM7o[jWA0_n`[=@3o`000004ok6[d_na[]Go/Z_Aok:[d@?o/ZkD0_nc[m@01?l0
003o/k7Gok>aeond/=@3ok>be`06ok:ef_nd]=So];CHokBdf?nc]]_o]KKI1?nc]m`01Ona^Moo/kWN
ok>ig_na^^3o/[[O00Co/;_Q00?o0000ooooooooool08_ooool000Wooooo00@00000oooooooooooo
oooo9@0000000ol00000000001TI6@0301TI6@8000000P0c<c<00`000000C4a<04a<C00200000003
06IVI_l0000000000080Ogmo0P00000309VIV@D00000102IVIT01@000000Ogmo07moO`1oOgl00000
00<0IVIV00Go000004a<C01<C4`0C4a<0000000503<c<`030000000I6AT06ATI01T06ATI>0000004
ooooo`0300000?oooooooooo01Kooooo00?o0000oooooon[V<<00_n[V<<2ojbI``03ojbLa_n/TK[o
[96j00?o[9>l00?o[IS2ojb</on]T;P00on]T;P00on]Ul3o[HZ`ojf@^003ojf@^003ojfH`On]R[3o
[HZ`00;o[Y:i00Co[XFZojj=/on^SK?o[Xfc0_n^U[h01On_R:go[Y6hojjA^?n^TKSo[Yg500;o[hjc
0on_VL04ojnE_003ojjQb_n`TkSo/9>h00;o[ik71?n_W<@00on]Ym7o/9_2ok2K`P03ojjUc`?o[Z?=
0_n[ZmL01?n]XL_oZjSDoj^Xe?n[Z=@2ojV]fP04ojZUdOnYZMKoZJWFojVYeP;oZJ_I0_nY[MX01?nY
YmGoZZWFojZYe_nZZMH2ojZ[e`05ojZUd_n[Ym?oZjOCoj^Wdon/ZM@00_n/Y<l3ojfVd003ojjXd_n^
Y<go[ZC=00?o[jK?00Co[jWAo`000?l0003o00000_naZ<l00onaZm;o/ZS>ok:[d@03ok:[d@06ok:^
e?nd[=3o]:c@ok>_e?nf[M3o00000ond/=@00onc/]Oo][7DokJae002okBdf004okJce_ne]]Wo]KKI
okFff@;o/kOL0_ne]m/00onc^Mko];WLok:jg`02ok:jg`;o/;_Q0_nb^n400ol0003oooooooooo`0Q
ooooo`002Oooool01000003ooooooooooooooolW000000H06ATI00D0000003<c<`0c<c?o00000000
000204a<C080000000<0IVIV0000000000000P1oOgl2000000X0VIVI00D0000007moO`1oOgl0Ogmo
0000000406IVIP050000001<C4`0C4a<04a<C00000001@0c<c<00ol0000000000000000K01TI6CD0
00001?ooool00`00003oooooooooo`0Eooooo`03o`000?nYVLKoZiS300?oZiS300?o[9W3oj^@^_n/
TKX00_n/TKX3ojbC_0?o[8bc0_n]T;P01?n]QZco[HZ`ojf:/?n]R[02ojf@^005ojf5ZOn]R[3o[HZ`
ojf:/?n^T[T00_n^QJX3ojj=/`03ojjF__n_R:go[hR]00?o[Y6h1?n_S[<00on_VL3o/8^_ok2;[`02
ojnE_005ok69[?n`TkSo/9>hok2C^?n_W/L00_naTKH3ojnLa0Co/9_200?o[ZG?ok2J`?n`V/000_n^
Xld4ojfQb`03oj^Xe?n]WlWoZZGA00?oZZGA00?oZJWFojZRconYYM<00_nYYM<3ojVWe@03ojZYe_nY
Y=7oZJCA00?oZZGB00?oZjOCoj^Rc_n/Y<l00on/Y<l00on]Y]3o[J;<ojjTc@03ojjTc@?o00000_n`
YLd2ok6Xc`04ok:UbonbZ<ko/ZS>ok:XcP;o/Z_A00Co]:S=okB/d?nd[=3o]:c@0_nf[M001?l0003o
]Zg@okB`e?ng[]43okJae006okRad_nf/mKo][?FokJce_ne]]Wo]kGG0one]m/01Ong]mWo];WLokBi
g?nd^Mco/[[O00;o];[N0_nb^n400onc_>3oooooo`00000Rooooo`002Oooool01000003ooooooooo
oooooolX000000H06ATI00@0000003<c<`0c<c<0<c<c0P00000204a<C0030000001VIVH0IVIV0080
00000P1oOgl00`000000VIVI09VIV@0709VIV@030000001oOgl0Ogmo0080Ogmo00D0000006IVIP1V
IVH0IVIV0000000404a<C0030000000c<c<0<c<c00D0<c<c0P00000J01TI6C@000001?ooool00`00
003oooooooooo`0Eooooo`03o`000?nYVLKoZIW600?oZiS30_n[T;X4ojbA^P03ojbC_?n/RK7o[8bc
00;o[8bc00?o[I2hojf6[?n]QZ`00on]R[000on]T;So[HFYojf5Z@03ojf:/0Co[XFZ0_n^SK<4ojn8
[@03ojjA^?n_QZSo[hjc00?o[hjc0on`Rjl01?n_UKco/HV/ok69[?naRJ`2ok2C^0Co/I6f00?o[ic4
ok:A]?nbTK@00_n`Vl801OnbT;?o/9[0ok2J`?n`V/3o[Z?=00;o/9Vo0on]XL/3ojfOb@?oZZGA0onZ
X/l3ojVUd`03ojVWeOnYXLooZJCA00?oZJCA00?oZZGBojZPcOn[X/h00_n[X/h2ojbTc`04ojbOb_n]
X/co[J;<ojfRc0?o00000on`XlX2ok2Uc@Co/ZG;00?o/ZS>okBUbOndZ<d00ondZ<d00ond[=3o]Z[=
okJZc@02okJ]d005o`000?ng[]7o]jkAokN^dOnf/M@00onh/M800onf/mKo^K?DokNee`02okNee`06
okFgfong]mWo]kOIokNgfOnd^Mco]kWK0ond^]h4ok>lh003o`000?oooooooooo023ooooo0009oooo
o`0400000?ooooooooooooooobT000001P0I6AT00`000000<c<c03<c<`0203<c<`040000001<C4`0
C4a<000000<0IVIV00<0000007moO`1oOgl00`00000509VIV@030000001oOgl0Ogmo00<0Ogmo00<0
000006IVIP1VIVH00P1VIVH00`000000C4a<04a<C00204a<C003o`00000c<c<0<c<c00H0<c<c00<0
000001TI6@0I6AT06P0I6ATa000000Cooooo00<00000ooooooooool05Oooool01_l0003oZIW6ojVI
a_nYVLKoZiS3ojRB_P?oZi2j0_n/TKX01?n[RK;o[8Vaojb9/On/RK42ojb</`Co[HJ/0_n]R[04ojf5
Z@;o[HZ`1?n^QJX00on^SK?o[h>Uojn8[@03ojn8[@?o[hJX0_n_S[<01?n`Q:Go/8^_ok2;[on`Rjl4
ok69[003ok2C^?nbRJ[o/I6f00?o/I6f0onbTK@01?n`Vl;o/Y2cok:@/onbT;<2ok2J`0Co/9Vo00?o
[J7;ok2H_on`V;l00on]WlT00onZYM7o[9g8ojbMb002ojZRc`;oZJGC00CoZIk;ojVQconYXLooZJ7?
0_nYY=401?nYW/_oZZ3=ojZPcOnZX<d2oj^RcP03ojbTcon/Wl[o[9o:00?o000000Co[ZC=ojnPb?n_
X<So[j380_n`XlX00on`YLgo/Z;8ok:Rb003ok:Ub`?o]:G90_ndZ<d01OnfY/Wo]Z[=okJZcOnfZ/go
]Zg@00;o^:c=00?o0000okN^dOni[/h00onh/M801Onj/=3o^K?DokVce?ni/mCo]kGG00;o^KKF0_ng
]mT01Oni^=So]kWKokNifong^M_o];[N00;o][_N0_nc_>02okBmh003o`000?oooooooooo01oooooo
0009ooooo`0400000?ooooooooooooooob/000001@0I6AT200000080<c<c00Go00000000001<C4`0
C4a<o`0000020000000306IVI_l00000000000<0Ogmo1@0000000ol00000Ogmo07moO`0407moO`04
0000001VIVH0IVIV06IVIP800000101<C4`2000000L0<c<c00@00000o`000000000000006P0I6AT0
0ol0000000000000000/000000Cooooo00<00000ooooooooool05Oooool01?l0003oooooojVIa_nU
U/D3ojRB_P;oZi2j00?o[96joj^9/_n[RK800on/RK400on/S;?o[8BZojb4ZP03ojf6[0;o[HZ`1?n]
QJT00on]R[3o[X6Tojj5ZP03ojj5ZP?o[h>U0_n_R:d01On`PJ;o[hJXojn6Z?n_QZSo[hjc00?o/8BU
0_n`Rjl4ok69[0?o/XVZ0_naTKH01?ncRJWo/Y6dok:A]?nbTK@4ok:@/`03ok2J`?ncTK?o/i6c00;o
/9Vo00Co/i6cok2H_on`V;oo/9Ro0_n]WlT01On_Ukko[9g8ojbMb?n/WLSoZZ;?00;oZi_60onYW//0
0onYXLooZI_8ojVNb`03ojVNb`;oZZ3=00?oZj;>oj^Mb?l000000_l000000on/Wl[o[J;<ojjMa`04
ojnPb003ok2Sb_naWlKo/Z;800?o/Z;800?o/ZG;okBRaondX/L00_ndYLT4okJVb@03okJZcOnhZ<Wo
^:c=00;o^:c=00Go^Z_:o`000?ni[/ko^Jk>okRadP03okZ`d003okVce?nk/m;o^KKF00;o^KKF1?ni
^=P01Ong^M_o^;[KokRjfonf^mko]kcM00?o];gP00?o][kPooooool000008?ooool000Wooooo00@0
0000oooooooooooooooo;@00000501TI6@050000000c<c<0<c<c03<c<`000000101<C4`200000003
06IVIP000000000000d0Ogmo00<0000006IVIP1VIVH00`1VIVH00`000000C4a<04a<C00304a<C003
0000000c<c<0<c<c00P0<c<c0`00000I01TI6Bd000001?ooool00`00003oooooooooo`0Eooooo`03
o`000?ooooooYIK500;oYIK50_nXT[h00on[T;[oZ8^foj^9/P03oj^9/P;o[8Va0on/Q:X3ojf6[003
ojf:/?n]PZKo[H:V00?o[HFY0on^PJ@3ojj5ZP?o[h>U00?o[hR]ok21X_n`PJ800on_QZP4ok24Y@03
ok2;[onbQ:?o/XBS00?o/HV/0onbRJX01?naTKKo/hVYok>9ZOncRJT2ok:A]004okF:Z?nbT;?o/Y2c
ok:@/`?o/i6c00Co/9Vook>A/oncTK?o/i6c0_n`V;l4ojnG_P03ojbMb?n^U[koZi_600?oZi_600?o
ZIk;oj^Ha?nYVlP00_nYVlP3ojVNb`04ojZPcOnZVlOo0000o`0000;oZig800?o[9o:ojbKaOn^WLL0
0_n^WLL2ojnPb004ok2La?naWlKo/Io6ok6OaP;o/Z;800Go/io4okBRaondX/Oo]:;7okBUb@02okJS
aP?o]ZK90onhZ<T01?nh[<go^Z_:okZ[b_l00002okV^cP?o^[3@00Go_K7>ok^cd_nk/m;o^k?BokVf
eP02ok^fe0;o^KSH0_nk^MP00onh^]_o^[cJokNlg@02okNlg@05okBmh?nf_^3o][kPokJnh?l00000
8?ooool000Wooooo00@00000oooooooooooooooo;@0000000ol000006ATI01TI6@0301TI6@040000
000c<c<0<c<c03<c<`800000101<C4`00`000000IVIV06IVIP02000000`0Ogmo00<0000006IVIP1V
IVH00`1VIVH00`000000C4a<04a<C00304a<C08000002`0c<c<4000001L06ATI:`000004ooooo`03
00000?oooooooooo01Gooooo00?o0000ooooooooool00_nUU/D00onXT[koXhnoojR;]P02ojR;]P?o
ZhVb00?o[8Vaoj^4Zon/Q:X00_n/Q:X3ojf6[0?o[H:V0_n]QJT01?n^Oj7o[X6Tojj1Y?n^PJ@2ojj5
ZP04ojmoX?n_PjGo[h>Uojn3Y@Co/86R0_n_QZP4ok24Y@?o/XBS0_naRJ`01?ncQ:;o/XVZok:9Z_nb
RJX4ok>9Z@03ok:A]?neRZSo]HZX00?o/Y2c1oncTK<00on`V;oo/i:dok>B]003ojnG_P?o[YJn0_n[
VlH01?n]UKkoZiS4oj^Ha?n[V<@2ojVKb0;oZIk;0ol000001?nZVlOoZig8oj^Mb?n[V<<3ojbKa@;o
[Yg71?n`W<@2ok6OaPCo/io40_ndX/L4okJSaP03okJVbOnhYLKo^:G600;o^:S900Go^ZS6okZ[b_nj
Zl[o^Z_:o`000002okb^c006okZ`d?nm/Lko_K7>okfac_nk/m;o_[CA0onk]]@3ok^if005okfkeonj
_=[o^[cJokZlf_ng_=d00_ni_]d2okJnh003okNoh?oooooo000001oooooo0009ooooo`0400000?oo
ooooooooooooobh000001P0I6AT2000000<0<c<c0P00000304a<C08000000P1VIVH00`00003o0000
0000000907moO`030000001VIVH0IVIV00@0IVIV00<0000004a<C01<C4`0101<C4`00ol00000<c<c
03<c<`0<03<c<`0400000?l000000000000001D06ATI:@000004ooooo`0300000?oooooooooo01Co
oooo00Ko0000ooooooooooooooooojFFaOnJULh2oj>?_`?oZ8^f0on[RK82oj^4Z`Co[8BZ00?o[HJ/
ojf1YOn]PZH00_n]PZH00on]QJWo[WnQojioX@03ojj1Y004ojj5Z_n_Oj3o[gnPojmoX0;o[h>U1?n`
PJ800on_QZSo/H2Ook24Y@03ok24Y@?o/XBS00Co/HV/ok>4X_ncQ:;o/hBR0_nbRJX01?nfQJ7o/hVY
ok>9ZOncRJT4okF:Z003ok:@/onfRjWo]X^Y00;o/i6c00Co]hfZok>A/oncTK?o/i6c1?ncT[@00on_
Ukko/i>fojjF_P02ojjF_P04oj^Ka_n]UKko[IFnojfE_P;oZiS400CoZI_8o`000?l0003o00000_nY
V<D2ojZKa`CoZiS30_n/VlD00on^WLOo[Y[2ojjJ`P03ok2La003ok6Oa_nbW<;o/Yc200?o/io400?o
]:;7okFP`oneX<<00_nfXlH01OnhX/;o^:G6okRUa_nhYLKo^:S900?o^ZS600Go^Z_:okf[b?nl[/co
0000okb^c003okfacP05ol2bcOnn]=7o_[CAokjddOnk]]@00_nn^=@01Onk^MSo_K_Gokfkeonm^mOo
^[cJ00;o_;gJ00?o^KkMokZog_ng_n000ong_n000ooooooo0000ooooo`0Mooooo`002Oooool01000
003oooooooooooooool_000000L06ATI00<0000003<c<`0c<c<00P0c<c<00`000000C4a<04a<C002
04a<C08000000`1VIVH3000000H0Ogmo00<0000006IVIP1VIVH0101VIVH00`000000C4a<04a<C005
04a<C0800000400c<c<3000001@06ATI9`000004ooooo`0300000?oooooooooo01Cooooo00Co0000
oooooooooooooooo0onJULh2oj>?_`?oZ8^f00?oZhVbojR6/?n[Q:/00_n[Q:/3ojb4ZP;o[H6U0on]
PZH4ojioX@;o[X6T1?n_Oj000on_PjGo/GjMok21XP03ok21XP03ojn6Z?naP9oo/H2O00;o/8BU00Co
/h6Mok:4XonbQ:?o/XBS1?ncQ:800onbRJ[o]XFQokJ5X@03ok>9Z@Co]HZX0onfRjT00oncTK?o]hfZ
okN=ZP03ok>A/`Co/i:d0oncTkH2ojjF_PCo[IFn0ol00002ojZF`@?oZIS500?oZY_7ojZF`_nZU/80
0on[V<<00on/VlGo[IO0ojjJ`P03ojjJ`P03ok2La?n`VL3o/Yc200;o/Yc20_ncWl@01OndWL3o]J33
okFP`oneX<?o]Z?600?o^:;200?o^:G6ok^U`onjZ<H00_njZ<H02?nmZ<Co_J_8okf[b?nmZlSo_:k<
o`000?nn[/[o_K7>0oo0//d00onn]=7o`KK@okjhe002okjhe0?o_K_G00Co_kgGokbmf_nl_M[o_;gJ
0onj_mh2okNoh0;o^<3Q00?o0000ooooooooool07?ooool000Wooooo00@00000oooooooooooooooo
<000000701TI6@030000000c<c<0<c<c0080<c<c00<0000004a<C01<C4`00`1<C4`00`000000IVIV
06IVIP0306IVIP@0000000<0Ogmo0000001VIVH01`1VIVH00`000000C4a<04a<C00604a<C0800000
4@0c<c<2000001<06ATI9P000004ooooo`0300000?oooooooooo01Cooooo00?o0000ooooooooool0
0_ooool2oiZEcP;oXhno0_nXRkH00onRR[[oZ8J`ojR6/003oj^4Z`;o[8BZ00Co[86Vojf1YOn]PJGo
[H6U0_n]PZH4ojioX@;o[X6T1?n_Oj000on_PjGo/GjMok21XP03ok21XP?o/H2O00Co/8BUok>1WOnc
PIgo/h6M0_nbQ:<4ok>4XP03ok:9Z_nfQJ7o]XFQ00;o/hVY0_ngQj43okF:Z0?o]X^Y1?ngSJX00onc
TK?o^8n/okR?[002ok>B]005okRA[_ncTkKo/i>fok>C]_n^U[h00_nbTkL3o`0000?o[9Bm0onZU/40
0onYV<GoZYBoojZF`P03ojZF`P03oj^H`on[U;oo[IO000;o[IO00_n^V/801?n_Ukko/9W0ok2I`?n`
VL02ok:L`PCo]9g000?o]J33okNO`?nhX/800_nhX/801OnjX/3o^jG3ok^U`onkYL?o^ZS600?o_JS4
0_nmZlP00onn[/[o0000okj^bP03ol2bc@05ol>dc?o1]]3o`KK@ol6fd?nn^=@00_o1^]<01Onm^mOo
_kgGoknmeono_MOo_;gJ00;o_[oK00?o^[oNok_1g_nk`Mh00_nh`>42okW2h@03o`000?oooooooooo
01_ooooo0009ooooo`0400000?oooooooooooooooc00000000?o000001TI6@0I6AT01@0I6AT00`00
0000<c<c03<c<`0203<c<`0300000?l00000C4a<0080C4a<00<0000006IVIP1VIVH01`1VIVH00`00
0000IVIV06IVIP0806IVIP030000001<C4`0C4a<00L0C4a<0P00000A03<c<`030000000I6AT06ATI
01406ATI9@000004ooooo`0300000?oooooooooo01Cooooo00?o0000ooooooooool00oooool00om_
U>KoTi3=oi>@c@03oj::^P?oZ8J`0_n[Q:/00on/Q:[o[86Vojb1YP03ojf1Y@03ojf2Y_n^OZ7o[WnQ
00?o[WnQ00?o[X6Tok1nW_n_Oj000on_Oj000on_PjGo/GjMok5nW@03ok21XP?o/H2O00Ko/8BUok>1
WOncPIgo/h6Mok:4XonfPY`4ok>4XPCo]XFQ00?o/hVYokN7XOngQj400_neRZP2okV9XP;o]X^Y1?ng
SJX3okR?[004ok>B]?nhTJko^96^okRA[P;o/i>f0ol000000onbTkOo[IFnok2B^003ojbD_@;oZYK1
00CoZi:lojZD_onZU;ooZYBo0_nZU/801?n[T[goZiBooj^D_on[U;l2ojfG`004ojjJ`_n_Ukko[iNn
ojnG_P;o/9W000?o/Yc2ok>J__ncV[h00ondWL03okNO`004okRR`_njX/3o^Z;0okZR`0;o^jG31?nm
Z<@01onmZlSo_jc6okn/a_nn[/[o0000ol:`bOo0//d00oo3]<`01?o1]]3o`kW@ol>id?o1^]<2ol>m
e0;o_kgG0_o2`=P00onn_m_o_l;Lok_1gP02ok_1gP?o^L;Q00?o^LCRooooool000007?ooool000Wo
oooo00@00000oooooooooooooooo<P00000701TI6@8000000`0c<c<2000000<0C4a<0P00000C06IV
IP8000002@1<C4`01?l00000000000000000000>03<c<`0400000?l000000000000001006ATI9000
0004ooooo`0300000?oooooooooo01Cooooo00?o0000ooooooooool01?ooool00om_U>KoTi3=oi>@
c@03oj::^P;oZ8J`0_n[Q:/3ojb1YP?o[H6U00?o[H:VojinXOn^Oj400on^Oj400on^PJCo/7jNok1n
WP03ojmoX0?o/GjM0_n`PJ801?ncOY_o/H2Ook60WonaP9l4ok>1W@03ok:4XonfPYco]X:L00?o/hBR
1?nfQJ43okN7X@05okF:Z?niRJ;o^HVRokV9X_nfRjT00_nkS:<3okN=ZP?o^8n/0onhTJh3o`000004
okRB/?nbTkOo/Y>gokJC/P?o/9:h0_n/U;d4oj^B_0;oZYBo00?oZYK2oj^B_On[T[d00on[U;l00on]
Ul3o[IBlojnG_P03ojnG_P03ok2I`?naUkco/iZn00?o/iZn00?o]9g0okJL_OnfW;d00_ngWl04okZR
`003ok^U`onmYL7o_JG100;o_JS400Co`:W3okn/a_no[<Ko_jc60_o2/<T00ol0003oaK;8ol>dc002
ol>dc0?o`kW@0oo3_M@3ol;0f005ol?3fOno`]co_l;Loko2g?nk`Mh00_nl`ml01Oni`^7o^LCRokW4
h_nia>;o000001cooooo0009ooooo`0400000?oooooooooooooooc8000002@0I6AT00`000000<c<c
03<c<`0203<c<`8000000`1<C4`2000001<0IVIV0P00000;04a<C0<000003`0c<c<2000001006ATI
8P000004ooooo`0300000?oooooooooo01Cooooo00?o0000ooooooooool01_ooool01?nCT<goXXZj
oj::^_nRR[X2ojR6/003oj^4ZonXPjco[86V00;o[86V0on]PJD3ojinX@?o[WnQ0on`OYh3ojmoX0?o
/GjM00Co/86Rok=nVoncOY_o/gjK0_naP9l4ok>1W@03ok:4XonfPYco]X:L00;o/hBR00?o^8>LokJ5
XOnfQJ400_nfQJ43okN7X@Co^HVR00?o]X^Yok^<XonkS:<00_ngSJX2okf>Y@;o^8n/0ol000001Onh
TJko^9:`okRB/?nhT[3o/Y>g00;o]Y>b0on`T[P00on/U;go[i:hojnB^003oj^B_003ojZD_on[TK_o
Zi:m00?oZi:m0_n[U;l3ojfD_0?o[iNn0onaUk`2ok>J_P05okFI^onfW;go]YbmokJL_OngWl000_ni
W[d3okZR`0?o_JG100Go_JS4ol2Y`oo0ZL?o`:W3okn/aP02ol>^a@05ol:`bOl0003oaK;8olFbb?o3
]<`00_o6]l`01?o3^M3oa[c@olJld?o3_M@2olG0e@05ol;0f?o3`mWo`l?Iol?3fOno`]`00_o1aMd0
0onl`moo_LGQokg5h@02okW4hP;o^LGS00?o0000ooooooooool06Oooool000Wooooo00@00000oooo
oooooooooooo<`00000801TI6@030000000c<c<0<c<c00@0<c<c00<0000004a<C01<C4`00P1<C4`2
000001<0IVIV00<0000004a<C01<C4`02`1<C4`00`000000<c<c03<c<`0>03<c<`030000000I6AT0
6ATI00h06ATI8@000004ooooo`0300000?oooooooooo01?ooooo00?o0000ooooooooool01oooool2
ocj2i`;oXXZj00CoZ8J`oj66]onXPjcoZ8>/0on/PJH2ojf1Y@04ojeoXon^OZ7o[WjQojinX@?o[WnQ
0on`OYh2ojmoX005ok5nVonaOYgo/GjMok5nWOn`PJ800oncOY/00onaP9oo]H2Jok>1W@03ok>1W@?o
]X:L00Co/hBRokR3W?nhPico^8>L0_nfQJ401?njQYgo]hNQokN7XOngQj44okV9XP?o^hbS00?o]hfZ
okf>YOnmSZD00ol000001?nnTJSo^96^okRA[_nhTJh3okRB/0Co]Y>b0_n`T[P3ojnB^0?oZi:l0on[
TK/3oj^B_@03oj^D_on/T[_o[IBl00?o[IBl00?o[iNnok2E^onaUk`00_naUk`01?ncV[ko]IVkokFI
^oneVK/2okJL_@Co^Ijm00?o^Z;0okfR__nmX[h00_nmYL401?o0Y[oo`:W3ol2Y`oo0ZL<3ol>^a@;o
aK;800?o0000olRfbOo6]l`00_o6]l`3olJld0?oaL3E0oo3`mT2olG6f`04ol75gOo1amoo`LOOokg5
h@;o_LOR0_niaN<00onia^Go0000ooooo`0Jooooo`002Oooool01000003ooooooooooooooold0000
00P06ATI00<0000003<c<`0c<c<0100c<c<00ol00000C4a<04a<C00304a<C0030000001VIVH0IVIV
0140IVIV00Co000000000000000000002P1<C4`4000000d0<c<c00<00000o`00000I6AT03P0I6ATP
000000Cooooo00<00000ooooooooool04oooool00ol0003oooooooooo`08ooooo`03ocj2ion:Rlko
RX_>00;oXHJg0onXPj`2ojb1YP03ojf1YOn]Oj?o[GnS00?o[WjQ0_n^Oj44ok1nWP03ojmoX?naOY_o
/GjK00?o/GjM1?ncOY/00onaP9oo]H2Jok>1W@03ok>1W@?o]X:L00Co/hBRokR3W?nhPico^8>L0_nf
QJ42okZ6W@03okN7XOnmRIko^HVR00?o^HVR0onkS:<01OnmSZGo0000o`000?nmSZGo^8n/00;o_Y6X
0_nhTJh2okjDZ`;o^9:`00Go_IJ_okJC/_nfTk;o]Y>bok2B^002okBC]0?o[i:h00?oZi:lojfA^?n[
TK/00_n[TK/2oj^B_@04ojb@^On/T[_o[9:kojbB^`;o[IBl00Co[Y:iok2E^on`UK_o/9Fk0_naUk`4
okFI^`03okJL_OnhW;_o^9bk00;o^Ijm00Go_9nlokfR__nmX[ko_J:nokfU`@03ol2V_`04ol2Y`oo3
Zl;o`j_2ol>^a@;oa[7500GoaK;8olRfbOl0003ob;K9olJgc002olVkc@04olJld?o9`=;obL3BolG0
e@;oalCG00Co`l?IolG6foo5a]_oa/[M0oo1aml3okg7hP?o^LKU00?oooooo`000?ooool06Oooool0
00Wooooo00@00000oooooooooooooooo=000000801TI6@030000000c<c<0<c<c00@0<c<c00<00000
04a<C01<C4`0101<C4`00`000000IVIV06IVIP0D06IVIP800000301<C4`3000000`0<c<c00<00000
01TI6@0I6AT03@0I6AT00ol0000000000000000L000000Cooooo00<00000ooooooooool04oooool0
0ol0003oooooooooo`09ooooo`03ocj2ion:RlkoXHJg00;oXHJg0_nXPj`2ojb1YPCo[GnS0_n^OZ40
0on^Oj7o/7jNok1nWP03ok1nWPCo/GjK0_naOYd4ok=nV`03ok60WoneP9[o]H2J00;o/h6M00Co^8:J
okJ2W?nfPYco]X:L1?nhPi`01OnfQJ7o^XJMokZ6WOnjQYgo]hNQ00;o_HVN0_niRJ800oo0SIoo^hbS
o`000002o`0000?o_HjU0onnTJP01OnhTJko_YB[okjDZonnU:_o^9:`00;o_IJ_0onfTk83okBC]0;o
[i:h00Co/I:fojfA^?n]TKSo[I6h0_n[TK/4ojb@^@;o[9:k00Co[IBlojjB^On^T[Wo[Y:i0_n`UK/0
0onaUkco/iJjok>F^P03okFI^`?o^9bk00Co^IjmokbO_?nlWkco_9nl0_nmX[h4ol2V_`?o`j_20oo6
/LD3olRfb@04o`000?o9^lgobK_=olVkc@?obL3B00Goc<GDolO4eoo9b=WobLSIolG6f`03olK:g@04
ol77goo1b^7o`L[Qokg7hP;o_LWT00Go^LKUokS7i_nhanKoooooo`00000Iooooo`002Oooool01000
003ooooooooooooooole000000P06ATI00<0000003<c<`0c<c<0100c<c<00`000000C4a<04a<C004
04a<C0030000001VIVH0IVIV01D0IVIV00<0000004a<C01<C4`0301<C4`2000000/0<c<c00<00000
01TI6@0I6AT03@0I6ATN000000Cooooo00<00000ooooooooool04oooool00ol0003oooooooooo`0:
ooooo`;oRX_>0_nQQ[L2ojR3[003ojb1Y_nZPJWo[GnS00?o[GnS0_n^OZ46ok1nWPCo/GjK00?o/GjM
okAoV_ncOY/00oncOY/3okF0VP;o/h6M00Co^8:JokJ2W?nfPYco]X:L1?nhPi`01OnfQJ7o^XJMokZ6
WOnjQYgo]hNQ00;o_HVN00Go^HVRo`000?l0003o0000ok^<X`02ol>AXP?o_HjU0onnTJP4okjDZ`Co
_IJ_00?o]Y>bok^G/_ndTk@00_ndTk@4ok6B]P;o[I6h00?oZi6kojf@^?n]T;P00on/T;T00on/T[_o
[I6hojjB^@03ojjB^@03ok2E^onaU;Wo/iJj00?o/iJj00?o]IVkokNI^OnhW;/00_nhW;/4okbO_003
okfR__o0Y;go`:Bm00;o`:Jo0_o4ZKl2ol>[`P09olN_`_o6/LGoa[75olZeaOo8]/Woc;_:o`000?o<
^l[obK_=00;oc<3?00?obL3Bolc5e?o<aM@00oo9b=T00oo;c=_oa/[MolK:g@02olK=g`04ol7:hOo1
c>?o`LcSokg9i0;o_<_U00Co^<OVokO8iongb>Oo00006Oooool000Wooooo00@00000oooooooooooo
oooo=00000000ol000006ATI01TI6@0701TI6@03o`00000c<c<0<c<c00@0<c<c00<0000004a<C01<
C4`0101<C4`00`000000IVIV06IVIP0E06IVIP<000003@1<C4`00`000000<c<c03<c<`0903<c<`80
00003P0I6ATM000000Cooooo00<00000ooooooooool04oooool00ol0003oooooooooo`0<ooooo`;o
XHJg00CoZ8>/oj25]_nZPJWoZX6Y1?n]Oj<2ojinX@Go/7jN00?o/WjLok5nVonaOY/00_naOY/00ona
OYgo]7nJok=nV`03ok=nV`?o]H2J00Co/h6MokR2V_nhPY[o^8:J0_nfPY`4okR3W0Co^XJM00Co_HVN
o`000?l0003o00000oo0SIl00onkS:?o`i6Rol>AXP02okf>Y@;oaIFU0_nnTJP01?o6VJSo_YB[okjD
ZonnU:/4okfF[`?o^iNb0_ndTk@01_ngU[Go/I:fok6B]_naT[Ko[I6hojnA]`?o[I2h0on/T;T3ojfA
^0;o[Y:i00Co/9:hok6D^OnaU;Wo/IBi0_ncU[X01?neUkSo]iViokNI^OngVKT2okRL^`04ok^M^_nl
Wkco_9nlokbO_0?o`:Bm00Go`:JoolBY_oo4ZKooa:Vool>[`P02olN_`P03olJaaOo:]LGob[G500?o
c;_:00Ko0000olc0coo<`<ooc<3?olo6dOo<aM@2olk:eP03olW8fOo;c=_oblcK00?oa/gO0_o6d>80
1?o1c>?o`<kUol3>iOnlbnD2ok_<i`04okO8ionfb>So]/SXo`0001Sooooo0009ooooo`0400000?oo
ooooooooooooocD000002P0I6AT00`000000<c<c03<c<`0403<c<`03o`00001<C4`0C4a<00@0C4a<
00?o000006IVIP1VIVH05`1VIVH01?l00000000000000000000:04a<C003o`0000000000000000X0
<c<c0P00000=01TI6@0300000?l00000000001T000001?ooool00`00003oooooooooo`0Cooooo`03
o`000?oooooooooo00cooooo0_mjQm@2oj25]P?oZX6Y0on]Oj<00on^OZ7o[gnPok1nWP04ok1nWP03
ok9nW?naOY_o/GjK00;o/GjK00?o/GjMokAoV_ndOiX00_ncOY/01OngPIWo]H2JokF0V_neP9[o/h6M
00?o^8:J00?o]X:Lok^4V_nhPi`00onhPi`2okZ6W@?o00000_nmRIh01OniRJ;o`8fOol2=Woo0SIoo
^hbS00?o`i6R00Co_HjUolFEYOo5UJGo_Y6X0_o6VJP2okjDZ`;oaYb]0_nmUZl01Oo4W[;o^iNbok^G
/_nkUk;o]9>d00;o]iJe0onaT[H3ojnA]`?o[I2h00?o[92iojf@^?n]TKP00_n]TKP00on^T[Wo/9:h
ok2B^003ok6D^@03ok>F^_neUkSo]INh00?o]iVi00Go^9bkok^M^_nkWK[o^ifjokbO_002oknQ^`;o
`:Bm0oo4ZKl01?o7[Kooajo2olN_`_o7[l83olZea@06oljjaoo<^l[ocl7<olo1c?l0003oc<3?0_o?
a]43olk:eP05olo?fOo;c=_obm7Nol_Ag_o6cMl00_o6d>800oo4d^Go`<kUol3>i@02okk?i`07ok_<
ionic>So^LcXokK8j?ndb>Woooooo`00000Gooooo`002Oooool01000003ooooooooooooooole0000
00X06ATI00<0000003<c<`0c<c<0100c<c<00`000000C4a<04a<C00404a<C0030000001VIVH0IVIV
01/0IVIV0P00000;04a<C0030000000c<c<0<c<c00T0<c<c00<0000001TI6@0I6AT02`0I6ATK0000
00Cooooo00<00000ooooooooool04_ooool00ol0003oooooooooo`0>ooooo`03ogZ7e?nPQKKoX8Ff
00?oZX6Y0on]Oj<2ojmoX0Go/7jN00?o/WjLok5nVonaOY/00_naOY/3okAoVP;o/gjK00Co]h6IokF0
V_neP9[o]H2J1?nhPYX00onfPYco^hBJok^4VP02okR3W0?o00000_njQYd3okf9WPCo`8fO1?o3TJ80
1?nmSZGoaIFUolFEYOnnTJP3olJIZ004okjDZoo6W:goaYb]okfF[`?oa9jb0_nkUk84okNF]@03ok6B
]_ndUKOo[i6g00;o[i6g0_n]T;P01?n^T;Oo[I2hojf@^?n]T;P2ojfA^0Co/9:h0_naU;T4okFG^0;o
]iVi1?nkWKX3oknQ^`04ol2T_Oo3Ykgo`jNmolBY_`?oajfo00Coajo2ol^c`oo;/l?ob[G50_o>^/L0
1_oB`LWocl7<olo1c?o?`Lco0000olo6d@;od/cD00Goc/[Folo?fOo?cmWod=GMol_AgP02ol[Dh@03
olK@h_o4d^Goa=;U00?o_/oW00Co_=3YokW<j?nic>So^LcX0ondb>T00ol0003oooooooooo`0Eoooo
o`002Oooool01000003ooooooooooooooold00000003o`00000I6AT06ATI00T06ATI00<0000003<c
<`0c<c<0100c<c<00`000000C4a<04a<C00404a<C0030000001VIVH0IVIV01`0IVIV0P00000:04a<
C08000002P0c<c<00`0000006ATI01TI6@0;01TI6AX000001?ooool00`00003oooooooooo`0Boooo
o`03o`000?oooooooooo00oooooo00?oNXODoj25]_nPQKH00_nZPJT2ojeoX`04ojb2Yon_Oj3o[gnP
ojmoX0?o/7jN0onbOY`3ok5nV`?o]7nJ00?o/gjKokN1VOngPIT00oneP9X4okR2VP03okJ2W?nkQ9[o
000000;o000000Go_XRKokZ6WOnjQYgo^XJMol:<W003okf9WPCo`8fO1?o3TJ83olFEY@CoaYVX0oo6
W:d4olBN/P03ok^G/_noW[Ko_ijf00;o]iJe00Co^YbiokBE]ondUKOo]9Fg0_n_TKL4ojj@]`;o[I2h
00?o[I6hojnA]on_TKL00on`T[P00onaU;Wo/iBgok>D]`03okFG^003okNI^OniV[Wo^IZi00;o^ifj
0_nnWkX2oknQ^`?o`jNm1?o7[Kl3ol^c``?oc[[70_oB`LT00oo?`LcodlO?o`000003om;<e006omCC
f?o?cmWod=GMom3EgOo?fN7ob]CQ0_o9enD01?o4d^Go`]CWol;DionncnL3okc@j@04okW<j?ngc>Wo
]lcYokC8j@;o/lSY00?o0000ooooooooool05?ooool000Wooooo00@00000oooooooooooooooo=@00
000;01TI6@030000000c<c<0<c<c00D0<c<c00<0000004a<C01<C4`0101<C4`00`000000IVIV06IV
IP0:06IVIPCo00003`1VIVH00ol0000000000000000904a<C08000002@0c<c<00`0000006ATI01TI
6@0;01TI6AT000001?ooool00`00003oooooooooo`0Booooo`03o`000?oooooooooo013ooooo0_nP
QKH2ojZ1Z@03ojeoXon/PZOo[8:W00?o[gnP0on`OYh3ok9nW0;o/GjK00Go]H2KokAoV_ndOi[o]7nJ
ok=nV`03okN1V@;o]H2J0onhPYX3o`000003ok^4V_nhPico_XRK00;o_XRK0_njQYd01?o2S9co_HVN
okf9W_nmRIh3ol2=W`03olZFX?o3TJ;o`i6R00;o`i6R0oo5UJD4olJIZ0?oaYb]00Cocj^eolBN/_o4
W[;oa9jb0onoW[H00ongU[Go^YbiokZL^@03okBE]`03ojnA]onaTkSo/I>h00?o[Y2g00?o[I2hojnA
]on_TKL00_n_TKL3ok2B^0?o/iBg0oneUkP3okVJ^@05ok^M^_nnWk[o_YnjokjO^_noXK/00_o3YK/2
ol>W_@06olN[__o7[KooajfoolN]_oo<//7obk?30_o?^/D00oo>^/Ood/79om;1b@02omK9c@04om?7
cooFcm;o0000om;<e0;oe=?H00Koe=WLom3EgOo?fN7ocmWQolgMi?o9enD2olKIj003ol;Dioo0e>Wo
`=CY00;o_=3Y00?o^/oZokO<jOngc>T00_nebnX01?ncb>Wo/LOZok77j_l0000Eooooo`002Oooool0
1000003ooooooooooooooole000000/06ATI00<0000003<c<`0c<c<01@0c<c<00`000000C4a<04a<
C00404a<C0030000001VIVH0IVIV00P0IVIV0_l0000407moO`Ko0000301VIVH2000000T0C4a<0P00
000803<c<`03o`00000000006ATI00/06ATI00?o00000000000000005@000004ooooo`0300000?oo
oooooooo01;ooooo00?o0000ooooooooool04Oooool00omFP^3oZX6Yoin6^003ojb2Y`?o[gnP0_n`
OYh01?nbPIoo/WjLok9nW?nbOY`2ok5nV`05okF0VondOi[o]7nJokAoV_ncOY/00ongPIT00oneP9[o
^X>IokR2VP02o`000005okR2V_nkQ9[o^hBJok^4V_nhPi`00onnR9/01OnjQYgo`XbLol:<W?o2S9co
_HVN00;oaY6N0_o0SIl2olZFX0;o`i6R0_o=W:@00oo5UJGod::Xom2RZ002olJIZ0;odJN^00?oaYb]
oln[]Oo?ZkD00oo4W[83oknN]PCo^Ybi0_ndUKL3ok6C^0?o[Y2g1_n_TKL00on`T[So/Y>gok>D]`03
ok>D]`03okFG^?ngV;So]iRh00;o^IZi1?nnWkX3ol>U^`05ol>W_Oo7Zkkoaj^nolN[__o7[Kl00_o<
//43olnja@03omC2b?oB`LWoe/W=00;oe/W=0ooFcm801_l0003oe=?HomCIg?oDfMcoe=oPoloIh@;o
cMgT00Gob]oXolKIj?o3f^[o`m[Zol3Dj@02okgDj`03ok[?j_ngc^_o]lk[00;o]L_Z00Go/l[[ok77
j_naan[o/<KZo`00000Eooooo`002Oooool01000003ooooooooooooooold000000`06ATI00<00000
03<c<`0c<c<01@0c<c<00`000000C4a<04a<C00504a<C0030000001VIVH0IVIV00H0IVIV00?o0000
07moO`1oOgl02P1oOgl2o`0000`0IVIV0P00000904a<C0030000000c<c<0<c<c00L0<c<c00<00000
01TI6@0I6AT02P0I6ATG000000Cooooo00<00000ooooooooool04_ooool00ol0003oooooooooo`0B
ooooo`;oWhJh1?n/PZL2ojmoX003ok1nW_nbPIoo/X6O00?o/WjL00?o/GjKokF0VoneP9/00ondOiX4
okN1V@?o00000onhPYX3ok^4VP05okR3W?nnR9_o_XRKokj8VonjQYd00oo2S9`01?nmRIkoaY6NolJA
W_o0SIl3olZFX005ol>AX_o=W:CocIbTolfLY?o5UJD00_o@XZP01Oo6VJSodJN^om6W[_oAYjkoaYb]
00?ocj^e00?oa9jbolZ[^oo:Zk/00_noW[H01_o2Z;oo^YbiokZL^OnjW;Wo]9FgokBI^`Co/I>h00?o
[Y2gojnB^On_TKL01?n_TKL01?n`T[So/Y>gok:C]onbTkL2ok>D]`05okJG^?ngV;So]iRhokNH^?ni
V[T00_nlWKT3okjO^P03ol6S^_o3YK_o`jFk00?oaj^n00Koc;70olbb`Oo<//7oc;;1om6j`oo?^/D2
omC2b0?oe/W=0_oId]401OoFcm;of=OFomSGe_l0003oe=WL00;oe=oP00KodNCTolgMi?o:gnSob]oX
olKPjoo3f^X2ol3Ik004okgDjonjdnco^]?/okO>j`;o]Lg/00?o/l[[ok78jonab>/00_n`a^X00on_
aN[o0000ooooo`0Cooooo`002Oooool01000003ooooooooooooooold000000`06ATI00<0000003<c
<`0c<c<01@0c<c<00`000000C4a<04a<C00504a<C0030000001VIVH0IVIV00D0IVIV00?o000007mo
O`1oOgl03@1oOgl4o`0000X0IVIV0P00000804a<C003o`00000c<c<0<c<c00L0<c<c00<0000001TI
6@0I6AT02P0I6ATF000000Cooooo00<00000ooooooooool04_ooool00ol0003oooooooooo`0Boooo
o`;oWhJh1?n/PZL2ojmoX0?o/X6O0onbOY`00onaOY_o]H2KokF0V`03okAoVP05okN1VOl0003o0000
o`000?neP9X00_njPiT2okR2VP04okj7V_nkQ9[o^hBJok^4VPCo_XRK00Go^XJMol:<W?o2S9co`XbL
okf9WP02olJAWP05ol2=Woo:UZ3obYJPolZFX?o3TJ800oo=W:@00oo5UJGod::Xom2RZ004om6W[PCo
cj^e0oo:Zk/00onoW[Ko`ZRool:X_`03okZL^@?o]9Vk0_naTkP01?naU[co[i:iojnB^On_T[T3ojnA
]`;o/9:h0onbTkL01?ncU;Oo]YNhokJG^?nfUkP2okNH^0Co_9fi00Co_Ynjol6S^_o1Xk[o`jFk0_o7
Z[d01Oo7Zkkoc;70olba`?o</L3oc;;100;odK[30ooD`/P01?oIblcoe/W=omWBdOoId]42omcKeP06
omSGe_oIg]_o0000omSUh?oDgn3odNCT0_o>i^P01Oo:gnSoa^3[ol;Ok_o2gnko`=W/00;o_=S^00Co
^]?/okOAkOngdNgo]Lg/0_ncbn`00onab>_o/<O[ok37j`02ojo5jP03o`000?oooooooooo01;ooooo
0009ooooo`0400000?oooooooooooooooc@00000300I6AT00`000000<c<c03<c<`0503<c<`030000
001<C4`0C4a<00D0C4a<00<0000006IVIP1VIVH01@1VIVH00ol00000Ogmo07moO`0@07moO`?o0000
2P1VIVH00`000000C4a<04a<C00504a<C08000002@0c<c<00ol000006ATI01TI6@0901TI6AH00000
1?ooool00`00003oooooooooo`0Booooo`03o`000?oooooooooo01?ooooo0_nOQ[P3ojb2Y`;o[gnP
0onbPIl3ok9nW0?o]H2K00Co]7nJo`000?l0003o00000ongPIT3okZ3V@;o^8:J00Co_XNJok^4V_nk
Q9[o^hBJ1?nnR9/4ol:<W0?oaY6N00Co`8fOolZFX?o:UZ3obYJP1?o=W:@3om2RZ005on2m]?oAYjko
dJN^om6W[_oNa;h00_o?ZkD2omO4a`;obZ^k1?o2Z;l00onjW;Wo^J?2okVS`P02okBI^`03ok6C^?na
U[co/IJl00?o[i:i00?o[i6gok2C^On`T[P00on`T[P2ok:C]`Co]YNh00?o]iRhokZK^OnjVkT00_nl
WKT01?o0X[[o`J>jol6S^_o1XkX3olNZ_@Coc;700ooA^/<01_oF`/Ooe<;8omW;c?oIblcogMG@omWB
d@;og=_F00Kog>CKomWNfooHiN3of>GPo`000?o@k^P2olkVj004olWWk?o4i^oo`]o^ol;OkP;o_]g_
00Co_=S^okSEkonheNoo]m7]0_ndc^d01Oncbnco/LW/ok79k?n`an_o[/G[00?o[L?Z00?o0000oooo
ooooool04Oooool000Wooooo00@00000oooooooooooooooo=000000<01TI6@030000000c<c<0<c<c
00D0<c<c00<0000004a<C01<C4`01@1<C4`00`000000IVIV06IVIP0506IVIP03o`00001oOgl0Ogmo
01<0Ogmo0ol0000806IVIP030000001<C4`0C4a<00H0C4a<00<0000003<c<`0c<c<01P0c<c<00`00
00006ATI01TI6@0:01TI6AD000001?ooool00`00003oooooooooo`0Aooooo`03o`000?oooooooooo
01Cooooo0_nOQ[P3ojb2Y`03ojmoX?n_Q:Oo/X6O00;o/X6O0onbOY`01_neP9_o0000o`000?l0003o
]7nJokV3V`Co]h6I0onjPiT01?nhPY[o_XNJokj7V_nnQiX2ok^4VPCo_XRK1?o2S9`3olJAWPCobYJP
1?o=W:@2om2RZ0;oh;fd0_oAYjh2omk4_P05oln[]OoGa<OoelC7omO4aoo:Zk/00_o;_/h2ol:X_`06
okfcd?niXl;o^J?2okVS`_ndVK_o/Yg21?naU[`2ojnB^@?o/9>i0on`T[P00onbTkOo]9JhokBF^002
okJG^005okRJ^OnjVkWo^Y^iokZK^OnlWKT00oo0X[X2ol6S^P04olJY_?o7Z[goajZmolba_`?oc;70
0_oA^/<2omK2a`06om_=c?oIblcogMG@omgEd?oOh=Kog=_F0_oLi=/02?oJk=ooe_;TomC[i?o@k^So
0000ol[^k?o9incoa>K_0_noho42okkMk`04ok[Jl?nheNoo^=G_okGBk`;o]<k]0_nbc>d00onabNco
[lO/ojo7k002ojk5j`04ojg3j_n/`^[o[<;Zo`0001;ooooo0009ooooo`0400000?oooooooooooooo
oc@00000300I6AT00`000000<c<c03<c<`0503<c<`030000001<C4`0C4a<00@0C4a<00<0000006IV
IP1VIVH01@1VIVH00ol00000Ogmo07moO`0G07moO`03o`00001VIVH0IVIV00H0IVIV00<0000004a<
C01<C4`01P1<C4`00`000000<c<c03<c<`0603<c<`030000000I6AT06ATI00X06ATI50000004oooo
o`0300000?oooooooooo017ooooo00?o0000ooooooooool05_ooool2ojb2Y`03oin<__n_Q:Oo[hBW
00?o/X6O00Co/WjLo`000?l0003o00000_neP9/00ondOi[o^H>KokV3V`04okN1V@?o^X>I00Ko^8:J
okj7V_nnQi[o_XNJok^4V_o3S9/3okj8V`03olRBW?o2S9co`XbL00;o`XbL0oo6TIh01OoCXJ;obYJP
olZFX?o:UZ3ofJZW00;ocIbT0_oN]:d01Oo@XZSoh;fdon2m]?oP_KCodJN^00;og/Bn00?og_GLomO4
aooGa<L00_o=j>T00oo;_/ko^]3Zok[@jP03okfcd003okVS`_nbZ<ko/Yg200;o/Yg20onaU[`00on_
T[Wo[iFlok2C^@03ok2C^@03ok2B^?nbUK[o]9Jh00;o]9Jh00?o]YNhokRJ^OnhV[T00onjVkT4ol2R
^P04ol6S^_o6ZKcoaZVlolNZ_@?oc;6o00?oc;70om6j`ooA^/<00ooF`/L00ooKcLcogmWAomgEd002
omoPeP03omo[f_oLi=_of^cO00;oe_;T00Ood?GXom3^j?o:k^co0000olC]l?nojO;o_n?a00;o^]ob
00Co^][`okKFlOnfe_7o]M;_0_nbcnl2ok;<k@04ok39kOn_anco[lO/ojg5j`?o[LC[00?o[<;Zojc1
jOl000004_ooool000Wooooo00@00000oooooooooooooooo=000000<01TI6@030000000c<c<0<c<c
00D0<c<c00<0000004a<C01<C4`0101<C4`00`000000IVIV06IVIP0506IVIP03o`00001oOgl0Ogmo
01P0Ogmo0_l0000706IVIP8000001`1<C4`00`000000<c<c03<c<`0603<c<`030000000I6AT06ATI
00X06ATI4`000004ooooo`0300000?oooooooooo017ooooo00?o0000ooooooooool05_ooool3oin<
_P?o[hBW0ol00002okJ3W`?o]H2K00Co]7nJokV3VoniPi_o^H>K0_ngPIT01OnmQi_o^X>IokZ3VOnj
PiWo^8:J00?o_XNJ00?o^hBJol><Voo3S9/00_nnR9/01Oo8TYco`XbLol:<W?o2S9cocYVO00?oaY6N
00?odj6RolZFX?o:UZ000_oIZZL01Oo=W:Cog[B]omjd[OoN]:god::X00?oh;fd00?ojoG<omk4__oN
mM`00om:a[000oo=j>WoM=cfogCLmP03ok[@jP03okfcd?nZ]n?o/ZS>00;o/ZS>0onbWL800onaU[co
[YW2ojnE_002ojnE_0;o/9>i00Co/9Jlok:E^_nbUK[o/YFj0_ndU[P4okRJ^@;o^Y^i00Co_Z2kol2R
^_o0X[[oa:Rm0oo6ZK`3olba_`CodK[300OoelC7omK2aooKcLcoflg<omoIdOoQi]Kogn3F00;ogn_J
00Cofo?OomGih_oFl^Cod?GX0_o9mN`00oo2lo3o0000okoYlP02ok[Um004ok[Ol_ngfo;o]m_bokKF
l@;o/m;`00Co//o_ok3<k_n`c>ko/<W]0_n^an`3ojg5j`06ojg4jon/`^[o[<;Zojc1jOn[`>Wo0000
4Oooool000Wooooo00@00000oooooooooooooooo=000000<01TI6@030000000c<c<0<c<c00D0<c<c
00<0000004a<C01<C4`0101<C4`00`000000IVIV06IVIP0506IVIP03o`00001oOgl0Ogmo01X0Ogmo
0_l0000706IVIP030000001<C4`0C4a<00D0C4a<00<0000003<c<`0c<c<01@0c<c<00`0000006ATI
01TI6@0:01TI6A<000001?ooool00`00003oooooooooo`0Aooooo`03o`000?oooooooooo01Oooooo
0_nOS;h3o`0000;o/X6O1?nfPil2okF0V`Co^H>K0_ngPIT01?nmQi_o^X>IokZ3VOnjPiT4okj7VP03
ok^4V_o3S9_o`hbK00;o_XRK0_o8TY`2ol:<W0;ocYVO00?oaY6Nom>QX_oCXJ800_o:UZ02omVZY`04
olfLY?oN]:gog[B]omjd[@?oh;fd00GojoG<oe:HlOm1SNko@Hg^ocf5j@02oc1ki@03oaI_h?l0H/go
6IgR00;o6IgR00CoQLGlojZghonZ]n?oZ[OS0_nbZ<h2ok:M`P04oj^Obon^VL;o[YW2ojjI`P;o[iFl
00?o/9>iok2F_?n`U[`00onbUKX00ondU[So]YZkokJJ^`03okRJ^@04okZK^OnnX;_o_Z2kol2R^P?o
a:Rm0_o6ZK`00oo;/L3oc;6oom6j``03om6j``;oelC700WogM3=om_=c?oOfM7ogmWAon7Ve_oPl]_o
gn_Jom_cgooEnN800_o<nnD01oo3n^WobOG/ol;cl?nlko?o^>[fo`000?njiO@00_nfgo@01?ngfo;o
/mKbok?Fl_ncd_02ok3>k`04ok3<k_n^b>go[/S]ojk7k0;o[LG[0_n/`n/2ojc2jP05oj_1j_n[`>Wo
Zl3Yoj_0jOl000004?ooool000Wooooo00@00000oooooooooooooooo=000000;01TI6@030000000c
<c<0<c<c00H0<c<c00<0000004a<C01<C4`0101<C4`00`000000IVIV06IVIP0406IVIP03o`00001o
Ogl0Ogmo00X0Ogmo1?l0000?07moO`03o`00001VIVH0IVIV00D0IVIV00<0000004a<C01<C4`01@1<
C4`00`000000<c<c03<c<`0503<c<`030000000I6AT06ATI00X06ATI4P000004ooooo`0300000?oo
oooooooo017ooooo00?o0000ooooooooool05_ooool3o`000003oin<__n_Q:Oo[hBW00;o/X6O1?nf
Pil2okF0V`Co^H>K00?o]h6Iokf7VonmQi/00onjPiT4okj7VP?o`hbK00Go_XRKolRBW?o8TYcob9:L
ol:<W003oljIW`05olJAW_oCXJ;odj6Rom>QX_o:UZ000_oIZZL4omjd[@03oo;[_ooP_KCoKJ_f00?o
Fj;e0om1SNh3oc1ki@03obIdh_lAK]oo3X3T00;oDj;f0_nZ]n<00onbZ<koXJOJoj^Ob`03oj^Ob`;o
[YW200?o[iFlojfH`On`U[`00on`U[`2ok:E^P?o]YZk0onhV[T3okjP^`Coa:Rm00?oaZVlol^a`?o;
/L000ooA^/<2omS6b006omO4aooMd<gogM3=on7Od_oOfM7ohNKF0_oPl]/02?oIn]goc_kNol;ngoo<
nnGo`o[Yokchk_ngm?;o]>kf0_nhj_H01?ndi?Ko0000okKOm?ncfO@2ok3DlP;o/M7a00Co/<k_ojo;
k_n_bnko[/S]0_n]a^`00on]aN_o[<?[ojc2jP02ojc2jP03oj_1j_n[`>WoZl3Y00;oZkoY00?o0000
ooooooooool03_ooool000Wooooo00@00000oooooooooooooooo=000000;01TI6@030000000c<c<0
<c<c00H0<c<c00<0000004a<C01<C4`0101<C4`00`000000IVIV06IVIP0406IVIP03o`00001oOgl0
Ogmo00P0Ogmo0_l0000409VIV@Ko00002P1oOgl00ol00000IVIV06IVIP0506IVIP030000001<C4`0
C4a<00D0C4a<00?o000003<c<`0c<c<01@0c<c<00ol000006ATI01TI6@0:01TI6A4000001?ooool0
0`00003oooooooooo`0Aooooo`03o`000?oooooooooo01Cooooo0_l00003ooooo`05oin<__n_Q:Oo
[hBWok:1WondRZT01?nfPil00oneP9_o^hROokV3V`03okV3V`03okN1VOnmQi_o_HNK00;o^X>I00?o
`hfLokj7V_nnQiX00_nnQiX3ol><V`05okj8Voo8TYcob9:LolRBW?o2S9`00oo>VIl01?o6TIkodj6R
om>QX_oCXJ83omVZY`05oo?K]_oN]:gog[B]oo;[_on8]_@00_mk/_H2of^]m`;oEjCf00Go?iScoc:;
kOlbRngo7gkWobEii@02oaebh@05ob9ah?lON>CoDj;foe>Rm_n8[>d00onQYmX3oj^Ob`03ojjI`_nX
VlWo[IS100;o[IS10on`U[`00onbUK[o/iZmok>J_@03okJJ^`03okRJ^OnkWkco^inl00;o_Z2k00Co
`ZNnolBX_Oo4Z;goa:Rm0oo;/L000ooA^lGodK[3omS6b002omS6b00@omgDcooMd<gohMoBon7Od_oR
kMSogOWJon3bfooIn]goc_kNol;ngonho>?o/OWXojkfl?n]lOKo]>kfok7Wn0;o/>3h00?o/]gfojoF
m?l000000_n`e?801On^co7o[lg_ojo=kon_cNoo[l_^00;o[LO]00?o[LK/ojc4jon/a>/00_n/`n/0
1?n/`^[oZl7Zoj_1j_n[`>T3ooooo`03o`000?oooooooooo00kooooo0009ooooo`0400000?oooooo
oooooooooc@000002`0I6AT00`000000<c<c03<c<`0603<c<`030000001<C4`0C4a<00@0C4a<00<0
000006IVIP1VIVH0101VIVH00ol00000Ogmo07moO`0807moO`03o`00002IVIT0VIVI00T0VIVI0_l0
000907moO`03o`00001VIVH0IVIV00@0IVIV00<0000004a<C01<C4`01@1<C4`00`000000<c<c03<c
<`0503<c<`030000000I6AT06ATI00X06ATI4@000004ooooo`0300000?oooooooooo013ooooo00?o
0000ooooooooool04_ooool3o`0000Gooooo00?oXA40ojn4YonOVLd00_ndRZT4okJ3W`03okF0Vonk
R9oo^H>K00?o^H>K00?o]h6Iokf7VonmQi/00_njPiT00oo3SIco_XNJokj7VP02okj7VP?o`hbK00Go
_XRKolRBW?o8TYcob9:Lol:<W003oljIW`Codj6R0_oIZZL3oo?K]P04omjd[OnB^_;oRKSeohVhm@;o
O;Gg0_m/[oT2oeJVn007ocZJlolTRN_o98W[o`YihOl?Ln7o7G;Qoa]_g`02obQdhP03od69jomZV>_o
JYS[00?oXJOJ00?oZio;oijNe?nXVlT00_nXVlT3ojfH`@03ok2F_?n_V/;o/iZm00;o/iZm0_nfV[/0
1OnhWkoo^inlok^O_?nkWkco_Z2k00?o`ZNn00Coa:RmolVa`Oo9/L7obk700_oA^lD3omS6b0;ogMC?
00Soh^GFon7Od_oRkMSoh^gHomgif_oAomWo`?kFoj?geP;oWoCY00?o[_K`ojgam_n]joT00_n]hoT0
1on`h?So[]WfojkIm_n_e_Co0000ojkAl_n^co400_n]b^l2ojg9kP;o[LO]0_n/aN`00on/a>_oZl;[
oj_1jP03oj_1jPGooooo00?o0000ooooooooool03_ooool000Wooooo00@00000oooooooooooooooo
=000000;01TI6@030000000c<c<0<c<c00H0<c<c00<0000004a<C01<C4`0101<C4`00`000000IVIV
06IVIP0406IVIP03o`00001oOgl0Ogmo00L0Ogmo00?o000009VIV@2IVIT0302IVIT2o`0000P0Ogmo
00?o000006IVIP1VIVH0101VIVH00`000000C4a<04a<C00404a<C0030000000c<c<0<c<c00H0<c<c
00<0000001TI6@0I6AT02P0I6AT@000000Cooooo00<00000ooooooooool04?ooool00ol0003ooooo
ooooo`0?ooooo`?o00002Oooool2oinIc@?o]8ZY0onfPil00oneP9_o^hROok^8W`03okV3V`?o_HNK
00?o^X>Iol>=W?o3SI`00onnQiX01?o9U9ko`hbKol><Voo3S9/4olRBW0CocYVO1?oCXJ801_o]bJoo
fJZWoo?K]_ocfkKoVK_`oi:jlP;oU;_b0_n;^_D2ogngn0;oK[;i0_mHZ_T02?ljWOCo6XSYoaZ8jOl0
M=[o06WGo`A[g?lKKmoo:7CR0_lkOND01?mZV>_oRikQoh^NhOn;W^43oijNe0;oZ9_90_n]V<401?nY
VlSo[i[2ojnJ`_n_V/82ok>J_@Co^9no0_nkWk`3ol:W_P04olNaa?o9/L7obK71olVa`@?odK_500?o
f<W;omS6b?oMe<l00_oMe<l02ooRiMKoh?GJon;]f?oMnM[odOoIol3ne_nSmmKoRnkOoiodjOnRl_?o
Y^ci00;oZ>Gk00Co[N?iojcKn?n/foSo[]Wf0_n]d_@01?n^dO;o0000ojc<l?n]b^l2ojc7kP;o[<K]
0_n/aN`01On[`n_oZl;[oj_2jon[`^_oZl7Z00Sooooo00?o0000ooooooooool03Oooool000Wooooo
00@00000oooooooooooooooo=000000;01TI6@030000000c<c<0<c<c00D0<c<c00<0000004a<C01<
C4`01@1<C4`00`000000IVIV06IVIP0406IVIP03o`00001oOgl0Ogmo00H0Ogmo00?o000009VIV@2I
VIT03`2IVIT00ol00000Ogmo07moO`0607moO`03o`00001VIVH0IVIV00@0IVIV00<0000004a<C01<
C4`0101<C4`00`000000<c<c03<c<`0603<c<`030000000I6AT06ATI00T06ATI40000004ooooo`03
00000?oooooooooo013ooooo00?o0000ooooooooool03?ooool3o`0000cooooo00?oXA40oinIcOnd
RZT00_ndRZT3okJ3W`?o^hRO0oniPi/3okf7V`04okZ3VOo3SIco`hfLol>=W0;o_XNJ00CobIBNol><
Voo3S9_o`hbK1?o8TY`4oljIW`?odj6R0_o]bJl00ooIZZOolm^foinmkP02oiZll003oiBkl_nF_?;o
U[cb00;oS[_e0_n3^_P2og>fnP;oGZoj0_m0XoH01olJT>Wo07;Do`1Ob?l0GLko0VOJob5`h?lkOND0
0_mHR^L3oh^Nh@;oWYkD00?oZ9_9oinLdOnYVlP00onYVlP2ojnJ`P03ok>J_OndWl?o]9o300?o^9no
00Co^inloknW`OnoYl7o`ZNn0oo7/L@01?o9/L7od;g8om2mb?oA^lD2omS9b`;ogM[C00_ogMC?on;U
e_oPmM[oh?GJol3nd?nVm/KoQ^S3ohGZcon;k]ooUNo_oig/n002oj?Vn`04ojSUnonYg?WoZMciojcK
n0;o[=Ce00So[M;dojc=lOn/cO7o[<c`o`000?n[b>ko[<O^oj_4k0?oZl?/00?oZl?[ooooooooool0
2oooool00ol0003oooooooooo`0=ooooo`002Oooool01000003ooooooooooooooold000000/06ATI
00<0000003<c<`0c<c<01@0c<c<00`000000C4a<04a<C00504a<C0030000001VIVH0IVIV00@0IVIV
00?o000007moO`1oOgl01@1oOgl00ol00000VIVI09VIV@0A09VIV@03o`00001oOgl0Ogmo00H0Ogmo
00?o000006IVIP1VIVH0101VIVH00`000000C4a<04a<C00404a<C0030000000c<c<0<c<c00H0<c<c
00<0000001TI6@0I6AT02@0I6AT?000000Cooooo00<00000ooooooooool04?ooool00ol0003ooooo
ooooo`09ooooo`?o00004?ooool2oinIc@;o]8ZY0_nfPil01?nkTjgo^hROok^8WonkR9l2okV3V`05
ol6?XOnmQi_o_HNKokf7VonjPiT00oo3SI`2okj7VP;obIBN0_o3S9/3olRBW004omZYY?o>VIoocYVO
oljIW`;oi;RY00Kodj6Rong9[oo]bJookLV_oj:mk?nO_Nh2oj2mk@;oW;g_00?oU[cboiVmlOnI_O40
0_nB_O@2ohRlm`;oN[Wj0_mV]?/3od^[n@06o`1gd_l0FK_o04jho`1GbOl7J=_o<7OS0omHR^L00omf
UN?oSi_KohnKf`03oinLd@?oZI_800?o[i[2ojjObOndWl<00ondWl<00onhWkoo^jO6oknW`@02oknW
`@04olBbbOo7/LCoak74olNaa0?od;g800Coe/g@omS9booMf]?ogM[C0_oPkMX01_oIo=_oh?GJol3n
d?mRdJ[oI]RkohWWm@;oTn_g0_nSg_`2ojKMnP04ojSFn?nZeOKoZ]Gfoj[?l`?oZlkb00Co[<gaoj_8
kon[b>oo00000_n[aNd2oj_4k003oj_3k?oooooooooo00gooooo00?o0000ooooooooool03Oooool0
00Wooooo00@00000oooooooooooooooo=000000;01TI6@030000000c<c<0<c<c00D0<c<c00<00000
04a<C01<C4`01@1<C4`00`000000IVIV06IVIP0406IVIP03o`00001oOgl0Ogmo00D0Ogmo00?o0000
09VIV@2IVIT04P2IVIT00ol00000Ogmo07moO`0507moO`03o`00001VIVH0IVIV00@0IVIV00<00000
04a<C01<C4`01@1<C4`00`000000<c<c03<c<`0503<c<`030000000I6AT06ATI00T06ATI3`000004
ooooo`0300000?oooooooooo013ooooo00?o0000ooooooooool01_ooool3o`0001Cooooo00CoWiW=
okB:ZOndRZWo]X>O0_nkTjd3ok^8W`03okV3Voo1Sj7o`HnQ00?o_HNK1?o3SI`01OnnQi[obIBNolVD
W_o9U9ko`hbK00;odIfQ0_o8TY`2omZYY0;ocYVO0_oT^:T01?oCXJ;okLV_ong9[oo]bJl2oj>mk003
oj2mkOnQ_NgoXKg]00;oW[g_00?oVKgaoi^nl?nF__<00_nF__<3ohfmmP;oP[ci0_ma^O`2oeRbn`;o
=jGc00?o38oPo`12X_l0@jd00_lGL>000om7PnKoI8oVofB?iP02ohnKf`?oWicA00?oZI_8ojBOdOn^
WlT00_n^WlT2okBO``05okFXc?nkYlKo^jO6ok^Wa_noYl400oo4//T01?o7/LCocKo<olfoc?o@_LP2
omK=d008om_PfOoMf]?oh>gJon3]f_oIo=_o`okBoh3Q[Omoho<2oi;So@04oiOTo?nOgOcoWmgloj?N
o0;oY]Kh00CoZ=KhojW?m?nYcoCoZ/oc0_nZb_03oj[9l004oj_8konZaNgoZ/G]o`0001?ooooo00?o
0000ooooooooool03Oooool000Wooooo00@00000oooooooooooooooo=000000;01TI6@030000000c
<c<0<c<c00H0<c<c00<0000004a<C01<C4`0101<C4`00`000000IVIV06IVIP0306IVIP03o`00001o
Ogl0Ogmo00D0Ogmo00?o000009VIV@2IVIT0502IVIT00ol00000Ogmo07moO`0507moO`03o`00001V
IVH0IVIV00@0IVIV00<0000004a<C01<C4`01@1<C4`00ol00000<c<c03<c<`0503<c<`030000000I
6AT06ATI00T06ATI3P000004ooooo`0300000?oooooooooo013ooooo00?o0000ooooooooool00ooo
ool3o`0001Sooooo00?o]8ZYoiJhkonkTjd00_nkTjd3ok^8W`04okV3Voo1Sj7o`HnQol6?X@;o_HNK
1?o3SI`01OnnQi[obIBNolVDW_o9U9ko`hbK00;odIfQ00Gob9:LomZYY?oJZJCofZVToljIW`03onBh
Z@;oc^nA00?okLV_ojFmj_nU_NX00_nT_N`00onQ_NgoXkk/oinnkP02oinnkP;oVkk`00CoU[kcoiVn
l_nI__;oVKkb0_nB__D2ohVnn003og^mnon5_o[oQKoj00;oM[gm0_mP^Od00om1[oKoH`00oaM`h002
obmliP03ofB?i_moV>7oOiSQ00?oUIgI0onTWm42ojjOb@04okBO`oneZ<co]JS<okFXc0;o^jO60oo4
//T01_o9`]?ocKo<olfoc?o=_lcodm7GomK=d0;ofn3I00Kof_CPon3]f_oIo=_o`okBogOOlon=h?d2
oi[Ko@04oicLoOnReO[oX]GjojCFn@;oY/oe0_nWcoD01?nYcoCoZL[aojW:lOnZb_02ojW6kP;oZ/K^
0_nZaNd2ooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool03Oooool000Wooooo00@0
0000oooooooooooooooo=000000;01TI6@030000000c<c<0<c<c00H0<c<c00<0000004a<C01<C4`0
101<C4`00`000000IVIV06IVIP0306IVIP03o`00001oOgl0Ogmo00D0Ogmo00?o000009VIV@2IVIT0
5@2IVIT00ol00000Ogmo07moO`0507moO`03o`00001VIVH0IVIV00@0IVIV00<0000004a<C01<C4`0
101<C4`00`000000<c<c03<c<`0503<c<`030000000I6AT06ATI00T06ATI00<00000o`0000000000
2`000004ooooo`0300000?oooooooooo00oooooo00Co0000oooooooooooooooo0ol0000Mooooo`Co
^i>]0_nkR9l4ol6?X@03okf7Voo9VJCo`hfL00?o`hfL00Go_XNJolVDW_o9U9kobIBNol><V`02om6M
X@05olRBW?oJZJCofZVTomZYY?o>VIl00ooT^:T01Oo>ki7oYkgYojNmjOnU_N[oY[gZ00?oYKg[0_nS
_^`01?nO_^koXKk]oj6nkOnQ_^d2oijnk`03oiVnl_nL_o3oW;o`00;oUkoc00?oT;ogoiK0m?nF`?@0
0_n>`OP2oh?1n`;oL[om0_mL^_`01?l0HM;o;gcVodf;j_m=RnX2ognHh@?oUIgI0_nTWm400on^WlWo
[:SCojbXd`03okFXc004ok^Wa_nn/loo_[??olBbb@?obL;C00GocKo<om?AeooCdMOoe^SRom_Pf@02
om[dh003oj;c`omdf:?oR]kn00;oV=Wm00CoV]_moj7Cn_nQdo[oX]Gj0_nUc_D00onVcoGoYl[bojO:
lP02ojS:l@04ojW:lOnYa^koZLK^ojW6kPSooooo00?o0000ooooooooool03oooool00ol0003ooooo
ooooo`0=ooooo`002Oooool01000003ooooooooooooooold000000/06ATI00<0000003<c<`0c<c<0
1P0c<c<00`000000C4a<04a<C00404a<C0030000001VIVH0IVIV00<0IVIV00?o000007moO`1oOgl0
1@1oOgl00ol00000VIVI09VIV@0F09VIV@03o`00001oOgl0Ogmo00@0Ogmo00?o000006IVIP1VIVH0
101VIVH00`000000C4a<04a<C00404a<C0030000000c<c<0<c<c00D0<c<c00<0000001TI6@0I6AT0
2P0I6AT=000000Cooooo00<00000ooooooooool03oooool4o`00023ooooo00CoU[S_ok^C[OnkTjgo
^i>]0_nkR9l4ol6?X@03okf7Voo9VJCo`hfL00?o`hfL1?o9U9h3om6MX@05olRBW?oJZJCofZVTomZY
Y?oelK000_oT^:T2ojRmj@?oYkgY0_nV_NX01?nU_N_oYKk[ojFnjonU_^/2ojBnk003oj6nkOnS_^co
Xkk/00;oX;k^00?oW;o`oinokonO_nl00_nK_o400onF`?CoV/3boi[0lP02oiG1mP;oSL;i00?oP/;l
ohg3nOn=`oT00_n2a?d00ol4L=koCH_ZoffHjP02offHjP;oR:7T0_nMY]`4ojbXd`03okFXc?nf]=Oo
_[??00;o_[??0oo9`]<2olgGh006om?AeooFj>;oe^SRolckiOoJm>3o00000_nGeod2oio@n@03oioB
nOnTc?GoY<ce00;oY<ge00CoYLkeojO9l_nWbO;oYl[b0_nXa^l2ojW6k`03ojW6k_oooooooooo00So
oooo00?o0000ooooooooool03oooool00ol0003oooooooooo`0=ooooo`002Oooool01000003ooooo
oooooooooole000000X06ATI00<0000003<c<`0c<c<01P0c<c<00`000000C4a<04a<C00404a<C003
0000001VIVH0IVIV00<0IVIV00?o000007moO`1oOgl01@1oOgl00ol00000VIVI09VIV@0F09VIV@03
o`00001oOgl0Ogmo00D0Ogmo00?o000006IVIP1VIVH0101VIVH00`000000C4a<04a<C00404a<C003
0000000c<c<0<c<c00D0<c<c00<0000001TI6@0I6AT02@0I6AT=000000Cooooo00<00000oooooooo
ool03oooool2o`0002?ooooo0onkTjd00onkR9ooaZ>eol6?X@03ol6?X@03okf7Voo9VJCobIVT00?o
`hfL1?o9U9h3om6MX@CofZVT0_oelK001OoT^:WoZ;gXojRmj?nX_NWoYkgY00?oZ;gY0_nW_NX00onU
_^_oY[kZojJnjP02ojFnj`03oj>nk?nT_^coY;k/00;oX[k]00?oWko_oj:ok_nR_nh00_nO_o000onJ
`?;oW/3`oik0l002oi[1l`;oUL;f00?oSL?ioiK3m_nF`oH00_n?aOX00ol0EKco9hCZoffHjP02offH
jP;oR:7T0_nMY]`2ojbXd`05ojRdhOnf]=Oo][CGokJdeonn/ll00_o2a=`00oo9`]?ocMOPolgGh002
ol__k005omKXh_o<nnGoZ?SAoio<monNc_P00_nSbO@2oj?;m0;oY<ce0onVb?42ojO5k`;oZ<G_00?o
Z<K_ooooooooool03Oooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo00cooooo0009
ooooo`0400000?oooooooooooooooc@0000000?o000001TI6@0I6AT02@0I6AT00`000000<c<c03<c
<`0503<c<`030000001<C4`0C4a<00@0C4a<00<0000006IVIP1VIVH0101VIVH00ol00000Ogmo07mo
O`0407moO`03o`00002IVIT0VIVI01L0VIVI00?o000007moO`1oOgl0101oOgl00ol00000IVIV06IV
IP0406IVIP030000001<C4`0C4a<00@0C4a<00<0000003<c<`0c<c<01@0c<c<00`0000006ATI01TI
6@0:01TI6@`000001?ooool00`00003oooooooooo`0Aooooo`03o`000?oooooooooo023ooooo0onk
Tjd00onkR9ooaZ>eolJS]@03ol6?X@?obIVT0_o3SI`00ooDYjSobIBNolVDWP02olVDWP?odIfQ00?o
l]JdomZYY?oJZJ@00_oelK02ojVmj003ojRmj?nY_NSoZ;gY00CoZ;gY0onW_NT00onV_^[oYkkZojNn
jP02ojJnj`03ojBnk?nU_^_oYKk[00;oY;k/00?oX[o^ojBokOnT_nd00_nQ_nh00onN`?3oXL3^oj70
kP02oik1l@03oi_2lonO`O7oWl7a00;oVl;c0onGa?H01Ol0Km;oD9Wboe2Il_m@VO;oMZSb00?oTk3[
0onX]>401?nf]=Oo]LKWokG6ioo2a=`2ol;Lk007olgGh?o;kncobno/ok3jiOmcg[[oWl[foio<m`02
oj?8l`03oj?9m?nUa_3oYLK`00;oYLOa0_nVb?400onWa>koYlG_ojO5k`0Dooooo`03o`000?oooooo
oooo00kooooo00?o0000ooooooooool03?ooool000Wooooo00@00000oooooooooooooooo=@00000;
01TI6@030000000c<c<0<c<c00D0<c<c00<0000004a<C01<C4`0101<C4`00`000000IVIV06IVIP04
06IVIP03o`00001oOgl0Ogmo00@0Ogmo00?o000009VIV@2IVIT05`2IVIT00ol00000Ogmo07moO`05
07moO`03o`00001VIVH0IVIV00@0IVIV00<0000004a<C01<C4`0101<C4`00`000000<c<c03<c<`05
03<c<`030000000I6AT06ATI00T06ATI30000004ooooo`0300000?oooooooooo01;ooooo00?o0000
ooooooooool08Oooool01?lMZlKoaZ>eolJS]Oo6XkD3ol6?X@?obIVT00Co`hfLomBWZ?oDYjSoe:NX
0_o9U9h2on>k[P05om6MXOobe[Col]Jdoo;F]?oJZJ@01onY_NP00onX_NWoZ;gXojRmj002ojRmj@05
ojNmjOnX_NWoZ;gYojNnj_nW_^T00onW_^X00onU_^_oY[kZojFnj`02ojFnj`03ojBokOnU_^coY;o]
00;oY;o]00?oXL3^ojBokOnT_nd00_nR`>l01?nO`O7oX/3^oj;0k_nR`>h2oj32l004oig3lonQ`_3o
XL;`oik3lP;o6hkY00CoD:_ioi>`jomn___oO[kk0onPaO<01?nea^Oo[=giojcMnOo2g>`2ok;am@05
oggWf?l0003oY<GaojC5lOnSa_800_nUa>l2ojG5l003ojG6l?nW`nkoYl?^00?oYlC^6?ooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo00cooooo0009ooooo`0400000?oooooooooooooo
ocD000002`0I6AT00`000000<c<c03<c<`0503<c<`030000001<C4`0C4a<00@0C4a<00<0000006IV
IP1VIVH0101VIVH00ol00000Ogmo07moO`0407moO`03o`00002IVIT0VIVI01L0VIVI00?o000007mo
O`1oOgl01@1oOgl00ol00000IVIV06IVIP0406IVIP030000001<C4`0C4a<00@0C4a<00<0000003<c
<`0c<c<01@0c<c<00ol000006ATI01TI6@0901TI6@`000001?ooool00`00003oooooooooo`0Coooo
o`03o`000?oooooooooo027ooooo00?o7J_6olJS]Oo6XkD00_o1Sj401OoG_l?obIVTolVIY?o9VJCo
`hfL00?oe:NX00GobIBNon>k[_oS^jkohk^^om6MX@02oo;F]0[oZKgX00?oZ;gXojVmj?nY_NP01OnX
_NT2ojNnj@03ojNnj_nW_^WoYkkY00;oY[kZ00?oYKk[ojJnjonV_^/00_nU_^`01OnT_ngoYKo/ojFo
k?nT_ngoYKo/00?oY;o]0_nR`>h01OnT`>goXl7^oj?1k_nS`NkoXL;`00;oY<7^0_nR`^l00onP`o7o
2YCIogjnn`02ogjnn`06oj35lon5e_ooQMKoojcMnOn5i_Co=kbf0_nU`nl2ojC4l004ojC5lOnV`nko
Y/?^ojG4k`CoYl;]00?oYl?^ooooooooool06_ooool00ol0003oooooooooo`0=ooooo`03o`000?oo
oooooooo00cooooo0009ooooo`0400000?ooooooooooooooocH000002`0I6AT00`000000<c<c03<c
<`0503<c<`030000001<C4`0C4a<00@0C4a<00<0000006IVIP1VIVH00`1VIVH00ol00000Ogmo07mo
O`0507moO`03o`00002IVIT0VIVI01L0VIVI00?o000007moO`1oOgl01@1oOgl00ol00000IVIV06IV
IP0406IVIP030000001<C4`0C4a<00@0C4a<00<0000003<c<`0c<c<0100c<c<00`0000006ATI01TI
6@0:01TI6@/000001?ooool00`00003oooooooooo`0Dooooo`;o00008_ooool2olJS]@04ol6?XOoG
_l?oeko3omNo``;obIVT1?oDYjP01_o9U9kohk^^on>k[_oS^jkodIfQoo;F]0ooZKgX0_nX_NP5ojRm
j@03ojNnjOnX_^WoZ;kY00;oYkkZ00?oY[k[ojNnj_nW_^X00_nV_^/00onU_ncoY[k[ojJnj`02ojFo
k004ojBokOnV_ncoY[o/ojJok0;oY<3]00GoXl7^ojG0k?nU`>coY<7^ojK0k003ojG1k@03ojC2k_nV
`>goY/3]00;oYL7^00?oY<;_ojK1kOnV`Nd00_nU`^h00onU`nooY/7]ojK1k@02ojK2k@03ojK3k_nW
`NcoYl7/00?oYl;]7oooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00cooooo0009
ooooo`0400000?ooooooooooooooocH000002`0I6AT00`000000<c<c03<c<`0503<c<`03o`00001<
C4`0C4a<00@0C4a<00?o000006IVIP1VIVH0101VIVH00ol00000Ogmo07moO`0507moO`03o`00002I
VIT0VIVI01H0VIVI00?o000007moO`1oOgl01@1oOgl00ol00000IVIV06IVIP0406IVIP030000001<
C4`0C4a<00@0C4a<00<0000003<c<`0c<c<01@0c<c<00`0000006ATI01TI6@0901TI6@/000001?oo
ool00`00003oooooooooo`0Fooooo`03o`000?oooooooooo02;ooooo0ooG_l<2olVIY005onO`dOoD
YjSoe:NXomBWZ?nHgh`00ooS^jhDojVmj003ojRmjOnY_NSoZKgX00;oZ;gY00?oZ;kYojRmjOnX_NT0
0_nX_^T00onW_^[oZ;kYojRnj@02ojNnjP04ojJnjonW_^[oYkkZojNnjP;oYkk[00?oY[o/ojNnjonW
_^/00_nV_n/00onU`>coY[o[ojJoj`02ojK0k004ojG1kOnV_ncoY[o/ojK0k@;oYko[0_nV`>`00onV
`NgoYko[ojNoj`02ojO0k003ojK1kOnW`>_oYl3[00;oYl3/00?oYl7/ooooooooool08_ooool00ol0
003oooooooooo`0;ooooo`03o`000?oooooooooo00cooooo0009ooooo`0400000?oooooooooooooo
ocH000002`0I6AT00`000000<c<c03<c<`0503<c<`030000001<C4`0C4a<00@0C4a<00<0000006IV
IP1VIVH0101VIVH00ol00000Ogmo07moO`0507moO`03o`00002IVIT0VIVI01H0VIVI00?o000007mo
O`1oOgl01@1oOgl00ol00000IVIV06IVIP0406IVIP030000001<C4`0C4a<00@0C4a<00<0000003<c
<`0c<c<01@0c<c<00`0000006ATI01TI6@0901TI6@/000001?ooool00`00003oooooooooo`0Goooo
o`03o`000?oooooooooo02;ooooo0_oG_l<00oo9VJCoio3AonO`d@03omBWZ0;ooooo00?ohk^^oooo
ooooool06OnY_NP01?nX_NWoZKgXojVmj?nY_NP7ojRnj@03ojNnj_nX_^WoZ;kY00;oYkkZ00?oYkk[
ojRnj_nX_^X00_nW_^X00onV_n_oYkkZojNnjP02ojNoj`05ojJok?nW_n[oYkoZojNojonX_nX01?nW
_n/2ojRojP;oZ;o[00?oYl3[ooooooooool09oooool00ol0003oooooooooo`0:ooooo`03o`000?oo
oooooooo00cooooo0009ooooo`0400000?ooooooooooooooocH00000300I6AT00`000000<c<c03<c
<`0503<c<`030000001<C4`0C4a<00@0C4a<00<0000006IVIP1VIVH0101VIVH00ol00000Ogmo07mo
O`0507moO`03o`00002IVIT0VIVI01D0VIVI00?o000007moO`1oOgl01@1oOgl00ol00000IVIV06IV
IP0406IVIP030000001<C4`0C4a<00@0C4a<00<0000003<c<`0c<c<01@0c<c<00`0000006ATI01TI
6@0901TI6@/000001?ooool00`00003oooooooooo`0Hooooo`03o`000?oooooooooo02Oooooo00?o
e:NXooooooooool01OoooolOojVmj003ojRnjOnY_NSoZKgX00OoZ;kY00?oZ;kZojRnjOnX_^T00_nX
_^T00onW_^[oZ;kYojRnj@02ojRnjP03ojNoj_nX_^WoZ;kY00;oZ;oZ00CoYko[ojRnjOnX_^WoZ;oZ
;Oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00_ooooo0009ooooo`0400000?oo
ooooooooooooocL000002`0I6AT00`000000<c<c03<c<`0503<c<`030000001<C4`0C4a<00@0C4a<
00<0000006IVIP1VIVH0101VIVH00ol00000Ogmo07moO`0507moO`03o`00002IVIT0VIVI01D0VIVI
00?o000007moO`1oOgl01@1oOgl00ol00000IVIV06IVIP0406IVIP030000001<C4`0C4a<00@0C4a<
00<0000003<c<`0c<c<01P0c<c<00`0000006ATI01TI6@0901TI6@X000001?ooool00`00003ooooo
ooooo`0Iooooo`;o0000<?oooolTojVmj003ojRnjOnY_NSoZ;kY00?oZ;kY0_nY_^T3ojRnj@;oZKkY
2?nX_^T`ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool02oooool000Wooooo00@0
0000oooooooooooooooo=`00000;01TI6@030000000c<c<0<c<c00H0<c<c00<0000004a<C01<C4`0
101<C4`00`000000IVIV06IVIP0406IVIP03o`00001oOgl0Ogmo00D0Ogmo00?o000009VIV@2IVIT0
502IVIT00ol00000Ogmo07moO`0507moO`03o`00001VIVH0IVIV00@0IVIV00<0000004a<C01<C4`0
101<C4`00`000000<c<c03<c<`0603<c<`030000000I6AT06ATI00T06ATI2P000004ooooo`030000
0?oooooooooo01_ooooo00?o0000ooooooooool0;_oooolVojVmj005ojRnjOnY_NSoZKgXojVnjOnY
_NP01?nY_^T2ojVnj0;oZKkY00?oZ;kYooooooooool0<oooool00ol0003oooooooooo`09ooooo`03
o`000?oooooooooo00_ooooo0009ooooo`0400000?ooooooooooooooocL000002`0I6AT00`000000
<c<c03<c<`0603<c<`030000001<C4`0C4a<00@0C4a<00<0000006IVIP1VIVH0101VIVH00ol00000
Ogmo07moO`0607moO`03o`00002IVIT0VIVI01<0VIVI00?o000007moO`1oOgl01@1oOgl00ol00000
IVIV06IVIP0406IVIP030000001<C4`0C4a<00@0C4a<00<0000003<c<`0c<c<01P0c<c<00`000000
6ATI01TI6@0901TI6@03o`0000000000000000L000001?ooool00`00003oooooooooo`0Looooo`03
o`000?oooooooooo02kooooo:onY_NP01?nY_^WoZKgXojVmj?nY_^Pjooooo`03o`000?oooooooooo
00Sooooo00?o0000ooooooooool02oooool000Wooooo00@00000oooooooooooooooo=`0000000ol0
00006ATI01TI6@0901TI6@030000000c<c<0<c<c00H0<c<c00<0000004a<C01<C4`0101<C4`00`00
0000IVIV06IVIP0406IVIP03o`00001oOgl0Ogmo00H0Ogmo00?o000009VIV@2IVIT04@2IVIT00ol0
0000Ogmo07moO`0607moO`03o`00001VIVH0IVIV00@0IVIV00<0000004a<C01<C4`01@1<C4`00`00
0000<c<c03<c<`0503<c<`030000000I6AT06ATI00T06ATI2P000004ooooo`0300000?oooooooooo
01gooooo00?o0000ooooooooool0;_ooool/ojVmj3cooooo00?o0000ooooooooool02?ooool00ol0
003oooooooooo`0;ooooo`002Oooool01000003oooooooooooooooli000000/06ATI00<0000003<c
<`0c<c<01@0c<c<00`000000C4a<04a<C00504a<C003o`00001VIVH0IVIV00@0IVIV00?o000007mo
O`1oOgl01P1oOgl3o`0000l0VIVI00?o000007moO`1oOgl01`1oOgl00ol00000IVIV06IVIP0406IV
IP030000001<C4`0C4a<00D0C4a<00<0000003<c<`0c<c<01@0c<c<00`0000006ATI01TI6@0901TI
6@X000001?ooool00`00003oooooooooo`0Nooooo`;o0000;ooooolWojVmj47ooooo00?o0000oooo
ooooool01oooool00ol0003oooooooooo`0;ooooo`002Oooool01000003oooooooooooooooli0000
00/06ATI00<0000003<c<`0c<c<01@0c<c<00`000000C4a<04a<C00504a<C0030000001VIVH0IVIV
00@0IVIV00?o000007moO`1oOgl02@1oOgl00ol00000VIVI09VIV@0;09VIV@;o00002@1oOgl00ol0
0000IVIV06IVIP0406IVIP030000001<C4`0C4a<00D0C4a<00<0000003<c<`0c<c<01@0c<c<00`00
00006ATI01TI6@0901TI6@X000001?ooool00`00003oooooooooo`0Pooooo`03o`000?oooooooooo
02gooooo8_nY_NQ6ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool02_ooool000Wo
oooo00@00000oooooooooooooooo>P00000;01TI6@030000000c<c<0<c<c00D0<c<c00<0000004a<
C01<C4`01@1<C4`00`000000IVIV06IVIP0406IVIP03o`00001oOgl0Ogmo00T0Ogmo0ol0000809VI
V@;o00002P1oOgl00ol00000IVIV06IVIP0506IVIP030000001<C4`0C4a<00D0C4a<00<0000003<c
<`0c<c<01@0c<c<00`0000006ATI01TI6@0901TI6@X000001?ooool00`00003oooooooooo`0Qoooo
o`03o`000?oooooooooo02kooooo7_nY_NQ9ooooo`03o`000?oooooooooo00Kooooo00?o0000oooo
ooooool02_ooool000Wooooo00@00000oooooooooooooooo>P00000;01TI6@030000000c<c<0<c<c
00H0<c<c00<0000004a<C01<C4`0101<C4`00`000000IVIV06IVIP0506IVIP;o0000301oOgl8o`00
00`0Ogmo00?o000006IVIP1VIVH01@1VIVH00`000000C4a<04a<C00404a<C0030000000c<c<0<c<c
00H0<c<c00<0000001TI6@0I6AT02@0I6AT:000000Cooooo00<00000ooooooooool08_ooool00ol0
003oooooooooo`0^oooooaWoZKgXCOooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo
00[ooooo0009ooooo`0400000?ooooooooooooooocX0000000?o000001TI6@0I6AT02@0I6AT00`00
0000<c<c03<c<`0603<c<`030000001<C4`0C4a<00@0C4a<00<00000o`00001VIVH01P1VIVH2o`00
01d0Ogmo00?o000006IVIP1VIVH01P1VIVH00`000000C4a<04a<C00404a<C003o`00000c<c<0<c<c
00H0<c<c00<0000001TI6@0I6AT02@0I6AT:000000Cooooo00<00000ooooooooool08oooool00ol0
003oooooooooo`0^oooooaCoZKgXD_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo
00[ooooo0009ooooo`0400000?oooooooooooooooc`000002`0I6AT00`000000<c<c03<c<`0603<c
<`03o`00001<C4`0C4a<00D0C4a<00<0000006IVIP1VIVH01P1VIVH2o`0001/0Ogmo00?o000006IV
IP1VIVH01P1VIVH00`000000C4a<04a<C00404a<C0030000000c<c<0<c<c00H0<c<c00<0000001TI
6@0I6AT02@0I6AT:000000Cooooo00<00000ooooooooool09?ooool2o`0002oooooo4?nY_NQFoooo
o`03o`000?oooooooooo00Cooooo00?o0000ooooooooool02_ooool000Wooooo00@00000oooooooo
oooooooo?000000<01TI6@030000000c<c<0<c<c00H0<c<c00<0000004a<C01<C4`01@1<C4`00`00
0000IVIV06IVIP0706IVIP03o`00001oOgl0Ogmo01H0Ogmo0_l0000806IVIP030000001<C4`0C4a<
00D0C4a<00<0000003<c<`0c<c<01@0c<c<00`0000006ATI01TI6@0:01TI6@X000001?ooool00`00
003oooooooooo`0Vooooo`03o`000?oooooooooo02gooooo3OnY_NQHooooo`03o`000?oooooooooo
00Cooooo00?o0000ooooooooool02_ooool000Wooooo00@00000oooooooooooooooo?@00000<01TI
6@030000000c<c<0<c<c00H0<c<c00<0000004a<C01<C4`01@1<C4`00`000000IVIV06IVIP0706IV
IP;o0000501oOgl2o`0000T0IVIV00<0000004a<C01<C4`01@1<C4`00`000000<c<c03<c<`0603<c
<`030000000I6AT06ATI00X06ATI2P000004ooooo`0300000?oooooooooo02Oooooo00?o0000oooo
ooooool0;Oooool8ojVmj5gooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0:oooo
o`002Oooool01000003ooooooooooooooolm000000`06ATI00<0000003<c<`0c<c<01`0c<c<00ol0
0000C4a<04a<C00504a<C0030000001VIVH0IVIV00P0IVIV0_l0000@07moO`;o00002`1VIVH00`00
0000C4a<04a<C00504a<C0030000000c<c<0<c<c00H0<c<c00<0000001TI6@0I6AT02P0I6AT:0000
00Cooooo00<00000ooooooooool0:?ooool00ol0003oooooooooo`0]ooooo`?oZKgXH_ooool00ol0
003oooooooooo`03ooooo`03o`000?oooooooooo00Wooooo0009ooooo`0400000?oooooooooooooo
och00000300I6AT00`000000<c<c03<c<`0703<c<`030000001<C4`0C4a<00D0C4a<00<0000006IV
IP1VIVH02@1VIVH3o`0000`0Ogmo00?o000006IVIP1VIVH02P1VIVH00`000000C4a<04a<C00604a<
C0030000000c<c<0<c<c00H0<c<c00<0000001TI6@0I6AT02P0I6AT:000000Cooooo00<00000oooo
ooooool0:Oooool2o`0002gooooo00?o0000ooooooooool0Hoooool00ol0003oooooooooo`02oooo
o`03o`000?oooooooooo00Wooooo0009ooooo`0400000?oooooooooooooooch0000000?o000001TI
6@0I6AT02P0I6AT00`000000<c<c03<c<`0703<c<`030000001<C4`0C4a<00D0C4a<0P00000<06IV
IPco0000301VIVH00`000000C4a<04a<C00604a<C0030000000c<c<0<c<c00H0<c<c00<0000001TI
6@0I6AT02`0I6AT:000000Cooooo00<00000ooooooooool0:oooool00ol0003oooooooooo`0Zoooo
o`03o`000?oooooooooo06?ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`09oooo
o`002Oooool01000003ooooooooooooooolo000000d06ATI00<0000003<c<`0c<c<01`0c<c<00`00
0000C4a<04a<C00604a<C0800000801VIVH2000000T0C4a<00?o000003<c<`0c<c<01P0c<c<00`00
00006ATI01TI6@0;01TI6@X000001?ooool00`00003oooooooooo`0/ooooo`03o`000?oooooooooo
02Wooooo00?o0000ooooooooool0I?ooool01Ol0003ooooooooooooooooo000000_ooooo0009oooo
o`0400000?oooooooooooooood0000003@0I6AT00`000000<c<c03<c<`0603<c<`03o`0000000000
C4a<00P0C4a<0`00000K06IVIP8000002P1<C4`00`000000<c<c03<c<`0703<c<`03o`00000I6AT0
6ATI00/06ATI2P000004ooooo`0300000?oooooooooo02gooooo00?o0000ooooooooool0:?ooool0
0ol0003oooooooooo`1Uooooo`04o`000?ooooooooooo`0000_ooooo0009ooooo`0400000?oooooo
oooooooood4000003@0I6AT00`000000<c<c03<c<`0703<c<`8000002P1<C4`2000001P0IVIV00<0
000004a<C01<C4`02@1<C4`00`000000<c<c03<c<`0803<c<`030000000I6AT06ATI00X06ATI2`00
0004ooooo`0300000?oooooooooo02kooooo0_l0000Xooooo`03o`000?oooooooooo06Kooooo00?o
0000ooooool000002oooool000Wooooo00@00000oooooooooooooooo@@0000000ol000006ATI01TI
6@0;01TI6@03o`0000000000<c<c00P0<c<c0P00000:04a<C0800000501VIVH2000000/0C4a<00<0
000003<c<`0c<c<0200c<c<00`0000006ATI01TI6@0;01TI6@/000001?ooool00`00003ooooooooo
o`0`ooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool0I_ooool00ol0003oooooo`00
000;ooooo`002Oooool01000003ooooooooooooooom3000000h06ATI00<0000003<c<`0c<c<0200c
<c<00`000000C4a<04a<C00904a<C0<000003`1VIVH2000000`0C4a<00<0000003<c<`0c<c<02@0c
<c<00`0000006ATI01TI6@0;01TI6@/000001?ooool00`00003oooooooooo`0aooooo`03o`000?oo
oooooooo02Cooooo00?o0000ooooooooool0Ioooool00ol0003oooooo`00000:ooooo`002Oooool0
1000003ooooooooooooooom3000000l06ATI00<0000003<c<`0c<c<0200c<c<2000000`0C4a<3`00
000=04a<C0030000000c<c<0<c<c00T0<c<c00<0000001TI6@0I6AT0300I6AT;000000Cooooo00<0
0000ooooooooool0<_ooool00ol0003oooooooooo`0Sooooo`03o`000?oooooooooo06Sooooo0_l0
000:ooooo`002Oooool01000003ooooooooooooooom4000000l06ATI00?o000003<c<`0c<c<02@0c
<c<00`000000C4a<04a<C00T04a<C0030000000c<c<0<c<c00X0<c<c00<0000001TI6@0I6AT02`0I
6AT<000000Cooooo00<00000ooooooooool0<oooool2o`0002?ooooo00?o0000ooooooooool0Iooo
ool3o`0000[ooooo0009ooooo`0400000?oooooooooooooood@0000000?o00000000000I6AT03@0I
6AT00`000000<c<c03<c<`0903<c<`0300000?l0000000000280C4a<00?o000003<c<`0c<c<02P0c
<c<00`0000006ATI01TI6@0<01TI6@`000001?ooool00`00003oooooooooo`0eooooo`03o`000?oo
oooooooo023ooooo00?o0000ooooooooool0Hoooool4o`0000gooooo0009ooooo`0400000?oooooo
ooooooooodL000003P0I6AT00`000000<c<c03<c<`0;03<c<`030000001<C4`0C4a<01`0C4a<0`00
000<03<c<`030000000I6AT06ATI00d06ATI30000004ooooo`0300000?oooooooooo03Kooooo00?o
0000ooooooooool07oooool00ol0003oooooooooo`1Pooooo`?o00004Oooool000Wooooo00@00000
ooooooooooooooooB000000>01TI6@<000002`0c<c<3000001P0C4a<0`00000>03<c<`030000000I
6AT06ATI00d06ATI3@000004ooooo`0300000?oooooooooo03Oooooo00?o0000ooooooooool07_oo
ool00ol0003oooooooooo`1Looooo`Co00005?ooool000Wooooo00@00000ooooooooooooooooB000
00000ol000006ATI01TI6@0>01TI6@03o`00000c<c<0<c<c00/0<c<c0P0000000ol00000000004a<
C00B04a<C003o`00000c<c<0<c<c00h0<c<c00<0000001TI6@0I6AT03@0I6AT>000000Cooooo00<0
0000ooooooooool0>?ooool2o`0001kooooo00?o0000ooooooooool0F?ooool4o`0001Sooooo0009
ooooo`0400000?oooooooooooooood/000003`0I6AT2000000l0<c<c1`00000604a<C0H000003`0c
<c<00`00003o000001TI6@0?01TI6@h000001?ooool00`00003oooooooooo`0jooooo`03o`000?oo
oooooooo01_ooooo00?o0000ooooooooool0E?ooool4o`0001cooooo0009ooooo`0400000?oooooo
oooooooood`00000400I6AT00`000000<c<c03<c<`0C03<c<`H00000500c<c<00`0000006ATI01TI
6@0?01TI6@l000001?ooool00`00003oooooooooo`0kooooo`03o`000?oooooooooo01[ooooo00?o
0000ooooooooool0DOooool3o`00023ooooo0009ooooo`0400000?oooooooooooooood`0000000?o
000001TI6@0I6AT03P0I6AT2000002`0<c<c00<0000001TI6@0I6AT0400I6AT?000000Cooooo00<0
0000ooooooooool0??ooool00ol0003oooooooooo`0Iooooo`03o`000?oooooooooo04gooooo1?l0
000Sooooo`002Oooool01000003ooooooooooooooom>000001406ATI1000000V03<c<`0300000?l0
00006ATI01406ATI40000004ooooo`0300000?oooooooooo03gooooo0_l0000Iooooo`03o`000?oo
oooooooo04Wooooo1?l0000Wooooo`002Oooool01000003ooooooooooooooom@000001<06ATI00<0
000003<c<`0c<c<0800c<c<3000001<06ATI00?o00000000000000003P000004ooooo`0300000?oo
oooooooo03oooooo00?o0000ooooooooool05_ooool00ol0003oooooooooo`15ooooo`Co0000:ooo
ool000Wooooo00@00000ooooooooooooooooD00000000ol000006ATI01TI6@0A01TI6@<000007P0c
<c<00`0000006ATI01TI6@0C01TI6A8000001?ooool00`00003oooooooooo`10ooooo`03o`000?oo
oooooooo01Cooooo00?o0000ooooooooool0@oooool3o`0002oooooo0009ooooo`0400000?oooooo
oooooooooe<00000500I6AT01000003o000000000000000F03<c<`@000005@0I6ATC000000Cooooo
00<00000ooooooooool0@Oooool00ol0003oooooooooo`0Cooooo`03o`000?oooooooooo03oooooo
1?l0000booooo`002Oooool01000003ooooooooooooooomE000001H06ATI1`00000903<c<`H00000
600I6ATD000000Cooooo00<00000ooooooooool0@_ooool2o`0001?ooooo00?o0000ooooooooool0
>oooool4o`0003Kooooo0009ooooo`0400000?oooooooooooooooeH00000700I6AT9000001d06ATI
5@000004ooooo`0300000?oooooooooo04Cooooo00?o0000ooooooooool04?ooool00ol0003ooooo
ooooo`0gooooo`Co0000>_ooool000Wooooo00@00000ooooooooooooooooEP0000000ol000006ATI
01TI6@0n01TI6AH000001?ooool00`00003oooooooooo`15ooooo`03o`000?oooooooooo00oooooo
00?o0000ooooooooool0<oooool4o`0003kooooo0009ooooo`0400000?oooooooooooooooeX00000
?00I6ATG000000Cooooo00<00000ooooooooool0A_ooool00ol0003oooooooooo`0>ooooo`03o`00
0?oooooooooo033ooooo0ol00012ooooo`002Oooool01000003ooooooooooooooomL000003P06ATI
00<00000o`00000000005P000004ooooo`0300000?oooooooooo04Oooooo00?o0000ooooooooool0
3Oooool00ol0003oooooooooo`0/ooooo`Co0000AOooool000Wooooo00@00000oooooooooooooooo
G@00000f01TI6AX000001?ooool00`00003oooooooooo`18ooooo`;o00003Oooool00ol0003ooooo
ooooo`0Xooooo`Co0000BOooool000Wooooo00@00000ooooooooooooooooH@00000_01TI6@030000
0?l00000000001X000001?ooool00`00003oooooooooo`1:ooooo`03o`000?oooooooooo00[ooooo
00?o0000ooooooooool09?ooool4o`0004gooooo0009ooooo`0400000?ooooooooooooooof@00000
:`0I6ATN000000Cooooo00<00000ooooooooool0Boooool00ol0003oooooooooo`09ooooo`03o`00
0?oooooooooo027ooooo0ol0001Aooooo`002Oooool01000003ooooooooooooooomW000002H06ATI
80000004ooooo`0300000?oooooooooo04cooooo00?o0000ooooooooool02?ooool00ol0003ooooo
ooooo`0Mooooo`Co0000E?ooool000Wooooo00@00000ooooooooooooooooJ00000000ol000006ATI
01TI6@0O01TI6B<000001?ooool00`00003oooooooooo`1=ooooo`;o00002?ooool00ol0003ooooo
ooooo`0Iooooo`Co0000F?ooool000Wooooo00@00000ooooooooooooooooKP00000H01TI6BL00000
1?ooool00`00003oooooooooo`1?ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0
5Oooool4o`0005cooooo0009ooooo`0400000?ooooooooooooooogT000000P0I6ATb000000Cooooo
00<00000ooooooooool0D?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo01;ooooo
0ol0001Pooooo`002Oooool01000003ooooooooooooooon]000000Cooooo00<00000ooooooooool0
DOooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00kooooo1?l0001Sooooo`002Ooo
ool01000003ooooooooooooooon]000000Cooooo00<00000ooooooooool0D_ooool2o`0000?ooooo
00?o0000ooooooooool02_ooool4o`0006Oooooo0009ooooo`0400000?ooooooooooooooojd00000
1?ooool00`00003oooooooooo`1Dooooo`04o`000?ooooooooooo`0000Sooooo1?l0001[ooooo`00
2Oooool01000003ooooooooooooooon]000000Cooooo00<00000ooooooooool0EOooool00ol0003o
ooooo`000005ooooo`?o0000Koooool000Wooooo00@00000oooooooooooooooo[@000004ooooo`03
00000?oooooooooo05Kooooo0_l000000ooooooo0000o`000002o`0007;ooooo0009ooooo`040000
0?ooooooooooooooojd000001?ooool00`00003oooooooooo`1Gooooo`;o0000M_ooool000Wooooo
00@00000oooooooooooooooo[@000004ooooo`0300000?oooooooooo0<oooooo0009ooooo`040000
0?ooooooooooooooojd000001?ooool00`00003oooooooooo`3?ooooo`002Oooool01000003ooooo
oooooooooon]000000Cooooo00<00000ooooooooool0coooool000Wooooo00@00000oooooooooooo
oooo[@000004ooooo`0300000?oooooooooo0<oooooo0009ooooo`0400000?ooooooooooooooojd0
00001?ooool00`00003oooooooooo`3?ooooo`002Oooool01000003ooooooooooooooon]000000Co
oooo00<00000ooooooooool0coooool000Wooooo00@00000oooooooooooooooo[@000004ooooo`03
00000?oooooooooo0<oooooo0009ooooo`0400000?ooooooooooooooojd000001?ooool00`00003o
ooooooooo`3?ooooo`002Oooool01000003ooooooooooooooon]000000Cooooo00<00000oooooooo
ool0coooool000Wooooo00@00000oooooooooooooooo[@000004ooooo`0300000?oooooooooo0<oo
oooo0009ooooo`0400000?ooooooooooooooojd000001?ooool00`00003oooooooooo`3?ooooo`00
2Oooool01000003ooooooooooooooon]000000Cooooo00<00000ooooooooool0coooool000Wooooo
00@00000oooooooooooooooo[@000004ooooo`0300000?oooooooooo0<oooooo0009ooooo`030000
0?oooooooooo0;;ooooo00<00000ooooooooool0coooool000Wooooo00<00000ooooooooool0/_oo
ool00`00003oooooooooo`3?ooooo`002Oooool00`00003oooooooooo`2booooo`0300000?oooooo
oooo0<oooooo0009oooookH00000dOooool00?ooooooTOooool00?ooooooTOooool00?ooooooTOoo
ool00?ooooooTOooool00?ooooooTOooool00?ooooooTOooool00?ooooooTOooool00?ooooooTOoo
ool00?ooooooTOooool00?ooooooTOooool00?ooooooTOooool00?ooooooTOooool00?ooooooTOoo
ool00?ooooooTOooool00?ooooooTOooool00?ooooooTOooool00?ooooooTOooool000Wooooo]_l0
000AoooookH000002_ooool000Wooooo00?o0000ooooooooool0/_ooool00ol0003oooooooooo`0?
ooooo`0300000?oooooooooo0;;ooooo00<00000ooooooooool02?ooool000Wooooo00?o0000oooo
ooooool0/_ooool00ol0003oooooooooo`0?ooooo`0300000?oooooooooo0;;ooooo00<00000oooo
ooooool02?ooool000Wooooo00?o0000ooooooooool0/_ooool00ol0003oooooooooo`0?ooooo`03
00000?oooooooooo0;;ooooo00<00000ooooooooool02?ooool000Wooooo00?o0000ooooooooool0
/_ooool00ol0003oooooooooo`0?ooooo`0300000?oooooooooo0;;ooooo00<00000ooooooooool0
2?ooool000Wooooo00?o0000ooooooooool0/_ooool00ol0003oooooooooo`0?ooooo`0300000?oo
oooooooo0;;ooooo00<00000ooooooooool02?ooool000Wooooo00?o0000ooooooooool0/_ooool0
0ol0003oooooooooo`0?ooooo`0300000?oooooooooo0;;ooooo00<00000ooooooooool02?ooool0
00Wooooo00?o0000ooooooooool0/_ooool00ol0003oooooooooo`0?ooooo`0300000?oooooooooo
0;;ooooo00<00000ooooooooool02?ooool000Wooooo00?o0000ooooooooool0/_ooool00ol0003o
ooooooooo`0?ooooo`0300000?oooooooooo0;;ooooo00<00000ooooooooool02?ooool000Wooooo
00?o0000ooooooooool0/_ooool00ol0003oooooooooo`0?ooooo`0300000?oooooooooo0;;ooooo
00<00000ooooooooool02?ooool000Wooooo00?o0000ooooooooool0/_ooool00ol0003ooooooooo
o`0?ooooo`0300000?oooooooooo0;;ooooo00<00000ooooooooool02?ooool000Wooooo00?o0000
ooooooooool0/_ooool00ol0003oooooooooo`0?ooooo`0300000?oooooooooo0;;ooooo00<00000
ooooooooool02?ooool000Wooooo00?o0000ooooooooool0/_ooool00ol0003oooooooooo`0?oooo
o`0300000?oooooooooo0;;ooooo00<00000ooooooooool02?ooool000Wooooo00?o0000oooooooo
ool0/_ooool00ol0003oooooooooo`0?ooooo`0300000?oooooooooo0;;ooooo00<00000oooooooo
ool02?ooool000Wooooo00?o0000ooooooooool0/_ooool00ol0003oooooooooo`0?ooooo`030000
0?oooooooooo0;;ooooo00<00000ooooooooool02?ooool000Wooooo00?o0000ooooooooool0/_oo
ool00ol0003oooooooooo`0?ooooo`0300000?oooooooooo0;;ooooo00<00000ooooooooool02?oo
ool000Wooooo00?o0000ooooooooool0/_ooool00ol0003oooooooooo`0?ooooo`0300000?oooooo
oooo0;;ooooo00<00000ooooooooool02?ooool000Wooooo00?o0000ooooooooool0/_ooool00ol0
003oooooooooo`0?ooooo`0300000?oooooooooo0;;ooooo00<00000ooooooooool02?ooool000Wo
oooo00?o0000ooooooooool0/_ooool00ol0003oooooooooo`0?ooooo`0300000?oooooooooo0;;o
oooo00<00000ooooooooool02?ooool000Wooooo00?o0000ooooooooool0/_ooool00ol0003ooooo
ooooo`0?ooooo`0300000?oooooooooo0;;ooooo00<00000ooooooooool02?ooool000Wooooo00?o
0000ooooooooool0/_ooool00ol0003oooooooooo`0?ooooo`0300000?oooooooooo0;;ooooo00<0
0000ooooooooool02?ooool000Wooooo00?o0000ooooooooool0/_ooool00ol0003oooooooooo`0?
ooooo`0300000?oooooooooo0;;ooooo00<00000ooooooooool02?ooool000Wooooo00?o0000oooo
ooooool0/_ooool00ol0003oooooooooo`0?ooooo`0300000?oooooooooo0;;ooooo00<00000oooo
ooooool02?ooool000Wooooo00?o0000ooooooooool00oooool20?mo00_ooooo0P3oO`2Pooooo`03
o`000?oooooooooo00oooooo00<00000ooooooooool00oooool2oomo00_ooooo0_ooO`2Pooooo`03
00000?oooooooooo00Sooooo0009ooooo`03o`000?oooooooooo00;ooooo0`3oO`0;ooooo`80ogl0
3?ooool20?mo09;ooooo00?o0000ooooooooool03oooool00`00003oooooooooo`02ooooo`?oogl0
2oooool2oomo00cooooo0_ooO`2Booooo`0300000?oooooooooo00Sooooo0009ooooo`03o`000?oo
oooooooo00;ooooo0P3oO`0Jooooo`80ogl0T_ooool00ol0003oooooooooo`0?ooooo`0300000?oo
oooooooo00;ooooo0_ooO`0Jooooo`;oogl0T_ooool00`00003oooooooooo`08ooooo`002Oooool0
0ol0003oooooooooo`2booooo`03o`000?oooooooooo00oooooo00<00000ooooooooool0/_ooool0
0`00003oooooooooo`08ooooo`002Oooool00ol0003oooooooooo`0Eooooo`L0003oU_ooool00ol0
003oooooooooo`0?ooooo`0300000?oooooooooo0;;ooooo00<00000ooooooooool02?ooool000Wo
oooo00?o0000ooooooooool04oooool20000o`Oooooo0`000?nCooooo`03o`000?oooooooooo00oo
oooo00<00000ooooooooool0/_ooool00`00003oooooooooo`08ooooo`002Oooool00ol0003ooooo
ooooo`0Booooo`030000oooooooooooo00[ooooo0P000?nAooooo`03o`000?oooooooooo00oooooo
00<00000ooooooooool0/_ooool00`00003oooooooooo`08ooooo`002Oooool00ol0003ooooooooo
o`0Booooo`030000oooooooooooo00cooooo0`000?n>ooooo`03o`000?oooooooooo00oooooo00<0
0000ooooooooool0/_ooool00`00003oooooooooo`08ooooo`002Oooool00ol0003oooooooooo`0B
ooooo`030000oooooooooooo00oooooo0P000?n<ooooo`03o`000?oooooooooo00oooooo00<00000
ooooooooool0/_ooool00`00003oooooooooo`08ooooo`002Oooool00ol0003oooooooooo`0Coooo
o`030000oooooooooooo013ooooo00<0003oooooooooool0ROooool00ol0003oooooooooo`0?oooo
o`0300000?oooooooooo0;;ooooo00<00000ooooooooool02?ooool000Wooooo00?o0000oooooooo
ool04oooool00`000?ooooooooooo`0Aooooo`030000oooooooooooo08Sooooo00?o0000oooooooo
ool03oooool00`00003oooooooooo`2booooo`0300000?oooooooooo00Sooooo0009ooooo`03o`00
0?oooooooooo01?ooooo00<0003oooooooooool00P3oO`05ooooo`80ogl02Oooool20000ohSooooo
00?o0000ooooooooool03oooool00`00003oooooooooo`0Fooooo`;oogl01Oooool2oomo09?ooooo
00<00000ooooooooool02?ooool000Wooooo00?o0000ooooooooool05?ooool010000?oooooo0?mo
003oO`05ooooo`80ogl02oooool00`000?ooooooooooo`25ooooo`03o`000?oooooooooo00oooooo
00<00000ooooooooool05_ooool2oomo00Gooooo0_ooO`2Cooooo`0300000?oooooooooo00Sooooo
0009ooooo`03o`000?oooooooooo01Gooooo00<0003oooooooooool04oooool00`000?oooooooooo
o`24ooooo`03o`000?oooooooooo00oooooo00<00000ooooooooool0/_ooool00`00003ooooooooo
o`08ooooo`002Oooool00ol0003oooooooooo`0Fooooo`030000oooooooooooo01?ooooo00<0003o
ooooooooool0Poooool00ol0003oooooooooo`0?ooooo`0300000?oooooooooo0;;ooooo00<00000
ooooooooool02?ooool000Wooooo00?o0000ooooooooool05_ooool00`000?ooooooooooo`03oooo
o`80ogl01_ooool20?mo00Oooooo00Co003ooooooooooooooooo0P3oO`03ooooo`80ogl0N_ooool0
0ol0003oooooooooo`0?ooooo`0300000?oooooooooo01cooooo0_ooO`06ooooo`;oogl02oooool2
oomo00?ooooo0_ooO`1jooooo`0300000?oooooooooo00Sooooo0009ooooo`03o`000?oooooooooo
01Oooooo00<0003oooooooooool00_ooool20?mo00Kooooo0P3oO`08ooooo`80003o00?ooooo0?mo
003oO`000oooool20?mo07[ooooo00?o0000ooooooooool03oooool00`00003oooooooooo`0Loooo
o`;oogl01_ooool2oomo00_ooooo0_ooO`03ooooo`;oogl0N_ooool00`00003oooooooooo`08oooo
o`002Oooool00ol0003oooooooooo`0Hooooo`030000oooooooooooo01Gooooo0P000?l5ooooo`80
ogl0NOooool00ol0003oooooooooo`0?ooooo`0300000?oooooooooo03Oooooo0_ooO`1iooooo`03
00000?oooooooooo00Sooooo0009ooooo`03o`000?oooooooooo01Wooooo00<0003oooooooooool0
5_ooool00`000?l0ogl00?mo0002ooooo`80ogl0NOooool00ol0003oooooooooo`0?ooooo`030000
0?oooooooooo03?ooooo0_ooO`02ooooo`;oogl0NOooool00`00003oooooooooo`08ooooo`002Ooo
ool00ol0003oooooooooo`0Jooooo`030000oooooooooooo01Kooooo00<0003o0?mo0?ooool0O?oo
ool00ol0003oooooooooo`0?ooooo`0300000?oooooooooo03?ooooo0_ooO`1mooooo`0300000?oo
oooooooo00Sooooo0009ooooo`03o`000?oooooooooo01_ooooo00?o003oooooooooool00oooool2
0?mo017ooooo0P000?mlooooo`03o`000?oooooooooo00oooooo00<00000ooooooooool08Oooool2
oomo08oooooo00<00000ooooooooool02?ooool000Wooooo00?o0000ooooooooool06_ooool20?mo
00030000oooooooooooo00;ooooo0P3oO`06ooooo`?o00002_ooool00`000?ooooooooooo`1ioooo
o`03o`000?oooooooooo00oooooo00<00000ooooooooool06_ooool2oomo00Gooooo0_ooO`2?oooo
o`0300000?oooooooooo00Sooooo0009ooooo`03o`000?oooooooooo01[ooooo0P3oO`000oooool0
003oooooo`09ooooo`Go00001Oooool20?mo00?ooooo00<0003oooooooooool01?ooool20?mo07;o
oooo00?o0000ooooooooool03oooool00`00003oooooooooo`0Jooooo`;oogl05_ooool2oomo00[o
oooo0_ooO`1booooo`0300000?oooooooooo00Sooooo0009ooooo`03o`000?oooooooooo01kooooo
00<0003oooooooooool01oooool5o`0000Gooooo0P3oO`03ooooo`030000oooooooooooo00Cooooo
0P3oO`1booooo`03o`000?oooooooooo00oooooo00<00000ooooooooool0<_ooool2oomo00[ooooo
0_ooO`1booooo`0300000?oooooooooo00Sooooo0009ooooo`03o`000?oooooooooo01oooooo00<0
003oooooooooool01_ooool5o`0000_ooooo00<0003oooooooooool0Moooool00ol0003ooooooooo
o`0?ooooo`0300000?oooooooooo0;;ooooo00<00000ooooooooool02?ooool000Wooooo00?o0000
ooooooooool08?ooool00ol00?l0003oooooo`06ooooo`?o00003Oooool00`000?ooooooooooo`1f
ooooo`03o`000?oooooooooo00oooooo00<00000ooooooooool0/_ooool00`00003oooooooooo`08
ooooo`002Oooool00ol0003oooooooooo`0Rooooo`030000oooooooooooo01Gooooo00<0003ooooo
ooooool0MOooool00ol0003oooooooooo`0?ooooo`0300000?oooooooooo0;;ooooo00<00000oooo
ooooool02?ooool000Wooooo00?o0000ooooooooool08oooool00`000?l0ogl0ooooo`020?mo01?o
oooo00<0003oooooooooool0M?ooool00ol0003oooooooooo`0?ooooo`0300000?oooooooooo02?o
oooo0_ooO`000oooooooogl0oomo002:ooooo`0300000?oooooooooo00Sooooo0009ooooo`03o`00
0?oooooooooo02?ooooo00<0ogl00000o`3oO`000P3oO`0Dooooo`030000oooooooooooo07?ooooo
00?o0000ooooooooool03oooool00`00003oooooooooo`0Sooooo`Googl0R_ooool00`00003ooooo
ooooo`08ooooo`002Oooool00ol0003oooooooooo`0Uooooo`030000o`3oO`3ooooo01?ooooo0P3o
O`000`000?ooooooooooo`1booooo`03o`000?oooooooooo00oooooo00<00000ooooooooool09Ooo
ool2oomo01Cooooo0_ooO`1eooooo`0300000?oooooooooo00Sooooo0009ooooo`03o`000?oooooo
oooo02Kooooo00<0003oooooooooool04_ooool20?mo0003ooooo`000?oooooo07;ooooo00?o0000
ooooooooool03oooool00`00003oooooooooo`0kooooo`;oogl0MOooool00`00003oooooooooo`08
ooooo`002Oooool00ol0003oooooooooo`0Wooooo`030000oooooooooooo01Cooooo00<0003ooooo
ooooool0LOooool00ol0003oooooooooo`0?ooooo`0300000?oooooooooo0;;ooooo00<00000oooo
ooooool02?ooool000Wooooo00?o0000ooooooooool0:?ooool20000oaGooooo00<0003ooooooooo
ool0L?ooool00ol0003oooooooooo`0?ooooo`0300000?oooooooooo0;;ooooo00<00000oooooooo
ool02?ooool000Wooooo00?o0000ooooooooool07_ooool20?mo00[ooooo0P000?lDooooo`030000
oooooooooooo06oooooo00?o0000ooooooooool03oooool00`00003oooooooooo`0Nooooo`;oogl0
T_ooool00`00003oooooooooo`08ooooo`002Oooool00ol0003oooooooooo`0Nooooo`80ogl03?oo
ool00`000?ooooooooooo`0Aooooo`030000oooooooooooo06oooooo00?o0000ooooooooool03ooo
ool00`00003oooooooooo`0Nooooo`;oogl0T_ooool00`00003oooooooooo`08ooooo`002Oooool0
0ol0003oooooooooo`0]ooooo`80003o4_ooool00`000?ooooooooooo`1^ooooo`03o`000?oooooo
oooo00oooooo00<00000ooooooooool0/_ooool00`00003oooooooooo`08ooooo`002Oooool00ol0
003oooooooooo`0_ooooo`80003o4?ooool00`000?ooooooooooo`1^ooooo`03o`000?oooooooooo
00oooooo00<00000ooooooooool0/_ooool00`00003oooooooooo`08ooooo`002Oooool00ol0003o
ooooooooo`0aooooo`030000oooooooooooo00gooooo00<0003oooooooooool0K_ooool00ol0003o
ooooooooo`0?ooooo`0300000?oooooooooo0;;ooooo00<00000ooooooooool02?ooool000Wooooo
00?o0000ooooooooool0<_ooool30000o`gooooo00<0003oooooooooool0KOooool00ol0003ooooo
ooooo`0?ooooo`0300000?oooooooooo0;;ooooo00<00000ooooooooool02?ooool000Wooooo00?o
0000ooooooooool0=Oooool20000o`_ooooo00<0003oooooooooool02Oooool20?mo06;ooooo00?o
0000ooooooooool03oooool00`00003oooooooooo`1>ooooo`;oogl0H_ooool00`00003ooooooooo
o`08ooooo`002Oooool00ol0003oooooooooo`0dooooo`80ogl000?oooooo`00o`000?l02Oooool0
0`000?ooooooooooo`09ooooo`80ogl0H_ooool00ol0003oooooooooo`0?ooooo`0300000?oooooo
oooo03Cooooo0_ooO`0Hooooo`;oogl0H_ooool00`00003oooooooooo`08ooooo`002Oooool00ol0
003oooooooooo`0dooooo`80ogl00oooool20000o`Kooooo00<0003oooooooooool0K_ooool00ol0
003oooooooooo`0?ooooo`0300000?oooooooooo03Cooooo0_ooO`1looooo`0300000?oooooooooo
00Sooooo0009ooooo`03o`000?oooooooooo03_ooooo1P000?maooooo`03o`000?oooooooooo00oo
oooo00<00000ooooooooool0/_ooool00`00003oooooooooo`08ooooo`002Oooool00ol0003ooooo
ooooo`0mooooo`80ogl00_ooool20?mo06oooooo00?o0000ooooooooool03oooool00`00003ooooo
ooooo`0mooooo`;oogl00_ooool2oomo06oooooo00<00000ooooooooool02?ooool000Wooooo00?o
0000ooooooooool0?Oooool20?mo00;ooooo0P3oO`1_ooooo`03o`000?oooooooooo00oooooo00<0
0000ooooooooool0?Oooool2oomo00;ooooo0_ooO`1_ooooo`0300000?oooooooooo00Sooooo0009
ooooo`03o`000?oooooooooo0;;ooooo00?o0000ooooooooool03oooool00`00003oooooooooo`2b
ooooo`0300000?oooooooooo00Sooooo0009ooooo`03o`000?oooooooooo0;;ooooo00?o0000oooo
ooooool03oooool00`00003oooooooooo`2booooo`0300000?oooooooooo00Sooooo0009ooooo`03
o`000?oooooooooo0;;ooooo00?o0000ooooooooool03oooool00`00003oooooooooo`2booooo`03
00000?oooooooooo00Sooooo0009ooooo`03o`000?oooooooooo0;;ooooo00?o0000ooooooooool0
3oooool00`00003oooooooooo`2booooo`0300000?oooooooooo00Sooooo0009ooooo`03o`000?oo
oooooooo0;;ooooo00?o0000ooooooooool03oooool00`00003oooooooooo`2booooo`0300000?oo
oooooooo00Sooooo0009ooooo`03o`000?oooooooooo0;;ooooo00?o0000ooooooooool03oooool0
0`00003oooooooooo`2booooo`0300000?oooooooooo00Sooooo0009ooooo`03o`000?oooooooooo
0;;ooooo00?o0000ooooooooool03oooool00`00003oooooooooo`2booooo`0300000?oooooooooo
00Sooooo0009ooooo`03o`000?oooooooooo0;;ooooo00?o0000ooooooooool03oooool00`00003o
ooooooooo`2booooo`0300000?oooooooooo00Sooooo0009ooooo`03o`000?oooooooooo0;;ooooo
00?o0000ooooooooool03oooool00`00003oooooooooo`2booooo`0300000?oooooooooo00Sooooo
0009ooooo`03o`000?oooooooooo0;;ooooo00?o0000ooooooooool03oooool00`00003ooooooooo
o`2booooo`0300000?oooooooooo00Sooooo0009ooooo`03o`000?oooooooooo0;;ooooo00?o0000
ooooooooool03oooool00`00003oooooooooo`2booooo`0300000?oooooooooo00Sooooo0009oooo
o`03o`000?oooooooooo0;;ooooo00?o0000ooooooooool03oooool00`00003oooooooooo`2boooo
o`0300000?oooooooooo00Sooooo0009ooooo`03o`000?oooooooooo0;;ooooo00?o0000oooooooo
ool03oooool00`00003oooooooooo`2booooo`0300000?oooooooooo00Sooooo0009ooooo`03o`00
0?oooooooooo0;;ooooo00?o0000ooooooooool03oooool00`00003oooooooooo`2booooo`030000
0?oooooooooo00Sooooo0009ooooo`03o`000?oooooooooo0;;ooooo00?o0000ooooooooool03ooo
ool00`00003oooooooooo`2booooo`0300000?oooooooooo00Sooooo0009ooooo`03o`000?oooooo
oooo0;;ooooo00?o0000ooooooooool03oooool00`00003oooooooooo`2booooo`0300000?oooooo
oooo00Sooooo0009ooooo`03o`000?oooooooooo0;;ooooo00?o0000ooooooooool03oooool00`00
003oooooooooo`2booooo`0300000?oooooooooo00Sooooo0009ooooo`03o`000?oooooooooo0;;o
oooo00?o0000ooooooooool03oooool00`00003oooooooooo`2booooo`0300000?oooooooooo00So
oooo0009ooooo`03o`000?oooooooooo06Cooooo1@000?m9ooooo`03o`000?oooooooooo00oooooo
00<00000ooooooooool0/_ooool00`00003oooooooooo`08ooooo`002Oooool00ol0003ooooooooo
o`1Oooooo`D0003o1Oooool50000odCooooo00?o0000ooooooooool03oooool00`00003ooooooooo
o`2booooo`0300000?oooooooooo00Sooooo0009ooooo`03o`000?oooooooooo05_ooooo10000?l?
ooooo`<0003o@Oooool00ol0003oooooooooo`0?ooooo`0300000?oooooooooo0;;ooooo00<00000
ooooooooool02?ooool000Wooooo00?o0000ooooooooool0F_ooool00`000?ooooooooooo`0Doooo
o`<0003o;_ooool20?mo00kooooo00?o0000ooooooooool03oooool00`00003oooooooooo`2Roooo
o`;oogl03_ooool00`00003oooooooooo`08ooooo`002Oooool00ol0003oooooooooo`1Iooooo`03
0000oooooooooooo01Sooooo0P000?l/ooooo`80ogl03_ooool00ol0003oooooooooo`0?ooooo`03
00000?oooooooooo0:;ooooo0_ooO`0>ooooo`0300000?oooooooooo00Sooooo0009ooooo`03o`00
0?oooooooooo05Oooooo00?o003o0000ooooool07?ooool20000oc[ooooo00?o0000ooooooooool0
3oooool00`00003oooooooooo`2booooo`0300000?oooooooooo00Sooooo0009ooooo`03o`000?oo
oooooooo05Kooooo00<0003oooooooooool07oooool20000ocSooooo00?o0000ooooooooool03ooo
ool00`00003oooooooooo`2booooo`0300000?oooooooooo00Sooooo0009ooooo`03o`000?oooooo
oooo05Gooooo00<0003oooooooooool08_ooool20000ocKooooo00?o0000ooooooooool03oooool0
0`00003oooooooooo`2booooo`0300000?oooooooooo00Sooooo0009ooooo`03o`000?oooooooooo
05Cooooo00<0003oooooooooool09Oooool00`000?ooooooooooo`0cooooo`03o`000?oooooooooo
00oooooo00<00000ooooooooool0/_ooool00`00003oooooooooo`08ooooo`002Oooool00ol0003o
ooooooooo`1Cooooo`030000oooooooooooo02Oooooo00<0003oooooooooool0<_ooool00ol0003o
ooooooooo`0?ooooo`0300000?oooooooooo0;;ooooo00<00000ooooooooool02?ooool000Wooooo
00?o0000ooooooooool0Doooool00ol00?ooooooooooo`0Xooooo`030000oooooooooooo037ooooo
00?o0000ooooooooool03oooool00`00003oooooooooo`2booooo`0300000?oooooooooo00Sooooo
0009ooooo`03o`000?oooooooooo05?ooooo00<0003oooooooooool0:Oooool00`000?oooooooooo
o`0`ooooo`03o`000?oooooooooo00oooooo00<00000ooooooooool0/_ooool00`00003ooooooooo
o`08ooooo`002Oooool00ol0003oooooooooo`1Booooo`030000oooooooooooo01cooooo0P3oO`0=
ooooo`030000oooooooooooo02oooooo00?o0000ooooooooool03oooool00`00003oooooooooo`1a
ooooo`;oogl0?oooool00`00003oooooooooo`08ooooo`002Oooool00ol0003oooooooooo`1Boooo
o`030000oooooooooooo01cooooo0P3oO`0>ooooo`030000oooooooooooo02kooooo00?o0000oooo
ooooool03oooool00`00003oooooooooo`1aooooo`;oogl0?oooool00`00003oooooooooo`08oooo
o`002Oooool00ol0003oooooooooo`1Aooooo`030000oooooooooooo02kooooo00<0003ooooooooo
ool03_ooool20?mo01gooooo00?o0000ooooooooool03oooool00`00003oooooooooo`2Cooooo`;o
ogl07Oooool00`00003oooooooooo`08ooooo`002Oooool00ol0003oooooooooo`1Aooooo`030000
oooooooooooo02kooooo00<0003oooooooooool02_ooool20?mo00;ooooo0P3oO`0Mooooo`03o`00
0?oooooooooo00oooooo00<00000ooooooooool0Soooool2oomo00;ooooo0_ooO`0Mooooo`030000
0?oooooooooo00Sooooo0009ooooo`03o`000?oooooooooo057ooooo00<0003oooooooooool09_oo
ool20?mo00Oooooo00<0003oooooooooool02Oooool20?mo027ooooo00?o0000ooooooooool03ooo
ool00`00003oooooooooo`1jooooo`;oogl04oooool2oomo027ooooo00<00000ooooooooool02?oo
ool000Wooooo00?o0000ooooooooool0DOooool00`000?ooooooooooo`0Vooooo`80ogl02?ooool0
0`000?ooooooooooo`0[ooooo`03o`000?oooooooooo00oooooo00<00000ooooooooool0N_ooool2
oomo03Kooooo00<00000ooooooooool02?ooool000Wooooo00?o0000ooooooooool0DOooool00`00
0?ooooooooooo`0Pooooo`80ogl03_ooool00`000?ooooooooooo`05ooooo`80ogl09?ooool00ol0
003oooooooooo`0?ooooo`0300000?oooooooooo07Cooooo0_ooO`0Fooooo`;oogl09?ooool00`00
003oooooooooo`08ooooo`002Oooool00ol0003oooooooooo`1Aooooo`030000oooooooooooo023o
oooo0P3oO`0?ooooo`030000oooooooooooo00Cooooo0P3oO`0Tooooo`03o`000?oooooooooo00oo
oooo00<00000ooooooooool0M?ooool2oomo01Kooooo0_ooO`0Tooooo`0300000?oooooooooo00So
oooo0009ooooo`03o`000?oooooooooo057ooooo00<0003oooooooooool07?ooool20?mo00oooooo
0P3oO`03ooooo`030000oooooooooooo00Oooooo0P3oO`0Pooooo`03o`000?oooooooooo00oooooo
00<00000ooooooooool0L?ooool2oomo00oooooo0_ooO`0=ooooo`;oogl08?ooool00`00003ooooo
ooooo`08ooooo`002Oooool00ol0003oooooooooo`1Aooooo`030000oooooooooooo01cooooo0P3o
O`04ooooo`80ogl02Oooool20?mo00Cooooo00<0003oooooooooool01_ooool20?mo023ooooo00?o
0000ooooooooool03oooool00`00003oooooooooo`1`ooooo`;oogl01?ooool2oomo00Wooooo0_oo
O`0=ooooo`;oogl08?ooool00`00003oooooooooo`08ooooo`002Oooool00ol0003oooooooooo`1A
ooooo`030000oooooooooooo00;ooooo0P3oO`0Hooooo`80ogl01?ooool20?mo00oooooo00<0003o
ooooooooool0:?ooool00ol0003oooooooooo`0?ooooo`0300000?oooooooooo05Kooooo0_ooO`0H
ooooo`;oogl01?ooool2oomo03[ooooo00<00000ooooooooool02?ooool000Wooooo00?o0000oooo
ooooool0DOooool00`000?ooooooooooo`02ooooo`80ogl04oooool3o`0000;ooooo0P3oO`0Eoooo
o`030000oooooooooooo02Sooooo00?o0000ooooooooool03oooool00`00003oooooooooo`1Foooo
o`;oogl06?ooool2oomo043ooooo00<00000ooooooooool02?ooool000Wooooo00?o0000oooooooo
ool0DOooool00`000?ooooooooooo`0Fooooo`Go00006?ooool00`000?ooooooooooo`0Xooooo`03
o`000?oooooooooo00oooooo00<00000ooooooooool0/_ooool00`00003oooooooooo`08ooooo`00
2Oooool00ol0003oooooooooo`1Booooo`030000oooooooooooo00Sooooo0P3oO`09ooooo`80ogl0
1Ol0000Dooooo`80ogl00_ooool00`000?ooooooooooo`0Xooooo`03o`000?oooooooooo00oooooo
00<00000ooooooooool0GOooool2oomo00Wooooo0_ooO`0Iooooo`;oogl0;Oooool00`00003ooooo
ooooo`08ooooo`002Oooool00ol0003oooooooooo`1Booooo`030000oooooooooooo00Sooooo0P3o
O`09ooooo`80ogl01Ol0000Dooooo`80ogl00oooool00`000?ooooooooooo`0Wooooo`03o`000?oo
oooooooo00oooooo00<00000ooooooooool0GOooool2oomo00Wooooo0_ooO`0Iooooo`;oogl0;Ooo
ool00`00003oooooooooo`08ooooo`002Oooool00ol0003oooooooooo`1Cooooo`030000oooooooo
oooo01Gooooo0ol0000Jooooo`030000oooooooooooo02Oooooo00?o0000ooooooooool03oooool0
0`00003oooooooooo`2booooo`0300000?oooooooooo00Sooooo0009ooooo`03o`000?oooooooooo
05?ooooo00?o003oooooooooool0<_ooool00`000?ooooooooooo`08ooooo`80ogl07Oooool00ol0
003oooooooooo`0?ooooo`0300000?oooooooooo09?ooooo0_ooO`0Mooooo`0300000?oooooooooo
00Sooooo0009ooooo`03o`000?oooooooooo05?ooooo00<0003oooooooooool0<?ooool20?mo0003
0000oooooooooooo00Sooooo0P3oO`0Mooooo`03o`000?oooooooooo00oooooo00<00000oooooooo
ool0Q_ooool2oomo00_ooooo0_ooO`0Mooooo`0300000?oooooooooo00Sooooo0009ooooo`03o`00
0?oooooooooo05Cooooo00<0003oooooooooool06oooool20?mo01;ooooo0P3oO`000`000?oooooo
ooooo`0Wooooo`03o`000?oooooooooo00oooooo00<00000ooooooooool0L_ooool2oomo01;ooooo
0_ooO`0Zooooo`0300000?oooooooooo00Sooooo0009ooooo`03o`000?oooooooooo05Gooooo00<0
003oooooooooool06_ooool20?mo01Cooooo00<0003oooooooooool09oooool00ol0003ooooooooo
o`0?ooooo`0300000?oooooooooo07;ooooo0_ooO`0nooooo`0300000?oooooooooo00Sooooo0009
ooooo`03o`000?oooooooooo05Gooooo00<0003oooooooooool04Oooool20?mo00Gooooo0P3oO`0B
ooooo`80ogl00_ooool00`000?ooooooooooo`0Wooooo`03o`000?oooooooooo00oooooo00<00000
ooooooooool0JOooool2oomo00Gooooo0_ooO`0Booooo`;oogl0;?ooool00`00003oooooooooo`08
ooooo`002Oooool00ol0003oooooooooo`1Fooooo`030000oooooooooooo00kooooo103oO`05oooo
o`80ogl03_ooool20?mo00;ooooo0P3oO`02ooooo`030000oooooooooooo02Oooooo00?o0000oooo
ooooool03oooool00`00003oooooooooo`1Wooooo`Coogl01Oooool2oomo00kooooo0_ooO`02oooo
o`;oogl0;?ooool00`00003oooooooooo`08ooooo`002Oooool00ol0003oooooooooo`1Fooooo`03
0000oooooooooooo00kooooo0P3oO`0Gooooo`80ogl01_ooool00`000?ooooooooooo`0Wooooo`03
o`000?oooooooooo00oooooo00<00000ooooooooool0Ioooool2oomo01Oooooo0_ooO`0`ooooo`03
00000?oooooooooo00Sooooo0009ooooo`03o`000?oooooooooo04Wooooo0P3oO`0<ooooo`80003o
;oooool00`000?ooooooooooo`0Wooooo`03o`000?oooooooooo00oooooo00<00000ooooooooool0
BOooool2oomo06Oooooo00<00000ooooooooool02?ooool000Wooooo00?o0000ooooooooool0BOoo
ool20?mo00Oooooo0P3oO`05ooooo`030000oooooooooooo01;ooooo0P3oO`0Gooooo`030000oooo
oooooooo02Sooooo00?o0000ooooooooool03oooool00`00003oooooooooo`19ooooo`;oogl01ooo
ool2oomo01[ooooo0_ooO`12ooooo`0300000?oooooooooo00Sooooo0009ooooo`03o`000?oooooo
oooo05;ooooo0P3oO`06ooooo`030000oooooooooooo017ooooo0P3oO`0Gooooo`030000oooooooo
oooo02Sooooo00?o0000ooooooooool03oooool00`00003oooooooooo`1Booooo`;oogl06_ooool2
oomo04;ooooo00<00000ooooooooool02?ooool000Wooooo00?o0000ooooooooool0F_ooool00`00
0?ooooooooooo`0<ooooo`80ogl07?ooool00`000?ooooooooooo`0Xooooo`03o`000?oooooooooo
00oooooo00<00000ooooooooool0JOooool2oomo04Oooooo00<00000ooooooooool02?ooool000Wo
oooo00?o0000ooooooooool0Foooool00`000?ooooooooooo`0;ooooo`80ogl07?ooool00`000?oo
ooooooooo`0Xooooo`03o`000?oooooooooo00oooooo00<00000ooooooooool0JOooool2oomo04Oo
oooo00<00000ooooooooool02?ooool000Wooooo00?o0000ooooooooool0G?ooool20000obSooooo
00<0003oooooooooool0:Oooool00ol0003oooooooooo`0?ooooo`0300000?oooooooooo0;;ooooo
00<00000ooooooooool02?ooool000Wooooo00?o0000ooooooooool0G_ooool20000obGooooo00<0
003oooooooooool0:_ooool00ol0003oooooooooo`0?ooooo`0300000?oooooooooo0;;ooooo00<0
0000ooooooooool02?ooool000Wooooo00?o0000ooooooooool0H?ooool00`000?ooooooooooo`0Q
ooooo`030000oooooooooooo02_ooooo00?o0000ooooooooool03oooool00`00003oooooooooo`2b
ooooo`0300000?oooooooooo00Sooooo0009ooooo`03o`000?oooooooooo05;ooooo0P3oO`0=oooo
o`03o`00o`000?oooooo01oooooo00<0003oooooooooool0;?ooool00ol0003oooooooooo`0?oooo
o`0300000?oooooooooo05;ooooo0_ooO`1Nooooo`0300000?oooooooooo00Sooooo0009ooooo`03
o`000?oooooooooo05;ooooo0P3oO`0?ooooo`<0003o6oooool20000oboooooo00?o0000oooooooo
ool03oooool00`00003oooooooooo`1Booooo`;oogl0G_ooool00`00003oooooooooo`08ooooo`00
2Oooool00ol0003oooooooooo`1Vooooo`80003o1oooool20?mo00kooooo0P000?laooooo`03o`00
0?oooooooooo00oooooo00<00000ooooooooool0Koooool2oomo047ooooo00<00000ooooooooool0
2?ooool000Wooooo00?o0000ooooooooool0J?ooool00`000?ooooooooooo`04ooooo`80ogl03Ooo
ool00`000?ooooooooooo`0aooooo`03o`000?oooooooooo00oooooo00<00000ooooooooool0Kooo
ool2oomo047ooooo00<00000ooooooooool02?ooool000Wooooo00?o0000ooooooooool0JOooool0
0`000?oo003o0000o`020000o`gooooo0`000?ldooooo`03o`000?oooooooooo00oooooo00<00000
ooooooooool0/_ooool00`00003oooooooooo`08ooooo`002Oooool00ol0003oooooooooo`1^oooo
o`D0003o0oooool50000ocOooooo00?o0000ooooooooool03oooool00`00003oooooooooo`2boooo
o`0300000?oooooooooo00Sooooo0009ooooo`03o`000?oooooooooo04gooooo0P3oO`0Tooooo`<0
003o??ooool00ol0003oooooooooo`0?ooooo`0300000?oooooooooo04gooooo0_ooO`1Sooooo`03
00000?oooooooooo00Sooooo0009ooooo`03o`000?oooooooooo04gooooo0P3oO`0Dooooo`80ogl0
COooool00ol0003oooooooooo`0?ooooo`0300000?oooooooooo04gooooo0_ooO`0Dooooo`;oogl0
COooool00`00003oooooooooo`08ooooo`002Oooool00ol0003oooooooooo`1Sooooo`80ogl0COoo
ool00ol0003oooooooooo`0?ooooo`0300000?oooooooooo06?ooooo0_ooO`1=ooooo`0300000?oo
oooooooo00Sooooo0009ooooo`03o`000?oooooooooo05Wooooo0P3oO`1Gooooo`03o`000?oooooo
oooo00oooooo00<00000ooooooooool0FOooool2oomo05Oooooo00<00000ooooooooool02?ooool0
00Wooooo00?o0000ooooooooool0FOooool20?mo05Oooooo00?o0000ooooooooool03oooool00`00
003oooooooooo`1Iooooo`;oogl0Eoooool00`00003oooooooooo`08ooooo`002Oooool00ol0003o
ooooooooo`1aooooo`80ogl0?oooool00ol0003oooooooooo`0?ooooo`0300000?oooooooooo077o
oooo0_ooO`0oooooo`0300000?oooooooooo00Sooooo0009ooooo`03o`000?oooooooooo077ooooo
0P3oO`0oooooo`03o`000?oooooooooo00oooooo00<00000ooooooooool0LOooool2oomo03oooooo
00<00000ooooooooool02?ooool000Wooooo00?o0000ooooooooool0/_ooool00ol0003ooooooooo
o`0?ooooo`0300000?oooooooooo0;;ooooo00<00000ooooooooool02?ooool000Wooooo00?o0000
ooooooooool0/_ooool00ol0003oooooooooo`0?ooooo`0300000?oooooooooo0;;ooooo00<00000
ooooooooool02?ooool000Wooooo00?o0000ooooooooool0/_ooool00ol0003oooooooooo`0?oooo
o`0300000?oooooooooo0;;ooooo00<00000ooooooooool02?ooool000Wooooo00?o0000oooooooo
ool0/_ooool00ol0003oooooooooo`0?ooooo`0300000?oooooooooo0;;ooooo00<00000oooooooo
ool02?ooool000Wooooo00?o0000ooooooooool0/_ooool00ol0003oooooooooo`0?ooooo`030000
0?oooooooooo0;;ooooo00<00000ooooooooool02?ooool000Wooooo00?o0000ooooooooool0/_oo
ool00ol0003oooooooooo`0?ooooo`0300000?oooooooooo0;;ooooo00<00000ooooooooool02?oo
ool000Wooooo00?o0000ooooooooool0/_ooool00ol0003oooooooooo`0?ooooo`0300000?oooooo
oooo0;;ooooo00<00000ooooooooool02?ooool000Wooooo00?o0000ooooooooool0/_ooool00ol0
003oooooooooo`0?ooooo`0300000?oooooooooo0;;ooooo00<00000ooooooooool02?ooool000Wo
oooo00?o0000ooooooooool0/_ooool00ol0003oooooooooo`0?ooooo`0300000?oooooooooo0;;o
oooo00<00000ooooooooool02?ooool000Wooooo00?o0000ooooooooool0/_ooool00ol0003ooooo
ooooo`0?ooooo`0300000?oooooooooo0;;ooooo00<00000ooooooooool02?ooool000Wooooo00?o
0000ooooooooool0/_ooool00ol0003oooooooooo`0?ooooo`0300000?oooooooooo0;;ooooo00<0
0000ooooooooool02?ooool000Wooooo00?o0000ooooooooool0/_ooool00ol0003oooooooooo`0?
ooooo`0300000?oooooooooo0;;ooooo00<00000ooooooooool02?ooool000Wooooo00?o0000oooo
ooooool0/_ooool00ol0003oooooooooo`0?ooooo`0300000?oooooooooo0;;ooooo00<00000oooo
ooooool02?ooool000Wooooo00?o0000ooooooooool0/_ooool00ol0003oooooooooo`0?ooooo`03
00000?oooooooooo0;;ooooo00<00000ooooooooool02?ooool000Wooooo00?o0000ooooooooool0
/_ooool00ol0003oooooooooo`0?ooooo`0300000?oooooooooo0;;ooooo00<00000ooooooooool0
2?ooool000Wooooo00?o0000ooooooooool0/_ooool00ol0003oooooooooo`0?ooooo`0300000?oo
oooooooo0;;ooooo00<00000ooooooooool02?ooool000Wooooo00?o0000ooooooooool0/_ooool0
0ol0003oooooooooo`0?ooooo`0300000?oooooooooo0;;ooooo00<00000ooooooooool02?ooool0
00Wooooo00?o0000ooooooooool0/_ooool00ol0003oooooooooo`0?ooooo`0300000?oooooooooo
0;;ooooo00<00000ooooooooool02?ooool000Wooooo00?o0000ooooooooool0/_ooool00ol0003o
ooooooooo`0?ooooo`0300000?oooooooooo0;;ooooo00<00000ooooooooool02?ooool000Wooooo
00?o0000ooooooooool0/_ooool00ol0003oooooooooo`0?ooooo`0300000?oooooooooo0;;ooooo
00<00000ooooooooool02?ooool000Wooooo00?o0000ooooooooool0/_ooool00ol0003ooooooooo
o`0?ooooo`0300000?oooooooooo0;;ooooo00<00000ooooooooool02?ooool000Wooooo00?o0000
ooooooooool0/_ooool00ol0003oooooooooo`0?ooooo`0300000?oooooooooo0;;ooooo00<00000
ooooooooool02?ooool000Wooooo00?o0000ooooooooool0/_ooool00ol0003oooooooooo`0?oooo
o`0300000?oooooooooo0;;ooooo00<00000ooooooooool02?ooool000Wooooo00?o0000oooooooo
ool0/_ooool00ol0003oooooooooo`0?ooooo`0300000?oooooooooo0;;ooooo00<00000oooooooo
ool02?ooool000Wooooo00?o0000ooooooooool0F?ooool20?mo05Sooooo00?o0000ooooooooool0
3oooool00`00003oooooooooo`1Hooooo`;oogl0F?ooool00`00003oooooooooo`08ooooo`002Ooo
ool00ol0003oooooooooo`1Hooooo`80ogl0F?ooool00ol0003oooooooooo`0?ooooo`0300000?oo
oooooooo05Sooooo0_ooO`1Hooooo`0300000?oooooooooo00Sooooo0009ooooo`03o`000?oooooo
oooo0;;ooooo00?o0000ooooooooool03oooool00`00003oooooooooo`2booooo`0300000?oooooo
oooo00Sooooo0009ooooo`03o`000?oooooooooo0;;ooooo00?o0000ooooooooool03oooool00`00
003oooooooooo`2booooo`0300000?oooooooooo00Sooooo0009ooooo`03o`000?oooooooooo0;;o
oooo00?o0000ooooooooool03oooool00`00003oooooooooo`2booooo`0300000?oooooooooo00So
oooo0009ooooo`03o`000?oooooooooo0;;ooooo00?o0000ooooooooool03oooool00`00003ooooo
ooooo`2booooo`0300000?oooooooooo00Sooooo0009ooooo`03o`000?oooooooooo0;;ooooo00?o
0000ooooooooool03oooool00`00003oooooooooo`2booooo`0300000?oooooooooo00Sooooo0009
ooooo`03o`000?oooooooooo0;;ooooo00?o0000ooooooooool03oooool00`00003oooooooooo`2b
ooooo`0300000?oooooooooo00Sooooo0009ooooo`03o`000?oooooooooo0;;ooooo00?o0000oooo
ooooool03oooool00`00003oooooooooo`2booooo`0300000?oooooooooo00Sooooo0009ooooo`03
o`000?oooooooooo0;;ooooo00?o0000ooooooooool03oooool00`00003oooooooooo`2booooo`03
00000?oooooooooo00Sooooo0009ooooo`03o`000?oooooooooo0;;ooooo00?o0000ooooooooool0
3oooool00`00003oooooooooo`2booooo`0300000?oooooooooo00Sooooo0009ooooo`03o`000?oo
oooooooo0;;ooooo00?o0000ooooooooool03oooool00`00003oooooooooo`2booooo`0300000?oo
oooooooo00Sooooo0009ooooo`03o`000?oooooooooo0;;ooooo00?o0000ooooooooool03oooool0
0`00003oooooooooo`2booooo`0300000?oooooooooo00Sooooo0009ooooo`03o`000?oooooooooo
0;;ooooo00?o0000ooooooooool03oooool00`00003oooooooooo`2booooo`0300000?oooooooooo
00Sooooo0009ooooo`03o`000?oooooooooo0;;ooooo00?o0000ooooooooool03oooool00`00003o
ooooooooo`2booooo`0300000?oooooooooo00Sooooo0009oooookKo00004Ooooonf000000[ooooo
003ooooooi7ooooo003ooooooi7ooooo003ooooooi7ooooo003ooooooi7ooooo003ooooooi7ooooo
003ooooooi7ooooo003ooooooi7ooooo003ooooooi7ooooo003ooooooi7ooooo0000\
\>"],
  ImageRangeCache->{{{0, 399}, {399, 0}} -> {-0.0500105, -0.0500105, \
0.00526322, 0.00526322}, {{9.5, 190.438}, {389.5, 208.5}} -> {-1.15081, \
-1.15117, 0.0115117, 0.0115117}, {{208.5, 389.438}, {389.5, 208.5}} -> \
{-1.09771, -0.0754011, 0.0052648, 0.0052648}, {{9.5, 190.438}, {190.438, \
9.5}} -> {-1.11761, -3.34306, 0.0111796, 0.0111796}, {{208.5, 389.438}, \
{190.438, 9.5}} -> {-3.34236, -3.34306, 0.0111796, 0.0111796}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
%%ImageSize: 400 400 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.47619 0.0238095 0.47619 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.0238095 0.477324 0.477324 MathSubStart
%% ContourGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.480769 0.5 0.480769 [
[ 0 0 -0.125 0 ]
[ 0 0 -0.125 0 ]
[ 0 1 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
0 0 m
1 0 L
s
0 0 m
0 1 L
s
0 1 m
1 1 L
s
1 0 m
1 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
.01923 .98077 m
.98077 .98077 L
.98077 .01923 L
.01923 .01923 L
F
.5 Mabswid
.1 g
.01923 .15774 m
.02687 .17308 L
.03846 .19095 L
.03953 .19231 L
.0549 .21154 L
.05769 .21499 L
.07255 .23077 L
.07692 .23526 L
.09234 .25 L
.09615 .25331 L
.11415 .26923 L
.11538 .27009 L
.13462 .28531 L
.13858 .28846 L
.15385 .29872 L
.16571 .30769 L
.17308 .3115 L
.19231 .32497 L
.19517 .32692 L
.21154 .33521 L
.22846 .34615 L
.23077 .34678 L
.25 .3561 L
.2664 .36538 L
.26923 .36603 L
.28846 .37376 L
.30769 .38277 L
.31197 .38462 L
.32692 .38855 L
.34615 .39499 L
.36538 .40073 L
.37798 .40385 L
.38462 .40466 L
.40385 .40694 L
.42308 .40781 L
.44231 .40619 L
.45311 .40385 L
.46154 .4001 L
.47705 .38462 L
.48077 .37291 L
.48133 .36538 L
.48077 .3584 L
.47803 .34615 L
.46986 .32692 L
.46154 .31153 L
.45868 .30769 L
.44431 .28846 L
.44231 .28581 L
.42736 .26923 L
.42308 .26458 L
.40826 .25 L
.40385 .24595 L
.38707 .23077 L
.38462 .2289 L
.36538 .21291 L
.36368 .21154 L
.34615 .19911 L
.3373 .19231 L
.32692 .18631 L
.30879 .17308 L
.30769 .17269 L
.28846 .16168 L
.27658 .15385 L
.26923 .15115 L
.25 .14018 L
.24043 .13462 L
.23077 .1315 L
.21154 .12207 L
.19791 .11538 L
.19231 .11409 L
.17308 .10728 L
.15385 .10004 L
.14207 .09615 L
.13462 .09482 L
.11538 .09085 L
.09615 .08763 L
.07692 .08607 L
.05769 .0869 L
.03846 .09151 L
.03091 .09615 L
.01923 .10599 L
F
0 g
.01923 .15774 m
.02687 .17308 L
.03846 .19095 L
.03953 .19231 L
.0549 .21154 L
.05769 .21499 L
.07255 .23077 L
.07692 .23526 L
.09234 .25 L
.09615 .25331 L
.11415 .26923 L
.11538 .27009 L
.13462 .28531 L
.13858 .28846 L
.15385 .29872 L
.16571 .30769 L
.17308 .3115 L
.19231 .32497 L
.19517 .32692 L
.21154 .33521 L
.22846 .34615 L
.23077 .34678 L
.25 .3561 L
.2664 .36538 L
.26923 .36603 L
.28846 .37376 L
.30769 .38277 L
.31197 .38462 L
.32692 .38855 L
.34615 .39499 L
.36538 .40073 L
.37798 .40385 L
.38462 .40466 L
.40385 .40694 L
.42308 .40781 L
.44231 .40619 L
.45311 .40385 L
.46154 .4001 L
.47705 .38462 L
.48077 .37291 L
.48133 .36538 L
.48077 .3584 L
.47803 .34615 L
.46986 .32692 L
.46154 .31153 L
.45868 .30769 L
.44431 .28846 L
.44231 .28581 L
.42736 .26923 L
.42308 .26458 L
Mistroke
.40826 .25 L
.40385 .24595 L
.38707 .23077 L
.38462 .2289 L
.36538 .21291 L
.36368 .21154 L
.34615 .19911 L
.3373 .19231 L
.32692 .18631 L
.30879 .17308 L
.30769 .17269 L
.28846 .16168 L
.27658 .15385 L
.26923 .15115 L
.25 .14018 L
.24043 .13462 L
.23077 .1315 L
.21154 .12207 L
.19791 .11538 L
.19231 .11409 L
.17308 .10728 L
.15385 .10004 L
.14207 .09615 L
.13462 .09482 L
.11538 .09085 L
.09615 .08763 L
.07692 .08607 L
.05769 .0869 L
.03846 .09151 L
.03091 .09615 L
.01923 .10599 L
Mfstroke
.2 g
.09615 .11456 m
.11538 .11465 L
.12361 .11538 L
.13462 .11705 L
.15385 .12141 L
.17308 .12718 L
.19231 .13342 L
.19637 .13462 L
.21154 .14121 L
.23077 .15003 L
.24035 .15385 L
.25 .1591 L
.26923 .16975 L
.27625 .17308 L
.28846 .18085 L
.30745 .19231 L
.30769 .19247 L
.32692 .20635 L
.33462 .21154 L
.34615 .22062 L
.359 .23077 L
.36538 .23626 L
.38057 .25 L
.38462 .25386 L
.39931 .26923 L
.40385 .27416 L
.41512 .28846 L
.42308 .29904 L
.4278 .30769 L
.43657 .32692 L
.43974 .34615 L
.43258 .36538 L
.42308 .37319 L
.40385 .37863 L
.38462 .37941 L
.36538 .37748 L
.34615 .37364 L
.32692 .36857 L
.31498 .36538 L
.30769 .36267 L
.28846 .3548 L
.26923 .34702 L
.2667 .34615 L
.25 .33745 L
.23077 .3278 L
.22867 .32692 L
.21154 .31637 L
.19622 .30769 L
.19231 .30506 L
.17308 .29177 L
.16784 .28846 L
.15385 .27774 L
.14257 .26923 L
.13462 .26259 L
.12009 .25 L
.11538 .24567 L
.10043 .23077 L
.09615 .22633 L
.08365 .21154 L
.07692 .20329 L
.06992 .19231 L
.05967 .17308 L
.05769 .16778 L
.0545 .15385 L
.05735 .13462 L
.05769 .13394 L
.07692 .11802 L
.08895 .11538 L
F
0 g
.09615 .11456 m
.11538 .11465 L
.12361 .11538 L
.13462 .11705 L
.15385 .12141 L
.17308 .12718 L
.19231 .13342 L
.19637 .13462 L
.21154 .14121 L
.23077 .15003 L
.24035 .15385 L
.25 .1591 L
.26923 .16975 L
.27625 .17308 L
.28846 .18085 L
.30745 .19231 L
.30769 .19247 L
.32692 .20635 L
.33462 .21154 L
.34615 .22062 L
.359 .23077 L
.36538 .23626 L
.38057 .25 L
.38462 .25386 L
.39931 .26923 L
.40385 .27416 L
.41512 .28846 L
.42308 .29904 L
.4278 .30769 L
.43657 .32692 L
.43974 .34615 L
.43258 .36538 L
.42308 .37319 L
.40385 .37863 L
.38462 .37941 L
.36538 .37748 L
.34615 .37364 L
.32692 .36857 L
.31498 .36538 L
.30769 .36267 L
.28846 .3548 L
.26923 .34702 L
.2667 .34615 L
.25 .33745 L
.23077 .3278 L
.22867 .32692 L
.21154 .31637 L
.19622 .30769 L
.19231 .30506 L
.17308 .29177 L
Mistroke
.16784 .28846 L
.15385 .27774 L
.14257 .26923 L
.13462 .26259 L
.12009 .25 L
.11538 .24567 L
.10043 .23077 L
.09615 .22633 L
.08365 .21154 L
.07692 .20329 L
.06992 .19231 L
.05967 .17308 L
.05769 .16778 L
.0545 .15385 L
.05735 .13462 L
.05769 .13394 L
.07692 .11802 L
.08895 .11538 L
.09615 .11456 L
Mfstroke
.3 g
.11538 .1326 m
.13462 .13271 L
.14986 .13462 L
.15385 .13535 L
.17308 .14006 L
.19231 .1463 L
.21154 .15321 L
.21335 .15385 L
.23077 .16184 L
.25 .17114 L
.25425 .17308 L
.26923 .18169 L
.28772 .19231 L
.28846 .19278 L
.30769 .2058 L
.31627 .21154 L
.32692 .21957 L
.34126 .23077 L
.34615 .23487 L
.36295 .25 L
.36538 .25228 L
.3814 .26923 L
.38462 .27259 L
.39643 .28846 L
.40385 .29742 L
.40756 .30769 L
.41334 .32692 L
.40975 .34615 L
.40385 .3547 L
.38462 .36073 L
.36538 .36152 L
.34615 .3594 L
.32692 .35519 L
.30769 .34959 L
.29659 .34615 L
.28846 .34291 L
.26923 .33455 L
.25189 .32692 L
.25 .32594 L
.23077 .31538 L
.21652 .30769 L
.21154 .30459 L
.19231 .2921 L
.18653 .28846 L
.17308 .27865 L
.16044 .26923 L
.15385 .26389 L
.13769 .25 L
.13462 .24722 L
.11819 .23077 L
.11538 .22793 L
.10202 .21154 L
.09615 .205 L
.08954 .19231 L
.08175 .17308 L
.08146 .15385 L
.09615 .13516 L
.10387 .13462 L
F
0 g
.11538 .1326 m
.13462 .13271 L
.14986 .13462 L
.15385 .13535 L
.17308 .14006 L
.19231 .1463 L
.21154 .15321 L
.21335 .15385 L
.23077 .16184 L
.25 .17114 L
.25425 .17308 L
.26923 .18169 L
.28772 .19231 L
.28846 .19278 L
.30769 .2058 L
.31627 .21154 L
.32692 .21957 L
.34126 .23077 L
.34615 .23487 L
.36295 .25 L
.36538 .25228 L
.3814 .26923 L
.38462 .27259 L
.39643 .28846 L
.40385 .29742 L
.40756 .30769 L
.41334 .32692 L
.40975 .34615 L
.40385 .3547 L
.38462 .36073 L
.36538 .36152 L
.34615 .3594 L
.32692 .35519 L
.30769 .34959 L
.29659 .34615 L
.28846 .34291 L
.26923 .33455 L
.25189 .32692 L
.25 .32594 L
.23077 .31538 L
.21652 .30769 L
.21154 .30459 L
.19231 .2921 L
.18653 .28846 L
.17308 .27865 L
.16044 .26923 L
.15385 .26389 L
.13769 .25 L
.13462 .24722 L
.11819 .23077 L
Mistroke
.11538 .22793 L
.10202 .21154 L
.09615 .205 L
.08954 .19231 L
.08175 .17308 L
.08146 .15385 L
.09615 .13516 L
.10387 .13462 L
.11538 .1326 L
Mfstroke
.4 g
.11538 .15025 m
.13462 .14633 L
.15385 .14735 L
.17308 .15089 L
.18602 .15385 L
.19231 .15615 L
.21154 .16319 L
.23077 .17125 L
.23509 .17308 L
.25 .18066 L
.26923 .19107 L
.27153 .19231 L
.28846 .20296 L
.30161 .21154 L
.30769 .21588 L
.32692 .23051 L
.32725 .23077 L
.34615 .24727 L
.34901 .25 L
.36538 .26703 L
.36718 .26923 L
.3814 .28846 L
.38462 .294 L
.3907 .30769 L
.39248 .32692 L
.38462 .3393 L
.36871 .34615 L
.36538 .34673 L
.34615 .34706 L
.33775 .34615 L
.32692 .34432 L
.30769 .33939 L
.28846 .33285 L
.27276 .32692 L
.26923 .32533 L
.25 .3161 L
.23337 .30769 L
.23077 .30621 L
.21154 .29461 L
.20158 .28846 L
.19231 .2821 L
.17458 .26923 L
.17308 .26807 L
.15385 .25201 L
.15162 .25 L
.13462 .23339 L
.13227 .23077 L
.11668 .21154 L
.11538 .20964 L
.10565 .19231 L
.10089 .17308 L
.10957 .15385 L
F
0 g
.11538 .15025 m
.13462 .14633 L
.15385 .14735 L
.17308 .15089 L
.18602 .15385 L
.19231 .15615 L
.21154 .16319 L
.23077 .17125 L
.23509 .17308 L
.25 .18066 L
.26923 .19107 L
.27153 .19231 L
.28846 .20296 L
.30161 .21154 L
.30769 .21588 L
.32692 .23051 L
.32725 .23077 L
.34615 .24727 L
.34901 .25 L
.36538 .26703 L
.36718 .26923 L
.3814 .28846 L
.38462 .294 L
.3907 .30769 L
.39248 .32692 L
.38462 .3393 L
.36871 .34615 L
.36538 .34673 L
.34615 .34706 L
.33775 .34615 L
.32692 .34432 L
.30769 .33939 L
.28846 .33285 L
.27276 .32692 L
.26923 .32533 L
.25 .3161 L
.23337 .30769 L
.23077 .30621 L
.21154 .29461 L
.20158 .28846 L
.19231 .2821 L
.17458 .26923 L
.17308 .26807 L
.15385 .25201 L
.15162 .25 L
.13462 .23339 L
.13227 .23077 L
.11668 .21154 L
.11538 .20964 L
.10565 .19231 L
Mistroke
.10089 .17308 L
.10957 .15385 L
.11538 .15025 L
Mfstroke
.5 g
.13462 .15699 m
.15385 .15815 L
.17308 .16055 L
.19231 .16526 L
.21154 .17163 L
.21562 .17308 L
.23077 .17955 L
.25 .18889 L
.25672 .19231 L
.26923 .19947 L
.28846 .21145 L
.2886 .21154 L
.30769 .22516 L
.31494 .23077 L
.32692 .24064 L
.33692 .25 L
.34615 .25873 L
.35473 .26923 L
.36538 .28194 L
.36793 .28846 L
.37493 .30769 L
.36941 .32692 L
.36538 .33084 L
.34615 .33543 L
.32692 .33412 L
.30769 .33016 L
.29485 .32692 L
.28846 .32439 L
.26923 .3168 L
.25 .30805 L
.24923 .30769 L
.23077 .29773 L
.21499 .28846 L
.21154 .28627 L
.19231 .27306 L
.18706 .26923 L
.17308 .25822 L
.16371 .25 L
.15385 .24105 L
.14454 .23077 L
.13462 .22023 L
.12975 .21154 L
.12043 .19231 L
.12014 .17308 L
F
0 g
.13462 .15699 m
.15385 .15815 L
.17308 .16055 L
.19231 .16526 L
.21154 .17163 L
.21562 .17308 L
.23077 .17955 L
.25 .18889 L
.25672 .19231 L
.26923 .19947 L
.28846 .21145 L
.2886 .21154 L
.30769 .22516 L
.31494 .23077 L
.32692 .24064 L
.33692 .25 L
.34615 .25873 L
.35473 .26923 L
.36538 .28194 L
.36793 .28846 L
.37493 .30769 L
.36941 .32692 L
.36538 .33084 L
.34615 .33543 L
.32692 .33412 L
.30769 .33016 L
.29485 .32692 L
.28846 .32439 L
.26923 .3168 L
.25 .30805 L
.24923 .30769 L
.23077 .29773 L
.21499 .28846 L
.21154 .28627 L
.19231 .27306 L
.18706 .26923 L
.17308 .25822 L
.16371 .25 L
.15385 .24105 L
.14454 .23077 L
.13462 .22023 L
.12975 .21154 L
.12043 .19231 L
.12014 .17308 L
.13462 .15699 L
s
.6 g
.15385 .1707 m
.17308 .17037 L
.18902 .17308 L
.19231 .17375 L
.21154 .17951 L
.23077 .18728 L
.24197 .19231 L
.25 .19638 L
.26923 .20726 L
.27626 .21154 L
.28846 .21953 L
.30361 .23077 L
.30769 .23371 L
.3258 .25 L
.32692 .25045 L
.34319 .26923 L
.34615 .27333 L
.35506 .28846 L
.35867 .30769 L
.34615 .32096 L
.32692 .32484 L
.30769 .32163 L
.28846 .31624 L
.26923 .30908 L
.26574 .30769 L
.25 .30042 L
.23077 .29007 L
.22793 .28846 L
.21154 .27826 L
.1986 .26923 L
.19231 .26476 L
.17484 .25 L
.17308 .24888 L
.15587 .23077 L
.15385 .22832 L
.14205 .21154 L
.13534 .19231 L
.14702 .17308 L
F
0 g
.15385 .1707 m
.17308 .17037 L
.18902 .17308 L
.19231 .17375 L
.21154 .17951 L
.23077 .18728 L
.24197 .19231 L
.25 .19638 L
.26923 .20726 L
.27626 .21154 L
.28846 .21953 L
.30361 .23077 L
.30769 .23371 L
.3258 .25 L
.32692 .25045 L
.34319 .26923 L
.34615 .27333 L
.35506 .28846 L
.35867 .30769 L
.34615 .32096 L
.32692 .32484 L
.30769 .32163 L
.28846 .31624 L
.26923 .30908 L
.26574 .30769 L
.25 .30042 L
.23077 .29007 L
.22793 .28846 L
.21154 .27826 L
.1986 .26923 L
.19231 .26476 L
.17484 .25 L
.17308 .24888 L
.15587 .23077 L
.15385 .22832 L
.14205 .21154 L
.13534 .19231 L
.14702 .17308 L
.15385 .1707 L
s
.7 g
.15385 .1897 m
.17308 .17706 L
.19231 .1819 L
.21154 .18744 L
.22631 .19231 L
.23077 .19452 L
.25 .20377 L
.26392 .21154 L
.26923 .21452 L
.28846 .22771 L
.29249 .23077 L
.30769 .24265 L
.31498 .25 L
.32692 .26012 L
.33179 .26923 L
.34191 .28846 L
.33677 .30769 L
.32692 .31327 L
.30769 .3124 L
.28846 .30804 L
.28695 .30769 L
.26923 .30182 L
.25 .29297 L
.24109 .28846 L
.23077 .28287 L
.21154 .27029 L
.21003 .26923 L
.19231 .25605 L
.18566 .25 L
.17308 .23934 L
.16698 .23077 L
.15454 .21154 L
.15385 .20965 L
.15231 .19231 L
F
0 g
.15385 .1897 m
.17308 .17706 L
.19231 .1819 L
.21154 .18744 L
.22631 .19231 L
.23077 .19452 L
.25 .20377 L
.26392 .21154 L
.26923 .21452 L
.28846 .22771 L
.29249 .23077 L
.30769 .24265 L
.31498 .25 L
.32692 .26012 L
.33179 .26923 L
.34191 .28846 L
.33677 .30769 L
.32692 .31327 L
.30769 .3124 L
.28846 .30804 L
.28695 .30769 L
.26923 .30182 L
.25 .29297 L
.24109 .28846 L
.23077 .28287 L
.21154 .27029 L
.21003 .26923 L
.19231 .25605 L
.18566 .25 L
.17308 .23934 L
.16698 .23077 L
.15454 .21154 L
.15385 .20965 L
.15231 .19231 L
.15385 .1897 L
s
.8 g
.17308 .19625 m
.19231 .19244 L
.21154 .19359 L
.23077 .20183 L
.25 .21153 L
.25002 .21154 L
.26923 .22207 L
.28123 .23077 L
.28846 .23357 L
.30404 .25 L
.30769 .25399 L
.32014 .26923 L
.3262 .28846 L
.30769 .3013 L
.28846 .3014 L
.26923 .29395 L
.25491 .28846 L
.25 .28631 L
.23077 .27515 L
.22171 .26923 L
.21154 .26369 L
.19658 .25 L
.19231 .24584 L
.17825 .23077 L
.17308 .22251 L
.16803 .21154 L
F
0 g
.17308 .19625 m
.19231 .19244 L
.21154 .19359 L
.23077 .20183 L
.25 .21153 L
.25002 .21154 L
.26923 .22207 L
.28123 .23077 L
.28846 .23357 L
.30404 .25 L
.30769 .25399 L
.32014 .26923 L
.3262 .28846 L
.30769 .3013 L
.28846 .3014 L
.26923 .29395 L
.25491 .28846 L
.25 .28631 L
.23077 .27515 L
.22171 .26923 L
.21154 .26369 L
.19658 .25 L
.19231 .24584 L
.17825 .23077 L
.17308 .22251 L
.16803 .21154 L
.17308 .19625 L
s
.9 g
.19231 .20633 m
.21154 .20231 L
.23077 .21102 L
.23237 .21154 L
.25 .21619 L
.26872 .23077 L
.26923 .23152 L
.28846 .24505 L
.29192 .25 L
.30615 .26923 L
.29872 .28846 L
.28846 .2892 L
.28413 .28846 L
.26923 .28476 L
.25 .27888 L
.23375 .26923 L
.23077 .2662 L
.21154 .253 L
.20875 .25 L
.19231 .23214 L
.19127 .23077 L
.18643 .21154 L
F
0 g
.19231 .20633 m
.21154 .20231 L
.23077 .21102 L
.23237 .21154 L
.25 .21619 L
.26872 .23077 L
.26923 .23152 L
.28846 .24505 L
.29192 .25 L
.30615 .26923 L
.29872 .28846 L
.28846 .2892 L
.28413 .28846 L
.26923 .28476 L
.25 .27888 L
.23375 .26923 L
.23077 .2662 L
.21154 .253 L
.20875 .25 L
.19231 .23214 L
.19127 .23077 L
.18643 .21154 L
.19231 .20633 L
s
1 g
.21154 .2217 m
.23077 .22226 L
.25 .22992 L
.25137 .23077 L
.26923 .24335 L
.27975 .25 L
.28561 .26923 L
.26923 .27305 L
.25622 .26923 L
.25 .26649 L
.23077 .25513 L
.22135 .25 L
.21154 .23626 L
.20675 .23077 L
F
0 g
.21154 .2217 m
.23077 .22226 L
.25 .22992 L
.25137 .23077 L
.26923 .24335 L
.27975 .25 L
.28561 .26923 L
.26923 .27305 L
.25622 .26923 L
.25 .26649 L
.23077 .25513 L
.22135 .25 L
.21154 .23626 L
.20675 .23077 L
.21154 .2217 L
s
.1 g
.65385 .45724 m
.67308 .45331 L
.69231 .45021 L
.71154 .44807 L
.73077 .44701 L
.75 .44711 L
.76923 .44849 L
.78846 .45132 L
.80769 .45581 L
.82492 .46154 L
.82692 .46236 L
.84615 .47184 L
.85959 .48077 L
.86538 .48546 L
.87939 .5 L
.88462 .50701 L
.89144 .51923 L
.89826 .53846 L
.90105 .55769 L
.90046 .57692 L
.8969 .59615 L
.89065 .61538 L
.88462 .62942 L
.88188 .63462 L
.87048 .65385 L
.86538 .66142 L
.85654 .67308 L
.84615 .68553 L
.83993 .69231 L
.82692 .70542 L
.82035 .71154 L
.80769 .72249 L
.79742 .73077 L
.78846 .73744 L
.77052 .75 L
.76923 .75082 L
.75 .76255 L
.73834 .76923 L
.73077 .7731 L
.71154 .78254 L
.69853 .78846 L
.69231 .79092 L
.67308 .79818 L
.65385 .80473 L
.64414 .80769 L
.63462 .81012 L
.61538 .81451 L
.59615 .81809 L
.57692 .82071 L
.55769 .82229 L
.53846 .82274 L
.51923 .82196 L
.5 .81981 L
.48077 .81611 L
.46154 .81057 L
.45372 .80769 L
.44231 .80254 L
.42308 .79107 L
.41955 .78846 L
.40385 .7739 L
.39996 .76923 L
.38803 .75 L
.38462 .74306 L
.38132 .73077 L
.37865 .71154 L
.3793 .69231 L
.38285 .67308 L
.38462 .66607 L
.38917 .65385 L
.39807 .63462 L
.40385 .62416 L
.40946 .61538 L
.42308 .59653 L
.42338 .59615 L
.44012 .57692 L
.44231 .57461 L
.45975 .55769 L
.46154 .55609 L
.48077 .53996 L
.48267 .53846 L
.5 .5258 L
.50938 .51923 L
.51923 .51311 L
.53846 .50126 L
.54062 .5 L
.55769 .49126 L
.57692 .48201 L
.57974 .48077 L
.59615 .4745 L
.61538 .46778 L
.63462 .46189 L
.63584 .46154 L
F
0 g
.65385 .45724 m
.67308 .45331 L
.69231 .45021 L
.71154 .44807 L
.73077 .44701 L
.75 .44711 L
.76923 .44849 L
.78846 .45132 L
.80769 .45581 L
.82492 .46154 L
.82692 .46236 L
.84615 .47184 L
.85959 .48077 L
.86538 .48546 L
.87939 .5 L
.88462 .50701 L
.89144 .51923 L
.89826 .53846 L
.90105 .55769 L
.90046 .57692 L
.8969 .59615 L
.89065 .61538 L
.88462 .62942 L
.88188 .63462 L
.87048 .65385 L
.86538 .66142 L
.85654 .67308 L
.84615 .68553 L
.83993 .69231 L
.82692 .70542 L
.82035 .71154 L
.80769 .72249 L
.79742 .73077 L
.78846 .73744 L
.77052 .75 L
.76923 .75082 L
.75 .76255 L
.73834 .76923 L
.73077 .7731 L
.71154 .78254 L
.69853 .78846 L
.69231 .79092 L
.67308 .79818 L
.65385 .80473 L
.64414 .80769 L
.63462 .81012 L
.61538 .81451 L
.59615 .81809 L
.57692 .82071 L
.55769 .82229 L
Mistroke
.53846 .82274 L
.51923 .82196 L
.5 .81981 L
.48077 .81611 L
.46154 .81057 L
.45372 .80769 L
.44231 .80254 L
.42308 .79107 L
.41955 .78846 L
.40385 .7739 L
.39996 .76923 L
.38803 .75 L
.38462 .74306 L
.38132 .73077 L
.37865 .71154 L
.3793 .69231 L
.38285 .67308 L
.38462 .66607 L
.38917 .65385 L
.39807 .63462 L
.40385 .62416 L
.40946 .61538 L
.42308 .59653 L
.42338 .59615 L
.44012 .57692 L
.44231 .57461 L
.45975 .55769 L
.46154 .55609 L
.48077 .53996 L
.48267 .53846 L
.5 .5258 L
.50938 .51923 L
.51923 .51311 L
.53846 .50126 L
.54062 .5 L
.55769 .49126 L
.57692 .48201 L
.57974 .48077 L
.59615 .4745 L
.61538 .46778 L
.63462 .46189 L
.63584 .46154 L
.65385 .45724 L
Mfstroke
.2 g
.63462 .49814 m
.65385 .49327 L
.67308 .48953 L
.69231 .487 L
.71154 .48578 L
.73077 .48601 L
.75 .48789 L
.76923 .49173 L
.78846 .49807 L
.79295 .5 L
.80769 .50802 L
.82199 .51923 L
.82692 .52417 L
.83706 .53846 L
.84473 .55769 L
.84615 .56472 L
.84721 .57692 L
.84615 .59268 L
.84559 .59615 L
.84037 .61538 L
.83189 .63462 L
.82692 .64364 L
.82021 .65385 L
.80769 .67027 L
.80527 .67308 L
.78846 .69069 L
.78675 .69231 L
.76923 .70752 L
.76413 .71154 L
.75 .72179 L
.73638 .73077 L
.73077 .73414 L
.71154 .74484 L
.70128 .75 L
.69231 .75407 L
.67308 .762 L
.65385 .76879 L
.65247 .76923 L
.63462 .7742 L
.61538 .7785 L
.59615 .78163 L
.57692 .78347 L
.55769 .78393 L
.53846 .78284 L
.51923 .77994 L
.5 .77483 L
.48581 .76923 L
.48077 .76672 L
.46154 .75389 L
.45726 .75 L
.44238 .73077 L
.44231 .73069 L
.43487 .71154 L
.43249 .69231 L
.4342 .67308 L
.43945 .65385 L
.44231 .64604 L
.448 .63462 L
.45974 .61538 L
.46154 .6128 L
.47479 .59615 L
.48077 .58951 L
.49339 .57692 L
.5 .57092 L
.51607 .55769 L
.51923 .55532 L
.53846 .54193 L
.54388 .53846 L
.55769 .53039 L
.57692 .52024 L
.57899 .51923 L
.59615 .51168 L
.61538 .50427 L
.62815 .5 L
F
0 g
.63462 .49814 m
.65385 .49327 L
.67308 .48953 L
.69231 .487 L
.71154 .48578 L
.73077 .48601 L
.75 .48789 L
.76923 .49173 L
.78846 .49807 L
.79295 .5 L
.80769 .50802 L
.82199 .51923 L
.82692 .52417 L
.83706 .53846 L
.84473 .55769 L
.84615 .56472 L
.84721 .57692 L
.84615 .59268 L
.84559 .59615 L
.84037 .61538 L
.83189 .63462 L
.82692 .64364 L
.82021 .65385 L
.80769 .67027 L
.80527 .67308 L
.78846 .69069 L
.78675 .69231 L
.76923 .70752 L
.76413 .71154 L
.75 .72179 L
.73638 .73077 L
.73077 .73414 L
.71154 .74484 L
.70128 .75 L
.69231 .75407 L
.67308 .762 L
.65385 .76879 L
.65247 .76923 L
.63462 .7742 L
.61538 .7785 L
.59615 .78163 L
.57692 .78347 L
.55769 .78393 L
.53846 .78284 L
.51923 .77994 L
.5 .77483 L
.48581 .76923 L
.48077 .76672 L
.46154 .75389 L
.45726 .75 L
Mistroke
.44238 .73077 L
.44231 .73069 L
.43487 .71154 L
.43249 .69231 L
.4342 .67308 L
.43945 .65385 L
.44231 .64604 L
.448 .63462 L
.45974 .61538 L
.46154 .6128 L
.47479 .59615 L
.48077 .58951 L
.49339 .57692 L
.5 .57092 L
.51607 .55769 L
.51923 .55532 L
.53846 .54193 L
.54388 .53846 L
.55769 .53039 L
.57692 .52024 L
.57899 .51923 L
.59615 .51168 L
.61538 .50427 L
.62815 .5 L
.63462 .49814 L
Mfstroke
.3 g
.65385 .51687 m
.67308 .51345 L
.69231 .51152 L
.71154 .51125 L
.73077 .5129 L
.75 .51691 L
.75754 .51923 L
.76923 .52414 L
.78846 .53673 L
.79036 .53846 L
.80487 .55769 L
.80769 .56425 L
.81097 .57692 L
.81139 .59615 L
.80769 .61407 L
.80728 .61538 L
.79913 .63462 L
.78846 .6521 L
.78714 .65385 L
.77111 .67308 L
.76923 .67506 L
.75058 .69231 L
.75 .69279 L
.73077 .70727 L
.72439 .71154 L
.71154 .71937 L
.69231 .7296 L
.68989 .73077 L
.67308 .73809 L
.65385 .74512 L
.63743 .75 L
.63462 .7507 L
.61538 .75479 L
.59615 .75742 L
.57692 .75848 L
.55769 .75776 L
.53846 .7549 L
.52104 .75 L
.51923 .74928 L
.5 .73961 L
.48887 .73077 L
.48077 .72221 L
.47461 .71154 L
.46865 .69231 L
.46834 .67308 L
.47255 .65385 L
.48075 .63462 L
.48077 .63458 L
.49286 .61538 L
.5 .60615 L
.50897 .59615 L
.51923 .58599 L
.52961 .57692 L
.53846 .56992 L
.55592 .55769 L
.55769 .55656 L
.57692 .54537 L
.59059 .53846 L
.59615 .53594 L
.61538 .52813 L
.63462 .52176 L
.64354 .51923 L
F
0 g
.65385 .51687 m
.67308 .51345 L
.69231 .51152 L
.71154 .51125 L
.73077 .5129 L
.75 .51691 L
.75754 .51923 L
.76923 .52414 L
.78846 .53673 L
.79036 .53846 L
.80487 .55769 L
.80769 .56425 L
.81097 .57692 L
.81139 .59615 L
.80769 .61407 L
.80728 .61538 L
.79913 .63462 L
.78846 .6521 L
.78714 .65385 L
.77111 .67308 L
.76923 .67506 L
.75058 .69231 L
.75 .69279 L
.73077 .70727 L
.72439 .71154 L
.71154 .71937 L
.69231 .7296 L
.68989 .73077 L
.67308 .73809 L
.65385 .74512 L
.63743 .75 L
.63462 .7507 L
.61538 .75479 L
.59615 .75742 L
.57692 .75848 L
.55769 .75776 L
.53846 .7549 L
.52104 .75 L
.51923 .74928 L
.5 .73961 L
.48887 .73077 L
.48077 .72221 L
.47461 .71154 L
.46865 .69231 L
.46834 .67308 L
.47255 .65385 L
.48075 .63462 L
.48077 .63458 L
.49286 .61538 L
.5 .60615 L
Mistroke
.50897 .59615 L
.51923 .58599 L
.52961 .57692 L
.53846 .56992 L
.55592 .55769 L
.55769 .55656 L
.57692 .54537 L
.59059 .53846 L
.59615 .53594 L
.61538 .52813 L
.63462 .52176 L
.64354 .51923 L
.65385 .51687 L
Mfstroke
.4 g
.65385 .53642 m
.67308 .53335 L
.69231 .53215 L
.71154 .53312 L
.73077 .5368 L
.73644 .53846 L
.75 .54426 L
.76764 .55769 L
.76923 .55881 L
.77942 .57692 L
.78258 .59615 L
.7798 .61538 L
.77208 .63462 L
.76923 .64011 L
.75968 .65385 L
.75 .66543 L
.74234 .67308 L
.73077 .68339 L
.7191 .69231 L
.71154 .6975 L
.69231 .70894 L
.68735 .71154 L
.67308 .7182 L
.65385 .72559 L
.63652 .73077 L
.63462 .73123 L
.61538 .73511 L
.59615 .73719 L
.57692 .73726 L
.55769 .73491 L
.54182 .73077 L
.53846 .72936 L
.51923 .71868 L
.51164 .71154 L
.50012 .69231 L
.5 .69193 L
.4971 .67308 L
.49999 .65385 L
.5 .6538 L
.50782 .63462 L
.51923 .61666 L
.52032 .61538 L
.53777 .59615 L
.53846 .5955 L
.55769 .57942 L
.56116 .57692 L
.57692 .56662 L
.59315 .55769 L
.59615 .55622 L
.61538 .54783 L
.63462 .54125 L
.64433 .53846 L
F
0 g
.65385 .53642 m
.67308 .53335 L
.69231 .53215 L
.71154 .53312 L
.73077 .5368 L
.73644 .53846 L
.75 .54426 L
.76764 .55769 L
.76923 .55881 L
.77942 .57692 L
.78258 .59615 L
.7798 .61538 L
.77208 .63462 L
.76923 .64011 L
.75968 .65385 L
.75 .66543 L
.74234 .67308 L
.73077 .68339 L
.7191 .69231 L
.71154 .6975 L
.69231 .70894 L
.68735 .71154 L
.67308 .7182 L
.65385 .72559 L
.63652 .73077 L
.63462 .73123 L
.61538 .73511 L
.59615 .73719 L
.57692 .73726 L
.55769 .73491 L
.54182 .73077 L
.53846 .72936 L
.51923 .71868 L
.51164 .71154 L
.50012 .69231 L
.5 .69193 L
.4971 .67308 L
.49999 .65385 L
.5 .6538 L
.50782 .63462 L
.51923 .61666 L
.52032 .61538 L
.53777 .59615 L
.53846 .5955 L
.55769 .57942 L
.56116 .57692 L
.57692 .56662 L
.59315 .55769 L
.59615 .55622 L
.61538 .54783 L
Mistroke
.63462 .54125 L
.64433 .53846 L
.65385 .53642 L
Mfstroke
.5 g
.65385 .55458 m
.67308 .55201 L
.69231 .5519 L
.71154 .55488 L
.72125 .55769 L
.73077 .56209 L
.74717 .57692 L
.75 .58151 L
.75494 .59615 L
.75413 .61538 L
.75 .62818 L
.74698 .63462 L
.73403 .65385 L
.73077 .65777 L
.71476 .67308 L
.71154 .67574 L
.69231 .6892 L
.68702 .69231 L
.67308 .69955 L
.65385 .70746 L
.64131 .71154 L
.63462 .71316 L
.61538 .71674 L
.59615 .71803 L
.57692 .71658 L
.55795 .71154 L
.55769 .71137 L
.53846 .70017 L
.53222 .69231 L
.52467 .67308 L
.52563 .65385 L
.53292 .63462 L
.53846 .62437 L
.54599 .61538 L
.55769 .60276 L
.5654 .59615 L
.57692 .58727 L
.59343 .57692 L
.59615 .57542 L
.61538 .56619 L
.63462 .55931 L
.6392 .55769 L
F
0 g
.65385 .55458 m
.67308 .55201 L
.69231 .5519 L
.71154 .55488 L
.72125 .55769 L
.73077 .56209 L
.74717 .57692 L
.75 .58151 L
.75494 .59615 L
.75413 .61538 L
.75 .62818 L
.74698 .63462 L
.73403 .65385 L
.73077 .65777 L
.71476 .67308 L
.71154 .67574 L
.69231 .6892 L
.68702 .69231 L
.67308 .69955 L
.65385 .70746 L
.64131 .71154 L
.63462 .71316 L
.61538 .71674 L
.59615 .71803 L
.57692 .71658 L
.55795 .71154 L
.55769 .71137 L
.53846 .70017 L
.53222 .69231 L
.52467 .67308 L
.52563 .65385 L
.53292 .63462 L
.53846 .62437 L
.54599 .61538 L
.55769 .60276 L
.5654 .59615 L
.57692 .58727 L
.59343 .57692 L
.59615 .57542 L
.61538 .56619 L
.63462 .55931 L
.6392 .55769 L
.65385 .55458 L
s
.6 g
.65385 .57324 m
.67308 .57155 L
.69231 .57355 L
.70509 .57692 L
.71154 .57895 L
.72458 .59615 L
.72743 .61538 L
.72127 .63462 L
.71154 .65166 L
.70738 .65385 L
.69231 .66789 L
.68453 .67308 L
.67308 .68004 L
.65385 .68887 L
.6448 .69231 L
.63462 .69463 L
.61538 .69772 L
.59615 .69757 L
.57692 .69274 L
.57585 .69231 L
.55769 .67776 L
.55502 .67308 L
.55231 .65385 L
.55769 .63658 L
.55867 .63462 L
.57271 .61538 L
.57692 .6109 L
.59592 .59615 L
.59615 .596 L
.61538 .58514 L
.63462 .57784 L
.63784 .57692 L
F
0 g
.65385 .57324 m
.67308 .57155 L
.69231 .57355 L
.70509 .57692 L
.71154 .57895 L
.72458 .59615 L
.72743 .61538 L
.72127 .63462 L
.71154 .65166 L
.70738 .65385 L
.69231 .66789 L
.68453 .67308 L
.67308 .68004 L
.65385 .68887 L
.6448 .69231 L
.63462 .69463 L
.61538 .69772 L
.59615 .69757 L
.57692 .69274 L
.57585 .69231 L
.55769 .67776 L
.55502 .67308 L
.55231 .65385 L
.55769 .63658 L
.55867 .63462 L
.57271 .61538 L
.57692 .6109 L
.59592 .59615 L
.59615 .596 L
.61538 .58514 L
.63462 .57784 L
.63784 .57692 L
.65385 .57324 L
s
.7 g
.65385 .596 m
.66779 .59615 L
.67308 .59711 L
.69231 .61109 L
.69384 .61538 L
.69231 .62999 L
.69055 .63462 L
.67387 .65385 L
.67308 .65455 L
.65385 .66785 L
.63462 .67229 L
.63025 .67308 L
.61538 .67392 L
.6092 .67308 L
.59615 .66824 L
.58519 .65385 L
.58935 .63462 L
.59615 .62519 L
.60578 .61538 L
.61538 .60806 L
.63462 .59842 L
.65251 .59615 L
F
0 g
.65385 .596 m
.66779 .59615 L
.67308 .59711 L
.69231 .61109 L
.69384 .61538 L
.69231 .62999 L
.69055 .63462 L
.67387 .65385 L
.67308 .65455 L
.65385 .66785 L
.63462 .67229 L
.63025 .67308 L
.61538 .67392 L
.6092 .67308 L
.59615 .66824 L
.58519 .65385 L
.58935 .63462 L
.59615 .62519 L
.60578 .61538 L
.61538 .60806 L
.63462 .59842 L
.65251 .59615 L
.65385 .596 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.522676 0.0238095 0.97619 0.477324 MathSubStart
%% SurfaceGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.11022e-16 1.04977 -0.0679587 1.04977 [
[ 0 0 0 0 ]
[ 1 .81114 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.39787 .81114 L
s
.39787 .81114 m
.40529 .59895 L
s
.40529 .59895 m
.03716 .25514 L
s
.68874 0 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.68874 0 m
.03716 .25514 L
s
.40529 .59895 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.39787 .81114 L
s
.39787 .81114 m
.40529 .59895 L
s
0 0 m
1 0 L
1 .81114 L
0 .81114 L
closepath
clip
newpath
.664 .741 .908 r
.39902 .59803 .40512 .60371 .41537 .60064 .40929 .59494 Mtetra
.40929 .59494 .41537 .60064 .42565 .59755 .4196 .59183 Mtetra
.4196 .59183 .42565 .59755 .43597 .59446 .42994 .58871 Mtetra
.42994 .58871 .43597 .59446 .44633 .59135 .44033 .58558 Mtetra
.44033 .58558 .44633 .59135 .45674 .58823 .45076 .58244 Mtetra
.45076 .58244 .45674 .58823 .46718 .5851 .46122 .57928 Mtetra
.46122 .57928 .46718 .5851 .47766 .58195 .47173 .57612 Mtetra
.663 .741 .908 r
.47173 .57612 .47766 .58195 .48818 .5788 .48228 .57294 Mtetra
.48228 .57294 .48818 .5788 .49874 .57563 .49287 .56975 Mtetra
.49287 .56975 .49874 .57563 .50935 .57245 .5035 .56655 Mtetra
.5035 .56655 .50935 .57245 .51999 .56926 .51417 .56334 Mtetra
.51417 .56334 .51999 .56926 .53068 .56606 .52489 .56011 Mtetra
.663 .742 .908 r
.52489 .56011 .53068 .56606 .54141 .56284 .53564 .55688 Mtetra
.53564 .55688 .54141 .56284 .55218 .55961 .54644 .55363 Mtetra
.663 .742 .909 r
.54644 .55363 .55218 .55961 .56299 .55637 .55728 .55038 Mtetra
.55728 .55038 .56299 .55637 .57385 .55312 .56816 .54711 Mtetra
.56816 .54711 .57385 .55312 .58474 .54986 .57909 .54383 Mtetra
.57909 .54383 .58474 .54986 .59568 .54658 .59006 .54054 Mtetra
.663 .743 .909 r
.59006 .54054 .59568 .54658 .60667 .54329 .60107 .53723 Mtetra
.60107 .53723 .60667 .54329 .6177 .53999 .61213 .53391 Mtetra
.663 .743 .91 r
.61213 .53391 .6177 .53999 .62877 .53667 .62323 .53057 Mtetra
.62323 .53057 .62877 .53667 .63988 .53334 .63437 .52722 Mtetra
.663 .744 .91 r
.63437 .52722 .63988 .53334 .65104 .52999 .64556 .52385 Mtetra
.64556 .52385 .65104 .52999 .66224 .52663 .6568 .52047 Mtetra
.664 .744 .91 r
.6568 .52047 .66224 .52663 .67349 .52326 .66808 .51706 Mtetra
.66808 .51706 .67349 .52326 .68478 .51986 .6794 .51364 Mtetra
.6794 .51364 .68478 .51986 .69612 .51646 .69077 .51021 Mtetra
.664 .744 .909 r
.69077 .51021 .69612 .51646 .7075 .51304 .70218 .50675 Mtetra
.664 .743 .909 r
.70218 .50675 .7075 .51304 .71893 .5096 .71364 .50329 Mtetra
.71364 .50329 .71893 .5096 .73041 .50615 .72515 .4998 Mtetra
.72515 .4998 .73041 .50615 .74193 .50269 .7367 .49631 Mtetra
.7367 .49631 .74193 .50269 .7535 .49922 .7483 .4928 Mtetra
.664 .742 .908 r
.7483 .4928 .7535 .49922 .76511 .49573 .75995 .48928 Mtetra
.75995 .48928 .76511 .49573 .77677 .49223 .77165 .48575 Mtetra
.77165 .48575 .77677 .49223 .78848 .48871 .78339 .4822 Mtetra
.78339 .4822 .78848 .48871 .80024 .48518 .79518 .47864 Mtetra
.79518 .47864 .80024 .48518 .81205 .48164 .80702 .47507 Mtetra
.80702 .47507 .81205 .48164 .8239 .47808 .81891 .47148 Mtetra
.664 .741 .908 r
.81891 .47148 .8239 .47808 .8358 .47451 .83085 .46788 Mtetra
.83085 .46788 .8358 .47451 .84775 .47092 .84283 .46427 Mtetra
.84283 .46427 .84775 .47092 .85976 .46732 .85487 .46064 Mtetra
.85487 .46064 .85976 .46732 .87181 .46371 .86696 .457 Mtetra
.86696 .457 .87181 .46371 .88391 .46008 .87909 .45334 Mtetra
.87909 .45334 .88391 .46008 .89606 .45643 .89128 .44966 Mtetra
.89128 .44966 .89606 .45643 .90826 .45277 .90352 .44598 Mtetra
.90352 .44598 .90826 .45277 .92051 .4491 .91581 .44227 Mtetra
.91581 .44227 .92051 .4491 .93281 .44541 .92815 .43855 Mtetra
.92815 .43855 .93281 .44541 .94517 .4417 .94054 .43482 Mtetra
.94054 .43482 .94517 .4417 .95757 .43798 .95299 .43107 Mtetra
.95299 .43107 .95757 .43798 .97003 .43424 .96548 .4273 Mtetra
.39287 .59231 .39902 .59803 .40929 .59494 .40317 .58919 Mtetra
.40317 .58919 .40929 .59494 .4196 .59183 .4135 .58606 Mtetra
.4135 .58606 .4196 .59183 .42994 .58871 .42387 .58292 Mtetra
.42387 .58292 .42994 .58871 .44033 .58558 .43428 .57977 Mtetra
.43428 .57977 .44033 .58558 .45076 .58244 .44474 .5766 Mtetra
.44474 .5766 .45076 .58244 .46122 .57928 .45523 .57343 Mtetra
.663 .741 .908 r
.45523 .57343 .46122 .57928 .47173 .57612 .46576 .57024 Mtetra
.46576 .57024 .47173 .57612 .48228 .57294 .47634 .56704 Mtetra
.47634 .56704 .48228 .57294 .49287 .56975 .48695 .56383 Mtetra
.48695 .56383 .49287 .56975 .5035 .56655 .49761 .56061 Mtetra
.49761 .56061 .5035 .56655 .51417 .56334 .50831 .55738 Mtetra
.663 .742 .908 r
.50831 .55738 .51417 .56334 .52489 .56011 .51905 .55414 Mtetra
.663 .742 .909 r
.51905 .55414 .52489 .56011 .53564 .55688 .52983 .55088 Mtetra
.52983 .55088 .53564 .55688 .54644 .55363 .54066 .54762 Mtetra
.54066 .54762 .54644 .55363 .55728 .55038 .55153 .54436 Mtetra
.55153 .54436 .55728 .55038 .56816 .54711 .56244 .54108 Mtetra
.663 .743 .91 r
.56244 .54108 .56816 .54711 .57909 .54383 .5734 .53779 Mtetra
.662 .743 .91 r
.5734 .53779 .57909 .54383 .59006 .54054 .58439 .53449 Mtetra
.662 .744 .911 r
.58439 .53449 .59006 .54054 .60107 .53723 .59544 .53117 Mtetra
.59544 .53117 .60107 .53723 .61213 .53391 .60652 .52784 Mtetra
.663 .745 .911 r
.60652 .52784 .61213 .53391 .62323 .53057 .61766 .5245 Mtetra
.663 .746 .912 r
.61766 .5245 .62323 .53057 .63437 .52722 .62883 .52113 Mtetra
.62883 .52113 .63437 .52722 .64556 .52385 .64005 .51775 Mtetra
.64005 .51775 .64556 .52385 .6568 .52047 .65132 .51434 Mtetra
.664 .747 .912 r
.65132 .51434 .6568 .52047 .66808 .51706 .66263 .51091 Mtetra
.66263 .51091 .66808 .51706 .6794 .51364 .67398 .50746 Mtetra
.67398 .50746 .6794 .51364 .69077 .51021 .68538 .50399 Mtetra
.664 .746 .911 r
.68538 .50399 .69077 .51021 .70218 .50675 .69683 .5005 Mtetra
.69683 .5005 .70218 .50675 .71364 .50329 .70832 .49699 Mtetra
.664 .745 .911 r
.70832 .49699 .71364 .50329 .72515 .4998 .71986 .49346 Mtetra
.664 .745 .91 r
.71986 .49346 .72515 .4998 .7367 .49631 .73144 .48993 Mtetra
.664 .744 .91 r
.73144 .48993 .7367 .49631 .7483 .4928 .74308 .48638 Mtetra
.664 .744 .909 r
.74308 .48638 .7483 .4928 .75995 .48928 .75476 .48281 Mtetra
.664 .743 .909 r
.75476 .48281 .75995 .48928 .77165 .48575 .76648 .47924 Mtetra
.76648 .47924 .77165 .48575 .78339 .4822 .77826 .47566 Mtetra
.664 .742 .909 r
.77826 .47566 .78339 .4822 .79518 .47864 .79009 .47206 Mtetra
.664 .742 .908 r
.79009 .47206 .79518 .47864 .80702 .47507 .80196 .46846 Mtetra
.80196 .46846 .80702 .47507 .81891 .47148 .81388 .46484 Mtetra
.81388 .46484 .81891 .47148 .83085 .46788 .82585 .46121 Mtetra
.82585 .46121 .83085 .46788 .84283 .46427 .83788 .45756 Mtetra
.664 .741 .908 r
.83788 .45756 .84283 .46427 .85487 .46064 .84995 .4539 Mtetra
.84995 .4539 .85487 .46064 .86696 .457 .86207 .45023 Mtetra
.86207 .45023 .86696 .457 .87909 .45334 .87424 .44655 Mtetra
.87424 .44655 .87909 .45334 .89128 .44966 .88647 .44284 Mtetra
.88647 .44284 .89128 .44966 .90352 .44598 .89874 .43913 Mtetra
.89874 .43913 .90352 .44598 .91581 .44227 .91107 .43539 Mtetra
.91107 .43539 .91581 .44227 .92815 .43855 .92345 .43164 Mtetra
.92345 .43164 .92815 .43855 .94054 .43482 .93588 .42788 Mtetra
.93588 .42788 .94054 .43482 .95299 .43107 .94836 .4241 Mtetra
.94836 .4241 .95299 .43107 .96548 .4273 .9609 .4203 Mtetra
.38668 .58654 .39287 .59231 .40317 .58919 .397 .5834 Mtetra
.397 .5834 .40317 .58919 .4135 .58606 .40736 .58025 Mtetra
.40736 .58025 .4135 .58606 .42387 .58292 .41776 .57709 Mtetra
.41776 .57709 .42387 .58292 .43428 .57977 .42819 .57392 Mtetra
.42819 .57392 .43428 .57977 .44474 .5766 .43867 .57073 Mtetra
.663 .741 .908 r
.43867 .57073 .44474 .5766 .45523 .57343 .44919 .56753 Mtetra
.44919 .56753 .45523 .57343 .46576 .57024 .45975 .56432 Mtetra
.45975 .56432 .46576 .57024 .47634 .56704 .47035 .5611 Mtetra
.47035 .5611 .47634 .56704 .48695 .56383 .48099 .55787 Mtetra
.48099 .55787 .48695 .56383 .49761 .56061 .49168 .55463 Mtetra
.663 .742 .908 r
.49168 .55463 .49761 .56061 .50831 .55738 .5024 .55138 Mtetra
.663 .742 .909 r
.5024 .55138 .50831 .55738 .51905 .55414 .51317 .54813 Mtetra
.51317 .54813 .51905 .55414 .52983 .55088 .52398 .54486 Mtetra
.662 .742 .909 r
.52398 .54486 .52983 .55088 .54066 .54762 .53484 .5416 Mtetra
.662 .743 .91 r
.53484 .5416 .54066 .54762 .55153 .54436 .54574 .53832 Mtetra
.662 .743 .911 r
.54574 .53832 .55153 .54436 .56244 .54108 .55668 .53504 Mtetra
.661 .744 .911 r
.55668 .53504 .56244 .54108 .5734 .53779 .56766 .53176 Mtetra
.661 .745 .912 r
.56766 .53176 .5734 .53779 .58439 .53449 .57869 .52847 Mtetra
.661 .746 .913 r
.57869 .52847 .58439 .53449 .59544 .53117 .58976 .52516 Mtetra
.661 .747 .914 r
.58976 .52516 .59544 .53117 .60652 .52784 .60088 .52184 Mtetra
.661 .748 .915 r
.60088 .52184 .60652 .52784 .61766 .5245 .61204 .5185 Mtetra
.662 .749 .915 r
.61204 .5185 .61766 .5245 .62883 .52113 .62325 .51514 Mtetra
.662 .75 .916 r
.62325 .51514 .62883 .52113 .64005 .51775 .6345 .51175 Mtetra
.663 .751 .916 r
.6345 .51175 .64005 .51775 .65132 .51434 .6458 .50833 Mtetra
.663 .752 .916 r
.6458 .50833 .65132 .51434 .66263 .51091 .65714 .50488 Mtetra
.664 .752 .916 r
.65714 .50488 .66263 .51091 .67398 .50746 .66853 .50139 Mtetra
.66853 .50139 .67398 .50746 .68538 .50399 .67996 .49788 Mtetra
.665 .752 .915 r
.67996 .49788 .68538 .50399 .69683 .5005 .69144 .49434 Mtetra
.665 .751 .914 r
.69144 .49434 .69683 .5005 .70832 .49699 .70296 .49078 Mtetra
.665 .75 .914 r
.70296 .49078 .70832 .49699 .71986 .49346 .71453 .4872 Mtetra
.665 .749 .913 r
.71453 .4872 .71986 .49346 .73144 .48993 .72615 .4836 Mtetra
.665 .748 .912 r
.72615 .4836 .73144 .48993 .74308 .48638 .73781 .47999 Mtetra
.665 .747 .911 r
.73781 .47999 .74308 .48638 .75476 .48281 .74953 .47637 Mtetra
.665 .746 .91 r
.74953 .47637 .75476 .48281 .76648 .47924 .76129 .47274 Mtetra
.665 .745 .91 r
.76129 .47274 .76648 .47924 .77826 .47566 .7731 .46911 Mtetra
.665 .744 .909 r
.7731 .46911 .77826 .47566 .79009 .47206 .78495 .46547 Mtetra
.664 .743 .909 r
.78495 .46547 .79009 .47206 .80196 .46846 .79686 .46182 Mtetra
.79686 .46182 .80196 .46846 .81388 .46484 .80882 .45816 Mtetra
.664 .742 .908 r
.80882 .45816 .81388 .46484 .82585 .46121 .82082 .45449 Mtetra
.82082 .45449 .82585 .46121 .83788 .45756 .83288 .45081 Mtetra
.83288 .45081 .83788 .45756 .84995 .4539 .84499 .44712 Mtetra
.84499 .44712 .84995 .4539 .86207 .45023 .85715 .44342 Mtetra
.664 .741 .908 r
.85715 .44342 .86207 .45023 .87424 .44655 .86936 .4397 Mtetra
.86936 .4397 .87424 .44655 .88647 .44284 .88162 .43597 Mtetra
.88162 .43597 .88647 .44284 .89874 .43913 .89393 .43222 Mtetra
.89393 .43222 .89874 .43913 .91107 .43539 .9063 .42846 Mtetra
.9063 .42846 .91107 .43539 .92345 .43164 .91871 .42468 Mtetra
.91871 .42468 .92345 .43164 .93588 .42788 .93118 .42089 Mtetra
.93118 .42089 .93588 .42788 .94836 .4241 .94371 .41708 Mtetra
.94371 .41708 .94836 .4241 .9609 .4203 .95628 .41325 Mtetra
.38045 .58074 .38668 .58654 .397 .5834 .39079 .57758 Mtetra
.39079 .57758 .397 .5834 .40736 .58025 .40117 .5744 Mtetra
.40117 .5744 .40736 .58025 .41776 .57709 .4116 .57122 Mtetra
.4116 .57122 .41776 .57709 .42819 .57392 .42206 .56802 Mtetra
.663 .741 .908 r
.42206 .56802 .42819 .57392 .43867 .57073 .43256 .56481 Mtetra
.43256 .56481 .43867 .57073 .44919 .56753 .44311 .56159 Mtetra
.44311 .56159 .44919 .56753 .45975 .56432 .45369 .55836 Mtetra
.45369 .55836 .45975 .56432 .47035 .5611 .46432 .55512 Mtetra
.46432 .55512 .47035 .5611 .48099 .55787 .47499 .55187 Mtetra
.47499 .55187 .48099 .55787 .49168 .55463 .4857 .54861 Mtetra
.663 .742 .909 r
.4857 .54861 .49168 .55463 .5024 .55138 .49646 .54535 Mtetra
.662 .742 .909 r
.49646 .54535 .5024 .55138 .51317 .54813 .50725 .54209 Mtetra
.662 .742 .91 r
.50725 .54209 .51317 .54813 .52398 .54486 .51809 .53882 Mtetra
.661 .743 .91 r
.51809 .53882 .52398 .54486 .53484 .5416 .52897 .53555 Mtetra
.661 .743 .911 r
.52897 .53555 .53484 .5416 .54574 .53832 .5399 .53229 Mtetra
.66 .744 .912 r
.5399 .53229 .54574 .53832 .55668 .53504 .55087 .52903 Mtetra
.66 .746 .914 r
.55087 .52903 .55668 .53504 .56766 .53176 .56188 .52577 Mtetra
.659 .747 .915 r
.56188 .52577 .56766 .53176 .57869 .52847 .57294 .52251 Mtetra
.659 .749 .917 r
.57294 .52251 .57869 .52847 .58976 .52516 .58405 .51925 Mtetra
.659 .751 .918 r
.58405 .51925 .58976 .52516 .60088 .52184 .5952 .51597 Mtetra
.659 .753 .92 r
.5952 .51597 .60088 .52184 .61204 .5185 .60639 .51267 Mtetra
.659 .756 .921 r
.60639 .51267 .61204 .5185 .62325 .51514 .61763 .50934 Mtetra
.66 .758 .923 r
.61763 .50934 .62325 .51514 .6345 .51175 .62892 .50597 Mtetra
.661 .76 .924 r
.62892 .50597 .6345 .51175 .6458 .50833 .64025 .50256 Mtetra
.662 .761 .924 r
.64025 .50256 .6458 .50833 .65714 .50488 .65163 .4991 Mtetra
.663 .762 .924 r
.65163 .4991 .65714 .50488 .66853 .50139 .66305 .49559 Mtetra
.664 .763 .923 r
.66305 .49559 .66853 .50139 .67996 .49788 .67451 .49203 Mtetra
.665 .762 .923 r
.67451 .49203 .67996 .49788 .69144 .49434 .68602 .48843 Mtetra
.666 .761 .921 r
.68602 .48843 .69144 .49434 .70296 .49078 .69758 .48479 Mtetra
.667 .76 .92 r
.69758 .48479 .70296 .49078 .71453 .4872 .70918 .48112 Mtetra
.667 .758 .918 r
.70918 .48112 .71453 .4872 .72615 .4836 .72083 .47743 Mtetra
.667 .756 .917 r
.72083 .47743 .72615 .4836 .73781 .47999 .73252 .47373 Mtetra
.667 .754 .915 r
.73252 .47373 .73781 .47999 .74953 .47637 .74427 .47002 Mtetra
.667 .751 .914 r
.74427 .47002 .74953 .47637 .76129 .47274 .75606 .46631 Mtetra
.666 .749 .912 r
.75606 .46631 .76129 .47274 .7731 .46911 .7679 .4626 Mtetra
.666 .747 .911 r
.7679 .4626 .7731 .46911 .78495 .46547 .77979 .45889 Mtetra
.665 .746 .91 r
.77979 .45889 .78495 .46547 .79686 .46182 .79173 .45518 Mtetra
.665 .745 .91 r
.79173 .45518 .79686 .46182 .80882 .45816 .80372 .45146 Mtetra
.665 .744 .909 r
.80372 .45146 .80882 .45816 .82082 .45449 .81576 .44775 Mtetra
.664 .743 .909 r
.81576 .44775 .82082 .45449 .83288 .45081 .82785 .44403 Mtetra
.664 .742 .908 r
.82785 .44403 .83288 .45081 .84499 .44712 .83999 .4403 Mtetra
.83999 .4403 .84499 .44712 .85715 .44342 .85219 .43656 Mtetra
.85219 .43656 .85715 .44342 .86936 .4397 .86443 .43281 Mtetra
.86443 .43281 .86936 .4397 .88162 .43597 .87673 .42905 Mtetra
.664 .741 .908 r
.87673 .42905 .88162 .43597 .89393 .43222 .88908 .42527 Mtetra
.88908 .42527 .89393 .43222 .9063 .42846 .90149 .42148 Mtetra
.90149 .42148 .9063 .42846 .91871 .42468 .91394 .41767 Mtetra
.91394 .41767 .91871 .42468 .93118 .42089 .92645 .41384 Mtetra
.92645 .41384 .93118 .42089 .94371 .41708 .93901 .41 Mtetra
.93901 .41 .94371 .41708 .95628 .41325 .95162 .40615 Mtetra
.37417 .57489 .38045 .58074 .39079 .57758 .38454 .57171 Mtetra
.38454 .57171 .39079 .57758 .40117 .5744 .39494 .56851 Mtetra
.39494 .56851 .40117 .5744 .4116 .57122 .40539 .56531 Mtetra
.663 .741 .908 r
.40539 .56531 .4116 .57122 .42206 .56802 .41588 .56209 Mtetra
.41588 .56209 .42206 .56802 .43256 .56481 .42641 .55885 Mtetra
.42641 .55885 .43256 .56481 .44311 .56159 .43698 .55561 Mtetra
.43698 .55561 .44311 .56159 .45369 .55836 .44759 .55236 Mtetra
.44759 .55236 .45369 .55836 .46432 .55512 .45825 .5491 Mtetra
.45825 .5491 .46432 .55512 .47499 .55187 .46894 .54583 Mtetra
.663 .742 .909 r
.46894 .54583 .47499 .55187 .4857 .54861 .47968 .54256 Mtetra
.662 .742 .909 r
.47968 .54256 .4857 .54861 .49646 .54535 .49046 .53929 Mtetra
.662 .742 .91 r
.49046 .53929 .49646 .54535 .50725 .54209 .50129 .53602 Mtetra
.661 .743 .911 r
.50129 .53602 .50725 .54209 .51809 .53882 .51215 .53276 Mtetra
.66 .743 .912 r
.51215 .53276 .51809 .53882 .52897 .53555 .52306 .52951 Mtetra
.659 .744 .913 r
.52306 .52951 .52897 .53555 .5399 .53229 .53402 .52628 Mtetra
.658 .746 .915 r
.53402 .52628 .5399 .53229 .55087 .52903 .54502 .52306 Mtetra
.656 .748 .917 r
.54502 .52306 .55087 .52903 .56188 .52577 .55606 .51986 Mtetra
.655 .75 .92 r
.55606 .51986 .56188 .52577 .57294 .52251 .56715 .51668 Mtetra
.654 .753 .923 r
.56715 .51668 .57294 .52251 .58405 .51925 .57829 .5135 Mtetra
.654 .757 .926 r
.57829 .5135 .58405 .51925 .5952 .51597 .58947 .51031 Mtetra
.653 .761 .929 r
.58947 .51031 .5952 .51597 .60639 .51267 .6007 .50711 Mtetra
.654 .765 .931 r
.6007 .50711 .60639 .51267 .61763 .50934 .61198 .50386 Mtetra
.654 .77 .934 r
.61198 .50386 .61763 .50934 .62892 .50597 .6233 .50057 Mtetra
.656 .774 .936 r
.6233 .50057 .62892 .50597 .64025 .50256 .63467 .49721 Mtetra
.658 .777 .937 r
.63467 .49721 .64025 .50256 .65163 .4991 .64608 .49378 Mtetra
.66 .78 .937 r
.64608 .49378 .65163 .4991 .66305 .49559 .65754 .49026 Mtetra
.663 .781 .937 r
.65754 .49026 .66305 .49559 .67451 .49203 .66904 .48666 Mtetra
.665 .781 .936 r
.66904 .48666 .67451 .49203 .68602 .48843 .68059 .48298 Mtetra
.667 .78 .934 r
.68059 .48298 .68602 .48843 .69758 .48479 .69218 .47924 Mtetra
.669 .778 .931 r
.69218 .47924 .69758 .48479 .70918 .48112 .70381 .47545 Mtetra
.67 .775 .928 r
.70381 .47545 .70918 .48112 .72083 .47743 .71549 .47162 Mtetra
.67 .771 .925 r
.71549 .47162 .72083 .47743 .73252 .47373 .72721 .46777 Mtetra
.67 .766 .922 r
.72721 .46777 .73252 .47373 .74427 .47002 .73898 .46391 Mtetra
.67 .762 .92 r
.73898 .46391 .74427 .47002 .75606 .46631 .7508 .46006 Mtetra
.669 .758 .917 r
.7508 .46006 .75606 .46631 .7679 .4626 .76267 .45622 Mtetra
.668 .754 .915 r
.76267 .45622 .7679 .4626 .77979 .45889 .77459 .4524 Mtetra
.667 .751 .913 r
.77459 .4524 .77979 .45889 .79173 .45518 .78656 .44859 Mtetra
.667 .749 .912 r
.78656 .44859 .79173 .45518 .80372 .45146 .79858 .44479 Mtetra
.666 .747 .911 r
.79858 .44479 .80372 .45146 .81576 .44775 .81066 .44101 Mtetra
.665 .745 .91 r
.81066 .44101 .81576 .44775 .82785 .44403 .82278 .43723 Mtetra
.665 .744 .909 r
.82278 .43723 .82785 .44403 .83999 .4403 .83496 .43345 Mtetra
.664 .743 .909 r
.83496 .43345 .83999 .4403 .85219 .43656 .84719 .42966 Mtetra
.664 .742 .908 r
.84719 .42966 .85219 .43656 .86443 .43281 .85947 .42587 Mtetra
.85947 .42587 .86443 .43281 .87673 .42905 .87181 .42207 Mtetra
.87181 .42207 .87673 .42905 .88908 .42527 .8842 .41826 Mtetra
.8842 .41826 .88908 .42527 .90149 .42148 .89664 .41444 Mtetra
.664 .741 .908 r
.89664 .41444 .90149 .42148 .91394 .41767 .90913 .4106 Mtetra
.90913 .4106 .91394 .41767 .92645 .41384 .92168 .40674 Mtetra
.92168 .40674 .92645 .41384 .93901 .41 .93428 .40287 Mtetra
.93428 .40287 .93901 .41 .95162 .40615 .94693 .39899 Mtetra
.36785 .56901 .37417 .57489 .38454 .57171 .37824 .5658 Mtetra
.37824 .5658 .38454 .57171 .39494 .56851 .38867 .56258 Mtetra
.38867 .56258 .39494 .56851 .40539 .56531 .39914 .55935 Mtetra
.663 .741 .908 r
.39914 .55935 .40539 .56531 .41588 .56209 .40966 .55611 Mtetra
.40966 .55611 .41588 .56209 .42641 .55885 .42022 .55285 Mtetra
.42022 .55285 .42641 .55885 .43698 .55561 .43081 .54959 Mtetra
.43081 .54959 .43698 .55561 .44759 .55236 .44145 .54631 Mtetra
.44145 .54631 .44759 .55236 .45825 .5491 .45213 .54303 Mtetra
.663 .741 .909 r
.45213 .54303 .45825 .5491 .46894 .54583 .46285 .53975 Mtetra
.662 .742 .909 r
.46285 .53975 .46894 .54583 .47968 .54256 .47362 .53647 Mtetra
.661 .742 .91 r
.47362 .53647 .47968 .54256 .49046 .53929 .48443 .53319 Mtetra
.48443 .53319 .49046 .53929 .50129 .53602 .49528 .52993 Mtetra
.659 .743 .912 r
.49528 .52993 .50129 .53602 .51215 .53276 .50617 .52669 Mtetra
.658 .744 .913 r
.50617 .52669 .51215 .53276 .52306 .52951 .51711 .52348 Mtetra
.656 .745 .916 r
.51711 .52348 .52306 .52951 .53402 .52628 .5281 .5203 Mtetra
.654 .747 .918 r
.5281 .5203 .53402 .52628 .54502 .52306 .53912 .51716 Mtetra
.651 .75 .922 r
.53912 .51716 .54502 .52306 .55606 .51986 .5502 .51407 Mtetra
.649 .754 .926 r
.5502 .51407 .55606 .51986 .56715 .51668 .56132 .51102 Mtetra
.646 .759 .931 r
.56132 .51102 .56715 .51668 .57829 .5135 .57249 .50799 Mtetra
.644 .764 .936 r
.57249 .50799 .57829 .5135 .58947 .51031 .58371 .50498 Mtetra
.643 .771 .941 r
.58371 .50498 .58947 .51031 .6007 .50711 .59498 .50196 Mtetra
.642 .779 .946 r
.59498 .50196 .6007 .50711 .61198 .50386 .6063 .4989 Mtetra
.643 .787 .951 r
.6063 .4989 .61198 .50386 .6233 .50057 .61766 .49577 Mtetra
.644 .795 .955 r
.61766 .49577 .6233 .50057 .63467 .49721 .62907 .49255 Mtetra
.647 .802 .957 r
.62907 .49255 .63467 .49721 .64608 .49378 .64053 .4892 Mtetra
.651 .808 .958 r
.64053 .4892 .64608 .49378 .65754 .49026 .65202 .48572 Mtetra
.656 .812 .958 r
.65202 .48572 .65754 .49026 .66904 .48666 .66356 .4821 Mtetra
.661 .813 .956 r
.66356 .4821 .66904 .48666 .68059 .48298 .67515 .47835 Mtetra
.666 .813 .954 r
.67515 .47835 .68059 .48298 .69218 .47924 .68677 .47447 Mtetra
.67 .81 .95 r
.68677 .47447 .69218 .47924 .70381 .47545 .69843 .4705 Mtetra
.673 .805 .945 r
.69843 .4705 .70381 .47545 .71549 .47162 .71014 .46646 Mtetra
.675 .798 .94 r
.71014 .46646 .71549 .47162 .72721 .46777 .72189 .46237 Mtetra
.676 .791 .935 r
.72189 .46237 .72721 .46777 .73898 .46391 .73369 .45828 Mtetra
.676 .783 .93 r
.73369 .45828 .73898 .46391 .7508 .46006 .74553 .4542 Mtetra
.675 .775 .926 r
.74553 .4542 .7508 .46006 .76267 .45622 .75743 .45015 Mtetra
.673 .768 .922 r
.75743 .45015 .76267 .45622 .77459 .4524 .76937 .44613 Mtetra
.672 .762 .918 r
.76937 .44613 .77459 .4524 .78656 .44859 .78137 .44216 Mtetra
.67 .757 .916 r
.78137 .44216 .78656 .44859 .79858 .44479 .79342 .43822 Mtetra
.668 .753 .913 r
.79342 .43822 .79858 .44479 .81066 .44101 .80553 .43432 Mtetra
.667 .749 .912 r
.80553 .43432 .81066 .44101 .82278 .43723 .81768 .43045 Mtetra
.666 .747 .91 r
.81768 .43045 .82278 .43723 .83496 .43345 .82989 .42659 Mtetra
.665 .745 .91 r
.82989 .42659 .83496 .43345 .84719 .42966 .84216 .42275 Mtetra
.665 .744 .909 r
.84216 .42275 .84719 .42966 .85947 .42587 .85448 .4189 Mtetra
.664 .743 .909 r
.85448 .4189 .85947 .42587 .87181 .42207 .86685 .41506 Mtetra
.664 .742 .908 r
.86685 .41506 .87181 .42207 .8842 .41826 .87927 .41121 Mtetra
.87927 .41121 .8842 .41826 .89664 .41444 .89175 .40735 Mtetra
.89175 .40735 .89664 .41444 .90913 .4106 .90428 .40348 Mtetra
.664 .741 .908 r
.90428 .40348 .90913 .4106 .92168 .40674 .91687 .39959 Mtetra
.91687 .39959 .92168 .40674 .93428 .40287 .92951 .39569 Mtetra
.92951 .39569 .93428 .40287 .94693 .39899 .9422 .39177 Mtetra
.36148 .56308 .36785 .56901 .37824 .5658 .37189 .55985 Mtetra
.37189 .55985 .37824 .5658 .38867 .56258 .38235 .5566 Mtetra
.38235 .5566 .38867 .56258 .39914 .55935 .39285 .55335 Mtetra
.663 .741 .908 r
.39285 .55335 .39914 .55935 .40966 .55611 .40339 .55008 Mtetra
.40339 .55008 .40966 .55611 .42022 .55285 .41397 .54681 Mtetra
.41397 .54681 .42022 .55285 .43081 .54959 .4246 .54352 Mtetra
.4246 .54352 .43081 .54959 .44145 .54631 .43526 .54023 Mtetra
.43526 .54023 .44145 .54631 .45213 .54303 .44597 .53693 Mtetra
.662 .741 .909 r
.44597 .53693 .45213 .54303 .46285 .53975 .45672 .53363 Mtetra
.45672 .53363 .46285 .53975 .47362 .53647 .46751 .53034 Mtetra
.661 .742 .91 r
.46751 .53034 .47362 .53647 .48443 .53319 .47835 .52706 Mtetra
.659 .742 .911 r
.47835 .52706 .48443 .53319 .49528 .52993 .48922 .52381 Mtetra
.657 .743 .913 r
.48922 .52381 .49528 .52993 .50617 .52669 .50015 .5206 Mtetra
.655 .744 .915 r
.50015 .5206 .50617 .52669 .51711 .52348 .51111 .51745 Mtetra
.652 .746 .919 r
.51111 .51745 .51711 .52348 .5281 .5203 .52213 .51436 Mtetra
.648 .748 .923 r
.52213 .51436 .5281 .5203 .53912 .51716 .53319 .51134 Mtetra
.644 .752 .928 r
.53319 .51134 .53912 .51716 .5502 .51407 .54429 .50842 Mtetra
.639 .757 .934 r
.54429 .50842 .5502 .51407 .56132 .51102 .55545 .50557 Mtetra
.633 .764 .941 r
.55545 .50557 .56132 .51102 .57249 .50799 .56666 .5028 Mtetra
.628 .773 .95 r
.56666 .5028 .57249 .50799 .58371 .50498 .57791 .50008 Mtetra
.623 .783 .958 r
.57791 .50008 .58371 .50498 .59498 .50196 .58922 .49737 Mtetra
.62 .795 .966 r
.58922 .49737 .59498 .50196 .6063 .4989 .60058 .49463 Mtetra
.617 .808 .973 r
.60058 .49463 .6063 .4989 .61766 .49577 .61199 .49181 Mtetra
.617 .822 .979 r
.61199 .49181 .61766 .49577 .62907 .49255 .62345 .48885 Mtetra
.619 .835 .983 r
.62345 .48885 .62907 .49255 .64053 .4892 .63496 .48572 Mtetra
.624 .846 .984 r
.63496 .48572 .64053 .4892 .65202 .48572 .6465 .48238 Mtetra
.632 .855 .984 r
.6465 .48238 .65202 .48572 .66356 .4821 .65809 .4788 Mtetra
.642 .861 .982 r
.65809 .4788 .66356 .4821 .67515 .47835 .66972 .47499 Mtetra
.653 .863 .979 r
.66972 .47499 .67515 .47835 .68677 .47447 .68138 .47096 Mtetra
.664 .86 .975 r
.68138 .47096 .68677 .47447 .69843 .4705 .69308 .46675 Mtetra
.672 .854 .969 r
.69308 .46675 .69843 .4705 .71014 .46646 .70481 .4624 Mtetra
.679 .845 .962 r
.70481 .4624 .71014 .46646 .72189 .46237 .71659 .45797 Mtetra
.683 .833 .955 r
.71659 .45797 .72189 .46237 .73369 .45828 .72841 .45351 Mtetra
.684 .819 .948 r
.72841 .45351 .73369 .45828 .74553 .4542 .74028 .44906 Mtetra
.684 .806 .94 r
.74028 .44906 .74553 .4542 .75743 .45015 .75219 .44465 Mtetra
.682 .793 .934 r
.75219 .44465 .75743 .45015 .76937 .44613 .76415 .44032 Mtetra
.679 .782 .928 r
.76415 .44032 .76937 .44613 .78137 .44216 .77617 .43606 Mtetra
.676 .772 .923 r
.77617 .43606 .78137 .44216 .79342 .43822 .78824 .43189 Mtetra
.674 .764 .919 r
.78824 .43189 .79342 .43822 .80553 .43432 .80037 .42779 Mtetra
.671 .758 .916 r
.80037 .42779 .80553 .43432 .81768 .43045 .81255 .42376 Mtetra
.669 .753 .913 r
.81255 .42376 .81768 .43045 .82989 .42659 .8248 .41978 Mtetra
.667 .749 .911 r
.8248 .41978 .82989 .42659 .84216 .42275 .83709 .41584 Mtetra
.666 .746 .91 r
.83709 .41584 .84216 .42275 .85448 .4189 .84944 .41192 Mtetra
.665 .745 .909 r
.84944 .41192 .85448 .4189 .86685 .41506 .86185 .40802 Mtetra
.665 .743 .909 r
.86185 .40802 .86685 .41506 .87927 .41121 .87431 .40412 Mtetra
.664 .743 .908 r
.87431 .40412 .87927 .41121 .89175 .40735 .88683 .40021 Mtetra
.664 .742 .908 r
.88683 .40021 .89175 .40735 .90428 .40348 .8994 .3963 Mtetra
.8994 .3963 .90428 .40348 .91687 .39959 .91202 .39238 Mtetra
.91202 .39238 .91687 .39959 .92951 .39569 .9247 .38844 Mtetra
.664 .741 .908 r
.9247 .38844 .92951 .39569 .9422 .39177 .93743 .38449 Mtetra
.35506 .5571 .36148 .56308 .37189 .55985 .3655 .55385 Mtetra
.3655 .55385 .37189 .55985 .38235 .5566 .37599 .55058 Mtetra
.663 .741 .908 r
.37599 .55058 .38235 .5566 .39285 .55335 .38651 .54731 Mtetra
.38651 .54731 .39285 .55335 .40339 .55008 .39708 .54402 Mtetra
.39708 .54402 .40339 .55008 .41397 .54681 .40769 .54072 Mtetra
.40769 .54072 .41397 .54681 .4246 .54352 .41834 .53741 Mtetra
.41834 .53741 .4246 .54352 .43526 .54023 .42903 .53409 Mtetra
.42903 .53409 .43526 .54023 .44597 .53693 .43976 .53078 Mtetra
.662 .741 .909 r
.43976 .53078 .44597 .53693 .45672 .53363 .45054 .52746 Mtetra
.661 .741 .91 r
.45054 .52746 .45672 .53363 .46751 .53034 .46136 .52416 Mtetra
.66 .742 .911 r
.46136 .52416 .46751 .53034 .47835 .52706 .47222 .52089 Mtetra
.658 .742 .912 r
.47222 .52089 .47835 .52706 .48922 .52381 .48313 .51766 Mtetra
.655 .743 .914 r
.48313 .51766 .48922 .52381 .50015 .5206 .49408 .5145 Mtetra
.651 .744 .917 r
.49408 .5145 .50015 .5206 .51111 .51745 .50507 .51142 Mtetra
.646 .746 .922 r
.50507 .51142 .51111 .51745 .52213 .51436 .51611 .50844 Mtetra
.64 .748 .927 r
.51611 .50844 .52213 .51436 .53319 .51134 .5272 .5056 Mtetra
.633 .753 .934 r
.5272 .5056 .53319 .51134 .54429 .50842 .53834 .5029 Mtetra
.624 .759 .943 r
.53834 .5029 .54429 .50842 .55545 .50557 .54953 .50035 Mtetra
.613 .768 .954 r
.54953 .50035 .55545 .50557 .56666 .5028 .56077 .49795 Mtetra
.601 .779 .965 r
.56077 .49795 .56666 .5028 .57791 .50008 .57207 .49566 Mtetra
.589 .793 .977 r
.57207 .49566 .57791 .50008 .58922 .49737 .58343 .49343 Mtetra
.575 .809 .988 r
.58343 .49343 .58922 .49737 .60058 .49463 .59484 .4912 Mtetra
.562 .826 .995 r
.59484 .4912 .60058 .49463 .61199 .49181 .6063 .4889 Mtetra
.55 .844 .998 r
.6063 .4889 .61199 .49181 .62345 .48885 .61782 .48642 Mtetra
.543 .861 .996 r
.61782 .48642 .62345 .48885 .63496 .48572 .62938 .4837 Mtetra
.542 .876 .991 r
.62938 .4837 .63496 .48572 .6465 .48238 .64099 .48066 Mtetra
.549 .89 .984 r
.64099 .48066 .6465 .48238 .65809 .4788 .65263 .47726 Mtetra
.565 .902 .979 r
.65263 .47726 .65809 .4788 .66972 .47499 .66431 .47346 Mtetra
.589 .912 .977 r
.66431 .47346 .66972 .47499 .68138 .47096 .67602 .4693 Mtetra
.616 .918 .977 r
.67602 .4693 .68138 .47096 .69308 .46675 .68776 .46481 Mtetra
.643 .918 .978 r
.68776 .46481 .69308 .46675 .70481 .4624 .69953 .46006 Mtetra
.665 .911 .978 r
.69953 .46006 .70481 .4624 .71659 .45797 .71133 .45514 Mtetra
.682 .897 .974 r
.71133 .45514 .71659 .45797 .72841 .45351 .72317 .45013 Mtetra
.691 .879 .968 r
.72317 .45013 .72841 .45351 .74028 .44906 .73505 .44511 Mtetra
.695 .858 .96 r
.73505 .44511 .74028 .44906 .75219 .44465 .74697 .44015 Mtetra
.695 .837 .951 r
.74697 .44015 .75219 .44465 .76415 .44032 .75895 .43529 Mtetra
.692 .817 .942 r
.75895 .43529 .76415 .44032 .77617 .43606 .77098 .43058 Mtetra
.687 .799 .934 r
.77098 .43058 .77617 .43606 .78824 .43189 .78306 .42601 Mtetra
.683 .785 .928 r
.78306 .42601 .78824 .43189 .80037 .42779 .79521 .42159 Mtetra
.678 .773 .922 r
.79521 .42159 .80037 .42779 .81255 .42376 .80741 .41729 Mtetra
.674 .764 .918 r
.80741 .41729 .81255 .42376 .8248 .41978 .81967 .41311 Mtetra
.671 .757 .915 r
.81967 .41311 .8248 .41978 .83709 .41584 .832 .40901 Mtetra
.669 .751 .912 r
.832 .40901 .83709 .41584 .84944 .41192 .84438 .40497 Mtetra
.667 .748 .911 r
.84438 .40497 .84944 .41192 .86185 .40802 .85682 .40097 Mtetra
.666 .745 .91 r
.85682 .40097 .86185 .40802 .87431 .40412 .86931 .397 Mtetra
.665 .744 .909 r
.86931 .397 .87431 .40412 .88683 .40021 .88186 .39304 Mtetra
.664 .743 .909 r
.88186 .39304 .88683 .40021 .8994 .3963 .89447 .38908 Mtetra
.664 .742 .908 r
.89447 .38908 .8994 .3963 .91202 .39238 .90714 .38512 Mtetra
.90714 .38512 .91202 .39238 .9247 .38844 .91985 .38115 Mtetra
.91985 .38115 .9247 .38844 .93743 .38449 .93263 .37716 Mtetra
.664 .741 .908 r
.3486 .55109 .35506 .5571 .3655 .55385 .35907 .54781 Mtetra
.35907 .54781 .3655 .55385 .37599 .55058 .36958 .54452 Mtetra
.663 .741 .908 r
.36958 .54452 .37599 .55058 .38651 .54731 .38013 .54122 Mtetra
.38013 .54122 .38651 .54731 .39708 .54402 .39072 .53791 Mtetra
.39072 .53791 .39708 .54402 .40769 .54072 .40135 .53458 Mtetra
.40135 .53458 .40769 .54072 .41834 .53741 .41203 .53125 Mtetra
.41203 .53125 .41834 .53741 .42903 .53409 .42275 .52791 Mtetra
.662 .741 .909 r
.42275 .52791 .42903 .53409 .43976 .53078 .43351 .52458 Mtetra
.43351 .52458 .43976 .53078 .45054 .52746 .44431 .52125 Mtetra
.66 .741 .91 r
.44431 .52125 .45054 .52746 .46136 .52416 .45516 .51794 Mtetra
.659 .741 .911 r
.45516 .51794 .46136 .52416 .47222 .52089 .46605 .51468 Mtetra
.656 .741 .913 r
.46605 .51468 .47222 .52089 .48313 .51766 .47698 .51147 Mtetra
.652 .742 .915 r
.47698 .51147 .48313 .51766 .49408 .5145 .48796 .50836 Mtetra
.647 .743 .919 r
.48796 .50836 .49408 .5145 .50507 .51142 .49898 .50536 Mtetra
.64 .744 .925 r
.49898 .50536 .50507 .51142 .51611 .50844 .51005 .50253 Mtetra
.631 .747 .932 r
.51005 .50253 .51611 .50844 .5272 .5056 .52117 .4999 Mtetra
.619 .752 .941 r
.52117 .4999 .5272 .5056 .53834 .5029 .53234 .49749 Mtetra
.603 .758 .952 r
.53234 .49749 .53834 .5029 .54953 .50035 .54356 .49533 Mtetra
.584 .767 .966 r
.54356 .49533 .54953 .50035 .56077 .49795 .55485 .49341 Mtetra
.56 .779 .98 r
.55485 .49341 .56077 .49795 .57207 .49566 .56619 .49171 Mtetra
.53 .792 .993 r
.56619 .49171 .57207 .49566 .58343 .49343 .57759 .49016 Mtetra
.493 .806 1 r
.57759 .49016 .58343 .49343 .59484 .4912 .58906 .48869 Mtetra
.449 .817 .994 r
.58906 .48869 .59484 .4912 .6063 .4889 .60058 .48716 Mtetra
.402 .821 .971 r
.60058 .48716 .6063 .4889 .61782 .48642 .61216 .48545 Mtetra
.359 .817 .93 r
.61216 .48545 .61782 .48642 .62938 .4837 .6238 .48343 Mtetra
.328 .81 .88 r
.6238 .48343 .62938 .4837 .64099 .48066 .63548 .48096 Mtetra
.317 .806 .836 r
.63548 .48096 .64099 .48066 .65263 .47726 .6472 .47794 Mtetra
.331 .814 .809 r
.6472 .47794 .65263 .47726 .66431 .47346 .65895 .47434 Mtetra
.368 .836 .805 r
.65895 .47434 .66431 .47346 .67602 .4693 .67072 .47013 Mtetra
.425 .869 .824 r
.67072 .47013 .67602 .4693 .68776 .46481 .68251 .46536 Mtetra
.494 .905 .859 r
.68251 .46536 .68776 .46481 .69953 .46006 .69432 .46014 Mtetra
.564 .936 .899 r
.69432 .46014 .69953 .46006 .71133 .45514 .70615 .45457 Mtetra
.625 .951 .934 r
.70615 .45457 .71133 .45514 .72317 .45013 .718 .4488 Mtetra
.669 .948 .957 r
.718 .4488 .72317 .45013 .73505 .44511 .72989 .44297 Mtetra
.695 .93 .967 r
.72989 .44297 .73505 .44511 .74697 .44015 .74181 .43718 Mtetra
.707 .903 .966 r
.74181 .43718 .74697 .44015 .75895 .43529 .75379 .43153 Mtetra
.708 .873 .959 r
.75379 .43153 .75895 .43529 .77098 .43058 .76581 .4261 Mtetra
.704 .844 .95 r
.76581 .4261 .77098 .43058 .78306 .42601 .7779 .4209 Mtetra
.697 .819 .94 r
.7779 .4209 .78306 .42601 .79521 .42159 .79005 .41595 Mtetra
.69 .799 .932 r
.79005 .41595 .79521 .42159 .80741 .41729 .80226 .41123 Mtetra
.684 .782 .925 r
.80226 .41123 .80741 .41729 .81967 .41311 .81454 .4067 Mtetra
.678 .77 .92 r
.81454 .4067 .81967 .41311 .832 .40901 .82688 .40234 Mtetra
.674 .761 .916 r
.82688 .40234 .832 .40901 .84438 .40497 .83929 .39811 Mtetra
.671 .754 .913 r
.83929 .39811 .84438 .40497 .85682 .40097 .85175 .39397 Mtetra
.668 .749 .911 r
.85175 .39397 .85682 .40097 .86931 .397 .86428 .38989 Mtetra
.666 .746 .91 r
.86428 .38989 .86931 .397 .88186 .39304 .87687 .38585 Mtetra
.665 .744 .909 r
.87687 .38585 .88186 .39304 .89447 .38908 .88951 .38183 Mtetra
.665 .743 .909 r
.88951 .38183 .89447 .38908 .90714 .38512 .90221 .37781 Mtetra
.664 .742 .908 r
.90221 .37781 .90714 .38512 .91985 .38115 .91497 .3738 Mtetra
.91497 .3738 .91985 .38115 .93263 .37716 .92779 .36977 Mtetra
.664 .741 .908 r
.34209 .54503 .3486 .55109 .35907 .54781 .35259 .54173 Mtetra
.35259 .54173 .35907 .54781 .36958 .54452 .36312 .53841 Mtetra
.663 .741 .908 r
.36312 .53841 .36958 .54452 .38013 .54122 .3737 .53509 Mtetra
.3737 .53509 .38013 .54122 .39072 .53791 .38431 .53175 Mtetra
.38431 .53175 .39072 .53791 .40135 .53458 .39497 .5284 Mtetra
.39497 .5284 .40135 .53458 .41203 .53125 .40568 .52505 Mtetra
.40568 .52505 .41203 .53125 .42275 .52791 .41642 .52169 Mtetra
.662 .741 .909 r
.41642 .52169 .42275 .52791 .43351 .52458 .42721 .51833 Mtetra
.661 .741 .909 r
.42721 .51833 .43351 .52458 .44431 .52125 .43804 .51499 Mtetra
.66 .741 .91 r
.43804 .51499 .44431 .52125 .45516 .51794 .44891 .51167 Mtetra
.658 .741 .911 r
.44891 .51167 .45516 .51794 .46605 .51468 .45983 .50841 Mtetra
.654 .741 .913 r
.45983 .50841 .46605 .51468 .47698 .51147 .47079 .50522 Mtetra
.649 .741 .916 r
.47079 .50522 .47698 .51147 .48796 .50836 .48179 .50216 Mtetra
.642 .741 .921 r
.48179 .50216 .48796 .50836 .49898 .50536 .49284 .49926 Mtetra
.633 .742 .927 r
.49284 .49926 .49898 .50536 .51005 .50253 .50394 .49658 Mtetra
.62 .744 .935 r
.50394 .49658 .51005 .50253 .52117 .4999 .51509 .49418 Mtetra
.602 .747 .946 r
.51509 .49418 .52117 .4999 .53234 .49749 .52629 .4921 Mtetra
.579 .752 .96 r
.52629 .4921 .53234 .49749 .54356 .49533 .53755 .4904 Mtetra
.546 .758 .975 r
.53755 .4904 .54356 .49533 .55485 .49341 .54887 .48907 Mtetra
.503 .766 .99 r
.54887 .48907 .55485 .49341 .56619 .49171 .56025 .48811 Mtetra
.443 .771 .997 r
.56025 .48811 .56619 .49171 .57759 .49016 .5717 .48745 Mtetra
.362 .766 .983 r
.5717 .48745 .57759 .49016 .58906 .48869 .58323 .48697 Mtetra
.261 .741 .931 r
.58323 .48697 .58906 .48869 .60058 .48716 .59482 .48654 Mtetra
.151 .689 .832 r
.59482 .48654 .60058 .48716 .61216 .48545 .60649 .48594 Mtetra
0 0 0 r
.60649 .48594 .61216 .48545 .6238 .48343 .61821 .48498 Mtetra
.007 0 0 r
.61821 .48498 .6238 .48343 .63548 .48096 .62998 .48344 Mtetra
.032 0 0 r
.62998 .48344 .63548 .48096 .6472 .47794 .64179 .48116 Mtetra
.023 0 0 r
.64179 .48116 .6472 .47794 .65895 .47434 .65362 .47802 Mtetra
0 0 0 r
.65362 .47802 .65895 .47434 .67072 .47013 .66548 .47397 Mtetra
.66548 .47397 .67072 .47013 .68251 .46536 .67733 .46903 Mtetra
.67733 .46903 .68251 .46536 .69432 .46014 .6892 .46332 Mtetra
.6892 .46332 .69432 .46014 .70615 .45457 .70106 .457 Mtetra
.403 .831 .673 r
.70106 .457 .70615 .45457 .718 .4488 .71294 .45027 Mtetra
.525 .913 .785 r
.71294 .45027 .718 .4488 .72989 .44297 .72483 .44334 Mtetra
.624 .96 .876 r
.72483 .44334 .72989 .44297 .74181 .43718 .73675 .4364 Mtetra
.686 .967 .931 r
.73675 .4364 .74181 .43718 .75379 .43153 .74871 .42963 Mtetra
.716 .945 .956 r
.74871 .42963 .75379 .43153 .76581 .4261 .76072 .42313 Mtetra
.723 .91 .96 r
.76072 .42313 .76581 .4261 .7779 .4209 .77279 .41698 Mtetra
.718 .873 .954 r
.77279 .41698 .7779 .4209 .79005 .41595 .78492 .41122 Mtetra
.709 .84 .945 r
.78492 .41122 .79005 .41595 .80226 .41123 .79713 .40582 Mtetra
.699 .813 .936 r
.79713 .40582 .80226 .41123 .81454 .4067 .80941 .40076 Mtetra
.69 .792 .928 r
.80941 .40076 .81454 .4067 .82688 .40234 .82176 .39599 Mtetra
.683 .776 .922 r
.82176 .39599 .82688 .40234 .83929 .39811 .83418 .39144 Mtetra
.677 .764 .917 r
.83418 .39144 .83929 .39811 .85175 .39397 .84667 .38707 Mtetra
.672 .756 .914 r
.84667 .38707 .85175 .39397 .86428 .38989 .85922 .38283 Mtetra
.669 .751 .912 r
.85922 .38283 .86428 .38989 .87687 .38585 .87184 .37866 Mtetra
.667 .747 .91 r
.87184 .37866 .87687 .38585 .88951 .38183 .88452 .37455 Mtetra
.666 .745 .909 r
.88452 .37455 .88951 .38183 .90221 .37781 .89725 .37047 Mtetra
.665 .743 .909 r
.89725 .37047 .90221 .37781 .91497 .3738 .91005 .3664 Mtetra
.664 .742 .908 r
.91005 .3664 .91497 .3738 .92779 .36977 .9229 .36234 Mtetra
.664 .741 .908 r
.33554 .53892 .34209 .54503 .35259 .54173 .34605 .5356 Mtetra
.34605 .5356 .35259 .54173 .36312 .53841 .35661 .53226 Mtetra
.663 .741 .908 r
.35661 .53226 .36312 .53841 .3737 .53509 .36722 .52891 Mtetra
.36722 .52891 .3737 .53509 .38431 .53175 .37786 .52555 Mtetra
.37786 .52555 .38431 .53175 .39497 .5284 .38855 .52218 Mtetra
.38855 .52218 .39497 .5284 .40568 .52505 .39928 .5188 Mtetra
.39928 .5188 .40568 .52505 .41642 .52169 .41005 .51541 Mtetra
.662 .741 .909 r
.41005 .51541 .41642 .52169 .42721 .51833 .42086 .51203 Mtetra
.661 .741 .909 r
.42086 .51203 .42721 .51833 .43804 .51499 .43172 .50867 Mtetra
.659 .74 .91 r
.43172 .50867 .43804 .51499 .44891 .51167 .44262 .50534 Mtetra
.657 .74 .911 r
.44262 .50534 .44891 .51167 .45983 .50841 .45357 .50207 Mtetra
.653 .74 .913 r
.45357 .50207 .45983 .50841 .47079 .50522 .46455 .4989 Mtetra
.647 .739 .916 r
.46455 .4989 .47079 .50522 .48179 .50216 .47558 .49588 Mtetra
.638 .739 .921 r
.47558 .49588 .48179 .50216 .49284 .49926 .48666 .49306 Mtetra
.626 .738 .928 r
.48666 .49306 .49284 .49926 .50394 .49658 .49779 .49052 Mtetra
.609 .738 .937 r
.49779 .49052 .50394 .49658 .51509 .49418 .50896 .48835 Mtetra
.586 .739 .949 r
.50896 .48835 .51509 .49418 .52629 .4921 .52019 .48662 Mtetra
.552 .74 .964 r
.52019 .48662 .52629 .4921 .53755 .4904 .53148 .4854 Mtetra
.505 .741 .979 r
.53148 .4854 .53755 .4904 .54887 .48907 .54283 .48473 Mtetra
.436 .738 .991 r
.54283 .48473 .54887 .48907 .56025 .48811 .55426 .48461 Mtetra
.336 .723 .984 r
.55426 .48461 .56025 .48811 .5717 .48745 .56576 .485 Mtetra
.198 .68 .931 r
.56576 .485 .5717 .48745 .58323 .48697 .57735 .48575 Mtetra
.033 .594 .804 r
.57735 .48575 .58323 .48697 .59482 .48654 .58902 .4867 Mtetra
.12 0 0 r
.58902 .4867 .59482 .48654 .60649 .48594 .60076 .48757 Mtetra
.224 0 0 r
.60076 .48757 .60649 .48594 .61821 .48498 .61258 .48809 Mtetra
.275 0 0 r
.61258 .48809 .61821 .48498 .62998 .48344 .62446 .48794 Mtetra
.285 0 0 r
.62446 .48794 .62998 .48344 .64179 .48116 .63638 .48684 Mtetra
.268 0 0 r
.63638 .48684 .64179 .48116 .65362 .47802 .64833 .48458 Mtetra
.231 0 0 r
.64833 .48458 .65362 .47802 .66548 .47397 .66029 .48102 Mtetra
.178 0 0 r
.66029 .48102 .66548 .47397 .67733 .46903 .67224 .47615 Mtetra
.106 0 0 r
.67224 .47615 .67733 .46903 .6892 .46332 .68417 .47008 Mtetra
.015 0 0 r
.68417 .47008 .6892 .46332 .70106 .457 .69609 .46299 Mtetra
0 0 0 r
.69609 .46299 .70106 .457 .71294 .45027 .70799 .45516 Mtetra
.70799 .45516 .71294 .45027 .72483 .44334 .71989 .44688 Mtetra
.71989 .44688 .72483 .44334 .73675 .4364 .7318 .43847 Mtetra
.553 .915 .733 r
.7318 .43847 .73675 .4364 .74871 .42963 .74374 .43018 Mtetra
.663 .974 .857 r
.74374 .43018 .74871 .42963 .76072 .42313 .75572 .42222 Mtetra
.721 .974 .925 r
.75572 .42222 .76072 .42313 .77279 .41698 .76775 .41474 Mtetra
.738 .942 .951 r
.76775 .41474 .77279 .41698 .78492 .41122 .77986 .40779 Mtetra
.734 .899 .953 r
.77986 .40779 .78492 .41122 .79713 .40582 .79204 .40141 Mtetra
.722 .859 .946 r
.79204 .40141 .79713 .40582 .80941 .40076 .8043 .39554 Mtetra
.708 .826 .938 r
.8043 .39554 .80941 .40076 .82176 .39599 .81664 .39013 Mtetra
.696 .8 .929 r
.81664 .39013 .82176 .39599 .83418 .39144 .82906 .38511 Mtetra
.687 .781 .923 r
.82906 .38511 .83418 .39144 .84667 .38707 .84156 .38038 Mtetra
.679 .768 .918 r
.84156 .38038 .84667 .38707 .85922 .38283 .85414 .37588 Mtetra
.674 .758 .914 r
.85414 .37588 .85922 .38283 .87184 .37866 .86678 .37153 Mtetra
.67 .752 .912 r
.86678 .37153 .87184 .37866 .88452 .37455 .87949 .36729 Mtetra
.668 .748 .91 r
.87949 .36729 .88452 .37455 .89725 .37047 .89226 .36311 Mtetra
.666 .745 .909 r
.89226 .36311 .89725 .37047 .91005 .3664 .90509 .35897 Mtetra
.665 .743 .909 r
.90509 .35897 .91005 .3664 .9229 .36234 .91799 .35485 Mtetra
.664 .741 .908 r
.32893 .53277 .33554 .53892 .34605 .5356 .33948 .52942 Mtetra
.33948 .52942 .34605 .5356 .35661 .53226 .35006 .52606 Mtetra
.663 .741 .908 r
.35006 .52606 .35661 .53226 .36722 .52891 .36069 .52269 Mtetra
.36069 .52269 .36722 .52891 .37786 .52555 .37136 .5193 Mtetra
.37136 .5193 .37786 .52555 .38855 .52218 .38207 .5159 Mtetra
.38207 .5159 .38855 .52218 .39928 .5188 .39283 .5125 Mtetra
.39283 .5125 .39928 .5188 .41005 .51541 .40363 .50909 Mtetra
.662 .741 .908 r
.40363 .50909 .41005 .51541 .42086 .51203 .41447 .50568 Mtetra
.661 .741 .909 r
.41447 .50568 .42086 .51203 .43172 .50867 .42536 .5023 Mtetra
.659 .74 .91 r
.42536 .5023 .43172 .50867 .44262 .50534 .43628 .49895 Mtetra
.656 .74 .911 r
.43628 .49895 .44262 .50534 .45357 .50207 .44725 .49567 Mtetra
.652 .739 .913 r
.44725 .49567 .45357 .50207 .46455 .4989 .45827 .49249 Mtetra
.645 .737 .916 r
.45827 .49249 .46455 .4989 .47558 .49588 .46933 .48949 Mtetra
.636 .736 .921 r
.46933 .48949 .47558 .49588 .48666 .49306 .48043 .48673 Mtetra
.621 .734 .927 r
.48043 .48673 .48666 .49306 .49779 .49052 .49158 .48431 Mtetra
.601 .732 .936 r
.49158 .48431 .49779 .49052 .50896 .48835 .50279 .48233 Mtetra
.571 .728 .948 r
.50279 .48233 .50896 .48835 .52019 .48662 .51404 .4809 Mtetra
.529 .724 .963 r
.51404 .4809 .52019 .48662 .53148 .4854 .52536 .48014 Mtetra
.467 .716 .977 r
.52536 .48014 .53148 .4854 .54283 .48473 .53675 .48012 Mtetra
.375 .698 .983 r
.53675 .48012 .54283 .48473 .55426 .48461 .54821 .48087 Mtetra
.238 .658 .96 r
.54821 .48087 .55426 .48461 .56576 .485 .55976 .48237 Mtetra
.052 .575 .87 r
.55976 .48237 .56576 .485 .57735 .48575 .5714 .4845 Mtetra
.153 0 0 r
.5714 .4845 .57735 .48575 .58902 .4867 .58314 .48704 Mtetra
.314 0 0 r
.58314 .48704 .58902 .4867 .60076 .48757 .59498 .4897 Mtetra
.402 0 0 r
.59498 .4897 .60076 .48757 .61258 .48809 .6069 .49209 Mtetra
.432 0 0 r
.6069 .49209 .61258 .48809 .62446 .48794 .6189 .49379 Mtetra
.427 0 0 r
.6189 .49379 .62446 .48794 .63638 .48684 .63095 .49438 Mtetra
.401 0 .057 r
.63095 .49438 .63638 .48684 .64833 .48458 .64303 .49351 Mtetra
.361 0 .088 r
.64303 .49351 .64833 .48458 .66029 .48102 .65512 .49094 Mtetra
.311 0 .095 r
.65512 .49094 .66029 .48102 .67224 .47615 .66719 .48654 Mtetra
.249 0 .083 r
.66719 .48654 .67224 .47615 .68417 .47008 .67923 .48039 Mtetra
.176 0 .048 r
.67923 .48039 .68417 .47008 .69609 .46299 .69122 .47268 Mtetra
.087 0 0 r
.69122 .47268 .69609 .46299 .70799 .45516 .70317 .46374 Mtetra
0 0 0 r
.70317 .46374 .70799 .45516 .71989 .44688 .71509 .45399 Mtetra
.71509 .45399 .71989 .44688 .7318 .43847 .72699 .44384 Mtetra
.72699 .44384 .7318 .43847 .74374 .43018 .7389 .43369 Mtetra
.5 .853 .598 r
.7389 .43369 .74374 .43018 .75572 .42222 .75083 .42386 Mtetra
.645 .958 .772 r
.75083 .42386 .75572 .42222 .76775 .41474 .76282 .41461 Mtetra
.727 .988 .884 r
.76282 .41461 .76775 .41474 .77986 .40779 .77487 .40608 Mtetra
.754 .963 .935 r
.77487 .40608 .77986 .40779 .79204 .40141 .78701 .39832 Mtetra
.75 .917 .948 r
.78701 .39832 .79204 .40141 .8043 .39554 .79923 .39132 Mtetra
.734 .872 .945 r
.79923 .39132 .8043 .39554 .81664 .39013 .81155 .385 Mtetra
.717 .834 .937 r
.81155 .385 .81664 .39013 .82906 .38511 .82396 .37927 Mtetra
.702 .805 .929 r
.82396 .37927 .82906 .38511 .84156 .38038 .83646 .37402 Mtetra
.69 .784 .923 r
.83646 .37402 .84156 .38038 .85414 .37588 .84904 .36913 Mtetra
.681 .769 .918 r
.84904 .36913 .85414 .37588 .86678 .37153 .8617 .3645 Mtetra
.675 .759 .914 r
.8617 .3645 .86678 .37153 .87949 .36729 .87443 .36007 Mtetra
.671 .752 .912 r
.87443 .36007 .87949 .36729 .89226 .36311 .88723 .35576 Mtetra
.668 .748 .91 r
.88723 .35576 .89226 .36311 .90509 .35897 .9001 .35152 Mtetra
.666 .745 .909 r
.9001 .35152 .90509 .35897 .91799 .35485 .91303 .34732 Mtetra
.664 .741 .908 r
.32228 .52658 .32893 .53277 .33948 .52942 .33285 .5232 Mtetra
.33285 .5232 .33948 .52942 .35006 .52606 .34346 .51982 Mtetra
.34346 .51982 .35006 .52606 .36069 .52269 .35411 .51642 Mtetra
.663 .741 .908 r
.35411 .51642 .36069 .52269 .37136 .5193 .36481 .513 Mtetra
.36481 .513 .37136 .5193 .38207 .5159 .37555 .50958 Mtetra
.37555 .50958 .38207 .5159 .39283 .5125 .38633 .50615 Mtetra
.38633 .50615 .39283 .5125 .40363 .50909 .39716 .50271 Mtetra
.662 .741 .908 r
.39716 .50271 .40363 .50909 .41447 .50568 .40803 .49928 Mtetra
.661 .74 .909 r
.40803 .49928 .41447 .50568 .42536 .5023 .41894 .49587 Mtetra
.659 .74 .909 r
.41894 .49587 .42536 .5023 .43628 .49895 .4299 .49249 Mtetra
.656 .739 .911 r
.4299 .49249 .43628 .49895 .44725 .49567 .4409 .48918 Mtetra
.652 .738 .912 r
.4409 .48918 .44725 .49567 .45827 .49249 .45194 .48599 Mtetra
.645 .736 .915 r
.45194 .48599 .45827 .49249 .46933 .48949 .46303 .48298 Mtetra
.634 .733 .919 r
.46303 .48298 .46933 .48949 .48043 .48673 .47416 .48024 Mtetra
.619 .729 .926 r
.47416 .48024 .48043 .48673 .49158 .48431 .48534 .47788 Mtetra
.596 .724 .934 r
.48534 .47788 .49158 .48431 .50279 .48233 .49656 .47603 Mtetra
.562 .717 .945 r
.49656 .47603 .50279 .48233 .51404 .4809 .50784 .47483 Mtetra
.514 .706 .958 r
.50784 .47483 .51404 .4809 .52536 .48014 .51919 .47443 Mtetra
.443 .688 .969 r
.51919 .47443 .52536 .48014 .53675 .48012 .5306 .47495 Mtetra
.336 .657 .971 r
.5306 .47495 .53675 .48012 .54821 .48087 .5421 .47649 Mtetra
.179 .598 .941 r
.5421 .47649 .54821 .48087 .55976 .48237 .55369 .47905 Mtetra
0 .491 .839 r
.55369 .47905 .55976 .48237 .5714 .4845 .56538 .48253 Mtetra
.256 0 0 r
.56538 .48253 .5714 .4845 .58314 .48704 .57719 .48674 Mtetra
.423 0 0 r
.57719 .48674 .58314 .48704 .59498 .4897 .58911 .49134 Mtetra
.507 0 0 r
.58911 .49134 .59498 .4897 .6069 .49209 .60113 .49587 Mtetra
.529 .009 0 r
.60113 .49587 .6069 .49209 .6189 .49379 .61325 .4998 Mtetra
.516 .039 .06 r
.61325 .4998 .6189 .49379 .63095 .49438 .62545 .50257 Mtetra
.483 .042 .122 r
.62545 .50257 .63095 .49438 .64303 .49351 .63768 .50365 Mtetra
.438 .026 .158 r
.63768 .50365 .64303 .49351 .65512 .49094 .64992 .50263 Mtetra
.384 0 .173 r
.64992 .50263 .65512 .49094 .66719 .48654 .66214 .49927 Mtetra
.323 0 .171 r
.66214 .49927 .66719 .48654 .67923 .48039 .67431 .49351 Mtetra
.254 0 .152 r
.67431 .49351 .67923 .48039 .69122 .47268 .68641 .48554 Mtetra
.176 0 .116 r
.68641 .48554 .69122 .47268 .70317 .46374 .69844 .47571 Mtetra
.084 0 .057 r
.69844 .47571 .70317 .46374 .71509 .45399 .7104 .46453 Mtetra
0 0 0 r
.7104 .46453 .71509 .45399 .72699 .44384 .7223 .45254 Mtetra
.7223 .45254 .72699 .44384 .7389 .43369 .73418 .4403 Mtetra
.73418 .4403 .7389 .43369 .75083 .42386 .74607 .42829 Mtetra
.501 .826 .524 r
.74607 .42829 .75083 .42386 .76282 .41461 .758 .41689 Mtetra
.654 .949 .718 r
.758 .41689 .76282 .41461 .77487 .40608 .76998 .40637 Mtetra
.744 .993 .853 r
.76998 .40637 .77487 .40608 .78701 .39832 .78205 .39684 Mtetra
.772 .973 .92 r
.78205 .39684 .78701 .39832 .79923 .39132 .79422 .38834 Mtetra
.764 .926 .941 r
.79422 .38834 .79923 .39132 .81155 .385 .80649 .38079 Mtetra
.744 .878 .941 r
.80649 .38079 .81155 .385 .82396 .37927 .81887 .3741 Mtetra
.724 .838 .935 r
.81887 .3741 .82396 .37927 .83646 .37402 .83135 .3681 Mtetra
.706 .807 .928 r
.83135 .3681 .83646 .37402 .84904 .36913 .84393 .36267 Mtetra
.692 .785 .922 r
.84393 .36267 .84904 .36913 .8617 .3645 .8566 .35765 Mtetra
.682 .769 .917 r
.8566 .35765 .8617 .3645 .87443 .36007 .86935 .35294 Mtetra
.676 .759 .914 r
.86935 .35294 .87443 .36007 .88723 .35576 .88217 .34844 Mtetra
.671 .752 .911 r
.88217 .34844 .88723 .35576 .9001 .35152 .89507 .34406 Mtetra
.668 .748 .91 r
.89507 .34406 .9001 .35152 .91303 .34732 .90803 .33977 Mtetra
.664 .741 .908 r
.31558 .52034 .32228 .52658 .33285 .5232 .32617 .51694 Mtetra
.32617 .51694 .33285 .5232 .34346 .51982 .33681 .51353 Mtetra
.33681 .51353 .34346 .51982 .35411 .51642 .34749 .5101 Mtetra
.663 .741 .908 r
.34749 .5101 .35411 .51642 .36481 .513 .35821 .50666 Mtetra
.35821 .50666 .36481 .513 .37555 .50958 .36898 .50321 Mtetra
.36898 .50321 .37555 .50958 .38633 .50615 .37979 .49975 Mtetra
.37979 .49975 .38633 .50615 .39716 .50271 .39064 .49629 Mtetra
.662 .741 .908 r
.39064 .49629 .39716 .50271 .40803 .49928 .40154 .49283 Mtetra
.661 .74 .909 r
.40154 .49283 .40803 .49928 .41894 .49587 .41248 .48938 Mtetra
.66 .74 .909 r
.41248 .48938 .41894 .49587 .4299 .49249 .42347 .48597 Mtetra
.657 .739 .91 r
.42347 .48597 .4299 .49249 .4409 .48918 .43449 .48263 Mtetra
.652 .737 .912 r
.43449 .48263 .4409 .48918 .45194 .48599 .44556 .4794 Mtetra
.645 .735 .914 r
.44556 .4794 .45194 .48599 .46303 .48298 .45668 .47635 Mtetra
.635 .731 .918 r
.45668 .47635 .46303 .48298 .47416 .48024 .46784 .47358 Mtetra
.618 .725 .923 r
.46784 .47358 .47416 .48024 .48534 .47788 .47904 .47121 Mtetra
.595 .718 .93 r
.47904 .47121 .48534 .47788 .49656 .47603 .49029 .46939 Mtetra
.56 .706 .939 r
.49029 .46939 .49656 .47603 .50784 .47483 .5016 .4683 Mtetra
.51 .69 .949 r
.5016 .4683 .50784 .47483 .51919 .47443 .51297 .46811 Mtetra
.437 .664 .958 r
.51297 .46811 .51919 .47443 .5306 .47495 .52441 .469 Mtetra
.329 .624 .958 r
.52441 .469 .5306 .47495 .5421 .47649 .53593 .47111 Mtetra
.174 .556 .932 r
.53593 .47111 .5421 .47649 .55369 .47905 .54755 .47452 Mtetra
0 .448 .849 r
.54755 .47452 .55369 .47905 .56538 .48253 .55929 .47917 Mtetra
0 .297 .683 r
.55929 .47917 .56538 .48253 .57719 .48674 .57114 .48489 Mtetra
.454 0 0 r
.57114 .48489 .57719 .48674 .58911 .49134 .58313 .49136 Mtetra
.56 0 0 r
.58313 .49136 .58911 .49134 .60113 .49587 .59525 .49807 Mtetra
.595 .056 0 r
.59525 .49807 .60113 .49587 .61325 .4998 .60748 .50441 Mtetra
.584 .087 .041 r
.60748 .50441 .61325 .4998 .62545 .50257 .61981 .50968 Mtetra
.547 .089 .117 r
.61981 .50968 .62545 .50257 .63768 .50365 .6322 .51317 Mtetra
.494 .07 .164 r
.6322 .51317 .63768 .50365 .64992 .50263 .64461 .51428 Mtetra
.433 .038 .188 r
.64461 .51428 .64992 .50263 .66214 .49927 .65701 .51256 Mtetra
.364 0 .195 r
.65701 .51256 .66214 .49927 .67431 .49351 .66934 .50784 Mtetra
.29 0 .186 r
.66934 .50784 .67431 .49351 .68641 .48554 .68158 .50017 Mtetra
.21 0 .161 r
.68158 .50017 .68641 .48554 .69844 .47571 .69371 .48991 Mtetra
.122 0 .12 r
.69371 .48991 .69844 .47571 .7104 .46453 .70574 .47761 Mtetra
.022 0 .057 r
.70574 .47761 .7104 .46453 .7223 .45254 .71768 .46394 Mtetra
0 0 0 r
.71768 .46394 .7223 .45254 .73418 .4403 .72955 .44961 Mtetra
.72955 .44961 .73418 .4403 .74607 .42829 .74141 .43528 Mtetra
.74141 .43528 .74607 .42829 .758 .41689 .75327 .42151 Mtetra
.562 .851 .524 r
.75327 .42151 .758 .41689 .76998 .40637 .76519 .40869 Mtetra
.701 .962 .713 r
.76519 .40869 .76998 .40637 .78205 .39684 .77718 .39706 Mtetra
.776 .997 .845 r
.77718 .39706 .78205 .39684 .79422 .38834 .78927 .38673 Mtetra
.791 .973 .911 r
.78927 .38673 .79422 .38834 .80649 .38079 .80148 .37764 Mtetra
.776 .925 .934 r
.80148 .37764 .80649 .38079 .81887 .3741 .81381 .36971 Mtetra
.751 .876 .936 r
.81381 .36971 .81887 .3741 .83135 .3681 .82626 .36275 Mtetra
.727 .836 .932 r
.82626 .36275 .83135 .3681 .84393 .36267 .83882 .35659 Mtetra
.708 .805 .925 r
.83882 .35659 .84393 .36267 .8566 .35765 .85148 .35104 Mtetra
.693 .783 .92 r
.85148 .35104 .8566 .35765 .86935 .35294 .86424 .34595 Mtetra
.683 .768 .916 r
.86424 .34595 .86935 .35294 .88217 .34844 .87709 .34118 Mtetra
.675 .758 .913 r
.87709 .34118 .88217 .34844 .89507 .34406 .89001 .33662 Mtetra
.671 .751 .911 r
.89001 .33662 .89507 .34406 .90803 .33977 .90301 .3322 Mtetra
.664 .741 .908 r
.30883 .51405 .31558 .52034 .32617 .51694 .31945 .51063 Mtetra
.31945 .51063 .32617 .51694 .33681 .51353 .33011 .50719 Mtetra
.33011 .50719 .33681 .51353 .34749 .5101 .34082 .50374 Mtetra
.663 .741 .908 r
.34082 .50374 .34749 .5101 .35821 .50666 .35157 .50027 Mtetra
.35157 .50027 .35821 .50666 .36898 .50321 .36236 .4968 Mtetra
.36236 .4968 .36898 .50321 .37979 .49975 .3732 .49331 Mtetra
.3732 .49331 .37979 .49975 .39064 .49629 .38408 .48982 Mtetra
.38408 .48982 .39064 .49629 .40154 .49283 .395 .48633 Mtetra
.662 .74 .908 r
.395 .48633 .40154 .49283 .41248 .48938 .40597 .48284 Mtetra
.66 .74 .909 r
.40597 .48284 .41248 .48938 .42347 .48597 .41698 .47939 Mtetra
.658 .739 .91 r
.41698 .47939 .42347 .48597 .43449 .48263 .42804 .476 Mtetra
.653 .737 .911 r
.42804 .476 .43449 .48263 .44556 .4794 .43914 .47272 Mtetra
.647 .734 .913 r
.43914 .47272 .44556 .4794 .45668 .47635 .45028 .46961 Mtetra
.637 .729 .915 r
.45028 .46961 .45668 .47635 .46784 .47358 .46147 .46676 Mtetra
.621 .723 .919 r
.46147 .46676 .46784 .47358 .47904 .47121 .4727 .46432 Mtetra
.598 .713 .924 r
.4727 .46432 .47904 .47121 .49029 .46939 .48398 .46243 Mtetra
.565 .699 .931 r
.48398 .46243 .49029 .46939 .5016 .4683 .49531 .46129 Mtetra
.517 .678 .938 r
.49531 .46129 .5016 .4683 .51297 .46811 .5067 .46112 Mtetra
.448 .648 .944 r
.5067 .46112 .51297 .46811 .52441 .469 .51816 .46213 Mtetra
.35 .602 .943 r
.51816 .46213 .52441 .469 .53593 .47111 .52971 .46451 Mtetra
.214 .535 .924 r
.52971 .46451 .53593 .47111 .54755 .47452 .54135 .46841 Mtetra
.034 .439 .871 r
.54135 .46841 .54755 .47452 .55929 .47917 .55311 .47385 Mtetra
0 .311 .764 r
.55311 .47385 .55929 .47917 .57114 .48489 .565 .48071 Mtetra
0 .168 .6 r
.565 .48071 .57114 .48489 .58313 .49136 .57704 .4887 Mtetra
.534 0 0 r
.57704 .4887 .58313 .49136 .59525 .49807 .58922 .49733 Mtetra
.613 .046 0 r
.58922 .49733 .59525 .49807 .60748 .50441 .60155 .50595 Mtetra
.629 .089 0 r
.60155 .50595 .60748 .50441 .61981 .50968 .614 .51374 Mtetra
.601 .095 .022 r
.614 .51374 .61981 .50968 .6322 .51317 .62653 .51986 Mtetra
.544 .075 .093 r
.62653 .51986 .6322 .51317 .64461 .51428 .63911 .5235 Mtetra
.469 .037 .136 r
.63911 .5235 .64461 .51428 .65701 .51256 .65168 .524 Mtetra
.384 0 .156 r
.65168 .524 .65701 .51256 .66934 .50784 .66419 .52096 Mtetra
.294 0 .157 r
.66419 .52096 .66934 .50784 .68158 .50017 .6766 .51432 Mtetra
.2 0 .142 r
.6766 .51432 .68158 .50017 .69371 .48991 .68888 .50431 Mtetra
.103 0 .11 r
.68888 .50431 .69371 .48991 .70574 .47761 .70101 .49149 Mtetra
0 0 .06 r
.70101 .49149 .70574 .47761 .71768 .46394 .71302 .4766 Mtetra
0 0 0 r
.71302 .4766 .71768 .46394 .72955 .44961 .72492 .4605 Mtetra
.72492 .4605 .72955 .44961 .74141 .43528 .73676 .44401 Mtetra
.73676 .44401 .74141 .43528 .75327 .42151 .74859 .42787 Mtetra
.74859 .42787 .75327 .42151 .76519 .40869 .76044 .41267 Mtetra
.67 .912 .588 r
.76044 .41267 .76519 .40869 .77718 .39706 .77235 .39877 Mtetra
.77 .987 .749 r
.77235 .39877 .77718 .39706 .78927 .38673 .78437 .38638 Mtetra
.811 .996 .857 r
.78437 .38638 .78927 .38673 .80148 .37764 .79651 .37553 Mtetra
.807 .962 .91 r
.79651 .37553 .80148 .37764 .81381 .36971 .80878 .36612 Mtetra
.782 .913 .929 r
.80878 .36612 .81381 .36971 .82626 .36275 .82118 .35799 Mtetra
.753 .866 .931 r
.82118 .35799 .82626 .36275 .83882 .35659 .83371 .35093 Mtetra
.727 .828 .927 r
.83371 .35093 .83882 .35659 .85148 .35104 .84636 .34471 Mtetra
.707 .799 .922 r
.84636 .34471 .85148 .35104 .86424 .34595 .85912 .33913 Mtetra
.692 .779 .918 r
.85912 .33913 .86424 .34595 .87709 .34118 .87197 .33401 Mtetra
.682 .765 .914 r
.87197 .33401 .87709 .34118 .89001 .33662 .88492 .32922 Mtetra
.675 .756 .912 r
.88492 .32922 .89001 .33662 .90301 .3322 .89794 .32463 Mtetra
.664 .741 .908 r
.30203 .50772 .30883 .51405 .31945 .51063 .31267 .50427 Mtetra
.31267 .50427 .31945 .51063 .33011 .50719 .32336 .50081 Mtetra
.32336 .50081 .33011 .50719 .34082 .50374 .33409 .49733 Mtetra
.663 .741 .908 r
.33409 .49733 .34082 .50374 .35157 .50027 .34487 .49384 Mtetra
.34487 .49384 .35157 .50027 .36236 .4968 .35569 .49033 Mtetra
.35569 .49033 .36236 .4968 .3732 .49331 .36656 .48682 Mtetra
.36656 .48682 .3732 .49331 .38408 .48982 .37746 .4833 Mtetra
.37746 .4833 .38408 .48982 .395 .48633 .38842 .47977 Mtetra
.662 .74 .908 r
.38842 .47977 .395 .48633 .40597 .48284 .39941 .47625 Mtetra
.661 .74 .909 r
.39941 .47625 .40597 .48284 .41698 .47939 .41045 .47276 Mtetra
.658 .739 .909 r
.41045 .47276 .41698 .47939 .42804 .476 .42154 .46931 Mtetra
.655 .737 .91 r
.42154 .46931 .42804 .476 .43914 .47272 .43267 .46596 Mtetra
.649 .734 .911 r
.43267 .46596 .43914 .47272 .45028 .46961 .44384 .46276 Mtetra
.64 .729 .913 r
.44384 .46276 .45028 .46961 .46147 .46676 .45506 .45981 Mtetra
.626 .722 .916 r
.45506 .45981 .46147 .46676 .4727 .46432 .46632 .45722 Mtetra
.605 .711 .919 r
.46632 .45722 .4727 .46432 .48398 .46243 .47762 .45517 Mtetra
.575 .695 .923 r
.47762 .45517 .48398 .46243 .49531 .46129 .48898 .45385 Mtetra
.531 .672 .927 r
.48898 .45385 .49531 .46129 .5067 .46112 .50039 .45349 Mtetra
.471 .639 .93 r
.50039 .45349 .5067 .46112 .51816 .46213 .51188 .45435 Mtetra
.388 .593 .927 r
.51188 .45435 .51816 .46213 .52971 .46451 .52344 .45665 Mtetra
.277 .531 .913 r
.52344 .45665 .52971 .46451 .54135 .46841 .53509 .46061 Mtetra
.138 .448 .881 r
.53509 .46061 .54135 .46841 .55311 .47385 .54687 .46632 Mtetra
0 .349 .824 r
.54687 .46632 .55311 .47385 .565 .48071 .55877 .47374 Mtetra
0 .239 .738 r
.55877 .47374 .565 .48071 .57704 .4887 .57084 .48266 Mtetra
0 .133 .626 r
.57084 .48266 .57704 .4887 .58922 .49733 .58306 .49264 Mtetra
.493 0 0 r
.58306 .49264 .58922 .49733 .60155 .50595 .59544 .50304 Mtetra
.575 .01 0 r
.59544 .50304 .60155 .50595 .614 .51374 .60798 .51301 Mtetra
.6 .028 0 r
.60798 .51301 .614 .51374 .62653 .51986 .62063 .5216 Mtetra
.566 .01 0 r
.62063 .5216 .62653 .51986 .63911 .5235 .63335 .52784 Mtetra
.485 0 0 r
.63335 .52784 .63911 .5235 .65168 .524 .64608 .53088 Mtetra
.372 0 0 r
.64608 .53088 .65168 .524 .66419 .52096 .65877 .53008 Mtetra
.247 0 .014 r
.65877 .53008 .66419 .52096 .6766 .51432 .67136 .52516 Mtetra
.121 0 .017 r
.67136 .52516 .6766 .51432 .68888 .50431 .68381 .51621 Mtetra
0 0 0 r
.68381 .51621 .68888 .50431 .70101 .49149 .69609 .50369 Mtetra
.69609 .50369 .70101 .49149 .71302 .4766 .7082 .48835 Mtetra
.7082 .48835 .71302 .4766 .72492 .4605 .72018 .47112 Mtetra
.72018 .47112 .72492 .4605 .73676 .44401 .73204 .45298 Mtetra
.73204 .45298 .73676 .44401 .74859 .42787 .74386 .43484 Mtetra
.585 .802 .397 r
.74386 .43484 .74859 .42787 .76044 .41267 .75567 .41745 Mtetra
.7 .903 .543 r
.75567 .41745 .76044 .41267 .77235 .39877 .76753 .40136 Mtetra
.788 .974 .686 r
.76753 .40136 .77235 .39877 .78437 .38638 .77948 .3869 Mtetra
.834 .999 .802 r
.77948 .3869 .78437 .38638 .79651 .37553 .79154 .37419 Mtetra
.837 .981 .874 r
.79154 .37419 .79651 .37553 .80878 .36612 .80375 .36319 Mtetra
.813 .939 .911 r
.80375 .36319 .80878 .36612 .82118 .35799 .8161 .35376 Mtetra
.781 .892 .923 r
.8161 .35376 .82118 .35799 .83371 .35093 .82859 .34566 Mtetra
.749 .85 .925 r
.82859 .34566 .83371 .35093 .84636 .34471 .84122 .33865 Mtetra
.723 .816 .922 r
.84122 .33865 .84636 .34471 .85912 .33913 .85397 .33249 Mtetra
.704 .791 .919 r
.85397 .33249 .85912 .33913 .87197 .33401 .86683 .32695 Mtetra
.69 .773 .915 r
.86683 .32695 .87197 .33401 .88492 .32922 .87979 .32186 Mtetra
.68 .761 .913 r
.87979 .32186 .88492 .32922 .89794 .32463 .89284 .31707 Mtetra
.664 .741 .908 r
.29517 .50134 .30203 .50772 .31267 .50427 .30585 .49786 Mtetra
.30585 .49786 .31267 .50427 .32336 .50081 .31656 .49437 Mtetra
.31656 .49437 .32336 .50081 .33409 .49733 .32732 .49087 Mtetra
.32732 .49087 .33409 .49733 .34487 .49384 .33812 .48735 Mtetra
.663 .741 .908 r
.33812 .48735 .34487 .49384 .35569 .49033 .34897 .48382 Mtetra
.34897 .48382 .35569 .49033 .36656 .48682 .35986 .48028 Mtetra
.35986 .48028 .36656 .48682 .37746 .4833 .3708 .47673 Mtetra
.3708 .47673 .37746 .4833 .38842 .47977 .38178 .47317 Mtetra
.662 .741 .908 r
.38178 .47317 .38842 .47977 .39941 .47625 .3928 .46961 Mtetra
.661 .74 .908 r
.3928 .46961 .39941 .47625 .41045 .47276 .40387 .46607 Mtetra
.66 .739 .909 r
.40387 .46607 .41045 .47276 .42154 .46931 .41499 .46257 Mtetra
.656 .737 .909 r
.41499 .46257 .42154 .46931 .43267 .46596 .42615 .45914 Mtetra
.652 .734 .91 r
.42615 .45914 .43267 .46596 .44384 .46276 .43735 .45584 Mtetra
.644 .73 .911 r
.43735 .45584 .44384 .46276 .45506 .45981 .4486 .45275 Mtetra
.632 .722 .913 r
.4486 .45275 .45506 .45981 .46632 .45722 .45989 .44999 Mtetra
.614 .711 .915 r
.45989 .44999 .46632 .45722 .47762 .45517 .47122 .44769 Mtetra
.588 .695 .917 r
.47122 .44769 .47762 .45517 .48898 .45385 .48261 .44607 Mtetra
.551 .672 .918 r
.48261 .44607 .48898 .45385 .50039 .45349 .49404 .44536 Mtetra
.5 .639 .917 r
.49404 .44536 .50039 .45349 .51188 .45435 .50554 .44581 Mtetra
.432 .595 .912 r
.50554 .44581 .51188 .45435 .52344 .45665 .51712 .4477 Mtetra
.346 .537 .899 r
.51712 .4477 .52344 .45665 .53509 .46061 .52879 .45126 Mtetra
.243 .467 .876 r
.52879 .45126 .53509 .46061 .54687 .46632 .54057 .45668 Mtetra
.129 .388 .842 r
.54057 .45668 .54687 .46632 .55877 .47374 .55248 .46399 Mtetra
.011 .308 .799 r
.55248 .46399 .55877 .47374 .57084 .48266 .56454 .47307 Mtetra
0 .235 .753 r
.56454 .47307 .57084 .48266 .58306 .49264 .57677 .48359 Mtetra
0 .179 .71 r
.57677 .48359 .58306 .49264 .59544 .50304 .58918 .49497 Mtetra
0 .148 .676 r
.58918 .49497 .59544 .50304 .60798 .51301 .60175 .5064 Mtetra
0 .15 .654 r
.60175 .5064 .60798 .51301 .62063 .5216 .61447 .5169 Mtetra
0 .195 .644 r
.61447 .5169 .62063 .5216 .63335 .52784 .62728 .52541 Mtetra
.292 0 0 r
.62728 .52541 .63335 .52784 .64608 .53088 .64015 .53091 Mtetra
.169 0 0 r
.64015 .53091 .64608 .53088 .65877 .53008 .65299 .53258 Mtetra
0 0 0 r
.65299 .53258 .65877 .53008 .67136 .52516 .66576 .5299 Mtetra
.66576 .5299 .67136 .52516 .68381 .51621 .67838 .52275 Mtetra
.67838 .52275 .68381 .51621 .69609 .50369 .69083 .51142 Mtetra
.69083 .51142 .69609 .50369 .7082 .48835 .70309 .49658 Mtetra
.70309 .49658 .7082 .48835 .72018 .47112 .71518 .47915 Mtetra
.71518 .47915 .72018 .47112 .73204 .45298 .72712 .46019 Mtetra
.664 .838 .422 r
.72712 .46019 .73204 .45298 .74386 .43484 .73897 .44074 Mtetra
.733 .89 .496 r
.73897 .44074 .74386 .43484 .75567 .41745 .75078 .42172 Mtetra
.797 .941 .587 r
.75078 .42172 .75567 .41745 .76753 .40136 .76262 .40383 Mtetra
.845 .98 .685 r
.76262 .40383 .76753 .40136 .77948 .3869 .77452 .38755 Mtetra
.87 .995 .775 r
.77452 .38755 .77948 .3869 .79154 .37419 .78654 .37312 Mtetra
.867 .983 .844 r
.78654 .37312 .79154 .37419 .80375 .36319 .7987 .36058 Mtetra
.842 .95 .888 r
.7987 .36058 .80375 .36319 .8161 .35376 .811 .34983 Mtetra
.807 .908 .91 r
.811 .34983 .8161 .35376 .82859 .34566 .82346 .34065 Mtetra
.772 .866 .918 r
.82346 .34065 .82859 .34566 .84122 .33865 .83606 .3328 Mtetra
.741 .83 .919 r
.83606 .3328 .84122 .33865 .85397 .33249 .8488 .32599 Mtetra
.717 .802 .918 r
.8488 .32599 .85397 .33249 .86683 .32695 .86167 .31998 Mtetra
.699 .781 .915 r
.86167 .31998 .86683 .32695 .87979 .32186 .87464 .31454 Mtetra
.686 .767 .913 r
.87464 .31454 .87979 .32186 .89284 .31707 .88771 .30951 Mtetra
.664 .741 .908 r
.28827 .49491 .29517 .50134 .30585 .49786 .29897 .49141 Mtetra
.29897 .49141 .30585 .49786 .31656 .49437 .30971 .48789 Mtetra
.30971 .48789 .31656 .49437 .32732 .49087 .3205 .48436 Mtetra
.3205 .48436 .32732 .49087 .33812 .48735 .33133 .48082 Mtetra
.663 .741 .908 r
.33133 .48082 .33812 .48735 .34897 .48382 .3422 .47726 Mtetra
.3422 .47726 .34897 .48382 .35986 .48028 .35312 .47369 Mtetra
.35312 .47369 .35986 .48028 .3708 .47673 .36408 .47011 Mtetra
.36408 .47011 .3708 .47673 .38178 .47317 .37509 .46652 Mtetra
.37509 .46652 .38178 .47317 .3928 .46961 .38615 .46292 Mtetra
.662 .74 .908 r
.38615 .46292 .3928 .46961 .40387 .46607 .39724 .45934 Mtetra
.661 .739 .908 r
.39724 .45934 .40387 .46607 .41499 .46257 .40839 .45578 Mtetra
.658 .738 .909 r
.40839 .45578 .41499 .46257 .42615 .45914 .41958 .45228 Mtetra
.654 .735 .909 r
.41958 .45228 .42615 .45914 .43735 .45584 .43081 .44887 Mtetra
.648 .731 .91 r
.43081 .44887 .43735 .45584 .4486 .45275 .44209 .44564 Mtetra
.638 .724 .91 r
.44209 .44564 .4486 .45275 .45989 .44999 .45341 .44266 Mtetra
.624 .714 .911 r
.45341 .44266 .45989 .44999 .47122 .44769 .46477 .44009 Mtetra
.602 .699 .911 r
.46477 .44009 .47122 .44769 .48261 .44607 .47619 .4381 Mtetra
.572 .677 .911 r
.47619 .4381 .48261 .44607 .49404 .44536 .48765 .43691 Mtetra
.53 .646 .907 r
.48765 .43691 .49404 .44536 .50554 .44581 .49918 .43677 Mtetra
.476 .605 .9 r
.49918 .43677 .50554 .44581 .51712 .4477 .51077 .43796 Mtetra
.41 .552 .887 r
.51077 .43796 .51712 .4477 .52879 .45126 .52244 .44075 Mtetra
.334 .491 .866 r
.52244 .44075 .52879 .45126 .54057 .45668 .53422 .44535 Mtetra
.253 .425 .839 r
.53422 .44535 .54057 .45668 .55248 .46399 .54612 .4519 Mtetra
.176 .361 .809 r
.54612 .4519 .55248 .46399 .56454 .47307 .55817 .46037 Mtetra
.111 .307 .781 r
.55817 .46037 .56454 .47307 .57677 .48359 .57038 .47053 Mtetra
.063 .27 .76 r
.57038 .47053 .57677 .48359 .58918 .49497 .58278 .48191 Mtetra
.04 .255 .753 r
.58278 .48191 .58918 .49497 .60175 .5064 .59535 .49381 Mtetra
.044 .268 .764 r
.59535 .49381 .60175 .5064 .61447 .5169 .60808 .50531 Mtetra
.081 .316 .795 r
.60808 .50531 .61447 .5169 .62728 .52541 .62094 .51534 Mtetra
.161 .407 .85 r
.62094 .51534 .62728 .52541 .64015 .53091 .63388 .52283 Mtetra
.293 .546 .92 r
.63388 .52283 .64015 .53091 .65299 .53258 .64683 .52678 Mtetra
.472 .723 .979 r
.64683 .52678 .65299 .53258 .66576 .5299 .65973 .52649 Mtetra
.656 .885 .981 r
.65973 .52649 .66576 .5299 .67838 .52275 .67252 .52162 Mtetra
.788 .976 .91 r
.67252 .52162 .67838 .52275 .69083 .51142 .68514 .51223 Mtetra
.852 .998 .809 r
.68514 .51223 .69083 .51142 .70309 .49658 .69757 .49883 Mtetra
.876 .988 .722 r
.69757 .49883 .70309 .49658 .71518 .47915 .7098 .48225 Mtetra
.885 .974 .668 r
.7098 .48225 .71518 .47915 .72712 .46019 .72187 .46351 Mtetra
.892 .967 .646 r
.72187 .46351 .72712 .46019 .73897 .44074 .73381 .44373 Mtetra
.9 .968 .652 r
.73381 .44373 .73897 .44074 .75078 .42172 .74568 .42391 Mtetra
.908 .974 .681 r
.74568 .42391 .75078 .42172 .76262 .40383 .75754 .40491 Mtetra
.913 .98 .726 r
.75754 .40491 .76262 .40383 .77452 .38755 .76944 .38734 Mtetra
.91 .979 .779 r
.76944 .38734 .77452 .38755 .78654 .37312 .78144 .37157 Mtetra
.893 .967 .828 r
.78144 .37157 .78654 .37312 .7987 .36058 .79357 .35775 Mtetra
.865 .942 .867 r
.79357 .35775 .7987 .36058 .811 .34983 .80584 .34584 Mtetra
.829 .908 .893 r
.80584 .34584 .811 .34983 .82346 .34065 .81827 .33566 Mtetra
.792 .872 .907 r
.81827 .33566 .82346 .34065 .83606 .3328 .83086 .32699 Mtetra
.758 .838 .913 r
.83086 .32699 .83606 .3328 .8488 .32599 .84359 .31954 Mtetra
.73 .81 .914 r
.84359 .31954 .8488 .32599 .86167 .31998 .85646 .31304 Mtetra
.708 .788 .914 r
.85646 .31304 .86167 .31998 .87464 .31454 .86945 .30724 Mtetra
.693 .772 .912 r
.86945 .30724 .87464 .31454 .88771 .30951 .88254 .30194 Mtetra
.664 .741 .908 r
.28131 .48843 .28827 .49491 .29897 .49141 .29204 .48491 Mtetra
.29204 .48491 .29897 .49141 .30971 .48789 .30281 .48136 Mtetra
.30281 .48136 .30971 .48789 .3205 .48436 .31362 .47781 Mtetra
.31362 .47781 .3205 .48436 .33133 .48082 .32448 .47423 Mtetra
.32448 .47423 .33133 .48082 .3422 .47726 .33538 .47065 Mtetra
.663 .741 .908 r
.33538 .47065 .3422 .47726 .35312 .47369 .34632 .46705 Mtetra
.34632 .46705 .35312 .47369 .36408 .47011 .35732 .46344 Mtetra
.35732 .46344 .36408 .47011 .37509 .46652 .36835 .45982 Mtetra
.36835 .45982 .37509 .46652 .38615 .46292 .37944 .45619 Mtetra
.662 .74 .908 r
.37944 .45619 .38615 .46292 .39724 .45934 .39056 .45256 Mtetra
.661 .74 .908 r
.39056 .45256 .39724 .45934 .40839 .45578 .40174 .44895 Mtetra
.66 .738 .908 r
.40174 .44895 .40839 .45578 .41958 .45228 .41296 .44537 Mtetra
.657 .736 .908 r
.41296 .44537 .41958 .45228 .43081 .44887 .42422 .44187 Mtetra
.652 .733 .908 r
.42422 .44187 .43081 .44887 .44209 .44564 .43553 .43849 Mtetra
.644 .727 .909 r
.43553 .43849 .44209 .44564 .45341 .44266 .44688 .43531 Mtetra
.633 .718 .908 r
.44688 .43531 .45341 .44266 .46477 .44009 .45828 .43245 Mtetra
.616 .704 .908 r
.45828 .43245 .46477 .44009 .47619 .4381 .46972 .43006 Mtetra
.592 .685 .906 r
.46972 .43006 .47619 .4381 .48765 .43691 .48122 .42834 Mtetra
.56 .657 .901 r
.48122 .42834 .48765 .43691 .49918 .43677 .49277 .4275 Mtetra
.517 .62 .893 r
.49277 .4275 .49918 .43677 .51077 .43796 .50438 .42783 Mtetra
.466 .574 .879 r
.50438 .42783 .51077 .43796 .52244 .44075 .51606 .42958 Mtetra
.407 .519 .859 r
.51606 .42958 .52244 .44075 .53422 .44535 .52784 .433 Mtetra
.347 .461 .834 r
.52784 .433 .53422 .44535 .54612 .4519 .53973 .43827 Mtetra
.293 .405 .806 r
.53973 .43827 .54612 .4519 .55817 .46037 .55176 .44545 Mtetra
.249 .358 .779 r
.55176 .44545 .55817 .46037 .57038 .47053 .56393 .45441 Mtetra
.223 .325 .758 r
.56393 .45441 .57038 .47053 .58278 .48191 .57628 .46485 Mtetra
.216 .31 .746 r
.57628 .46485 .58278 .48191 .59535 .49381 .58881 .47617 Mtetra
.23 .314 .743 r
.58881 .47617 .59535 .49381 .60808 .50531 .60151 .4876 Mtetra
.267 .338 .751 r
.60151 .4876 .60808 .50531 .62094 .51534 .61436 .49815 Mtetra
.327 .383 .767 r
.61436 .49815 .62094 .51534 .63388 .52283 .62731 .50676 Mtetra
.407 .448 .79 r
.62731 .50676 .63388 .52283 .64683 .52678 .64032 .5124 Mtetra
.506 .529 .814 r
.64032 .5124 .64683 .52678 .65973 .52649 .65331 .51423 Mtetra
.614 .62 .833 r
.65331 .51423 .65973 .52649 .67252 .52162 .66621 .5117 Mtetra
.72 .71 .84 r
.66621 .5117 .67252 .52162 .68514 .51223 .67898 .50468 Mtetra
.811 .788 .831 r
.67898 .50468 .68514 .51223 .69757 .49883 .69158 .49344 Mtetra
.878 .846 .809 r
.69158 .49344 .69757 .49883 .7098 .48225 .70398 .47863 Mtetra
.919 .885 .783 r
.70398 .47863 .7098 .48225 .72187 .46351 .7162 .46117 Mtetra
.941 .909 .761 r
.7162 .46117 .72187 .46351 .73381 .44373 .72828 .44213 Mtetra
.948 .923 .749 r
.72828 .44213 .73381 .44373 .74568 .42391 .74026 .42253 Mtetra
.947 .932 .75 r
.74026 .42253 .74568 .42391 .75754 .40491 .75219 .40332 Mtetra
.94 .937 .765 r
.75219 .40332 .75754 .40491 .76944 .38734 .76415 .38522 Mtetra
.926 .936 .79 r
.76415 .38522 .76944 .38734 .78144 .37157 .77618 .36872 Mtetra
.904 .93 .821 r
.77618 .36872 .78144 .37157 .79357 .35775 .78831 .35407 Mtetra
.876 .914 .851 r
.78831 .35407 .79357 .35775 .80584 .34584 .80059 .34132 Mtetra
.841 .892 .876 r
.80059 .34132 .80584 .34584 .81827 .33566 .81302 .33037 Mtetra
.805 .865 .893 r
.81302 .33037 .81827 .33566 .83086 .32699 .8256 .32101 Mtetra
.77 .837 .903 r
.8256 .32101 .83086 .32699 .84359 .31954 .83834 .31299 Mtetra
.741 .812 .908 r
.83834 .31299 .84359 .31954 .85646 .31304 .85121 .30603 Mtetra
.717 .791 .91 r
.85121 .30603 .85646 .31304 .86945 .30724 .86421 .29989 Mtetra
.699 .775 .91 r
.86421 .29989 .86945 .30724 .88254 .30194 .87733 .29433 Mtetra
.664 .741 .908 r
.27431 .48191 .28131 .48843 .29204 .48491 .28506 .47835 Mtetra
.28506 .47835 .29204 .48491 .30281 .48136 .29585 .47478 Mtetra
.29585 .47478 .30281 .48136 .31362 .47781 .30669 .4712 Mtetra
.30669 .4712 .31362 .47781 .32448 .47423 .31758 .4676 Mtetra
.31758 .4676 .32448 .47423 .33538 .47065 .3285 .46399 Mtetra
.3285 .46399 .33538 .47065 .34632 .46705 .33948 .46036 Mtetra
.663 .741 .908 r
.33948 .46036 .34632 .46705 .35732 .46344 .3505 .45672 Mtetra
.3505 .45672 .35732 .46344 .36835 .45982 .36156 .45307 Mtetra
.36156 .45307 .36835 .45982 .37944 .45619 .37267 .4494 Mtetra
.37267 .4494 .37944 .45619 .39056 .45256 .38383 .44574 Mtetra
.662 .74 .908 r
.38383 .44574 .39056 .45256 .40174 .44895 .39503 .44207 Mtetra
.661 .739 .908 r
.39503 .44207 .40174 .44895 .41296 .44537 .40628 .43843 Mtetra
.659 .737 .908 r
.40628 .43843 .41296 .44537 .42422 .44187 .41758 .43484 Mtetra
.655 .735 .908 r
.41758 .43484 .42422 .44187 .43553 .43849 .42892 .43133 Mtetra
.65 .73 .908 r
.42892 .43133 .43553 .43849 .44688 .43531 .4403 .42797 Mtetra
.641 .723 .907 r
.4403 .42797 .44688 .43531 .45828 .43245 .45173 .42484 Mtetra
.629 .711 .906 r
.45173 .42484 .45828 .43245 .46972 .43006 .46321 .42207 Mtetra
.611 .695 .903 r
.46321 .42207 .46972 .43006 .48122 .42834 .47474 .41982 Mtetra
.586 .671 .898 r
.47474 .41982 .48122 .42834 .49277 .4275 .48631 .41827 Mtetra
.553 .639 .89 r
.48631 .41827 .49277 .4275 .50438 .42783 .49795 .41768 Mtetra
.513 .599 .877 r
.49795 .41768 .50438 .42783 .51606 .42958 .50965 .41827 Mtetra
.468 .551 .858 r
.50965 .41827 .51606 .42958 .52784 .433 .52143 .42031 Mtetra
.421 .499 .833 r
.52143 .42031 .52784 .433 .53973 .43827 .53331 .42399 Mtetra
.378 .447 .806 r
.53331 .42399 .53973 .43827 .55176 .44545 .54531 .42942 Mtetra
.344 .403 .779 r
.54531 .42942 .55176 .44545 .56393 .45441 .55745 .4366 Mtetra
.323 .369 .755 r
.55745 .4366 .56393 .45441 .57628 .46485 .56975 .44532 Mtetra
.318 .349 .736 r
.56975 .44532 .57628 .46485 .58881 .47617 .58221 .45516 Mtetra
.328 .344 .725 r
.58221 .45516 .58881 .47617 .60151 .4876 .59484 .4655 Mtetra
.353 .353 .72 r
.59484 .4655 .60151 .4876 .61436 .49815 .60763 .4755 Mtetra
.392 .375 .72 r
.60763 .4755 .61436 .49815 .62731 .50676 .62054 .48422 Mtetra
.443 .409 .726 r
.62054 .48422 .62731 .50676 .64032 .5124 .63354 .49067 Mtetra
.503 .453 .734 r
.63354 .49067 .64032 .5124 .65331 .51423 .64655 .49397 Mtetra
.57 .505 .743 r
.64655 .49397 .65331 .51423 .66621 .5117 .65953 .49345 Mtetra
.639 .561 .751 r
.65953 .49345 .66621 .5117 .67898 .50468 .67241 .48878 Mtetra
.707 .619 .756 r
.67241 .48878 .67898 .50468 .69158 .49344 .68515 .48003 Mtetra
.769 .674 .759 r
.68515 .48003 .69158 .49344 .70398 .47863 .69771 .46761 Mtetra
.821 .725 .759 r
.69771 .46761 .70398 .47863 .7162 .46117 .7101 .45226 Mtetra
.862 .768 .758 r
.7101 .45226 .7162 .46117 .72828 .44213 .72234 .43491 Mtetra
.89 .804 .758 r
.72234 .43491 .72828 .44213 .74026 .42253 .73447 .41654 Mtetra
.906 .832 .763 r
.73447 .41654 .74026 .42253 .75219 .40332 .74654 .39808 Mtetra
.91 .853 .773 r
.74654 .39808 .75219 .40332 .76415 .38522 .75859 .38031 Mtetra
.905 .866 .79 r
.75859 .38031 .76415 .38522 .77618 .36872 .7707 .36381 Mtetra
.891 .872 .812 r
.7707 .36381 .77618 .36872 .78831 .35407 .78289 .34892 Mtetra
.869 .87 .836 r
.78289 .34892 .78831 .35407 .80059 .34132 .7952 .33579 Mtetra
.84 .861 .859 r
.7952 .33579 .80059 .34132 .81302 .33037 .80765 .3244 Mtetra
.809 .845 .878 r
.80765 .3244 .81302 .33037 .8256 .32101 .82026 .3146 Mtetra
.777 .827 .891 r
.82026 .3146 .8256 .32101 .83834 .31299 .83301 .30617 Mtetra
.748 .807 .9 r
.83301 .30617 .83834 .31299 .85121 .30603 .8459 .29886 Mtetra
.723 .79 .905 r
.8459 .29886 .85121 .30603 .86421 .29989 .85893 .29242 Mtetra
.704 .775 .907 r
.85893 .29242 .86421 .29989 .87733 .29433 .87207 .28664 Mtetra
.664 .741 .908 r
.26725 .47533 .27431 .48191 .28506 .47835 .27802 .47175 Mtetra
.27802 .47175 .28506 .47835 .29585 .47478 .28884 .46816 Mtetra
.28884 .46816 .29585 .47478 .30669 .4712 .29971 .46454 Mtetra
.29971 .46454 .30669 .4712 .31758 .4676 .31062 .46092 Mtetra
.31062 .46092 .31758 .4676 .3285 .46399 .32158 .45728 Mtetra
.32158 .45728 .3285 .46399 .33948 .46036 .33258 .45362 Mtetra
.663 .741 .908 r
.33258 .45362 .33948 .46036 .3505 .45672 .34363 .44995 Mtetra
.34363 .44995 .3505 .45672 .36156 .45307 .35472 .44627 Mtetra
.35472 .44627 .36156 .45307 .37267 .4494 .36586 .44257 Mtetra
.36586 .44257 .37267 .4494 .38383 .44574 .37705 .43887 Mtetra
.37705 .43887 .38383 .44574 .39503 .44207 .38828 .43516 Mtetra
.662 .74 .908 r
.38828 .43516 .39503 .44207 .40628 .43843 .39956 .43146 Mtetra
.66 .739 .908 r
.39956 .43146 .40628 .43843 .41758 .43484 .41088 .42779 Mtetra
.658 .736 .908 r
.41088 .42779 .41758 .43484 .42892 .43133 .42226 .42417 Mtetra
.654 .733 .907 r
.42226 .42417 .42892 .43133 .4403 .42797 .43367 .42065 Mtetra
.648 .727 .906 r
.43367 .42065 .4403 .42797 .45173 .42484 .44514 .41729 Mtetra
.639 .718 .905 r
.44514 .41729 .45173 .42484 .46321 .42207 .45665 .41419 Mtetra
.626 .705 .902 r
.45665 .41419 .46321 .42207 .47474 .41982 .46821 .41146 Mtetra
.608 .686 .898 r
.46821 .41146 .47474 .41982 .48631 .41827 .47981 .40926 Mtetra
.584 .66 .89 r
.47981 .40926 .48631 .41827 .49795 .41768 .49148 .40779 Mtetra
.553 .626 .878 r
.49148 .40779 .49795 .41768 .50965 .41827 .5032 .40726 Mtetra
.518 .584 .861 r
.5032 .40726 .50965 .41827 .52143 .42031 .51499 .40789 Mtetra
.48 .538 .838 r
.51499 .40789 .52143 .42031 .53331 .42399 .52687 .40989 Mtetra
.445 .49 .812 r
.52687 .40989 .53331 .42399 .54531 .42942 .53885 .41339 Mtetra
.415 .446 .785 r
.53885 .41339 .54531 .42942 .55745 .4366 .55096 .41846 Mtetra
.395 .411 .759 r
.55096 .41846 .55745 .4366 .56975 .44532 .5632 .42499 Mtetra
.387 .386 .736 r
.5632 .42499 .56975 .44532 .58221 .45516 .57559 .43273 Mtetra
.391 .373 .719 r
.57559 .43273 .58221 .45516 .59484 .4655 .58813 .4412 Mtetra
.406 .371 .708 r
.58813 .4412 .59484 .4655 .60763 .4755 .60084 .44977 Mtetra
.431 .381 .701 r
.60084 .44977 .60763 .4755 .62054 .48422 .61367 .45764 Mtetra
.464 .399 .699 r
.61367 .45764 .62054 .48422 .63354 .49067 .62661 .46396 Mtetra
.505 .425 .699 r
.62661 .46396 .63354 .49067 .64655 .49397 .6396 .46787 Mtetra
.55 .457 .702 r
.6396 .46787 .64655 .49397 .65953 .49345 .65259 .4687 Mtetra
.597 .494 .707 r
.65259 .4687 .65953 .49345 .67241 .48878 .66552 .466 Mtetra
.646 .534 .712 r
.66552 .466 .67241 .48878 .68515 .48003 .67836 .45963 Mtetra
.694 .576 .718 r
.67836 .45963 .68515 .48003 .69771 .46761 .69106 .44979 Mtetra
.74 .619 .724 r
.69106 .44979 .69771 .46761 .7101 .45226 .70361 .43701 Mtetra
.78 .66 .731 r
.70361 .43701 .7101 .45226 .72234 .43491 .71603 .422 Mtetra
.813 .698 .738 r
.71603 .422 .72234 .43491 .73447 .41654 .72833 .40564 Mtetra
.838 .733 .748 r
.72833 .40564 .73447 .41654 .74654 .39808 .74055 .38876 Mtetra
.854 .764 .761 r
.74055 .38876 .74654 .39808 .75859 .38031 .75275 .37213 Mtetra
.861 .788 .778 r
.75275 .37213 .75859 .38031 .7707 .36381 .76497 .35637 Mtetra
.858 .806 .798 r
.76497 .35637 .7707 .36381 .78289 .34892 .77726 .34188 Mtetra
.846 .817 .821 r
.77726 .34188 .78289 .34892 .7952 .33579 .78964 .3289 Mtetra
.827 .821 .843 r
.78964 .3289 .7952 .33579 .80765 .3244 .80216 .31748 Mtetra
.802 .817 .863 r
.80216 .31748 .80765 .3244 .82026 .3146 .81481 .30753 Mtetra
.775 .808 .879 r
.81481 .30753 .82026 .3146 .83301 .30617 .8276 .29891 Mtetra
.749 .796 .891 r
.8276 .29891 .83301 .30617 .8459 .29886 .84052 .29139 Mtetra
.726 .784 .898 r
.84052 .29139 .8459 .29886 .85893 .29242 .85358 .28476 Mtetra
.707 .773 .903 r
.85358 .28476 .85893 .29242 .87207 .28664 .86675 .27881 Mtetra
.664 .741 .908 r
.26013 .46871 .26725 .47533 .27802 .47175 .27093 .4651 Mtetra
.27093 .4651 .27802 .47175 .28884 .46816 .28178 .46148 Mtetra
.28178 .46148 .28884 .46816 .29971 .46454 .29268 .45784 Mtetra
.29268 .45784 .29971 .46454 .31062 .46092 .30361 .45418 Mtetra
.30361 .45418 .31062 .46092 .32158 .45728 .3146 .45051 Mtetra
.3146 .45051 .32158 .45728 .33258 .45362 .32563 .44683 Mtetra
.32563 .44683 .33258 .45362 .34363 .44995 .3367 .44313 Mtetra
.663 .741 .908 r
.3367 .44313 .34363 .44995 .35472 .44627 .34782 .43942 Mtetra
.34782 .43942 .35472 .44627 .36586 .44257 .35899 .43569 Mtetra
.35899 .43569 .36586 .44257 .37705 .43887 .37021 .43195 Mtetra
.37021 .43195 .37705 .43887 .38828 .43516 .38147 .4282 Mtetra
.662 .74 .908 r
.38147 .4282 .38828 .43516 .39956 .43146 .39278 .42446 Mtetra
.662 .739 .908 r
.39278 .42446 .39956 .43146 .41088 .42779 .40414 .42072 Mtetra
.66 .738 .908 r
.40414 .42072 .41088 .42779 .42226 .42417 .41554 .41701 Mtetra
.658 .735 .907 r
.41554 .41701 .42226 .42417 .43367 .42065 .42699 .41336 Mtetra
.654 .731 .906 r
.42699 .41336 .43367 .42065 .44514 .41729 .43849 .40982 Mtetra
.648 .725 .905 r
.43849 .40982 .44514 .41729 .45665 .41419 .45003 .40644 Mtetra
.638 .715 .903 r
.45003 .40644 .45665 .41419 .46821 .41146 .46163 .40332 Mtetra
.626 .7 .899 r
.46163 .40332 .46821 .41146 .47981 .40926 .47327 .40057 Mtetra
.608 .68 .892 r
.47327 .40057 .47981 .40926 .49148 .40779 .48496 .39835 Mtetra
.586 .652 .882 r
.48496 .39835 .49148 .40779 .5032 .40726 .49671 .39681 Mtetra
.559 .618 .867 r
.49671 .39681 .5032 .40726 .51499 .40789 .50852 .39616 Mtetra
.529 .577 .848 r
.50852 .39616 .51499 .40789 .52687 .40989 .52041 .39657 Mtetra
.499 .534 .824 r
.52041 .39657 .52687 .40989 .53885 .41339 .53238 .3982 Mtetra
.472 .492 .797 r
.53238 .3982 .53885 .41339 .55096 .41846 .54446 .40112 Mtetra
.452 .455 .771 r
.54446 .40112 .55096 .41846 .5632 .42499 .55665 .40533 Mtetra
.441 .426 .746 r
.55665 .40533 .5632 .42499 .57559 .43273 .56898 .41068 Mtetra
.439 .406 .726 r
.56898 .41068 .57559 .43273 .58813 .4412 .58144 .41685 Mtetra
.446 .397 .71 r
.58144 .41685 .58813 .4412 .60084 .44977 .59405 .4234 Mtetra
.461 .396 .698 r
.59405 .4234 .60084 .44977 .61367 .45764 .60678 .42971 Mtetra
.483 .404 .691 r
.60678 .42971 .61367 .45764 .62661 .46396 .61963 .43507 Mtetra
.51 .418 .687 r
.61963 .43507 .62661 .46396 .6396 .46787 .63256 .43878 Mtetra
.542 .439 .686 r
.63256 .43878 .6396 .46787 .65259 .4687 .64551 .44018 Mtetra
.577 .464 .688 r
.64551 .44018 .65259 .4687 .66552 .466 .65846 .43878 Mtetra
.613 .492 .691 r
.65846 .43878 .66552 .466 .67836 .45963 .67135 .43434 Mtetra
.65 .523 .696 r
.67135 .43434 .67836 .45963 .69106 .44979 .68415 .42688 Mtetra
.686 .557 .702 r
.68415 .42688 .69106 .44979 .70361 .43701 .69684 .41669 Mtetra
.721 .591 .71 r
.69684 .41669 .70361 .43701 .71603 .422 .70941 .40429 Mtetra
.752 .626 .72 r
.70941 .40429 .71603 .422 .72833 .40564 .72188 .39036 Mtetra
.778 .66 .732 r
.72188 .39036 .72833 .40564 .74055 .38876 .73428 .37561 Mtetra
.799 .692 .747 r
.73428 .37561 .74055 .38876 .75275 .37213 .74664 .36074 Mtetra
.812 .721 .764 r
.74664 .36074 .75275 .37213 .76497 .35637 .75901 .34632 Mtetra
.818 .746 .784 r
.75901 .34632 .76497 .35637 .77726 .34188 .77142 .3328 Mtetra
.815 .765 .806 r
.77142 .3328 .77726 .34188 .78964 .3289 .78392 .32046 Mtetra
.805 .778 .828 r
.78392 .32046 .78964 .3289 .80216 .31748 .79652 .30941 Mtetra
.788 .784 .849 r
.79652 .30941 .80216 .31748 .81481 .30753 .80924 .29965 Mtetra
.767 .785 .867 r
.80924 .29965 .81481 .30753 .8276 .29891 .82209 .29108 Mtetra
.746 .781 .881 r
.82209 .29108 .8276 .29891 .84052 .29139 .83506 .28353 Mtetra
.725 .774 .891 r
.83506 .28353 .84052 .29139 .85358 .28476 .84817 .27683 Mtetra
.708 .767 .898 r
.84817 .27683 .85358 .28476 .86675 .27881 .86138 .27078 Mtetra
.664 .741 .908 r
.25296 .46203 .26013 .46871 .27093 .4651 .26379 .4584 Mtetra
.26379 .4584 .27093 .4651 .28178 .46148 .27467 .45475 Mtetra
.27467 .45475 .28178 .46148 .29268 .45784 .28559 .45108 Mtetra
.28559 .45108 .29268 .45784 .30361 .45418 .29655 .4474 Mtetra
.29655 .4474 .30361 .45418 .3146 .45051 .30756 .4437 Mtetra
.30756 .4437 .3146 .45051 .32563 .44683 .31862 .43998 Mtetra
.31862 .43998 .32563 .44683 .3367 .44313 .32973 .43626 Mtetra
.32973 .43626 .3367 .44313 .34782 .43942 .34088 .43251 Mtetra
.663 .741 .908 r
.34088 .43251 .34782 .43942 .35899 .43569 .35207 .42875 Mtetra
.35207 .42875 .35899 .43569 .37021 .43195 .36332 .42498 Mtetra
.36332 .42498 .37021 .43195 .38147 .4282 .37461 .4212 Mtetra
.37461 .4212 .38147 .4282 .39278 .42446 .38595 .41741 Mtetra
.662 .74 .908 r
.38595 .41741 .39278 .42446 .40414 .42072 .39734 .41362 Mtetra
.661 .739 .908 r
.39734 .41362 .40414 .42072 .41554 .41701 .40877 .40984 Mtetra
.66 .738 .907 r
.40877 .40984 .41554 .41701 .42699 .41336 .42025 .40609 Mtetra
.657 .735 .907 r
.42025 .40609 .42699 .41336 .43849 .40982 .43179 .4024 Mtetra
.653 .73 .906 r
.43179 .4024 .43849 .40982 .45003 .40644 .44336 .39881 Mtetra
.648 .723 .904 r
.44336 .39881 .45003 .40644 .46163 .40332 .45499 .39539 Mtetra
.639 .713 .901 r
.45499 .39539 .46163 .40332 .47327 .40057 .46666 .39221 Mtetra
.627 .697 .895 r
.46666 .39221 .47327 .40057 .48496 .39835 .47839 .38938 Mtetra
.611 .676 .887 r
.47839 .38938 .48496 .39835 .49671 .39681 .49017 .38704 Mtetra
.591 .649 .876 r
.49017 .38704 .49671 .39681 .50852 .39616 .50201 .38532 Mtetra
.569 .616 .86 r
.50201 .38532 .50852 .39616 .52041 .39657 .51391 .38437 Mtetra
.544 .578 .839 r
.51391 .38437 .52041 .39657 .53238 .3982 .52589 .38434 Mtetra
.521 .539 .815 r
.52589 .38434 .53238 .3982 .54446 .40112 .53795 .38532 Mtetra
.501 .502 .789 r
.53795 .38532 .54446 .40112 .55665 .40533 .55012 .38734 Mtetra
.487 .47 .764 r
.55012 .38734 .55665 .40533 .56898 .41068 .56239 .39033 Mtetra
.48 .445 .741 r
.56239 .39033 .56898 .41068 .58144 .41685 .57479 .39413 Mtetra
.481 .429 .722 r
.57479 .39413 .58144 .41685 .59405 .4234 .58731 .39841 Mtetra
.488 .421 .707 r
.58731 .39841 .59405 .4234 .60678 .42971 .59995 .40276 Mtetra
.502 .42 .696 r
.59995 .40276 .60678 .42971 .61963 .43507 .6127 .40664 Mtetra
.52 .426 .689 r
.6127 .40664 .61963 .43507 .63256 .43878 .62554 .40948 Mtetra
.543 .438 .685 r
.62554 .40948 .63256 .43878 .64551 .44018 .63844 .41073 Mtetra
.568 .454 .683 r
.63844 .41073 .64551 .44018 .65846 .43878 .65135 .40993 Mtetra
.595 .474 .684 r
.65135 .40993 .65846 .43878 .67135 .43434 .66426 .40679 Mtetra
.624 .497 .688 r
.66426 .40679 .67135 .43434 .68415 .42688 .67711 .40119 Mtetra
.653 .523 .693 r
.67711 .40119 .68415 .42688 .69684 .41669 .68989 .39328 Mtetra
.681 .551 .7 r
.68989 .39328 .69684 .41669 .70941 .40429 .7026 .38336 Mtetra
.708 .58 .71 r
.7026 .38336 .70941 .40429 .72188 .39036 .71522 .37192 Mtetra
.732 .611 .722 r
.71522 .37192 .72188 .39036 .73428 .37561 .72779 .35951 Mtetra
.753 .641 .737 r
.72779 .35951 .73428 .37561 .74664 .36074 .74032 .3467 Mtetra
.769 .67 .754 r
.74032 .3467 .74664 .36074 .75901 .34632 .75285 .33402 Mtetra
.779 .697 .774 r
.75285 .33402 .75901 .34632 .77142 .3328 .76541 .32186 Mtetra
.782 .721 .795 r
.76541 .32186 .77142 .3328 .78392 .32046 .77803 .31054 Mtetra
.778 .74 .818 r
.77803 .31054 .78392 .32046 .79652 .30941 .79074 .30021 Mtetra
.769 .753 .839 r
.79074 .30021 .79652 .30941 .80924 .29965 .80355 .29092 Mtetra
.754 .761 .858 r
.80355 .29092 .80924 .29965 .82209 .29108 .81648 .28263 Mtetra
.738 .763 .873 r
.81648 .28263 .82209 .29108 .83506 .28353 .82952 .27523 Mtetra
.721 .762 .885 r
.82952 .27523 .83506 .28353 .84817 .27683 .84268 .26859 Mtetra
.706 .759 .894 r
.84268 .26859 .84817 .27683 .86138 .27078 .85595 .26254 Mtetra
.664 .741 .908 r
.24574 .45531 .25296 .46203 .26379 .4584 .25659 .45164 Mtetra
.25659 .45164 .26379 .4584 .27467 .45475 .2675 .44796 Mtetra
.2675 .44796 .27467 .45475 .28559 .45108 .27844 .44427 Mtetra
.27844 .44427 .28559 .45108 .29655 .4474 .28944 .44056 Mtetra
.28944 .44056 .29655 .4474 .30756 .4437 .30048 .43683 Mtetra
.30048 .43683 .30756 .4437 .31862 .43998 .31156 .43309 Mtetra
.31156 .43309 .31862 .43998 .32973 .43626 .32269 .42933 Mtetra
.32269 .42933 .32973 .43626 .34088 .43251 .33387 .42556 Mtetra
.33387 .42556 .34088 .43251 .35207 .42875 .3451 .42177 Mtetra
.663 .741 .908 r
.3451 .42177 .35207 .42875 .36332 .42498 .35637 .41796 Mtetra
.35637 .41796 .36332 .42498 .37461 .4212 .36769 .41415 Mtetra
.36769 .41415 .37461 .4212 .38595 .41741 .37906 .41032 Mtetra
.37906 .41032 .38595 .41741 .39734 .41362 .39048 .40648 Mtetra
.662 .74 .908 r
.39048 .40648 .39734 .41362 .40877 .40984 .40195 .40265 Mtetra
.661 .739 .907 r
.40195 .40265 .40877 .40984 .42025 .40609 .41346 .39882 Mtetra
.66 .737 .907 r
.41346 .39882 .42025 .40609 .43179 .4024 .42503 .39502 Mtetra
.658 .734 .906 r
.42503 .39502 .43179 .4024 .44336 .39881 .43664 .39128 Mtetra
.654 .73 .905 r
.43664 .39128 .44336 .39881 .45499 .39539 .4483 .38764 Mtetra
.648 .722 .903 r
.4483 .38764 .45499 .39539 .46666 .39221 .46001 .38414 Mtetra
.64 .712 .899 r
.46001 .38414 .46666 .39221 .47839 .38938 .47177 .38087 Mtetra
.63 .697 .893 r
.47177 .38087 .47839 .38938 .49017 .38704 .48358 .37791 Mtetra
.616 .677 .885 r
.48358 .37791 .49017 .38704 .50201 .38532 .49545 .37538 Mtetra
.6 .651 .873 r
.49545 .37538 .50201 .38532 .51391 .38437 .50737 .37337 Mtetra
.581 .62 .856 r
.50737 .37337 .51391 .38437 .52589 .38434 .51937 .372 Mtetra
.562 .586 .836 r
.51937 .372 .52589 .38434 .53795 .38532 .53143 .37137 Mtetra
.544 .552 .813 r
.53143 .37137 .53795 .38532 .55012 .38734 .54358 .37152 Mtetra
.529 .519 .789 r
.54358 .37152 .55012 .38734 .56239 .39033 .55583 .37243 Mtetra
.519 .491 .765 r
.55583 .37243 .56239 .39033 .57479 .39413 .56817 .37403 Mtetra
.515 .469 .744 r
.56817 .37403 .57479 .39413 .58731 .39841 .58063 .37611 Mtetra
.516 .454 .726 r
.58063 .37611 .58731 .39841 .59995 .40276 .59319 .37841 Mtetra
.523 .447 .711 r
.59319 .37841 .59995 .40276 .6127 .40664 .60586 .38056 Mtetra
.534 .445 .701 r
.60586 .38056 .6127 .40664 .62554 .40948 .61861 .38215 Mtetra
.549 .45 .694 r
.61861 .38215 .62554 .40948 .63844 .41073 .63144 .38273 Mtetra
.568 .459 .69 r
.63144 .38273 .63844 .41073 .65135 .40993 .64431 .38192 Mtetra
.588 .472 .689 r
.64431 .38192 .65135 .40993 .66426 .40679 .65719 .37943 Mtetra
.61 .489 .69 r
.65719 .37943 .66426 .40679 .67711 .40119 .67007 .37509 Mtetra
.633 .509 .694 r
.67007 .37509 .67711 .40119 .68989 .39328 .68291 .36892 Mtetra
.656 .531 .7 r
.68291 .36892 .68989 .39328 .7026 .38336 .69571 .36108 Mtetra
.679 .556 .709 r
.69571 .36108 .7026 .38336 .71522 .37192 .70846 .35188 Mtetra
.7 .582 .72 r
.70846 .35188 .71522 .37192 .72779 .35951 .72117 .34169 Mtetra
.719 .609 .734 r
.72117 .34169 .72779 .35951 .74032 .3467 .73386 .33097 Mtetra
.734 .637 .75 r
.73386 .33097 .74032 .3467 .75285 .33402 .74654 .32013 Mtetra
.746 .663 .769 r
.74654 .32013 .75285 .33402 .76541 .32186 .75925 .30953 Mtetra
.752 .688 .79 r
.75925 .30953 .76541 .32186 .77803 .31054 .77201 .29945 Mtetra
.753 .71 .811 r
.77201 .29945 .77803 .31054 .79074 .30021 .78484 .29006 Mtetra
.748 .727 .832 r
.78484 .29006 .79074 .30021 .80355 .29092 .79776 .28144 Mtetra
.739 .739 .851 r
.79776 .28144 .80355 .29092 .81648 .28263 .81078 .27361 Mtetra
.727 .747 .868 r
.81078 .27361 .81648 .28263 .82952 .27523 .8239 .2665 Mtetra
.714 .75 .88 r
.8239 .2665 .82952 .27523 .84268 .26859 .83712 .26003 Mtetra
.702 .751 .89 r
.83712 .26003 .84268 .26859 .85595 .26254 .85045 .25406 Mtetra
.664 .741 .908 r
.23846 .44853 .24574 .45531 .25659 .45164 .24934 .44484 Mtetra
.24934 .44484 .25659 .45164 .2675 .44796 .26027 .44113 Mtetra
.26027 .44113 .2675 .44796 .27844 .44427 .27124 .4374 Mtetra
.27124 .4374 .27844 .44427 .28944 .44056 .28226 .43366 Mtetra
.28226 .43366 .28944 .44056 .30048 .43683 .29333 .42991 Mtetra
.29333 .42991 .30048 .43683 .31156 .43309 .30445 .42614 Mtetra
.30445 .42614 .31156 .43309 .32269 .42933 .31561 .42235 Mtetra
.31561 .42235 .32269 .42933 .33387 .42556 .32681 .41855 Mtetra
.32681 .41855 .33387 .42556 .3451 .42177 .33807 .41473 Mtetra
.33807 .41473 .3451 .42177 .35637 .41796 .34937 .41089 Mtetra
.663 .741 .908 r
.34937 .41089 .35637 .41796 .36769 .41415 .36072 .40704 Mtetra
.36072 .40704 .36769 .41415 .37906 .41032 .37212 .40318 Mtetra
.37212 .40318 .37906 .41032 .39048 .40648 .38357 .39931 Mtetra
.38357 .39931 .39048 .40648 .40195 .40265 .39507 .39542 Mtetra
.662 .74 .908 r
.39507 .39542 .40195 .40265 .41346 .39882 .40662 .39154 Mtetra
.661 .739 .907 r
.40662 .39154 .41346 .39882 .42503 .39502 .41821 .38767 Mtetra
.66 .737 .907 r
.41821 .38767 .42503 .39502 .43664 .39128 .42986 .38382 Mtetra
.658 .734 .906 r
.42986 .38382 .43664 .39128 .4483 .38764 .44155 .38003 Mtetra
.654 .73 .905 r
.44155 .38003 .4483 .38764 .46001 .38414 .4533 .37633 Mtetra
.649 .723 .903 r
.4533 .37633 .46001 .38414 .47177 .38087 .46509 .37276 Mtetra
.642 .714 .899 r
.46509 .37276 .47177 .38087 .48358 .37791 .47693 .36939 Mtetra
.633 .7 .894 r
.47693 .36939 .48358 .37791 .49545 .37538 .48883 .36628 Mtetra
.622 .682 .886 r
.48883 .36628 .49545 .37538 .50737 .37337 .50079 .36352 Mtetra
.609 .659 .874 r
.50079 .36352 .50737 .37337 .51937 .372 .5128 .36117 Mtetra
.594 .632 .859 r
.5128 .36117 .51937 .372 .53143 .37137 .52489 .3593 Mtetra
.58 .602 .839 r
.52489 .3593 .53143 .37137 .54358 .37152 .53704 .35797 Mtetra
.567 .572 .818 r
.53704 .35797 .54358 .37152 .55583 .37243 .54927 .35718 Mtetra
.556 .542 .795 r
.54927 .35718 .55583 .37243 .56817 .37403 .56159 .3569 Mtetra
.549 .517 .773 r
.56159 .3569 .56817 .37403 .58063 .37611 .57401 .35705 Mtetra
.546 .497 .753 r
.57401 .35705 .58063 .37611 .59319 .37841 .58651 .35746 Mtetra
.547 .483 .736 r
.58651 .35746 .59319 .37841 .60586 .38056 .59911 .3579 Mtetra
.552 .476 .722 r
.59911 .3579 .60586 .38056 .61861 .38215 .6118 .35809 Mtetra
.561 .473 .712 r
.6118 .35809 .61861 .38215 .63144 .38273 .62456 .35771 Mtetra
.574 .476 .706 r
.62456 .35771 .63144 .38273 .64431 .38192 .63738 .35647 Mtetra
.588 .483 .702 r
.63738 .35647 .64431 .38192 .65719 .37943 .65023 .35411 Mtetra
.605 .495 .702 r
.65023 .35411 .65719 .37943 .67007 .37509 .66311 .35046 Mtetra
.623 .509 .704 r
.66311 .35046 .67007 .37509 .68291 .36892 .67599 .34546 Mtetra
.641 .527 .708 r
.67599 .34546 .68291 .36892 .69571 .36108 .68885 .33916 Mtetra
.66 .547 .716 r
.68885 .33916 .69571 .36108 .70846 .35188 .70169 .33175 Mtetra
.677 .569 .726 r
.70169 .33175 .70846 .35188 .72117 .34169 .71452 .32346 Mtetra
.694 .593 .738 r
.71452 .32346 .72117 .34169 .73386 .33097 .72734 .31461 Mtetra
.708 .618 .754 r
.72734 .31461 .73386 .33097 .74654 .32013 .74016 .3055 Mtetra
.72 .643 .771 r
.74016 .3055 .74654 .32013 .75925 .30953 .75301 .29642 Mtetra
.727 .667 .791 r
.75301 .29642 .75925 .30953 .77201 .29945 .7659 .28762 Mtetra
.73 .689 .811 r
.7659 .28762 .77201 .29945 .78484 .29006 .77886 .27924 Mtetra
.728 .708 .831 r
.77886 .27924 .78484 .29006 .79776 .28144 .79188 .27141 Mtetra
.723 .722 .849 r
.79188 .27141 .79776 .28144 .81078 .27361 .80499 .26414 Mtetra
.715 .733 .865 r
.80499 .26414 .81078 .27361 .8239 .2665 .8182 .25742 Mtetra
.706 .74 .878 r
.8182 .25742 .8239 .2665 .83712 .26003 .83149 .25119 Mtetra
.696 .743 .888 r
.83149 .25119 .83712 .26003 .85045 .25406 .84488 .24537 Mtetra
.664 .741 .908 r
.23112 .4417 .23846 .44853 .24934 .44484 .24203 .43798 Mtetra
.24203 .43798 .24934 .44484 .26027 .44113 .25299 .43424 Mtetra
.25299 .43424 .26027 .44113 .27124 .4374 .26399 .43049 Mtetra
.26399 .43049 .27124 .4374 .28226 .43366 .27504 .42672 Mtetra
.27504 .42672 .28226 .43366 .29333 .42991 .28613 .42293 Mtetra
.28613 .42293 .29333 .42991 .30445 .42614 .29727 .41913 Mtetra
.29727 .41913 .30445 .42614 .31561 .42235 .30846 .41532 Mtetra
.30846 .41532 .31561 .42235 .32681 .41855 .3197 .41148 Mtetra
.3197 .41148 .32681 .41855 .33807 .41473 .33099 .40763 Mtetra
.33099 .40763 .33807 .41473 .34937 .41089 .34232 .40377 Mtetra
.663 .741 .908 r
.34232 .40377 .34937 .41089 .36072 .40704 .3537 .39989 Mtetra
.3537 .39989 .36072 .40704 .37212 .40318 .36513 .39599 Mtetra
.36513 .39599 .37212 .40318 .38357 .39931 .37661 .39208 Mtetra
.37661 .39208 .38357 .39931 .39507 .39542 .38814 .38816 Mtetra
.38814 .38816 .39507 .39542 .40662 .39154 .39971 .38424 Mtetra
.662 .74 .908 r
.39971 .38424 .40662 .39154 .41821 .38767 .41134 .38032 Mtetra
.661 .739 .908 r
.41134 .38032 .41821 .38767 .42986 .38382 .42302 .37642 Mtetra
.659 .738 .908 r
.42302 .37642 .42986 .38382 .44155 .38003 .43475 .37256 Mtetra
.656 .736 .909 r
.43475 .37256 .44155 .38003 .4533 .37633 .44652 .36877 Mtetra
.653 .733 .909 r
.44652 .36877 .4533 .37633 .46509 .37276 .45835 .36506 Mtetra
.648 .729 .908 r
.45835 .36506 .46509 .37276 .47693 .36939 .47023 .36148 Mtetra
.642 .722 .906 r
.47023 .36148 .47693 .36939 .48883 .36628 .48216 .35805 Mtetra
.636 .711 .901 r
.48216 .35805 .48883 .36628 .50079 .36352 .49415 .3548 Mtetra
.629 .697 .894 r
.49415 .3548 .50079 .36352 .5128 .36117 .5062 .35177 Mtetra
.62 .677 .883 r
.5062 .35177 .5128 .36117 .52489 .3593 .5183 .349 Mtetra
.611 .653 .867 r
.5183 .349 .52489 .3593 .53704 .35797 .53047 .34653 Mtetra
.601 .626 .849 r
.53047 .34653 .53704 .35797 .54927 .35718 .54271 .3444 Mtetra
.591 .598 .828 r
.54271 .3444 .54927 .35718 .56159 .3569 .55503 .34261 Mtetra
.583 .571 .806 r
.55503 .34261 .56159 .3569 .57401 .35705 .56742 .34116 Mtetra
.577 .548 .786 r
.56742 .34116 .57401 .35705 .58651 .35746 .57989 .33995 Mtetra
.574 .529 .767 r
.57989 .33995 .58651 .35746 .59911 .3579 .59245 .33888 Mtetra
.574 .516 .752 r
.59245 .33888 .59911 .3579 .6118 .35809 .60509 .33774 Mtetra
.578 .508 .74 r
.60509 .33774 .6118 .35809 .62456 .35771 .6178 .33634 Mtetra
.585 .505 .731 r
.6178 .33634 .62456 .35771 .63738 .35647 .63058 .33446 Mtetra
.595 .507 .725 r
.63058 .33446 .63738 .35647 .65023 .35411 .64341 .33188 Mtetra
.607 .513 .722 r
.64341 .33188 .65023 .35411 .66311 .35046 .65627 .32846 Mtetra
.62 .523 .722 r
.65627 .32846 .66311 .35046 .67599 .34546 .66916 .32412 Mtetra
.634 .536 .725 r
.66916 .32412 .67599 .34546 .68885 .33916 .68207 .31885 Mtetra
.649 .552 .731 r
.68207 .31885 .68885 .33916 .70169 .33175 .69498 .31272 Mtetra
.664 .57 .74 r
.69498 .31272 .70169 .33175 .71452 .32346 .7079 .30589 Mtetra
.677 .59 .751 r
.7079 .30589 .71452 .32346 .72734 .31461 .72082 .29854 Mtetra
.69 .612 .764 r
.72082 .29854 .72734 .31461 .74016 .3055 .73376 .2909 Mtetra
.7 .635 .78 r
.73376 .2909 .74016 .3055 .75301 .29642 .74673 .28317 Mtetra
.707 .657 .798 r
.74673 .28317 .75301 .29642 .7659 .28762 .75974 .27553 Mtetra
.711 .678 .816 r
.75974 .27553 .7659 .28762 .77886 .27924 .77281 .26813 Mtetra
.711 .696 .834 r
.77281 .26813 .77886 .27924 .79188 .27141 .78594 .26107 Mtetra
.709 .712 .851 r
.78594 .26107 .79188 .27141 .80499 .26414 .79915 .25438 Mtetra
.703 .723 .865 r
.79915 .25438 .80499 .26414 .8182 .25742 .81244 .24808 Mtetra
.697 .732 .877 r
.81244 .24808 .8182 .25742 .83149 .25119 .82581 .24214 Mtetra
.69 .737 .887 r
.82581 .24214 .83149 .25119 .84488 .24537 .83926 .2365 Mtetra
.664 .741 .908 r
.22373 .43482 .23112 .4417 .24203 .43798 .23467 .43107 Mtetra
.23467 .43107 .24203 .43798 .25299 .43424 .24565 .4273 Mtetra
.24565 .4273 .25299 .43424 .26399 .43049 .25668 .42352 Mtetra
.25668 .42352 .26399 .43049 .27504 .42672 .26775 .41972 Mtetra
.26775 .41972 .27504 .42672 .28613 .42293 .27888 .4159 Mtetra
.27888 .4159 .28613 .42293 .29727 .41913 .29005 .41207 Mtetra
.29005 .41207 .29727 .41913 .30846 .41532 .30127 .40823 Mtetra
.30127 .40823 .30846 .41532 .3197 .41148 .31253 .40436 Mtetra
.31253 .40436 .3197 .41148 .33099 .40763 .32384 .40048 Mtetra
.32384 .40048 .33099 .40763 .34232 .40377 .33521 .39659 Mtetra
.663 .741 .908 r
.33521 .39659 .34232 .40377 .3537 .39989 .34662 .39268 Mtetra
.34662 .39268 .3537 .39989 .36513 .39599 .35808 .38875 Mtetra
.35808 .38875 .36513 .39599 .37661 .39208 .36959 .38482 Mtetra
.663 .741 .909 r
.36959 .38482 .37661 .39208 .38814 .38816 .38115 .38088 Mtetra
.662 .742 .909 r
.38115 .38088 .38814 .38816 .39971 .38424 .39275 .37696 Mtetra
.66 .742 .91 r
.39275 .37696 .39971 .38424 .41134 .38032 .40441 .37305 Mtetra
.658 .743 .912 r
.40441 .37305 .41134 .38032 .42302 .37642 .41612 .3692 Mtetra
.656 .744 .915 r
.41612 .3692 .42302 .37642 .43475 .37256 .42787 .3654 Mtetra
.652 .746 .918 r
.42787 .3654 .43475 .37256 .44652 .36877 .43968 .36168 Mtetra
.649 .748 .922 r
.43968 .36168 .44652 .36877 .45835 .36506 .45154 .35803 Mtetra
.646 .75 .925 r
.45154 .35803 .45835 .36506 .47023 .36148 .46345 .35444 Mtetra
.644 .75 .926 r
.46345 .35444 .47023 .36148 .48216 .35805 .47542 .35089 Mtetra
.644 .747 .924 r
.47542 .35089 .48216 .35805 .49415 .3548 .48745 .34734 Mtetra
.643 .739 .918 r
.48745 .34734 .49415 .3548 .5062 .35177 .49953 .34381 Mtetra
.642 .725 .909 r
.49953 .34381 .5062 .35177 .5183 .349 .51167 .34031 Mtetra
.638 .705 .895 r
.51167 .34031 .5183 .349 .53047 .34653 .52387 .33692 Mtetra
.632 .68 .878 r
.52387 .33692 .53047 .34653 .54271 .3444 .53613 .33369 Mtetra
.624 .653 .859 r
.53613 .33369 .54271 .3444 .55503 .34261 .54845 .33069 Mtetra
.615 .627 .839 r
.54845 .33069 .55503 .34261 .56742 .34116 .56085 .32796 Mtetra
.607 .602 .82 r
.56085 .32796 .56742 .34116 .57989 .33995 .57331 .32546 Mtetra
.601 .58 .802 r
.57331 .32546 .57989 .33995 .59245 .33888 .58585 .32315 Mtetra
.598 .563 .786 r
.58585 .32315 .59245 .33888 .60509 .33774 .59846 .3209 Mtetra
.598 .551 .773 r
.59846 .3209 .60509 .33774 .6178 .33634 .61114 .31856 Mtetra
.601 .544 .763 r
.61114 .31856 .6178 .33634 .63058 .33446 .62389 .31599 Mtetra
.606 .541 .755 r
.62389 .31599 .63058 .33446 .64341 .33188 .6367 .31303 Mtetra
.614 .543 .75 r
.6367 .31303 .64341 .33188 .65627 .32846 .64956 .30956 Mtetra
.623 .548 .749 r
.64956 .30956 .65627 .32846 .66916 .32412 .66246 .30549 Mtetra
.634 .556 .75 r
.66246 .30549 .66916 .32412 .68207 .31885 .67539 .3008 Mtetra
.645 .568 .754 r
.67539 .3008 .68207 .31885 .69498 .31272 .68835 .29551 Mtetra
.656 .583 .761 r
.68835 .29551 .69498 .31272 .7079 .30589 .70134 .28969 Mtetra
.667 .6 .77 r
.70134 .28969 .7079 .30589 .72082 .29854 .71434 .28345 Mtetra
.678 .618 .781 r
.71434 .28345 .72082 .29854 .73376 .2909 .72738 .27693 Mtetra
.686 .637 .795 r
.72738 .27693 .73376 .2909 .74673 .28317 .74045 .27027 Mtetra
.692 .657 .81 r
.74045 .27027 .74673 .28317 .75974 .27553 .75356 .2636 Mtetra
.696 .675 .826 r
.75356 .2636 .75974 .27553 .77281 .26813 .76673 .25704 Mtetra
.697 .692 .841 r
.76673 .25704 .77281 .26813 .78594 .26107 .77996 .25066 Mtetra
.696 .707 .856 r
.77996 .25066 .78594 .26107 .79915 .25438 .79325 .24451 Mtetra
.693 .718 .869 r
.79325 .24451 .79915 .25438 .81244 .24808 .80662 .23861 Mtetra
.689 .727 .879 r
.80662 .23861 .81244 .24808 .82581 .24214 .82007 .23295 Mtetra
.684 .733 .888 r
.82007 .23295 .82581 .24214 .83926 .2365 .83359 .22751 Mtetra
.664 .741 .908 r
.21628 .42788 .22373 .43482 .23467 .43107 .22724 .4241 Mtetra
.22724 .4241 .23467 .43107 .24565 .4273 .23825 .4203 Mtetra
.23825 .4203 .24565 .4273 .25668 .42352 .24931 .41649 Mtetra
.24931 .41649 .25668 .42352 .26775 .41972 .26041 .41266 Mtetra
.26041 .41266 .26775 .41972 .27888 .4159 .27156 .40882 Mtetra
.27156 .40882 .27888 .4159 .29005 .41207 .28276 .40496 Mtetra
.28276 .40496 .29005 .41207 .30127 .40823 .29401 .40108 Mtetra
.29401 .40108 .30127 .40823 .31253 .40436 .3053 .39719 Mtetra
.663 .741 .908 r
.3053 .39719 .31253 .40436 .32384 .40048 .31665 .39328 Mtetra
.31665 .39328 .32384 .40048 .33521 .39659 .32804 .38935 Mtetra
.32804 .38935 .33521 .39659 .34662 .39268 .33948 .38542 Mtetra
.663 .741 .909 r
.33948 .38542 .34662 .39268 .35808 .38875 .35097 .38149 Mtetra
.662 .742 .909 r
.35097 .38149 .35808 .38875 .36959 .38482 .36251 .37757 Mtetra
.66 .743 .911 r
.36251 .37757 .36959 .38482 .38115 .38088 .37409 .37368 Mtetra
.657 .744 .914 r
.37409 .37368 .38115 .38088 .39275 .37696 .38573 .36986 Mtetra
.653 .747 .919 r
.38573 .36986 .39275 .37696 .40441 .37305 .39741 .36614 Mtetra
.647 .752 .926 r
.39741 .36614 .40441 .37305 .41612 .3692 .40914 .36255 Mtetra
.641 .759 .934 r
.40914 .36255 .41612 .3692 .42787 .3654 .42092 .35909 Mtetra
.635 .769 .944 r
.42092 .35909 .42787 .3654 .43968 .36168 .43275 .35572 Mtetra
.631 .78 .953 r
.43275 .35572 .43968 .36168 .45154 .35803 .44464 .35238 Mtetra
.631 .792 .959 r
.44464 .35238 .45154 .35803 .46345 .35444 .45658 .34894 Mtetra
.637 .8 .961 r
.45658 .34894 .46345 .35444 .47542 .35089 .46859 .34532 Mtetra
.647 .802 .957 r
.46859 .34532 .47542 .35089 .48745 .34734 .48066 .34145 Mtetra
.658 .795 .948 r
.48066 .34145 .48745 .34734 .49953 .34381 .49279 .33733 Mtetra
.666 .779 .934 r
.49279 .33733 .49953 .34381 .51167 .34031 .50497 .33304 Mtetra
.667 .756 .917 r
.50497 .33304 .51167 .34031 .52387 .33692 .51721 .32872 Mtetra
.663 .729 .899 r
.51721 .32872 .52387 .33692 .53613 .33369 .5295 .3245 Mtetra
.654 .702 .881 r
.5295 .3245 .53613 .33369 .54845 .33069 .54185 .32049 Mtetra
.644 .675 .865 r
.54185 .32049 .54845 .33069 .56085 .32796 .55426 .31675 Mtetra
.634 .651 .849 r
.55426 .31675 .56085 .32796 .57331 .32546 .56673 .31329 Mtetra
.626 .63 .835 r
.56673 .31329 .57331 .32546 .58585 .32315 .57927 .31005 Mtetra
.621 .612 .821 r
.57927 .31005 .58585 .32315 .59846 .3209 .59188 .30694 Mtetra
.618 .599 .809 r
.59188 .30694 .59846 .3209 .61114 .31856 .60455 .30385 Mtetra
.618 .589 .798 r
.60455 .30385 .61114 .31856 .62389 .31599 .61729 .30067 Mtetra
.62 .583 .79 r
.61729 .30067 .62389 .31599 .6367 .31303 .63009 .29729 Mtetra
.625 .581 .784 r
.63009 .29729 .6367 .31303 .64956 .30956 .64295 .29362 Mtetra
.631 .582 .781 r
.64295 .29362 .64956 .30956 .66246 .30549 .65586 .28959 Mtetra
.638 .587 .78 r
.65586 .28959 .66246 .30549 .67539 .3008 .66882 .28517 Mtetra
.646 .595 .782 r
.66882 .28517 .67539 .3008 .68835 .29551 .68181 .28035 Mtetra
.654 .605 .787 r
.68181 .28035 .68835 .29551 .70134 .28969 .69485 .27516 Mtetra
.663 .618 .794 r
.69485 .27516 .70134 .28969 .71434 .28345 .70792 .26965 Mtetra
.67 .633 .803 r
.70792 .26965 .71434 .28345 .72738 .27693 .72103 .26392 Mtetra
.677 .648 .814 r
.72103 .26392 .72738 .27693 .74045 .27027 .73418 .25804 Mtetra
.682 .664 .826 r
.73418 .25804 .74045 .27027 .75356 .2636 .74738 .25211 Mtetra
.685 .68 .839 r
.74738 .25211 .75356 .2636 .76673 .25704 .76063 .2462 Mtetra
.686 .694 .852 r
.76063 .2462 .76673 .25704 .77996 .25066 .77395 .24037 Mtetra
.686 .707 .863 r
.77395 .24037 .77996 .25066 .79325 .24451 .78732 .23467 Mtetra
.684 .717 .874 r
.78732 .23467 .79325 .24451 .80662 .23861 .80077 .22911 Mtetra
.681 .725 .883 r
.80077 .22911 .80662 .23861 .82007 .23295 .81428 .2237 Mtetra
.678 .731 .89 r
.81428 .2237 .82007 .23295 .83359 .22751 .82787 .21843 Mtetra
.664 .741 .908 r
.20877 .42089 .21628 .42788 .22724 .4241 .21976 .41708 Mtetra
.21976 .41708 .22724 .4241 .23825 .4203 .2308 .41325 Mtetra
.2308 .41325 .23825 .4203 .24931 .41649 .24188 .40941 Mtetra
.24188 .40941 .24931 .41649 .26041 .41266 .25302 .40555 Mtetra
.25302 .40555 .26041 .41266 .27156 .40882 .26419 .40168 Mtetra
.26419 .40168 .27156 .40882 .28276 .40496 .27542 .39779 Mtetra
.27542 .39779 .28276 .40496 .29401 .40108 .2867 .39388 Mtetra
.663 .741 .908 r
.2867 .39388 .29401 .40108 .3053 .39719 .29802 .38996 Mtetra
.29802 .38996 .3053 .39719 .31665 .39328 .30939 .38603 Mtetra
.663 .741 .909 r
.30939 .38603 .31665 .39328 .32804 .38935 .32081 .38209 Mtetra
.662 .742 .909 r
.32081 .38209 .32804 .38935 .33948 .38542 .33228 .37818 Mtetra
.659 .743 .911 r
.33228 .37818 .33948 .38542 .35097 .38149 .34379 .37431 Mtetra
.656 .744 .915 r
.34379 .37431 .35097 .38149 .36251 .37757 .35535 .37053 Mtetra
.649 .748 .921 r
.35535 .37053 .36251 .37757 .37409 .37368 .36696 .36692 Mtetra
.639 .754 .931 r
.36696 .36692 .37409 .37368 .38573 .36986 .3786 .36353 Mtetra
.626 .764 .946 r
.3786 .36353 .38573 .36986 .39741 .36614 .39029 .36041 Mtetra
.607 .779 .963 r
.39029 .36041 .39741 .36614 .40914 .36255 .40203 .35756 Mtetra
.586 .799 .981 r
.40203 .35756 .40914 .36255 .42092 .35909 .41382 .3549 Mtetra
.566 .822 .994 r
.41382 .3549 .42092 .35909 .43275 .35572 .42567 .35224 Mtetra
.559 .845 .998 r
.42567 .35224 .43275 .35572 .44464 .35238 .43759 .34934 Mtetra
.573 .866 .996 r
.43759 .34934 .44464 .35238 .45658 .34894 .44959 .34597 Mtetra
.609 .88 .991 r
.44959 .34597 .45658 .34894 .46859 .34532 .46166 .34197 Mtetra
.652 .881 .982 r
.46166 .34197 .46859 .34532 .48066 .34145 .47379 .33733 Mtetra
.685 .864 .967 r
.47379 .33733 .48066 .34145 .49279 .33733 .48598 .33219 Mtetra
.701 .834 .946 r
.48598 .33219 .49279 .33733 .50497 .33304 .49821 .32678 Mtetra
.701 .798 .925 r
.49821 .32678 .50497 .33304 .51721 .32872 .5105 .32137 Mtetra
.692 .764 .907 r
.5105 .32137 .51721 .32872 .5295 .3245 .52283 .31617 Mtetra
.679 .734 .892 r
.52283 .31617 .5295 .3245 .54185 .32049 .53521 .31132 Mtetra
.666 .709 .88 r
.53521 .31132 .54185 .32049 .55426 .31675 .54764 .30685 Mtetra
.654 .688 .87 r
.54764 .30685 .55426 .31675 .56673 .31329 .56013 .30272 Mtetra
.645 .671 .86 r
.56013 .30272 .56673 .31329 .57927 .31005 .57269 .29884 Mtetra
.639 .656 .85 r
.57269 .29884 .57927 .31005 .59188 .30694 .5853 .29513 Mtetra
.635 .644 .841 r
.5853 .29513 .59188 .30694 .60455 .30385 .59799 .29149 Mtetra
.634 .634 .833 r
.59799 .29149 .60455 .30385 .61729 .30067 .61074 .28783 Mtetra
.634 .627 .825 r
.61074 .28783 .61729 .30067 .63009 .29729 .62354 .28408 Mtetra
.636 .622 .819 r
.62354 .28408 .63009 .29729 .64295 .29362 .63641 .28017 Mtetra
.64 .621 .815 r
.63641 .28017 .64295 .29362 .65586 .28959 .64934 .27606 Mtetra
.644 .622 .813 r
.64934 .27606 .65586 .28959 .66882 .28517 .66232 .27171 Mtetra
.65 .627 .814 r
.66232 .27171 .66882 .28517 .68181 .28035 .67535 .26711 Mtetra
.655 .633 .816 r
.67535 .26711 .68181 .28035 .69485 .27516 .68842 .26226 Mtetra
.661 .642 .821 r
.68842 .26226 .69485 .27516 .70792 .26965 .70154 .25721 Mtetra
.666 .653 .827 r
.70154 .25721 .70792 .26965 .72103 .26392 .71471 .25197 Mtetra
.671 .665 .835 r
.71471 .25197 .72103 .26392 .73418 .25804 .72793 .24662 Mtetra
.675 .677 .844 r
.72793 .24662 .73418 .25804 .74738 .25211 .7412 .24119 Mtetra
.677 .689 .854 r
.7412 .24119 .74738 .25211 .76063 .2462 .75453 .23575 Mtetra
.678 .7 .863 r
.75453 .23575 .76063 .2462 .77395 .24037 .76791 .23033 Mtetra
.678 .71 .872 r
.76791 .23033 .77395 .24037 .78732 .23467 .78136 .22496 Mtetra
.677 .719 .881 r
.78136 .22496 .78732 .23467 .80077 .22911 .79488 .21967 Mtetra
.676 .726 .887 r
.79488 .21967 .80077 .22911 .81428 .2237 .80846 .21445 Mtetra
.674 .731 .893 r
.80846 .21445 .81428 .2237 .82787 .21843 .82211 .20932 Mtetra
.664 .741 .908 r
.2012 .41384 .20877 .42089 .21976 .41708 .21222 .41 Mtetra
.21222 .41 .21976 .41708 .2308 .41325 .22329 .40615 Mtetra
.22329 .40615 .2308 .41325 .24188 .40941 .2344 .40227 Mtetra
.2344 .40227 .24188 .40941 .25302 .40555 .24556 .39839 Mtetra
.24556 .39839 .25302 .40555 .26419 .40168 .25677 .39448 Mtetra
.663 .741 .908 r
.25677 .39448 .26419 .40168 .27542 .39779 .26802 .39056 Mtetra
.26802 .39056 .27542 .39779 .2867 .39388 .27932 .38663 Mtetra
.27932 .38663 .2867 .39388 .29802 .38996 .29068 .3827 Mtetra
.662 .742 .909 r
.29068 .3827 .29802 .38996 .30939 .38603 .30207 .37878 Mtetra
.66 .742 .911 r
.30207 .37878 .30939 .38603 .32081 .38209 .31352 .3749 Mtetra
.655 .744 .915 r
.31352 .3749 .32081 .38209 .33228 .37818 .32501 .37115 Mtetra
.647 .747 .922 r
.32501 .37115 .33228 .37818 .34379 .37431 .33653 .36759 Mtetra
.633 .753 .935 r
.33653 .36759 .34379 .37431 .35535 .37053 .34809 .36437 Mtetra
.608 .765 .954 r
.34809 .36437 .35535 .37053 .36696 .36692 .35968 .36161 Mtetra
.567 .781 .979 r
.35968 .36161 .36696 .36692 .3786 .36353 .37131 .35939 Mtetra
.499 .798 .999 r
.37131 .35939 .3786 .36353 .39029 .36041 .38297 .3577 Mtetra
.395 .798 .983 r
.38297 .3577 .39029 .36041 .40203 .35756 .3947 .35635 Mtetra
.279 .768 .909 r
.3947 .35635 .40203 .35756 .41382 .3549 .40649 .35499 Mtetra
.213 .737 .817 r
.40649 .35499 .41382 .3549 .42567 .35224 .41837 .35313 Mtetra
.242 .757 .781 r
.41837 .35313 .42567 .35224 .43759 .34934 .43035 .35032 Mtetra
.366 .836 .825 r
.43035 .35032 .43759 .34934 .44959 .34597 .44243 .34627 Mtetra
.537 .923 .905 r
.44243 .34627 .44959 .34597 .46166 .34197 .45459 .34095 Mtetra
.674 .952 .953 r
.45459 .34095 .46166 .34197 .47379 .33733 .46681 .33462 Mtetra
.738 .92 .954 r
.46681 .33462 .47379 .33733 .48598 .33219 .47908 .32773 Mtetra
.749 .866 .934 r
.47908 .32773 .48598 .33219 .49821 .32678 .49139 .32077 Mtetra
.736 .816 .914 r
.49139 .32077 .49821 .32678 .5105 .32137 .50373 .31414 Mtetra
.716 .776 .899 r
.50373 .31414 .5105 .32137 .52283 .31617 .5161 .30807 Mtetra
.696 .747 .891 r
.5161 .30807 .52283 .31617 .53521 .31132 .52851 .30259 Mtetra
.679 .727 .886 r
.52851 .30259 .53521 .31132 .54764 .30685 .54098 .29766 Mtetra
.666 .711 .882 r
.54098 .29766 .54764 .30685 .56013 .30272 .5535 .29313 Mtetra
.657 .699 .877 r
.5535 .29313 .56013 .30272 .57269 .29884 .56608 .28888 Mtetra
.651 .689 .872 r
.56608 .28888 .57269 .29884 .5853 .29513 .57872 .28479 Mtetra
.648 .68 .867 r
.57872 .28479 .5853 .29513 .59799 .29149 .59142 .28077 Mtetra
.646 .672 .861 r
.59142 .28077 .59799 .29149 .61074 .28783 .60419 .27677 Mtetra
.646 .666 .855 r
.60419 .27677 .61074 .28783 .62354 .28408 .61702 .27272 Mtetra
.647 .661 .85 r
.61702 .27272 .62354 .28408 .63641 .28017 .62991 .2686 Mtetra
.648 .658 .846 r
.62991 .2686 .63641 .28017 .64934 .27606 .64285 .26435 Mtetra
.651 .658 .844 r
.64285 .26435 .64934 .27606 .66232 .27171 .65586 .25997 Mtetra
.654 .659 .843 r
.65586 .25997 .66232 .27171 .67535 .26711 .66892 .25545 Mtetra
.657 .663 .844 r
.66892 .25545 .67535 .26711 .68842 .26226 .68203 .25077 Mtetra
.661 .669 .847 r
.68203 .25077 .68842 .26226 .70154 .25721 .6952 .24594 Mtetra
.664 .676 .851 r
.6952 .24594 .70154 .25721 .71471 .25197 .70842 .241 Mtetra
.667 .684 .856 r
.70842 .241 .71471 .25197 .72793 .24662 .7217 .23595 Mtetra
.67 .692 .862 r
.7217 .23595 .72793 .24662 .7412 .24119 .73503 .23085 Mtetra
.672 .701 .869 r
.73503 .23085 .7412 .24119 .75453 .23575 .74842 .22571 Mtetra
.673 .709 .875 r
.74842 .22571 .75453 .23575 .76791 .23033 .76186 .22055 Mtetra
.673 .716 .882 r
.76186 .22055 .76791 .23033 .78136 .22496 .77537 .21542 Mtetra
.672 .723 .887 r
.77537 .21542 .78136 .22496 .79488 .21967 .78895 .21031 Mtetra
.671 .728 .892 r
.78895 .21031 .79488 .21967 .80846 .21445 .80259 .20523 Mtetra
.67 .732 .896 r
.80259 .20523 .80846 .21445 .82211 .20932 .8163 .20019 Mtetra
.664 .741 .908 r
.19358 .40674 .2012 .41384 .21222 .41 .20462 .40287 Mtetra
.20462 .40287 .21222 .41 .22329 .40615 .21571 .39899 Mtetra
.21571 .39899 .22329 .40615 .2344 .40227 .22685 .39508 Mtetra
.663 .741 .908 r
.22685 .39508 .2344 .40227 .24556 .39839 .23804 .39116 Mtetra
.23804 .39116 .24556 .39839 .25677 .39448 .24928 .38723 Mtetra
.24928 .38723 .25677 .39448 .26802 .39056 .26056 .38329 Mtetra
.662 .741 .909 r
.26056 .38329 .26802 .39056 .27932 .38663 .27189 .37937 Mtetra
.66 .742 .91 r
.27189 .37937 .27932 .38663 .29068 .3827 .28327 .37548 Mtetra
.656 .743 .914 r
.28327 .37548 .29068 .3827 .30207 .37878 .29468 .3717 Mtetra
.647 .746 .921 r
.29468 .3717 .30207 .37878 .31352 .3749 .30613 .36814 Mtetra
.63 .751 .935 r
.30613 .36814 .31352 .3749 .32501 .37115 .31761 .36498 Mtetra
.598 .761 .957 r
.31761 .36498 .32501 .37115 .33653 .36759 .32911 .36244 Mtetra
.531 .774 .987 r
.32911 .36244 .33653 .36759 .34809 .36437 .34061 .36075 Mtetra
.388 .766 .991 r
.34061 .36075 .34809 .36437 .35968 .36161 .35213 .36006 Mtetra
.116 .654 .852 r
.35213 .36006 .35968 .36161 .37131 .35939 .36368 .36031 Mtetra
.174 0 0 r
.36368 .36031 .37131 .35939 .38297 .3577 .37528 .36116 Mtetra
.313 0 0 r
.37528 .36116 .38297 .3577 .3947 .35635 .38698 .36194 Mtetra
.327 0 0 r
.38698 .36194 .3947 .35635 .40649 .35499 .3988 .3618 Mtetra
.258 0 0 r
.3988 .3618 .40649 .35499 .41837 .35313 .41076 .3599 Mtetra
.097 0 0 r
.41076 .3599 .41837 .35313 .43035 .35032 .42287 .35574 Mtetra
0 0 0 r
.42287 .35574 .43035 .35032 .44243 .34627 .4351 .34932 Mtetra
.555 .921 .757 r
.4351 .34932 .44243 .34627 .45459 .34095 .4474 .34112 Mtetra
.767 .987 .899 r
.4474 .34112 .45459 .34095 .46681 .33462 .45976 .33197 Mtetra
.808 .924 .913 r
.45976 .33197 .46681 .33462 .47908 .32773 .47213 .32273 Mtetra
.789 .853 .898 r
.47213 .32273 .47908 .32773 .49139 .32077 .48451 .31409 Mtetra
.758 .801 .887 r
.48451 .31409 .49139 .32077 .50373 .31414 .4969 .30639 Mtetra
.728 .766 .883 r
.4969 .30639 .50373 .31414 .5161 .30807 .50931 .29972 Mtetra
.703 .745 .884 r
.50931 .29972 .5161 .30807 .52851 .30259 .52177 .29394 Mtetra
.684 .732 .887 r
.52177 .29394 .52851 .30259 .54098 .29766 .53427 .28881 Mtetra
.671 .723 .889 r
.53427 .28881 .54098 .29766 .5535 .29313 .54682 .28411 Mtetra
.663 .717 .889 r
.54682 .28411 .5535 .29313 .56608 .28888 .55943 .27967 Mtetra
.658 .711 .887 r
.55943 .27967 .56608 .28888 .57872 .28479 .57211 .27536 Mtetra
.655 .706 .884 r
.57211 .27536 .57872 .28479 .59142 .28077 .58484 .27111 Mtetra
.654 .701 .881 r
.58484 .27111 .59142 .28077 .60419 .27677 .59763 .26687 Mtetra
.654 .696 .877 r
.59763 .26687 .60419 .27677 .61702 .27272 .61049 .26261 Mtetra
.654 .692 .873 r
.61049 .26261 .61702 .27272 .62991 .2686 .6234 .25831 Mtetra
.655 .689 .87 r
.6234 .25831 .62991 .2686 .64285 .26435 .63638 .25394 Mtetra
.656 .688 .868 r
.63638 .25394 .64285 .26435 .65586 .25997 .64941 .24949 Mtetra
.658 .688 .867 r
.64941 .24949 .65586 .25997 .66892 .25545 .66251 .24495 Mtetra
.659 .689 .867 r
.66251 .24495 .66892 .25545 .68203 .25077 .67566 .24032 Mtetra
.662 .692 .868 r
.67566 .24032 .68203 .25077 .6952 .24594 .68887 .2356 Mtetra
.664 .696 .87 r
.68887 .2356 .6952 .24594 .70842 .241 .70213 .2308 Mtetra
.665 .701 .873 r
.70213 .2308 .70842 .241 .7217 .23595 .71546 .22592 Mtetra
.667 .707 .877 r
.71546 .22592 .7217 .23595 .73503 .23085 .72884 .22099 Mtetra
.668 .712 .881 r
.72884 .22099 .73503 .23085 .74842 .22571 .74229 .21602 Mtetra
.669 .718 .885 r
.74229 .21602 .74842 .22571 .76186 .22055 .75579 .21103 Mtetra
.669 .723 .89 r
.75579 .21103 .76186 .22055 .77537 .21542 .76936 .20603 Mtetra
.669 .727 .893 r
.76936 .20603 .77537 .21542 .78895 .21031 .78299 .20103 Mtetra
.668 .731 .897 r
.78299 .20103 .78895 .21031 .80259 .20523 .79669 .19604 Mtetra
.668 .734 .9 r
.79669 .19604 .80259 .20523 .8163 .20019 .81045 .19106 Mtetra
.664 .741 .908 r
.18589 .39958 .19358 .40674 .20462 .40287 .19696 .39568 Mtetra
.19696 .39568 .20462 .40287 .21571 .39899 .20808 .39177 Mtetra
.663 .741 .908 r
.20808 .39177 .21571 .39899 .22685 .39508 .21925 .38784 Mtetra
.21925 .38784 .22685 .39508 .23804 .39116 .23046 .38389 Mtetra
.663 .741 .909 r
.23046 .38389 .23804 .39116 .24928 .38723 .24173 .37995 Mtetra
.661 .742 .91 r
.24173 .37995 .24928 .38723 .26056 .38329 .25303 .37604 Mtetra
.658 .742 .912 r
.25303 .37604 .26056 .38329 .27189 .37937 .26438 .37222 Mtetra
.65 .744 .918 r
.26438 .37222 .27189 .37937 .28327 .37548 .27576 .36859 Mtetra
.634 .748 .931 r
.27576 .36859 .28327 .37548 .29468 .3717 .28717 .36536 Mtetra
.599 .756 .953 r
.28717 .36536 .29468 .3717 .30613 .36814 .29858 .36283 Mtetra
.52 .764 .986 r
.29858 .36283 .30613 .36814 .31761 .36498 .30997 .36136 Mtetra
.319 .73 .978 r
.30997 .36136 .31761 .36498 .32911 .36244 .32135 .36134 Mtetra
.104 0 0 r
.32135 .36134 .32911 .36244 .34061 .36075 .3327 .363 Mtetra
.441 0 0 r
.3327 .363 .34061 .36075 .35213 .36006 .34405 .36622 Mtetra
.544 .058 .053 r
.34405 .36622 .35213 .36006 .36368 .36031 .35546 .3704 Mtetra
.551 .118 .172 r
.35546 .3704 .36368 .36031 .37528 .36116 .36699 .37441 Mtetra
.516 .112 .212 r
.36699 .37441 .37528 .36116 .38698 .36194 .37871 .37679 Mtetra
.445 .052 .198 r
.37871 .37679 .38698 .36194 .3988 .3618 .39066 .37617 Mtetra
.315 0 .121 r
.39066 .37617 .3988 .3618 .41076 .3599 .40283 .37175 Mtetra
.067 0 0 r
.40283 .37175 .41076 .3599 .42287 .35574 .41518 .36357 Mtetra
0 0 0 r
.41518 .36357 .42287 .35574 .4351 .34932 .42765 .35252 Mtetra
.788 .995 .78 r
.42765 .35252 .4351 .34932 .4474 .34112 .44016 .33999 Mtetra
.872 .95 .859 r
.44016 .33999 .4474 .34112 .45976 .33197 .45266 .32744 Mtetra
.843 .863 .858 r
.45266 .32744 .45976 .33197 .47213 .32273 .46513 .31593 Mtetra
.799 .803 .855 r
.46513 .31593 .47213 .32273 .48451 .31409 .47758 .30602 Mtetra
.758 .766 .859 r
.47758 .30602 .48451 .31409 .4969 .30639 .49002 .29779 Mtetra
.725 .746 .868 r
.49002 .29779 .4969 .30639 .50931 .29972 .50248 .29099 Mtetra
.7 .736 .879 r
.50248 .29099 .50931 .29972 .52177 .29394 .51497 .28522 Mtetra
.682 .731 .888 r
.51497 .28522 .52177 .29394 .53427 .28881 .5275 .28011 Mtetra
.671 .729 .893 r
.5275 .28011 .53427 .28881 .54682 .28411 .54009 .2754 Mtetra
.665 .727 .896 r
.54009 .2754 .54682 .28411 .55943 .27967 .55274 .27088 Mtetra
.661 .725 .896 r
.55274 .27088 .55943 .27967 .57211 .27536 .56545 .26646 Mtetra
.659 .722 .895 r
.56545 .26646 .57211 .27536 .58484 .27111 .57821 .26206 Mtetra
.659 .719 .893 r
.57821 .26206 .58484 .27111 .59763 .26687 .59104 .25767 Mtetra
.658 .716 .891 r
.59104 .25767 .59763 .26687 .61049 .26261 .60393 .25326 Mtetra
.658 .714 .889 r
.60393 .25326 .61049 .26261 .6234 .25831 .61688 .24882 Mtetra
.659 .711 .887 r
.61688 .24882 .6234 .25831 .63638 .25394 .62989 .24435 Mtetra
.659 .71 .885 r
.62989 .24435 .63638 .25394 .64941 .24949 .64296 .23982 Mtetra
.66 .709 .884 r
.64296 .23982 .64941 .24949 .66251 .24495 .65609 .23524 Mtetra
.661 .71 .884 r
.65609 .23524 .66251 .24495 .67566 .24032 .66928 .2306 Mtetra
.662 .711 .884 r
.66928 .2306 .67566 .24032 .68887 .2356 .68253 .2259 Mtetra
.663 .713 .885 r
.68253 .2259 .68887 .2356 .70213 .2308 .69584 .22115 Mtetra
.664 .716 .887 r
.69584 .22115 .70213 .2308 .71546 .22592 .70921 .21635 Mtetra
.665 .719 .889 r
.70921 .21635 .71546 .22592 .72884 .22099 .72264 .2115 Mtetra
.666 .722 .891 r
.72264 .2115 .72884 .22099 .74229 .21602 .73613 .20661 Mtetra
.666 .725 .894 r
.73613 .20661 .74229 .21602 .75579 .21103 .74969 .2017 Mtetra
.666 .729 .896 r
.74969 .2017 .75579 .21103 .76936 .20603 .76331 .19677 Mtetra
.666 .731 .898 r
.76331 .19677 .76936 .20603 .78299 .20103 .77699 .19183 Mtetra
.666 .734 .9 r
.77699 .19183 .78299 .20103 .79669 .19604 .79074 .18687 Mtetra
.666 .736 .902 r
.79074 .18687 .79669 .19604 .81045 .19106 .80455 .18191 Mtetra
.663 .741 .908 r
.17814 .39237 .18589 .39958 .19696 .39568 .18924 .38844 Mtetra
.18924 .38844 .19696 .39568 .20808 .39177 .20039 .3845 Mtetra
.20039 .3845 .20808 .39177 .21925 .38784 .21158 .38055 Mtetra
.662 .741 .909 r
.21158 .38055 .21925 .38784 .23046 .38389 .22282 .37661 Mtetra
.66 .742 .911 r
.22282 .37661 .23046 .38389 .24173 .37995 .2341 .37273 Mtetra
.654 .743 .915 r
.2341 .37273 .24173 .37995 .25303 .37604 .24542 .369 Mtetra
.641 .746 .925 r
.24542 .369 .25303 .37604 .26438 .37222 .25676 .36561 Mtetra
.611 .751 .944 r
.25676 .36561 .26438 .37222 .27576 .36859 .2681 .36286 Mtetra
.54 .757 .977 r
.2681 .36286 .27576 .36859 .28717 .36536 .27941 .36122 Mtetra
.341 .725 .985 r
.27941 .36122 .28717 .36536 .29858 .36283 .29067 .36127 Mtetra
.152 0 0 r
.29067 .36127 .29858 .36283 .30997 .36136 .30184 .3636 Mtetra
.54 0 0 r
.30184 .3636 .30997 .36136 .32135 .36134 .31294 .36855 Mtetra
.635 .185 .165 r
.31294 .36855 .32135 .36134 .3327 .363 .324 .37591 Mtetra
.642 .248 .283 r
.324 .37591 .3327 .363 .34405 .36622 .33511 .3847 Mtetra
.619 .256 .332 r
.33511 .3847 .34405 .36622 .35546 .3704 .34639 .39311 Mtetra
.577 .23 .345 r
.34639 .39311 .35546 .3704 .36699 .37441 .35796 .39887 Mtetra
.507 .168 .326 r
.35796 .39887 .36699 .37441 .37871 .37679 .36988 .39986 Mtetra
.389 .049 .263 r
.36988 .39986 .37871 .37679 .39066 .37617 .38216 .39488 Mtetra
.153 0 .105 r
.38216 .39488 .39066 .37617 .40283 .37175 .39472 .3841 Mtetra
0 0 0 r
.39472 .3841 .40283 .37175 .41518 .36357 .40745 .36902 Mtetra
.848 .982 .693 r
.40745 .36902 .41518 .36357 .42765 .35252 .42021 .35184 Mtetra
.923 .927 .794 r
.42021 .35184 .42765 .35252 .44016 .33999 .43294 .3348 Mtetra
.877 .835 .801 r
.43294 .3348 .44016 .33999 .45266 .32744 .44557 .3195 Mtetra
.825 .777 .807 r
.44557 .3195 .45266 .32744 .46513 .31593 .45812 .30673 Mtetra
.781 .746 .821 r
.45812 .30673 .46513 .31593 .47758 .30602 .47062 .29654 Mtetra
.743 .731 .841 r
.47062 .29654 .47758 .30602 .49002 .29779 .4831 .28849 Mtetra
.713 .727 .861 r
.4831 .28849 .49002 .29779 .50248 .29099 .49559 .28199 Mtetra
.691 .728 .878 r
.49559 .28199 .50248 .29099 .51497 .28522 .50811 .27647 Mtetra
.677 .731 .891 r
.50811 .27647 .51497 .28522 .5275 .28011 .52068 .27152 Mtetra
.669 .733 .898 r
.52068 .27152 .5275 .28011 .54009 .2754 .53331 .26685 Mtetra
.665 .733 .901 r
.53331 .26685 .54009 .2754 .55274 .27088 .546 .26231 Mtetra
.663 .733 .902 r
.546 .26231 .55274 .27088 .56545 .26646 .55874 .25781 Mtetra
.662 .732 .902 r
.55874 .25781 .56545 .26646 .57821 .26206 .57154 .25333 Mtetra
.661 .73 .901 r
.57154 .25333 .57821 .26206 .59104 .25767 .58441 .24883 Mtetra
.661 .729 .899 r
.58441 .24883 .59104 .25767 .60393 .25326 .59733 .24432 Mtetra
.661 .727 .898 r
.59733 .24432 .60393 .25326 .61688 .24882 .61032 .23978 Mtetra
.661 .725 .897 r
.61032 .23978 .61688 .24882 .62989 .24435 .62336 .23522 Mtetra
.661 .724 .896 r
.62336 .23522 .62989 .24435 .64296 .23982 .63647 .23063 Mtetra
.662 .724 .895 r
.63647 .23063 .64296 .23982 .65609 .23524 .64964 .22599 Mtetra
.64964 .22599 .65609 .23524 .66928 .2306 .66286 .22132 Mtetra
.663 .724 .895 r
.66286 .22132 .66928 .2306 .68253 .2259 .67616 .21661 Mtetra
.663 .725 .895 r
.67616 .21661 .68253 .2259 .69584 .22115 .68951 .21186 Mtetra
.664 .726 .896 r
.68951 .21186 .69584 .22115 .70921 .21635 .70292 .20706 Mtetra
.664 .728 .897 r
.70292 .20706 .70921 .21635 .72264 .2115 .7164 .20224 Mtetra
.665 .73 .898 r
.7164 .20224 .72264 .2115 .73613 .20661 .72994 .19738 Mtetra
.665 .731 .899 r
.72994 .19738 .73613 .20661 .74969 .2017 .74354 .19249 Mtetra
.665 .733 .901 r
.74354 .19249 .74969 .2017 .76331 .19677 .75721 .18758 Mtetra
.665 .735 .902 r
.75721 .18758 .76331 .19677 .77699 .19183 .77095 .18265 Mtetra
.665 .736 .903 r
.77095 .18265 .77699 .19183 .79074 .18687 .78475 .17771 Mtetra
.665 .738 .904 r
.78475 .17771 .79074 .18687 .80455 .18191 .79861 .17275 Mtetra
.663 .741 .908 r
.17033 .3851 .17814 .39237 .18924 .38844 .18146 .38115 Mtetra
.18146 .38115 .18924 .38844 .20039 .3845 .19263 .37719 Mtetra
.661 .742 .91 r
.19263 .37719 .20039 .3845 .21158 .38055 .20385 .37326 Mtetra
.657 .742 .912 r
.20385 .37326 .21158 .38055 .22282 .37661 .2151 .36943 Mtetra
.648 .744 .919 r
.2151 .36943 .22282 .37661 .2341 .37273 .22638 .36583 Mtetra
.627 .747 .933 r
.22638 .36583 .2341 .37273 .24542 .369 .23767 .36275 Mtetra
.576 .752 .961 r
.23767 .36275 .24542 .369 .25676 .36561 .24893 .36062 Mtetra
.431 .74 .992 r
.24893 .36062 .25676 .36561 .2681 .36286 .26011 .36014 Mtetra
0 .538 .819 r
.26011 .36014 .2681 .36286 .27941 .36122 .27117 .36215 Mtetra
.539 0 0 r
.27117 .36215 .27941 .36122 .29067 .36127 .28207 .36747 Mtetra
.676 .226 .176 r
.28207 .36747 .29067 .36127 .30184 .3636 .29282 .37657 Mtetra
.692 .308 .316 r
.29282 .37657 .30184 .3636 .31294 .36855 .30347 .38913 Mtetra
.677 .329 .377 r
.30347 .38913 .31294 .36855 .324 .37591 .31417 .40365 Mtetra
.648 .319 .401 r
.31417 .40365 .324 .37591 .33511 .3847 .3251 .41749 Mtetra
.603 .285 .403 r
.3251 .41749 .33511 .3847 .34639 .39311 .33644 .42731 Mtetra
.534 .22 .382 r
.33644 .42731 .34639 .39311 .35796 .39887 .34833 .43007 Mtetra
.41 .097 .321 r
.34833 .43007 .35796 .39887 .36988 .39986 .36077 .42412 Mtetra
.141 0 .156 r
.36077 .42412 .36988 .39986 .38216 .39488 .37364 .40986 Mtetra
0 0 0 r
.37364 .40986 .38216 .39488 .39472 .3841 .38674 .3896 Mtetra
.941 .961 .679 r
.38674 .3896 .39472 .3841 .40745 .36902 .39989 .36662 Mtetra
.938 .859 .737 r
.39989 .36662 .40745 .36902 .42021 .35184 .41293 .3441 Mtetra
.88 .776 .743 r
.41293 .3441 .42021 .35184 .43294 .3348 .42581 .32426 Mtetra
.83 .73 .755 r
.42581 .32426 .43294 .3348 .44557 .3195 .43852 .30812 Mtetra
.788 .709 .777 r
.43852 .30812 .44557 .3195 .45812 .30673 .4511 .29565 Mtetra
.753 .704 .806 r
.4511 .29565 .45812 .30673 .47062 .29654 .46362 .28621 Mtetra
.722 .709 .837 r
.46362 .28621 .47062 .29654 .4831 .28849 .47612 .27891 Mtetra
.698 .718 .864 r
.47612 .27891 .4831 .28849 .49559 .28199 .48864 .27297 Mtetra
.682 .726 .884 r
.48864 .27297 .49559 .28199 .50811 .27647 .5012 .26779 Mtetra
.672 .732 .895 r
.5012 .26779 .50811 .27647 .52068 .27152 .51381 .263 Mtetra
.667 .736 .902 r
.51381 .263 .52068 .27152 .53331 .26685 .52647 .25838 Mtetra
.664 .737 .904 r
.52647 .25838 .53331 .26685 .546 .26231 .5392 .25382 Mtetra
.663 .737 .905 r
.5392 .25382 .546 .26231 .55874 .25781 .55198 .24927 Mtetra
.55198 .24927 .55874 .25781 .57154 .25333 .56482 .24472 Mtetra
.662 .736 .905 r
.56482 .24472 .57154 .25333 .58441 .24883 .57772 .24015 Mtetra
.662 .735 .904 r
.57772 .24015 .58441 .24883 .59733 .24432 .59068 .23557 Mtetra
.662 .734 .903 r
.59068 .23557 .59733 .24432 .61032 .23978 .60371 .23096 Mtetra
.662 .733 .903 r
.60371 .23096 .61032 .23978 .62336 .23522 .61679 .22633 Mtetra
.662 .733 .902 r
.61679 .22633 .62336 .23522 .63647 .23063 .62994 .22167 Mtetra
.663 .732 .901 r
.62994 .22167 .63647 .23063 .64964 .22599 .64314 .21699 Mtetra
.64314 .21699 .64964 .22599 .66286 .22132 .65641 .21227 Mtetra
.65641 .21227 .66286 .22132 .67616 .21661 .66975 .20753 Mtetra
.66975 .20753 .67616 .21661 .68951 .21186 .68314 .20275 Mtetra
.664 .733 .901 r
.68314 .20275 .68951 .21186 .70292 .20706 .6966 .19794 Mtetra
.664 .734 .902 r
.6966 .19794 .70292 .20706 .7164 .20224 .71012 .1931 Mtetra
.664 .735 .902 r
.71012 .1931 .7164 .20224 .72994 .19738 .72371 .18824 Mtetra
.664 .736 .903 r
.72371 .18824 .72994 .19738 .74354 .19249 .73736 .18334 Mtetra
.664 .737 .904 r
.73736 .18334 .74354 .19249 .75721 .18758 .75108 .17843 Mtetra
.75108 .17843 .75721 .18758 .77095 .18265 .76486 .17349 Mtetra
.664 .738 .905 r
.76486 .17349 .77095 .18265 .78475 .17771 .77871 .16852 Mtetra
.664 .739 .906 r
.77871 .16852 .78475 .17771 .79861 .17275 .79262 .16354 Mtetra
.662 .741 .909 r
.16246 .37778 .17033 .3851 .18146 .38115 .17361 .37382 Mtetra
.66 .742 .91 r
.17361 .37382 .18146 .38115 .19263 .37719 .1848 .36991 Mtetra
.655 .742 .914 r
.1848 .36991 .19263 .37719 .20385 .37326 .19603 .36614 Mtetra
.642 .744 .923 r
.19603 .36614 .20385 .37326 .2151 .36943 .20727 .3627 Mtetra
.61 .748 .943 r
.20727 .3627 .2151 .36943 .22638 .36583 .21849 .35997 Mtetra
.525 .749 .977 r
.21849 .35997 .22638 .36583 .23767 .36275 .22965 .35858 Mtetra
.247 .675 .962 r
.22965 .35858 .23767 .36275 .24893 .36062 .24068 .35943 Mtetra
.391 0 0 r
.24068 .35943 .24893 .36062 .26011 .36014 .2515 .36367 Mtetra
.678 .194 .094 r
.2515 .36367 .26011 .36014 .27117 .36215 .26206 .37238 Mtetra
.721 .326 .301 r
.26206 .37238 .27117 .36215 .28207 .36747 .27236 .38616 Mtetra
.716 .366 .384 r
.27236 .38616 .28207 .36747 .29282 .37657 .2825 .40451 Mtetra
.696 .37 .421 r
.2825 .40451 .29282 .37657 .30347 .38913 .29267 .42538 Mtetra
.665 .353 .434 r
.29267 .42538 .30347 .38913 .31417 .40365 .30316 .44515 Mtetra
.62 .315 .431 r
.30316 .44515 .31417 .40365 .3251 .41749 .31423 .45926 Mtetra
.547 .244 .406 r
.31423 .45926 .3251 .41749 .33644 .42731 .32609 .46366 Mtetra
.404 .103 .337 r
.32609 .46366 .33644 .42731 .34833 .43007 .33873 .45627 Mtetra
.033 0 .115 r
.33873 .45627 .34833 .43007 .36077 .42412 .35199 .43784 Mtetra
.782 .884 .465 r
.35199 .43784 .36077 .42412 .37364 .40986 .36559 .41167 Mtetra
.973 .882 .681 r
.36559 .41167 .37364 .40986 .38674 .3896 .37922 .38226 Mtetra
.912 .769 .691 r
.37922 .38226 .38674 .3896 .39989 .36662 .39267 .35381 Mtetra
.857 .707 .695 r
.39267 .35381 .39989 .36662 .41293 .3441 .40586 .32917 Mtetra
.815 .676 .709 r
.40586 .32917 .41293 .3441 .42581 .32426 .41877 .30953 Mtetra
.782 .665 .735 r
.41877 .30953 .42581 .32426 .43852 .30812 .43148 .29475 Mtetra
.752 .67 .771 r
.43148 .29475 .43852 .30812 .4511 .29565 .44405 .2839 Mtetra
.726 .685 .81 r
.44405 .2839 .4511 .29565 .46362 .28621 .45657 .27582 Mtetra
.703 .703 .847 r
.45657 .27582 .46362 .28621 .47612 .27891 .46909 .26947 Mtetra
.685 .718 .874 r
.46909 .26947 .47612 .27891 .48864 .27297 .48164 .26409 Mtetra
.674 .729 .891 r
.48164 .26409 .48864 .27297 .5012 .26779 .49423 .2592 Mtetra
.668 .735 .9 r
.49423 .2592 .5012 .26779 .51381 .263 .50687 .25452 Mtetra
.665 .738 .905 r
.50687 .25452 .51381 .263 .52647 .25838 .51958 .24992 Mtetra
.664 .739 .906 r
.51958 .24992 .52647 .25838 .5392 .25382 .53234 .24534 Mtetra
.663 .74 .907 r
.53234 .24534 .5392 .25382 .55198 .24927 .54516 .24075 Mtetra
.663 .739 .907 r
.54516 .24075 .55198 .24927 .56482 .24472 .55804 .23614 Mtetra
.663 .739 .906 r
.55804 .23614 .56482 .24472 .57772 .24015 .57098 .23152 Mtetra
.57098 .23152 .57772 .24015 .59068 .23557 .58398 .22688 Mtetra
.663 .738 .906 r
.58398 .22688 .59068 .23557 .60371 .23096 .59704 .22221 Mtetra
.663 .738 .905 r
.59704 .22221 .60371 .23096 .61679 .22633 .61017 .21753 Mtetra
.663 .737 .905 r
.61017 .21753 .61679 .22633 .62994 .22167 .62336 .21282 Mtetra
.62336 .21282 .62994 .22167 .64314 .21699 .6366 .20808 Mtetra
.6366 .20808 .64314 .21699 .65641 .21227 .64992 .20332 Mtetra
.64992 .20332 .65641 .21227 .66975 .20753 .66329 .19854 Mtetra
.66329 .19854 .66975 .20753 .68314 .20275 .67673 .19372 Mtetra
.67673 .19372 .68314 .20275 .6966 .19794 .69023 .18888 Mtetra
.664 .737 .905 r
.69023 .18888 .6966 .19794 .71012 .1931 .7038 .18401 Mtetra
.664 .738 .905 r
.7038 .18401 .71012 .1931 .72371 .18824 .71743 .17912 Mtetra
.71743 .17912 .72371 .18824 .73736 .18334 .73113 .1742 Mtetra
.664 .739 .906 r
.73113 .1742 .73736 .18334 .75108 .17843 .74489 .16926 Mtetra
.74489 .16926 .75108 .17843 .76486 .17349 .75872 .16429 Mtetra
.664 .74 .906 r
.75872 .16429 .76486 .17349 .77871 .16852 .77262 .1593 Mtetra
.664 .74 .907 r
.77262 .1593 .77871 .16852 .79262 .16354 .78658 .15429 Mtetra
.659 .742 .911 r
.15452 .37045 .16246 .37778 .17361 .37382 .16568 .36655 Mtetra
.652 .743 .916 r
.16568 .36655 .17361 .37382 .1848 .36991 .17688 .36284 Mtetra
.634 .745 .928 r
.17688 .36284 .1848 .36991 .19603 .36614 .18808 .35957 Mtetra
.59 .748 .952 r
.18808 .35957 .19603 .36614 .20727 .3627 .19923 .35721 Mtetra
.459 .737 .987 r
.19923 .35721 .20727 .3627 .21849 .35997 .21028 .35656 Mtetra
.011 .543 .849 r
.21028 .35656 .21849 .35997 .22965 .35858 .22113 .35875 Mtetra
.589 .029 0 r
.22113 .35875 .22965 .35858 .24068 .35943 .23168 .36521 Mtetra
.728 .295 .221 r
.23168 .36521 .24068 .35943 .2515 .36367 .24186 .37726 Mtetra
.742 .376 .359 r
.24186 .37726 .2515 .36367 .26206 .37238 .25168 .3956 Mtetra
.731 .398 .417 r
.25168 .3956 .26206 .37238 .27236 .38616 .26124 .41954 Mtetra
.71 .395 .442 r
.26124 .41954 .27236 .38616 .2825 .40451 .27084 .44645 Mtetra
.68 .374 .45 r
.27084 .44645 .2825 .40451 .29267 .42538 .28083 .47172 Mtetra
.634 .333 .443 r
.28083 .47172 .29267 .42538 .30316 .44515 .29161 .48964 Mtetra
.554 .253 .412 r
.29161 .48964 .30316 .44515 .31423 .45926 .30343 .4952 Mtetra
.369 .067 .316 r
.30343 .4952 .31423 .45926 .32609 .46366 .31632 .48598 Mtetra
0 0 0 r
.31632 .48598 .32609 .46366 .33873 .45627 .33003 .4632 Mtetra
.979 .917 .639 r
.33003 .4632 .33873 .45627 .35199 .43784 .34417 .43119 Mtetra
.927 .766 .663 r
.34417 .43119 .35199 .43784 .36559 .41167 .35834 .39567 Mtetra
.865 .684 .656 r
.35834 .39567 .36559 .41167 .37922 .38226 .37225 .36176 Mtetra
.822 .643 .66 r
.37225 .36176 .37922 .38226 .39267 .35381 .38578 .33281 Mtetra
.791 .625 .675 r
.38578 .33281 .39267 .35381 .40586 .32917 .39892 .31011 Mtetra
.766 .623 .702 r
.39892 .31011 .40586 .32917 .41877 .30953 .41176 .29334 Mtetra
.744 .636 .74 r
.41176 .29334 .41877 .30953 .43148 .29475 .4244 .28131 Mtetra
.723 .659 .786 r
.4244 .28131 .43148 .29475 .44405 .2839 .43694 .27259 Mtetra
.703 .686 .83 r
.43694 .27259 .44405 .2839 .45657 .27582 .44946 .26591 Mtetra
.686 .709 .865 r
.44946 .26591 .45657 .27582 .46909 .26947 .462 .26037 Mtetra
.675 .724 .887 r
.462 .26037 .46909 .26947 .48164 .26409 .47457 .25539 Mtetra
.668 .733 .899 r
.47457 .25539 .48164 .26409 .49423 .2592 .4872 .25067 Mtetra
.665 .738 .904 r
.4872 .25067 .49423 .2592 .50687 .25452 .49988 .24604 Mtetra
.664 .74 .906 r
.49988 .24604 .50687 .25452 .51958 .24992 .51262 .24143 Mtetra
.664 .74 .907 r
.51262 .24143 .51958 .24992 .53234 .24534 .52542 .23682 Mtetra
.663 .741 .907 r
.52542 .23682 .53234 .24534 .54516 .24075 .53828 .23219 Mtetra
.53828 .23219 .54516 .24075 .55804 .23614 .5512 .22754 Mtetra
.663 .74 .907 r
.5512 .22754 .55804 .23614 .57098 .23152 .56418 .22287 Mtetra
.56418 .22287 .57098 .23152 .58398 .22688 .57722 .21818 Mtetra
.57722 .21818 .58398 .22688 .59704 .22221 .59033 .21346 Mtetra
.59033 .21346 .59704 .22221 .61017 .21753 .60349 .20873 Mtetra
.60349 .20873 .61017 .21753 .62336 .21282 .61672 .20397 Mtetra
.663 .739 .907 r
.61672 .20397 .62336 .21282 .6366 .20808 .63001 .19919 Mtetra
.663 .739 .906 r
.63001 .19919 .6366 .20808 .64992 .20332 .64337 .19438 Mtetra
.64337 .19438 .64992 .20332 .66329 .19854 .65678 .18955 Mtetra
.65678 .18955 .66329 .19854 .67673 .19372 .67027 .1847 Mtetra
.67027 .1847 .67673 .19372 .69023 .18888 .68381 .17982 Mtetra
.664 .739 .906 r
.68381 .17982 .69023 .18888 .7038 .18401 .69742 .17491 Mtetra
.664 .74 .906 r
.69742 .17491 .7038 .18401 .71743 .17912 .7111 .16998 Mtetra
.664 .74 .907 r
.7111 .16998 .71743 .17912 .73113 .1742 .72484 .16503 Mtetra
.72484 .16503 .73113 .1742 .74489 .16926 .73865 .16005 Mtetra
.73865 .16005 .74489 .16926 .75872 .16429 .75253 .15505 Mtetra
.75253 .15505 .75872 .16429 .77262 .1593 .76648 .15002 Mtetra
.664 .741 .907 r
.76648 .15002 .77262 .1593 .78658 .15429 .78049 .14497 Mtetra
.65 .743 .918 r
.1465 .36317 .15452 .37045 .16568 .36655 .15766 .35951 Mtetra
.628 .745 .931 r
.15766 .35951 .16568 .36655 .17688 .36284 .16881 .35639 Mtetra
.571 .746 .96 r
.16881 .35639 .17688 .36284 .18808 .35957 .17991 .35435 Mtetra
.392 .717 .988 r
.17991 .35435 .18808 .35957 .19923 .35721 .19085 .35433 Mtetra
0 .395 .701 r
.19085 .35433 .19923 .35721 .21028 .35656 .20152 .35765 Mtetra
.67 .15 0 r
.20152 .35765 .21028 .35656 .22113 .35875 .21181 .36594 Mtetra
.751 .343 .278 r
.21181 .36594 .22113 .35875 .23168 .36521 .22163 .38069 Mtetra
.756 .403 .385 r
.22163 .38069 .23168 .36521 .24186 .37726 .23097 .40265 Mtetra
.744 .418 .431 r
.23097 .40265 .24186 .37726 .25168 .3956 .24 .43094 Mtetra
.724 .412 .451 r
.24 .43094 .25168 .3956 .26124 .41954 .24904 .46241 Mtetra
.694 .39 .455 r
.24904 .46241 .26124 .41954 .27084 .44645 .25858 .49167 Mtetra
.648 .345 .444 r
.25858 .49167 .27084 .44645 .28083 .47172 .26909 .51209 Mtetra
.557 .248 .4 r
.26909 .51209 .28083 .47172 .29161 .48964 .2809 .51798 Mtetra
.264 0 .223 r
.2809 .51798 .29161 .48964 .30343 .4952 .29402 .50681 Mtetra
.881 .941 .574 r
.29402 .50681 .30343 .4952 .31632 .48598 .30816 .48028 Mtetra
.931 .773 .662 r
.30816 .48028 .31632 .48598 .33003 .4632 .32282 .44364 Mtetra
.859 .665 .638 r
.32282 .44364 .33003 .4632 .34417 .43119 .33749 .40352 Mtetra
.816 .615 .631 r
.33749 .40352 .34417 .43119 .35834 .39567 .35183 .36568 Mtetra
.787 .591 .636 r
.35183 .36568 .35834 .39567 .37225 .36176 .36566 .33375 Mtetra
.765 .582 .651 r
.36566 .33375 .37225 .36176 .38578 .33281 .37901 .309 Mtetra
.747 .587 .677 r
.37901 .309 .38578 .33281 .39892 .31011 .39197 .29096 Mtetra
.732 .606 .717 r
.39197 .29096 .39892 .31011 .41176 .29334 .40467 .2782 Mtetra
.717 .635 .766 r
.40467 .2782 .41176 .29334 .4244 .28131 .41724 .26909 Mtetra
.701 .669 .816 r
.41724 .26909 .4244 .28131 .43694 .27259 .42976 .26222 Mtetra
.686 .699 .857 r
.42976 .26222 .43694 .27259 .44946 .26591 .44228 .25659 Mtetra
.675 .72 .883 r
.44228 .25659 .44946 .26591 .462 .26037 .45484 .25156 Mtetra
.668 .732 .897 r
.45484 .25156 .462 .26037 .47457 .25539 .46745 .24681 Mtetra
.665 .737 .904 r
.46745 .24681 .47457 .25539 .4872 .25067 .48011 .24216 Mtetra
.664 .74 .906 r
.48011 .24216 .4872 .25067 .49988 .24604 .49283 .23753 Mtetra
.664 .741 .907 r
.49283 .23753 .49988 .24604 .51262 .24143 .50561 .23289 Mtetra
.664 .741 .908 r
.50561 .23289 .51262 .24143 .52542 .23682 .51844 .22824 Mtetra
.51844 .22824 .52542 .23682 .53828 .23219 .53134 .22357 Mtetra
.663 .741 .908 r
.53134 .22357 .53828 .23219 .5512 .22754 .5443 .21888 Mtetra
.5443 .21888 .5512 .22754 .56418 .22287 .55732 .21416 Mtetra
.55732 .21416 .56418 .22287 .57722 .21818 .57041 .20943 Mtetra
.57041 .20943 .57722 .21818 .59033 .21346 .58355 .20467 Mtetra
.663 .741 .907 r
.58355 .20467 .59033 .21346 .60349 .20873 .59676 .19989 Mtetra
.59676 .19989 .60349 .20873 .61672 .20397 .61003 .19509 Mtetra
.663 .74 .907 r
.61003 .19509 .61672 .20397 .63001 .19919 .62336 .19026 Mtetra
.62336 .19026 .63001 .19919 .64337 .19438 .63676 .18541 Mtetra
.63676 .18541 .64337 .19438 .65678 .18955 .65022 .18054 Mtetra
.65022 .18054 .65678 .18955 .67027 .1847 .66375 .17564 Mtetra
.664 .74 .907 r
.66375 .17564 .67027 .1847 .68381 .17982 .67734 .17072 Mtetra
.67734 .17072 .68381 .17982 .69742 .17491 .69099 .16577 Mtetra
.69099 .16577 .69742 .17491 .7111 .16998 .70472 .1608 Mtetra
.664 .741 .907 r
.70472 .1608 .7111 .16998 .72484 .16503 .71851 .1558 Mtetra
.71851 .1558 .72484 .16503 .73865 .16005 .73236 .15078 Mtetra
.73236 .15078 .73865 .16005 .75253 .15505 .74629 .14574 Mtetra
.664 .741 .908 r
.74629 .14574 .75253 .15505 .76648 .15002 .76028 .14067 Mtetra
.76028 .14067 .76648 .15002 .78049 .14497 .77434 .13557 Mtetra
.623 .745 .934 r
.13837 .35615 .1465 .36317 .15766 .35951 .14949 .35311 Mtetra
.557 .745 .964 r
.14949 .35311 .15766 .35951 .16881 .35639 .16052 .35128 Mtetra
.345 .699 .983 r
.16052 .35128 .16881 .35639 .17991 .35435 .17137 .35165 Mtetra
.291 0 0 r
.17137 .35165 .17991 .35435 .19085 .35433 .1819 .35566 Mtetra
.701 .199 .043 r
.1819 .35566 .19085 .35433 .20152 .35765 .19199 .36502 Mtetra
.764 .365 .296 r
.19199 .36502 .20152 .35765 .21181 .36594 .20152 .38129 Mtetra
.767 .417 .392 r
.20152 .38129 .21181 .36594 .22163 .38069 .2105 .40517 Mtetra
.756 .43 .433 r
.2105 .40517 .22163 .38069 .23097 .40265 .21912 .43561 Mtetra
.738 .424 .45 r
.21912 .43561 .23097 .40265 .24 .43094 .22776 .46913 Mtetra
.712 .402 .451 r
.22776 .46913 .24 .43094 .24904 .46241 .23697 .49988 Mtetra
.667 .353 .431 r
.23697 .49988 .24904 .46241 .25858 .49167 .24729 .52083 Mtetra
.556 .221 .356 r
.24729 .52083 .25858 .49167 .26909 .51209 .25911 .52609 Mtetra
0 0 0 r
.25911 .52609 .26909 .51209 .2809 .51798 .27242 .51324 Mtetra
.924 .798 .702 r
.27242 .51324 .2809 .51798 .29402 .50681 .28688 .48443 Mtetra
.842 .647 .639 r
.28688 .48443 .29402 .50681 .30816 .48028 .30191 .44542 Mtetra
.8 .591 .619 r
.30191 .44542 .30816 .48028 .32282 .44364 .31694 .40325 Mtetra
.774 .564 .615 r
.31694 .40325 .32282 .44364 .33749 .40352 .33157 .36389 Mtetra
.755 .551 .62 r
.33157 .36389 .33749 .40352 .35183 .36568 .34562 .33096 Mtetra
.74 .549 .635 r
.34562 .33096 .35183 .36568 .36566 .33375 .35911 .30564 Mtetra
.728 .559 .662 r
.35911 .30564 .36566 .33375 .37901 .309 .37215 .28732 Mtetra
.718 .582 .702 r
.37215 .28732 .37901 .309 .39197 .29096 .38489 .27443 Mtetra
.708 .617 .753 r
.38489 .27443 .39197 .29096 .40467 .2782 .39747 .26527 Mtetra
.696 .657 .807 r
.39747 .26527 .40467 .2782 .41724 .26909 .40998 .25838 Mtetra
.684 .692 .852 r
.40998 .25838 .41724 .26909 .42976 .26222 .42249 .25273 Mtetra
.674 .717 .881 r
.42249 .25273 .42976 .26222 .44228 .25659 .43503 .2477 Mtetra
.668 .73 .896 r
.43503 .2477 .44228 .25659 .45484 .25156 .44762 .24293 Mtetra
.665 .737 .903 r
.44762 .24293 .45484 .25156 .46745 .24681 .46026 .23826 Mtetra
.664 .74 .906 r
.46026 .23826 .46745 .24681 .48011 .24216 .47296 .23361 Mtetra
.664 .741 .907 r
.47296 .23361 .48011 .24216 .49283 .23753 .48571 .22896 Mtetra
.664 .741 .908 r
.48571 .22896 .49283 .23753 .50561 .23289 .49853 .22429 Mtetra
.49853 .22429 .50561 .23289 .51844 .22824 .51141 .2196 Mtetra
.51141 .2196 .51844 .22824 .53134 .22357 .52435 .21488 Mtetra
.52435 .21488 .53134 .22357 .5443 .21888 .53735 .21015 Mtetra
.53735 .21015 .5443 .21888 .55732 .21416 .55041 .20539 Mtetra
.55041 .20539 .55732 .21416 .57041 .20943 .56353 .20062 Mtetra
.56353 .20062 .57041 .20943 .58355 .20467 .57672 .19581 Mtetra
.57672 .19581 .58355 .20467 .59676 .19989 .58997 .19099 Mtetra
.58997 .19099 .59676 .19989 .61003 .19509 .60328 .18614 Mtetra
.60328 .18614 .61003 .19509 .62336 .19026 .61665 .18127 Mtetra
.61665 .18127 .62336 .19026 .63676 .18541 .63009 .17638 Mtetra
.63009 .17638 .63676 .18541 .65022 .18054 .6436 .17146 Mtetra
.6436 .17146 .65022 .18054 .66375 .17564 .65717 .16652 Mtetra
.65717 .16652 .66375 .17564 .67734 .17072 .6708 .16155 Mtetra
.6708 .16155 .67734 .17072 .69099 .16577 .68451 .15656 Mtetra
.68451 .15656 .69099 .16577 .70472 .1608 .69828 .15155 Mtetra
.69828 .15155 .70472 .1608 .71851 .1558 .71211 .14651 Mtetra
.71211 .14651 .71851 .1558 .73236 .15078 .72602 .14144 Mtetra
.72602 .14144 .73236 .15078 .74629 .14574 .73999 .13635 Mtetra
.73999 .13635 .74629 .14574 .76028 .14067 .75403 .13124 Mtetra
.75403 .13124 .76028 .14067 .77434 .13557 .76814 .1261 Mtetra
.554 .743 .965 r
.1301 .3497 .13837 .35615 .14949 .35311 .14109 .34791 Mtetra
.338 .694 .982 r
.14109 .34791 .14949 .35311 .16052 .35128 .15188 .34836 Mtetra
.292 0 0 r
.15188 .34836 .16052 .35128 .17137 .35165 .16233 .35246 Mtetra
.704 .197 .028 r
.16233 .35246 .17137 .35165 .1819 .35566 .1723 .36189 Mtetra
.772 .367 .284 r
.1723 .36189 .1819 .35566 .19199 .36502 .18168 .37815 Mtetra
.778 .422 .381 r
.18168 .37815 .19199 .36502 .20152 .38129 .19048 .4018 Mtetra
.77 .437 .423 r
.19048 .4018 .20152 .38129 .2105 .40517 .19892 .43168 Mtetra
.756 .433 .438 r
.19892 .43168 .2105 .40517 .21912 .43561 .20739 .4642 Mtetra
.735 .412 .433 r
.20739 .4642 .21912 .43561 .22776 .46913 .21647 .49354 Mtetra
.696 .356 .396 r
.21647 .49354 .22776 .46913 .23697 .49988 .22675 .51288 Mtetra
.533 .113 .189 r
.22675 .51288 .23697 .49988 .24729 .52083 .23859 .51665 Mtetra
.861 .857 .836 r
.23859 .51665 .24729 .52083 .25911 .52609 .252 .50281 Mtetra
.805 .626 .659 r
.252 .50281 .25911 .52609 .27242 .51324 .26658 .47376 Mtetra
.774 .567 .619 r
.26658 .47376 .27242 .51324 .28688 .48443 .28174 .43523 Mtetra
.754 .54 .606 r
.28174 .43523 .28688 .48443 .30191 .44542 .29689 .39407 Mtetra
.74 .526 .604 r
.29689 .39407 .30191 .44542 .31694 .40325 .31162 .35595 Mtetra
.728 .521 .611 r
.31162 .35595 .31694 .40325 .33157 .36389 .32574 .32424 Mtetra
.719 .525 .627 r
.32574 .32424 .33157 .36389 .34562 .33096 .33927 .29995 Mtetra
.711 .539 .654 r
.33927 .29995 .34562 .33096 .35911 .30564 .35233 .28237 Mtetra
.705 .566 .695 r
.35233 .28237 .35911 .30564 .37215 .28732 .36507 .26999 Mtetra
.699 .605 .748 r
.36507 .26999 .37215 .28732 .38489 .27443 .37764 .26112 Mtetra
.691 .65 .804 r
.37764 .26112 .38489 .27443 .39747 .26527 .39013 .25439 Mtetra
.681 .689 .85 r
.39013 .25439 .39747 .26527 .40998 .25838 .40262 .24881 Mtetra
.673 .715 .88 r
.40262 .24881 .40998 .25838 .42249 .25273 .41514 .24379 Mtetra
.668 .73 .896 r
.41514 .24379 .42249 .25273 .43503 .2477 .42771 .23902 Mtetra
.665 .737 .903 r
.42771 .23902 .43503 .2477 .44762 .24293 .44033 .23434 Mtetra
.664 .74 .906 r
.44033 .23434 .44762 .24293 .46026 .23826 .453 .22968 Mtetra
.664 .741 .907 r
.453 .22968 .46026 .23826 .47296 .23361 .46574 .22501 Mtetra
.664 .741 .908 r
.46574 .22501 .47296 .23361 .48571 .22896 .47854 .22032 Mtetra
.47854 .22032 .48571 .22896 .49853 .22429 .49139 .21561 Mtetra
.49139 .21561 .49853 .22429 .51141 .2196 .50431 .21088 Mtetra
.50431 .21088 .51141 .2196 .52435 .21488 .51729 .20613 Mtetra
.51729 .20613 .52435 .21488 .53735 .21015 .53033 .20135 Mtetra
.53033 .20135 .53735 .21015 .55041 .20539 .54343 .19655 Mtetra
.54343 .19655 .55041 .20539 .56353 .20062 .55659 .19173 Mtetra
.55659 .19173 .56353 .20062 .57672 .19581 .56982 .18689 Mtetra
.56982 .18689 .57672 .19581 .58997 .19099 .58311 .18202 Mtetra
.58311 .18202 .58997 .19099 .60328 .18614 .59647 .17713 Mtetra
.59647 .17713 .60328 .18614 .61665 .18127 .60989 .17221 Mtetra
.60989 .17221 .61665 .18127 .63009 .17638 .62337 .16727 Mtetra
.62337 .16727 .63009 .17638 .6436 .17146 .63692 .16231 Mtetra
.63692 .16231 .6436 .17146 .65717 .16652 .65053 .15733 Mtetra
.65053 .15733 .65717 .16652 .6708 .16155 .66421 .15231 Mtetra
.66421 .15231 .6708 .16155 .68451 .15656 .67796 .14728 Mtetra
.67796 .14728 .68451 .15656 .69828 .15155 .69178 .14222 Mtetra
.69178 .14222 .69828 .15155 .71211 .14651 .70566 .13713 Mtetra
.70566 .13713 .71211 .14651 .72602 .14144 .71961 .13202 Mtetra
.71961 .13202 .72602 .14144 .73999 .13635 .73363 .12689 Mtetra
.73363 .12689 .73999 .13635 .75403 .13124 .74772 .12173 Mtetra
.74772 .12173 .75403 .13124 .76814 .1261 .76188 .11654 Mtetra
.374 .704 .985 r
.12163 .34422 .1301 .3497 .14109 .34791 .1324 .34439 Mtetra
0 .386 .716 r
.1324 .34439 .14109 .34791 .15188 .34836 .14283 .34797 Mtetra
.674 .14 0 r
.14283 .34797 .15188 .34836 .16233 .35246 .1528 .35647 Mtetra
.773 .346 .235 r
.1528 .35647 .16233 .35246 .1723 .36189 .16219 .37117 Mtetra
.788 .414 .349 r
.16219 .37117 .1723 .36189 .18168 .37815 .17104 .3925 Mtetra
.786 .437 .395 r
.17104 .3925 .18168 .37815 .19048 .4018 .17955 .41922 Mtetra
.779 .437 .408 r
.17955 .41922 .19048 .4018 .19892 .43168 .18812 .44794 Mtetra
.768 .417 .39 r
.18812 .44794 .19892 .43168 .20739 .4642 .19732 .47332 Mtetra
.743 .34 .288 r
.19732 .47332 .20739 .4642 .21647 .49354 .20768 .48929 Mtetra
.116 .604 .91 r
.20768 .48929 .21647 .49354 .22675 .51288 .21955 .49109 Mtetra
.726 .591 .705 r
.21955 .49109 .22675 .51288 .23859 .51665 .23291 .47719 Mtetra
.733 .538 .629 r
.23291 .47719 .23859 .51665 .252 .50281 .2474 .44995 Mtetra
.727 .517 .606 r
.2474 .44995 .252 .50281 .26658 .47376 .26242 .41461 Mtetra
.72 .505 .598 r
.26242 .41461 .26658 .47376 .28174 .43523 .27743 .37724 Mtetra
.713 .5 .599 r
.27743 .37724 .28174 .43523 .29689 .39407 .29203 .34282 Mtetra
.706 .5 .608 r
.29203 .34282 .29689 .39407 .31162 .35595 .30605 .31425 Mtetra
.7 .509 .625 r
.30605 .31425 .31162 .35595 .32574 .32424 .3195 .29233 Mtetra
.697 .527 .654 r
.3195 .29233 .32574 .32424 .33927 .29995 .3325 .27639 Mtetra
.694 .558 .696 r
.3325 .27639 .33927 .29995 .35233 .28237 .3452 .26501 Mtetra
.691 .601 .751 r
.3452 .26501 .35233 .28237 .36507 .26999 .35774 .25672 Mtetra
.686 .649 .807 r
.35774 .25672 .36507 .26999 .37764 .26112 .37021 .25028 Mtetra
.678 .689 .853 r
.37021 .25028 .37764 .26112 .39013 .25439 .38268 .24483 Mtetra
.671 .716 .882 r
.38268 .24483 .39013 .25439 .40262 .24881 .39518 .23986 Mtetra
.667 .73 .897 r
.39518 .23986 .40262 .24881 .41514 .24379 .40772 .2351 Mtetra
.665 .737 .904 r
.40772 .2351 .41514 .24379 .42771 .23902 .42032 .23041 Mtetra
.664 .74 .906 r
.42032 .23041 .42771 .23902 .44033 .23434 .43297 .22573 Mtetra
.664 .741 .907 r
.43297 .22573 .44033 .23434 .453 .22968 .44569 .22104 Mtetra
.664 .741 .908 r
.44569 .22104 .453 .22968 .46574 .22501 .45846 .21634 Mtetra
.45846 .21634 .46574 .22501 .47854 .22032 .4713 .21161 Mtetra
.4713 .21161 .47854 .22032 .49139 .21561 .48419 .20686 Mtetra
.48419 .20686 .49139 .21561 .50431 .21088 .49715 .20209 Mtetra
.49715 .20209 .50431 .21088 .51729 .20613 .51017 .19729 Mtetra
.51017 .19729 .51729 .20613 .53033 .20135 .52325 .19247 Mtetra
.52325 .19247 .53033 .20135 .54343 .19655 .53639 .18763 Mtetra
.53639 .18763 .54343 .19655 .55659 .19173 .5496 .18277 Mtetra
.5496 .18277 .55659 .19173 .56982 .18689 .56287 .17788 Mtetra
.56287 .17788 .56982 .18689 .58311 .18202 .5762 .17297 Mtetra
.5762 .17297 .58311 .18202 .59647 .17713 .5896 .16803 Mtetra
.5896 .16803 .59647 .17713 .60989 .17221 .60306 .16307 Mtetra
.60306 .16307 .60989 .17221 .62337 .16727 .61659 .15809 Mtetra
.61659 .15809 .62337 .16727 .63692 .16231 .63018 .15308 Mtetra
.63018 .15308 .63692 .16231 .65053 .15733 .64384 .14805 Mtetra
.64384 .14805 .65053 .15733 .66421 .15231 .65757 .143 Mtetra
.65757 .143 .66421 .15231 .67796 .14728 .67136 .13792 Mtetra
.67136 .13792 .67796 .14728 .69178 .14222 .68522 .13281 Mtetra
.68522 .13281 .69178 .14222 .70566 .13713 .69915 .12768 Mtetra
.69915 .12768 .70566 .13713 .71961 .13202 .71315 .12252 Mtetra
.71315 .12252 .71961 .13202 .73363 .12689 .72722 .11734 Mtetra
.72722 .11734 .73363 .12689 .74772 .12173 .74135 .11213 Mtetra
.74135 .11213 .74772 .12173 .76188 .11654 .75556 .1069 Mtetra
.011 .524 .862 r
.11292 .33986 .12163 .34422 .1324 .34439 .12341 .34241 Mtetra
.572 0 0 r
.12341 .34241 .1324 .34439 .14283 .34797 .13347 .34915 Mtetra
.755 .283 .122 r
.13347 .34915 .14283 .34797 .1528 .35647 .14304 .36112 Mtetra
.793 .384 .276 r
.14304 .36112 .1528 .35647 .16219 .37117 .15214 .37854 Mtetra
.802 .421 .334 r
.15214 .37854 .16219 .37117 .17104 .3925 .16095 .40024 Mtetra
.806 .428 .34 r
.16095 .40024 .17104 .3925 .17955 .41922 .16986 .42324 Mtetra
.811 .403 .274 r
.16986 .42324 .17955 .41922 .18812 .44794 .17935 .44305 Mtetra
.697 .161 0 r
.17935 .44305 .18812 .44794 .19732 .47332 .1899 .45471 Mtetra
.532 .508 .774 r
.1899 .45471 .19732 .47332 .20768 .48929 .20179 .4545 Mtetra
.667 .502 .653 r
.20179 .4545 .20768 .48929 .21955 .49109 .21499 .44141 Mtetra
.69 .492 .615 r
.21499 .44141 .21955 .49109 .23291 .47719 .22917 .41755 Mtetra
.695 .486 .6 r
.22917 .41755 .23291 .47719 .2474 .44995 .24382 .38728 Mtetra
.694 .482 .596 r
.24382 .38728 .2474 .44995 .26242 .41461 .25845 .35558 Mtetra
.691 .482 .599 r
.25845 .35558 .26242 .41461 .27743 .37724 .27273 .32647 Mtetra
.688 .488 .61 r
.27273 .32647 .27743 .37724 .29203 .34282 .2865 .30227 Mtetra
.686 .5 .63 r
.2865 .30227 .29203 .34282 .30605 .31425 .29978 .28358 Mtetra
.685 .523 .661 r
.29978 .28358 .30605 .31425 .3195 .29233 .31267 .2698 Mtetra
.685 .559 .706 r
.31267 .2698 .3195 .29233 .3325 .27639 .32529 .25974 Mtetra
.684 .605 .762 r
.32529 .25974 .3325 .27639 .3452 .26501 .33778 .25217 Mtetra
.681 .654 .817 r
.33778 .25217 .3452 .26501 .35774 .25672 .35022 .2461 Mtetra
.675 .693 .859 r
.35022 .2461 .35774 .25672 .37021 .25028 .36266 .24081 Mtetra
.67 .718 .885 r
.36266 .24081 .37021 .25028 .38268 .24483 .37513 .23591 Mtetra
.666 .731 .898 r
.37513 .23591 .38268 .24483 .39518 .23986 .38766 .23116 Mtetra
.664 .737 .904 r
.38766 .23116 .39518 .23986 .40772 .2351 .40023 .22646 Mtetra
.664 .74 .907 r
.40023 .22646 .40772 .2351 .42032 .23041 .41286 .22177 Mtetra
.664 .741 .907 r
.41286 .22177 .42032 .23041 .43297 .22573 .42556 .21706 Mtetra
.664 .741 .908 r
.42556 .21706 .43297 .22573 .44569 .22104 .43831 .21234 Mtetra
.43831 .21234 .44569 .22104 .45846 .21634 .45112 .20759 Mtetra
.45112 .20759 .45846 .21634 .4713 .21161 .46399 .20282 Mtetra
.46399 .20282 .4713 .21161 .48419 .20686 .47693 .19803 Mtetra
.47693 .19803 .48419 .20686 .49715 .20209 .48993 .19321 Mtetra
.48993 .19321 .49715 .20209 .51017 .19729 .50298 .18838 Mtetra
.50298 .18838 .51017 .19729 .52325 .19247 .5161 .18352 Mtetra
.5161 .18352 .52325 .19247 .53639 .18763 .52929 .17863 Mtetra
.52929 .17863 .53639 .18763 .5496 .18277 .54254 .17372 Mtetra
.54254 .17372 .5496 .18277 .56287 .17788 .55585 .16879 Mtetra
.55585 .16879 .56287 .17788 .5762 .17297 .56922 .16384 Mtetra
.56922 .16384 .5762 .17297 .5896 .16803 .58266 .15886 Mtetra
.58266 .15886 .5896 .16803 .60306 .16307 .59617 .15386 Mtetra
.59617 .15386 .60306 .16307 .61659 .15809 .60974 .14883 Mtetra
.60974 .14883 .61659 .15809 .63018 .15308 .62338 .14378 Mtetra
.62338 .14378 .63018 .15308 .64384 .14805 .63708 .1387 Mtetra
.63708 .1387 .64384 .14805 .65757 .143 .65086 .1336 Mtetra
.65086 .1336 .65757 .143 .67136 .13792 .6647 .12847 Mtetra
.6647 .12847 .67136 .13792 .68522 .13281 .6786 .12332 Mtetra
.6786 .12332 .68522 .13281 .69915 .12768 .69258 .11814 Mtetra
.69258 .11814 .69915 .12768 .71315 .12252 .70663 .11294 Mtetra
.70663 .11294 .71315 .12252 .72722 .11734 .72074 .10771 Mtetra
.72074 .10771 .72722 .11734 .74135 .11213 .73493 .10245 Mtetra
.73493 .10245 .74135 .11213 .75556 .1069 .74918 .09717 Mtetra
.303 0 0 r
.10402 .33619 .11292 .33986 .12341 .34241 .11427 .34071 Mtetra
.668 .12 0 r
.11427 .34071 .12341 .34241 .13347 .34915 .12412 .3493 Mtetra
.772 .297 .11 r
.12412 .3493 .13347 .34915 .14304 .36112 .13359 .36204 Mtetra
.805 .362 .191 r
.13359 .36204 .14304 .36112 .15214 .37854 .14287 .3779 Mtetra
.82 .369 .162 r
.14287 .3779 .15214 .37854 .16095 .40024 .15225 .39446 Mtetra
.764 .257 0 r
.15225 .39446 .16095 .40024 .16986 .42324 .16215 .40823 Mtetra
.152 .329 .789 r
.16215 .40823 .16986 .42324 .17935 .44305 .17294 .41551 Mtetra
.562 .458 .693 r
.17294 .41551 .17935 .44305 .1899 .45471 .18483 .4136 Mtetra
.639 .467 .635 r
.18483 .4136 .1899 .45471 .20179 .4545 .19778 .40192 Mtetra
.663 .468 .611 r
.19778 .40192 .20179 .4545 .21499 .44141 .21152 .38221 Mtetra
.672 .468 .601 r
.21152 .38221 .21499 .44141 .22917 .41755 .22565 .35781 Mtetra
.675 .469 .599 r
.22565 .35781 .22917 .41755 .24382 .38728 .23976 .33248 Mtetra
.675 .473 .605 r
.23976 .33248 .24382 .38728 .25845 .35558 .2536 .30924 Mtetra
.675 .483 .618 r
.2536 .30924 .25845 .35558 .27273 .32647 .26703 .2898 Mtetra
.675 .5 .641 r
.26703 .2898 .27273 .32647 .2865 .30227 .28007 .27458 Mtetra
.677 .528 .676 r
.28007 .27458 .2865 .30227 .29978 .28358 .2928 .26308 Mtetra
.679 .569 .724 r
.2928 .26308 .29978 .28358 .31267 .2698 .30533 .25441 Mtetra
.679 .618 .78 r
.30533 .25441 .31267 .2698 .32529 .25974 .31776 .2476 Mtetra
.677 .665 .831 r
.31776 .2476 .32529 .25974 .33778 .25217 .33016 .2419 Mtetra
.672 .701 .868 r
.33016 .2419 .33778 .25217 .35022 .2461 .34257 .23678 Mtetra
.668 .722 .89 r
.34257 .23678 .35022 .2461 .36266 .24081 .35501 .23194 Mtetra
.665 .733 .9 r
.35501 .23194 .36266 .24081 .37513 .23591 .36751 .2272 Mtetra
.664 .738 .905 r
.36751 .2272 .37513 .23591 .38766 .23116 .38006 .2225 Mtetra
.664 .74 .907 r
.38006 .2225 .38766 .23116 .40023 .22646 .39267 .21779 Mtetra
.664 .741 .908 r
.39267 .21779 .40023 .22646 .41286 .22177 .40534 .21307 Mtetra
.40534 .21307 .41286 .22177 .42556 .21706 .41807 .20832 Mtetra
.41807 .20832 .42556 .21706 .43831 .21234 .43086 .20356 Mtetra
.43086 .20356 .43831 .21234 .45112 .20759 .44372 .19877 Mtetra
.44372 .19877 .45112 .20759 .46399 .20282 .45663 .19396 Mtetra
.45663 .19396 .46399 .20282 .47693 .19803 .4696 .18912 Mtetra
.4696 .18912 .47693 .19803 .48993 .19321 .48264 .18427 Mtetra
.48264 .18427 .48993 .19321 .50298 .18838 .49574 .17939 Mtetra
.49574 .17939 .50298 .18838 .5161 .18352 .5089 .17448 Mtetra
.5089 .17448 .5161 .18352 .52929 .17863 .52212 .16955 Mtetra
.52212 .16955 .52929 .17863 .54254 .17372 .53541 .1646 Mtetra
.53541 .1646 .54254 .17372 .55585 .16879 .54877 .15963 Mtetra
.54877 .15963 .55585 .16879 .56922 .16384 .56218 .15463 Mtetra
.56218 .15463 .56922 .16384 .58266 .15886 .57567 .1496 Mtetra
.57567 .1496 .58266 .15886 .59617 .15386 .58922 .14455 Mtetra
.58922 .14455 .59617 .15386 .60974 .14883 .60283 .13948 Mtetra
.60283 .13948 .60974 .14883 .62338 .14378 .61652 .13438 Mtetra
.61652 .13438 .62338 .14378 .63708 .1387 .63027 .12926 Mtetra
.63027 .12926 .63708 .1387 .65086 .1336 .64408 .12411 Mtetra
.64408 .12411 .65086 .1336 .6647 .12847 .65797 .11894 Mtetra
.65797 .11894 .6647 .12847 .6786 .12332 .67193 .11374 Mtetra
.67193 .11374 .6786 .12332 .69258 .11814 .68595 .10851 Mtetra
.68595 .10851 .69258 .11814 .70663 .11294 .70004 .10326 Mtetra
.70004 .10326 .70663 .11294 .72074 .10771 .71421 .09798 Mtetra
.71421 .09798 .72074 .10771 .73493 .10245 .72844 .09268 Mtetra
.72844 .09268 .73493 .10245 .74918 .09717 .74275 .08735 Mtetra
.343 0 0 r
.09509 .33202 .10402 .33619 .11427 .34071 .10526 .33718 Mtetra
.608 .039 0 r
.10526 .33718 .11427 .34071 .12412 .3493 .11518 .34526 Mtetra
.692 .149 0 r
.11518 .34526 .12412 .3493 .13359 .36204 .12497 .35543 Mtetra
.625 .092 0 r
.12497 .35543 .13359 .36204 .14287 .3779 .13487 .36589 Mtetra
0 .235 .753 r
.13487 .36589 .14287 .3779 .15225 .39446 .1452 .37413 Mtetra
.425 .422 .752 r
.1452 .37413 .15225 .39446 .16215 .40823 .15621 .37757 Mtetra
.575 .451 .674 r
.15621 .37757 .16215 .40823 .17294 .41551 .16808 .37443 Mtetra
.625 .457 .634 r
.16808 .37443 .17294 .41551 .18483 .4136 .18074 .36443 Mtetra
.647 .459 .615 r
.18074 .36443 .18483 .4136 .19778 .40192 .194 .34886 Mtetra
.657 .461 .608 r
.194 .34886 .19778 .40192 .21152 .38221 .20755 .33011 Mtetra
.661 .466 .609 r
.20755 .33011 .21152 .38221 .22565 .35781 .22111 .31081 Mtetra
.664 .474 .618 r
.22111 .31081 .22565 .35781 .23976 .33248 .23446 .29307 Mtetra
.666 .488 .634 r
.23446 .29307 .23976 .33248 .2536 .30924 .24752 .27805 Mtetra
.668 .51 .662 r
.24752 .27805 .2536 .30924 .26703 .2898 .2603 .26604 Mtetra
.672 .544 .701 r
.2603 .26604 .26703 .2898 .28007 .27458 .27286 .25665 Mtetra
.675 .588 .751 r
.27286 .25665 .28007 .27458 .2928 .26308 .28529 .24923 Mtetra
.676 .637 .803 r
.28529 .24923 .2928 .26308 .30533 .25441 .29766 .2431 Mtetra
.673 .68 .848 r
.29766 .2431 .30533 .25441 .31776 .2476 .31001 .23773 Mtetra
.67 .709 .878 r
.31001 .23773 .31776 .2476 .33016 .2419 .32239 .23276 Mtetra
.666 .727 .894 r
.32239 .23276 .33016 .2419 .34257 .23678 .33481 .22796 Mtetra
.665 .735 .902 r
.33481 .22796 .34257 .23678 .35501 .23194 .34729 .22323 Mtetra
.664 .739 .906 r
.34729 .22323 .35501 .23194 .36751 .2272 .35982 .21852 Mtetra
.664 .74 .907 r
.35982 .21852 .36751 .2272 .38006 .2225 .3724 .21379 Mtetra
.664 .741 .908 r
.3724 .21379 .38006 .2225 .39267 .21779 .38505 .20905 Mtetra
.38505 .20905 .39267 .21779 .40534 .21307 .39776 .20429 Mtetra
.39776 .20429 .40534 .21307 .41807 .20832 .41053 .19951 Mtetra
.41053 .19951 .41807 .20832 .43086 .20356 .42335 .1947 Mtetra
.42335 .1947 .43086 .20356 .44372 .19877 .43624 .18987 Mtetra
.43624 .18987 .44372 .19877 .45663 .19396 .4492 .18501 Mtetra
.4492 .18501 .45663 .19396 .4696 .18912 .46221 .18014 Mtetra
.46221 .18014 .4696 .18912 .48264 .18427 .47529 .17524 Mtetra
.47529 .17524 .48264 .18427 .49574 .17939 .48843 .17031 Mtetra
.48843 .17031 .49574 .17939 .5089 .17448 .50163 .16537 Mtetra
.50163 .16537 .5089 .17448 .52212 .16955 .51489 .16039 Mtetra
.51489 .16039 .52212 .16955 .53541 .1646 .52823 .1554 Mtetra
.52823 .1554 .53541 .1646 .54877 .15963 .54162 .15038 Mtetra
.54162 .15038 .54877 .15963 .56218 .15463 .55508 .14533 Mtetra
.55508 .14533 .56218 .15463 .57567 .1496 .56861 .14026 Mtetra
.56861 .14026 .57567 .1496 .58922 .14455 .5822 .13517 Mtetra
.5822 .13517 .58922 .14455 .60283 .13948 .59586 .13005 Mtetra
.59586 .13005 .60283 .13948 .61652 .13438 .60959 .12491 Mtetra
.60959 .12491 .61652 .13438 .63027 .12926 .62339 .11974 Mtetra
.62339 .11974 .63027 .12926 .64408 .12411 .63725 .11454 Mtetra
.63725 .11454 .64408 .12411 .65797 .11894 .65119 .10932 Mtetra
.65119 .10932 .65797 .11894 .67193 .11374 .66519 .10407 Mtetra
.66519 .10407 .67193 .11374 .68595 .10851 .67926 .0988 Mtetra
.67926 .0988 .68595 .10851 .70004 .10326 .6934 .0935 Mtetra
.6934 .0935 .70004 .10326 .71421 .09798 .70762 .08817 Mtetra
.70762 .08817 .71421 .09798 .72844 .09268 .7219 .08282 Mtetra
.7219 .08282 .72844 .09268 .74275 .08735 .73626 .07744 Mtetra
0 .425 .833 r
.08632 .32592 .09509 .33202 .10526 .33718 .09665 .32995 Mtetra
0 .34 .791 r
.09665 .32995 .10526 .33718 .11518 .34526 .10692 .33528 Mtetra
.053 .386 .848 r
.10692 .33528 .11518 .34526 .12497 .35543 .1173 .34066 Mtetra
.346 .449 .823 r
.1173 .34066 .12497 .35543 .13487 .36589 .128 .34442 Mtetra
.513 .463 .739 r
.128 .34442 .13487 .36589 .1452 .37413 .13921 .34489 Mtetra
.586 .463 .679 r
.13921 .34489 .1452 .37413 .15621 .37757 .15103 .34099 Mtetra
.621 .463 .646 r
.15103 .34099 .15621 .37757 .16808 .37443 .16341 .33259 Mtetra
.638 .464 .63 r
.16341 .33259 .16808 .37443 .18074 .36443 .17622 .32062 Mtetra
.648 .467 .625 r
.17622 .32062 .18074 .36443 .194 .34886 .18924 .30664 Mtetra
.653 .473 .628 r
.18924 .30664 .194 .34886 .20755 .33011 .20227 .29237 Mtetra
.657 .485 .64 r
.20227 .29237 .20755 .33011 .22111 .31081 .21518 .27918 Mtetra
.661 .504 .661 r
.21518 .27918 .22111 .31081 .23446 .29307 .2279 .26781 Mtetra
.665 .532 .692 r
.2279 .26781 .23446 .29307 .24752 .27805 .24044 .2584 Mtetra
.67 .571 .735 r
.24044 .2584 .24752 .27805 .2603 .26604 .25284 .25071 Mtetra
.673 .616 .784 r
.25284 .25071 .2603 .26604 .27286 .25665 .26517 .2443 Mtetra
.673 .66 .83 r
.26517 .2443 .27286 .25665 .28529 .24923 .27747 .23871 Mtetra
.67 .696 .865 r
.27747 .23871 .28529 .24923 .29766 .2431 .28979 .2336 Mtetra
.667 .718 .887 r
.28979 .2336 .29766 .2431 .31001 .23773 .30214 .22874 Mtetra
.665 .731 .899 r
.30214 .22874 .31001 .23773 .32239 .23276 .31453 .22398 Mtetra
.664 .737 .904 r
.31453 .22398 .32239 .23276 .33481 .22796 .32698 .21925 Mtetra
.664 .74 .906 r
.32698 .21925 .33481 .22796 .34729 .22323 .33949 .21452 Mtetra
.664 .741 .907 r
.33949 .21452 .34729 .22323 .35982 .21852 .35205 .20978 Mtetra
.664 .741 .908 r
.35205 .20978 .35982 .21852 .3724 .21379 .36468 .20503 Mtetra
.36468 .20503 .3724 .21379 .38505 .20905 .37736 .20024 Mtetra
.37736 .20024 .38505 .20905 .39776 .20429 .39011 .19544 Mtetra
.39011 .19544 .39776 .20429 .41053 .19951 .40291 .19061 Mtetra
.40291 .19061 .41053 .19951 .42335 .1947 .41578 .18576 Mtetra
.41578 .18576 .42335 .1947 .43624 .18987 .42871 .18089 Mtetra
.42871 .18089 .43624 .18987 .4492 .18501 .4417 .17599 Mtetra
.4417 .17599 .4492 .18501 .46221 .18014 .45475 .17107 Mtetra
.45475 .17107 .46221 .18014 .47529 .17524 .46787 .16613 Mtetra
.46787 .16613 .47529 .17524 .48843 .17031 .48105 .16116 Mtetra
.48105 .16116 .48843 .17031 .50163 .16537 .49429 .15617 Mtetra
.49429 .15617 .50163 .16537 .51489 .16039 .5076 .15115 Mtetra
.5076 .15115 .51489 .16039 .52823 .1554 .52097 .14611 Mtetra
.52097 .14611 .52823 .1554 .54162 .15038 .53441 .14104 Mtetra
.53441 .14104 .54162 .15038 .55508 .14533 .54792 .13595 Mtetra
.54792 .13595 .55508 .14533 .56861 .14026 .56149 .13084 Mtetra
.56149 .13084 .56861 .14026 .5822 .13517 .57513 .1257 Mtetra
.57513 .1257 .5822 .13517 .59586 .13005 .58883 .12053 Mtetra
.58883 .12053 .59586 .13005 .60959 .12491 .60261 .11534 Mtetra
.60261 .11534 .60959 .12491 .62339 .11974 .61645 .11012 Mtetra
.61645 .11012 .62339 .11974 .63725 .11454 .63036 .10488 Mtetra
.63036 .10488 .63725 .11454 .65119 .10932 .64434 .09961 Mtetra
.64434 .09961 .65119 .10932 .66519 .10407 .65839 .09431 Mtetra
.65839 .09431 .66519 .10407 .67926 .0988 .67251 .08899 Mtetra
.67251 .08899 .67926 .0988 .6934 .0935 .6867 .08364 Mtetra
.6867 .08364 .6934 .0935 .70762 .08817 .70096 .07827 Mtetra
.70096 .07827 .70762 .08817 .7219 .08282 .71529 .07286 Mtetra
.71529 .07286 .7219 .08282 .73626 .07744 .7297 .06743 Mtetra
.345 .591 .936 r
.07786 .31708 .08632 .32592 .09665 .32995 .08852 .31871 Mtetra
.406 .556 .892 r
.08852 .31871 .09665 .32995 .10692 .33528 .09927 .32029 Mtetra
.495 .528 .82 r
.09927 .32029 .10692 .33528 .1173 .34066 .11027 .32078 Mtetra
.561 .506 .751 r
.11027 .32078 .1173 .34066 .128 .34442 .12162 .31918 Mtetra
.6 .491 .701 r
.12162 .31918 .128 .34442 .13921 .34489 .13337 .31487 Mtetra
.623 .484 .672 r
.13337 .31487 .13921 .34489 .15103 .34099 .14551 .30783 Mtetra
.637 .482 .657 r
.14551 .30783 .15103 .34099 .16341 .33259 .15794 .29863 Mtetra
.645 .486 .653 r
.15794 .29863 .16341 .33259 .17622 .32062 .17052 .28827 Mtetra
.651 .495 .659 r
.17052 .28827 .17622 .32062 .18924 .30664 .18312 .27778 Mtetra
.656 .51 .674 r
.18312 .27778 .18924 .30664 .20227 .29237 .19566 .26797 Mtetra
.661 .534 .699 r
.19566 .26797 .20227 .29237 .21518 .27918 .2081 .25928 Mtetra
.666 .566 .734 r
.2081 .25928 .21518 .27918 .2279 .26781 .22044 .2518 Mtetra
.67 .606 .776 r
.22044 .2518 .2279 .26781 .24044 .2584 .23271 .24534 Mtetra
.671 .648 .818 r
.23271 .24534 .24044 .2584 .25284 .25071 .24496 .23965 Mtetra
.67 .684 .854 r
.24496 .23965 .25284 .25071 .26517 .2443 .2572 .23445 Mtetra
.668 .71 .88 r
.2572 .23445 .26517 .2443 .27747 .23871 .26948 .22952 Mtetra
.666 .726 .894 r
.26948 .22952 .27747 .23871 .28979 .2336 .2818 .22473 Mtetra
.665 .735 .902 r
.2818 .22473 .28979 .2336 .30214 .22874 .29417 .21999 Mtetra
.664 .739 .906 r
.29417 .21999 .30214 .22874 .31453 .22398 .30659 .21526 Mtetra
.664 .74 .907 r
.30659 .21526 .31453 .22398 .32698 .21925 .31908 .21052 Mtetra
.664 .741 .908 r
.31908 .21052 .32698 .21925 .33949 .21452 .33162 .20576 Mtetra
.33162 .20576 .33949 .21452 .35205 .20978 .34422 .20098 Mtetra
.34422 .20098 .35205 .20978 .36468 .20503 .35688 .19618 Mtetra
.35688 .19618 .36468 .20503 .37736 .20024 .3696 .19136 Mtetra
.3696 .19136 .37736 .20024 .39011 .19544 .38239 .18651 Mtetra
.38239 .18651 .39011 .19544 .40291 .19061 .39523 .18164 Mtetra
.39523 .18164 .40291 .19061 .41578 .18576 .40813 .17675 Mtetra
.40813 .17675 .41578 .18576 .42871 .18089 .4211 .17183 Mtetra
.4211 .17183 .42871 .18089 .4417 .17599 .43413 .16689 Mtetra
.43413 .16689 .4417 .17599 .45475 .17107 .44723 .16193 Mtetra
.44723 .16193 .45475 .17107 .46787 .16613 .46038 .15694 Mtetra
.46038 .15694 .46787 .16613 .48105 .16116 .4736 .15192 Mtetra
.4736 .15192 .48105 .16116 .49429 .15617 .48689 .14689 Mtetra
.48689 .14689 .49429 .15617 .5076 .15115 .50024 .14183 Mtetra
.50024 .14183 .5076 .15115 .52097 .14611 .51366 .13674 Mtetra
.51366 .13674 .52097 .14611 .53441 .14104 .52714 .13163 Mtetra
.52714 .13163 .53441 .14104 .54792 .13595 .54069 .12649 Mtetra
.54069 .12649 .54792 .13595 .56149 .13084 .5543 .12133 Mtetra
.5543 .12133 .56149 .13084 .57513 .1257 .56798 .11614 Mtetra
.56798 .11614 .57513 .1257 .58883 .12053 .58173 .11093 Mtetra
.58173 .11093 .58883 .12053 .60261 .11534 .59555 .10569 Mtetra
.59555 .10569 .60261 .11534 .61645 .11012 .60944 .10042 Mtetra
.60944 .10042 .61645 .11012 .63036 .10488 .6234 .09513 Mtetra
.6234 .09513 .63036 .10488 .64434 .09961 .63742 .08981 Mtetra
.63742 .08981 .64434 .09961 .65839 .09431 .65152 .08447 Mtetra
.65152 .08447 .65839 .09431 .67251 .08899 .66569 .0791 Mtetra
.66569 .0791 .67251 .08899 .6867 .08364 .67993 .0737 Mtetra
.67993 .0737 .6867 .08364 .70096 .07827 .69424 .06827 Mtetra
.69424 .06827 .70096 .07827 .71529 .07286 .70863 .06282 Mtetra
.70863 .06282 .71529 .07286 .7297 .06743 .72309 .05734 Mtetra
.537 .621 .883 r
.06965 .30591 .07786 .31708 .08852 .31871 .08068 .30491 Mtetra
.567 .584 .83 r
.08068 .30491 .08852 .31871 .09927 .32029 .09188 .30322 Mtetra
.596 .554 .778 r
.09188 .30322 .09927 .32029 .11027 .32078 .10331 .3003 Mtetra
.617 .533 .737 r
.10331 .3003 .11027 .32078 .12162 .31918 .11501 .29582 Mtetra
.631 .521 .71 r
.11501 .29582 .12162 .31918 .13337 .31487 .12696 .28978 Mtetra
.641 .517 .697 r
.12696 .28978 .13337 .31487 .14551 .30783 .1391 .28254 Mtetra
.648 .521 .695 r
.1391 .28254 .14551 .30783 .15794 .29863 .15134 .27466 Mtetra
.653 .531 .703 r
.15134 .27466 .15794 .29863 .17052 .28827 .16362 .26673 Mtetra
.659 .55 .72 r
.16362 .26673 .17052 .28827 .18312 .27778 .17589 .25921 Mtetra
.663 .576 .747 r
.17589 .25921 .18312 .27778 .19566 .26797 .18811 .25232 Mtetra
.667 .61 .781 r
.18811 .25232 .19566 .26797 .2081 .25928 .2003 .24611 Mtetra
.669 .646 .817 r
.2003 .24611 .2081 .25928 .22044 .2518 .21247 .24048 Mtetra
.669 .679 .85 r
.21247 .24048 .22044 .2518 .23271 .24534 .22465 .23525 Mtetra
.668 .705 .875 r
.22465 .23525 .23271 .24534 .24496 .23965 .23685 .23029 Mtetra
.666 .722 .891 r
.23685 .23029 .24496 .23965 .2572 .23445 .24909 .22548 Mtetra
.665 .732 .9 r
.24909 .22548 .2572 .23445 .26948 .22952 .26138 .22072 Mtetra
.664 .737 .904 r
.26138 .22072 .26948 .22952 .2818 .22473 .27372 .21599 Mtetra
.664 .74 .906 r
.27372 .21599 .2818 .22473 .29417 .21999 .28613 .21125 Mtetra
.664 .741 .907 r
.28613 .21125 .29417 .21999 .30659 .21526 .29858 .20649 Mtetra
.664 .741 .908 r
.29858 .20649 .30659 .21526 .31908 .21052 .3111 .20172 Mtetra
.3111 .20172 .31908 .21052 .33162 .20576 .32368 .19692 Mtetra
.32368 .19692 .33162 .20576 .34422 .20098 .33632 .1921 Mtetra
.33632 .1921 .34422 .20098 .35688 .19618 .34902 .18726 Mtetra
.34902 .18726 .35688 .19618 .3696 .19136 .36178 .18239 Mtetra
.36178 .18239 .3696 .19136 .38239 .18651 .3746 .1775 Mtetra
.3746 .1775 .38239 .18651 .39523 .18164 .38748 .17259 Mtetra
.38748 .17259 .39523 .18164 .40813 .17675 .40042 .16765 Mtetra
.40042 .16765 .40813 .17675 .4211 .17183 .41343 .16269 Mtetra
.41343 .16269 .4211 .17183 .43413 .16689 .4265 .15771 Mtetra
.4265 .15771 .43413 .16689 .44723 .16193 .43963 .1527 Mtetra
.43963 .1527 .44723 .16193 .46038 .15694 .45283 .14766 Mtetra
.45283 .14766 .46038 .15694 .4736 .15192 .46609 .14261 Mtetra
.46609 .14261 .4736 .15192 .48689 .14689 .47942 .13752 Mtetra
.47942 .13752 .48689 .14689 .50024 .14183 .49281 .13242 Mtetra
.49281 .13242 .50024 .14183 .51366 .13674 .50627 .12728 Mtetra
.50627 .12728 .51366 .13674 .52714 .13163 .5198 .12212 Mtetra
.5198 .12212 .52714 .13163 .54069 .12649 .53339 .11694 Mtetra
.53339 .11694 .54069 .12649 .5543 .12133 .54705 .11173 Mtetra
.54705 .11173 .5543 .12133 .56798 .11614 .56078 .1065 Mtetra
.56078 .1065 .56798 .11614 .58173 .11093 .57457 .10123 Mtetra
.57457 .10123 .58173 .11093 .59555 .10569 .58844 .09595 Mtetra
.58844 .09595 .59555 .10569 .60944 .10042 .60237 .09063 Mtetra
.60237 .09063 .60944 .10042 .6234 .09513 .61637 .08529 Mtetra
.61637 .08529 .6234 .09513 .63742 .08981 .63045 .07992 Mtetra
.63045 .07992 .63742 .08981 .65152 .08447 .64459 .07453 Mtetra
.64459 .07453 .65152 .08447 .66569 .0791 .65881 .06911 Mtetra
.65881 .06911 .66569 .0791 .67993 .0737 .6731 .06366 Mtetra
.6731 .06366 .67993 .0737 .69424 .06827 .68746 .05818 Mtetra
.68746 .05818 .69424 .06827 .70863 .06282 .7019 .05267 Mtetra
.7019 .05267 .70863 .06282 .72309 .05734 .71641 .04714 Mtetra
.61 .632 .849 r
.06154 .29373 .06965 .30591 .08068 .30491 .07285 .29072 Mtetra
.622 .605 .812 r
.07285 .29072 .08068 .30491 .09188 .30322 .08433 .28703 Mtetra
.633 .584 .781 r
.08433 .28703 .09188 .30322 .10331 .3003 .09597 .2825 Mtetra
.642 .571 .759 r
.09597 .2825 .10331 .3003 .11501 .29582 .10778 .27713 Mtetra
.649 .567 .749 r
.10778 .27713 .11501 .29582 .12696 .28978 .11972 .27114 Mtetra
.654 .57 .748 r
.11972 .27114 .12696 .28978 .1391 .28254 .13174 .26482 Mtetra
.659 .582 .757 r
.13174 .26482 .1391 .28254 .15134 .27466 .14379 .25848 Mtetra
.663 .601 .775 r
.14379 .25848 .15134 .27466 .16362 .26673 .15587 .25236 Mtetra
.666 .626 .799 r
.15587 .25236 .16362 .26673 .17589 .25921 .16794 .24658 Mtetra
.668 .654 .827 r
.16794 .24658 .17589 .25921 .18811 .25232 .18002 .24114 Mtetra
.668 .681 .853 r
.18002 .24114 .18811 .25232 .2003 .24611 .19212 .23598 Mtetra
.667 .704 .874 r
.19212 .23598 .2003 .24611 .21247 .24048 .20424 .23104 Mtetra
.666 .72 .889 r
.20424 .23104 .21247 .24048 .22465 .23525 .2164 .22622 Mtetra
.665 .73 .898 r
.2164 .22622 .22465 .23525 .23685 .23029 .22861 .22146 Mtetra
.664 .736 .903 r
.22861 .22146 .23685 .23029 .24909 .22548 .24088 .21672 Mtetra
.664 .739 .906 r
.24088 .21672 .24909 .22548 .26138 .22072 .2532 .21198 Mtetra
.664 .74 .907 r
.2532 .21198 .26138 .22072 .27372 .21599 .26557 .20723 Mtetra
.664 .741 .908 r
.26557 .20723 .27372 .21599 .28613 .21125 .27801 .20245 Mtetra
.27801 .20245 .28613 .21125 .29858 .20649 .29051 .19766 Mtetra
.29051 .19766 .29858 .20649 .3111 .20172 .30306 .19284 Mtetra
.30306 .19284 .3111 .20172 .32368 .19692 .31567 .188 Mtetra
.31567 .188 .32368 .19692 .33632 .1921 .32835 .18314 Mtetra
.32835 .18314 .33632 .1921 .34902 .18726 .34108 .17826 Mtetra
.34108 .17826 .34902 .18726 .36178 .18239 .35388 .17335 Mtetra
.35388 .17335 .36178 .18239 .3746 .1775 .36674 .16841 Mtetra
.36674 .16841 .3746 .1775 .38748 .17259 .37966 .16346 Mtetra
.37966 .16346 .38748 .17259 .40042 .16765 .39264 .15847 Mtetra
.39264 .15847 .40042 .16765 .41343 .16269 .40569 .15347 Mtetra
.40569 .15347 .41343 .16269 .4265 .15771 .4188 .14844 Mtetra
.4188 .14844 .4265 .15771 .43963 .1527 .43197 .14339 Mtetra
.43197 .14339 .43963 .1527 .45283 .14766 .44521 .13831 Mtetra
.44521 .13831 .45283 .14766 .46609 .14261 .45852 .1332 Mtetra
.45852 .1332 .46609 .14261 .47942 .13752 .47188 .12807 Mtetra
.47188 .12807 .47942 .13752 .49281 .13242 .48532 .12292 Mtetra
.48532 .12292 .49281 .13242 .50627 .12728 .49882 .11774 Mtetra
.49882 .11774 .50627 .12728 .5198 .12212 .51239 .11253 Mtetra
.51239 .11253 .5198 .12212 .53339 .11694 .52603 .1073 Mtetra
.52603 .1073 .53339 .11694 .54705 .11173 .53973 .10205 Mtetra
.53973 .10205 .54705 .11173 .56078 .1065 .5535 .09676 Mtetra
.5535 .09676 .56078 .1065 .57457 .10123 .56734 .09145 Mtetra
.56734 .09145 .57457 .10123 .58844 .09595 .58125 .08612 Mtetra
.58125 .08612 .58844 .09595 .60237 .09063 .59523 .08075 Mtetra
.59523 .08075 .60237 .09063 .61637 .08529 .60929 .07536 Mtetra
.60929 .07536 .61637 .08529 .63045 .07992 .62341 .06994 Mtetra
.62341 .06994 .63045 .07992 .64459 .07453 .6376 .0645 Mtetra
.6376 .0645 .64459 .07453 .65881 .06911 .65187 .05902 Mtetra
.65187 .05902 .65881 .06911 .6731 .06366 .66621 .05352 Mtetra
.66621 .05352 .6731 .06366 .68746 .05818 .68062 .04799 Mtetra
.68062 .04799 .68746 .05818 .7019 .05267 .6951 .04244 Mtetra
.6951 .04244 .7019 .05267 .71641 .04714 .70966 .03685 Mtetra
.641 .653 .846 r
.05331 .28189 .06154 .29373 .07285 .29072 .0648 .27778 Mtetra
.647 .636 .825 r
.0648 .27778 .07285 .29072 .08433 .28703 .0764 .27324 Mtetra
.653 .626 .81 r
.0764 .27324 .08433 .28703 .09597 .2825 .08811 .26829 Mtetra
.657 .622 .803 r
.08811 .26829 .09597 .2825 .10778 .27713 .09991 .26302 Mtetra
.661 .626 .804 r
.09991 .26302 .10778 .27713 .11972 .27114 .11178 .2576 Mtetra
.664 .636 .812 r
.11178 .2576 .11972 .27114 .13174 .26482 .12369 .25216 Mtetra
.666 .652 .826 r
.12369 .25216 .13174 .26482 .14379 .25848 .13564 .24683 Mtetra
.667 .671 .844 r
.13564 .24683 .14379 .25848 .15587 .25236 .14762 .24165 Mtetra
.667 .69 .862 r
.14762 .24165 .15587 .25236 .16794 .24658 .15962 .23663 Mtetra
.667 .707 .878 r
.15962 .23663 .16794 .24658 .18002 .24114 .17166 .23174 Mtetra
.666 .721 .89 r
.17166 .23174 .18002 .24114 .19212 .23598 .18374 .22694 Mtetra
.665 .73 .898 r
.18374 .22694 .19212 .23598 .20424 .23104 .19587 .22219 Mtetra
.664 .736 .903 r
.19587 .22219 .20424 .23104 .2164 .22622 .20806 .21745 Mtetra
.664 .739 .906 r
.20806 .21745 .2164 .22622 .22861 .22146 .22029 .21271 Mtetra
.664 .74 .907 r
.22029 .21271 .22861 .22146 .24088 .21672 .23259 .20796 Mtetra
.664 .741 .908 r
.23259 .20796 .24088 .21672 .2532 .21198 .24494 .20319 Mtetra
.24494 .20319 .2532 .21198 .26557 .20723 .25735 .1984 Mtetra
.25735 .1984 .26557 .20723 .27801 .20245 .26982 .19359 Mtetra
.26982 .19359 .27801 .20245 .29051 .19766 .28235 .18875 Mtetra
.28235 .18875 .29051 .19766 .30306 .19284 .29494 .18389 Mtetra
.29494 .18389 .30306 .19284 .31567 .188 .30759 .17901 Mtetra
.30759 .17901 .31567 .188 .32835 .18314 .32031 .1741 Mtetra
.32031 .1741 .32835 .18314 .34108 .17826 .33308 .16917 Mtetra
.33308 .16917 .34108 .17826 .35388 .17335 .34591 .16422 Mtetra
.34591 .16422 .35388 .17335 .36674 .16841 .35881 .15924 Mtetra
.35881 .15924 .36674 .16841 .37966 .16346 .37177 .15424 Mtetra
.37177 .15424 .37966 .16346 .39264 .15847 .38479 .14922 Mtetra
.38479 .14922 .39264 .15847 .40569 .15347 .39788 .14417 Mtetra
.39788 .14417 .40569 .15347 .4188 .14844 .41103 .13909 Mtetra
.41103 .13909 .4188 .14844 .43197 .14339 .42424 .13399 Mtetra
.42424 .13399 .43197 .14339 .44521 .13831 .43752 .12886 Mtetra
.43752 .12886 .44521 .13831 .45852 .1332 .45087 .12371 Mtetra
.45087 .12371 .45852 .1332 .47188 .12807 .46428 .11854 Mtetra
.46428 .11854 .47188 .12807 .48532 .12292 .47776 .11334 Mtetra
.47776 .11334 .48532 .12292 .49882 .11774 .4913 .10811 Mtetra
.4913 .10811 .49882 .11774 .51239 .11253 .50491 .10286 Mtetra
.50491 .10286 .51239 .11253 .52603 .1073 .51859 .09758 Mtetra
.51859 .09758 .52603 .1073 .53973 .10205 .53234 .09227 Mtetra
.53234 .09227 .53973 .10205 .5535 .09676 .54616 .08694 Mtetra
.54616 .08694 .5535 .09676 .56734 .09145 .56005 .08158 Mtetra
.56005 .08158 .56734 .09145 .58125 .08612 .574 .07619 Mtetra
.574 .07619 .58125 .08612 .59523 .08075 .58803 .07078 Mtetra
.58803 .07078 .59523 .08075 .60929 .07536 .60213 .06534 Mtetra
.60213 .06534 .60929 .07536 .62341 .06994 .6163 .05987 Mtetra
.6163 .05987 .62341 .06994 .6376 .0645 .63054 .05437 Mtetra
.63054 .05437 .6376 .0645 .65187 .05902 .64486 .04885 Mtetra
.64486 .04885 .65187 .05902 .66621 .05352 .65925 .04329 Mtetra
.65925 .04329 .66621 .05352 .68062 .04799 .67371 .03771 Mtetra
.67371 .03771 .68062 .04799 .6951 .04244 .68825 .0321 Mtetra
.68825 .0321 .6951 .04244 .70966 .03685 .70286 .02646 Mtetra
.656 .68 .861 r
.04486 .27109 .05331 .28189 .0648 .27778 .05642 .26656 Mtetra
.659 .673 .852 r
.05642 .26656 .0648 .27778 .0764 .27324 .06807 .26183 Mtetra
.662 .671 .849 r
.06807 .26183 .0764 .27324 .08811 .26829 .07978 .25696 Mtetra
.664 .674 .85 r
.07978 .25696 .08811 .26829 .09991 .26302 .09155 .252 Mtetra
.665 .681 .856 r
.09155 .252 .09991 .26302 .11178 .2576 .10338 .24703 Mtetra
.666 .692 .865 r
.10338 .24703 .11178 .2576 .12369 .25216 .11525 .24209 Mtetra
.666 .704 .875 r
.11525 .24209 .12369 .25216 .13564 .24683 .12716 .23722 Mtetra
.666 .715 .885 r
.12716 .23722 .13564 .24683 .14762 .24165 .13911 .23241 Mtetra
.665 .724 .893 r
.13911 .23241 .14762 .24165 .15962 .23663 .15111 .22764 Mtetra
.665 .731 .899 r
.15111 .22764 .15962 .23663 .17166 .23174 .16316 .2229 Mtetra
.664 .736 .903 r
.16316 .2229 .17166 .23174 .18374 .22694 .17526 .21817 Mtetra
.664 .739 .906 r
.17526 .21817 .18374 .22694 .19587 .22219 .18741 .21344 Mtetra
.664 .74 .907 r
.18741 .21344 .19587 .22219 .20806 .21745 .19963 .20869 Mtetra
.664 .741 .907 r
.19963 .20869 .20806 .21745 .22029 .21271 .2119 .20392 Mtetra
.664 .741 .908 r
.2119 .20392 .22029 .21271 .23259 .20796 .22423 .19914 Mtetra
.22423 .19914 .23259 .20796 .24494 .20319 .23661 .19433 Mtetra
.23661 .19433 .24494 .20319 .25735 .1984 .24906 .1895 Mtetra
.24906 .1895 .25735 .1984 .26982 .19359 .26157 .18464 Mtetra
.26157 .18464 .26982 .19359 .28235 .18875 .27413 .17976 Mtetra
.27413 .17976 .28235 .18875 .29494 .18389 .28676 .17486 Mtetra
.28676 .17486 .29494 .18389 .30759 .17901 .29944 .16993 Mtetra
.29944 .16993 .30759 .17901 .32031 .1741 .31219 .16498 Mtetra
.31219 .16498 .32031 .1741 .33308 .16917 .325 .16001 Mtetra
.325 .16001 .33308 .16917 .34591 .16422 .33788 .15501 Mtetra
.33788 .15501 .34591 .16422 .35881 .15924 .35081 .14999 Mtetra
.35081 .14999 .35881 .15924 .37177 .15424 .36381 .14494 Mtetra
.36381 .14494 .37177 .15424 .38479 .14922 .37687 .13987 Mtetra
.37687 .13987 .38479 .14922 .39788 .14417 .39 .13478 Mtetra
.39 .13478 .39788 .14417 .41103 .13909 .40319 .12965 Mtetra
.40319 .12965 .41103 .13909 .42424 .13399 .41644 .12451 Mtetra
.41644 .12451 .42424 .13399 .43752 .12886 .42976 .11934 Mtetra
.42976 .11934 .43752 .12886 .45087 .12371 .44315 .11414 Mtetra
.44315 .11414 .45087 .12371 .46428 .11854 .4566 .10892 Mtetra
.4566 .10892 .46428 .11854 .47776 .11334 .47013 .10367 Mtetra
.47013 .10367 .47776 .11334 .4913 .10811 .48371 .09839 Mtetra
.48371 .09839 .4913 .10811 .50491 .10286 .49737 .09309 Mtetra
.49737 .09309 .50491 .10286 .51859 .09758 .51109 .08776 Mtetra
.51109 .08776 .51859 .09758 .53234 .09227 .52489 .0824 Mtetra
.52489 .0824 .53234 .09227 .54616 .08694 .53875 .07702 Mtetra
.53875 .07702 .54616 .08694 .56005 .08158 .55268 .07161 Mtetra
.55268 .07161 .56005 .08158 .574 .07619 .56669 .06618 Mtetra
.56669 .06618 .574 .07619 .58803 .07078 .58076 .06071 Mtetra
.58076 .06071 .58803 .07078 .60213 .06534 .59491 .05522 Mtetra
.59491 .05522 .60213 .06534 .6163 .05987 .60913 .0497 Mtetra
.60913 .0497 .6163 .05987 .63054 .05437 .62342 .04415 Mtetra
.62342 .04415 .63054 .05437 .64486 .04885 .63778 .03857 Mtetra
.63778 .03857 .64486 .04885 .65925 .04329 .65222 .03297 Mtetra
.65222 .03297 .65925 .04329 .67371 .03771 .66673 .02733 Mtetra
.66673 .02733 .67371 .03771 .68825 .0321 .68132 .02167 Mtetra
.68132 .02167 .68825 .0321 .70286 .02646 .69599 .01598 Mtetra
.662 .706 .88 r
.03617 .26136 .04486 .27109 .05642 .26656 .04777 .25674 Mtetra
.663 .705 .878 r
.04777 .25674 .05642 .26656 .06807 .26183 .05943 .25204 Mtetra
.664 .707 .879 r
.05943 .25204 .06807 .26183 .07978 .25696 .07114 .2473 Mtetra
.665 .712 .883 r
.07114 .2473 .07978 .25696 .09155 .252 .0829 .24254 Mtetra
.665 .717 .887 r
.0829 .24254 .09155 .252 .10338 .24703 .09472 .23779 Mtetra
.665 .723 .893 r
.09472 .23779 .10338 .24703 .11525 .24209 .10658 .23306 Mtetra
.665 .729 .897 r
.10658 .23306 .11525 .24209 .12716 .23722 .1185 .22833 Mtetra
.664 .733 .901 r
.1185 .22833 .12716 .23722 .13911 .23241 .13046 .22362 Mtetra
.664 .737 .904 r
.13046 .22362 .13911 .23241 .15111 .22764 .14248 .2189 Mtetra
.664 .739 .906 r
.14248 .2189 .15111 .22764 .16316 .2229 .15456 .21417 Mtetra
.664 .74 .907 r
.15456 .21417 .16316 .2229 .17526 .21817 .16669 .20942 Mtetra
.664 .741 .907 r
.16669 .20942 .17526 .21817 .18741 .21344 .17888 .20466 Mtetra
.664 .741 .908 r
.17888 .20466 .18741 .21344 .19963 .20869 .19112 .19988 Mtetra
.19112 .19988 .19963 .20869 .2119 .20392 .20343 .19507 Mtetra
.20343 .19507 .2119 .20392 .22423 .19914 .21579 .19024 Mtetra
.21579 .19024 .22423 .19914 .23661 .19433 .22821 .18539 Mtetra
.22821 .18539 .23661 .19433 .24906 .1895 .24069 .18051 Mtetra
.24069 .18051 .24906 .1895 .26157 .18464 .25323 .17561 Mtetra
.25323 .17561 .26157 .18464 .27413 .17976 .26583 .17069 Mtetra
.26583 .17069 .27413 .17976 .28676 .17486 .2785 .16575 Mtetra
.2785 .16575 .28676 .17486 .29944 .16993 .29122 .16078 Mtetra
.29122 .16078 .29944 .16993 .31219 .16498 .30401 .15578 Mtetra
.30401 .15578 .31219 .16498 .325 .16001 .31685 .15076 Mtetra
.31685 .15076 .325 .16001 .33788 .15501 .32977 .14572 Mtetra
.32977 .14572 .33788 .15501 .35081 .14999 .34274 .14065 Mtetra
.34274 .14065 .35081 .14999 .36381 .14494 .35578 .13556 Mtetra
.35578 .13556 .36381 .14494 .37687 .13987 .36888 .13044 Mtetra
.36888 .13044 .37687 .13987 .39 .13478 .38204 .1253 Mtetra
.38204 .1253 .39 .13478 .40319 .12965 .39527 .12013 Mtetra
.39527 .12013 .40319 .12965 .41644 .12451 .40857 .11494 Mtetra
.40857 .11494 .41644 .12451 .42976 .11934 .42193 .10972 Mtetra
.42193 .10972 .42976 .11934 .44315 .11414 .43536 .10448 Mtetra
.43536 .10448 .44315 .11414 .4566 .10892 .44886 .0992 Mtetra
.44886 .0992 .4566 .10892 .47013 .10367 .46242 .09391 Mtetra
.46242 .09391 .47013 .10367 .48371 .09839 .47605 .08858 Mtetra
.47605 .08858 .48371 .09839 .49737 .09309 .48975 .08323 Mtetra
.48975 .08323 .49737 .09309 .51109 .08776 .50352 .07785 Mtetra
.50352 .07785 .51109 .08776 .52489 .0824 .51736 .07245 Mtetra
.51736 .07245 .52489 .0824 .53875 .07702 .53127 .06701 Mtetra
.53127 .06701 .53875 .07702 .55268 .07161 .54525 .06155 Mtetra
.54525 .06155 .55268 .07161 .56669 .06618 .5593 .05607 Mtetra
.5593 .05607 .56669 .06618 .58076 .06071 .57342 .05055 Mtetra
.57342 .05055 .58076 .06071 .59491 .05522 .58762 .04501 Mtetra
.58762 .04501 .59491 .05522 .60913 .0497 .60188 .03943 Mtetra
.60188 .03943 .60913 .0497 .62342 .04415 .61623 .03383 Mtetra
.61623 .03383 .62342 .04415 .63778 .03857 .63064 .0282 Mtetra
.63064 .0282 .63778 .03857 .65222 .03297 .64513 .02254 Mtetra
.64513 .02254 .65222 .03297 .66673 .02733 .65969 .01685 Mtetra
.65969 .01685 .66673 .02733 .68132 .02167 .67433 .01113 Mtetra
.67433 .01113 .68132 .02167 .69599 .01598 .68905 .00539 Mtetra
0 g
.68874 0 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.68874 0 m
.03716 .25514 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 0.522676 0.477324 0.97619 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.49505 0.5 0.49505 [
[ 0 0 -0.125 0 ]
[ 0 0 -0.125 0 ]
[ 0 1 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
0 0 m
1 0 L
s
0 0 m
0 1 L
s
0 1 m
1 1 L
s
1 0 m
1 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
1 .5 0 r
.015 w
.03175 .1355 Mdot
.03435 .12523 Mdot
.11137 .12765 Mdot
.14107 .18841 Mdot
.16218 .24538 Mdot
.17294 .21053 Mdot
.18267 .18577 Mdot
.18434 .1304 Mdot
.18553 .30956 Mdot
.20401 .239 Mdot
.21247 .27571 Mdot
.21687 .20845 Mdot
.22376 .2799 Mdot
.22832 .27485 Mdot
.29063 .20974 Mdot
.29686 .25079 Mdot
.30487 .22936 Mdot
.30683 .34623 Mdot
.32055 .20902 Mdot
.32574 .21979 Mdot
.34472 .28521 Mdot
.35998 .36393 Mdot
.36335 .24976 Mdot
.3794 .36608 Mdot
.42386 .66992 Mdot
.44391 .74519 Mdot
.45059 .34198 Mdot
.47208 .67586 Mdot
.47436 .71381 Mdot
.49778 .59825 Mdot
.50874 .91643 Mdot
.51516 .76219 Mdot
.53655 .61374 Mdot
.56563 .75219 Mdot
.59189 .65665 Mdot
.59581 .61604 Mdot
.59923 .6556 Mdot
.60292 .68499 Mdot
.62656 .67779 Mdot
.63555 .72451 Mdot
.63919 .652 Mdot
.64169 .6004 Mdot
.64246 .58611 Mdot
.64496 .54267 Mdot
.64608 .77288 Mdot
.65077 .64308 Mdot
.66065 .57816 Mdot
.67474 .59169 Mdot
.69296 .563 Mdot
.72815 .65902 Mdot
.73169 .58879 Mdot
.74669 .61318 Mdot
.74821 .65474 Mdot
.75963 .63781 Mdot
.79673 .57809 Mdot
.80925 .55852 Mdot
.81525 .58444 Mdot
.83417 .62985 Mdot
.83598 .55526 Mdot
.91595 .49319 Mdot
0 0 1 r
.005 w
.13523 .18197 m
.16128 .16731 L
.18734 .17066 L
.21339 .17762 L
.23565 .18734 L
.23945 .19061 L
.2655 .2041 L
.27839 .21339 L
.29156 .22348 L
.31098 .23945 L
.31761 .24653 L
.33421 .2655 L
.34367 .28741 L
.34421 .29156 L
.34367 .29696 L
.31761 .31142 L
.29156 .30806 L
.2655 .30106 L
.24359 .29156 L
.23945 .28811 L
.21339 .27457 L
.20079 .2655 L
.18734 .25522 L
.16813 .23945 L
.16128 .23216 L
.14485 .21339 L
.13523 .19108 L
.13475 .18734 L
.13523 .18197 L
s
.68239 .54895 m
.70844 .54974 L
.72083 .55211 L
.7345 .55541 L
.76055 .5761 L
.76156 .57817 L
.76928 .60422 L
.76388 .63028 L
.76055 .63751 L
.74858 .65633 L
.7345 .67305 L
.72268 .68239 L
.70844 .69318 L
.68239 .70779 L
.68107 .70844 L
.65633 .71868 L
.63028 .72576 L
.60422 .72905 L
.57817 .72822 L
.55211 .72152 L
.53336 .70844 L
.52606 .69886 L
.51957 .68239 L
.52107 .65633 L
.52606 .64298 L
.53303 .63028 L
.55211 .60617 L
.55513 .60422 L
.57817 .58524 L
.58996 .57817 L
.60422 .57038 L
.63028 .55937 L
.65633 .55249 L
.65837 .55211 L
.68239 .54895 L
s
0 g
.03 w
.23947 .23937 Mdot
.64399 .63883 Mdot
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.522676 0.522676 0.97619 0.97619 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.49505 0.5 0.49505 [
[ 0 0 -0.125 0 ]
[ 0 0 -0.125 0 ]
[ 0 1 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
0 0 m
1 0 L
s
0 0 m
0 1 L
s
0 1 m
1 1 L
s
1 0 m
1 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
1 .5 0 r
.015 w
.03175 .1355 Mdot
.03435 .12523 Mdot
.11137 .12765 Mdot
.14107 .18841 Mdot
.16218 .24538 Mdot
.17294 .21053 Mdot
.18267 .18577 Mdot
.18434 .1304 Mdot
.18553 .30956 Mdot
.20401 .239 Mdot
.21247 .27571 Mdot
.21687 .20845 Mdot
.22376 .2799 Mdot
.22832 .27485 Mdot
.29063 .20974 Mdot
.29686 .25079 Mdot
.30487 .22936 Mdot
.30683 .34623 Mdot
.32055 .20902 Mdot
.32574 .21979 Mdot
.34472 .28521 Mdot
.35998 .36393 Mdot
.36335 .24976 Mdot
.3794 .36608 Mdot
.42386 .66992 Mdot
.44391 .74519 Mdot
.45059 .34198 Mdot
.47208 .67586 Mdot
.47436 .71381 Mdot
.49778 .59825 Mdot
.50874 .91643 Mdot
.51516 .76219 Mdot
.53655 .61374 Mdot
.56563 .75219 Mdot
.59189 .65665 Mdot
.59581 .61604 Mdot
.59923 .6556 Mdot
.60292 .68499 Mdot
.62656 .67779 Mdot
.63555 .72451 Mdot
.63919 .652 Mdot
.64169 .6004 Mdot
.64246 .58611 Mdot
.64496 .54267 Mdot
.64608 .77288 Mdot
.65077 .64308 Mdot
.66065 .57816 Mdot
.67474 .59169 Mdot
.69296 .563 Mdot
.72815 .65902 Mdot
.73169 .58879 Mdot
.74669 .61318 Mdot
.74821 .65474 Mdot
.75963 .63781 Mdot
.79673 .57809 Mdot
.80925 .55852 Mdot
.81525 .58444 Mdot
.83417 .62985 Mdot
.83598 .55526 Mdot
.91595 .49319 Mdot
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{400, 400},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40006@0001T2000`400?l00000o`00003ooooooonA
ooooo`00oooooonAooooo`00oooooonAooooo`00oooooonAooooo`00oooooonAooooo`00oooooonA
ooooo`00oooooonAooooo`00oooooonAooooo`00oooooonAooooo`00oooooonAooooo`002Ooooonf
00000=7ooooo0009ooooo`0300000?oooooooooo0;;ooooo00<00000ooooooooool0coooool000Wo
oooo00<00000ooooooooool0/_ooool00`00003oooooooooo`3?ooooo`002Oooool00`00003ooooo
ooooo`2booooo`0300000?oooooooooo0<oooooo0009ooooo`0300000?oooooooooo0;;ooooo00<0
0000ooooooooool0coooool000Wooooo00@00000oooooooooooooooo[@000004ooooo`0300000?oo
oooooooo0<oooooo0009ooooo`0400000?ooooooooooooooojd000001?ooool00`00003ooooooooo
o`3?ooooo`002Oooool01000003ooooooooooooooon]000000Cooooo00<00000ooooooooool0cooo
ool000Wooooo00@00000oooooooooooooooo[@000004ooooo`0300000?oooooooooo0<oooooo0009
ooooo`0400000?ooooooooooooooojd000001?ooool00`00003oooooooooo`3?ooooo`002Oooool0
1000003ooooooooooooooon]000000Cooooo00<00000ooooooooool0coooool000Wooooo00@00000
oooooooooooooooo[@000004ooooo`0300000?oooooooooo0<oooooo0009ooooo`0400000?oooooo
ooooooooojd000001?ooool00`00003oooooooooo`3?ooooo`002Oooool01000003ooooooooooooo
oon]000000Cooooo00<00000ooooooooool0coooool000Wooooo00@00000oooooooooooooooo[@00
0004ooooo`0300000?oooooooooo0<oooooo0009ooooo`0400000?ooooooooooooooojd000001?oo
ool00`00003oooooooooo`3?ooooo`002Oooool01000003ooooooooooooooon]000000Cooooo00<0
0000ooooooooool0coooool000Wooooo00@00000oooooooooooooooo0`0000000ol00000000001TI
6@0;01TI6I`000001?ooool00`00003oooooooooo`2;ooooo`;o0000@_ooool000Wooooo00@00000
oooooooooooooooo0`00000C01TI6IL000001?ooool00`00003oooooooooo`28ooooo`?o000000?o
ooooo`000?ooool0@Oooool000Wooooo00D00000oooooooooooooooo0000000I01TI6I<000001?oo
ool00`00003oooooooooo`26ooooo`;o00000oooool00onY_NSo0000o`000011ooooo`002Oooool0
1000003ooooooooooooooolK01TI6I8000001?ooool00`00003oooooooooo`23ooooo`?o00000_oo
ool4ojVmj003o`000?oooooo0000043ooooo0009ooooo`0400000?ooooooooooooooo`X06ATI1`00
00000ol00000000000000003000000L06ATI0P0000000ol0000000000000002:000000Cooooo00<0
0000ooooooooool0P?ooool3o`0000;ooooo1onY_NP00ol0003oooooo`000010ooooo`002Oooool0
1000003oooooooooooooool901TI6@030000000c<c<0<c<c00/0<c<c1000000701TI6H/000001?oo
ool00`00003oooooooooo`1nooooo`;o00000oooool9ojVmj004o`000?nY_NSoooooo`0003oooooo
0009ooooo`0400000?ooooooooooooooo`P06ATI00<0000003<c<`0c<c<0400c<c<3000000H06ATI
R@000004ooooo`0300000?oooooooooo07_ooooo0ol00002ooooo`coZKgX00Go0000ojVmj?oooooo
ooooo`00000nooooo`002Oooool01000003oooooooooooooool601TI6@03o`0000000000<c<c00H0
<c<c200000000ol00000<c<c03<c<`0403<c<`0300000?l00000000000D06ATIQ`000004ooooo`03
00000?oooooooooo07Wooooo0_l00003ooooo`koZKgX00Go0000ojVmj?nY_NSoooooo`00000noooo
o`002Oooool01000003oooooooooooooool601TI6@030000000c<c<0<c<c00D0<c<c00?o000004a<
C01<C4`01`1<C4`5000000@0<c<c00<0000001TI6@0I6AT01@0I6AT00ol000000000000000210000
00Cooooo00<00000ooooooooool0M_ooool3o`0000;ooooo4OnY_NP01_l0003oZKgXojVmj?nY_NSo
ooooo`0003gooooo0009ooooo`0400000?ooooooooooooooo`H06ATI00<0000003<c<`0c<c<0100c
<c<00`000000C4a<04a<C00=04a<C08000000`0c<c<3000000H06ATIPP000004ooooo`0300000?oo
oooooooo07Cooooo0_l00002oooooaCoZKgX00?o0000ojVmj?nY_NP00_nY_NP00ol0003ooooooooo
o`0kooooo`002Oooool01000003oooooooooooooool601TI6@030000000c<c<0<c<c00<0<c<c00<0
000004a<C01<C4`00P1<C4`00ol0000000000000000:0000000404a<C00000000000000000<0<c<c
0`00000501TI6H0000001?ooool00`00003oooooooooo`1aooooo`?o00000_oooolFojVmj003o`00
0?nY_NSoZKgX00?oZKgX00?o0000ooooooooool0>_ooool000Wooooo00@00000oooooooooooooooo
1P0I6AT00`000000<c<c03<c<`0203<c<`030000001<C4`0C4a<0080C4a<00?o000006IVIP1VIVH0
2`1VIVH01Ol0000000000000001<C4co000000<000000P0c<c<00ol000006ATI01TI6@0301TI6@03
o`0000000000000007`000001?ooool00`00003oooooooooo`1^ooooo`?o00000_oooolIojVmj003
o`000?nY_NSoZKgX00?oZKgX00?oooooo`000?ooool0>_ooool000Wooooo00D00000oooooooooooo
oooo0000000501TI6@030000000c<c<0<c<c0080<c<c00<0000004a<C01<C4`00P1<C4`010000000
IVIV06IVIP1VIVH:o`0000<0IVIV00<0000004a<C01<C4`00P1<C4`20000000303<c<`0000000000
00D06ATIO@000004ooooo`0300000?oooooooooo06cooooo0_l00003oooooacoZKgX00?o0000ojVm
j?nY_NP00onY_NP00ol0003oooooooooo`0iooooo`002Oooool01@00003oooooooooooooool00000
00H06ATI00D0000003<c<`0c<c<0<c<c0000000304a<C0050000001VIVH0IVIV06IVI_l000002P1o
Ogl4o`0000<000000`1<C4`00`000000<c<c03<c<`02000000D06ATIN`000004ooooo`0300000?oo
oooooooo06Wooooo0ol00002oooooaooZKgX00?o0000ojVmj?nY_NP00onY_NP00ooooooo0000oooo
o`0iooooo`002Oooool01000003oooooooooooooool2000000D06ATI00Go000003<c<`0c<c<0<c<c
0000000204a<C0050000001VIVH0IVIV06IVI_l00000101oOgl8o`0000<0Ogmo0ol000001@00003o
00000000001<C4co00000080000000<0<c<co`00000000001@0I6AUi000000Cooooo00<00000oooo
ooooool0Ioooool2o`0000?ooooo8OnY_NP00ol0003oZKgXojVmj004ojVmj003ooooool0003ooooo
03Sooooo0009ooooo`0400000?ooooooooooooooo`8000001@0I6AT01@000000<c<c03<c<`0c<c<0
00000080C4a<00D0000006IVIP1VIVH0IVIVo`00000407moO`03o`00002IVIT0VIVI00Co000000@0
VIVIo`000?l0003o00000`1oOgl01?l00000IVIV06IVIP00000304a<C0040000000c<c<0<c<c0000
00D06ATIN0000004ooooo`0300000?oooooooooo06Cooooo0ol00002ooooobCoZKgX00?o0000ojVm
j?nY_NP01?nY_NP00ooooooo0000ooooo`0hooooo`002Oooool01000003oooooooooooooool30000
00D06ATI00@0000003<c<`0c<c<000000P1<C4`01@000000IVIV06IVIP1VIVKo000000<0Ogmo00Co
000009VIV@2IVIWo0000102c/k<7o`00000407moOol0003o0000o`00008000000P1<C4`200000003
03<c<`000000000000@06ATIM`000004ooooo`0300000?oooooooooo06;ooooo0_l00003ooooobKo
ZKgX00?o0000ojVmj?nY_NP01OnY_NP00ooooooo0000ooooo`0gooooo`002Oooool01000003ooooo
ooooooooool3000000D06ATI00D0000003<c<`0c<c<0<c<c0000000204a<C0040000001VIVH0IVIV
o`0000<0Ogmo00?o000009VIVOl000002@2c/k<6o`00000307moOol0003o0000008000000P1<C4`0
0`000000<c<c03<c<`02000000<06ATIMP000004ooooo`0300000?oooooooooo05oooooo0ol00002
ooooobWoZKgX00?o0000ojVmj?nY_NP01_nY_NP00ooooooo0000ooooo`0fooooo`002Oooool01000
003oooooooooooooool4000000D06ATI00@0000003<c<`0c<c<000000P1<C4`010000000IVIV06IV
I_l0000207moO`04o`00002IVIT0VIVIo`0000@0/k>c1`0000000`2c/k?o0000o`000002o`000080
Ogmo0_l000020000000304a<C000000000000080<c<c0P00000301TI6G@000001?ooool00`00003o
ooooooooo`1Mooooo`;o00000oooool[ojVmj003o`000?nY_NSoZKgX00OoZKgX00?o0000oooooooo
ool0=Oooool000Wooooo00@00000oooooooooooooooo1@00000401TI6@070000000c<c<0<c<c03<c
<`000000C4a<0000000206IVIP04o`00001oOgl0Ogmoo`000080VIVI00?o00000;>c/`2c/k<00P00
00070<c<c08000000P2c/k<3o`000080Ogmo0_l000000`000000C4a<04a<C00200000080<c<c00<0
000001TI6@0I6AT00P0I6AUb000000Cooooo00<00000ooooooooool0F_ooool3o`0000;ooooo;_nY
_NP00ol0003oZKgXojVmj008ojVmj003o`000?oooooooooo03Cooooo0009ooooo`0400000?oooooo
ooooooooo`H00000100I6AT01`000000<c<c03<c<`0c<c<0000004a<C00000000P1VIVH01_l00000
Ogmo07moOol00000VIVIo`000080/k>c00@000000<c<c03<c<`0c<c<1_l00000103<c<`000000000
00000004o`000080Ogmo00Ko0000000000000000000004a<C?l0000203<c<`800000100I6AU`0000
00Cooooo00<00000ooooooooool0Eoooool3o`0000?ooooo<?nY_NP00ol0003oZKgXojVmj008ojVm
j003ooooool0003ooooo03Cooooo0009ooooo`0400000?ooooooooooooooo`H0000000?o000001TI
6@0I6AT00P0I6AT01ol00000<c<c03<c<`0c<c?o000004a<C00000000P1VIVH01ol00000Ogmoo`00
002IVIWo00000;>c/`0000000`3<c<`00ol00000i^KV0>KViP040>KViPCo00000P0000001@2c/k?o
0000o`000?l00000Ogmo00;o000000@0IVIVo`00001<C4`000000`0c<c<00`0000006ATI01TI6@02
01TI6Fl000001?ooool00`00003oooooooooo`1Eooooo`;o00000ooooolcojVmj003o`000?nY_NSo
ZKgX00WoZKgX00?o0000ooooooooool0<oooool000Wooooo00@00000oooooooooooooooo20000004
01TI6@060000000c<c<0<c<c0000001<C4`000000P1VIVH01ol00000Ogmoo`00002IVIWo00000;>c
/`0000000`3<c<`00ol00000i^KV0>KViP080>KViP;o00000P000003o`000080Ogmo00Go000006IV
IP000000C4a<0000000303<c<`050000000I6AT06ATI01TI6Ol00000KP000004ooooo`0300000?oo
oooooooo05;ooooo0ol00003ooooocGoZKgX00?o0000ojVmj?nY_NP02OnY_NP00ooooooo0000oooo
o`0cooooo`002Oooool01000003oooooooooooooool8000000D06ATI00P0000003<c<`0c<c<00000
04a<C0000000IVIVo`000080Ogmo00Go000009VIVOl00000/k>c000000020<c<c004o`00003Vi^H0
i^KV0>KViPKo00000`3Vi^H01?l00000c<c<0000002c/k<3o`00000507moOol00000IVIV0000001<
C4`00P00000203<c<`030000000I6AT06ATI00806ATIK@000004ooooo`0300000?oooooooooo053o
oooo0_l00004ooooocOoZKgX00?o0000ojVmj?nY_NP02_nY_NP00ol0003oooooooooo`0booooo`00
2Oooool01000003oooooooooooooool9000000D06ATI00P0000003<c<`0c<c<0000004a<C0000000
IVIVo`000080Ogmo0_l000000`2c/k<000000<c<c0020<c<c004o`00003Vi^H0i^KVo`0000D0oooo
00oo00000>KViP3Vi^H0i^KVo`00003<c<`000000;>c/ol00000VIVIo`00001oOgoo000006IVIP00
00000P1<C4`010000000<c<c03<c<`00000401TI6F`000001?ooool00`00003oooooooooo`1=oooo
o`?o00000oooooljojVmj003o`000?nY_NSoZKgX00[oZKgX00?oooooo`000?ooool0<_ooool000Wo
oooo00@00000oooooooooooooooo2@0000000ol000006ATI01TI6@0201TI6@04o`00000c<c<0<c<c
o`000080C4a<0P0000001ol00000Ogmoo`00002IVIWo00000;>c/`0000000P3<c<`00ol00000i^KV
o`0000070?ooo`?o000000D0i^KVo`000?l0003o000000000005o`00000506IVIP000000000004a<
C?l000000P0c<c<00ol000006ATI01TI6@0201TI6F/000001?ooool00`00003oooooooooo`1;oooo
o`;o00001?oooollojVmj003o`000?nY_NSoZKgX00_oZKgX00?oooooo`000?ooool0<Oooool000Wo
oooo00@00000oooooooooooooooo3000000301TI6@040000000c<c<0<c<c000000<0C4a<00D00000
o`00001oOgoo000009VIV@02o`0000060000003<c<`0c<c<o`00003Vi^Ko00002@3oool02Ol00000
i^KV0>KVi_l00000c<c<0000002c/k?o000009VIV@02o`000080IVIV00D0000004a<C00000000000
03<c<`02000000<06ATIJP000004ooooo`0300000?oooooooooo04Sooooo0ol00003ooooocooZKgX
00?o0000ojVmj?nY_NP03?nY_NP00ol0003oooooooooo`0`ooooo`002Oooool01000003ooooooooo
ooooool=000000<06ATI00@0000003<c<`0c<c<000000`1<C4`01000003o0000o`000?l0000209VI
V@07o`0000000000c<c<0<c<c?l00000i^KVo`0000090?ooo`;o000000L0i^KVo`00003<c<`00000
0;>c/ol00000VIVI00?o000000D0IVIV0000001<C4`0C4a<0000000203<c<`040000000I6AT06ATI
01TI6FT000001?ooool00`00003oooooooooo`15ooooo`?o00000_oooom3ojVmj003o`000?nY_NSo
ZKgX00coZKgX00?oooooo`000?ooool0<?ooool000Wooooo00@00000oooooooooooooooo3@000000
2Ol000006ATI01TI6@0I6AT00000o`00000c<c<00000o`00000204a<C0030000001VIVKo000000;o
000000L0VIVIo`000000003o00000<c<c?l00000i^KV00;o00002@3oool03Ol00000i^KVo`00003<
c<co00000;>c/ol00000VIVIo`00001oOgoo000006IVIP0000000P1<C4`01?l00000<c<c03<c<ol0
000301TI6@0300000?l00000000006D000001?ooool00`00003oooooooooo`13ooooo`;o00000_oo
oom6ojVmj003o`000?nY_NSoZKgX00goZKgX00?oooooo`000?ooool0;oooool000Wooooo00@00000
oooooooooooooooo3`00000301TI6@090000000c<c<0<c<c03<c<`000000C4a<o`00001VIVKo0000
0080Ogmo00Go000009VIVOl0000000000<c<c002o`000080i^KV0_l000070?ooo`03o`00003Vi^Ko
00000080c<c<00@000000;>c/ol0003o00000P1oOgl01Ol00000IVIV0000001<C4`0000000<0<c<c
00<0000001TI6@0I6AT00P0I6AUV000000Cooooo00<00000ooooooooool0@?ooool3o`0000;ooooo
B?nY_NP00ol0003oZKgXojVmj00=ojVmj003ooooool0003ooooo02oooooo0009ooooo`0400000?oo
oooooooooooooa0000000`0I6AT020000000<c<c03<c<`0c<c<0000004a<C0000000IVIV0_l00000
1@1oOgoo000009VIVOl0000000000080c<c<0_l000020>KViP03o`00003oool0oooo00@0oooo00Ko
00000>KViP3Vi^Ko00000<c<c00000020;>c/`;o00000P1oOgl01Ol00000IVIV0000001<C4`00000
0080<c<c00<0000001TI6@0I6AT00`0I6AUU000000Cooooo00<00000ooooooooool0?_ooool2o`00
00?oooooB_nY_NP00ol0003oZKgXojVmj00:ojVmj006ojVmionY_NSoZKgXojVmj?oooooo0000;ooo
ool000Wooooo00@00000oooooooooooooooo4@00000301TI6@8000000P0c<c<00`000000C4a<0000
000206IVIP05o`00001oOgoo000009VIVOl000000P0000020<c<c004o`00003Vi^H0i^KVo`0000H0
oooo00?o00000>KVi_l000000P3<c<`01`000000/k>co`00002IVIWo000007moOol000000P1VIVH0
0ol00000C4a<0000000203<c<`030000000I6AT06ATI00<06ATII0000004ooooo`0300000?oooooo
oooo03_ooooo0ol00002ooooodgoZKgX00?o0000ojVmj?nY_NP01onY_NP5ojVmi`05ojVmj?nY_NOo
ZKgWooooool00000;_ooool000Wooooo00@00000oooooooooooooooo4P00000401TI6@80000000H0
<c<co`00001<C4`00000o`0000000006o`00008000000_l000020>KViPOo00000P3Vi^H03?l00000
c<c<0<c<c0000000/k>co`00002IVIWo000007moOol00000IVIV00000080C4a<00Co00000000000c
<c?o0000100I6AT00ol0000000000000001Q000000Cooooo00<00000ooooooooool0>Oooool2o`00
00?oooooConY_NP00ol0003oZKgXojVmi`05ojVmj0KoZKgW0_nY_>L01?nY_NOoZ[cWojZliol0000^
ooooo`002Oooool01000003ooooooooooooooolC000000D06ATI00<0000003<c<`0000000`1<C4`0
10000000IVIVo`00001oOgl4o`000080000000?o00000>KViP3Vi^H0203Vi^H01_l00000c<c<0<c<
c0000000/k>co`000080VIVI00Go000007moOol00000IVIV0000000204a<C0040000000c<c<0<c<c
000000@06ATIH`000004ooooo`0300000?oooooooooo03Kooooo0ol00003oooooe3oZKgX00?oZKgW
o`000?nY_NL00_nY_NL00onY_NSoZKcWojVli`02ojVmi`KoZKcW1OnZ_>L00ol0003oooooooooo`0[
ooooo`002Oooool01000003ooooooooooooooolD000000D06ATI00<0000003<c<`0000000P000000
101<C4`0000000000?l0000207moO`05o`00002IVIWo0000o`00000000000ol000060>KViP03o`00
003<c<`0c<c<0080c<c<00D000000;>c/ol00000VIVIo`00000207moO`03o`00001VIVH000000080
C4a<00@0000003<c<`0c<c<00000100I6AUR000000Cooooo00<00000ooooooooool0<oooool3o`00
00CoooooD?nY_NP3ojVmi`03o`000?nY_>OoZKcW00WoZKcW0_nZ_>H5ojZli`03ojZli_l0003ooooo
02cooooo0009ooooo`0400000?oooooooooooooooa@0000000?o00000000000000000`0I6AT01@00
0000<c<c03<c<`0c<c<000000080C4a<00<00000o`000?l000000_l0000209VIV@04o`000000003o
0000000000Oo0000103<c<`01P000000/k>c0;>c/ol00000VIVIo`000080Ogmo00?o000006IVI_l0
00000P1<C4`010000000<c<c03<c<`00000401TI6F4000001?ooool00`00003oooooooooo`0aoooo
o`;o00001?oooom>ojVmj0KoZKgW0onY_>L01?l0003oZKcWojVlionY_>H5ojVli`03ojZki_nZ_>Ko
Z[cV00;oZ[cV00?oZ[cWojZki_nZ_>H00onZ_>H00ol0003oooooooooo`0Zooooo`002Oooool01000
003ooooooooooooooolH000000<06ATI00[o00000000000c<c<0<c<co`0000000000C4a<o`000000
0000IVIV1_l000020;>c/`8000001`3<c<`01`000000/k>c0;>c/`2c/k?o000009VIVOl000000P1o
Ogl01_l00000IVIV06IVIP000000C4a<000000<0<c<c00@0000001TI6@0I6AT06ATIH@000004oooo
o`0300000?oooooooooo02kooooo0ol00002ooooodooZKgX1_nY_NL6ojVli`03o`000?nY^nKoZKcV
00;oZKcV0_nY_>L4ojZkiP;oZ[cV0_nZ^nD2ojZkiP;oZ[cV0_n[^nH00ol0003oooooooooo`0Yoooo
o`002Oooool01000003ooooooooooooooolI000000@06ATI0P00000203<c<`030000001<C4`0C4a<
008000000_l000000`1oOgoo0000o`000002o`000080/k>c00<000000<c<c03<c<`00`3<c<`00`00
0000/k>c0;>c/`020;>c/`03o`00002IVIWo00000080Ogmo00Co000006IVIP1VIVH000000P1<C4`0
1@000000<c<c03<c<`0c<c<0000000<06ATIH0000004ooooo`0300000?oooooooooo02cooooo0_l0
0003oooooe3oZKgX1OnY_NL6ojVli`;oZK_V00Co0000ojVki_nY^nKoZKcV0_nZ^^D4ojZkiP;oZ[[U
0_nZ^nD01?n[^^CoZk_Uoj^kiOn[^nD2oj^kiP03oj^kiOl0003ooooo02[ooooo0009ooooo`040000
0?oooooooooooooooaX000001@0I6AT010000000<c<c03<c<`00000304a<C0030000001VIVKo0000
0080Ogmo00?o000009VIVOl000000_l00005000000@0/k>c00Go000009VIV@2IVIT0VIVIo`000002
07moO`06o`00001VIVH0IVIV0000001<C4`000000`0c<c<00`0000006ATI01TI6@0201TI6El00000
1?ooool00`00003oooooooooo`0Yooooo`?o00000_oooomDojVmj0;oZKgW1_nY_>L4ojVkiP06o`00
0?nY^nKoZK[UojVjiOnZ^^GoZ[ST1?nZ^N@00onZ^^GoZkWSoj^ji003oj^ji003oj^kiOn[^^CoZk_U
00?oZk_U00?o0000ooooooooool0:?ooool000Wooooo00@00000oooooooooooooooo6P0000000ol0
000000000000000301TI6@04o`0000000000<c<co`000080000000?o00000000000000002_l00005
0;>c/`;o00000`2IVIT01?l00000Ogmo07moOol0000206IVIP040000001<C4`0C4a<00000080<c<c
00<0000001TI6@0I6AT00`0I6AT00`00003o00000000001K000000Cooooo00<00000ooooooooool0
9oooool2o`0000?ooooo4?nY_NP00onY_NOoZKgXojVmj003ojVmj003ojVmionY_NSoZKgX03coZKgX
1_nY_>L4ojVkiP?oZKWU00Co0000ojVjiOnY^^GoZ[SS0onZ^>@2ojZii004oj^gh_n[^N?oZkWSoj^i
h`;oZk[T00Co[;WSoj^ji?n[^^CoZk[T0_n[^nD00on/^nCoooooo`00000Yooooo`002Oooool01000
003ooooooooooooooolN000000@06ATI0P00000203<c<`80000000@0C4a<000000000000IVIV0ol0
00000`1oOgoo0000o`000006o`0000@0VIVI00Go000007moO`1oOgl0Ogmoo`00000206IVIP040000
001<C4`0C4a<00000080<c<c00<0000001TI6@0I6AT0100I6AUM000000Cooooo00<00000oooooooo
ool09?ooool3o`0000?ooooo0onY_NL3ojVmj0;oZKgW0_nY_NP01?nY_>OoZKgWojVmionY_NL2ojVm
j004ojVlionY_NOoZKgWojVmi`;oZKgX00GoZKcWojVmionY_NOoZKgWojVmj002ojVmi`CoZKgX0_nY
_NL_ojVmj0KoZKcW1_nY^nH6ojVii@03o`000?nZ^>?oZ[SS00;oZ[SS00?oZ[SToj^fhOn[]n800on[
]n800on[^N?o[;OQojbih`03ojbih`03oj^ji?n]^N?o[;_T00?o[;_T00?o0000ooooooooool09ooo
ool000Wooooo00@00000oooooooooooooooo7`00000501TI6@050000000c<c<0<c<c03<c<`000000
0P1<C4`200000080IVIV00Co000007moO`1oOgl0Ogmo1?l0000209VIV@?o00000`1oOgl01Ol00000
IVIV06IVIP1VIVH0000000<0C4a<00@0000003<c<`0c<c<000001P0I6AUL000000Cooooo00<00000
ooooooooool08_ooool2o`0000Cooooo0_nY_>L2ojVmi`05ojZki_nY_>OoZKcWojVlionY_NL00_nZ
^^D3ojVli`03ojVmionZ^^GoZ[[U00?oZKcW00?oZKgWojZki_nZ^nH00onY_>L00onY_NOoZ[cVojZl
iP03ojVmi`04ojVmj?nY_>OoZKcWojVli`;oZKgW00?oZKgXojVmionY_NL00_nY_NP00onY_>OoZKgX
ojVmj00TojVmj0KoZKcW1_nY^nH6ojVii@04ojVfh_nY]n?o0000ojVgh`;oZ[SS00CoZ[CPoj^fhOn[
]^7oZkKQ0_n[]n801?n/]Moo[;OQojbghOn/]n42ojbih`04ojfhhOn]^N?o[KWSojfih`;o[;_T0_n]
^n<00ol0003oooooooooo`0Vooooo`002Oooool01000003ooooooooooooooolQ000000@06ATI00P0
0000o`0000000000<c<c00000?l00000000004a<C0<000001?l0000307moO`;o00001P1oOgl01Ol0
0000IVIV06IVIP1VIVH0000000<0C4a<00D0000003<c<`0c<c<0<c<c0000000501TI6E`000001?oo
ool00`00003oooooooooo`0Oooooo`?o000000?oooooojZjiOnZ^^D00onY^nH00onY_>OoZ[WTojZi
i003ojZkiP03ojVlionZ^>?oZ[SS00?oZ[[U00?oZKcWojZhhonZ^><00onZ^^D00onY_>OoZ[STojZh
i003ojZkiP03ojVlionZ^NCoZ[WT00?oZ[cV00?oZKgWojZki_nZ^nH00_nY_>L01OnZ^^CoZ[cVojZl
i_nZ_>KoZKgW00;oZ[_V0onY_>L00onY_NSoZKcWojVli`04ojVmj0;oZKgW6_nY_NP00onY_NOoZKcW
ojVli`03ojVli`03ojVkionY^nKoZK_V00?oZK_V1OnY^ND5ojVfhP03o`000?nZ/mooZ[?O00?oZ[CP
00?oZkKQojbcg_n//mh00on/]Ml00on/]n7o[KGOojfhh@03ojfhh@03ojfihon^^N;o[[WR00;o[K_S
00?o[k_Sooooool000009oooool000Wooooo00@00000oooooooooooooooo8P00000601TI6@050000
000c<c<0<c<c03<c<`0000000`1<C4`30000000406IVI_l0003o0000o`0000H0Ogmo0_l0000406IV
IP050000001<C4`0C4a<04a<C00000000`0c<c<00`0000006ATI01TI6@0301TI6E`000001?ooool0
0`00003oooooooooo`0Looooo`?o00000_ooool2ojZii0?oZ[[U00?oZK_VojZgh_nZ]n800onZ^N@0
0onZ^nKoZ[CPojZdh003ojZhh`03ojZjiOnZ]=ooZ[SS00?oZ[SS00?oZ[[Uoj^dgon[]=l00onZ^>@0
1?nZ^nKoZkGQoj^ehOnZ^N@2oj^bg@?oZ[OS00?oZ[_Voj^eh?n[]N000onZ^^@00onZ_>KoZkSSoj^h
h`03ojZkiP03ojVlionZ^nGoZ[_U00?oZKcW00?oZKgXojZlionZ_>L00onY_NL00onY_NSoZKgWojVm
i`02ojVmj003ojVmionY_NSoZKgX00koZKgX1OnY_NL00onY_>OoZK_WojVki`03ojVki`03ojVki_nY
^NGoZKWU00CoZKWU00?oZKGRojVfh_nY]^800onY]^800onY/]ko0000ojZcg`02ojZcg`03ojZdh?n[
/Mco[;?N00?o[;?N00?o[;GOojfcg?n]]Ml00_n]]Ml2ojfhh@;o[kOO00?o[[WRok2jhOn_^n<00on_
^n<00ol0003oooooooooo`0Uooooo`002Oooool01000003ooooooooooooooolT000000D06ATI0P00
000203<c<`<000000`1<C4`4000000Ko0000101VIVH2000000@0C4a<00D0000003<c<`0c<c<0<c<c
0000000601TI6E/000001?ooool00`00003oooooooooo`0Jooooo`;o00000oooool2ojZgh`?oZ[WT
00?oZ[[UojZdgonZ]=l00onZ]n800onZ^NCoZ[3LojZdh003ojZdh003ojZhhon[[][oZ[CO00;oZ[CO
0_nZ^><01On[[MWoZkCOoj^dgon[]=ooZjGA00?oZjoJ00?oZkGQojbXe?n/Z=@00on[/]d00onZ]n?o
[:kIoj^eh003oj^eh003ojZji?n//mkoZkSS00?oZkSS00?oZ[_Voj^gh_n[]n800onZ^nD01?nY_>Oo
Z[[UojZjiOnZ_>L2oj^ji@?oZ[cW00?oZKgWojZlionZ_>L00onY_NL00onY_NSoZKgWojVmj00<ojVm
j0CoZKgW0_nY_>L4ojVki`KoZKWU0_nX]N82ojVehP;oZKKR00CoZK7NojVbg_nY/]ko00000_nZ/ml0
1?nZ[m_oZk7Loj^ag?n[/M`2ojbcgP05ojf`f_n]/mco[K?Lojfcg?n]]Ml00on_]=`00on_]moo/KON
ok2jh@02ok2jh@;o[k_S00?o/;cSooooool000009_ooool000Wooooo00@00000oooooooooooooooo
9@00000601TI6@030000000c<c<0<c<c0080<c<c0P00000504a<C08000001`1VIVH00`000000C4a<
04a<C00304a<C0030000000c<c<0<c<c00<0<c<c00<0000001TI6@0I6AT00`0I6AUK000000Cooooo
00<00000ooooooooool05oooool3o`0000?ooooo0_nZ]^83ojZgh`03ojZii?nZ/MgoZ[CO00?oZ[CO
00?oZ[ORojZ[f?nZ/=`00_nZ/=`2ojZdh005oj^Wdon[[][oZjkJoj^^f_nZ]=l00_n[YM43oj^]f@06
oj^dgon[YM7oZjGAoj^UdOn[[m[o[9g81?n/Z=@00on[/]go[J?=ojb^f@02ojb^f@;oZkGP00Co[J[D
ojbcg_n//mko[;?N0_n[^><2ojbaf`03oj^gh_n]/=[o[K3J00?oZkOQ00?oZ[[UojbghOn[^^D00on[
^^D00onZ_>OoZk[UojZli`03ojZli`03ojVmionZ_>OoZ[cW00;oZKgW0_nY_NP2ojVmi`OoZKgX1_nY
_>L00onY^^KoZK[UojVji@02ojVji@03ojViiOnX]^?oZ;GR00CoZ;GR1?nX/=d3ojVagP;o00001?nZ
[m/00on[/Mco[:gHojf`fP03ojf`fP03ojfcg?n_/M[o[k7J00;o[kCL00Ko/[CKok6gg_na]mko/KON
ok2jhOnb^n04ok2lh`03ooooool0003ooooo02Cooooo0009ooooo`0400000?ooooooooooooooobD0
000000Co000000000000000000000`0I6AT01000003o000000000000000203<c<`D000000P1<C4`6
00000003o`00001<C4`0C4a<00@0C4a<00?o000003<c<`0c<c<00`0c<c<00`0000006ATI01TI6@04
01TI6EX000001?ooool00`00003oooooooooo`0Fooooo`;o00000oooool00onY]>7oZ[KRojZfhP02
ojZfhP03ojZghonZ[]_oZ[7M00;oZ[7M0_nZ]=l01OnZY]?oZZ_HojZ[f?nZZmSoZ[3L00;oZZ3<0on[
Ym<00on[[][oZYc7ojZLa`03oj^Ud@03oj^]fOn[VlKoZi_600?oZjGA0on/WLP2ojbXe005ojbF`?n]
Xlgo[J?=ojfScOn/[]T00_n]W/L3ojfZe003ojbcg_n^Ym7o[ZOA00?o[;7K1?n]/=X00on[]n7o[[3I
ojbgh@02ojbgh@;oZk[U00Co[;OQoj^jiOn[^^GoZk[U0_nZ_>L2oj^ki@03ojZlion[^nKoZ[cW00?o
Z[cW00?oZKgWojZlionY_NL00onY_NL00onY_NSoZKcWojVli`04ojVli`CoZK[V0_nY^^D4ojRfh`;o
Z;GR00?oYk3NojR`gOnX/=d00_nX/=d01onXZMSo0000o`000?l0003oZJgIo`000?nY[MT00_nZ[m/0
1?n[Z]Go[:gHojb]f?n/[MP2ojf`fP04ojn^e_n_/M[o[k7JojnafPCo/[CK00?o/KONok>igOnb^n00
0_nb^n02ok2lh`;o/[kS00?o0000ooooooooool08oooool000Wooooo00@00000oooooooooooooooo
:`00000501TI6@8000001@0c<c<3000000X0C4a<0P00000603<c<`030000000I6AT06ATI00@06ATI
FP000004ooooo`0300000?oooooooooo01Kooooo00?o0000ooooool000000_nY]>02ojVdh@;oZ[KR
00GoZJcIojZ^fonZ[]_oZZkKojZag@02ojVRc`?oZZKC00?oZZ_HojVIa_nYVLH00onZX<`00on[Ym?o
ZI>oojZLa`03ojZLa`03oj^UdOnZT;_oZi_600?oZi_600?oZjGAoj^B_?n[T[`00_n/WLP01?n/Z=Co
[9K0ojbF`?n/U/02ojfSc@Co[Ik700?o[J[DojnJ`on^Ym400on^Ym400on//M_o[jK>ojnVcP02ojf`
fP05ok2VcOn^/=Wo[[3Iojj`fOn/]n400_n_/MX3ojbgh@06oj^jiOn/^>;o[;SRojbhh_n[^nGo[;WS
0on[^nH2ojZli`04oj^li_nZ_>OoZ[cWojZli`;oZKgW1OnY_>L2ojVkiPCoZK[V00?oZ;OTojRfhonX
]^<00onX]^<5ojN`gP05ojR`gOl0003o0000o`000?nXZMP00onYZmP00onY[MWo0000oj^Ze@03oj^Z
e@03ojb]f?n^ZM?o[jkF00?o[jkF00?o[k7Jok:aeonb/ML00_nb]=/01One]]Wo/kWMok>igOnc^Mgo
/[_P00;o];gP0_nb_^<00onc`>?oooooo`00000Tooooo`002Oooool01000003oooooooooooooool/
000000H06ATI0P00000603<c<`X000001`0c<c<00`0000006ATI01TI6@0501TI6EX000001?ooool0
0`00003oooooooooo`0Fooooo`05o`000?nY]>7oZKCQojVdh?nX[=X00onYZmT3ojV/f@03ojZ^fonY
X<goZJ3=00?oZJ;?00?oZZKCojRD`OnYVLH00onYVLH00onZX<coZ8bhojVC_`02ojVC_`;oZYc700Co
ZHRbojZ@^onZT;_oZY2k0_n[VlH01_nZR;7oZi:loj^B_?n[T[co[9g8ojb;/`Co[9K000?o[J?=ojfA
^On]TKT00on]W/L3ojnJ``;o[ZOA00Co/9W0ojnVc_n_Y/ko[jK>1?n`Y/d00on^/=Wo/ZS>ojnafP03
ojnafP03ojbghOn_/]_o[k;K00;o[;SR00Go[kGMojbihon/^N?o[;WSoj^kiP02ojbji0?oZkcV00?o
Z[cWojZli_nZ_>H01?nY_>L5ojVkiP03ojVji_nX^>CoZ;ST00;oZ;OT0_nX]^<00onW/MooYk3NojN`
gP02ojN`gP?o00000_nWZ=L3ojRYf005ojV[f?nYY=;oZZOCojZWdol000000_n[Z]D01?n]YM3o[ZWC
ojjYdon^ZM<2ojn^eP04ok:/donb/MOo/[7Gok:ae`Co]KKI00Go/kWMokNkgOng^mgo];gPokJoh@04
ok?0h`03o`000?oooooooooo02;ooooo0009ooooo`0400000?ooooooooooooooob`0000000?o0000
0000000000001@0I6AT00`00003o00000000000C03<c<`030000000I6AT06ATI00H06ATI00?o0000
000000000000E`000004ooooo`0300000?oooooooooo01Kooooo00Co0000ojVdhOnW[]coYjkL0_nX
[=X3ojV[f@03ojV/fOnXWlgoZ9o=00?oZJ3=00?oZJ;?ojNA_onXU<400_nXU<42ojVIaP04ojN7/onX
S;SoZ8bhojR<^0;oZI>o00?oZYc7ojV8/_nYR;800onZT;/01?n[VlKoZXRaojZ8/OnZR;42oj^B_0?o
[8^c0on/U/04ojfA^@03ojfNaon_SkCo[hnd00;o[i[31?n`VL000on_Y/ko/YZook:J_`03ok2Vc@?o
/ZS>0_n_/MX2ok>[d003ojnbfonc[mCo/joD00?o[kGM00?o[;WSojnggon/^^@00on/^^@01?n[_>Ko
[;_UojbkiOnZ_>H2oj^ki@?oZ[_V00?oZK_VojViiOnY^ND00onX^>D00onX^>CoYk?QojNbh003ojNb
h0;oYk7O0ol00003ojJXf003ojNXeonVX=3oYj;@00;oYj;@0onYY=800onZYm?oZj;=o`000003ojfU
d003ojjYdonaZ<oo/ZcC00?o/ZcC00?o/[7GokJbeOnf/]D00_ne]]T01?ni^=Wo]k_MokNkgOng^md3
okJoh@;o/l3S0_nd`^@00ol0003oooooooooo`0Qooooo`002Oooool01000003oooooooooooooool`
000000L06ATI0`00000@03<c<`030000000I6AT06ATI00H06ATIFP000004ooooo`0300000?oooooo
oooo01Gooooo00?o0000ooooooooool00onW[]`2ojR/fP03ojV[fOnWX<ooZ9o=00?oZ9o=00?oZJ3=
ojJA_onWTKl00_nWTKl2ojRD`@03ojVIa_nWQk?oYhNc00?oZ8bh00?oZI>oojN2[?nYR;800onYR;82
ojZ@^`CoZXRa00?oZi:loj^2ZOn/Rk<00on/Rk<00on/U/3o[HN]ojf7[@02ojfA^@05ojn5ZOn_SkCo
[hndojn?]?n_V/<00_naS[83ok2I`0Co/YZo00Co/:K=okFM`?neWL3o/ZS>0_ngX/@3ok>[d0Co/joD
00?o[kGMok>cf?n_]ml00_n_]ml2ojbji0;o[[WR00?o[;_Uojfki?n[^nD00on[^nD00onZ^nKoZ[[U
ojVii@03ojVii@03ojRhiOnW]>;oYk?Q00;oYk?Q0_nW/^03o`0000?oYJSH0_nVZ=P01?nTWm3oYZ3@
ojJPd?nVX=03ojNRd008ojVTd_nYW/_oZj;=oj^RcOl0003oZj;=ojfUd?n_Xl/3ok6Xc`;o/ZcC00Co
]Zg@okJbeOnf/]Go][;E1?ni^=T01?ng^mgo^[oNokZog_nf_n42okS3hP;o]<;T00?o]LCUooooool0
00008_ooool000Wooooo00@00000oooooooooooooooo<`00000701TI6@L000001P0c<c<3000000T0
6ATIFP000004ooooo`0300000?oooooooooo01Gooooo00Ko0000ooooooooooooooooojN^g?nTYmP2
ojFRd`?oYj3?0_nXWld00onTT/;oYY6oojJA_`03ojNA_`03ojRD`OnUQK7oYhNc00?oYhNc0_nXS;P3
ojN2[0?oZHRb00?oZY2kojV1ZOnZR;400onZR;43oj^2Z@?o[8^c0on]Qjd00on]TKWo[hFYojn5Z@03
ojn?]0Co/Hjb00?o/9W0okB@/OndT;400_nbV[l01?ngU;?o]Ig0okFM`?neWL04okNRa003ok>[d?ni
Z<Wo^JS900;o/joD00Go^Jo?ok>cf?nc/mSo/k?Hojngg`03ok:gg@03ojjih_n`^^3o[K_T00;o[K_T
0_n[^nD01?n[^^CoZ[[UojZjiOnZ^^D2ojVii@05ojRfhonW]>;oYkCRojNdh_nW/n400ol00002ojFZ
fP;oYJWI00?oYJSHoj>Nd?nTWm000onTWm02ojJPd0;oYj;@00CoYi[9ojVNbonYW/_oZIk;0_n[X/d0
1Ol0003o[j?;ojnSbon_Xl_o/JS?00;o]:S<0onf[M000onf/]Go^[GDokZee002okVhf@;o_KgI00Go
^[oNokc3gonl`moo^<?RokW6i004okG4i@03o`000?oooooooooo023ooooo0009ooooo`0400000?oo
oooooooooooooc@0000000?o000001TI6@0I6AT02P0I6AT6000000`06ATIFP000004ooooo`030000
0?oooooooooo01Gooooo00Co0000oooooooooooooooo0onTYmP2ojFRd`03ojNPconRULOoY9;200;o
Y9;20onVTKl2ojNA_`?oYHFa0onWQk<00onXS;SoYWjXojN2[002ojN2[0?oZHRb0onYPJT2ojZ8/@04
ojYlX_n[PZWoZh:Yoj^2Z@;o[8^c00Co[7nTojf7[On]Qjgo[HN]1?n_QJT2ojn?]0Co/Hjb0ondT;40
1?nbV[oo]iBcokND/ongU;<2okFM`004ok^K]ongX/Co]j;4okNRa0?o^JS91?ni[ll00onc/mSo^;GF
okReeP02ok:gg@05okJjg?n`^^3o/;[Pok2jh?n]^n@00on^^n<2oj^ji003ojZjiOnY]n?oZKOS00?o
Z;KS0ol00003ojF/g0;oYJ[J00?oYJWIoj:OdOnSW]000_nSW]03ojBOd003ojJPd?nUV<SoYi[900?o
Yi[90_nYW//3ojfNa`03o`000?n_Xl_o[j?;00Co]:S<00?o]Zg@okZ`conj]M@00_nj]M@3okfmf@04
ol72fonl`moo_<?Ookc3g`?o^LKT0_nea>D2okC5i`03o`000?oooooooooo01oooooo0009ooooo`04
00000?ooooooooooooooocT000006@0I6AUK000000Cooooo00<00000ooooooooool05Oooool00ol0
003oooooooooo`02ooooo`;oY:OH00?oYJ;CoinJconRULL00_nRULL3ojBB`P;oYY6o00?oYi6oojB4
/_nUQK400_nUQK43ojN7/`;oYWjX1?nWPZ`00onYR;;oZ7bSojV1Z@02ojV1Z@03ojZ8/OnZO:;oZWbR
00?oZh:Y00Co[8^cojaoY?n/OjCo[7nT0_n]Qjd4ojn5Z@03ojn?]?nbQZOo/XJW00;o/Hjb00Co]XVW
okB@/OndT;7o]92a1?ngU;<01OneWL3o^i^gok^K]onkVkOo]j;400;o_Z:m00?o^JS9ol2[aOo0ZlD0
0oni[ll3okReeP05okjkeonf^]co][[LokJjg?n`^^000_nc_>42ojjkh`06ojnkhon[^N?oZkWSoj^i
honY]n?oZ;;P0ol00003ojF^g@;oYJcL00?oXZ;Eoj:PdonRX=<00onRWm43oj>Nd003ojBOd?nSU/Oo
YIS800;oYIS80onWV/T00onYW/_oZYW5ojZIa@03ojfNa`03o`000?ncX/Oo/j;700;o]:S<00Go^Z[:
okZ`conj/<oo^[3?okZee002oknje005okfmfOo1`]_o`L;Kol72fonl`ml00_nnan400onia^Co^LSU
okW8i@02okC5i`;o]<KX00?o0000ooooooooool07_ooool000Wooooo00@00000oooooooooooooooo
>`00000F01TI6E`000001?ooool00`00003oooooooooo`0Eooooo`03o`000?oooooooooo00?ooooo
0_nLXMT2oinJc`?oXYG70_nTT/800onVTKooXHFeojB4/P02ojB4/P?oYHFa00?oYhNcojElYonVOZP0
0_nVOZP3ojN2[0?oZ7bS0_nYPJT4ojYlXP;oZh:Y1?n/Oj@00on]Qjgo[gnQojn5Z@03ojn5Z@?o/XJW
00Co/HjbokJ9YonfRJOo]XVW0_ndT;401?njSjWo]iBcokND/ongU;<4ok^K]`?o_Z:m1?o0ZlD01?ni
[loo`;C>ol2dc_nh]MH3okjke`04okJjg?ni_]ko^KkNok>lh@;o/kkR0on_^n<01?n[^N?oZ[KQo`00
0?l00002ojRbh0;oY[3O00?oYJkMoj:TeonRX]D00onRX]D2oj:Pd`03oj:OdOnOU<SoXIC700;oXIC7
0onSU/L3ojFHb003ojNJbOnWUL;oZYW500;oZYW50_n]W/L01On`W<?o0000ok>RaoncX/Oo]:S<00?o
^Z[:00Co^[3?ol2ecoo0]Loo_k[D0_o4`=H2ol72f`;oa<SM00Co_/OQoko;i?nobnCo^LSU0_nib^L2
okC6j003ok;6j?l0003ooooo01oooooo0009ooooo`0400000?oooooooooooooooch000004@0I6AUN
000000Cooooo00<00000ooooooooool05Oooool00ol0003oooooooooo`04ooooo`;oW:7I0_nOV/l0
1?nRULOoV8g7oif8_?nMR;`2oj65]@?oY8Bb0_nUQK400onSNjSoYGbWojElY`03ojInZ0;oYh:/00Co
YgVPojQlXonXO:?oZ7bS0_nYPJT4ojYlXP;oZh:Y1?n/Oj@00on]Qjgo[gnQojmoX@03ojn5Z@?o/XJW
1?nfRJL00ondT;7o^XnYokZ?Z@03okND/`03oknF[OnkVkOo^i^g00;oa9nc0_nnX[d01?o8Z[co`:_5
ol2[aOo9]LH3ol2dcP04olNnd_nn^mOo_[_Gol;4f`?o^KkN1?nc_^801On_^n?o0000o`000?l0003o
Z[KQ00;oZ;;P00?oYJ_Loj>WfOnSYmT00onRY=L3oj:Re@03oj:PdonNUL[oWiC800;oWiC80onQU<L2
oj>Fa`;oYIS800KoYI71ojNE`_nWUL;oYiG2ojZIaOn]Ul04ok2L``03o`000?nhY<Go^Z[:00;o^Z[:
00Co`;3:ol2ecoo0]Loo`;G?0oo4`=H3olC8g@07olK>hOnobnCo_l_Toko;i?noc^Ko^L[WokO:j004
ok;6j003o`000?oooooooooo01gooooo0009ooooo`0400000?ooooooooooooooodD00000200I6AUP
000000Cooooo00<00000ooooooooool05?ooool00ol0003oooooooooo`05ooooo`;oRIkR0_nAUM@2
oiR=a`;oWHRl0onQQKD2ojB4/P03ojF5/OnSNjSoXg^X00?oYGbW0_nVOZP00onWPZcoYgVPojMiX003
ojQlX`03ojV1ZOnYNIkoZWbR00?oZWbR00?oZh:YojakW_n/Oj@00on/Oj@3ojmoX@;o[hFY00Go/h:O
ok:6YonbQZOo/XJWokR6X003okJ9Y`Co^XnY00Co]iBcoknF[OnoUZgo^i^g0oo4Wk<01?nnX[gob:Zl
olRZ_?o0ZlD3olVeaP04ol2dc_o7_];oakkBolc=fP?o`/CK00Co^KkNok[4h_nja>;o/kkR0ol00002
ojfjhP03ojZfhOnW/=koYk3N00?oYJ_L0_nSYmT00onRY=OoWYW?oijFc002oijFc0?oWYG:0onOU<P0
1?nQU<OoWhbooj:>_onRS[l4ojFA`@;oYiG20on]Ul03ok2L``04okRTaOl0003o^:C5okZZbP?o`;3:
00Co`;G?olNmdOo7_M7oa<3F0_o9b=T01Oo4b=goa/kQolK>hOo6c^7o_l_T00;o_lkV0ongb^P2ok;6
j0;o/LGY00?o0000ooooooooool07?ooool000Wooooo00@00000oooooooooooooooo[@000004oooo
o`0300000?oooooooooo01Cooooo00?o0000ooooooooool01_ooool2ohVNhP;oTIGD0_nHSLL2oif8
_0;oXHFe00?oY8Bboimk[?nSNjP00_nSNjP3ojElY`;oYWjX1?nWNJ02ojQlX`?oZGVN0onZO:83ojak
WP?o[7nT0on_Oj401On_QJWo/h:Ook>2WoncPYoo/XJW00;o^8JP0onfRJL4okZ?Z@?o_iJ]1?o4Wk<3
olRZ_006omBj`Oo9]LKobKG6olVea_oCa/koakkB0oo<cMX00oo2a=_o`/gSol;=h`03o`000003okO6
i_nb_nCo[K_T00?oZ[GQ0onW/=h01?nUZmcoX:7EoijLd_nNW=83oijIc`?oWYK<0_nNULX2oinDb003
oif;_onOS;ooWhbo00?oXXjo0onUTL400onWUL;oZI6mojfG`003ojfG`005ok2L`oneW/7o]Ik1okRT
aOl000000oo0/<X01?o8^<_oakgAolNmdOo7_M43olW8f@03olgAg?o6c^7oa/kQ00;oa]?T00Co_lkV
okg?j?nmcnSo]l[X0_nebNT2ok75j@03ojo4jOl0003ooooo01gooooo0009ooooo`0400000?oooooo
ooooooooojd000001?ooool00`00003oooooooooo`0Dooooo`03o`000?oooooooooo00Oooooo00?o
F9O_oi6Ee?nAUM@00_nHSLL2oif8_004oj65]OnIOK?oWg^/oimk[0CoXg^X0_nUO:L00onVOZSoYGNO
ojMiX003ojMiX0;oZ7bS0onYNIh3ojYlXP?o[7^N0_n/Oj@01?n`O9co[gnQojmoXOn_Oj44ok>2W`03
ok:6YonhQZ3o^8JP00;o]XVW00?o_HbRokZ?ZOnjSjT00_njSjT3oknF[@Coa9nc00?od:feolRZ_?o8
Z[`00_oD^/400oo9]LKodlK>om?6cP03olc=fP05olWJiOl0003o0000o`000?nld>T00_nga^H01_na
`nSo[K_Tojfki?n]^nCoZ[GQojB/g@?oXZKI0onPXMD2oijLdP?oWYW?00CoWYK<oiV;`onKR/7oVh[1
0onMRkl3oin<_`;oXXjo0_nUTL401?nVSK_oZI6mojVA_OnYTKd2ojfG`008ok6G_?neW/7o]Ik1okFN
`OnhY<Go0000okjYa?o0/<X3olRhb`04olNmdOo>am?oc/OColW8f@;ocM7L00?ocmSPolKCi?o6dn@0
0_o5e^L01?nmcnSo^/oYok[?jOnebNT2ok;7jP;o[lCY00?o[/;Yo`000?ooool07?ooool000Wooooo
00@00000oooooooooooooooo[@000004ooooo`0300000?oooooooooo01Cooooo00?o0000oooooooo
ool02?ooool2ofN>i0;oOXOA0_n?PL02oiUm/`;oWg^/1?nSNjP2ojElY`;oYGNO1?nWNJ000onXO:?o
ZGNKojUiWP02ojUiWP;oZWbR00Go[7VJojakW_n/Niko[7^NojaoY003ok1lW0;o[gnQ1?ncPYl01Onb
QZOo^8JPokR6X?nhQZ3o]XVW00;o_HbR0_njSjT2ol>DYP03oknF[Oo:WjcobYn/00;oa9nc0_o@[KD0
1_o8Z[coe;[1omBj`OoD^/7oh=G=om?6cP;oemcK0ol00002okoMk`03okc@jOncc>co/lc/00?o/L?X
00?o[K_TojNchOnT[=d00_nT[=d3oj:Vf@;oX:7E00?oWYcBoiV@bOnISLD00_nISLD2oiV;``?oVh[1
0onMRkl2oin<_`03oj:>_onRRKWoYXfk00?oYXfk0_nYTKd01?n]Ul3o/INlok6G_?naUk`2okFN`@;o
_ZW400?o0000olNba_o8^</00_o8^</3olk7d`05om?Beoo=dMcocmSPoloHh?o>gN@00_o5e^L2ol;F
j@05ok[?jOngcN_o]lg[ok;7j_n`aNX00on^`^T00ooooooo0000ooooo`0Kooooo`002Oooool01000
003ooooooooooooooon]000000Cooooo00<00000ooooooooool05?ooool00ol0003oooooooooo`09
ooooo`;oIhkT00?oOXOAohn1`?n?PL000_nIOK<3oimk[0?oXg^X00?oYGbWoj=fXOnUMil00_nUMil3
ojMiX003ojQlXonYMi_oZGVN00;oZGVN00?oZWbRojaiV_n/NIX00on/Nih4ok1lW003ojmoXOndOi_o
/h:O00?o/h:O1?nhQZ001?nfRJOo_HbRokf<X_njSjT3ol>DYP04oknF[Oo:WjcobYn/olBO/`?od:fe
0ooD^/42on3Ec@?o000000Coc^cYokc[m?nljoCo_mg_0_nceO83ok?<k003ok73j?nY^^KoZK[V00;o
Yk?Q00?oY:cMoifPe_nKV]400_nKV]42oiVDc@?oVI390onISLD2oiV;``;oVh[10onMRkl00onOS;oo
WXFhoj:9^@02oj:9^@?oYXfk00?oZI6mojfA^OnaUk`00onaUk`00oneW/7o^j>ook^S_`02okjYa003
o`000?o7//Kob;S;00;od<?>00Goc/OCom?BeooCd]OoemcKoloHh002olkMi003ol[Oj?o2e^Wo`]KY
00;o_MC[00?o]lg[okC:jon`aNX00_n`aNX01?n^`^Wo[<7Yojc1jOl0000Looooo`002Oooool01000
003ooooooooooooooon]000000Cooooo00<00000ooooooooool05?ooool00ol0003oooooooooo`0;
ooooo`;oOXOA0_n?PL02oiUm/`;oWg^/0_nSNjP00onNMZGoXgJQoj=fX@03ojEgW`?oYgVP0onYMi/2
ojUiWPCo[7VJ0_n/Nih4ok1lW003ojmoXOndOi_o/h:O00?o/h:O1?nhQZ03okf<XP04okZ?ZOo3U:Ko
`iBVol>DYP?obYn/00KofkBaom2]]Oo@[KGod:feon76__oD^/43o`000003omocfoo4o>Koc^cY00;o
_>_d0_n_gOL00onceO;oZ/O_oj[7k`03oj[1jP04ojVji_nQ[^3oWjOKoinWf`?oWJ3F0onKV]42oiVD
c@;oVI390onISLD2oiV;``03oi^:`OnHPKWoVh>h00;oVh>h0_nNQKP4oj:9^@03ojJ=^onXS;Oo[I6i
00;o[I6i0_naUk`02?nhVk_o^j>ook^S_onkXkoo_ZW4olNba_l0003oak;60oo@`lh01_oHdM;odm;G
omOLfooGg=_oenCPolkMi0;ob]oX00CoaMg[okgDjonme>_o^M3/0ondb^/01on`aN[o[/?Yojk3jOn/
`NWoZl3Yooooool000006oooool000Wooooo00@00000oooooooooooooooo[@000004ooooo`030000
0?oooooooooo01?ooooo00?o0000ooooooooool03Oooool00ol=H]WoSh70ohn1`002oiUm/`;oWg^/
00?oXg^XoiifYOnNMZD00_nSMZ43ojEgW`;oYgVP00CoZ7JKojUgVonYMi_oZGNK0_nYNIh4ojaiVP03
ojakW_n`NiWo/7bL00?o/7bL00?o[gnQokAoVondOi/00_ncPYl00onjQIco^8JPokR6X002okR6X0?o
_HbR1?o3U:H3olZO[0;ofkBa00Sod:feo`000?l0003o0000onc]booPeLgogo?KolCliP;o[??c0_nV
hO/00on_gOOoZ<_bojS;lP03oj[7k`03oj[1j_nS]>GoXJkP00;oXJkP0_nOYm/3oifPeP;oVi[A00Co
VIC=oi:7a?nBQ<3oTXC00onCP[d2oiF1^`?oV86i0_nKPkP3oij5^0;oXXVi00?oY8JeojR<]onXS;L0
0on]TKT01?naUkco^9^kokRK^onhVk/2ok^S_`?oak;600?o0000om6nb?o@`lh00_oHdM801_oNg]Ko
emcKomOTh?oGi>3oe>STol[Oj0;oaMg[00?o_mW/okW@k?ndc>`01?naan/00on^`nWo[<;Yojc2j@02
oj_0j@03o`000?oooooooooo01Wooooo0009ooooo`0400000?ooooooooooooooojd000001?ooool0
0`00003oooooooooo`0Cooooo`03o`000?oooooooooo00kooooo00Ko3F;IoeQbd_n3M[goPgJmoimk
[?nFMZd3oiifY@?oXgJQ0_nUMil00onWNJ3oZ7JKojQfV`03ojUgV`03ojUiW_n/N9Wo[7VJ00?o[7VJ
00?o[7^Nok1kVOn`O9`00on`O9`3okAoV`;o/h:O0_njQI`2okR6X004ol6=W_nmS:;o_HbRokf<XP?o
`iBV0_oBY:P00oo:WjcofkBaom^d/@02o`0000;ohLJn00?ok>g;olWnaon>jl400_n9k>L2oi_Qo@04
ojKQnonUcOCoYLgdojS;lP;oY;g[0onT^NP2oj>di@04oj6^h?nIX=WoUiWCoiNId`?oUI;>0_nCS<T2
oi:7a0?oTXC00_nCP[d2oiF1^`?oV86i0onKPkP2oij5^003oj:9^OnTQ[GoY8Je00?oZ8bg0_n]TKT4
okRK^`04ok^S_oo4Zl7oa:_1olNbaP;odKk800?o0000om_>c?oHdM800_oNg]H00ooPjMWoenCPomCX
i002olkXj003olGMjonofNco_mW/00?o]<c/0_naan/2ojk4jP03ojc2jOn[`>WoZkoX00;oZkoX00?o
0000ooooooooool06?ooool000Wooooo00@00000oooooooooooooooo[@000004ooooo`0300000?oo
oooooooo01?ooooo00?o0000ooooooooool03oooool00ona9P3oPgJmoh=f_@02oiIf[@?oWWJU0onS
MZ42ojEgW`?oZ7JK0onYMi/00onYNIko[7RIojaiVP03ojaiVP03ojakW_n`NiWo/7^I00?o/7bL0ond
Oi/01?ncPYoo^XFLokZ5W?njQI`2okR6X0;o`HfN00?o_HbRolVGX_o9Uj800_o3U:H2om:TZ0?o0000
00KofkBaoo3K_?oQa[kok>g;o`000?n?f?l2oi;MoP;oXL[e0_nSc?H00onUcOCoY;o/ojBok003ojBm
j`04ojBij?nN[N;oW:OMoibWg@?oVJ3I0_nGVM<3oiFBcP;oThc90_nBQl@2oi:4`0?oTh:m0_nEPK/3
oiR1^@;oVh>h00?oWXFhoin2]?nTQ[D00onTQ[D2ojR<]`03ojfA^OncU;So/iBh00?o^9^k0oo4Zl43
om6nb004om_>c?l0003oi=o?omkNeP;oh>WI00?ogO7MomOchoo>j>P00_o7i>`01?nofNco^]?]ok[C
kOndc>`2ok78j`;o[/CZ0_n]`^T2oj_0j@04oj^oj?nZ_^SoZ[kXo`0001Wooooo0009ooooo`040000
0?ooooooooooooooog/000003`0I6ATS000000Cooooo00<00000ooooooooool04oooool00ol0003o
ooooooooo`0@ooooo`04oeQbd_n3M[goUWJ]oiIf[@?oWWJU0onSMZ42ojEgW`?oZ7JK0onYMi/00onY
NIko[7RIojaiVP03ojaiVP?o/7^I0_n`O9`01OnfOiWo]7nKokAoVondOi_o/h:O00?o^XFL00Go^8JP
ol6=W_o1SIko`HfNokf<XP02olVGXP04ol>DY_l0003o0000o`0000?ofkBa0_o`fk`00ooInk7oX/Ca
oj;4l@03oj77l`03oj7:mOnU_ncoY;o]00;oY;o]00?oY;o/oj:fi_nR]^H00onQ/^@2oij]hP;oW:OM
0_nIX=T3oiNId`;oUI;>0_nCS<T2oi:7a0?oTXC00_nCP[d2oiF1^`;oV86i00?oUW^coiYn/onJO[<0
0onOP[@3ojB6]@03ojR<]on]S[Go/iBh00?o/iBh00Co^9^kol2T_?o0Y;coa:_10_o?^<<02OoA_/So
flk<om_>c?l0003oi=o?onO^d_oPjMWogO7MomOch`02om3`j@04olOTk?o0gNko`=g^ok[Ck@;o]Lk/
00?o/LS[ojk4j_n^a>X00_n]`^T01?n[`>WoZkoXoj^oj?n[_nP2ojZnj003o`000?oooooooooo01Oo
oooo0009ooooo`0400000?ooooooooooooooog@000006P0I6ATO000000Cooooo00<00000oooooooo
ool04oooool00ol0003oooooooooo`0Aooooo`;oPgJm0_nFMZd2oiifY@?oXgJQ00?oYGNOojEeWOnX
MY/00_nXMY/3ojUgV`?o[7RI0on/NIX3ok1kV@;o/7bL00Co]WnIokAoVondOi_o]7nK1?njQI`01Onh
QZ3o`HfNol6=W_o1SIko_HbR00?o00000ooBY:P00ooYa;3ofkBaoo3K_002oo3K_005ojC2konRa?7o
X/Caoj;4lOnQao<00_nV_n`2ojFok003ojBokOnT^>OoY;SW00?oX[KV00CoXK;Toi^XgonHXM_oV:7K
0_nDV]H2oi6Bd@?oSX[;0_n<Q<D2oh]o`0;oS7^l0on=NKP2ohmi]P;oTWVd0onFNk<2oiYn/`?oWh:d
0onTQ[D3ojf>]@;o/iBh00Co^ibhol2T_?o0Y;co`:Bl0oo?^<<01OoLbLOoflk<onCOcooTgloo0000
00;oi?OC00?oeo?Som3`jOo@l>T00_o8jNd01?o0gNko^]K^ok[Fk_nec^`2ok78k003ojk4j_n/`^Wo
Zl3Y00;oZl3Y0_n[_nP4ojZnj003o`000?oooooooooo01Kooooo0009ooooo`0400000?oooooooooo
ooooog400000800I6AT00ol0000000000000000I000000Cooooo00<00000ooooooooool04oooool0
0ol0003oooooooooo`0Booooo`03oh=f_OnFMZgoUWJ]00;oWWJU0_nSMZ400onOM:;oYGFMojEeW@03
ojQfV`?oZGNK0on/N9T2ojaiVP05ok5kV?n`NiWo/7^Iok1kVOn`O9`00onfOiT2okAoV`Co^XFL0_o1
SIh3o`0000;obINR0ooBY:P2onW4/0;ol?J]00Col=^lojC2konW_^[oYkkZ0onV_^/00onV_ncoYk_X
ojFjj002ojFjj003ojBhionR/nCoX[?T00;oWjkR0onKZ=l2oiRQf`;oU9[F0_nAT]43ohj:b`;oS8C5
00CoRgo0ohak_?n<NkcoS7^l0_n=NKP2ohmi]P?oTWVd0onFNk<2oiYn/`?oWh:d00?oY8JeojN7/on]
S[D00_n]S[D01?ncU;So^ibhok^L^?nkW;P2ol2T_00<olba_oo?^<?og<W7omc9aooWgL[oi=o?onO^
d_oTmm?o0000omgkf?oFnmooc_KX0_o8jNd00oo0h>oo^]K^ok[FkP02okC>k@03ok78k?n^a>_o[/C[
00;o[<;Y00?oZl3Yoj^oj?n[_nP00onZ_^P3ojVmj003o`000?oooooooooo01Gooooo0009ooooo`04
00000?ooooooooooooooofd00000:00I6ATH000000Cooooo00<00000ooooooooool04_ooool00ol0
003oooooooooo`0Dooooo`;oUWJ]0_nNMZD00onSMZ7oWgBRoimdXP02ojEeW@?oZ7JK0_nYMi/01?n/
MiWo[7RIojahVOn/N9T2ojaiVP05ok5kV?n`NiWo/7^Iok1kVOn`O9`00onfOiT00ondOi_o_HJJokZ5
W002okZ5W0?o00000_o1SIh3olVGXP03omf_YooBY:SodZBX00;ojLB`0_o`mZd3ojRnj@;oYkkZ00?o
Y[k[ojNlj?nW_>P00_nW^nP00onU^^SoY;KVojBfiP03oj:ci0;oWjkR00CoVjSOoiBNfon?U]KoSiKF
0_n;SM03ohN4b@;oSX[;0_n<Q<D2oh]o`0;oS7^l0on=NKP2ohmi]P;oTWVd0onFNk<2oiYn/`;oWh:d
00CoXX:aojN7/onWQk?oYhNc0_n]S[D4ok^L^003ol2T_?o</Kooc;6o00?og<W700Ooimg:ong_b_oX
n/Ooi?OComgkf?l0003oc_KX00;oa^c_00?o`>3_okWFkonie^l00_ndc^d2ok38k003ojk4jon/`^Wo
Zl3Y00;oZl3Y00?oZkoXojZnj?nZ_^P00onZ_^P2ojVmj003o`000?oooooooooo01Gooooo0009oooo
o`0400000?ooooooooooooooofX00000;00I6ATG000000Cooooo00<00000ooooooooool04_ooool0
0ol0003oooooooooo`0Dooooo`;oK6c00_nCLj`3oimdXP?oYGFM0_nXMY/00onYMi_o[7NIojagV@03
ojahV@03ojaiV_naNiSo/G^H00?o/7^I1?nfOiT00ondOi_o_HJJo`000002o`000005olJ@WOo1SIko
`HfNol6=W_o@WJ400_o9Uj83omf_Y`05om:TZ?oYa;3ol?J]oo3f[OnX_NP00_nX_^T01_nY_NSoZ;cX
ojRlj?nX_>SoYkcXojNji`?oY[WW00?oY;KVoj6bi?nQ/^@00_nM[N82oiVVg`?oU9kK0_n?U]H2oh^=
d0;oQhC90_n4OL<2oh=h_P;oQ7Bi0on<Nk`2ohei^0;oSgVf0onBNK@2oiIk/`03oiYn/onLOK3oXX:a
00;oXX:a0onWQk<00on]S[Go]IBeokFD]@03ok^L^0?oc;6o00_of/?2omc9aooWgL[oimg:ong_b_oX
n/Oog_k6omGocOl0003ob_WYolK/k`02okkPl003okWFkoncc^go/lk]00;o/<S/00Go[LC[ojc2jOn/
`^Wo[<;Yoj_0j@02ojZoj0;oZ[kX1_nY_NP00ol0003oooooooooo`0Dooooo`002Oooool01000003o
oooooooooooooomT00000003o`0000000000000003006ATI00?o00000000000000004`000004oooo
o`0300000?oooooooooo01;ooooo00?o0000ooooooooool05Oooool00om/K<3oTg>/oi=c[003oimd
XP?oYGFM0_nXMY/3ojagV@?o[7RI00?o[7VJok5kV?naNiP00on`NiT3okIoV@?o000000?o_HJJokZ5
W?njQI`00_o6T9d2ol6=WP;od9fQ00CobINRomf_YooM[jOogJnW0_oYa;000oo`mZgoZ;gXojVmj004
ojVmj003ojRlj?nX^nOoZ;_W00;oYk[W00?oY[WWoj>fi_nS]^H00onQ/^@2oif]hP;oVJKO0_nDW]/2
ohnFeP?oRhg@0_n7Q<T2ohAm``03oh=h__n4M;WoQ7Bi00?oQG:f0_n8LK<2ohac/@?oTGF`0_nFN;03
oiam/0?oXX:a0_nWQk<3okFD]@?o^ibh00ooajRkolba_ooJ`l;of/?2onSJaOoWgL[okNo:onSjaooN
o/KoeOo=olonfoo:nNWo0000ol?]l?nnh?000_ngeNl01Oncc^go[lO/ojo7k?n]a>_o[<7Y00CoZl3Y
00?oZ[oXojZnj?nZ_^P00_nZ_^P6ojVmj003o`000?oooooooooo01?ooooo0009ooooo`0400000?oo
ooooooooooooof<000005@0I6AT?000001406ATI5@000004ooooo`0300000?oooooooooo01;ooooo
00?o0000ooooooooool05_ooool2oi=c[0?oWgBR0onUMId2ojQfV`?o[7NI0on/N9T3ok5kV0;o/7^I
00Go^86IokIoVOl0003o0000okIoV@03okf6VP05okZ5W?o6T9goaY2MolJ@WOo1SIh00oo@WJ401_o9
Uj;ogJnWomf_YooM[jOonN6^onW4/0GoZKgX0onX_>P00onX^nOoYk[WojFhi`02ojFhi`?oXkKV00Co
XK;Toib]honGY^3oUjKP0_nAWM`2oh^CeP;oQHW@0on0P<T2ogah``;oQ7g30_n3N;h2ohAd^@;oQG:f
0_n8LK<3ohac/@;oTGF`0_nFN;03oiam/0?oXX:a00?oYhNcojj=/oneU;D00oneU;D00onkW;SoajRk
olNX^`03om[3`P0<onSJaOo`kl?ojOZiomSj[oo9nJooaOboolKof?o5nN_o`ng`o`000?nkgo7o]mG_
0_nbc>d00on_anco[L?Zojg3jP02ojc1j@;oZl3Y1OnZ_^P7ojVmj003o`000?oooooooooo01?ooooo
0009ooooo`0400000?ooooooooooooooof8000003`0I6AT7000000l0<c<c0`00000@01TI6A<00000
1?ooool00`00003oooooooooo`0Booooo`03o`000?oooooooooo01Kooooo00?oK6c0oi=c[?nCLj`0
0_nOM:83ojEeW@03ojQfVonYMico[7NI00;o[7NI0on/N9T3ok5kV004ok1kVOl0003o0000o`0000?o
]WnI0onmQYX01OnjQIcoaY2MolJ@WOo6T9go`HfN00?od9fQ0ooM[jL2ooWQ[POoZKgX00?oZ;cXojRk
ionX^nL00_nW^^L00onU^>OoXkKVoj>fiP03oj2bi@;oW:gS0_nGY^02oi6Mg0;oRi?F0_n5RM03oh20
b@03ogah`omjLKgoNW6m00;oNffh0_n4M;T3ohEb]P;oR76c0_n<Lk43oi5e/0;oUWR`0_nLOK03oj:2
/@?o[Xfc0_neU;D01_o0X;SoajRkolNX^oo7Z;_oe[^oom[3`P;oj=[500Kol>o3onWj^OoHnZooaObo
olKof?o5nN/2okoZlP04ok_OlOl0003o]M?`ok;<k@;o[/K/00?o[L?Zoj_1jOn[_nT00_n[_nT3ojZn
j0?oZKkX2?nY_NP00ol0003oooooooooo`0Booooo`002Oooool01000003ooooooooooooooomP0000
00d06ATI00@00000o`000?l0000000006@0c<c<3000000h06ATI4P000004ooooo`0300000?oooooo
oooo01;ooooo00?o0000ooooooooool05oooool2oi=c[0;oWgBR0onUMId00onXMY_oZGNLojagV@02
ojagV@;o[7RI00?o/GbIok5kV?l000000_l00002okR1V@Co]WnI0onmQYX01OnjQIcoaY2MolJ@WOo6
T9go`HfN00?od9fQ0ooM[jL2ooWQ[PGoZKgX0onX_>P00onX^nOoYk[WojFii`03ojFii`;oXkKV00Co
X;;Uoi^^i?nFY^7oUZKQ0_n?W]d2ohNCf@;oOhSB0omhOL`2oh20b@;oO7S300?oNW6mog]]^?mkKKP0
0omlJk@2ohEb]P;oR76c0_n<Lk43oi5e/0;oUWR`0onLOK000onRP[7oYhFaojj=/`02ojj=/`05okFD
]Oo0X;So`:2hol2P^?o7Z;/00_oF^kl02?oWe<?oj=[5oo3_`ooYn[Wof?Z_ok?f]_nno][o`OK_0_no
j_800onhfo;o]M?`o`000002ok3:k@03ojk6k?n/`^[o[<;Z00;oZl7Y00?oZkoYojZnj?nZ_^P00_nZ
_^P2ojVnj0WoZKgX00?o0000ooooooooool04_ooool000Wooooo00@00000ooooooooooooooooG@00
00000ol000006ATI01TI6@0:01TI6@<00000800c<c<00`0000006ATI01TI6@0;01TI6A8000001?oo
ool00`00003oooooooooo`0Booooo`03o`000?oooooooooo01Oooooo0_nCLj`2oimdXP;oYGFM00?o
XgNRojUgW?nYMi`00on/MiT01?n/N9Wo0000o`000?l00002ok5kV004ok1kVOnhPIWo^86IokR1V@;o
]WnI00Co`HZKokf6V_nmQY[o_HJJ1?o6T9d4om2MX@04ong4ZOoM[jOonN6^ooWQ[POoZKgX0onX_>P2
ojNji`;oYKWW00CoXkOWoj2ci_nP/nKoX;?V0_nK[^@2oiJVh@;oSikM0_n7TmT2ogn8dP;oN7g<0_mc
M<D2og1]_P;oNW6m00CoNffhoga[]?mlJkCoO6^d0_n0Jk82ohQa/`?oS7>a0_nAMK02oiIh/0;oW7f`
00CoWgn`ojN5/OnWQK7oYhFa0_n^SK<4ol2P^00:olNX^ooF^kooe[^oonOD`oobk[ooj?V^olc`U_nc
ih_o__kJol7fk`;o^nKc00Go^=_bok;@konbd>oo/<[]o`000002ojg5j`03ojc2j_n[`>WoZ[oY00;o
Z[oY0_nZ_^P3ojVnj0_oZKgX00?o0000ooooooooool04Oooool000Wooooo00@00000oooooooooooo
ooooG000000=01TI6@030000000c<c<0<c<c0280<c<c0P00000<01TI6A4000001?ooool00`00003o
ooooooooo`0Aooooo`03o`000?oooooooooo01Sooooo0_lVE<T2oimdXP03ojEeWOnSMj;oXgNR00?o
ZGNL0ol00002ok5lV@?o/G^H00Co/7^IokR1VOnhPIWo^86I0_nfOiT01?o1RY_o_HJJokf6V_nmQYX4
olJ@W@?od9fQ0_o]a:T00ooM[jOob>9gojVmj005ojVmj0CoZ;cX0_nW^nL3ojFii`;oXkOW00CoX;?V
oi^_iOnEZ>?oUJSS0_n=X>02ohBEg0;oNXWF0omaOLl2ogQmc005og=daOm`KKkoL6fnog1W^OmjLKd0
0_mkKKP2oga[]0;oP6^b0_n5KK03oh]`[`;oTGB^0_nHNJl3oimo/0?oYhFa0_n^SK<01_nhUkGo`:2h
ol2P^?o0X;Sod;:lomJk_`;oimC300Col^joonSi[_o<l9Ko^_cR0_nllO<01?nki_?o]MOaokGGlOnb
d>l2ojo8k003ojg5jol0003oZl7Z00?oZl3Y00?oZ[oYojZnj?nZ_^P00_nZ_^P00onY_^SoZKgXojVm
j00;ojVmj003o`000?oooooooooo013ooooo0009ooooo`0400000?oooooooooooooooe/00000300I
6AT2000000/0<c<c3`00000=03<c<`030000000I6AT06ATI00T06ATI4@000004ooooo`0300000?oo
oooooooo017ooooo00?o0000ooooooooool06Oooool00olVE<WoSgFaohme/@03oj=gXP?o00000_n/
MiT00on/N9Wo/GbIok5lV@03ok5kV0Co^86I0_nfOiT01?o1RY_o_HJJokf6V_nmQYX3olJ@W@;ofjZS
0_o@WJ42ong4Z@03olSRMonY_NSoZKgX00KoZKgX0onX_>P3ojNki`03ojFiionS]nOoXkOW00;oX;CV
0_nK[nD2oiFXh`;oSJ3P0_n4UM`2ogZ9eP;oLGg?0_mZL/P2og=da@03og1]__m`IkWoL6Ni00;oNffh
0omlJk@00on0Jk;oQFf`ohE]/003oh]`[`;oTGB^0_nHNJl4oimo/0;oYhFa00Go[XfcokRG]OnhUkGo
^9Neol2P^002om2b_0;oimC300Ool^joonSi[_o<l9KoYOG5okSik?nllO?o]mod00;o/]7`0_n`c>h0
1On_b>co[<?[ojc3jon[`N[o000000GoZ[kX0_nY_^P?ojVmj003o`000?oooooooooo013ooooo0009
ooooo`0400000?oooooooooooooooeT000002P0I6AT01000003o000000000000000703<c<`030000
0?l00000000000<000003`1<C4`01000003o000000000000000:03<c<`03o`00000I6AT06ATI00T0
6ATI40000004ooooo`0300000?oooooooooo017ooooo00?o0000ooooooooool06_ooool2ohme/@?o
00000onYMi`2ojagV@Co/GbI0_naNiP4okR1V@05okIoVOo1RY_o`HZKol6:VonmQYX00_o<Uih2olJ@
W@;ofjZS00Cod9fQong4ZOo]a:WokLBY1onY_NP4ojRlj0;oYk_X0onU^^L01?nS]nOoXKKWoibaionL
/NL3oiJ[i@03ohfShon3VN3oPiWP00?oMhgK00GoJgoEog5mcomaOLooLGg?ofYbb002ofEY`P;oL6fn
00?oL6Niog9U]OmbIKD00omlJk@2oh1[/P04ohE]/?n;L:ooRg2_oh]`[`;oTGB^0onHNJl3oimo/003
ojN5/On_S[?o^9Ne00?o^9Ne0oo@/[`01ooScL;oimC3oo;^_onkhgkoYOG5okSik?nij?D00_ndf?<0
0onbdO3o[/S]ojg5k002ojg5k005ojc3jon[`>WoZl3Yo`000?nZ_nT01?nZ_^P00onY_^SoZKgXojVm
j00?ojVmj003o`000?oooooooooo00oooooo0009ooooo`0400000?oooooooooooooooeL000002`0I
6AT00`000000<c<c03<c<`0703<c<`8000006@1<C4`2000000T0<c<c00<0000001TI6@0I6AT0200I
6AT@000000Cooooo00<00000ooooooooool04Oooool00ol0003oooooooooo`0Iooooo`?o00001?nS
Mj82ojUgW0;o[7NI1?naO9T2ok5kV0Co^86I00Go]WnIol6:Voo1RY_o`HZKokf6VP02olbGWP05olJ@
WOoKZZ?ofjZSom^ZXoo@WJ400_o]a:T9ojVmj0CoZ;cX0_nW^nP00onU^^OoY;WXojBij002oj6fi`;o
W;7W00CoUZ_UohnXi_n4W^CoQ9kT0_n3VN03ogN=f`03of]oeOmPL/koH7;>00;oJW;800CoIFW2of=R
_?mSH[coL6Ni0_mbIKD3ogIU/P;oP6^b0_n5KK03oh]`[`;oTGB^0_nHNJl2oimo/004ojJ5/_n_S[?o
[hjcojn>/`;o^9Ne0_o7Z;/01oo@/[cohlg2on?=`_obk;ooi_NVok_SO_nglO@00_negoD00ondf??o
[lc_ojo<k`02ojk8k@07ojg5k?n[`^[oZl;Zoj_0jOnZ_nSoZ[kXo`000003ojZnj1CoZKgX00?o0000
ooooooooool03_ooool000Wooooo00@00000ooooooooooooooooE@00000;01TI6@800000200c<c<2
000000`0C4a<2000000904a<C08000001`0c<c<00`0000006ATI01TI6@0901TI6@l000001?ooool0
0`00003oooooooooo`0Aooooo`03o`000?oooooooooo01Kooooo0ol00002ooooo`;oSgFa0onSMj82
ojUgW003ojagVOn`OIgo/GbI00?o/GbI00?o/G^HokZ4VonhPIT00onhPIT01OnfOiWo`HZKol6:Voo1
RY_o_HJJ00;oc9NN00CoaY2Mom^ZXooKZZ?ofjZS0_ojjZ<00oo]a:WoZKgXojVmj007ojVmj0;oZ;gX
00?oZ;cXojNlj?nW_>P00_nV^^P00onT^NSoX[OXoifdj002oifdj0;oUjoW0_n?Z>H2ohBNi0;oMi;Q
0_mXQ=/2oeQfe@04of1bc_mHIlOoF6O7ofEY`P;oHf:l00CoI5nhog1W^OmbIKGoLVFe0_mfIK82og]W
/0;oQFf`0on;L:l2oi5d[P;oV7V_00?oWgn`ojJ5/_nVQK800on_S[<01OnhUkGoajRkolNX^oo7Z;_o
d;:l00;ohlg200?ol^book_SO_ndioL00_negoD00onadO7o[lc_ojo<k`02ojg5k0;o[<?[00?oZl;Z
ojZojOnZ_nT00_nZ_nP00onZ_^So0000ojVnj00EojVmj003o`000?oooooooooo00kooooo0009oooo
o`0400000?oooooooooooooooe@000002P0I6AT2000000H0<c<c00@00000o`000000000000001P1<
C4`00`00003o0000o`000005000000P0IVIV00Co000000000000000000001`1<C4`00`000000<c<c
03<c<`0503<c<`030000000I6AT06ATI00P06ATI3`000004ooooo`0300000?oooooooooo017ooooo
00?o0000ooooooooool05?ooool2o`0000Gooooo0_n?MK43oj=gXP;oZGNL00?o[7NIok1mWOnaO9T0
0onaO9T00onaNiSo^XBKokR1V@03okR1V@Co`HZK00Co_HJJolbGW_o<UikoaY2M0ooKZZ<2oo[ZX`[o
ZKgX0onX_>P00onW_>SoY[_XojBjj002ojBjj0;oX[OX00CoWKCXoiZbjOnB[NWoTZgY0_n7YNP3ogVJ
iP;oJ8gS0_mXQ=/01omHM]GoBfO>of1bc_mHIlOoDUk1ofEY`_mSH[`00_mTGkP2og9U]@;oMVFb0_mk
Ik02oh9[[`?oRg2_0_nAM:h00onHNJooW7f`ojJ5/P03ojJ5/P;o[hjc1?o7Z;/01OoLa<;ohlg2oo;/
_ooVmjKo]>Og00;o/MKc00?o/M7aojg8kOn]b>d00_n]aN`01On[`N[oZl3Yoj_0jOn[`>WoZ[oY00Co
Z[kX00?oZKkXo`000?nY_NP04OnY_NP3ooooo`03o`000?oooooooooo00kooooo0009ooooo`040000
0?oooooooooooooooe<0000000?o000001TI6@0I6AT01P0I6AT00`00003o000003<c<`0603<c<`03
0000001<C4`0C4a<00D0C4a<0`00000D06IVIP030000001<C4`0C4a<00@0C4a<00<0000003<c<`0c
<c<01@0c<c<00`0000006ATI01TI6@0801TI6@l000001?ooool00`00003oooooooooo`0@ooooo`03
o`000?oooooooooo01;ooooo0ol00008ooooo`04ohme/OnSMj;oXgNRoj=gXP;oZGNL0_n`OId4ok5l
V@03ok5kV?njQ9_o^XBK00?o^86I1?o1RY/3olbGWP?ofjZS0oojjZ<;ojVmj0?oZ;cX0_nV^nP00onT
^^SoXkWXoinfj@02oinfj@;oV[;Y0_nB[NT2ohNUj0?oNI[V00?oJ8gSoeEmgOmEOMd00_mHM]D01?m;
IlkoF6O7oeQWaomBG/42of=R_004ofAO^?mWG[GoIejeofMN]@;oMVFb00?oNfN`oh9[[on2Jjl00on:
L:l2oi=f/0?oW7f`0onVQK800on_S[?o_IjiokfN^@02olNX^`;og<C200Gol>S2onCgYOnafoGo/M_e
ok7Fl`02ojk;k`03ojg8kOn/`n_o[<?[00;oZl7Z0_n[`>T2ojZoj@03ojZnj?nY_^SoZKgX00;oZKgX
00?o0000ojVmj?nY_NP03_nY_NP5ooooo`03o`000?oooooooooo00kooooo0009ooooo`0400000?oo
oooooooooooooe<00000200I6AT00`000000<c<c03<c<`0503<c<`8000001@1<C4`3000001P0IVIV
00<0000004a<C01<C4`0101<C4`00`000000<c<c03<c<`0503<c<`030000000I6AT06ATI00L06ATI
3`000004ooooo`0300000?oooooooooo013ooooo00?o0000ooooooooool03oooool3o`0000cooooo
0onSMj800onYMicoZX2Wok1mW@02ok1mW@?o/GbI0onjQ9/2okR1V@03olJAW_o1RY_o`HZK00;o`HZK
0oo<Uih00oo^aJWofjZSom^ZX`02oo[ZX`[oZKgX1?nX_>P01?nW_>SoYK_XojFkj?nU^nP2oj>ij003
oinfjOnM]^[oWKKZ00;oU[7Z0on=[>/2ognSjP04ofjHjOmHRNKoF8WVoeEmg@;o@6cF00CoBfO>ocmK
aoloFlOoDUk10_mAFK`2ofAO^0;oIeje00CoKV6cogIU/_mkIk3oNfN`0_n2Jjl2ohY`[`;oTgJ`0onL
OK03ojJ5/P?o_Iji00OoajRkomc4`_oLa<;og<C2oo3X`_oTmjGo[m7b00;o[lk`00Co[/__ojc4k?n/
a>co[<?[0_nZ`>T4ojZoj@;oZ[kX0_nY_^P3ojVmj003o`000?nY_NSoZKgX00WoZKgX2_ooool00ol0
003oooooooooo`0=ooooo`002Oooool01000003ooooooooooooooomB000000P06ATI00<0000003<c
<`0c<c<01@0c<c<00`000000C4a<04a<C00404a<C0030000001VIVH0IVIV00D0IVIV3Ol0000806IV
IP030000001<C4`0C4a<00@0C4a<00<0000003<c<`0c<c<0100c<c<00`0000006ATI01TI6@0801TI
6@h000001?ooool00`00003oooooooooo`0@ooooo`03o`000?oooooooooo00cooooo0ol0000?oooo
o`?oR8;60_nZP:L3ok1mW@?o/GbI0onjQ9/2okR1V@03olJAW_o1RY_o`HZK00;o`HZK0oo<Uih01?o^
aJWofjZSom^ZXoojjZ<<ojVmj0?oZ;cX0_nW_>P00onU^nSoY;[YojBjj@02oj6hj@03oiffj_nJ]^_o
V[K[00;oTk7/0_n7[>d2ogRSkP;oHiO]0_mHRNH02?lnMn3o@6cFobeLcol]G<oo?e_7ocUC`_mBG/7o
DEVl0_mCF;T2ofMN]@;oKV6c0_mkIk02oh9[[`?oRW2_0_nCM[03oiam/003ojJ5/_naTkOo_Iji00;o
_Iji00Kod[W2omc4`_oLa<;ol>S2onCgYOn_dO82ojg8kP;o[<K]00Co[<C/oj_1j_n[`N[oZ/3Y1_nZ
_^P7ojVmj003o`000?nY_NSoZKgX00GoZKgX3Oooool00ol0003oooooooooo`0=ooooo`002Oooool0
1000003ooooooooooooooom?00000003o`00000000006ATI00H06ATI00<00000o`00000c<c<01@0c
<c<2000000@0C4a<00<00000o`0000000000101VIVH4o`0000d0Ogmo0_l0000706IVIP030000001<
C4`0C4a<00@0C4a<00?o000003<c<`0c<c<0100c<c<00ol000006ATI01TI6@0701TI6@h000001?oo
ool00`00003oooooooooo`0@ooooo`03o`000?oooooooooo00Wooooo0ol0000Cooooo`;oR8;60_nZ
P:L3ok1mW@?o/GbI0onjQ9/01?nhPIWoaY6NolJAW_o6TIh2ol6:V`03omNUXoo<Uikoc9NN00?ok/FY
00?on^ZSojVmj?nY_NP03?nY_NP00onX_>SoYkcXojNlj002ojJkj003ojBjjOnS^^WoX;SZ00?oX;SZ
0_nJ]^/2oi>ak0;oQjc]0_mhXnh2of>Gk@08odJ7jOlSL^7o8g;Qob5Seol]G<oo74k7ocmKaoliDl82
oe5I_0;oDeRi0_mWG[D00om^HK?oMVJbogIV/P02oh9[[`?oRW2_0_nCM[02oiam/004ojF8]_naTkOo
/I>gok6C]`;o_Iji0_oB^L801OoLa<;ol>S2ojg:kon]b^oo[LS^00;oZl?[0_n[`^X00on[`N[oZ[oY
ojZoj@03ojZnj0;oZKkX2?nY_NP01?l0003oZKgXojVmj?nY_NPAooooo`03o`000?oooooooooo00go
oooo0009ooooo`0400000?ooooooooooooooodl00000200I6AT00`000000<c<c03<c<`0403<c<`80
00001@1<C4`00`000000IVIV06IVIP0206IVIP?o00004`1oOgl2o`0000D0IVIV00<0000004a<C01<
C4`0101<C4`00`000000<c<c03<c<`0403<c<`030000000I6AT06ATI00L06ATI3P000004ooooo`03
00000?oooooooooo013ooooo00?o0000ooooooooool01_ooool3o`0001Kooooo0_n8P/H3ojZ0Y`;o
/7fM0_naO9T01OnkRJ7o^XBKokZ4VonjQ9_o^86I00?oaY6N0_o1RY/2omNUX`04olbGW_o^aJWok/FY
onk5Z@goZKgX0onX_NP2ojNlj0?oY[_Y0_nS^^T2oj2hjP;oW[W[0_nI]^`2oi2bkP;oQ:g`0_mbYO42
oeVJl@07ocJ8k?lSL^7o05WBo`9>c?l]G<oo74k7ocUC`P02ocM?_P;oDeRi00?oFUZhofMN]Om^HK<0
0_mfI[83oh5//P;oRW2_00?oTgJ`oiQn]?nUR;H00_nUR;H3ok6C]`07okfN^OoB^L;od[W2om:i`_o[
h/Soh_V[ojg:k`02oj_4k003oj_3jonZ`>WoZ[oY00?oZ[oY00?oZ[kXojVnj?nY_^P00_nY_^P:ojVm
j003o`000?oooooooooo017ooooo00?o0000ooooooooool03Oooool000Wooooo00@00000oooooooo
ooooooooCP00000801TI6@030000000c<c<0<c<c00@0<c<c00<0000004a<C01<C4`00`1<C4`20000
00@0IVIV00?o000007moO`1oOgl0201oOgl5o`0000T0Ogmo00?o000006IVIP1VIVH00`1VIVH00`00
0000C4a<04a<C00304a<C0030000000c<c<0<c<c00@0<c<c00<0000001TI6@0I6AT01`0I6AT>0000
00Cooooo00<00000ooooooooool04?ooool00ol0003oooooooooo`03ooooo`?o00006_ooool2ohR2
aP;oZX2W0_n`OId00onaO9Wo^hVQok^9X@03okZ4V`05okR1VOo6TIkoaY6NolJAW_o1RY/00ooGYJ<0
1?o<Uikok/FYonk5ZOo^aJT>ojVmj0?oZ;gX0_nW_>P01?nV^nWoYK_YojFkjOnU^nT2oj>jjP03oiji
jonN^NcoV;O^00;oV;O^0_n?]?02oh:`lP;oKjWe0_mDWoD01ol/S^ko273No`1Id_l2C/co74k7oa15
`_liDl800_lgCkh00omCF;WoFUZhoeYJ^002ofiQ/`;oMVJb0_n1K;82ohad/`?oV7jd0onUR;H2ok6C
]`?od[W200Gojn;8on;iZon[aNcoZlG/oj_4k002oj[1jP;oZ/3Y00?oZ[oYojZnj?nZ_^P00_nZ_^P0
0onY_^SoZKgXojVmj006ojVmj0Gooooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`0=
ooooo`002Oooool01000003ooooooooooooooom=000000P06ATI00?o000003<c<`0c<c<0100c<c<0
0ol00000C4a<04a<C00304a<C0040000001VIVH0IVIV06IVIP?o00001P1oOgl5o`0000D0VIVI1?l0
000607moO`03o`00001VIVH0IVIV00<0IVIV00<0000004a<C01<C4`00`1<C4`00`000000<c<c03<c
<`0303<c<`030000000I6AT06ATI00L06ATI3P000004ooooo`0300000?oooooooooo00oooooo00Co
0000oooooooooooooooo0ol0000Mooooo`;oR8;60_nZP:L2ok1mW@Co^hVQ0_njQ9/4olJAWP04ol6:
VooGYJ?oejFSomNUX`?ok/FY4?nY_NP4ojRmj0;oYkcY00?oYK_YojFljOnR^n/00_nR^n/2oijik003
oiRgk_nH^NooV;W_00;oSkOa0_n3]?D2og6`n0;oEZSh00Ko;IW`o`1bfOl0Cl?o03floaa>aol@AL82
ocM?_P05ocY@__mCF;WoFUZhofAO^?m^HK<00_mfI[82oh5//P;oS7Bc0onHO[@3ojF8]P06ok6C]oo4
[<;oa:c2om:i`_o[h/Soh_V[0_n[aN`3oj[1jP;oZ[oY0onZ_^P2ojVnj0SoZKgX2?ooool00ol0003o
ooooooooo`0?ooooo`03o`000?oooooooooo00gooooo0009ooooo`0400000?ooooooooooooooodd0
0000200I6AT00`000000<c<c03<c<`0303<c<`030000001<C4`0C4a<0080C4a<00<00000o`00001V
IVH00P1VIVH00ol00000Ogmo07moO`0507moO`?o00003@2IVIT00ol00000Ogmo07moO`0407moO`03
o`00001VIVH0IVIV0080IVIV00<0000004a<C01<C4`00`1<C4`00`000000<c<c03<c<`0303<c<`03
0000000I6AT06ATI00L06ATI3P000004ooooo`0300000?oooooooooo00oooooo1?l0000Qooooo`03
ohR2a_nZP:OoZX2W00;o/7fM1?nkRJ42okZ4V`CoaY6N00Ko`HZKomNUXooGYJ?oejFSon7`T_o^aJT@
ojVmj0GoZ;gX0onV_>T2ojFlj@?oX[_[0_nN^^d00onH^NooVK__oiVkk`02oi:jlP;oQkWf0_mg]oX2
oenbn`;o?:Se00?o3I?No`0RX?l@AL800_l:@L000olgCkko>U2noeYJ^002ofAO^0;oMVJb0on1K;82
ohad/`;oV7jd0onUR;H3olB/`P05on3HcooPo;SoZ/;[oj[2jonZ`NX01?nZ_nT5ojVnj0GoZKgX3?oo
ool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo00gooooo0009ooooo`0400000?oooooo
oooooooood`00000200I6AT00`000000<c<c03<c<`0303<c<`030000001<C4`0C4a<0080C4a<00<0
000006IVIP1VIVH00P1VIVH00ol00000Ogmo07moO`0307moO`?o0000402IVIT00ol00000Ogmo07mo
O`0407moO`03o`00001VIVH0IVIV0080IVIV00<0000004a<C01<C4`00`1<C4`00`000000<c<c03<c
<`0303<c<`030000000I6AT06ATI00L06ATI3P000004ooooo`0300000?oooooooooo00oooooo0_l0
000Tooooo`;oZX2W00?o/7fMokVG]?nkRJ400onkRJ400onjQ9_ocZ2XolJAWP03olJAWPCoejFS00?o
hO2BojVmj?nY_NP04?nY_NP5ojRmj0?oY[cY0_nU_>X00onR^n_oX[c[oj:lj`02oijkk@03oiVkkonK
_>ooU[gb00;oU[gb0_n=_OH2oh6mnP03ofnloOn0a?goP<Cm00;oLLGo00So02:Po`0]]Ol:@L3o2T70
ocY@__m4E/3oFUZhofAO^0?oLFRi0_n1K;82ohad/`?oV7jd00CoYHRfokBN`OndW/7oa:c20_oPf<l0
0ooPo;SoZ[oYojZoj@02ojZoj@KoZKkX1OnY_NP?ooooo`03o`000?oooooooooo00oooooo00?o0000
ooooooooool03?ooool000Wooooo00@00000ooooooooooooooooB`00000801TI6@030000000c<c<0
<c<c00<0<c<c00<0000004a<C01<C4`00P1<C4`00`000000IVIV06IVIP0206IVIP03o`00001oOgl0
Ogmo00<0Ogmo00?o000009VIV@2IVIT04P2IVIT00ol00000Ogmo07moO`0407moO`03o`00001VIVH0
IVIV0080IVIV00<0000004a<C01<C4`00P1<C4`00`000000<c<c03<c<`0303<c<`03o`00000I6AT0
6ATI00H06ATI3`000004ooooo`0300000?oooooooooo017ooooo00?o0000ooooooooool08_ooool0
0olMV^So^INdokVG]004ok^9X@03okZ4Voo>X:SocZ2X00?oaY6N0ooGYJ<00ooQl9;oZKgXojVmj00B
ojVmj0?oZ;gX0_nW_NT00onV_>WoY[gYojJmj@02ojFljP03oj:ljonS_N_oXkg[00;oX;c]0_nK_>l0
0onF_O;oV[oboiZolP02oiC0m@03oh_2nOnEa?OoULCg00?oSlOj00GoQl[noiK;n_nFbo[o2T70ocY@
_P02odAF`0;oI5nh0_maJ;T2oh1c^`;oTH6n0onSSl03okBN`@05olo9e?oPf<ooh?bhojZojOnY_^T0
1_nY_^P4ojVmj1Cooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`0<ooooo`002Ooo
ool01000003ooooooooooooooom:000000P06ATI00?o000003<c<`0c<c<00`0c<c<00`000000C4a<
04a<C00204a<C0030000001VIVH0IVIV0080IVIV00?o000007moO`1oOgl00P1oOgl2o`0000D0VIVI
2Ol0000809VIV@03o`00001oOgl0Ogmo00<0Ogmo00?o000006IVIP1VIVH00P1VIVH00`000000C4a<
04a<C00204a<C0030000000c<c<0<c<c00<0<c<c00<0000001TI6@0I6AT01P0I6AT?000000Cooooo
00<00000ooooooooool04_ooool00ol0003oooooooooo`0Rooooo`?o^INd0onkRJ400onjQ9_ocZ2X
oljPZ002olJAWP;ok<bc00?oejFSon7`T_nY_NP05OnY_NP2ojRmj0?oYkgY00?oY[gYojNmjOnU_NX0
0_nU_NX00onS_N_oY;g[oj:mk@02oj:mk@;oW[k_00?oV[oboik0l?nN`?000_nJ`_<01?nEa?OoW<Cd
oic4m?nLa?@2oiW7m`06oiK;n_nOb?GoWlSeo`Y1`?ljD;koA5K00_mCH/@2og5X^@;oP7>k0onAPKh3
oj>?`004okBN`Oo?bMCoclWDom[oc`CoZKkY1?nY_^PJooooo`03o`000?oooooooooo00gooooo00?o
0000ooooooooool03?ooool000Wooooo00@00000ooooooooooooooooB@00000901TI6@030000000c
<c<0<c<c0080<c<c00<0000004a<C01<C4`00P1<C4`00`000000IVIV06IVIP0206IVIP03o`00001o
Ogl0Ogmo0080Ogmo00?o000009VIV@2IVIT00`2IVIT2o`0000T0/k>c00?o000009VIV@2IVIT01@2I
VIT00ol00000Ogmo07moO`0307moO`03o`00001VIVH0IVIV0080IVIV00<0000004a<C01<C4`00P1<
C4`00`000000<c<c03<c<`0303<c<`030000000I6AT06ATI00H06ATI3`000004ooooo`0300000?oo
oooooooo01?ooooo00?o0000ooooooooool08Oooool00olMV^So^INdokVG]003ok^9X@?ocZ2X00Ko
aY6Nonc</oo/c;?ok<bcomNUXooooolGojVmj0;oZ;gX00?oYkgYojRmjOnX_NT00_nW_NT00onU_N[o
Y[gZojJmjP02ojBmj`03oj:mkOnS_^coXkk/00;oXKo^00?oW/3`oj;0konR`>l00onO`_401?nLa?Co
X/?`oj;3l?nPaO<2ojC3k`;oY<G`00?o2dC3odAF`?m4E/000_mCH/@2og5X^@;oP7>k0_nAPKh3oj>?
`0?oclWD00?of_o?ojVnjOnY_^P01?nY_^PLooooo`03o`000?oooooooooo00gooooo00?o0000oooo
ooooool03?ooool000Wooooo00@00000ooooooooooooooooB000000901TI6@030000000c<c<0<c<c
0080<c<c00<0000004a<C01<C4`00P1<C4`00`000000IVIV06IVIP0206IVIP03o`00001oOgl0Ogmo
0080Ogmo00?o000009VIV@2IVIT00`2IVIT00ol00000/k>c0;>c/`0:0;>c/`03o`00002IVIT0VIVI
00D0VIVI00Go000007moO`1oOgl0Ogmoo`00000406IVIP030000001<C4`0C4a<0080C4a<00<00000
03<c<`0c<c<00`0c<c<00`0000006ATI01TI6@0601TI6A0000001?ooool00`00003oooooooooo`0D
ooooo`;o00008_ooool2okVG]0;o^hVQ00Gog=_FoljPZ?o>X:SocZ2XolJAWP03onc</`?ooooo5onY
_NP2ojRmj0?oZ;gY0_nW_NT3ojJmjP;oYKk[00?oXkk/ojFnk?nU_^`00_nS_nd01?nR`>ooY<3]ojC0
kOnT`>d2oj?1k`04oj;3l?nU`^koYL;^ojC3k`;oYl7]0_nW`^d2oaA@b`;oDf;40_mXL/X2oh1c^`?o
TH6n00GoXho0okReeonh]MOoclWDom[oc`03ojVnj27ooooo00?o0000ooooooooool03?ooool00ol0
003oooooooooo`0<ooooo`002Oooool01000003ooooooooooooooom7000000P06ATI00?o00000000
000c<c<00`0c<c<00ol00000C4a<04a<C00204a<C0030000001VIVH0IVIV0080IVIV00?o000007mo
O`1oOgl00P1oOgl00ol00000VIVI09VIV@0309VIV@03o`00002c/k<0/k>c00`0/k>c00?o000009VI
V@2IVIT0102IVIT01Ol00000Ogmo07moO`1oOgoo000000@0IVIV00<0000004a<C01<C4`00P1<C4`0
0`000000<c<c03<c<`0303<c<`030000000I6AT06ATI00H06ATI40000004ooooo`0300000?oooooo
oooo01Kooooo00?o0000ooooooooool08Oooool01?nkRJ7og=_FomcKe_oLfmH2oljPZ0;ooooo00?o
k<bcooooooooool00ooooolGojVmj0;oZ;gX0onX_NT2ojNmj@03ojJmj_nW_^WoYkkY00;oY[kZ00Co
YKk/ojJnjonV_^_oY[k[0_nU_n`00onT`>goY[o/ojJok002ojK1k@04ojG2k_nW`>coYl3/ojO1k@Co
Z<3[0_lDD</00olYJ=WoDf;4ofQbbP02oh67d0CoWIkE00?o^;GGolWij?o9nNP00_nY_^PTooooo`03
o`000?oooooooooo00_ooooo00?o0000ooooooooool03?ooool000Wooooo00@00000oooooooooooo
ooooA`00000801TI6@030000000c<c<0<c<c00<0<c<c00<0000004a<C01<C4`00P1<C4`01Ol00000
IVIV06IVIP1VIVKo000000D0Ogmo00?o000009VIV@2IVIT00P2IVIT00ol00000/k>c0;>c/`0=0;>c
/`03o`00002IVIT0VIVI00@0VIVI00Go000007moO`1oOgl0Ogmoo`00000406IVIP030000001<C4`0
C4a<0080C4a<00<0000003<c<`0c<c<00`0c<c<00`0000006ATI01TI6@0601TI6A0000001?ooool0
0`00003oooooooooo`0Gooooo`03o`000?oooooooooo02Cooooo00?ocZ2Xooooooooool02?oooolG
ojVmj0;oZ;gX1_nX_NT00onW_^WoZ;kYojRnj@02ojNnjP03ojJnjonW_^[oYkkZ00;oYko[00?oY[o/
ojNoj_nW_nX00_nW_n/00onW`>coZ;oZojRojP03ojS0j`?oZKoZ00CoZKkYobUXfOmXL/[oJ7;:0_n1
Qm02oifNe@;oYn;k00?obOWXooooooooool09_ooool00ol0003oooooooooo`0:ooooo`03o`000?oo
oooooooo00cooooo0009ooooo`0400000?ooooooooooooooodH00000200I6AT00`000000<c<c03<c
<`0303<c<`030000001<C4`0C4a<00<0C4a<00@0000006IVIP1VIVKo00001@1oOgl00ol00000VIVI
09VIV@0209VIV@03o`00002c/k<0/k>c00h0/k>c00?o000009VIV@2IVIT00`2IVIT00ol00000Ogmo
07moO`0207moO`03o`00001VIVH0IVIV0080IVIV00<0000004a<C01<C4`00P1<C4`00`000000<c<c
03<c<`0203<c<`030000000I6AT06ATI00H06ATI4@000004ooooo`0300000?oooooooooo01Sooooo
00?o0000ooooooooool0;ooooolGojVmj005ojRmj?nY_NSoZKgXojRmjOnY_NP00onX_NT5ojRnj@03
ojNnj_nX_^WoZ;kY00;oZ;kZ00?oYkoZojRnjOnX_^T00onX_nX2ojVnj@;oZKoY00?oZKoZojVnjOnY
_^T00_nY_^T00om:003oBh_[od^;j`02ogRinP;oYn;k:_ooool00ol0003oooooooooo`0;ooooo`03
o`000?oooooooooo00_ooooo0009ooooo`0400000?ooooooooooooooodH00000200I6AT00`000000
<c<c03<c<`0303<c<`030000001<C4`0C4a<0080C4a<00D0000006IVIP1VIVH0IVIVo`00000407mo
O`03o`00002IVIT0VIVI00<0VIVI00?o00000;>c/`2c/k<03P2c/k<00ol00000VIVI09VIV@0309VI
V@03o`00001oOgl0Ogmo0080Ogmo00Go000006IVIP1VIVH0IVIV0000000404a<C0030000000c<c<0
<c<c00<0<c<c00<0000001TI6@0I6AT01P0I6AT00ol0000000000000000>000000Cooooo00<00000
ooooooooool06Oooool2o`00033ooooo7?nY_NP00onX_NWoZKgXojVmj006ojRnj@03ojVnjOnX_^Wo
Z;kY00;oZ;kY2_nY_^T5ojVnj33ooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0;
ooooo`002Oooool01000003ooooooooooooooom5000000P06ATI00<0000003<c<`0c<c<00`0c<c<0
0`000000C4a<04a<C00204a<C0050000001VIVH0IVIV06IVI_l00000101oOgl00ol00000VIVI09VI
V@0309VIV@03o`00002c/k<0/k>c00l0/k>c00?o000009VIV@2IVIT00P2IVIT00ol00000Ogmo07mo
O`0207moO`03o`00001VIVH0IVIV0080IVIV00?o000004a<C01<C4`00P1<C4`00`000000<c<c03<c
<`0203<c<`03o`00000I6AT06ATI00H06ATI4P000004ooooo`0300000?oooooooooo01_ooooo00?o
0000ooooooooool0;_oooolOojVmj0;oZKkY00?oZ;kYojVnj?nY_^P00_nY_^T01?nX_^WoZKkYojVn
jOnY_^T4ojVnj003ojVnjOnY_^SoZKkX00?oZKkX=Oooool00ol0003oooooooooo`09ooooo`03o`00
0?oooooooooo00_ooooo0009ooooo`0400000?ooooooooooooooodD00000200I6AT00`000000<c<c
03<c<`0303<c<`030000001<C4`0C4a<0080C4a<00D0000006IVIP1VIVH0IVIVo`00000407moO`03
o`00002IVIT0VIVI00<0VIVI00?o00000;>c/`2c/k<03P2c/k<00ol00000VIVI09VIV@0309VIV@03
o`00001oOgl0Ogmo0080Ogmo00Go000006IVIP1VIVH0IVIV0000000504a<C0030000000c<c<0<c<c
0080<c<c00<0000001TI6@0I6AT01P0I6ATB000000Cooooo00<00000ooooooooool07?ooool00ol0
003oooooooooo`0^ooooob7oZKgX00?oZKkXojVmj?nY_NP00_nY_^P00onY_^WoZKgXojVmj003ojVn
j0;oZKgX00?oZKkXooooooooool0>?ooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo
00_ooooo0009ooooo`0400000?oooooooooooooood@00000200I6AT00`000000<c<c03<c<`0303<c
<`030000001<C4`0C4a<0080C4a<00D0000006IVIP1VIVH0IVIVo`00000407moO`03o`00002IVIT0
VIVI00<0VIVI00?o00000;>c/`2c/k<03P2c/k<00ol00000VIVI09VIV@0309VIV@03o`00001oOgl0
Ogmo0080Ogmo00Go000006IVIP1VIVH0IVIV0000000504a<C0030000000c<c<0<c<c0080<c<c00<0
000001TI6@0I6AT01P0I6ATC000000Cooooo00<00000ooooooooool07Oooool00ol0003ooooooooo
o`0^ooooobcoZKgX??ooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00_ooooo0009
ooooo`0400000?oooooooooooooood<000002@0I6AT00ol00000<c<c03<c<`0303<c<`060000001<
C4`0C4a<04a<C000003o00000`1VIVH00ol00000Ogmo07moO`0207moO`03o`00002IVIT0VIVI00<0
VIVI00?o00000;>c/`2c/k<0302c/k<2o`0000D0VIVI0_l0000307moO`05o`00001VIVH0IVIV06IV
IP000000101<C4`00`00003o000003<c<`0303<c<`030000000I6AT06ATI00H06ATI50000004oooo
o`0300000?oooooooooo01kooooo0_l0000_ooooobOoZKgX@Oooool00ol0003oooooooooo`07oooo
o`03o`000?oooooooooo00_ooooo0009ooooo`0400000?oooooooooooooood<000002@0I6AT00`00
0000<c<c03<c<`0303<c<`050000001<C4`0C4a<04a<C0000000101VIVH00ol00000Ogmo07moO`02
07moO`03o`00002IVIT0VIVI00<0VIVI00?o00000;>c/`2c/k<02`2c/k<00ol00000VIVI09VIV@04
09VIV@03o`00001oOgl0Ogmo0080Ogmo00?o000006IVIP1VIVH00P1VIVH00`000000C4a<04a<C002
04a<C0030000000c<c<0<c<c00<0<c<c00<0000001TI6@0I6AT01P0I6ATD000000Cooooo00<00000
ooooooooool08?ooool00ol0003oooooooooo`0]ooooob;oZKgXA_ooool00ol0003oooooooooo`07
ooooo`03o`000?oooooooooo00[ooooo0009ooooo`0400000?oooooooooooooood<000002@0I6AT0
0`000000<c<c03<c<`0303<c<`050000001<C4`0C4a<04a<C0000000101VIVH00ol00000Ogmo07mo
O`0207moO`03o`00002IVIT0VIVI00@0VIVI00?o00000;>c/`2c/k<02@2c/k<00ol00000VIVI09VI
V@0409VIV@03o`00001oOgl0Ogmo0080Ogmo00?o000006IVIP1VIVH00P1VIVH00`000000C4a<04a<
C00204a<C0030000000c<c<0<c<c00<0<c<c00<0000001TI6@0I6AT01P0I6ATE000000Cooooo00<0
0000ooooooooool08Oooool00ol0003oooooooooo`0^oooooakoZKgXBOooool00ol0003ooooooooo
o`06ooooo`03o`000?oooooooooo00[ooooo0009ooooo`0400000?oooooooooooooood<00000200I
6AT00`000000<c<c03<c<`0303<c<`030000001<C4`0C4a<0080C4a<00<0000006IVIP1VIVH00P1V
IVH00ol00000Ogmo07moO`0207moO`03o`00002IVIT0VIVI00D0VIVI0_l000070;>c/`;o00001P2I
VIT00ol00000Ogmo07moO`0207moO`03o`00001VIVH0IVIV0080IVIV00<0000004a<C01<C4`00P1<
C4`00`000000<c<c03<c<`0303<c<`03o`00000I6AT06ATI00L06ATI5@000004ooooo`0300000?oo
oooooooo02;ooooo00?o0000ooooooooool0;_oooolIojVmj4gooooo00?o0000ooooooooool01_oo
ool00ol0003oooooooooo`0:ooooo`002Oooool01000003ooooooooooooooom100000003o`00000I
6AT06ATI00L06ATI00<0000003<c<`0c<c<00`0c<c<00`000000C4a<04a<C00204a<C0030000001V
IVH0IVIV0080IVIV00?o000007moO`1oOgl00P1oOgl00ol00000VIVI09VIV@0709VIV@Oo00001P2I
VIT2o`0000<0Ogmo0_l0000406IVIP030000001<C4`0C4a<0080C4a<00<0000003<c<`0c<c<0100c
<c<00`0000006ATI01TI6@0601TI6AH000001?ooool00`00003oooooooooo`0Sooooo`03o`000?oo
oooooooo02kooooo5?nY_NQBooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool02_oo
ool000Wooooo00@00000oooooooooooooooo@P00000901TI6@030000000c<c<0<c<c00<0<c<c00<0
000004a<C01<C4`00P1<C4`00`000000IVIV06IVIP0206IVIP03o`00001oOgl0Ogmo00<0Ogmo0_l0
000B09VIV@;o0000101oOgl00ol00000IVIV06IVIP0306IVIP030000001<C4`0C4a<0080C4a<00<0
000003<c<`0c<c<0100c<c<00`0000006ATI01TI6@0601TI6AL000001?ooool00`00003ooooooooo
o`0Tooooo`;o0000;oooool@ojVmj5Kooooo00?o0000ooooooooool01?ooool00ol0003ooooooooo
o`0:ooooo`002Oooool01000003ooooooooooooooom2000000P06ATI00<0000003<c<`0c<c<0100c
<c<00`000000C4a<04a<C00204a<C0030000001VIVH0IVIV00<0IVIV00?o000007moO`1oOgl0101o
Ogl00ol00000VIVI09VIV@0=09VIV@;o00001@1oOgl00ol00000IVIV06IVIP0206IVIP800000101<
C4`00`000000<c<c03<c<`0403<c<`030000000I6AT06ATI00H06ATI00?o00000000000000005@00
0004ooooo`0300000?oooooooooo02Kooooo00?o0000ooooooooool0;Oooool=ojVmj5Sooooo00?o
0000ooooooooool01?ooool00ol0003oooooooooo`0:ooooo`002Oooool01000003ooooooooooooo
oom2000000P06ATI00<0000003<c<`0c<c<0100c<c<00`000000C4a<04a<C00204a<C0030000001V
IVH0IVIV00<0IVIV00?o000007moO`1oOgl01@1oOgl3o`0000T0VIVI0ol0000507moO`;o0000101V
IVH00ol00000C4a<04a<C00204a<C08000001@0c<c<00`00003o000001TI6@0701TI6AT000001?oo
ool00`00003oooooooooo`0Wooooo`03o`000?oooooooooo02gooooo2?nY_NQMooooo`03o`000?oo
oooooooo00?ooooo00?o0000ooooooooool02_ooool000Wooooo00@00000oooooooooooooooo@P00
000801TI6@030000000c<c<0<c<c00@0<c<c00<0000004a<C01<C4`00P1<C4`00`000000IVIV06IV
IP0306IVIP03o`00001oOgl0Ogmo00P0Ogmo2Ol0000707moO`03o`00001VIVH0IVIV0080IVIV0P00
000404a<C0030000000c<c<0<c<c00@0<c<c00<0000001TI6@0I6AT0200I6ATI000000Cooooo00<0
0000ooooooooool0:?ooool00ol0003oooooooooo`0]ooooo`?oZKgXH_ooool00ol0003ooooooooo
o`03ooooo`03o`000?oooooooooo00Wooooo0009ooooo`0400000?oooooooooooooood800000200I
6AT00`000000<c<c03<c<`0403<c<`030000001<C4`0C4a<00<0C4a<00<0000006IVIP1VIVH00`1V
IVH2o`0001D0Ogmo0ol0000306IVIP8000001@1<C4`00`000000<c<c03<c<`0403<c<`030000000I
6AT06ATI00P06ATI6P000004ooooo`0300000?oooooooooo02Wooooo0_l0000]ooooo`03o`000?oo
oooooooo06?ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`09ooooo`002Oooool0
1000003ooooooooooooooom2000000T06ATI00<0000003<c<`0c<c<0100c<c<00`000000C4a<04a<
C00304a<C0030000001VIVH0IVIV00@0IVIV0_l0000@07moO`?o00001@1VIVH00ol00000C4a<04a<
C00404a<C003o`00000c<c<0<c<c00@0<c<c00?o000001TI6@0I6AT01`0I6ATL000000Cooooo00<0
0000ooooooooool0:oooool00ol0003oooooooooo`0Zooooo`03o`000?oooooooooo06?ooooo00?o
0000ooooooooool00_ooool00ol0003oooooooooo`09ooooo`002Oooool01000003ooooooooooooo
oom2000000T06ATI00<0000003<c<`0c<c<0100c<c<00`000000C4a<04a<C00404a<C0030000001V
IVH0IVIV00D0IVIV0ol0000907moO`Co00001P1VIVH2000000D0C4a<0P00000603<c<`030000000I
6AT06ATI00L06ATI7@000004ooooo`0300000?oooooooooo02cooooo00?o0000ooooooooool0:Ooo
ool00ol0003oooooooooo`1Tooooo`05o`000?ooooooooooooooool000002oooool000Wooooo00@0
0000oooooooooooooooo@P00000901TI6@030000000c<c<0<c<c00@0<c<c00<0000004a<C01<C4`0
1@1<C4`00ol00000000006IVIP0706IVIPWo00001`1VIVH3000000D0C4a<0P00000703<c<`030000
000I6AT06ATI00L06ATI7P000004ooooo`0300000?oooooooooo02gooooo00?o0000ooooooooool0
:?ooool00ol0003oooooooooo`1Uooooo`04o`000?ooooooooooo`0000_ooooo0009ooooo`040000
0?oooooooooooooood8000002P0I6AT00`000000<c<c03<c<`0403<c<`030000001<C4`0C4a<00H0
C4a<00<0000006IVIP1VIVH04P1VIVH3000000H0C4a<0P00000703<c<`800000200I6ATP000000Co
oooo00<00000ooooooooool0;_ooool2o`0002Sooooo00?o0000ooooooooool0I_ooool00ol0003o
ooooo`00000;ooooo`002Oooool01000003ooooooooooooooom2000000X06ATI00<0000003<c<`0c
<c<01@0c<c<00ol00000C4a<04a<C00604a<C00400000?l000000000000000`0IVIV1000000704a<
C08000001`0c<c<00ol00000000001TI6@0801TI6@03o`0000000000000001h000001?ooool00`00
003oooooooooo`0`ooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool0I_ooool00ol0
003oooooo`00000;ooooo`002Oooool01000003ooooooooooooooom2000000X06ATI00<0000003<c
<`0c<c<01P0c<c<00`000000C4a<04a<C00904a<C0`000002P1<C4`00`000000<c<c03<c<`0503<c
<`8000002@0I6ATS000000Cooooo00<00000ooooooooool0<Oooool00ol0003oooooooooo`0Toooo
o`03o`000?oooooooooo06Oooooo00?o0000ooooool000002_ooool000Wooooo00@00000oooooooo
oooooooo@`00000:01TI6@030000000c<c<0<c<c00H0<c<c0P00000L04a<C0<000001`0c<c<00`00
00006ATI01TI6@0801TI6B@000001?ooool00`00003oooooooooo`0booooo`03o`000?oooooooooo
02?ooooo00?o0000ooooooooool0J?ooool2o`0000[ooooo0009ooooo`0400000?oooooooooooooo
od<000002`0I6AT00`000000<c<c03<c<`0703<c<`8000005`1<C4`3000000P0<c<c0P00000:01TI
6BD000001?ooool00`00003oooooooooo`0cooooo`;o00008oooool00ol0003oooooooooo`1Woooo
o`?o00002_ooool000Wooooo00@00000oooooooooooooooo@`00000<01TI6@0300000?l00000<c<c
00P0<c<c0`00000@04a<C0@000001`0c<c<4000000X06ATI9`000004ooooo`0300000?oooooooooo
03Gooooo00?o0000ooooooooool08?ooool00ol0003oooooooooo`1Sooooo`Co00003Oooool000Wo
oooo00@00000oooooooooooooooo@`00000>01TI6@030000000c<c<0<c<c00T0<c<c4000000:03<c
<`030000000I6AT06ATI00/06ATI:0000004ooooo`0300000?oooooooooo03Kooooo00?o0000oooo
ooooool07oooool00ol0003oooooooooo`1Pooooo`?o00004Oooool000Wooooo00@00000oooooooo
ooooooooA000000>01TI6@030000000c<c<0<c<c01l0<c<c0`00000<01TI6BX000001?ooool00`00
003oooooooooo`0gooooo`03o`000?oooooooooo01kooooo00?o0000ooooooooool0G?ooool4o`00
01Cooooo0009ooooo`0400000?ooooooooooooooodD000003P0I6AT00`00003o00000000000K03<c
<`<000003@0I6AT/000000Cooooo00<00000ooooooooool0>?ooool2o`0001kooooo00?o0000oooo
ooooool0F?ooool4o`0001Sooooo0009ooooo`0400000?ooooooooooooooodD0000000?o000001TI
6@0I6AT03P0I6AT3000001@0<c<c1000000>01TI6Bh000001?ooool00`00003oooooooooo`0joooo
o`03o`000?oooooooooo01_ooooo00?o0000ooooooooool0E?ooool4o`0001cooooo0009ooooo`04
00000?ooooooooooooooodL000004P0I6AT4000000T0<c<c1`00000A01TI6Bl000001?ooool00`00
003oooooooooo`0kooooo`03o`000?oooooooooo01[ooooo00?o0000ooooooooool0DOooool3o`00
023ooooo0009ooooo`0400000?ooooooooooooooodP000005@0I6AT9000001H06ATI<@000004oooo
o`0300000?oooooooooo03cooooo00?o0000ooooooooool06Oooool00ol0003oooooooooo`1=oooo
o`Co00008oooool000Wooooo00@00000ooooooooooooooooB@0000000ol00000000001TI6@0/01TI
6@80000000?o0000000000000000<0000004ooooo`0300000?oooooooooo03gooooo0_l0000Ioooo
o`03o`000?oooooooooo04Wooooo1?l0000Wooooo`002Oooool01000003ooooooooooooooom<0000
02T06ATI>0000004ooooo`0300000?oooooooooo03oooooo00?o0000ooooooooool05_ooool00ol0
003oooooooooo`15ooooo`Co0000:oooool000Wooooo00@00000ooooooooooooooooCP00000U01TI
6CX000001?ooool00`00003oooooooooo`10ooooo`03o`000?oooooooooo01Cooooo00?o0000oooo
ooooool0@oooool3o`0002oooooo0009ooooo`0400000?oooooooooooooooe000000800I6AT20000
0003o`0000000000000003P000001?ooool00`00003oooooooooo`11ooooo`03o`000?oooooooooo
01?ooooo00?o0000ooooooooool0?oooool4o`0003;ooooo0009ooooo`0400000?oooooooooooooo
oe<000005`0I6AU3000000Cooooo00<00000ooooooooool0@_ooool2o`0001?ooooo00?o0000oooo
ooooool0>oooool4o`0003Kooooo0009ooooo`0400000?oooooooooooooooeT000002P0I6AU:0000
00Cooooo00<00000ooooooooool0A?ooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo
03Oooooo1?l0000jooooo`002Oooool01000003ooooooooooooooon]000000Cooooo00<00000oooo
ooooool0AOooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo03?ooooo1?l0000noooo
o`002Oooool01000003ooooooooooooooon]000000Cooooo00<00000ooooooooool0A_ooool00ol0
003oooooooooo`0>ooooo`03o`000?oooooooooo033ooooo0ol00012ooooo`002Oooool01000003o
oooooooooooooon]000000Cooooo00<00000ooooooooool0Aoooool00ol0003oooooooooo`0=oooo
o`03o`000?oooooooooo02cooooo1?l00015ooooo`002Oooool01000003ooooooooooooooon]0000
00Cooooo00<00000ooooooooool0B?ooool2o`0000gooooo00?o0000ooooooooool0:?ooool4o`00
04Wooooo0009ooooo`0400000?ooooooooooooooojd000001?ooool00`00003oooooooooo`1:oooo
o`03o`000?oooooooooo00[ooooo00?o0000ooooooooool09?ooool4o`0004gooooo0009ooooo`04
00000?ooooooooooooooojd000001?ooool00`00003oooooooooo`1;ooooo`03o`000?oooooooooo
00Wooooo00?o0000ooooooooool08Oooool3o`00057ooooo0009ooooo`0400000?oooooooooooooo
ojd000001?ooool00`00003oooooooooo`1<ooooo`03o`000?oooooooooo00Sooooo00?o0000oooo
ooooool07Oooool4o`0005Cooooo0009ooooo`0400000?ooooooooooooooojd000001?ooool00`00
003oooooooooo`1=ooooo`;o00002?ooool00ol0003oooooooooo`0Iooooo`Co0000F?ooool000Wo
oooo00@00000oooooooooooooooo[@000004ooooo`0300000?oooooooooo04oooooo00?o0000oooo
ooooool01Oooool00ol0003oooooooooo`0Eooooo`Co0000G?ooool000Wooooo00@00000oooooooo
oooooooo[@000004ooooo`0300000?oooooooooo053ooooo00?o0000ooooooooool01?ooool00ol0
003oooooooooo`0Booooo`?o0000H?ooool000Wooooo00@00000oooooooooooooooo[@000004oooo
o`0300000?oooooooooo057ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0>oooo
o`Co0000Hoooool000Wooooo00@00000oooooooooooooooo[@000004ooooo`0300000?oooooooooo
05;ooooo0_l00003ooooo`03o`000?oooooooooo00[ooooo1?l0001Wooooo`002Oooool01000003o
oooooooooooooon]000000Cooooo00<00000ooooooooool0E?ooool01?l0003oooooooooool00008
ooooo`Co0000Joooool000Wooooo00@00000oooooooooooooooo[@000004ooooo`0300000?oooooo
oooo05Gooooo00?o0000ooooool000001Oooool3o`0006oooooo0009ooooo`0400000?oooooooooo
ooooojd000001?ooool00`00003oooooooooo`1Fooooo`;o000000?oooooo`000?l000000_l0001b
ooooo`002Oooool01000003ooooooooooooooon]000000Cooooo00<00000ooooooooool0Eoooool2
o`0007Kooooo0009ooooo`0400000?ooooooooooooooojd000001?ooool00`00003oooooooooo`3?
ooooo`002Oooool01000003ooooooooooooooon]000000Cooooo00<00000ooooooooool0coooool0
00Wooooo00@00000oooooooooooooooo[@000004ooooo`0300000?oooooooooo0<oooooo0009oooo
o`0400000?ooooooooooooooojd000001?ooool00`00003oooooooooo`3?ooooo`002Oooool01000
003ooooooooooooooon]000000Cooooo00<00000ooooooooool0coooool000Wooooo00@00000oooo
oooooooooooo[@000004ooooo`0300000?oooooooooo0<oooooo0009ooooo`0400000?oooooooooo
ooooojd000001?ooool00`00003oooooooooo`3?ooooo`002Oooool01000003ooooooooooooooon]
000000Cooooo00<00000ooooooooool0coooool000Wooooo00@00000oooooooooooooooo[@000004
ooooo`0300000?oooooooooo0<oooooo0009ooooo`0400000?ooooooooooooooojd000001?ooool0
0`00003oooooooooo`3?ooooo`002Oooool01000003ooooooooooooooon]000000Cooooo00<00000
ooooooooool0coooool000Wooooo00@00000oooooooooooooooo[@000004ooooo`0300000?oooooo
oooo0<oooooo0009ooooo`0400000?ooooooooooooooojd000001?ooool00`00003oooooooooo`3?
ooooo`002Oooool00`00003oooooooooo`2booooo`0300000?oooooooooo0<oooooo0009ooooo`03
00000?oooooooooo0;;ooooo00<00000ooooooooool0coooool000Wooooo00<00000ooooooooool0
/_ooool00`00003oooooooooo`3?ooooo`002Ooooonf00000=7ooooo003ooooooi7ooooo003ooooo
oi7ooooo003ooooooi7ooooo003ooooooi7ooooo003ooooooi7ooooo003ooooooi7ooooo003ooooo
oi7ooooo003ooooooi7ooooo003ooooooi7ooooo003ooooooi7ooooo003ooooooi7ooooo003ooooo
oi7ooooo003ooooooi7ooooo003ooooooi7ooooo003ooooooi7ooooo003ooooooi7ooooo003ooooo
oi7ooooo0009oooookKo00004Ooooonfo`0000[ooooo0009ooooo`03o`000?oooooooooo0;;ooooo
00?o0000ooooooooool03oooool00ol0003oooooooooo`2booooo`03o`000?oooooooooo00Sooooo
0009ooooo`03o`000?oooooooooo0;;ooooo00?o0000ooooooooool03oooool00ol0003ooooooooo
o`2booooo`03o`000?oooooooooo00Sooooo0009ooooo`03o`000?oooooooooo0;;ooooo00?o0000
ooooooooool03oooool00ol0003oooooooooo`2booooo`03o`000?oooooooooo00Sooooo0009oooo
o`03o`000?oooooooooo0;;ooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`2boooo
o`03o`000?oooooooooo00Sooooo0009ooooo`03o`000?oooooooooo0;;ooooo00?o0000oooooooo
ool03oooool00ol0003oooooooooo`2booooo`03o`000?oooooooooo00Sooooo0009ooooo`03o`00
0?oooooooooo0;;ooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`2booooo`03o`00
0?oooooooooo00Sooooo0009ooooo`03o`000?oooooooooo0;;ooooo00?o0000ooooooooool03ooo
ool00ol0003oooooooooo`2booooo`03o`000?oooooooooo00Sooooo0009ooooo`03o`000?oooooo
oooo0;;ooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`2booooo`03o`000?oooooo
oooo00Sooooo0009ooooo`03o`000?oooooooooo0;;ooooo00?o0000ooooooooool03oooool00ol0
003oooooooooo`2booooo`03o`000?oooooooooo00Sooooo0009ooooo`03o`000?oooooooooo0;;o
oooo00?o0000ooooooooool03oooool00ol0003oooooooooo`2booooo`03o`000?oooooooooo00So
oooo0009ooooo`03o`000?oooooooooo0;;ooooo00?o0000ooooooooool03oooool00ol0003ooooo
ooooo`2booooo`03o`000?oooooooooo00Sooooo0009ooooo`03o`000?oooooooooo0;;ooooo00?o
0000ooooooooool03oooool00ol0003oooooooooo`2booooo`03o`000?oooooooooo00Sooooo0009
ooooo`03o`000?oooooooooo0;;ooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`2b
ooooo`03o`000?oooooooooo00Sooooo0009ooooo`03o`000?oooooooooo0;;ooooo00?o0000oooo
ooooool03oooool00ol0003oooooooooo`2booooo`03o`000?oooooooooo00Sooooo0009ooooo`03
o`000?oooooooooo0;;ooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`2booooo`03
o`000?oooooooooo00Sooooo0009ooooo`03o`000?oooooooooo0;;ooooo00?o0000ooooooooool0
3oooool00ol0003oooooooooo`2booooo`03o`000?oooooooooo00Sooooo0009ooooo`03o`000?oo
oooooooo0;;ooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`2booooo`03o`000?oo
oooooooo00Sooooo0009ooooo`03o`000?oooooooooo0;;ooooo00?o0000ooooooooool03oooool0
0ol0003oooooooooo`2booooo`03o`000?oooooooooo00Sooooo0009ooooo`03o`000?oooooooooo
0;;ooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`2booooo`03o`000?oooooooooo
00Sooooo0009ooooo`03o`000?oooooooooo0;;ooooo00?o0000ooooooooool03oooool00ol0003o
ooooooooo`2booooo`03o`000?oooooooooo00Sooooo0009ooooo`03o`000?oooooooooo0;;ooooo
00?o0000ooooooooool03oooool00ol0003oooooooooo`2booooo`03o`000?oooooooooo00Sooooo
0009ooooo`03o`000?oooooooooo0;;ooooo00?o0000ooooooooool03oooool00ol0003ooooooooo
o`2booooo`03o`000?oooooooooo00Sooooo0009ooooo`03o`000?oooooooooo00?ooooo0P3oO`0;
ooooo`80ogl0X?ooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo00?ooooo0P3oO`0;
ooooo`80ogl0X?ooool00ol0003oooooooooo`08ooooo`002Oooool00ol0003oooooooooo`02oooo
o`<0ogl02oooool20?mo00cooooo0P3oO`2Booooo`03o`000?oooooooooo00oooooo00?o0000oooo
ooooool00_ooool30?mo00_ooooo0P3oO`0<ooooo`80ogl0T_ooool00ol0003oooooooooo`08oooo
o`002Oooool00ol0003oooooooooo`02ooooo`80ogl06_ooool20?mo09;ooooo00?o0000oooooooo
ool03oooool00ol0003oooooooooo`02ooooo`80ogl06_ooool20?mo09;ooooo00?o0000oooooooo
ool02?ooool000Wooooo00?o0000ooooooooool0/_ooool00ol0003oooooooooo`0?ooooo`03o`00
0?oooooooooo0;;ooooo00?o0000ooooooooool02?ooool000Wooooo00?o0000ooooooooool0/_oo
ool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo0;;ooooo00?o0000ooooooooool02?oo
ool000Wooooo00?o0000ooooooooool0/_ooool00ol0003oooooooooo`0?ooooo`03o`000?oooooo
oooo0;;ooooo00?o0000ooooooooool02?ooool000Wooooo00?o0000ooooooooool0/_ooool00ol0
003oooooooooo`0?ooooo`03o`000?oooooooooo0;;ooooo00?o0000ooooooooool02?ooool000Wo
oooo00?o0000ooooooooool06Oooool5o`00oiCooooo00?o0000ooooooooool03oooool00ol0003o
ooooooooo`2booooo`03o`000?oooooooooo00Sooooo0009ooooo`03o`000?oooooooooo01Sooooo
00?o003oooooooooool00oooool5o`00ohoooooo00?o0000ooooooooool03oooool00ol0003ooooo
ooooo`2booooo`03o`000?oooooooooo00Sooooo0009ooooo`03o`000?oooooooooo01Oooooo00?o
003oooooooooool02Oooool3o`00ohcooooo00?o0000ooooooooool03oooool00ol0003ooooooooo
o`2booooo`03o`000?oooooooooo00Sooooo0009ooooo`03o`000?oooooooooo01Kooooo00?o003o
ooooooooool03Oooool2o`00oh[ooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`2b
ooooo`03o`000?oooooooooo00Sooooo0009ooooo`03o`000?oooooooooo01Gooooo00?o003o0?mo
003oO`001Oooool20?mo00Wooooo00?o003oooooooooool0Qoooool00ol0003oooooooooo`0?oooo
o`03o`000?oooooooooo01Kooooo0P3oO`05ooooo`80ogl0Toooool00ol0003oooooooooo`08oooo
o`002Oooool00ol0003oooooooooo`0Fooooo`03o`00o`3oO`3ooooo00Cooooo0P3oO`09ooooo`;o
003oR?ooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo01Kooooo0P3oO`05ooooo`80
ogl0Toooool00ol0003oooooooooo`08ooooo`002Oooool00ol0003oooooooooo`0Fooooo`03o`00
oooooooooooo017ooooo0ol00?n5ooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool0
/_ooool00ol0003oooooooooo`08ooooo`002Oooool00ol0003oooooooooo`0Fooooo`03o`00oooo
oooooooo01Cooooo00?o003oooooooooool0P_ooool00ol0003oooooooooo`0?ooooo`03o`000?oo
oooooooo0;;ooooo00?o0000ooooooooool02?ooool000Wooooo00?o0000ooooooooool05oooool0
0ol00?ooooooooooo`02ooooo`80ogl01_ooool20?mo00Sooooo00?o003oooooooooool00P3oO`03
ooooo`80ogl0N_ooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo01cooooo0P3oO`06
ooooo`80ogl02oooool20?mo00?ooooo0P3oO`1jooooo`03o`000?oooooooooo00Sooooo0009oooo
o`03o`000?oooooooooo01Oooooo00?o003oooooooooool00_ooool20?mo00Kooooo0P3oO`09oooo
o`;o003o0P3oO`03ooooo`80ogl0N_ooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo
01cooooo0P3oO`06ooooo`80ogl02oooool20?mo00?ooooo0P3oO`1jooooo`03o`000?oooooooooo
00Sooooo0009ooooo`03o`000?oooooooooo01Sooooo00?o003oooooooooool05_ooool00ol00?oo
ooooooooo`03ooooo`80ogl0NOooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo03Oo
oooo0P3oO`1iooooo`03o`000?oooooooooo00Sooooo0009ooooo`03o`000?oooooooooo01Wooooo
00?o003oooooooooool05_ooool2o`00o`030?mo0?oooooooooo0080ogl0NOooool00ol0003ooooo
ooooo`0?ooooo`03o`000?oooooooooo03?ooooo0P3oO`02ooooo`80ogl0NOooool00ol0003ooooo
ooooo`08ooooo`002Oooool00ol0003oooooooooo`0Jooooo`;o003o2oooool3000000Wooooo00<0
ogl0o`00ooooool0O?ooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo03?ooooo0P3o
O`1mooooo`03o`000?oooooooooo00Sooooo0009ooooo`03o`000?oooooooooo01cooooo00?o003o
ooooooooool00_ooool20?mo00?ooooo1@00000:ooooo`03o`00oooooooooooo07[ooooo00?o0000
ooooooooool03oooool00ol0003oooooooooo`0Qooooo`80ogl0Soooool00ol0003oooooooooo`08
ooooo`002Oooool00ol0003oooooooooo`0Jooooo`80ogl000?oooooo`00ooooool00_ooool20?mo
00?ooooo1@00000;ooooo`03o`00oooooooooooo07Wooooo00?o0000ooooooooool03oooool00ol0
003oooooooooo`0Jooooo`80ogl01Oooool20?mo08oooooo00?o0000ooooooooool02?ooool000Wo
oooo00?o0000ooooooooool06_ooool20?mo00;ooooo00?o003oooooooooool01Oooool5000000Oo
oooo0P3oO`03ooooo`03o`00oooooooooooo00Cooooo0P3oO`1booooo`03o`000?oooooooooo00oo
oooo00?o0000ooooooooool06_ooool20?mo01Kooooo0P3oO`0:ooooo`80ogl0L_ooool00ol0003o
ooooooooo`08ooooo`002Oooool00ol0003oooooooooo`0Oooooo`03o`00oooooooooooo00Gooooo
0`000008ooooo`80ogl01?ooool00ol00?ooooooooooo`03ooooo`80ogl0L_ooool00ol0003ooooo
ooooo`0?ooooo`03o`000?oooooooooo03;ooooo0P3oO`0:ooooo`80ogl0L_ooool00ol0003ooooo
ooooo`08ooooo`002Oooool00ol0003oooooooooo`0Pooooo`03o`00oooooooooooo01Kooooo00?o
003oooooooooool0M_ooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo0;;ooooo00?o
0000ooooooooool02?ooool000Wooooo00?o0000ooooooooool08Oooool2o`00oaOooooo00?o003o
ooooooooool0MOooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo0;;ooooo00?o0000
ooooooooool02?ooool000Wooooo00?o0000ooooooooool08oooool00ol00?ooooooooooo`0Doooo
o`03o`00oooooooooooo07Gooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`2boooo
o`03o`000?oooooooooo00Sooooo0009ooooo`03o`000?oooooooooo02?ooooo00<0ogl0o`00ool0
0?l00P3oO`0Booooo`03o`00oooooooooooo07Gooooo00?o0000ooooooooool03oooool00ol0003o
ooooooooo`0Sooooo`80ogl000?ooooo0?mo003oO`00R_ooool00ol0003oooooooooo`08ooooo`00
2Oooool00ol0003oooooooooo`0Sooooo`<0ogl00_l00?lCooooo`03o`00oooooooooooo07Cooooo
00?o0000ooooooooool03oooool00ol0003oooooooooo`0Sooooo`D0ogl0R_ooool00ol0003ooooo
ooooo`08ooooo`002Oooool00ol0003oooooooooo`0Uooooo`80ogl000?oooooo`00ooooool04Ooo
ool00ol00?l0ogl0ooooo`1dooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool09Ooo
ool20?mo01Cooooo0P3oO`1eooooo`03o`000?oooooooooo00Sooooo0009ooooo`03o`000?oooooo
oooo02Wooooo0_l00?l@ooooo`03o`00o`3oO`3ooooo07Cooooo00?o0000ooooooooool03oooool0
0ol0003oooooooooo`0kooooo`80ogl0MOooool00ol0003oooooooooo`08ooooo`002Oooool00ol0
003oooooooooo`0[ooooo`;o003o3Oooool2o`00ogKooooo00?o0000ooooooooool03oooool00ol0
003oooooooooo`2booooo`03o`000?oooooooooo00Sooooo0009ooooo`03o`000?oooooooooo02go
oooo1?l00?l7ooooo`;o003oN?ooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo0;;o
oooo00?o0000ooooooooool02?ooool000Wooooo00?o0000ooooooooool07_ooool20?mo017ooooo
1ol00?mjooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool07_ooool20?mo09;ooooo
00?o0000ooooooooool02?ooool000Wooooo00?o0000ooooooooool07_ooool20?mo09;ooooo00?o
0000ooooooooool03oooool00ol0003oooooooooo`0Nooooo`80ogl0T_ooool00ol0003ooooooooo
o`08ooooo`002Oooool00ol0003oooooooooo`2booooo`03o`000?oooooooooo00oooooo00?o0000
ooooooooool0/_ooool00ol0003oooooooooo`08ooooo`002Oooool00ol0003oooooooooo`2boooo
o`03o`000?oooooooooo00oooooo00?o0000ooooooooool0/_ooool00ol0003oooooooooo`08oooo
o`002Oooool00ol0003oooooooooo`2booooo`03o`000?oooooooooo00oooooo00?o0000oooooooo
ool0/_ooool00ol0003oooooooooo`08ooooo`002Oooool00ol0003oooooooooo`2booooo`03o`00
0?oooooooooo00oooooo00?o0000ooooooooool0/_ooool00ol0003oooooooooo`08ooooo`002Ooo
ool00ol0003oooooooooo`1>ooooo`80ogl0H_ooool00ol0003oooooooooo`0?ooooo`03o`000?oo
oooooooo04kooooo0P3oO`1Rooooo`03o`000?oooooooooo00Sooooo0009ooooo`03o`000?oooooo
oooo03Cooooo0P3oO`0Hooooo`80ogl0H_ooool00ol0003oooooooooo`0?ooooo`03o`000?oooooo
oooo03Cooooo0P3oO`0Hooooo`80ogl0H_ooool00ol0003oooooooooo`08ooooo`002Oooool00ol0
003oooooooooo`0dooooo`80ogl0O?ooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo
03Cooooo0P3oO`1looooo`03o`000?oooooooooo00Sooooo0009ooooo`03o`000?oooooooooo0;;o
oooo00?o0000ooooooooool03oooool00ol0003oooooooooo`2booooo`03o`000?oooooooooo00So
oooo0009ooooo`03o`000?oooooooooo03gooooo0P3oO`02ooooo`80ogl0Koooool00ol0003ooooo
ooooo`0?ooooo`03o`000?oooooooooo03gooooo0P3oO`02ooooo`80ogl0Koooool00ol0003ooooo
ooooo`08ooooo`002Oooool00ol0003oooooooooo`0mooooo`80ogl00_ooool20?mo06oooooo00?o
0000ooooooooool03oooool00ol0003oooooooooo`0mooooo`80ogl00_ooool20?mo06oooooo00?o
0000ooooooooool02?ooool000Wooooo00?o0000ooooooooool0/_ooool00ol0003oooooooooo`0?
ooooo`03o`000?oooooooooo0;;ooooo00?o0000ooooooooool02?ooool000Wooooo00?o0000oooo
ooooool0/_ooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo0;;ooooo00?o0000oooo
ooooool02?ooool000Wooooo00?o0000ooooooooool0/_ooool00ol0003oooooooooo`0?ooooo`03
o`000?oooooooooo0;;ooooo00?o0000ooooooooool02?ooool000Wooooo00?o0000ooooooooool0
/_ooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo0;;ooooo00?o0000ooooooooool0
2?ooool000Wooooo00?o0000ooooooooool0/_ooool00ol0003oooooooooo`0?ooooo`03o`000?oo
oooooooo0;;ooooo00?o0000ooooooooool02?ooool000Wooooo00?o0000ooooooooool0/_ooool0
0ol0003oooooooooo`0?ooooo`03o`000?oooooooooo0;;ooooo00?o0000ooooooooool02?ooool0
00Wooooo00?o0000ooooooooool0/_ooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo
0;;ooooo00?o0000ooooooooool02?ooool000Wooooo00?o0000ooooooooool0/_ooool00ol0003o
ooooooooo`0?ooooo`03o`000?oooooooooo0;;ooooo00?o0000ooooooooool02?ooool000Wooooo
00?o0000ooooooooool0/_ooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo0;;ooooo
00?o0000ooooooooool02?ooool000Wooooo00?o0000ooooooooool0/_ooool00ol0003ooooooooo
o`0?ooooo`03o`000?oooooooooo0;;ooooo00?o0000ooooooooool02?ooool000Wooooo00?o0000
ooooooooool0/_ooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo0;;ooooo00?o0000
ooooooooool02?ooool000Wooooo00?o0000ooooooooool0/_ooool00ol0003oooooooooo`0?oooo
o`03o`000?oooooooooo0;;ooooo00?o0000ooooooooool02?ooool000Wooooo00?o0000oooooooo
ool0/_ooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo0;;ooooo00?o0000oooooooo
ool02?ooool000Wooooo00?o0000ooooooooool0/_ooool00ol0003oooooooooo`0?ooooo`03o`00
0?oooooooooo0;;ooooo00?o0000ooooooooool02?ooool000Wooooo00?o0000ooooooooool0/_oo
ool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo0;;ooooo00?o0000ooooooooool02?oo
ool000Wooooo00?o0000ooooooooool0/_ooool00ol0003oooooooooo`0?ooooo`03o`000?oooooo
oooo0;;ooooo00?o0000ooooooooool02?ooool000Wooooo00?o0000ooooooooool0/_ooool00ol0
003oooooooooo`0?ooooo`03o`000?oooooooooo0;;ooooo00?o0000ooooooooool02?ooool000Wo
oooo00?o0000ooooooooool0/_ooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo0;;o
oooo00?o0000ooooooooool02?ooool000Wooooo00?o0000ooooooooool0/_ooool00ol0003ooooo
ooooo`0?ooooo`03o`000?oooooooooo0;;ooooo00?o0000ooooooooool02?ooool000Wooooo00?o
0000ooooooooool0/_ooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo0;;ooooo00?o
0000ooooooooool02?ooool000Wooooo00?o0000ooooooooool0/_ooool00ol0003oooooooooo`0?
ooooo`03o`000?oooooooooo0;;ooooo00?o0000ooooooooool02?ooool000Wooooo00?o0000oooo
ooooool0X_ooool20?mo00kooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`2Roooo
o`80ogl03_ooool00ol0003oooooooooo`08ooooo`002Oooool00ol0003oooooooooo`2Rooooo`80
ogl03_ooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo0:;ooooo0P3oO`0>ooooo`03
o`000?oooooooooo00Sooooo0009ooooo`03o`000?oooooooooo0;;ooooo00?o0000ooooooooool0
3oooool00ol0003oooooooooo`2booooo`03o`000?oooooooooo00Sooooo0009ooooo`03o`000?oo
oooooooo0;;ooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`2booooo`03o`000?oo
oooooooo00Sooooo0009ooooo`03o`000?oooooooooo0;;ooooo00?o0000ooooooooool03oooool0
0ol0003oooooooooo`2booooo`03o`000?oooooooooo00Sooooo0009ooooo`03o`000?oooooooooo
0;;ooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`2booooo`03o`000?oooooooooo
00Sooooo0009ooooo`03o`000?oooooooooo0;;ooooo00?o0000ooooooooool03oooool00ol0003o
ooooooooo`2booooo`03o`000?oooooooooo00Sooooo0009ooooo`03o`000?oooooooooo0;;ooooo
00?o0000ooooooooool03oooool00ol0003oooooooooo`2booooo`03o`000?oooooooooo00Sooooo
0009ooooo`03o`000?oooooooooo0;;ooooo00?o0000ooooooooool03oooool00ol0003ooooooooo
o`2booooo`03o`000?oooooooooo00Sooooo0009ooooo`03o`000?oooooooooo077ooooo0P3oO`0o
ooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool0LOooool20?mo03oooooo00?o0000
ooooooooool02?ooool000Wooooo00?o0000ooooooooool0LOooool20?mo00?ooooo1_l00?lfoooo
o`03o`000?oooooooooo00oooooo00?o0000ooooooooool0LOooool20?mo03oooooo00?o0000oooo
ooooool02?ooool000Wooooo00?o0000ooooooooool0L_ooool4o`00o`Kooooo1_l00?lAooooo`80
ogl07Oooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo09?ooooo0P3oO`0Mooooo`03
o`000?oooooooooo00Sooooo0009ooooo`03o`000?oooooooooo06kooooo1?l00?l@ooooo`;o003o
2oooool20?mo00;ooooo0P3oO`0Mooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool0
Soooool20?mo00;ooooo0P3oO`0Mooooo`03o`000?oooooooooo00Sooooo0009ooooo`03o`000?oo
oooooooo06_ooooo0ol00?l<ooooo`80ogl02?ooool2o`00o`Wooooo0P3oO`0Qooooo`03o`000?oo
oooooooo00oooooo00?o0000ooooooooool0N_ooool20?mo01?ooooo0P3oO`0Qooooo`03o`000?oo
oooooooo00Sooooo0009ooooo`03o`000?oooooooooo06[ooooo00?o003oooooooooool03Oooool2
0?mo00[ooooo00?o003oooooooooool0:Oooool00ol0003oooooooooo`0?ooooo`03o`000?oooooo
oooo07[ooooo0P3oO`0fooooo`03o`000?oooooooooo00Sooooo0009ooooo`03o`000?oooooooooo
06Wooooo00?o003oooooooooool02?ooool20?mo017ooooo00?o003oooooooooool00_ooool20?mo
02Cooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`1dooooo`80ogl05_ooool20?mo
02Cooooo00?o0000ooooooooool02?ooool000Wooooo00?o0000ooooooooool0Ioooool2o`00o`_o
oooo0P3oO`0Aooooo`03o`00oooooooooooo00;ooooo0P3oO`0Tooooo`03o`000?oooooooooo00oo
oooo00?o0000ooooooooool0M?ooool20?mo01Kooooo0P3oO`0Tooooo`03o`000?oooooooooo00So
oooo0009ooooo`03o`000?oooooooooo06Gooooo0_l00?l9ooooo`80ogl03oooool20?mo00Cooooo
00?o003oooooooooool01_ooool20?mo023ooooo00?o0000ooooooooool03oooool00ol0003ooooo
ooooo`1`ooooo`80ogl03oooool20?mo00gooooo0P3oO`0Pooooo`03o`000?oooooooooo00Sooooo
0009ooooo`03o`000?oooooooooo06?ooooo0_l00?l;ooooo`80ogl01?ooool20?mo00Wooooo0P3o
O`04ooooo`03o`00oooooooooooo00Kooooo0P3oO`0Pooooo`03o`000?oooooooooo00oooooo00?o
0000ooooooooool0L?ooool20?mo00Cooooo0P3oO`09ooooo`80ogl03Oooool20?mo023ooooo00?o
0000ooooooooool02?ooool000Wooooo00?o0000ooooooooool0E_ooool20?mo00[ooooo00?o003o
ooooooooool02oooool20?mo00Cooooo0P3oO`0@ooooo`03o`00oooooooooooo02Oooooo00?o0000
ooooooooool03oooool00ol0003oooooooooo`1Fooooo`80ogl06?ooool20?mo00Cooooo0P3oO`0j
ooooo`03o`000?oooooooooo00Sooooo0009ooooo`03o`000?oooooooooo05Kooooo0P3oO`09oooo
o`03o`00oooooooooooo00cooooo0P3oO`0Fooooo`03o`00oooooooooooo02Oooooo00?o0000oooo
ooooool03oooool00ol0003oooooooooo`1Fooooo`80ogl06?ooool20?mo043ooooo00?o0000oooo
ooooool02?ooool000Wooooo00?o0000ooooooooool0HOooool00ol00?ooooooooooo`0Tooooo`03
o`00oooooooooooo02Oooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`2booooo`03
o`000?oooooooooo00Sooooo0009ooooo`03o`000?oooooooooo05gooooo0P3oO`000ooooooo003o
ooooo`06ooooo`80ogl06Oooool20?mo00?ooooo00?o003oooooooooool09oooool00ol0003ooooo
ooooo`0?ooooo`03o`000?oooooooooo05gooooo0P3oO`09ooooo`80ogl06Oooool20?mo02gooooo
00?o0000ooooooooool02?ooool000Wooooo00?o0000ooooooooool0GOooool20?mo0003o`00oooo
oooooooo00Kooooo0P3oO`0Iooooo`80ogl00_ooool00ol00?ooooooooooo`0Xooooo`03o`000?oo
oooooooo00oooooo00?o0000ooooooooool0GOooool20?mo00Wooooo0P3oO`0Iooooo`80ogl0;Ooo
ool00ol0003oooooooooo`08ooooo`002Oooool00ol0003oooooooooo`1Nooooo`03o`00oooooooo
oooo02Kooooo00?o003oooooooooool0:?ooool00ol0003oooooooooo`0?ooooo`03o`000?oooooo
oooo0;;ooooo00?o0000ooooooooool02?ooool000Wooooo00?o0000ooooooooool0GOooool00ol0
0?ooooooooooo`0@ooooo`<000005?ooool00ol00?ooooooooooo`09ooooo`80ogl07Oooool00ol0
003oooooooooo`0?ooooo`03o`000?oooooooooo09?ooooo0P3oO`0Mooooo`03o`000?oooooooooo
00Sooooo0009ooooo`03o`000?oooooooooo05gooooo00?o003oooooooooool03oooool5000001;o
oooo00<0ogl0o`00ooooool02_ooool20?mo01gooooo00?o0000ooooooooool03oooool00ol0003o
ooooooooo`26ooooo`80ogl02oooool20?mo01gooooo00?o0000ooooooooool02?ooool000Wooooo
00?o0000ooooooooool0G?ooool00ol00?ooooooooooo`0@ooooo`D000004_ooool00`3oO`3o003o
ooooo`0Yooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool0L_ooool20?mo01;ooooo
0P3oO`0Zooooo`03o`000?oooooooooo00Sooooo0009ooooo`03o`000?oooooooooo05cooooo00?o
003oooooooooool04?ooool5000001;ooooo00?o003oooooooooool0:Oooool00ol0003ooooooooo
o`0?ooooo`03o`000?oooooooooo07;ooooo0P3oO`0nooooo`03o`000?oooooooooo00Sooooo0009
ooooo`03o`000?oooooooooo05_ooooo00?o003oooooooooool02oooool20?mo00Gooooo0`00000A
ooooo`030?mo0?l00?oooooo02_ooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`1Y
ooooo`80ogl01Oooool20?mo01;ooooo0P3oO`0/ooooo`03o`000?oooooooooo00Sooooo0009oooo
o`03o`000?oooooooooo05_ooooo00?o003oooooooooool02Oooool40?mo00Gooooo0P3oO`0>oooo
o`80ogl00_ooool00ol00?l0ogl0ooooo`0[ooooo`03o`000?oooooooooo00oooooo00?o0000oooo
ooooool0Ioooool40?mo00Gooooo0P3oO`0>ooooo`80ogl00_ooool20?mo02cooooo00?o0000oooo
ooooool02?ooool000Wooooo00?o0000ooooooooool0Foooool00ol00?ooooooooooo`09ooooo`80
ogl05oooool20?mo00;ooooo00?o003oooooooooool0:oooool00ol0003oooooooooo`0?ooooo`03
o`000?oooooooooo06Oooooo0P3oO`0Gooooo`80ogl0<?ooool00ol0003oooooooooo`08ooooo`00
2Oooool00ol0003oooooooooo`19ooooo`80ogl04?ooool00ol00?ooooooooooo`0Uooooo`03o`00
oooooooooooo02cooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`19ooooo`80ogl0
Ioooool00ol0003oooooooooo`08ooooo`002Oooool00ol0003oooooooooo`19ooooo`80ogl01ooo
ool20?mo00Oooooo00?o003oooooooooool04?ooool20?mo017ooooo0_l00?l_ooooo`03o`000?oo
oooooooo00oooooo00?o0000ooooooooool0BOooool20?mo00Oooooo0P3oO`0Jooooo`80ogl0@_oo
ool00ol0003oooooooooo`08ooooo`002Oooool00ol0003oooooooooo`1Booooo`80ogl01oooool0
0ol00?ooooooooooo`0@ooooo`80ogl03oooool2o`00oc7ooooo00?o0000ooooooooool03oooool0
0ol0003oooooooooo`1Booooo`80ogl06_ooool20?mo04;ooooo00?o0000ooooooooool02?ooool0
00Wooooo00?o0000ooooooooool0Foooool00ol00?ooooooooooo`0;ooooo`80ogl04oooool00ol0
0?ooooooooooo`0aooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool0JOooool20?mo
04Oooooo00?o0000ooooooooool02?ooool000Wooooo00?o0000ooooooooool0G?ooool00ol00?oo
ooooooooo`0:ooooo`80ogl04Oooool2o`00ocCooooo00?o0000ooooooooool03oooool00ol0003o
ooooooooo`1Yooooo`80ogl0Aoooool00ol0003oooooooooo`08ooooo`002Oooool00ol0003ooooo
ooooo`1Looooo`03o`00oooooooooooo01_ooooo0_l00?lfooooo`03o`000?oooooooooo00oooooo
00?o0000ooooooooool0/_ooool00ol0003oooooooooo`08ooooo`002Oooool00ol0003ooooooooo
o`1Looooo`03o`00oooooooooooo01[ooooo00?o003oooooooooool0=_ooool00ol0003ooooooooo
o`0?ooooo`03o`000?oooooooooo0;;ooooo00?o0000ooooooooool02?ooool000Wooooo00?o0000
ooooooooool0GOooool2o`00oaSooooo0_l00?liooooo`03o`000?oooooooooo00oooooo00?o0000
ooooooooool0/_ooool00ol0003oooooooooo`08ooooo`002Oooool00ol0003oooooooooo`1Boooo
o`80ogl02oooool00ol00?ooooooooooo`0Cooooo`;o003o>oooool00ol0003oooooooooo`0?oooo
o`03o`000?oooooooooo05;ooooo0P3oO`1Nooooo`03o`000?oooooooooo00Sooooo0009ooooo`03
o`000?oooooooooo05;ooooo0P3oO`0<ooooo`03o`00oooooooooooo00oooooo0ol00?lmooooo`03
o`000?oooooooooo00oooooo00?o0000ooooooooool0D_ooool20?mo05kooooo00?o0000oooooooo
ool02?ooool000Wooooo00?o0000ooooooooool0HOooool4o`00o`Sooooo1Ol00?m0ooooo`03o`00
0?oooooooooo00oooooo00?o0000ooooooooool0Koooool20?mo047ooooo00?o0000ooooooooool0
2?ooool000Wooooo00?o0000ooooooooool0IOooool8o`00o`;ooooo0P3oO`11ooooo`03o`000?oo
oooooooo00oooooo00?o0000ooooooooool0Koooool20?mo047ooooo00?o0000ooooooooool02?oo
ool000Wooooo00?o0000ooooooooool0/_ooool00ol0003oooooooooo`0?ooooo`03o`000?oooooo
oooo0;;ooooo00?o0000ooooooooool02?ooool000Wooooo00?o0000ooooooooool0/_ooool00ol0
003oooooooooo`0?ooooo`03o`000?oooooooooo0;;ooooo00?o0000ooooooooool02?ooool000Wo
oooo00?o0000ooooooooool0COooool20?mo06?ooooo00?o0000ooooooooool03oooool00ol0003o
ooooooooo`1=ooooo`80ogl0Hoooool00ol0003oooooooooo`08ooooo`002Oooool00ol0003ooooo
ooooo`1=ooooo`80ogl05?ooool20?mo04gooooo00?o0000ooooooooool03oooool00ol0003ooooo
ooooo`1=ooooo`80ogl05?ooool20?mo04gooooo00?o0000ooooooooool02?ooool000Wooooo00?o
0000ooooooooool0Hoooool20?mo04gooooo00?o0000ooooooooool03oooool00ol0003ooooooooo
o`1Sooooo`80ogl0COooool00ol0003oooooooooo`08ooooo`002Oooool00ol0003oooooooooo`1I
ooooo`80ogl0Eoooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo05Wooooo0P3oO`1G
ooooo`03o`000?oooooooooo00Sooooo0009ooooo`03o`000?oooooooooo05Wooooo0P3oO`1Goooo
o`03o`000?oooooooooo00oooooo00?o0000ooooooooool0FOooool20?mo05Oooooo00?o0000oooo
ooooool02?ooool000Wooooo00?o0000ooooooooool0LOooool20?mo03oooooo00?o0000oooooooo
ool03oooool00ol0003oooooooooo`1aooooo`80ogl0?oooool00ol0003oooooooooo`08ooooo`00
2Oooool00ol0003oooooooooo`1aooooo`80ogl0?oooool00ol0003oooooooooo`0?ooooo`03o`00
0?oooooooooo077ooooo0P3oO`0oooooo`03o`000?oooooooooo00Sooooo0009ooooo`03o`000?oo
oooooooo0;;ooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`2booooo`03o`000?oo
oooooooo00Sooooo0009ooooo`03o`000?oooooooooo0;;ooooo00?o0000ooooooooool03oooool0
0ol0003oooooooooo`2booooo`03o`000?oooooooooo00Sooooo0009ooooo`03o`000?oooooooooo
0;;ooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`2booooo`03o`000?oooooooooo
00Sooooo0009ooooo`03o`000?oooooooooo0;;ooooo00?o0000ooooooooool03oooool00ol0003o
ooooooooo`2booooo`03o`000?oooooooooo00Sooooo0009ooooo`03o`000?oooooooooo0;;ooooo
00?o0000ooooooooool03oooool00ol0003oooooooooo`2booooo`03o`000?oooooooooo00Sooooo
0009ooooo`03o`000?oooooooooo0;;ooooo00?o0000ooooooooool03oooool00ol0003ooooooooo
o`2booooo`03o`000?oooooooooo00Sooooo0009ooooo`03o`000?oooooooooo0;;ooooo00?o0000
ooooooooool03oooool00ol0003oooooooooo`2booooo`03o`000?oooooooooo00Sooooo0009oooo
o`03o`000?oooooooooo0;;ooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`2boooo
o`03o`000?oooooooooo00Sooooo0009ooooo`03o`000?oooooooooo0;;ooooo00?o0000oooooooo
ool03oooool00ol0003oooooooooo`2booooo`03o`000?oooooooooo00Sooooo0009ooooo`03o`00
0?oooooooooo0;;ooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`2booooo`03o`00
0?oooooooooo00Sooooo0009ooooo`03o`000?oooooooooo0;;ooooo00?o0000ooooooooool03ooo
ool00ol0003oooooooooo`2booooo`03o`000?oooooooooo00Sooooo0009ooooo`03o`000?oooooo
oooo0;;ooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`2booooo`03o`000?oooooo
oooo00Sooooo0009ooooo`03o`000?oooooooooo0;;ooooo00?o0000ooooooooool03oooool00ol0
003oooooooooo`2booooo`03o`000?oooooooooo00Sooooo0009ooooo`03o`000?oooooooooo0;;o
oooo00?o0000ooooooooool03oooool00ol0003oooooooooo`2booooo`03o`000?oooooooooo00So
oooo0009ooooo`03o`000?oooooooooo0;;ooooo00?o0000ooooooooool03oooool00ol0003ooooo
ooooo`2booooo`03o`000?oooooooooo00Sooooo0009ooooo`03o`000?oooooooooo0;;ooooo00?o
0000ooooooooool03oooool00ol0003oooooooooo`2booooo`03o`000?oooooooooo00Sooooo0009
ooooo`03o`000?oooooooooo0;;ooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`2b
ooooo`03o`000?oooooooooo00Sooooo0009ooooo`03o`000?oooooooooo0;;ooooo00?o0000oooo
ooooool03oooool00ol0003oooooooooo`2booooo`03o`000?oooooooooo00Sooooo0009ooooo`03
o`000?oooooooooo0;;ooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`2booooo`03
o`000?oooooooooo00Sooooo0009ooooo`03o`000?oooooooooo0;;ooooo00?o0000ooooooooool0
3oooool00ol0003oooooooooo`2booooo`03o`000?oooooooooo00Sooooo0009ooooo`03o`000?oo
oooooooo0;;ooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`2booooo`03o`000?oo
oooooooo00Sooooo0009ooooo`03o`000?oooooooooo0;;ooooo00?o0000ooooooooool03oooool0
0ol0003oooooooooo`2booooo`03o`000?oooooooooo00Sooooo0009ooooo`03o`000?oooooooooo
0;;ooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`2booooo`03o`000?oooooooooo
00Sooooo0009ooooo`03o`000?oooooooooo0;;ooooo00?o0000ooooooooool03oooool00ol0003o
ooooooooo`2booooo`03o`000?oooooooooo00Sooooo0009ooooo`03o`000?oooooooooo05Sooooo
0P3oO`1Hooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool0F?ooool20?mo05Sooooo
00?o0000ooooooooool02?ooool000Wooooo00?o0000ooooooooool0F?ooool20?mo05Sooooo00?o
0000ooooooooool03oooool00ol0003oooooooooo`1Hooooo`80ogl0F?ooool00ol0003ooooooooo
o`08ooooo`002Oooool00ol0003oooooooooo`2booooo`03o`000?oooooooooo00oooooo00?o0000
ooooooooool0/_ooool00ol0003oooooooooo`08ooooo`002Oooool00ol0003oooooooooo`2boooo
o`03o`000?oooooooooo00oooooo00?o0000ooooooooool0/_ooool00ol0003oooooooooo`08oooo
o`002Oooool00ol0003oooooooooo`2booooo`03o`000?oooooooooo00oooooo00?o0000oooooooo
ool0/_ooool00ol0003oooooooooo`08ooooo`002Oooool00ol0003oooooooooo`2booooo`03o`00
0?oooooooooo00oooooo00?o0000ooooooooool0/_ooool00ol0003oooooooooo`08ooooo`002Ooo
ool00ol0003oooooooooo`2booooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool0/_oo
ool00ol0003oooooooooo`08ooooo`002Oooool00ol0003oooooooooo`2booooo`03o`000?oooooo
oooo00oooooo00?o0000ooooooooool0/_ooool00ol0003oooooooooo`08ooooo`002Oooool00ol0
003oooooooooo`2booooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool0/_ooool00ol0
003oooooooooo`08ooooo`002Oooool00ol0003oooooooooo`2booooo`03o`000?oooooooooo00oo
oooo00?o0000ooooooooool0/_ooool00ol0003oooooooooo`08ooooo`002Oooool00ol0003ooooo
ooooo`2booooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool0/_ooool00ol0003ooooo
ooooo`08ooooo`002Oooool00ol0003oooooooooo`2booooo`03o`000?oooooooooo00oooooo00?o
0000ooooooooool0/_ooool00ol0003oooooooooo`08ooooo`002Oooool00ol0003oooooooooo`2b
ooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool0/_ooool00ol0003oooooooooo`08
ooooo`002Oooool00ol0003oooooooooo`2booooo`03o`000?oooooooooo00oooooo00?o0000oooo
ooooool0/_ooool00ol0003oooooooooo`08ooooo`002Oooool00ol0003oooooooooo`2booooo`03
o`000?oooooooooo00oooooo00?o0000ooooooooool0/_ooool00ol0003oooooooooo`08ooooo`00
2Ooooonfo`00017ooooo]_l0000:ooooo`00oooooonAooooo`00oooooonAooooo`00oooooonAoooo
o`00oooooonAooooo`00oooooonAooooo`00oooooonAooooo`00oooooonAooooo`00oooooonAoooo
o`00oooooonAooooo`00\
\>"],
  ImageRangeCache->{{{0, 399}, {399, 0}} -> {-0.0500105, -0.0500105, \
0.00526322, 0.00526322}, {{9.5, 190.438}, {389.5, 208.5}} -> {-1.15081, \
-1.15117, 0.0115117, 0.0115117}, {{208.5, 389.438}, {389.5, 208.5}} -> \
{-1.09771, -0.0754011, 0.0052648, 0.0052648}, {{9.5, 190.438}, {190.438, \
9.5}} -> {-1.11761, -3.34306, 0.0111796, 0.0111796}, {{208.5, 389.438}, \
{190.438, 9.5}} -> {-3.34236, -3.34306, 0.0111796, 0.0111796}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
%%ImageSize: 400 400 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.47619 0.0238095 0.47619 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.0238095 0.477324 0.477324 MathSubStart
%% ContourGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.480769 0.5 0.480769 [
[ 0 0 -0.125 0 ]
[ 0 0 -0.125 0 ]
[ 0 1 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
0 0 m
1 0 L
s
0 0 m
0 1 L
s
0 1 m
1 1 L
s
1 0 m
1 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
.01923 .98077 m
.98077 .98077 L
.98077 .01923 L
.01923 .01923 L
F
.5 Mabswid
.1 g
.01923 .14789 m
.02076 .15385 L
.02872 .17308 L
.03846 .18928 L
.04079 .19231 L
.05562 .21154 L
.05769 .21419 L
.07306 .23077 L
.07692 .2348 L
.09275 .25 L
.09615 .25296 L
.11457 .26923 L
.11538 .26979 L
.13462 .28479 L
.13927 .28846 L
.15385 .29805 L
.16669 .30769 L
.17308 .31081 L
.19231 .32393 L
.19675 .32692 L
.21154 .33398 L
.23066 .34615 L
.23077 .34621 L
.25 .35437 L
.26923 .36502 L
.26994 .36538 L
.28846 .37164 L
.30769 .3803 L
.31809 .38462 L
.32692 .3865 L
.34615 .39214 L
.36538 .39757 L
.38462 .40168 L
.40089 .40385 L
.40385 .40404 L
.42308 .4044 L
.43173 .40385 L
.44231 .40217 L
.46154 .39533 L
.47331 .38462 L
.48017 .36538 L
.4781 .34615 L
.47064 .32692 L
.46154 .30978 L
.45991 .30769 L
.44559 .28846 L
.44231 .28417 L
.42874 .26923 L
.42308 .26317 L
.40955 .25 L
.40385 .24484 L
.38809 .23077 L
.38462 .22817 L
.36538 .21228 L
.36446 .21154 L
.34615 .19884 L
.3375 .19231 L
.32692 .18644 L
.30826 .17308 L
.30769 .1729 L
.28846 .16256 L
.27494 .15385 L
.26923 .15204 L
.25 .14186 L
.23713 .13462 L
.23077 .13296 L
.21154 .12457 L
.19231 .11563 L
.19174 .11538 L
.17308 .11032 L
.15385 .10379 L
.13462 .09815 L
.12706 .09615 L
.11538 .09464 L
.09615 .09233 L
.07692 .0915 L
.05769 .09316 L
.04503 .09615 L
.03846 .09912 L
.02175 .11538 L
.01923 .12157 L
F
0 g
.01923 .14789 m
.02076 .15385 L
.02872 .17308 L
.03846 .18928 L
.04079 .19231 L
.05562 .21154 L
.05769 .21419 L
.07306 .23077 L
.07692 .2348 L
.09275 .25 L
.09615 .25296 L
.11457 .26923 L
.11538 .26979 L
.13462 .28479 L
.13927 .28846 L
.15385 .29805 L
.16669 .30769 L
.17308 .31081 L
.19231 .32393 L
.19675 .32692 L
.21154 .33398 L
.23066 .34615 L
.23077 .34621 L
.25 .35437 L
.26923 .36502 L
.26994 .36538 L
.28846 .37164 L
.30769 .3803 L
.31809 .38462 L
.32692 .3865 L
.34615 .39214 L
.36538 .39757 L
.38462 .40168 L
.40089 .40385 L
.40385 .40404 L
.42308 .4044 L
.43173 .40385 L
.44231 .40217 L
.46154 .39533 L
.47331 .38462 L
.48017 .36538 L
.4781 .34615 L
.47064 .32692 L
.46154 .30978 L
.45991 .30769 L
.44559 .28846 L
.44231 .28417 L
.42874 .26923 L
.42308 .26317 L
.40955 .25 L
Mistroke
.40385 .24484 L
.38809 .23077 L
.38462 .22817 L
.36538 .21228 L
.36446 .21154 L
.34615 .19884 L
.3375 .19231 L
.32692 .18644 L
.30826 .17308 L
.30769 .1729 L
.28846 .16256 L
.27494 .15385 L
.26923 .15204 L
.25 .14186 L
.23713 .13462 L
.23077 .13296 L
.21154 .12457 L
.19231 .11563 L
.19174 .11538 L
.17308 .11032 L
.15385 .10379 L
.13462 .09815 L
.12706 .09615 L
.11538 .09464 L
.09615 .09233 L
.07692 .0915 L
.05769 .09316 L
.04503 .09615 L
.03846 .09912 L
.02175 .11538 L
.01923 .12157 L
Mfstroke
.2 g
.07692 .12449 m
.09615 .11964 L
.11538 .11897 L
.13462 .1209 L
.15385 .12474 L
.17308 .12989 L
.19012 .13462 L
.19231 .13544 L
.21154 .14327 L
.23077 .15141 L
.23753 .15385 L
.25 .16037 L
.26923 .17048 L
.2751 .17308 L
.28846 .18134 L
.30731 .19231 L
.30769 .19257 L
.32692 .20613 L
.33517 .21154 L
.34615 .22002 L
.36002 .23077 L
.36538 .23531 L
.38186 .25 L
.38462 .25259 L
.4007 .26923 L
.40385 .2726 L
.41643 .28846 L
.42308 .29699 L
.42879 .30769 L
.437 .32692 L
.43905 .34615 L
.42901 .36538 L
.42308 .36966 L
.40385 .37564 L
.38462 .37664 L
.36538 .37492 L
.34615 .37135 L
.32692 .36675 L
.3211 .36538 L
.30769 .36069 L
.28846 .3531 L
.26976 .34615 L
.26923 .3459 L
.25 .33612 L
.23077 .32704 L
.23048 .32692 L
.21154 .31545 L
.1974 .30769 L
.19231 .3043 L
.17308 .29124 L
.16858 .28846 L
.15385 .27725 L
.14313 .26923 L
.13462 .26214 L
.12063 .25 L
.11538 .24516 L
.1011 .23077 L
.09615 .22557 L
.08464 .21154 L
.07692 .20174 L
.07142 .19231 L
.06213 .17308 L
.05841 .15385 L
.06456 .13462 L
F
0 g
.07692 .12449 m
.09615 .11964 L
.11538 .11897 L
.13462 .1209 L
.15385 .12474 L
.17308 .12989 L
.19012 .13462 L
.19231 .13544 L
.21154 .14327 L
.23077 .15141 L
.23753 .15385 L
.25 .16037 L
.26923 .17048 L
.2751 .17308 L
.28846 .18134 L
.30731 .19231 L
.30769 .19257 L
.32692 .20613 L
.33517 .21154 L
.34615 .22002 L
.36002 .23077 L
.36538 .23531 L
.38186 .25 L
.38462 .25259 L
.4007 .26923 L
.40385 .2726 L
.41643 .28846 L
.42308 .29699 L
.42879 .30769 L
.437 .32692 L
.43905 .34615 L
.42901 .36538 L
.42308 .36966 L
.40385 .37564 L
.38462 .37664 L
.36538 .37492 L
.34615 .37135 L
.32692 .36675 L
.3211 .36538 L
.30769 .36069 L
.28846 .3531 L
.26976 .34615 L
.26923 .3459 L
.25 .33612 L
.23077 .32704 L
.23048 .32692 L
.21154 .31545 L
.1974 .30769 L
.19231 .3043 L
.17308 .29124 L
Mistroke
.16858 .28846 L
.15385 .27725 L
.14313 .26923 L
.13462 .26214 L
.12063 .25 L
.11538 .24516 L
.1011 .23077 L
.09615 .22557 L
.08464 .21154 L
.07692 .20174 L
.07142 .19231 L
.06213 .17308 L
.05841 .15385 L
.06456 .13462 L
.07692 .12449 L
Mfstroke
.3 g
.09615 .14111 m
.11538 .13705 L
.13462 .13642 L
.15385 .13858 L
.17308 .1428 L
.19231 .14849 L
.20891 .15385 L
.21154 .15492 L
.23077 .16328 L
.25 .17202 L
.25249 .17308 L
.26923 .18234 L
.28729 .19231 L
.28846 .19304 L
.30769 .20571 L
.31667 .21154 L
.32692 .2191 L
.34219 .23077 L
.34615 .23403 L
.36419 .25 L
.36538 .2511 L
.38274 .26923 L
.38462 .2711 L
.39765 .28846 L
.40385 .29348 L
.40841 .30769 L
.41342 .32692 L
.40778 .34615 L
.40385 .35095 L
.38462 .3583 L
.36538 .35929 L
.34615 .35733 L
.32692 .35334 L
.30769 .34806 L
.30099 .34615 L
.28846 .34141 L
.26923 .33329 L
.25411 .32692 L
.25 .32483 L
.23077 .31447 L
.21783 .30769 L
.21154 .30382 L
.19231 .29153 L
.18735 .28846 L
.17308 .27814 L
.16104 .26923 L
.15385 .26342 L
.13827 .25 L
.13462 .24668 L
.11893 .23077 L
.11538 .22715 L
.10315 .21154 L
.09615 .2036 L
.09134 .19231 L
.08479 .17308 L
.08708 .15385 L
F
0 g
.09615 .14111 m
.11538 .13705 L
.13462 .13642 L
.15385 .13858 L
.17308 .1428 L
.19231 .14849 L
.20891 .15385 L
.21154 .15492 L
.23077 .16328 L
.25 .17202 L
.25249 .17308 L
.26923 .18234 L
.28729 .19231 L
.28846 .19304 L
.30769 .20571 L
.31667 .21154 L
.32692 .2191 L
.34219 .23077 L
.34615 .23403 L
.36419 .25 L
.36538 .2511 L
.38274 .26923 L
.38462 .2711 L
.39765 .28846 L
.40385 .29348 L
.40841 .30769 L
.41342 .32692 L
.40778 .34615 L
.40385 .35095 L
.38462 .3583 L
.36538 .35929 L
.34615 .35733 L
.32692 .35334 L
.30769 .34806 L
.30099 .34615 L
.28846 .34141 L
.26923 .33329 L
.25411 .32692 L
.25 .32483 L
.23077 .31447 L
.21783 .30769 L
.21154 .30382 L
.19231 .29153 L
.18735 .28846 L
.17308 .27814 L
.16104 .26923 L
.15385 .26342 L
.13827 .25 L
.13462 .24668 L
.11893 .23077 L
Mistroke
.11538 .22715 L
.10315 .21154 L
.09615 .2036 L
.09134 .19231 L
.08479 .17308 L
.08708 .15385 L
.09615 .14111 L
Mfstroke
.4 g
.13462 .15051 m
.15385 .15058 L
.17308 .15342 L
.17565 .15385 L
.19231 .15832 L
.21154 .1649 L
.23077 .17241 L
.23246 .17308 L
.25 .18155 L
.26923 .19151 L
.27079 .19231 L
.28846 .20306 L
.30186 .21154 L
.30769 .21559 L
.32692 .22988 L
.32807 .23077 L
.34615 .24623 L
.35016 .25 L
.36538 .26553 L
.36844 .26923 L
.38256 .28846 L
.38462 .29203 L
.3914 .30769 L
.39203 .32692 L
.38462 .3373 L
.36538 .34516 L
.34615 .34533 L
.32692 .34269 L
.30769 .3379 L
.28846 .33158 L
.27547 .32692 L
.26923 .3242 L
.25 .31515 L
.23483 .30769 L
.23077 .30542 L
.21154 .29397 L
.20246 .28846 L
.19231 .28156 L
.17522 .26923 L
.17308 .26759 L
.15385 .25148 L
.15221 .25 L
.13462 .23256 L
.13306 .23077 L
.11796 .21154 L
.11538 .20748 L
.10779 .19231 L
.10476 .17308 L
.11538 .15667 L
.12085 .15385 L
F
0 g
.13462 .15051 m
.15385 .15058 L
.17308 .15342 L
.17565 .15385 L
.19231 .15832 L
.21154 .1649 L
.23077 .17241 L
.23246 .17308 L
.25 .18155 L
.26923 .19151 L
.27079 .19231 L
.28846 .20306 L
.30186 .21154 L
.30769 .21559 L
.32692 .22988 L
.32807 .23077 L
.34615 .24623 L
.35016 .25 L
.36538 .26553 L
.36844 .26923 L
.38256 .28846 L
.38462 .29203 L
.3914 .30769 L
.39203 .32692 L
.38462 .3373 L
.36538 .34516 L
.34615 .34533 L
.32692 .34269 L
.30769 .3379 L
.28846 .33158 L
.27547 .32692 L
.26923 .3242 L
.25 .31515 L
.23483 .30769 L
.23077 .30542 L
.21154 .29397 L
.20246 .28846 L
.19231 .28156 L
.17522 .26923 L
.17308 .26759 L
.15385 .25148 L
.15221 .25 L
.13462 .23256 L
.13306 .23077 L
.11796 .21154 L
.11538 .20748 L
.10779 .19231 L
.10476 .17308 L
.11538 .15667 L
.12085 .15385 L
Mistroke
.13462 .15051 L
Mfstroke
.5 g
.13462 .16338 m
.15385 .16153 L
.17308 .16323 L
.19231 .16737 L
.21135 .17308 L
.21154 .17317 L
.23077 .18073 L
.25 .18963 L
.25556 .19231 L
.26923 .19983 L
.28846 .2114 L
.28869 .21154 L
.30769 .22472 L
.31571 .23077 L
.32692 .23977 L
.33806 .25 L
.34615 .25733 L
.35599 .26923 L
.36538 .27831 L
.36902 .28846 L
.37545 .30769 L
.36757 .32692 L
.36538 .32864 L
.34615 .33376 L
.32692 .33266 L
.30769 .32888 L
.29908 .32692 L
.28846 .32325 L
.26923 .31581 L
.25086 .30769 L
.25 .30726 L
.23077 .29704 L
.21593 .28846 L
.21154 .28571 L
.19231 .27257 L
.18771 .26923 L
.17308 .25771 L
.16435 .25 L
.15385 .2404 L
.14542 .23077 L
.13462 .21873 L
.13118 .21154 L
.12297 .19231 L
.12555 .17308 L
F
0 g
.13462 .16338 m
.15385 .16153 L
.17308 .16323 L
.19231 .16737 L
.21135 .17308 L
.21154 .17317 L
.23077 .18073 L
.25 .18963 L
.25556 .19231 L
.26923 .19983 L
.28846 .2114 L
.28869 .21154 L
.30769 .22472 L
.31571 .23077 L
.32692 .23977 L
.33806 .25 L
.34615 .25733 L
.35599 .26923 L
.36538 .27831 L
.36902 .28846 L
.37545 .30769 L
.36757 .32692 L
.36538 .32864 L
.34615 .33376 L
.32692 .33266 L
.30769 .32888 L
.29908 .32692 L
.28846 .32325 L
.26923 .31581 L
.25086 .30769 L
.25 .30726 L
.23077 .29704 L
.21593 .28846 L
.21154 .28571 L
.19231 .27257 L
.18771 .26923 L
.17308 .25771 L
.16435 .25 L
.15385 .2404 L
.14542 .23077 L
.13462 .21873 L
.13118 .21154 L
.12297 .19231 L
.12555 .17308 L
.13462 .16338 L
s
.6 g
.15385 .17502 m
.17308 .17314 L
.19231 .17566 L
.21154 .18107 L
.23077 .18836 L
.24018 .19231 L
.25 .19702 L
.26923 .20749 L
.27614 .21154 L
.28846 .21933 L
.30431 .23077 L
.30769 .23311 L
.3269 .25 L
.32692 .25001 L
.34441 .26923 L
.34615 .27162 L
.35609 .28846 L
.35891 .30769 L
.34615 .31981 L
.32692 .32367 L
.30769 .3205 L
.28846 .31523 L
.26923 .30825 L
.26778 .30769 L
.25 .29969 L
.23077 .28948 L
.22894 .28846 L
.21154 .27775 L
.19928 .26923 L
.19231 .26431 L
.1755 .25 L
.17308 .24857 L
.15682 .23077 L
.15385 .22701 L
.14368 .21154 L
.13835 .19231 L
F
0 g
.15385 .17502 m
.17308 .17314 L
.19231 .17566 L
.21154 .18107 L
.23077 .18836 L
.24018 .19231 L
.25 .19702 L
.26923 .20749 L
.27614 .21154 L
.28846 .21933 L
.30431 .23077 L
.30769 .23311 L
.3269 .25 L
.32692 .25001 L
.34441 .26923 L
.34615 .27162 L
.35609 .28846 L
.35891 .30769 L
.34615 .31981 L
.32692 .32367 L
.30769 .3205 L
.28846 .31523 L
.26923 .30825 L
.26778 .30769 L
.25 .29969 L
.23077 .28948 L
.22894 .28846 L
.21154 .27775 L
.19928 .26923 L
.19231 .26431 L
.1755 .25 L
.17308 .24857 L
.15682 .23077 L
.15385 .22701 L
.14368 .21154 L
.13835 .19231 L
.15385 .17502 L
s
.7 g
.17308 .18111 m
.19231 .18417 L
.21154 .18901 L
.22351 .19231 L
.23077 .19545 L
.25 .20433 L
.26355 .21154 L
.26923 .21461 L
.28846 .22735 L
.2931 .23077 L
.30769 .24172 L
.31606 .25 L
.32692 .25751 L
.33301 .26923 L
.34284 .28846 L
.33594 .30769 L
.32692 .31196 L
.30769 .3114 L
.29028 .30769 L
.28846 .30736 L
.26923 .30109 L
.25 .29234 L
.2422 .28846 L
.23077 .28236 L
.21154 .2698 L
.21073 .26923 L
.19231 .25551 L
.18636 .25 L
.17308 .23854 L
.16803 .23077 L
.15635 .21154 L
.15706 .19231 L
F
0 g
.17308 .18111 m
.19231 .18417 L
.21154 .18901 L
.22351 .19231 L
.23077 .19545 L
.25 .20433 L
.26355 .21154 L
.26923 .21461 L
.28846 .22735 L
.2931 .23077 L
.30769 .24172 L
.31606 .25 L
.32692 .25751 L
.33301 .26923 L
.34284 .28846 L
.33594 .30769 L
.32692 .31196 L
.30769 .3114 L
.29028 .30769 L
.28846 .30736 L
.26923 .30109 L
.25 .29234 L
.2422 .28846 L
.23077 .28236 L
.21154 .2698 L
.21073 .26923 L
.19231 .25551 L
.18636 .25 L
.17308 .23854 L
.16803 .23077 L
.15635 .21154 L
.15706 .19231 L
.17308 .18111 L
s
.8 g
.17308 .20181 m
.19231 .19484 L
.21154 .19477 L
.23077 .20283 L
.24954 .21154 L
.25 .21168 L
.26923 .22201 L
.28172 .23077 L
.28846 .23286 L
.30506 .25 L
.30769 .25283 L
.32134 .26923 L
.32692 .28454 L
.32703 .28846 L
.32692 .28895 L
.30769 .30072 L
.28846 .30057 L
.26923 .29331 L
.25628 .28846 L
.25 .2859 L
.23077 .27467 L
.22244 .26923 L
.21154 .2634 L
.1973 .25 L
.19231 .24506 L
.1794 .23077 L
.17308 .21922 L
.17058 .21154 L
F
0 g
.17308 .20181 m
.19231 .19484 L
.21154 .19477 L
.23077 .20283 L
.24954 .21154 L
.25 .21168 L
.26923 .22201 L
.28172 .23077 L
.28846 .23286 L
.30506 .25 L
.30769 .25283 L
.32134 .26923 L
.32692 .28454 L
.32703 .28846 L
.32692 .28895 L
.30769 .30072 L
.28846 .30057 L
.26923 .29331 L
.25628 .28846 L
.25 .2859 L
.23077 .27467 L
.22244 .26923 L
.21154 .2634 L
.1973 .25 L
.19231 .24506 L
.1794 .23077 L
.17308 .21922 L
.17058 .21154 L
.17308 .20181 L
s
.9 g
.19231 .2099 m
.21154 .20493 L
.22939 .21154 L
.23077 .21201 L
.25 .2165 L
.26892 .23077 L
.26923 .23131 L
.28846 .24353 L
.293 .25 L
.30737 .26923 L
.29815 .28846 L
.28846 .28875 L
.2866 .28846 L
.26923 .28435 L
.25 .2784 L
.23457 .26923 L
.23077 .26576 L
.21154 .25225 L
.20955 .25 L
.19243 .23077 L
.19231 .23007 L
.19045 .21154 L
F
0 g
.19231 .2099 m
.21154 .20493 L
.22939 .21154 L
.23077 .21201 L
.25 .2165 L
.26892 .23077 L
.26923 .23131 L
.28846 .24353 L
.293 .25 L
.30737 .26923 L
.29815 .28846 L
.28846 .28875 L
.2866 .28846 L
.26923 .28435 L
.25 .2784 L
.23457 .26923 L
.23077 .26576 L
.21154 .25225 L
.20955 .25 L
.19243 .23077 L
.19231 .23007 L
.19045 .21154 L
.19231 .2099 L
s
1 g
.21154 .22562 m
.23077 .22325 L
.25 .23024 L
.25095 .23077 L
.26923 .2428 L
.28153 .25 L
.287 .26923 L
.26923 .27299 L
.25677 .26923 L
.25 .26621 L
.23077 .25463 L
.22268 .25 L
.21154 .23356 L
.20994 .23077 L
F
0 g
.21154 .22562 m
.23077 .22325 L
.25 .23024 L
.25095 .23077 L
.26923 .2428 L
.28153 .25 L
.287 .26923 L
.26923 .27299 L
.25677 .26923 L
.25 .26621 L
.23077 .25463 L
.22268 .25 L
.21154 .23356 L
.20994 .23077 L
.21154 .22562 L
s
.1 g
.71154 .47743 m
.73077 .4729 L
.75 .46899 L
.76923 .46605 L
.78846 .46427 L
.80769 .46383 L
.82692 .46497 L
.84615 .46812 L
.86538 .47403 L
.8789 .48077 L
.88462 .4846 L
.8992 .5 L
.90385 .50856 L
.90729 .51923 L
.90866 .53846 L
.90544 .55769 L
.90385 .56475 L
.89845 .57692 L
.88839 .59615 L
.88462 .6025 L
.87553 .61538 L
.86538 .62859 L
.86018 .63462 L
.84615 .64995 L
.84229 .65385 L
.82692 .66847 L
.82179 .67308 L
.80769 .68493 L
.79861 .69231 L
.78846 .69982 L
.77265 .71154 L
.76923 .71371 L
.75 .72641 L
.74331 .73077 L
.73077 .73778 L
.71154 .74913 L
.71001 .75 L
.69231 .75855 L
.67308 .76834 L
.67126 .76923 L
.65385 .77616 L
.63462 .78428 L
.62414 .78846 L
.61538 .79107 L
.59615 .79712 L
.57692 .80286 L
.5581 .80769 L
.55769 .80776 L
.53846 .81109 L
.51923 .81379 L
.5 .81551 L
.48077 .81597 L
.46154 .81487 L
.44231 .8118 L
.42764 .80769 L
.42308 .80589 L
.40385 .79509 L
.39645 .78846 L
.38462 .77089 L
.38408 .76923 L
.38014 .75 L
.38152 .73077 L
.38462 .71813 L
.38689 .71154 L
.39575 .69231 L
.40385 .67808 L
.40728 .67308 L
.42155 .65385 L
.42308 .65191 L
.43845 .63462 L
.44231 .63053 L
.45779 .61538 L
.46154 .61196 L
.47964 .59615 L
.48077 .59526 L
.5 .58025 L
.50439 .57692 L
.51923 .56673 L
.53224 .55769 L
.53846 .55406 L
.55769 .54209 L
.56361 .53846 L
.57692 .53166 L
.59615 .52107 L
.59962 .51923 L
.61538 .51241 L
.63462 .50349 L
.64248 .5 L
.65385 .49614 L
.67308 .48914 L
.69231 .48248 L
.69766 .48077 L
F
0 g
.71154 .47743 m
.73077 .4729 L
.75 .46899 L
.76923 .46605 L
.78846 .46427 L
.80769 .46383 L
.82692 .46497 L
.84615 .46812 L
.86538 .47403 L
.8789 .48077 L
.88462 .4846 L
.8992 .5 L
.90385 .50856 L
.90729 .51923 L
.90866 .53846 L
.90544 .55769 L
.90385 .56475 L
.89845 .57692 L
.88839 .59615 L
.88462 .6025 L
.87553 .61538 L
.86538 .62859 L
.86018 .63462 L
.84615 .64995 L
.84229 .65385 L
.82692 .66847 L
.82179 .67308 L
.80769 .68493 L
.79861 .69231 L
.78846 .69982 L
.77265 .71154 L
.76923 .71371 L
.75 .72641 L
.74331 .73077 L
.73077 .73778 L
.71154 .74913 L
.71001 .75 L
.69231 .75855 L
.67308 .76834 L
.67126 .76923 L
.65385 .77616 L
.63462 .78428 L
.62414 .78846 L
.61538 .79107 L
.59615 .79712 L
.57692 .80286 L
.5581 .80769 L
.55769 .80776 L
.53846 .81109 L
.51923 .81379 L
Mistroke
.5 .81551 L
.48077 .81597 L
.46154 .81487 L
.44231 .8118 L
.42764 .80769 L
.42308 .80589 L
.40385 .79509 L
.39645 .78846 L
.38462 .77089 L
.38408 .76923 L
.38014 .75 L
.38152 .73077 L
.38462 .71813 L
.38689 .71154 L
.39575 .69231 L
.40385 .67808 L
.40728 .67308 L
.42155 .65385 L
.42308 .65191 L
.43845 .63462 L
.44231 .63053 L
.45779 .61538 L
.46154 .61196 L
.47964 .59615 L
.48077 .59526 L
.5 .58025 L
.50439 .57692 L
.51923 .56673 L
.53224 .55769 L
.53846 .55406 L
.55769 .54209 L
.56361 .53846 L
.57692 .53166 L
.59615 .52107 L
.59962 .51923 L
.61538 .51241 L
.63462 .50349 L
.64248 .5 L
.65385 .49614 L
.67308 .48914 L
.69231 .48248 L
.69766 .48077 L
.71154 .47743 L
Mfstroke
.2 g
.75 .49778 m
.76923 .49655 L
.78846 .49698 L
.80769 .49964 L
.80946 .5 L
.82692 .50571 L
.84615 .51869 L
.84665 .51923 L
.85781 .53846 L
.85973 .55769 L
.85589 .57692 L
.84781 .59615 L
.84615 .59948 L
.83604 .61538 L
.82692 .62776 L
.82111 .63462 L
.80769 .64927 L
.80307 .65385 L
.78846 .66739 L
.78186 .67308 L
.76923 .68323 L
.7573 .69231 L
.75 .69739 L
.73077 .71036 L
.72895 .71154 L
.71154 .72177 L
.69572 .73077 L
.69231 .73244 L
.67308 .74187 L
.65567 .75 L
.65385 .75071 L
.63462 .75816 L
.61538 .76514 L
.60282 .76923 L
.59615 .77099 L
.57692 .77572 L
.55769 .77958 L
.53846 .78226 L
.51923 .78351 L
.5 .78303 L
.48077 .78027 L
.46154 .77408 L
.45251 .76923 L
.44231 .76166 L
.43444 .75 L
.42913 .73077 L
.43069 .71154 L
.43705 .69231 L
.44231 .68068 L
.44722 .67308 L
.46074 .65385 L
.46154 .65282 L
.47749 .63462 L
.48077 .63118 L
.49728 .61538 L
.5 .61297 L
.51923 .59698 L
.52028 .59615 L
.53846 .58286 L
.54697 .57692 L
.55769 .57012 L
.57692 .55824 L
.57785 .55769 L
.59615 .54793 L
.61451 .53846 L
.61538 .53808 L
.63462 .52973 L
.65385 .52176 L
.66041 .51923 L
.67308 .51513 L
.69231 .50927 L
.71154 .50424 L
.73077 .5003 L
.73161 .5 L
F
0 g
.75 .49778 m
.76923 .49655 L
.78846 .49698 L
.80769 .49964 L
.80946 .5 L
.82692 .50571 L
.84615 .51869 L
.84665 .51923 L
.85781 .53846 L
.85973 .55769 L
.85589 .57692 L
.84781 .59615 L
.84615 .59948 L
.83604 .61538 L
.82692 .62776 L
.82111 .63462 L
.80769 .64927 L
.80307 .65385 L
.78846 .66739 L
.78186 .67308 L
.76923 .68323 L
.7573 .69231 L
.75 .69739 L
.73077 .71036 L
.72895 .71154 L
.71154 .72177 L
.69572 .73077 L
.69231 .73244 L
.67308 .74187 L
.65567 .75 L
.65385 .75071 L
.63462 .75816 L
.61538 .76514 L
.60282 .76923 L
.59615 .77099 L
.57692 .77572 L
.55769 .77958 L
.53846 .78226 L
.51923 .78351 L
.5 .78303 L
.48077 .78027 L
.46154 .77408 L
.45251 .76923 L
.44231 .76166 L
.43444 .75 L
.42913 .73077 L
.43069 .71154 L
.43705 .69231 L
.44231 .68068 L
.44722 .67308 L
Mistroke
.46074 .65385 L
.46154 .65282 L
.47749 .63462 L
.48077 .63118 L
.49728 .61538 L
.5 .61297 L
.51923 .59698 L
.52028 .59615 L
.53846 .58286 L
.54697 .57692 L
.55769 .57012 L
.57692 .55824 L
.57785 .55769 L
.59615 .54793 L
.61451 .53846 L
.61538 .53808 L
.63462 .52973 L
.65385 .52176 L
.66041 .51923 L
.67308 .51513 L
.69231 .50927 L
.71154 .50424 L
.73077 .5003 L
.73161 .5 L
.75 .49778 L
Mfstroke
.3 g
.73077 .51874 m
.75 .5173 L
.76923 .51778 L
.78031 .51923 L
.78846 .52099 L
.80769 .52866 L
.81897 .53846 L
.82692 .55328 L
.82798 .55769 L
.82763 .57692 L
.82692 .58022 L
.82142 .59615 L
.81075 .61538 L
.80769 .62006 L
.7962 .63462 L
.78846 .64337 L
.77803 .65385 L
.76923 .662 L
.75617 .67308 L
.75 .67791 L
.73077 .69196 L
.73027 .69231 L
.71154 .70427 L
.69936 .71154 L
.69231 .71534 L
.67308 .72526 L
.66154 .73077 L
.65385 .73402 L
.63462 .7417 L
.61538 .74847 L
.61064 .75 L
.59615 .75389 L
.57692 .75821 L
.55769 .76125 L
.53846 .76272 L
.51923 .76221 L
.5 .75894 L
.48077 .7508 L
.47955 .75 L
.4633 .73077 L
.46154 .72525 L
.46023 .71154 L
.46154 .70167 L
.46409 .69231 L
.47294 .67308 L
.48077 .66023 L
.48581 .65385 L
.5 .63706 L
.50237 .63462 L
.51923 .61833 L
.5226 .61538 L
.53846 .60239 L
.5467 .59615 L
.55769 .58844 L
.57523 .57692 L
.57692 .57592 L
.59615 .56489 L
.60964 .55769 L
.61538 .55496 L
.63462 .54619 L
.65341 .53846 L
.65385 .53831 L
.67308 .53182 L
.69231 .52622 L
.71154 .52179 L
.72558 .51923 L
F
0 g
.73077 .51874 m
.75 .5173 L
.76923 .51778 L
.78031 .51923 L
.78846 .52099 L
.80769 .52866 L
.81897 .53846 L
.82692 .55328 L
.82798 .55769 L
.82763 .57692 L
.82692 .58022 L
.82142 .59615 L
.81075 .61538 L
.80769 .62006 L
.7962 .63462 L
.78846 .64337 L
.77803 .65385 L
.76923 .662 L
.75617 .67308 L
.75 .67791 L
.73077 .69196 L
.73027 .69231 L
.71154 .70427 L
.69936 .71154 L
.69231 .71534 L
.67308 .72526 L
.66154 .73077 L
.65385 .73402 L
.63462 .7417 L
.61538 .74847 L
.61064 .75 L
.59615 .75389 L
.57692 .75821 L
.55769 .76125 L
.53846 .76272 L
.51923 .76221 L
.5 .75894 L
.48077 .7508 L
.47955 .75 L
.4633 .73077 L
.46154 .72525 L
.46023 .71154 L
.46154 .70167 L
.46409 .69231 L
.47294 .67308 L
.48077 .66023 L
.48581 .65385 L
.5 .63706 L
.50237 .63462 L
.51923 .61833 L
Mistroke
.5226 .61538 L
.53846 .60239 L
.5467 .59615 L
.55769 .58844 L
.57523 .57692 L
.57692 .57592 L
.59615 .56489 L
.60964 .55769 L
.61538 .55496 L
.63462 .54619 L
.65341 .53846 L
.65385 .53831 L
.67308 .53182 L
.69231 .52622 L
.71154 .52179 L
.72558 .51923 L
.73077 .51874 L
Mfstroke
.4 g
.71154 .53616 m
.73077 .53408 L
.75 .53407 L
.76923 .53712 L
.77406 .53846 L
.78846 .54455 L
.7993 .55769 L
.80382 .57692 L
.79994 .59615 L
.79044 .61538 L
.78846 .61876 L
.77635 .63462 L
.76923 .64279 L
.75806 .65385 L
.75 .66118 L
.73546 .67308 L
.73077 .67661 L
.71154 .68999 L
.70794 .69231 L
.69231 .70161 L
.6739 .71154 L
.67308 .71194 L
.65385 .7208 L
.63462 .72859 L
.62871 .73077 L
.61538 .73499 L
.59615 .74015 L
.57692 .74392 L
.55769 .746 L
.53846 .74597 L
.51923 .74297 L
.5 .73415 L
.49621 .73077 L
.48569 .71154 L
.48642 .69231 L
.49365 .67308 L
.5 .66085 L
.50579 .65385 L
.51923 .63762 L
.52224 .63462 L
.53846 .61915 L
.54292 .61538 L
.55769 .60369 L
.56818 .59615 L
.57692 .59034 L
.59615 .57857 L
.59904 .57692 L
.61538 .56837 L
.63462 .55931 L
.63831 .55769 L
.65385 .55166 L
.67308 .54513 L
.69231 .53989 L
.69727 .53846 L
F
0 g
.71154 .53616 m
.73077 .53408 L
.75 .53407 L
.76923 .53712 L
.77406 .53846 L
.78846 .54455 L
.7993 .55769 L
.80382 .57692 L
.79994 .59615 L
.79044 .61538 L
.78846 .61876 L
.77635 .63462 L
.76923 .64279 L
.75806 .65385 L
.75 .66118 L
.73546 .67308 L
.73077 .67661 L
.71154 .68999 L
.70794 .69231 L
.69231 .70161 L
.6739 .71154 L
.67308 .71194 L
.65385 .7208 L
.63462 .72859 L
.62871 .73077 L
.61538 .73499 L
.59615 .74015 L
.57692 .74392 L
.55769 .746 L
.53846 .74597 L
.51923 .74297 L
.5 .73415 L
.49621 .73077 L
.48569 .71154 L
.48642 .69231 L
.49365 .67308 L
.5 .66085 L
.50579 .65385 L
.51923 .63762 L
.52224 .63462 L
.53846 .61915 L
.54292 .61538 L
.55769 .60369 L
.56818 .59615 L
.57692 .59034 L
.59615 .57857 L
.59904 .57692 L
.61538 .56837 L
.63462 .55931 L
.63831 .55769 L
Mistroke
.65385 .55166 L
.67308 .54513 L
.69231 .53989 L
.69727 .53846 L
.71154 .53616 L
Mfstroke
.5 g
.67308 .55696 m
.69231 .55223 L
.71154 .5492 L
.73077 .54833 L
.75 .55055 L
.76735 .55769 L
.76923 .55923 L
.78108 .57692 L
.78042 .59615 L
.77238 .61538 L
.76923 .62149 L
.75885 .63462 L
.75 .64479 L
.74041 .65385 L
.73077 .66235 L
.7169 .67308 L
.71154 .67691 L
.69231 .68938 L
.68732 .69231 L
.67308 .70003 L
.65385 .70922 L
.6485 .71154 L
.63462 .71688 L
.61538 .72316 L
.59615 .72791 L
.57766 .73077 L
.57692 .73085 L
.55769 .7316 L
.54724 .73077 L
.53846 .72938 L
.51923 .7227 L
.51111 .71154 L
.50704 .69231 L
.5122 .67308 L
.51923 .6601 L
.52344 .65385 L
.53846 .63577 L
.53975 .63462 L
.55769 .61799 L
.56097 .61538 L
.57692 .60335 L
.58769 .59615 L
.59615 .59092 L
.61538 .58016 L
.62179 .57692 L
.63462 .57102 L
.65385 .56326 L
.67047 .55769 L
F
0 g
.67308 .55696 m
.69231 .55223 L
.71154 .5492 L
.73077 .54833 L
.75 .55055 L
.76735 .55769 L
.76923 .55923 L
.78108 .57692 L
.78042 .59615 L
.77238 .61538 L
.76923 .62149 L
.75885 .63462 L
.75 .64479 L
.74041 .65385 L
.73077 .66235 L
.7169 .67308 L
.71154 .67691 L
.69231 .68938 L
.68732 .69231 L
.67308 .70003 L
.65385 .70922 L
.6485 .71154 L
.63462 .71688 L
.61538 .72316 L
.59615 .72791 L
.57766 .73077 L
.57692 .73085 L
.55769 .7316 L
.54724 .73077 L
.53846 .72938 L
.51923 .7227 L
.51111 .71154 L
.50704 .69231 L
.5122 .67308 L
.51923 .6601 L
.52344 .65385 L
.53846 .63577 L
.53975 .63462 L
.55769 .61799 L
.56097 .61538 L
.57692 .60335 L
.58769 .59615 L
.59615 .59092 L
.61538 .58016 L
.62179 .57692 L
.63462 .57102 L
.65385 .56326 L
.67047 .55769 L
.67308 .55696 L
s
.6 g
.65385 .57427 m
.67308 .5682 L
.69231 .56397 L
.71154 .56197 L
.73077 .56281 L
.75 .56906 L
.75624 .57692 L
.76115 .59615 L
.75515 .61538 L
.75 .62831 L
.74234 .63462 L
.73077 .64786 L
.7237 .65385 L
.71154 .66414 L
.69899 .67308 L
.69231 .67752 L
.67308 .68883 L
.66635 .69231 L
.65385 .6982 L
.63462 .70595 L
.61676 .71154 L
.61538 .71188 L
.59615 .71603 L
.57692 .71796 L
.55769 .71671 L
.54129 .71154 L
.53846 .70868 L
.52801 .69231 L
.53011 .67308 L
.53846 .65644 L
.54016 .65385 L
.55628 .63462 L
.55769 .63315 L
.57692 .6163 L
.57821 .61538 L
.59615 .60268 L
.60697 .59615 L
.61538 .59145 L
.63462 .58195 L
.6466 .57692 L
F
0 g
.65385 .57427 m
.67308 .5682 L
.69231 .56397 L
.71154 .56197 L
.73077 .56281 L
.75 .56906 L
.75624 .57692 L
.76115 .59615 L
.75515 .61538 L
.75 .62831 L
.74234 .63462 L
.73077 .64786 L
.7237 .65385 L
.71154 .66414 L
.69899 .67308 L
.69231 .67752 L
.67308 .68883 L
.66635 .69231 L
.65385 .6982 L
.63462 .70595 L
.61676 .71154 L
.61538 .71188 L
.59615 .71603 L
.57692 .71796 L
.55769 .71671 L
.54129 .71154 L
.53846 .70868 L
.52801 .69231 L
.53011 .67308 L
.53846 .65644 L
.54016 .65385 L
.55628 .63462 L
.55769 .63315 L
.57692 .6163 L
.57821 .61538 L
.59615 .60268 L
.60697 .59615 L
.61538 .59145 L
.63462 .58195 L
.6466 .57692 L
.65385 .57427 L
s
.7 g
.69231 .57644 m
.71154 .57644 L
.71471 .57692 L
.73077 .58297 L
.74017 .59615 L
.73755 .61538 L
.73077 .62772 L
.72579 .63462 L
.71154 .65109 L
.70688 .65385 L
.69231 .66557 L
.68034 .67308 L
.67308 .67741 L
.65385 .68735 L
.64186 .69231 L
.63462 .69486 L
.61538 .70062 L
.59615 .70407 L
.57692 .70471 L
.55769 .69973 L
.55261 .69231 L
.54875 .67308 L
.55702 .65385 L
.55769 .65243 L
.57284 .63462 L
.57692 .63041 L
.59586 .61538 L
.59615 .61517 L
.61538 .60264 L
.62799 .59615 L
.63462 .59303 L
.65385 .58513 L
.67308 .57947 L
.68817 .57692 L
F
0 g
.69231 .57644 m
.71154 .57644 L
.71471 .57692 L
.73077 .58297 L
.74017 .59615 L
.73755 .61538 L
.73077 .62772 L
.72579 .63462 L
.71154 .65109 L
.70688 .65385 L
.69231 .66557 L
.68034 .67308 L
.67308 .67741 L
.65385 .68735 L
.64186 .69231 L
.63462 .69486 L
.61538 .70062 L
.59615 .70407 L
.57692 .70471 L
.55769 .69973 L
.55261 .69231 L
.54875 .67308 L
.55702 .65385 L
.55769 .65243 L
.57284 .63462 L
.57692 .63041 L
.59586 .61538 L
.59615 .61517 L
.61538 .60264 L
.62799 .59615 L
.63462 .59303 L
.65385 .58513 L
.67308 .57947 L
.68817 .57692 L
.69231 .57644 L
s
.8 g
.67308 .59204 m
.69231 .58994 L
.71062 .59615 L
.71154 .59683 L
.71781 .61538 L
.71154 .62921 L
.70797 .63462 L
.69231 .65059 L
.6886 .65385 L
.67308 .66585 L
.65834 .67308 L
.65385 .67526 L
.63462 .68358 L
.61538 .6893 L
.59615 .68902 L
.57692 .68276 L
.57066 .67308 L
.57542 .65385 L
.57692 .65138 L
.5907 .63462 L
.59615 .6288 L
.61538 .61561 L
.6157 .61538 L
.63462 .60427 L
.65385 .5968 L
.65751 .59615 L
F
0 g
.67308 .59204 m
.69231 .58994 L
.71062 .59615 L
.71154 .59683 L
.71781 .61538 L
.71154 .62921 L
.70797 .63462 L
.69231 .65059 L
.6886 .65385 L
.67308 .66585 L
.65834 .67308 L
.65385 .67526 L
.63462 .68358 L
.61538 .6893 L
.59615 .68902 L
.57692 .68276 L
.57066 .67308 L
.57542 .65385 L
.57692 .65138 L
.5907 .63462 L
.59615 .6288 L
.61538 .61561 L
.6157 .61538 L
.63462 .60427 L
.65385 .5968 L
.65751 .59615 L
.67308 .59204 L
s
.9 g
.65385 .61125 m
.67308 .60955 L
.6883 .61538 L
.687 .63462 L
.67308 .64745 L
.66684 .65385 L
.65385 .66364 L
.63462 .66771 L
.61538 .67049 L
.59933 .65385 L
.61309 .63462 L
.61538 .63283 L
.63462 .62019 L
.64507 .61538 L
F
0 g
.65385 .61125 m
.67308 .60955 L
.6883 .61538 L
.687 .63462 L
.67308 .64745 L
.66684 .65385 L
.65385 .66364 L
.63462 .66771 L
.61538 .67049 L
.59933 .65385 L
.61309 .63462 L
.61538 .63283 L
.63462 .62019 L
.64507 .61538 L
.65385 .61125 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.522676 0.0238095 0.97619 0.477324 MathSubStart
%% SurfaceGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.11022e-16 1.04977 -0.0679587 1.04977 [
[ 0 0 0 0 ]
[ 1 .81114 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.39787 .81114 L
s
.39787 .81114 m
.40529 .59895 L
s
.40529 .59895 m
.03716 .25514 L
s
.68874 0 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.68874 0 m
.03716 .25514 L
s
.40529 .59895 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.39787 .81114 L
s
.39787 .81114 m
.40529 .59895 L
s
0 0 m
1 0 L
1 .81114 L
0 .81114 L
closepath
clip
newpath
.664 .741 .908 r
.39902 .59803 .40512 .60371 .41537 .60064 .40929 .59494 Mtetra
.40929 .59494 .41537 .60064 .42565 .59755 .4196 .59183 Mtetra
.4196 .59183 .42565 .59755 .43597 .59446 .42994 .58871 Mtetra
.42994 .58871 .43597 .59446 .44633 .59135 .44033 .58558 Mtetra
.44033 .58558 .44633 .59135 .45674 .58823 .45076 .58244 Mtetra
.45076 .58244 .45674 .58823 .46718 .5851 .46122 .57928 Mtetra
.663 .741 .908 r
.46122 .57928 .46718 .5851 .47766 .58195 .47173 .57612 Mtetra
.47173 .57612 .47766 .58195 .48818 .5788 .48228 .57294 Mtetra
.48228 .57294 .48818 .5788 .49874 .57563 .49287 .56975 Mtetra
.49287 .56975 .49874 .57563 .50935 .57245 .5035 .56655 Mtetra
.5035 .56655 .50935 .57245 .51999 .56926 .51417 .56334 Mtetra
.663 .742 .908 r
.51417 .56334 .51999 .56926 .53068 .56605 .52489 .56011 Mtetra
.52489 .56011 .53068 .56605 .54141 .56284 .53564 .55688 Mtetra
.53564 .55688 .54141 .56284 .55218 .55961 .54644 .55363 Mtetra
.54644 .55363 .55218 .55961 .56299 .55636 .55728 .55036 Mtetra
.55728 .55036 .56299 .55636 .57385 .55311 .56816 .54709 Mtetra
.56816 .54709 .57385 .55311 .58474 .54984 .57909 .54379 Mtetra
.664 .742 .909 r
.57909 .54379 .58474 .54984 .59568 .54656 .59006 .54049 Mtetra
.59006 .54049 .59568 .54656 .60667 .54326 .60107 .53717 Mtetra
.664 .742 .908 r
.60107 .53717 .60667 .54326 .61769 .53995 .61213 .53383 Mtetra
.61213 .53383 .61769 .53995 .62876 .53663 .62323 .53048 Mtetra
.62323 .53048 .62876 .53663 .63988 .53329 .63437 .52712 Mtetra
.63437 .52712 .63988 .53329 .65104 .52994 .64556 .52374 Mtetra
.64556 .52374 .65104 .52994 .66224 .52658 .65679 .52035 Mtetra
.65679 .52035 .66224 .52658 .67349 .52321 .66807 .51695 Mtetra
.66807 .51695 .67349 .52321 .68478 .51982 .67939 .51353 Mtetra
.67939 .51353 .68478 .51982 .69612 .51642 .69076 .5101 Mtetra
.664 .741 .908 r
.69076 .5101 .69612 .51642 .7075 .513 .70218 .50666 Mtetra
.70218 .50666 .7075 .513 .71893 .50957 .71364 .50321 Mtetra
.71364 .50321 .71893 .50957 .73041 .50613 .72515 .49974 Mtetra
.72515 .49974 .73041 .50613 .74193 .50267 .7367 .49625 Mtetra
.7367 .49625 .74193 .50267 .7535 .4992 .7483 .49276 Mtetra
.7483 .49276 .7535 .4992 .76511 .49572 .75995 .48925 Mtetra
.75995 .48925 .76511 .49572 .77677 .49222 .77165 .48572 Mtetra
.77165 .48572 .77677 .49222 .78848 .48871 .78339 .48218 Mtetra
.78339 .48218 .78848 .48871 .80024 .48518 .79518 .47863 Mtetra
.79518 .47863 .80024 .48518 .81205 .48164 .80702 .47506 Mtetra
.80702 .47506 .81205 .48164 .8239 .47808 .81891 .47148 Mtetra
.81891 .47148 .8239 .47808 .8358 .47451 .83085 .46788 Mtetra
.83085 .46788 .8358 .47451 .84775 .47092 .84283 .46427 Mtetra
.84283 .46427 .84775 .47092 .85976 .46732 .85487 .46064 Mtetra
.85487 .46064 .85976 .46732 .87181 .46371 .86696 .45699 Mtetra
.86696 .45699 .87181 .46371 .88391 .46008 .87909 .45334 Mtetra
.87909 .45334 .88391 .46008 .89606 .45643 .89128 .44966 Mtetra
.89128 .44966 .89606 .45643 .90826 .45277 .90352 .44598 Mtetra
.90352 .44598 .90826 .45277 .92051 .4491 .91581 .44227 Mtetra
.91581 .44227 .92051 .4491 .93281 .44541 .92815 .43855 Mtetra
.92815 .43855 .93281 .44541 .94517 .4417 .94054 .43482 Mtetra
.94054 .43482 .94517 .4417 .95757 .43798 .95299 .43107 Mtetra
.95299 .43107 .95757 .43798 .97003 .43424 .96548 .4273 Mtetra
.39287 .59231 .39902 .59803 .40929 .59494 .40317 .58919 Mtetra
.40317 .58919 .40929 .59494 .4196 .59183 .4135 .58606 Mtetra
.4135 .58606 .4196 .59183 .42994 .58871 .42387 .58292 Mtetra
.42387 .58292 .42994 .58871 .44033 .58558 .43428 .57977 Mtetra
.43428 .57977 .44033 .58558 .45076 .58244 .44474 .5766 Mtetra
.663 .741 .908 r
.44474 .5766 .45076 .58244 .46122 .57928 .45523 .57343 Mtetra
.45523 .57343 .46122 .57928 .47173 .57612 .46576 .57024 Mtetra
.46576 .57024 .47173 .57612 .48228 .57294 .47634 .56704 Mtetra
.47634 .56704 .48228 .57294 .49287 .56975 .48695 .56383 Mtetra
.48695 .56383 .49287 .56975 .5035 .56655 .49761 .56061 Mtetra
.663 .742 .908 r
.49761 .56061 .5035 .56655 .51417 .56334 .50831 .55738 Mtetra
.50831 .55738 .51417 .56334 .52489 .56011 .51905 .55414 Mtetra
.663 .742 .909 r
.51905 .55414 .52489 .56011 .53564 .55688 .52983 .55089 Mtetra
.52983 .55089 .53564 .55688 .54644 .55363 .54066 .54762 Mtetra
.54066 .54762 .54644 .55363 .55728 .55036 .55153 .54434 Mtetra
.663 .743 .909 r
.55153 .54434 .55728 .55036 .56816 .54709 .56244 .54105 Mtetra
.56244 .54105 .56816 .54709 .57909 .54379 .5734 .53774 Mtetra
.5734 .53774 .57909 .54379 .59006 .54049 .58439 .53441 Mtetra
.58439 .53441 .59006 .54049 .60107 .53717 .59544 .53107 Mtetra
.664 .743 .909 r
.59544 .53107 .60107 .53717 .61213 .53383 .60652 .52771 Mtetra
.60652 .52771 .61213 .53383 .62323 .53048 .61765 .52433 Mtetra
.61765 .52433 .62323 .53048 .63437 .52712 .62882 .52093 Mtetra
.62882 .52093 .63437 .52712 .64556 .52374 .64004 .51752 Mtetra
.64004 .51752 .64556 .52374 .65679 .52035 .65131 .5141 Mtetra
.65131 .5141 .65679 .52035 .66807 .51695 .66262 .51067 Mtetra
.664 .742 .908 r
.66262 .51067 .66807 .51695 .67939 .51353 .67397 .50722 Mtetra
.67397 .50722 .67939 .51353 .69076 .5101 .68537 .50376 Mtetra
.68537 .50376 .69076 .5101 .70218 .50666 .69682 .50028 Mtetra
.69682 .50028 .70218 .50666 .71364 .50321 .70831 .4968 Mtetra
.70831 .4968 .71364 .50321 .72515 .49974 .71985 .4933 Mtetra
.664 .741 .908 r
.71985 .4933 .72515 .49974 .7367 .49625 .73144 .48979 Mtetra
.73144 .48979 .7367 .49625 .7483 .49276 .74307 .48627 Mtetra
.74307 .48627 .7483 .49276 .75995 .48925 .75475 .48273 Mtetra
.75475 .48273 .75995 .48925 .77165 .48572 .76648 .47918 Mtetra
.76648 .47918 .77165 .48572 .78339 .48218 .77826 .47561 Mtetra
.77826 .47561 .78339 .48218 .79518 .47863 .79008 .47203 Mtetra
.79008 .47203 .79518 .47863 .80702 .47506 .80196 .46843 Mtetra
.80196 .46843 .80702 .47506 .81891 .47148 .81388 .46482 Mtetra
.81388 .46482 .81891 .47148 .83085 .46788 .82585 .4612 Mtetra
.82585 .4612 .83085 .46788 .84283 .46427 .83788 .45756 Mtetra
.83788 .45756 .84283 .46427 .85487 .46064 .84995 .4539 Mtetra
.84995 .4539 .85487 .46064 .86696 .45699 .86207 .45023 Mtetra
.86207 .45023 .86696 .45699 .87909 .45334 .87424 .44654 Mtetra
.87424 .44654 .87909 .45334 .89128 .44966 .88647 .44284 Mtetra
.88647 .44284 .89128 .44966 .90352 .44598 .89874 .43913 Mtetra
.89874 .43913 .90352 .44598 .91581 .44227 .91107 .43539 Mtetra
.91107 .43539 .91581 .44227 .92815 .43855 .92345 .43164 Mtetra
.92345 .43164 .92815 .43855 .94054 .43482 .93588 .42788 Mtetra
.93588 .42788 .94054 .43482 .95299 .43107 .94836 .4241 Mtetra
.94836 .4241 .95299 .43107 .96548 .4273 .9609 .4203 Mtetra
.38668 .58654 .39287 .59231 .40317 .58919 .397 .5834 Mtetra
.397 .5834 .40317 .58919 .4135 .58606 .40736 .58025 Mtetra
.40736 .58025 .4135 .58606 .42387 .58292 .41776 .57709 Mtetra
.41776 .57709 .42387 .58292 .43428 .57977 .42819 .57392 Mtetra
.663 .741 .908 r
.42819 .57392 .43428 .57977 .44474 .5766 .43867 .57073 Mtetra
.43867 .57073 .44474 .5766 .45523 .57343 .44919 .56753 Mtetra
.44919 .56753 .45523 .57343 .46576 .57024 .45975 .56432 Mtetra
.45975 .56432 .46576 .57024 .47634 .56704 .47035 .56111 Mtetra
.47035 .56111 .47634 .56704 .48695 .56383 .48099 .55788 Mtetra
.663 .742 .908 r
.48099 .55788 .48695 .56383 .49761 .56061 .49168 .55464 Mtetra
.663 .742 .909 r
.49168 .55464 .49761 .56061 .50831 .55738 .5024 .5514 Mtetra
.5024 .5514 .50831 .55738 .51905 .55414 .51317 .54814 Mtetra
.51317 .54814 .51905 .55414 .52983 .55089 .52398 .54488 Mtetra
.662 .743 .91 r
.52398 .54488 .52983 .55089 .54066 .54762 .53484 .54161 Mtetra
.53484 .54161 .54066 .54762 .55153 .54434 .54574 .53832 Mtetra
.662 .744 .911 r
.54574 .53832 .55153 .54434 .56244 .54105 .55668 .53502 Mtetra
.663 .745 .911 r
.55668 .53502 .56244 .54105 .5734 .53774 .56766 .53171 Mtetra
.56766 .53171 .5734 .53774 .58439 .53441 .57869 .52837 Mtetra
.663 .746 .912 r
.57869 .52837 .58439 .53441 .59544 .53107 .58976 .52501 Mtetra
.58976 .52501 .59544 .53107 .60652 .52771 .60087 .52163 Mtetra
.664 .746 .912 r
.60087 .52163 .60652 .52771 .61765 .52433 .61203 .51822 Mtetra
.664 .746 .911 r
.61203 .51822 .61765 .52433 .62882 .52093 .62324 .51479 Mtetra
.62324 .51479 .62882 .52093 .64004 .51752 .63449 .51134 Mtetra
.63449 .51134 .64004 .51752 .65131 .5141 .64578 .50787 Mtetra
.664 .745 .91 r
.64578 .50787 .65131 .5141 .66262 .51067 .65712 .50439 Mtetra
.664 .744 .91 r
.65712 .50439 .66262 .51067 .67397 .50722 .66851 .5009 Mtetra
.664 .744 .909 r
.66851 .5009 .67397 .50722 .68537 .50376 .67994 .4974 Mtetra
.664 .743 .909 r
.67994 .4974 .68537 .50376 .69682 .50028 .69142 .49388 Mtetra
.69142 .49388 .69682 .50028 .70831 .4968 .70294 .49036 Mtetra
.664 .742 .908 r
.70294 .49036 .70831 .4968 .71985 .4933 .71451 .48683 Mtetra
.71451 .48683 .71985 .4933 .73144 .48979 .72613 .48329 Mtetra
.72613 .48329 .73144 .48979 .74307 .48627 .7378 .47973 Mtetra
.7378 .47973 .74307 .48627 .75475 .48273 .74951 .47616 Mtetra
.664 .741 .908 r
.74951 .47616 .75475 .48273 .76648 .47918 .76127 .47258 Mtetra
.76127 .47258 .76648 .47918 .77826 .47561 .77309 .46899 Mtetra
.77309 .46899 .77826 .47561 .79008 .47203 .78495 .46538 Mtetra
.78495 .46538 .79008 .47203 .80196 .46843 .79686 .46176 Mtetra
.79686 .46176 .80196 .46843 .81388 .46482 .80881 .45812 Mtetra
.80881 .45812 .81388 .46482 .82585 .4612 .82082 .45446 Mtetra
.82082 .45446 .82585 .4612 .83788 .45756 .83288 .4508 Mtetra
.83288 .4508 .83788 .45756 .84995 .4539 .84499 .44711 Mtetra
.84499 .44711 .84995 .4539 .86207 .45023 .85715 .44341 Mtetra
.85715 .44341 .86207 .45023 .87424 .44654 .86936 .4397 Mtetra
.86936 .4397 .87424 .44654 .88647 .44284 .88162 .43597 Mtetra
.88162 .43597 .88647 .44284 .89874 .43913 .89393 .43222 Mtetra
.89393 .43222 .89874 .43913 .91107 .43539 .9063 .42846 Mtetra
.9063 .42846 .91107 .43539 .92345 .43164 .91871 .42468 Mtetra
.91871 .42468 .92345 .43164 .93588 .42788 .93118 .42089 Mtetra
.93118 .42089 .93588 .42788 .94836 .4241 .94371 .41708 Mtetra
.94371 .41708 .94836 .4241 .9609 .4203 .95628 .41325 Mtetra
.38045 .58074 .38668 .58654 .397 .5834 .39079 .57758 Mtetra
.39079 .57758 .397 .5834 .40736 .58025 .40117 .5744 Mtetra
.40117 .5744 .40736 .58025 .41776 .57709 .4116 .57122 Mtetra
.4116 .57122 .41776 .57709 .42819 .57392 .42206 .56802 Mtetra
.663 .741 .908 r
.42206 .56802 .42819 .57392 .43867 .57073 .43256 .56481 Mtetra
.43256 .56481 .43867 .57073 .44919 .56753 .44311 .56159 Mtetra
.44311 .56159 .44919 .56753 .45975 .56432 .45369 .55837 Mtetra
.45369 .55837 .45975 .56432 .47035 .56111 .46432 .55513 Mtetra
.46432 .55513 .47035 .56111 .48099 .55788 .47499 .55188 Mtetra
.663 .742 .909 r
.47499 .55188 .48099 .55788 .49168 .55464 .4857 .54863 Mtetra
.662 .742 .909 r
.4857 .54863 .49168 .55464 .5024 .5514 .49646 .54538 Mtetra
.662 .742 .91 r
.49646 .54538 .5024 .5514 .51317 .54814 .50725 .54212 Mtetra
.662 .743 .91 r
.50725 .54212 .51317 .54814 .52398 .54488 .51809 .53887 Mtetra
.661 .744 .911 r
.51809 .53887 .52398 .54488 .53484 .54161 .52897 .5356 Mtetra
.661 .745 .912 r
.52897 .5356 .53484 .54161 .54574 .53832 .5399 .53234 Mtetra
.661 .746 .913 r
.5399 .53234 .54574 .53832 .55668 .53502 .55087 .52906 Mtetra
.661 .748 .914 r
.55087 .52906 .55668 .53502 .56766 .53171 .56188 .52576 Mtetra
.661 .749 .915 r
.56188 .52576 .56766 .53171 .57869 .52837 .57294 .52244 Mtetra
.662 .751 .916 r
.57294 .52244 .57869 .52837 .58976 .52501 .58404 .51908 Mtetra
.663 .752 .917 r
.58404 .51908 .58976 .52501 .60087 .52163 .59519 .51569 Mtetra
.663 .753 .917 r
.59519 .51569 .60087 .52163 .61203 .51822 .60638 .51226 Mtetra
.664 .753 .916 r
.60638 .51226 .61203 .51822 .62324 .51479 .61762 .50879 Mtetra
.665 .753 .916 r
.61762 .50879 .62324 .51479 .63449 .51134 .6289 .50529 Mtetra
.665 .752 .915 r
.6289 .50529 .63449 .51134 .64578 .50787 .64022 .50177 Mtetra
.666 .751 .914 r
.64022 .50177 .64578 .50787 .65712 .50439 .65159 .49822 Mtetra
.666 .75 .913 r
.65159 .49822 .65712 .50439 .66851 .5009 .66301 .49466 Mtetra
.666 .748 .912 r
.66301 .49466 .66851 .5009 .67994 .4974 .67447 .49109 Mtetra
.665 .747 .911 r
.67447 .49109 .67994 .4974 .69142 .49388 .68598 .48751 Mtetra
.665 .745 .91 r
.68598 .48751 .69142 .49388 .70294 .49036 .69753 .48393 Mtetra
.665 .744 .909 r
.69753 .48393 .70294 .49036 .71451 .48683 .70914 .48035 Mtetra
.664 .743 .909 r
.70914 .48035 .71451 .48683 .72613 .48329 .72079 .47676 Mtetra
.72079 .47676 .72613 .48329 .7378 .47973 .73249 .47316 Mtetra
.664 .742 .908 r
.73249 .47316 .7378 .47973 .74951 .47616 .74423 .46956 Mtetra
.74423 .46956 .74951 .47616 .76127 .47258 .75603 .46594 Mtetra
.75603 .46594 .76127 .47258 .77309 .46899 .76788 .46232 Mtetra
.664 .741 .908 r
.76788 .46232 .77309 .46899 .78495 .46538 .77977 .45868 Mtetra
.77977 .45868 .78495 .46538 .79686 .46176 .79171 .45503 Mtetra
.79171 .45503 .79686 .46176 .80881 .45812 .80371 .45136 Mtetra
.80371 .45136 .80881 .45812 .82082 .45446 .81575 .44768 Mtetra
.81575 .44768 .82082 .45446 .83288 .4508 .82785 .44398 Mtetra
.82785 .44398 .83288 .4508 .84499 .44711 .83999 .44027 Mtetra
.83999 .44027 .84499 .44711 .85715 .44341 .85219 .43654 Mtetra
.85219 .43654 .85715 .44341 .86936 .4397 .86443 .4328 Mtetra
.86443 .4328 .86936 .4397 .88162 .43597 .87673 .42904 Mtetra
.87673 .42904 .88162 .43597 .89393 .43222 .88908 .42526 Mtetra
.88908 .42526 .89393 .43222 .9063 .42846 .90148 .42147 Mtetra
.90148 .42147 .9063 .42846 .91871 .42468 .91394 .41767 Mtetra
.91394 .41767 .91871 .42468 .93118 .42089 .92645 .41384 Mtetra
.92645 .41384 .93118 .42089 .94371 .41708 .93901 .41 Mtetra
.93901 .41 .94371 .41708 .95628 .41325 .95162 .40615 Mtetra
.37417 .57489 .38045 .58074 .39079 .57758 .38454 .57171 Mtetra
.38454 .57171 .39079 .57758 .40117 .5744 .39494 .56851 Mtetra
.39494 .56851 .40117 .5744 .4116 .57122 .40539 .56531 Mtetra
.663 .741 .908 r
.40539 .56531 .4116 .57122 .42206 .56802 .41588 .56209 Mtetra
.41588 .56209 .42206 .56802 .43256 .56481 .42641 .55885 Mtetra
.42641 .55885 .43256 .56481 .44311 .56159 .43698 .55561 Mtetra
.43698 .55561 .44311 .56159 .45369 .55837 .44759 .55236 Mtetra
.44759 .55236 .45369 .55837 .46432 .55513 .45825 .54911 Mtetra
.663 .741 .909 r
.45825 .54911 .46432 .55513 .47499 .55188 .46894 .54585 Mtetra
.662 .742 .909 r
.46894 .54585 .47499 .55188 .4857 .54863 .47968 .54259 Mtetra
.662 .742 .91 r
.47968 .54259 .4857 .54863 .49646 .54538 .49046 .53933 Mtetra
.661 .742 .91 r
.49046 .53933 .49646 .54538 .50725 .54212 .50129 .53609 Mtetra
.66 .743 .912 r
.50129 .53609 .50725 .54212 .51809 .53887 .51215 .53285 Mtetra
.659 .744 .913 r
.51215 .53285 .51809 .53887 .52897 .5356 .52306 .52962 Mtetra
.658 .746 .915 r
.52306 .52962 .52897 .5356 .5399 .53234 .53402 .52641 Mtetra
.657 .749 .917 r
.53402 .52641 .5399 .53234 .55087 .52906 .54502 .52319 Mtetra
.657 .751 .919 r
.54502 .52319 .55087 .52906 .56188 .52576 .55606 .51996 Mtetra
.657 .755 .922 r
.55606 .51996 .56188 .52576 .57294 .52244 .56715 .51671 Mtetra
.658 .758 .924 r
.56715 .51671 .57294 .52244 .58404 .51908 .57829 .51341 Mtetra
.659 .761 .925 r
.57829 .51341 .58404 .51908 .59519 .51569 .58947 .51006 Mtetra
.661 .764 .926 r
.58947 .51006 .59519 .51569 .60638 .51226 .60069 .50664 Mtetra
.663 .766 .927 r
.60069 .50664 .60638 .51226 .61762 .50879 .61196 .50316 Mtetra
.665 .767 .926 r
.61196 .50316 .61762 .50879 .6289 .50529 .62327 .49961 Mtetra
.666 .767 .925 r
.62327 .49961 .6289 .50529 .64022 .50177 .63463 .496 Mtetra
.668 .765 .923 r
.63463 .496 .64022 .50177 .65159 .49822 .64603 .49235 Mtetra
.668 .762 .921 r
.64603 .49235 .65159 .49822 .66301 .49466 .65748 .48867 Mtetra
.668 .759 .919 r
.65748 .48867 .66301 .49466 .67447 .49109 .66897 .48498 Mtetra
.668 .756 .916 r
.66897 .48498 .67447 .49109 .68598 .48751 .68051 .48129 Mtetra
.667 .753 .914 r
.68051 .48129 .68598 .48751 .69753 .48393 .69209 .4776 Mtetra
.667 .75 .913 r
.69209 .4776 .69753 .48393 .70914 .48035 .70373 .47392 Mtetra
.666 .748 .911 r
.70373 .47392 .70914 .48035 .72079 .47676 .71541 .47026 Mtetra
.665 .746 .91 r
.71541 .47026 .72079 .47676 .73249 .47316 .72714 .46659 Mtetra
.665 .744 .909 r
.72714 .46659 .73249 .47316 .74423 .46956 .73892 .46294 Mtetra
.664 .743 .909 r
.73892 .46294 .74423 .46956 .75603 .46594 .75075 .45928 Mtetra
.664 .742 .908 r
.75075 .45928 .75603 .46594 .76788 .46232 .76263 .45561 Mtetra
.76263 .45561 .76788 .46232 .77977 .45868 .77456 .45194 Mtetra
.77456 .45194 .77977 .45868 .79171 .45503 .78653 .44825 Mtetra
.664 .741 .908 r
.78653 .44825 .79171 .45503 .80371 .45136 .79856 .44456 Mtetra
.79856 .44456 .80371 .45136 .81575 .44768 .81064 .44084 Mtetra
.81064 .44084 .81575 .44768 .82785 .44398 .82277 .43712 Mtetra
.82277 .43712 .82785 .44398 .83999 .44027 .83495 .43338 Mtetra
.83495 .43338 .83999 .44027 .85219 .43654 .84719 .42962 Mtetra
.84719 .42962 .85219 .43654 .86443 .4328 .85947 .42585 Mtetra
.85947 .42585 .86443 .4328 .87673 .42904 .87181 .42206 Mtetra
.87181 .42206 .87673 .42904 .88908 .42526 .88419 .41825 Mtetra
.88419 .41825 .88908 .42526 .90148 .42147 .89664 .41443 Mtetra
.89664 .41443 .90148 .42147 .91394 .41767 .90913 .4106 Mtetra
.90913 .4106 .91394 .41767 .92645 .41384 .92168 .40674 Mtetra
.92168 .40674 .92645 .41384 .93901 .41 .93428 .40287 Mtetra
.93428 .40287 .93901 .41 .95162 .40615 .94693 .39899 Mtetra
.36785 .56901 .37417 .57489 .38454 .57171 .37824 .5658 Mtetra
.37824 .5658 .38454 .57171 .39494 .56851 .38867 .56258 Mtetra
.38867 .56258 .39494 .56851 .40539 .56531 .39914 .55935 Mtetra
.663 .741 .908 r
.39914 .55935 .40539 .56531 .41588 .56209 .40966 .55611 Mtetra
.40966 .55611 .41588 .56209 .42641 .55885 .42022 .55285 Mtetra
.42022 .55285 .42641 .55885 .43698 .55561 .43081 .54959 Mtetra
.43081 .54959 .43698 .55561 .44759 .55236 .44145 .54632 Mtetra
.44145 .54632 .44759 .55236 .45825 .54911 .45213 .54304 Mtetra
.662 .741 .909 r
.45213 .54304 .45825 .54911 .46894 .54585 .46285 .53977 Mtetra
.46285 .53977 .46894 .54585 .47968 .54259 .47362 .5365 Mtetra
.661 .742 .91 r
.47362 .5365 .47968 .54259 .49046 .53933 .48443 .53325 Mtetra
.659 .742 .911 r
.48443 .53325 .49046 .53933 .50129 .53609 .49528 .53002 Mtetra
.658 .743 .913 r
.49528 .53002 .50129 .53609 .51215 .53285 .50617 .52683 Mtetra
.656 .745 .915 r
.50617 .52683 .51215 .53285 .52306 .52962 .51711 .52367 Mtetra
.654 .747 .919 r
.51711 .52367 .52306 .52962 .53402 .52641 .5281 .52055 Mtetra
.652 .751 .922 r
.5281 .52055 .53402 .52641 .54502 .52319 .53913 .51746 Mtetra
.65 .756 .927 r
.53913 .51746 .54502 .52319 .55606 .51996 .5502 .51438 Mtetra
.649 .762 .931 r
.5502 .51438 .55606 .51996 .56715 .51671 .56133 .51129 Mtetra
.649 .768 .936 r
.56133 .51129 .56715 .51671 .57829 .51341 .5725 .50816 Mtetra
.651 .776 .94 r
.5725 .50816 .57829 .51341 .58947 .51006 .58371 .50495 Mtetra
.653 .783 .943 r
.58371 .50495 .58947 .51006 .60069 .50664 .59497 .50164 Mtetra
.657 .789 .945 r
.59497 .50164 .60069 .50664 .61196 .50316 .60628 .49821 Mtetra
.661 .793 .945 r
.60628 .49821 .61196 .50316 .62327 .49961 .61763 .49465 Mtetra
.665 .794 .944 r
.61763 .49465 .62327 .49961 .63463 .496 .62902 .49096 Mtetra
.669 .793 .941 r
.62902 .49096 .63463 .496 .64603 .49235 .64045 .48717 Mtetra
.671 .79 .938 r
.64045 .48717 .64603 .49235 .65748 .48867 .65193 .48331 Mtetra
.673 .785 .933 r
.65193 .48331 .65748 .48867 .66897 .48498 .66345 .47941 Mtetra
.673 .778 .929 r
.66345 .47941 .66897 .48498 .68051 .48129 .67502 .47551 Mtetra
.673 .771 .924 r
.67502 .47551 .68051 .48129 .69209 .4776 .68663 .47161 Mtetra
.672 .765 .92 r
.68663 .47161 .69209 .4776 .70373 .47392 .69829 .46775 Mtetra
.67 .759 .917 r
.69829 .46775 .70373 .47392 .71541 .47026 .71 .46392 Mtetra
.669 .754 .914 r
.71 .46392 .71541 .47026 .72714 .46659 .72176 .46012 Mtetra
.667 .75 .912 r
.72176 .46012 .72714 .46659 .73892 .46294 .73357 .45636 Mtetra
.666 .747 .911 r
.73357 .45636 .73892 .46294 .75075 .45928 .74543 .45262 Mtetra
.665 .745 .91 r
.74543 .45262 .75075 .45928 .76263 .45561 .75734 .44889 Mtetra
.665 .743 .909 r
.75734 .44889 .76263 .45561 .77456 .45194 .7693 .44516 Mtetra
.664 .742 .908 r
.7693 .44516 .77456 .45194 .78653 .44825 .78132 .44144 Mtetra
.78132 .44144 .78653 .44825 .79856 .44456 .79338 .4377 Mtetra
.79338 .4377 .79856 .44456 .81064 .44084 .80549 .43396 Mtetra
.664 .741 .908 r
.80549 .43396 .81064 .44084 .82277 .43712 .81766 .4302 Mtetra
.81766 .4302 .82277 .43712 .83495 .43338 .82988 .42643 Mtetra
.82988 .42643 .83495 .43338 .84719 .42962 .84215 .42264 Mtetra
.84215 .42264 .84719 .42962 .85947 .42585 .85447 .41884 Mtetra
.85447 .41884 .85947 .42585 .87181 .42206 .86684 .41502 Mtetra
.86684 .41502 .87181 .42206 .88419 .41825 .87927 .41119 Mtetra
.87927 .41119 .88419 .41825 .89664 .41443 .89175 .40734 Mtetra
.89175 .40734 .89664 .41443 .90913 .4106 .90428 .40347 Mtetra
.90428 .40347 .90913 .4106 .92168 .40674 .91687 .39958 Mtetra
.91687 .39958 .92168 .40674 .93428 .40287 .92951 .39568 Mtetra
.92951 .39568 .93428 .40287 .94693 .39899 .9422 .39177 Mtetra
.36148 .56307 .36785 .56901 .37824 .5658 .37189 .55985 Mtetra
.37189 .55985 .37824 .5658 .38867 .56258 .38235 .5566 Mtetra
.38235 .5566 .38867 .56258 .39914 .55935 .39285 .55335 Mtetra
.663 .741 .908 r
.39285 .55335 .39914 .55935 .40966 .55611 .40339 .55008 Mtetra
.40339 .55008 .40966 .55611 .42022 .55285 .41397 .5468 Mtetra
.41397 .5468 .42022 .55285 .43081 .54959 .4246 .54352 Mtetra
.4246 .54352 .43081 .54959 .44145 .54632 .43526 .54022 Mtetra
.43526 .54022 .44145 .54632 .45213 .54304 .44597 .53693 Mtetra
.662 .741 .909 r
.44597 .53693 .45213 .54304 .46285 .53977 .45672 .53364 Mtetra
.661 .741 .909 r
.45672 .53364 .46285 .53977 .47362 .5365 .46751 .53036 Mtetra
.66 .741 .91 r
.46751 .53036 .47362 .5365 .48443 .53325 .47835 .52712 Mtetra
.657 .742 .912 r
.47835 .52712 .48443 .53325 .49528 .53002 .48922 .52392 Mtetra
.655 .742 .914 r
.48922 .52392 .49528 .53002 .50617 .52683 .50015 .52078 Mtetra
.651 .744 .918 r
.50015 .52078 .50617 .52683 .51711 .52367 .51111 .51772 Mtetra
.647 .747 .922 r
.51111 .51772 .51711 .52367 .5281 .52055 .52213 .51475 Mtetra
.642 .752 .928 r
.52213 .51475 .5281 .52055 .53913 .51746 .53319 .51186 Mtetra
.638 .758 .935 r
.53319 .51186 .53913 .51746 .5502 .51438 .5443 .50905 Mtetra
.634 .767 .944 r
.5443 .50905 .5502 .51438 .56133 .51129 .55546 .50627 Mtetra
.631 .779 .952 r
.55546 .50627 .56133 .51129 .5725 .50816 .56666 .50347 Mtetra
.629 .792 .96 r
.56666 .50347 .5725 .50816 .58371 .50495 .57792 .50059 Mtetra
.63 .807 .967 r
.57792 .50059 .58371 .50495 .59497 .50164 .58923 .49758 Mtetra
.634 .821 .972 r
.58923 .49758 .59497 .50164 .60628 .49821 .60058 .49437 Mtetra
.641 .833 .974 r
.60058 .49437 .60628 .49821 .61763 .49465 .61197 .49092 Mtetra
.65 .841 .974 r
.61197 .49092 .61763 .49465 .62902 .49096 .6234 .48723 Mtetra
.659 .845 .971 r
.6234 .48723 .62902 .49096 .64045 .48717 .63488 .48332 Mtetra
.669 .843 .967 r
.63488 .48332 .64045 .48717 .65193 .48331 .64639 .47922 Mtetra
.676 .836 .96 r
.64639 .47922 .65193 .48331 .66345 .47941 .65794 .475 Mtetra
.68 .826 .953 r
.65794 .475 .66345 .47941 .67502 .47551 .66953 .47072 Mtetra
.682 .813 .945 r
.66953 .47072 .67502 .47551 .68663 .47161 .68116 .46644 Mtetra
.681 .799 .938 r
.68116 .46644 .68663 .47161 .69829 .46775 .69284 .46221 Mtetra
.679 .786 .93 r
.69284 .46221 .69829 .46775 .71 .46392 .70458 .45805 Mtetra
.676 .774 .924 r
.70458 .45805 .71 .46392 .72176 .46012 .71636 .45398 Mtetra
.673 .765 .919 r
.71636 .45398 .72176 .46012 .73357 .45636 .72819 .45 Mtetra
.67 .757 .916 r
.72819 .45 .73357 .45636 .74543 .45262 .74008 .44608 Mtetra
.668 .752 .913 r
.74008 .44608 .74543 .45262 .75734 .44889 .75202 .44223 Mtetra
.667 .748 .911 r
.75202 .44223 .75734 .44889 .7693 .44516 .76401 .43841 Mtetra
.665 .745 .91 r
.76401 .43841 .7693 .44516 .78132 .44144 .77606 .43461 Mtetra
.665 .743 .909 r
.77606 .43461 .78132 .44144 .79338 .4377 .78816 .43082 Mtetra
.664 .743 .908 r
.78816 .43082 .79338 .4377 .80549 .43396 .80031 .42703 Mtetra
.664 .742 .908 r
.80031 .42703 .80549 .43396 .81766 .4302 .81251 .42324 Mtetra
.81251 .42324 .81766 .4302 .82988 .42643 .82476 .41943 Mtetra
.664 .741 .908 r
.82476 .41943 .82988 .42643 .84215 .42264 .83707 .41561 Mtetra
.83707 .41561 .84215 .42264 .85447 .41884 .84943 .41178 Mtetra
.84943 .41178 .85447 .41884 .86684 .41502 .86184 .40793 Mtetra
.86184 .40793 .86684 .41502 .87927 .41119 .8743 .40406 Mtetra
.8743 .40406 .87927 .41119 .89175 .40734 .88682 .40018 Mtetra
.88682 .40018 .89175 .40734 .90428 .40347 .89939 .39628 Mtetra
.89939 .39628 .90428 .40347 .91687 .39958 .91202 .39237 Mtetra
.91202 .39237 .91687 .39958 .92951 .39568 .9247 .38844 Mtetra
.9247 .38844 .92951 .39568 .9422 .39177 .93743 .38449 Mtetra
.35506 .5571 .36148 .56307 .37189 .55985 .3655 .55385 Mtetra
.3655 .55385 .37189 .55985 .38235 .5566 .37599 .55058 Mtetra
.37599 .55058 .38235 .5566 .39285 .55335 .38651 .5473 Mtetra
.663 .741 .908 r
.38651 .5473 .39285 .55335 .40339 .55008 .39708 .54401 Mtetra
.39708 .54401 .40339 .55008 .41397 .5468 .40769 .54071 Mtetra
.40769 .54071 .41397 .5468 .4246 .54352 .41834 .5374 Mtetra
.41834 .5374 .4246 .54352 .43526 .54022 .42903 .53408 Mtetra
.42903 .53408 .43526 .54022 .44597 .53693 .43976 .53077 Mtetra
.662 .741 .909 r
.43976 .53077 .44597 .53693 .45672 .53364 .45054 .52746 Mtetra
.661 .741 .909 r
.45054 .52746 .45672 .53364 .46751 .53036 .46136 .52417 Mtetra
.659 .741 .91 r
.46136 .52417 .46751 .53036 .47835 .52712 .47222 .52093 Mtetra
.656 .741 .912 r
.47222 .52093 .47835 .52712 .48922 .52392 .48312 .51775 Mtetra
.652 .741 .915 r
.48312 .51775 .48922 .52392 .50015 .52078 .49407 .51467 Mtetra
.646 .742 .919 r
.49407 .51467 .50015 .52078 .51111 .51772 .50507 .51173 Mtetra
.639 .745 .925 r
.50507 .51173 .51111 .51772 .52213 .51475 .51611 .50894 Mtetra
.63 .749 .933 r
.51611 .50894 .52213 .51475 .53319 .51186 .5272 .50633 Mtetra
.62 .756 .944 r
.5272 .50633 .53319 .51186 .5443 .50905 .53834 .50389 Mtetra
.608 .768 .956 r
.53834 .50389 .5443 .50905 .55546 .50627 .54954 .50159 Mtetra
.596 .783 .97 r
.54954 .50159 .55546 .50627 .56666 .50347 .56079 .49935 Mtetra
.584 .803 .983 r
.56079 .49935 .56666 .50347 .57792 .50059 .57209 .49709 Mtetra
.573 .826 .993 r
.57209 .49709 .57792 .50059 .58923 .49758 .58345 .49469 Mtetra
.566 .849 .997 r
.58345 .49469 .58923 .49758 .60058 .49437 .59485 .49202 Mtetra
.565 .871 .995 r
.59485 .49202 .60058 .49437 .61197 .49092 .6063 .48899 Mtetra
.573 .889 .989 r
.6063 .48899 .61197 .49092 .6234 .48723 .61779 .48553 Mtetra
.59 .904 .983 r
.61779 .48553 .6234 .48723 .63488 .48332 .62932 .48163 Mtetra
.615 .913 .98 r
.62932 .48163 .63488 .48332 .64639 .47922 .64087 .47733 Mtetra
.642 .916 .979 r
.64087 .47733 .64639 .47922 .65794 .475 .65246 .47271 Mtetra
.667 .909 .978 r
.65246 .47271 .65794 .475 .66953 .47072 .66407 .46788 Mtetra
.683 .893 .973 r
.66407 .46788 .66953 .47072 .68116 .46644 .67573 .46297 Mtetra
.692 .87 .966 r
.67573 .46297 .68116 .46644 .69284 .46221 .68743 .45808 Mtetra
.694 .845 .956 r
.68743 .45808 .69284 .46221 .70458 .45805 .69917 .4533 Mtetra
.691 .821 .945 r
.69917 .4533 .70458 .45805 .71636 .45398 .71096 .44868 Mtetra
.686 .8 .935 r
.71096 .44868 .71636 .45398 .72819 .45 .72281 .44423 Mtetra
.681 .782 .927 r
.72281 .44423 .72819 .45 .74008 .44608 .73472 .43994 Mtetra
.676 .769 .921 r
.73472 .43994 .74008 .44608 .75202 .44223 .74668 .43581 Mtetra
.672 .759 .916 r
.74668 .43581 .75202 .44223 .76401 .43841 .7587 .43178 Mtetra
.669 .752 .913 r
.7587 .43178 .76401 .43841 .77606 .43461 .77077 .42784 Mtetra
.667 .748 .911 r
.77077 .42784 .77606 .43461 .78816 .43082 .7829 .42395 Mtetra
.666 .745 .91 r
.7829 .42395 .78816 .43082 .80031 .42703 .79508 .42009 Mtetra
.665 .743 .909 r
.79508 .42009 .80031 .42703 .81251 .42324 .80732 .41624 Mtetra
.664 .742 .908 r
.80732 .41624 .81251 .42324 .82476 .41943 .81961 .41239 Mtetra
.81961 .41239 .82476 .41943 .83707 .41561 .83195 .40853 Mtetra
.83195 .40853 .83707 .41561 .84943 .41178 .84435 .40466 Mtetra
.664 .741 .908 r
.84435 .40466 .84943 .41178 .86184 .40793 .8568 .40078 Mtetra
.8568 .40078 .86184 .40793 .8743 .40406 .8693 .39689 Mtetra
.8693 .39689 .8743 .40406 .88682 .40018 .88186 .39297 Mtetra
.88186 .39297 .88682 .40018 .89939 .39628 .89447 .38904 Mtetra
.89447 .38904 .89939 .39628 .91202 .39237 .90713 .3851 Mtetra
.90713 .3851 .91202 .39237 .9247 .38844 .91985 .38114 Mtetra
.91985 .38114 .9247 .38844 .93743 .38449 .93263 .37715 Mtetra
.3486 .55109 .35506 .5571 .3655 .55385 .35907 .54781 Mtetra
.35907 .54781 .3655 .55385 .37599 .55058 .36958 .54452 Mtetra
.36958 .54452 .37599 .55058 .38651 .5473 .38013 .54122 Mtetra
.38013 .54122 .38651 .5473 .39708 .54401 .39072 .5379 Mtetra
.663 .741 .908 r
.39072 .5379 .39708 .54401 .40769 .54071 .40135 .53458 Mtetra
.40135 .53458 .40769 .54071 .41834 .5374 .41203 .53124 Mtetra
.41203 .53124 .41834 .5374 .42903 .53408 .42275 .5279 Mtetra
.42275 .5279 .42903 .53408 .43976 .53077 .43351 .52455 Mtetra
.662 .741 .909 r
.43351 .52455 .43976 .53077 .45054 .52746 .44431 .52122 Mtetra
.66 .74 .909 r
.44431 .52122 .45054 .52746 .46136 .52417 .45516 .51791 Mtetra
.658 .74 .91 r
.45516 .51791 .46136 .52417 .47222 .52093 .46605 .51466 Mtetra
.655 .739 .912 r
.46605 .51466 .47222 .52093 .48312 .51775 .47698 .5115 Mtetra
.649 .739 .915 r
.47698 .5115 .48312 .51775 .49407 .51467 .48796 .50846 Mtetra
.641 .739 .92 r
.48796 .50846 .49407 .51467 .50507 .51173 .49898 .50562 Mtetra
.631 .74 .926 r
.49898 .50562 .50507 .51173 .51611 .50894 .51005 .50303 Mtetra
.616 .743 .936 r
.51005 .50303 .51611 .50894 .5272 .50633 .52117 .50073 Mtetra
.598 .748 .949 r
.52117 .50073 .5272 .50633 .53834 .50389 .53234 .49875 Mtetra
.574 .758 .965 r
.53234 .49875 .53834 .50389 .54954 .50159 .54357 .49707 Mtetra
.544 .773 .983 r
.54357 .49707 .54954 .50159 .56079 .49935 .55487 .49564 Mtetra
.505 .791 .997 r
.55487 .49564 .56079 .49935 .57209 .49709 .56622 .49433 Mtetra
.455 .809 .997 r
.56622 .49433 .57209 .49709 .58345 .49469 .57763 .49296 Mtetra
.397 .818 .97 r
.57763 .49296 .58345 .49469 .59485 .49202 .58911 .49134 Mtetra
.341 .812 .911 r
.58911 .49134 .59485 .49202 .6063 .48899 .60063 .48924 Mtetra
.303 .797 .838 r
.60063 .48924 .6063 .48899 .61779 .48553 .61219 .4865 Mtetra
.296 .791 .779 r
.61219 .4865 .61779 .48553 .62932 .48163 .62379 .483 Mtetra
.326 .806 .755 r
.62379 .483 .62932 .48163 .64087 .47733 .63541 .47875 Mtetra
.389 .843 .771 r
.63541 .47875 .64087 .47733 .65246 .47271 .64705 .47381 Mtetra
.474 .893 .82 r
.64705 .47381 .65246 .47271 .66407 .46788 .6587 .46833 Mtetra
.564 .937 .881 r
.6587 .46833 .66407 .46788 .67573 .46297 .67038 .46253 Mtetra
.638 .955 .933 r
.67038 .46253 .67573 .46297 .68743 .45808 .68209 .45661 Mtetra
.684 .945 .961 r
.68209 .45661 .68743 .45808 .69917 .4533 .69383 .45077 Mtetra
.704 .914 .967 r
.69383 .45077 .69917 .4533 .71096 .44868 .70562 .44513 Mtetra
.707 .876 .96 r
.70562 .44513 .71096 .44868 .72281 .44423 .71747 .43978 Mtetra
.701 .84 .949 r
.71747 .43978 .72281 .44423 .73472 .43994 .72937 .43475 Mtetra
.693 .81 .938 r
.72937 .43475 .73472 .43994 .74668 .43581 .74134 .43003 Mtetra
.685 .787 .928 r
.74134 .43003 .74668 .43581 .7587 .43178 .75337 .42557 Mtetra
.678 .771 .921 r
.75337 .42557 .7587 .43178 .77077 .42784 .76546 .42131 Mtetra
.673 .76 .916 r
.76546 .42131 .77077 .42784 .7829 .42395 .77761 .4172 Mtetra
.669 .752 .913 r
.77761 .4172 .7829 .42395 .79508 .42009 .78982 .41319 Mtetra
.667 .747 .911 r
.78982 .41319 .79508 .42009 .80732 .41624 .80209 .40924 Mtetra
.665 .745 .909 r
.80209 .40924 .80732 .41624 .81961 .41239 .81442 .40532 Mtetra
.665 .743 .909 r
.81442 .40532 .81961 .41239 .83195 .40853 .82679 .40141 Mtetra
.664 .742 .908 r
.82679 .40141 .83195 .40853 .84435 .40466 .83923 .3975 Mtetra
.83923 .3975 .84435 .40466 .8568 .40078 .85171 .39358 Mtetra
.664 .741 .908 r
.85171 .39358 .8568 .40078 .8693 .39689 .86426 .38965 Mtetra
.86426 .38965 .8693 .39689 .88186 .39297 .87685 .38571 Mtetra
.87685 .38571 .88186 .39297 .89447 .38904 .8895 .38175 Mtetra
.8895 .38175 .89447 .38904 .90713 .3851 .90221 .37777 Mtetra
.90221 .37777 .90713 .3851 .91985 .38114 .91497 .37377 Mtetra
.91497 .37377 .91985 .38114 .93263 .37715 .92778 .36976 Mtetra
.34209 .54503 .3486 .55109 .35907 .54781 .35259 .54172 Mtetra
.35259 .54172 .35907 .54781 .36958 .54452 .36312 .53841 Mtetra
.36312 .53841 .36958 .54452 .38013 .54122 .3737 .53508 Mtetra
.3737 .53508 .38013 .54122 .39072 .5379 .38431 .53174 Mtetra
.663 .741 .908 r
.38431 .53174 .39072 .5379 .40135 .53458 .39497 .52839 Mtetra
.39497 .52839 .40135 .53458 .41203 .53124 .40568 .52503 Mtetra
.40568 .52503 .41203 .53124 .42275 .5279 .41642 .52166 Mtetra
.41642 .52166 .42275 .5279 .43351 .52455 .42721 .51829 Mtetra
.662 .741 .908 r
.42721 .51829 .43351 .52455 .44431 .52122 .43804 .51493 Mtetra
.661 .74 .909 r
.43804 .51493 .44431 .52122 .45516 .51791 .44891 .5116 Mtetra
.658 .739 .91 r
.44891 .5116 .45516 .51791 .46605 .51466 .45983 .50832 Mtetra
.654 .738 .911 r
.45983 .50832 .46605 .51466 .47698 .5115 .47079 .50514 Mtetra
.648 .737 .914 r
.47079 .50514 .47698 .5115 .48796 .50846 .4818 .50212 Mtetra
.638 .735 .918 r
.4818 .50212 .48796 .50846 .49898 .50562 .49284 .49934 Mtetra
.625 .733 .925 r
.49284 .49934 .49898 .50562 .51005 .50303 .50394 .4969 Mtetra
.605 .733 .935 r
.50394 .4969 .51005 .50303 .52117 .50073 .51509 .49487 Mtetra
.577 .733 .949 r
.51509 .49487 .52117 .50073 .53234 .49875 .52629 .49335 Mtetra
.538 .737 .967 r
.52629 .49335 .53234 .49875 .54357 .49707 .53755 .49237 Mtetra
.482 .742 .985 r
.53755 .49237 .54357 .49707 .55487 .49564 .54889 .49191 Mtetra
.4 .744 .993 r
.54889 .49191 .55487 .49564 .56622 .49433 .56029 .49184 Mtetra
.279 .728 .96 r
.56029 .49184 .56622 .49433 .57763 .49296 .57177 .49195 Mtetra
.125 .665 .842 r
.57177 .49195 .57763 .49296 .58911 .49134 .58332 .49196 Mtetra
.021 0 0 r
.58332 .49196 .58911 .49134 .60063 .48924 .59493 .49151 Mtetra
.112 0 0 r
.59493 .49151 .60063 .48924 .61219 .4865 .60659 .49026 Mtetra
.142 0 0 r
.60659 .49026 .61219 .4865 .62379 .483 .61829 .48793 Mtetra
.128 0 0 r
.61829 .48793 .62379 .483 .63541 .47875 .63001 .48435 Mtetra
.081 0 0 r
.63001 .48435 .63541 .47875 .64705 .47381 .64173 .47952 Mtetra
.004 0 0 r
.64173 .47952 .64705 .47381 .6587 .46833 .65345 .47358 Mtetra
0 0 0 r
.65345 .47358 .6587 .46833 .67038 .46253 .66517 .46679 Mtetra
.66517 .46679 .67038 .46253 .68209 .45661 .67689 .45951 Mtetra
.424 .834 .646 r
.67689 .45951 .68209 .45661 .69383 .45077 .68863 .45208 Mtetra
.581 .941 .813 r
.68863 .45208 .69383 .45077 .70562 .44513 .70041 .44481 Mtetra
.679 .971 .917 r
.70041 .44481 .70562 .44513 .71747 .43978 .71223 .43791 Mtetra
.717 .943 .957 r
.71223 .43791 .71747 .43978 .72937 .43475 .7241 .43152 Mtetra
.719 .895 .959 r
.7241 .43152 .72937 .43475 .74134 .43003 .73605 .42566 Mtetra
.709 .849 .949 r
.73605 .42566 .74134 .43003 .75337 .42557 .74807 .42031 Mtetra
.697 .813 .937 r
.74807 .42031 .75337 .42557 .76546 .42131 .76016 .4154 Mtetra
.686 .787 .927 r
.76016 .4154 .76546 .42131 .77761 .4172 .77232 .41082 Mtetra
.678 .769 .92 r
.77232 .41082 .77761 .4172 .78982 .41319 .78454 .4065 Mtetra
.672 .758 .915 r
.78454 .4065 .78982 .41319 .80209 .40924 .79684 .40233 Mtetra
.669 .751 .912 r
.79684 .40233 .80209 .40924 .81442 .40532 .80919 .39828 Mtetra
.666 .746 .91 r
.80919 .39828 .81442 .40532 .82679 .40141 .8216 .39428 Mtetra
.665 .744 .909 r
.8216 .39428 .82679 .40141 .83923 .3975 .83407 .3903 Mtetra
.664 .743 .908 r
.83407 .3903 .83923 .3975 .85171 .39358 .84659 .38634 Mtetra
.664 .742 .908 r
.84659 .38634 .85171 .39358 .86426 .38965 .85917 .38237 Mtetra
.85917 .38237 .86426 .38965 .87685 .38571 .87181 .37839 Mtetra
.664 .741 .908 r
.87181 .37839 .87685 .38571 .8895 .38175 .8845 .37439 Mtetra
.8845 .37439 .8895 .38175 .90221 .37777 .89724 .37038 Mtetra
.89724 .37038 .90221 .37777 .91497 .37377 .91004 .36635 Mtetra
.91004 .36635 .91497 .37377 .92778 .36976 .9229 .36231 Mtetra
.33554 .53892 .34209 .54503 .35259 .54172 .34605 .5356 Mtetra
.34605 .5356 .35259 .54172 .36312 .53841 .35661 .53226 Mtetra
.35661 .53226 .36312 .53841 .3737 .53508 .36722 .52891 Mtetra
.36722 .52891 .3737 .53508 .38431 .53174 .37786 .52554 Mtetra
.663 .741 .908 r
.37786 .52554 .38431 .53174 .39497 .52839 .38855 .52217 Mtetra
.38855 .52217 .39497 .52839 .40568 .52503 .39928 .51878 Mtetra
.39928 .51878 .40568 .52503 .41642 .52166 .41005 .51538 Mtetra
.41005 .51538 .41642 .52166 .42721 .51829 .42086 .51198 Mtetra
.662 .741 .908 r
.42086 .51198 .42721 .51829 .43804 .51493 .43172 .50859 Mtetra
.661 .74 .909 r
.43172 .50859 .43804 .51493 .44891 .5116 .44262 .50521 Mtetra
.659 .739 .909 r
.44262 .50521 .44891 .5116 .45983 .50832 .45357 .5019 Mtetra
.655 .737 .91 r
.45357 .5019 .45983 .50832 .47079 .50514 .46456 .49868 Mtetra
.648 .735 .913 r
.46456 .49868 .47079 .50514 .4818 .50212 .47559 .49563 Mtetra
.638 .732 .916 r
.47559 .49563 .4818 .50212 .49284 .49934 .48666 .49286 Mtetra
.622 .727 .922 r
.48666 .49286 .49284 .49934 .50394 .4969 .49779 .49047 Mtetra
.598 .722 .931 r
.49779 .49047 .50394 .4969 .51509 .49487 .50896 .48862 Mtetra
.564 .716 .943 r
.50896 .48862 .51509 .49487 .52629 .49335 .52019 .48745 Mtetra
.512 .708 .96 r
.52019 .48745 .52629 .49335 .53755 .49237 .53148 .48708 Mtetra
.434 .698 .976 r
.53148 .48708 .53755 .49237 .54889 .49191 .54285 .48757 Mtetra
.311 .674 .976 r
.54285 .48757 .54889 .49191 .56029 .49184 .5543 .48886 Mtetra
.121 .611 .91 r
.5543 .48886 .56029 .49184 .57177 .49195 .56583 .49075 Mtetra
0 .471 .709 r
.56583 .49075 .57177 .49195 .58332 .49196 .57746 .49291 Mtetra
.304 0 0 r
.57746 .49291 .58332 .49196 .59493 .49151 .58917 .49487 Mtetra
.385 0 0 r
.58917 .49487 .59493 .49151 .60659 .49026 .60096 .49607 Mtetra
.397 0 0 r
.60096 .49607 .60659 .49026 .61829 .48793 .61279 .49598 Mtetra
.375 0 .067 r
.61279 .49598 .61829 .48793 .63001 .48435 .62465 .49417 Mtetra
.335 0 .108 r
.62465 .49417 .63001 .48435 .64173 .47952 .6365 .4904 Mtetra
.282 0 .115 r
.6365 .4904 .64173 .47952 .65345 .47358 .64834 .48468 Mtetra
.216 0 .092 r
.64834 .48468 .65345 .47358 .66517 .46679 .66013 .47726 Mtetra
.132 0 .037 r
.66013 .47726 .66517 .46679 .67689 .45951 .6719 .46859 Mtetra
.02 0 0 r
.6719 .46859 .67689 .45951 .68863 .45208 .68365 .45921 Mtetra
0 0 0 r
.68365 .45921 .68863 .45208 .70041 .44481 .6954 .44966 Mtetra
.6954 .44966 .70041 .44481 .71223 .43791 .70717 .44041 Mtetra
.548 .906 .705 r
.70717 .44041 .71223 .43791 .7241 .43152 .71899 .43178 Mtetra
.686 .979 .88 r
.71899 .43178 .7241 .43152 .73605 .42566 .73088 .42396 Mtetra
.731 .954 .947 r
.73088 .42396 .73605 .42566 .74807 .42031 .74285 .417 Mtetra
.729 .897 .955 r
.74285 .417 .74807 .42031 .76016 .4154 .7549 .41082 Mtetra
.713 .846 .946 r
.7549 .41082 .76016 .4154 .77232 .41082 .76705 .40532 Mtetra
.697 .808 .934 r
.76705 .40532 .77232 .41082 .78454 .4065 .77927 .40033 Mtetra
.685 .782 .924 r
.77927 .40033 .78454 .4065 .79684 .40233 .79157 .39573 Mtetra
.677 .765 .918 r
.79157 .39573 .79684 .40233 .80919 .39828 .80394 .39138 Mtetra
.671 .755 .913 r
.80394 .39138 .80919 .39828 .8216 .39428 .81638 .3872 Mtetra
.668 .749 .911 r
.81638 .3872 .8216 .39428 .83407 .3903 .82887 .38311 Mtetra
.666 .745 .909 r
.82887 .38311 .83407 .3903 .84659 .38634 .84143 .37906 Mtetra
.665 .743 .909 r
.84143 .37906 .84659 .38634 .85917 .38237 .85405 .37504 Mtetra
.664 .742 .908 r
.85405 .37504 .85917 .38237 .87181 .37839 .86672 .37101 Mtetra
.86672 .37101 .87181 .37839 .8845 .37439 .87945 .36698 Mtetra
.664 .741 .908 r
.87945 .36698 .8845 .37439 .89724 .37038 .89224 .36293 Mtetra
.89224 .36293 .89724 .37038 .91004 .36635 .90508 .35887 Mtetra
.90508 .35887 .91004 .36635 .9229 .36231 .91798 .35479 Mtetra
.32893 .53277 .33554 .53892 .34605 .5356 .33948 .52942 Mtetra
.33948 .52942 .34605 .5356 .35661 .53226 .35006 .52606 Mtetra
.35006 .52606 .35661 .53226 .36722 .52891 .36069 .52268 Mtetra
.36069 .52268 .36722 .52891 .37786 .52554 .37136 .51929 Mtetra
.37136 .51929 .37786 .52554 .38855 .52217 .38207 .51589 Mtetra
.663 .741 .908 r
.38207 .51589 .38855 .52217 .39928 .51878 .39283 .51248 Mtetra
.39283 .51248 .39928 .51878 .41005 .51538 .40363 .50905 Mtetra
.40363 .50905 .41005 .51538 .42086 .51198 .41447 .50562 Mtetra
.41447 .50562 .42086 .51198 .43172 .50859 .42536 .50219 Mtetra
.661 .74 .908 r
.42536 .50219 .43172 .50859 .44262 .50521 .43629 .49878 Mtetra
.66 .739 .909 r
.43629 .49878 .44262 .50521 .45357 .5019 .44726 .49541 Mtetra
.656 .737 .91 r
.44726 .49541 .45357 .5019 .46456 .49868 .45828 .49213 Mtetra
.65 .734 .911 r
.45828 .49213 .46456 .49868 .47559 .49563 .46934 .48902 Mtetra
.64 .73 .914 r
.46934 .48902 .47559 .49563 .48666 .49286 .48044 .48617 Mtetra
.624 .723 .918 r
.48044 .48617 .48666 .49286 .49779 .49047 .49159 .48373 Mtetra
.599 .713 .924 r
.49159 .48373 .49779 .49047 .50896 .48862 .50279 .4819 Mtetra
.562 .7 .934 r
.50279 .4819 .50896 .48862 .52019 .48745 .51404 .48087 Mtetra
.505 .682 .946 r
.51404 .48087 .52019 .48745 .53148 .48708 .52536 .48088 Mtetra
.417 .656 .958 r
.52536 .48088 .53148 .48708 .54285 .48757 .53675 .48208 Mtetra
.279 .61 .956 r
.53675 .48208 .54285 .48757 .5543 .48886 .54824 .48454 Mtetra
.06 .52 .894 r
.54824 .48454 .5543 .48886 .56583 .49075 .55982 .48817 Mtetra
0 .35 .691 r
.55982 .48817 .56583 .49075 .57746 .49291 .57152 .49268 Mtetra
.452 0 0 r
.57152 .49268 .57746 .49291 .58917 .49487 .58333 .49755 Mtetra
.539 0 0 r
.58333 .49755 .58917 .49487 .60096 .49607 .59524 .50205 Mtetra
.54 .068 .082 r
.59524 .50205 .60096 .49607 .61279 .49598 .60723 .50538 Mtetra
.508 .089 .18 r
.60723 .50538 .61279 .49598 .62465 .49417 .61927 .50674 Mtetra
.462 .083 .232 r
.61927 .50674 .62465 .49417 .6365 .4904 .63131 .50552 Mtetra
.411 .06 .256 r
.63131 .50552 .6365 .4904 .64834 .48468 .64332 .50138 Mtetra
.356 .024 .259 r
.64332 .50138 .64834 .48468 .66013 .47726 .65526 .49439 Mtetra
.296 0 .243 r
.65526 .49439 .66013 .47726 .6719 .46859 .66713 .48495 Mtetra
.226 0 .206 r
.66713 .48495 .6719 .46859 .68365 .45921 .67892 .47375 Mtetra
.142 0 .143 r
.67892 .47375 .68365 .45921 .6954 .44966 .69066 .46159 Mtetra
.029 0 .037 r
.69066 .46159 .6954 .44966 .70717 .44041 .70239 .44928 Mtetra
0 0 0 r
.70239 .44928 .70717 .44041 .71899 .43178 .71413 .43748 Mtetra
.71413 .43748 .71899 .43178 .73088 .42396 .72593 .42666 Mtetra
.581 .915 .687 r
.72593 .42666 .73088 .42396 .74285 .417 .73781 .41706 Mtetra
.717 .986 .882 r
.73781 .41706 .74285 .417 .7549 .41082 .74978 .40871 Mtetra
.745 .946 .946 r
.74978 .40871 .7549 .41082 .76705 .40532 .76186 .40152 Mtetra
.731 .883 .95 r
.76186 .40152 .76705 .40532 .77927 .40033 .77404 .39529 Mtetra
.711 .832 .94 r
.77404 .39529 .77927 .40033 .79157 .39573 .78632 .38982 Mtetra
.694 .796 .929 r
.78632 .38982 .79157 .39573 .80394 .39138 .79868 .38489 Mtetra
.682 .773 .92 r
.79868 .38489 .80394 .39138 .81638 .3872 .81113 .38033 Mtetra
.674 .759 .915 r
.81113 .38033 .81638 .3872 .82887 .38311 .82365 .376 Mtetra
.669 .751 .912 r
.82365 .376 .82887 .38311 .84143 .37906 .83624 .37181 Mtetra
.667 .746 .91 r
.83624 .37181 .84143 .37906 .85405 .37504 .84889 .36769 Mtetra
.665 .744 .909 r
.84889 .36769 .85405 .37504 .86672 .37101 .8616 .3636 Mtetra
.664 .742 .908 r
.8616 .3636 .86672 .37101 .87945 .36698 .87437 .35952 Mtetra
.87437 .35952 .87945 .36698 .89224 .36293 .88719 .35543 Mtetra
.88719 .35543 .89224 .36293 .90508 .35887 .90008 .35133 Mtetra
.664 .741 .908 r
.90008 .35133 .90508 .35887 .91798 .35479 .91302 .34722 Mtetra
.32228 .52658 .32893 .53277 .33948 .52942 .33285 .5232 Mtetra
.33285 .5232 .33948 .52942 .35006 .52606 .34346 .51982 Mtetra
.34346 .51982 .35006 .52606 .36069 .52268 .35411 .51641 Mtetra
.35411 .51641 .36069 .52268 .37136 .51929 .36481 .513 Mtetra
.36481 .513 .37136 .51929 .38207 .51589 .37555 .50957 Mtetra
.663 .741 .908 r
.37555 .50957 .38207 .51589 .39283 .51248 .38633 .50613 Mtetra
.38633 .50613 .39283 .51248 .40363 .50905 .39716 .50268 Mtetra
.39716 .50268 .40363 .50905 .41447 .50562 .40803 .49922 Mtetra
.40803 .49922 .41447 .50562 .42536 .50219 .41895 .49575 Mtetra
.662 .74 .908 r
.41895 .49575 .42536 .50219 .43629 .49878 .4299 .4923 Mtetra
.661 .739 .908 r
.4299 .4923 .43629 .49878 .44726 .49541 .44091 .48887 Mtetra
.658 .738 .909 r
.44091 .48887 .44726 .49541 .45828 .49213 .45195 .48552 Mtetra
.652 .735 .91 r
.45195 .48552 .45828 .49213 .46934 .48902 .46304 .4823 Mtetra
.644 .73 .911 r
.46304 .4823 .46934 .48902 .48044 .48617 .47417 .47932 Mtetra
.629 .722 .914 r
.47417 .47932 .48044 .48617 .49159 .48373 .48535 .47674 Mtetra
.606 .709 .918 r
.48535 .47674 .49159 .48373 .50279 .4819 .49657 .47475 Mtetra
.57 .692 .923 r
.49657 .47475 .50279 .4819 .51404 .48087 .50785 .47362 Mtetra
.515 .666 .93 r
.50785 .47362 .51404 .48087 .52536 .48088 .51919 .47364 Mtetra
.432 .628 .936 r
.51919 .47364 .52536 .48088 .53675 .48208 .5306 .47512 Mtetra
.304 .57 .933 r
.5306 .47512 .53675 .48208 .54824 .48454 .54211 .47827 Mtetra
.106 .476 .895 r
.54211 .47827 .54824 .48454 .55982 .48817 .55373 .48318 Mtetra
0 .32 .765 r
.55373 .48318 .55982 .48817 .57152 .49268 .56547 .4897 Mtetra
.465 0 0 r
.56547 .4897 .57152 .49268 .58333 .49755 .57736 .49741 Mtetra
.624 .063 0 r
.57736 .49741 .58333 .49755 .59524 .50205 .58938 .50555 Mtetra
.649 .151 .052 r
.58938 .50555 .59524 .50205 .60723 .50538 .60153 .51311 Mtetra
.614 .177 .188 r
.60153 .51311 .60723 .50538 .61927 .50674 .61376 .51895 Mtetra
.558 .171 .264 r
.61376 .51895 .61927 .50674 .63131 .50552 .62603 .52196 Mtetra
.498 .148 .304 r
.62603 .52196 .63131 .50552 .64332 .50138 .63828 .52131 Mtetra
.438 .116 .321 r
.63828 .52131 .64332 .50138 .65526 .49439 .65045 .51658 Mtetra
.378 .077 .322 r
.65045 .51658 .65526 .49439 .66713 .48495 .6625 .5079 Mtetra
.318 .031 .309 r
.6625 .5079 .66713 .48495 .67892 .47375 .67442 .49589 Mtetra
.254 0 .282 r
.67442 .49589 .67892 .47375 .69066 .46159 .68622 .48154 Mtetra
.182 0 .236 r
.68622 .48154 .69066 .46159 .70239 .44928 .69793 .46601 Mtetra
.091 0 .161 r
.69793 .46601 .70239 .44928 .71413 .43748 .7096 .45039 Mtetra
0 0 .038 r
.7096 .45039 .71413 .43748 .72593 .42666 .72128 .43559 Mtetra
0 0 0 r
.72128 .43559 .72593 .42666 .73781 .41706 .73302 .4222 Mtetra
.73302 .4222 .73781 .41706 .74978 .40871 .74487 .41054 Mtetra
.668 .963 .76 r
.74487 .41054 .74978 .40871 .76186 .40152 .75683 .40061 Mtetra
.753 .981 .913 r
.75683 .40061 .76186 .40152 .77404 .39529 .76891 .39227 Mtetra
.75 .919 .948 r
.76891 .39227 .77404 .39529 .78632 .38982 .78113 .38524 Mtetra
.725 .856 .943 r
.78113 .38524 .78632 .38982 .79868 .38489 .79346 .37923 Mtetra
.703 .811 .932 r
.79346 .37923 .79868 .38489 .81113 .38033 .80589 .37394 Mtetra
.687 .782 .923 r
.80589 .37394 .81113 .38033 .82365 .376 .81842 .36915 Mtetra
.677 .764 .916 r
.81842 .36915 .82365 .376 .83624 .37181 .83102 .36467 Mtetra
.671 .753 .913 r
.83102 .36467 .83624 .37181 .84889 .36769 .8437 .36037 Mtetra
.667 .748 .91 r
.8437 .36037 .84889 .36769 .8616 .3636 .85644 .35617 Mtetra
.665 .744 .909 r
.85644 .35617 .8616 .3636 .87437 .35952 .86925 .35202 Mtetra
.664 .743 .908 r
.86925 .35202 .87437 .35952 .88719 .35543 .88211 .34788 Mtetra
.664 .742 .908 r
.88211 .34788 .88719 .35543 .90008 .35133 .89503 .34374 Mtetra
.89503 .34374 .90008 .35133 .91302 .34722 .90801 .33959 Mtetra
.664 .741 .908 r
.31558 .52034 .32228 .52658 .33285 .5232 .32617 .51694 Mtetra
.32617 .51694 .33285 .5232 .34346 .51982 .33681 .51353 Mtetra
.33681 .51353 .34346 .51982 .35411 .51641 .34749 .5101 Mtetra
.34749 .5101 .35411 .51641 .36481 .513 .35821 .50666 Mtetra
.35821 .50666 .36481 .513 .37555 .50957 .36898 .5032 Mtetra
.36898 .5032 .37555 .50957 .38633 .50613 .37979 .49974 Mtetra
.663 .741 .908 r
.37979 .49974 .38633 .50613 .39716 .50268 .39064 .49626 Mtetra
.39064 .49626 .39716 .50268 .40803 .49922 .40154 .49277 Mtetra
.40154 .49277 .40803 .49922 .41895 .49575 .41248 .48927 Mtetra
.41248 .48927 .41895 .49575 .4299 .4923 .42347 .48577 Mtetra
.661 .74 .908 r
.42347 .48577 .4299 .4923 .44091 .48887 .4345 .48229 Mtetra
.659 .738 .908 r
.4345 .48229 .44091 .48887 .45195 .48552 .44558 .47886 Mtetra
.655 .736 .909 r
.44558 .47886 .45195 .48552 .46304 .4823 .45669 .47553 Mtetra
.648 .731 .909 r
.45669 .47553 .46304 .4823 .47417 .47932 .46786 .47239 Mtetra
.636 .723 .91 r
.46786 .47239 .47417 .47932 .48535 .47674 .47906 .46959 Mtetra
.617 .71 .912 r
.47906 .46959 .48535 .47674 .49657 .47475 .49032 .46731 Mtetra
.586 .691 .914 r
.49032 .46731 .49657 .47475 .50785 .47362 .50162 .46584 Mtetra
.538 .661 .916 r
.50162 .46584 .50785 .47362 .51919 .47364 .51298 .46553 Mtetra
.466 .619 .916 r
.51298 .46553 .51919 .47364 .5306 .47512 .52441 .46676 Mtetra
.361 .557 .909 r
.52441 .46676 .5306 .47512 .54211 .47827 .53593 .46992 Mtetra
.207 .469 .885 r
.53593 .46992 .54211 .47827 .55373 .48318 .54756 .47528 Mtetra
0 .343 .822 r
.54756 .47528 .55373 .48318 .56547 .4897 .55932 .48295 Mtetra
0 .171 .679 r
.55932 .48295 .56547 .4897 .57736 .49741 .57125 .49271 Mtetra
.556 .021 0 r
.57125 .49271 .57736 .49741 .58938 .50555 .58335 .50397 Mtetra
.704 .165 0 r
.58335 .50397 .58938 .50555 .60153 .51311 .59562 .51571 Mtetra
.718 .227 .074 r
.59562 .51571 .60153 .51311 .61376 .51895 .60803 .5266 Mtetra
.663 .231 .211 r
.60803 .5266 .61376 .51895 .62603 .52196 .62053 .53511 Mtetra
.588 .207 .287 r
.62053 .53511 .62603 .52196 .63828 .52131 .63306 .5398 Mtetra
.511 .171 .327 r
.63306 .5398 .63828 .52131 .65045 .51658 .64552 .53958 Mtetra
.439 .131 .344 r
.64552 .53958 .65045 .51658 .6625 .5079 .65785 .53399 Mtetra
.372 .087 .345 r
.65785 .53399 .6625 .5079 .67442 .49589 .67001 .52325 Mtetra
.308 .04 .334 r
.67001 .52325 .67442 .49589 .68622 .48154 .68196 .50826 Mtetra
.245 0 .311 r
.68196 .50826 .68622 .48154 .69793 .46601 .69373 .49036 Mtetra
.177 0 .273 r
.69373 .49036 .69793 .46601 .7096 .45039 .70538 .47108 Mtetra
.096 0 .213 r
.70538 .47108 .7096 .45039 .72128 .43559 .71697 .45187 Mtetra
0 0 .115 r
.71697 .45187 .72128 .43559 .73302 .4222 .72857 .43384 Mtetra
0 0 0 r
.72857 .43384 .73302 .4222 .74487 .41054 .74024 .41775 Mtetra
.74024 .41775 .74487 .41054 .75683 .40061 .75203 .40394 Mtetra
.617 .911 .632 r
.75203 .40394 .75683 .40061 .76891 .39227 .76397 .39239 Mtetra
.752 .994 .862 r
.76397 .39239 .76891 .39227 .78113 .38524 .77607 .38287 Mtetra
.766 .947 .937 r
.77607 .38287 .78113 .38524 .79346 .37923 .78831 .37503 Mtetra
.74 .877 .944 r
.78831 .37503 .79346 .37923 .80589 .37394 .80069 .36848 Mtetra
.712 .824 .934 r
.80069 .36848 .80589 .37394 .81842 .36915 .81319 .36284 Mtetra
.693 .789 .925 r
.81319 .36284 .81842 .36915 .83102 .36467 .82579 .35782 Mtetra
.68 .768 .918 r
.82579 .35782 .83102 .36467 .8437 .36037 .83848 .35319 Mtetra
.673 .756 .913 r
.83848 .35319 .8437 .36037 .85644 .35617 .85125 .34878 Mtetra
.668 .749 .911 r
.85125 .34878 .85644 .35617 .86925 .35202 .86409 .34451 Mtetra
.666 .745 .909 r
.86409 .34451 .86925 .35202 .88211 .34788 .87699 .34029 Mtetra
.665 .743 .909 r
.87699 .34029 .88211 .34788 .89503 .34374 .88995 .33609 Mtetra
.664 .742 .908 r
.88995 .33609 .89503 .34374 .90801 .33959 .90297 .3319 Mtetra
.664 .741 .908 r
.30883 .51405 .31558 .52034 .32617 .51694 .31945 .51063 Mtetra
.31945 .51063 .32617 .51694 .33681 .51353 .33011 .50719 Mtetra
.33011 .50719 .33681 .51353 .34749 .5101 .34082 .50374 Mtetra
.34082 .50374 .34749 .5101 .35821 .50666 .35157 .50027 Mtetra
.35157 .50027 .35821 .50666 .36898 .5032 .36236 .49679 Mtetra
.36236 .49679 .36898 .5032 .37979 .49974 .3732 .4933 Mtetra
.3732 .4933 .37979 .49974 .39064 .49626 .38408 .48979 Mtetra
.663 .741 .908 r
.38408 .48979 .39064 .49626 .40154 .49277 .39501 .48627 Mtetra
.39501 .48627 .40154 .49277 .41248 .48927 .40598 .48274 Mtetra
.40598 .48274 .41248 .48927 .42347 .48577 .41699 .4792 Mtetra
.662 .74 .908 r
.41699 .4792 .42347 .48577 .4345 .48229 .42805 .47568 Mtetra
.661 .739 .908 r
.42805 .47568 .4345 .48229 .44558 .47886 .43915 .47217 Mtetra
.658 .737 .908 r
.43915 .47217 .44558 .47886 .45669 .47553 .4503 .46874 Mtetra
.653 .733 .908 r
.4503 .46874 .45669 .47553 .46786 .47239 .46149 .46544 Mtetra
.644 .726 .908 r
.46149 .46544 .46786 .47239 .47906 .46959 .47273 .46239 Mtetra
.629 .715 .908 r
.47273 .46239 .47906 .46959 .49032 .46731 .48401 .45976 Mtetra
.604 .696 .908 r
.48401 .45976 .49032 .46731 .50162 .46584 .49534 .45782 Mtetra
.566 .667 .906 r
.49534 .45782 .50162 .46584 .51298 .46553 .50673 .4569 Mtetra
.508 .625 .902 r
.50673 .4569 .51298 .46553 .52441 .46676 .51817 .45744 Mtetra
.425 .566 .891 r
.51817 .45744 .52441 .46676 .53593 .46992 .5297 .45991 Mtetra
.312 .485 .87 r
.5297 .45991 .53593 .46992 .54756 .47528 .54133 .46479 Mtetra
.163 .383 .831 r
.54133 .46479 .54756 .47528 .55932 .48295 .5531 .4724 Mtetra
0 .258 .766 r
.5531 .4724 .55932 .48295 .57125 .49271 .56503 .48284 Mtetra
0 .113 .662 r
.56503 .48284 .57125 .49271 .58335 .50397 .57715 .49584 Mtetra
0 0 .5 r
.57715 .49584 .58335 .50397 .59562 .51571 .58948 .51061 Mtetra
.687 .177 0 r
.58948 .51061 .59562 .51571 .60803 .5266 .60201 .52589 Mtetra
.759 .247 0 r
.60201 .52589 .60803 .5266 .62053 .53511 .6147 .53997 Mtetra
.71 .247 .149 r
.6147 .53997 .62053 .53511 .63306 .5398 .62748 .55096 Mtetra
.611 .209 .256 r
.62748 .55096 .63306 .5398 .64552 .53958 .64026 .55709 Mtetra
.509 .159 .31 r
.64026 .55709 .64552 .53958 .65785 .53399 .65293 .55706 Mtetra
.418 .11 .333 r
.65293 .55706 .65785 .53399 .67001 .52325 .66542 .55036 Mtetra
.339 .061 .337 r
.66542 .55036 .67001 .52325 .68196 .50826 .67765 .53736 Mtetra
.268 .013 .329 r
.67765 .53736 .68196 .50826 .69373 .49036 .68961 .51926 Mtetra
.203 0 .308 r
.68961 .51926 .69373 .49036 .70538 .47108 .70135 .49778 Mtetra
.136 0 .274 r
.70135 .49778 .70538 .47108 .71697 .45187 .71292 .47482 Mtetra
.06 0 .22 r
.71292 .47482 .71697 .45187 .72857 .43384 .72441 .45212 Mtetra
0 0 .134 r
.72441 .45212 .72857 .43384 .74024 .41775 .73592 .43105 Mtetra
0 0 0 r
.73592 .43105 .74024 .41775 .75203 .40394 .74752 .41244 Mtetra
.74752 .41244 .75203 .40394 .76397 .39239 .75927 .39664 Mtetra
.601 .877 .555 r
.75927 .39664 .76397 .39239 .77607 .38287 .77119 .38362 Mtetra
.756 .994 .818 r
.77119 .38362 .77607 .38287 .78831 .37503 .78329 .37306 Mtetra
.78 .963 .924 r
.78329 .37306 .78831 .37503 .80069 .36848 .79557 .36451 Mtetra
.752 .891 .942 r
.79557 .36451 .80069 .36848 .81319 .36284 .80801 .35747 Mtetra
.72 .833 .935 r
.80801 .35747 .81319 .36284 .82579 .35782 .82058 .35153 Mtetra
.697 .795 .925 r
.82058 .35153 .82579 .35782 .83848 .35319 .83326 .34631 Mtetra
.683 .771 .918 r
.83326 .34631 .83848 .35319 .85125 .34878 .84604 .34154 Mtetra
.674 .757 .913 r
.84604 .34154 .85125 .34878 .86409 .34451 .85889 .33704 Mtetra
.669 .749 .911 r
.85889 .33704 .86409 .34451 .87699 .34029 .87183 .33269 Mtetra
.666 .745 .909 r
.87183 .33269 .87699 .34029 .88995 .33609 .88482 .32841 Mtetra
.665 .743 .909 r
.88482 .32841 .88995 .33609 .90297 .3319 .89789 .32415 Mtetra
.664 .741 .908 r
.30203 .50772 .30883 .51405 .31945 .51063 .31267 .50427 Mtetra
.31267 .50427 .31945 .51063 .33011 .50719 .32336 .5008 Mtetra
.32336 .5008 .33011 .50719 .34082 .50374 .33409 .49733 Mtetra
.33409 .49733 .34082 .50374 .35157 .50027 .34487 .49383 Mtetra
.34487 .49383 .35157 .50027 .36236 .49679 .35569 .49033 Mtetra
.35569 .49033 .36236 .49679 .3732 .4933 .36656 .48681 Mtetra
.36656 .48681 .3732 .4933 .38408 .48979 .37746 .48327 Mtetra
.663 .741 .908 r
.37746 .48327 .38408 .48979 .39501 .48627 .38842 .47973 Mtetra
.38842 .47973 .39501 .48627 .40598 .48274 .39942 .47617 Mtetra
.39942 .47617 .40598 .48274 .41699 .4792 .41046 .4726 Mtetra
.41046 .4726 .41699 .4792 .42805 .47568 .42155 .46902 Mtetra
.662 .74 .908 r
.42155 .46902 .42805 .47568 .43915 .47217 .43268 .46546 Mtetra
.66 .738 .908 r
.43268 .46546 .43915 .47217 .4503 .46874 .44386 .46193 Mtetra
.657 .736 .908 r
.44386 .46193 .4503 .46874 .46149 .46544 .45508 .45849 Mtetra
.651 .73 .907 r
.45508 .45849 .46149 .46544 .47273 .46239 .46635 .45522 Mtetra
.64 .721 .906 r
.46635 .45522 .47273 .46239 .48401 .45976 .47767 .45225 Mtetra
.622 .705 .905 r
.47767 .45225 .48401 .45976 .49534 .45782 .48903 .44979 Mtetra
.593 .68 .902 r
.48903 .44979 .49534 .45782 .50673 .4569 .50043 .44815 Mtetra
.549 .643 .895 r
.50043 .44815 .50673 .4569 .51817 .45744 .5119 .44774 Mtetra
.486 .589 .882 r
.5119 .44774 .51817 .45744 .5297 .45991 .52344 .44905 Mtetra
.402 .517 .86 r
.52344 .44905 .5297 .45991 .54133 .46479 .53507 .45264 Mtetra
.296 .429 .827 r
.53507 .45264 .54133 .46479 .5531 .4724 .54682 .45905 Mtetra
.174 .331 .783 r
.54682 .45905 .5531 .4724 .56503 .48284 .55872 .46864 Mtetra
.04 .228 .729 r
.55872 .46864 .56503 .48284 .57715 .49584 .57082 .4815 Mtetra
0 .127 .67 r
.57082 .4815 .57715 .49584 .58948 .51061 .58314 .49727 Mtetra
0 .029 .601 r
.58314 .49727 .58948 .51061 .60201 .52589 .5957 .51501 Mtetra
0 0 .507 r
.5957 .51501 .60201 .52589 .6147 .53997 .60848 .53321 Mtetra
.635 .15 0 r
.60848 .53321 .6147 .53997 .62748 .55096 .62143 .54985 Mtetra
.718 .184 0 r
.62143 .54985 .62748 .55096 .64026 .55709 .63448 .56273 Mtetra
.625 .148 .1 r
.63448 .56273 .64026 .55709 .65293 .55706 .64749 .56979 Mtetra
.478 .087 .219 r
.64749 .56979 .65293 .55706 .66542 .55036 .66035 .56961 Mtetra
.354 .03 .271 r
.66035 .56961 .66542 .55036 .67765 .53736 .67296 .56166 Mtetra
.258 0 .288 r
.67296 .56166 .67765 .53736 .68961 .51926 .68525 .54649 Mtetra
.182 0 .286 r
.68525 .54649 .68961 .51926 .70135 .49778 .69722 .52558 Mtetra
.115 0 .269 r
.69722 .52558 .70135 .49778 .71292 .47482 .7089 .50099 Mtetra
.05 0 .238 r
.7089 .50099 .71292 .47482 .72441 .45212 .7204 .47494 Mtetra
0 0 .186 r
.7204 .47494 .72441 .45212 .73592 .43105 .73182 .44941 Mtetra
0 0 .103 r
.73182 .44941 .73592 .43105 .74752 .41244 .74326 .4259 Mtetra
0 0 0 r
.74326 .4259 .74752 .41244 .75927 .39664 .7548 .40532 Mtetra
.7548 .40532 .75927 .39664 .77119 .38362 .76652 .38803 Mtetra
.636 .886 .548 r
.76652 .38803 .77119 .38362 .78329 .37306 .77845 .37391 Mtetra
.775 .996 .803 r
.77845 .37391 .78329 .37306 .79557 .36451 .79058 .36258 Mtetra
.793 .967 .915 r
.79058 .36258 .79557 .36451 .80801 .35747 .8029 .3535 Mtetra
.76 .896 .938 r
.8029 .3535 .80801 .35747 .82058 .35153 .8154 .34612 Mtetra
.725 .837 .933 r
.8154 .34612 .82058 .35153 .83326 .34631 .82804 .33995 Mtetra
.7 .797 .925 r
.82804 .33995 .83326 .34631 .84604 .34154 .84081 .33458 Mtetra
.684 .772 .918 r
.84081 .33458 .84604 .34154 .85889 .33704 .85368 .32971 Mtetra
.675 .758 .913 r
.85368 .32971 .85889 .33704 .87183 .33269 .86664 .32513 Mtetra
.669 .75 .911 r
.86664 .32513 .87183 .33269 .88482 .32841 .87966 .32071 Mtetra
.666 .745 .909 r
.87966 .32071 .88482 .32841 .89789 .32415 .89276 .31637 Mtetra
.664 .741 .908 r
.29517 .50134 .30203 .50772 .31267 .50427 .30585 .49786 Mtetra
.30585 .49786 .31267 .50427 .32336 .5008 .31656 .49437 Mtetra
.31656 .49437 .32336 .5008 .33409 .49733 .32732 .49087 Mtetra
.32732 .49087 .33409 .49733 .34487 .49383 .33812 .48735 Mtetra
.33812 .48735 .34487 .49383 .35569 .49033 .34897 .48382 Mtetra
.34897 .48382 .35569 .49033 .36656 .48681 .35986 .48027 Mtetra
.35986 .48027 .36656 .48681 .37746 .48327 .3708 .47671 Mtetra
.3708 .47671 .37746 .48327 .38842 .47973 .38178 .47313 Mtetra
.663 .741 .908 r
.38178 .47313 .38842 .47973 .39942 .47617 .39281 .46954 Mtetra
.39281 .46954 .39942 .47617 .41046 .4726 .40388 .46594 Mtetra
.40388 .46594 .41046 .4726 .42155 .46902 .415 .46233 Mtetra
.415 .46233 .42155 .46902 .43268 .46546 .42616 .45872 Mtetra
.662 .74 .908 r
.42616 .45872 .43268 .46546 .44386 .46193 .43737 .45512 Mtetra
.66 .738 .907 r
.43737 .45512 .44386 .46193 .45508 .45849 .44862 .45157 Mtetra
.656 .734 .907 r
.44862 .45157 .45508 .45849 .46635 .45522 .45992 .44811 Mtetra
.649 .727 .906 r
.45992 .44811 .46635 .45522 .47767 .45225 .47127 .44485 Mtetra
.637 .715 .904 r
.47127 .44485 .47767 .45225 .48903 .44979 .48266 .44194 Mtetra
.617 .696 .9 r
.48266 .44194 .48903 .44979 .50043 .44815 .4941 .4396 Mtetra
.585 .665 .894 r
.4941 .4396 .50043 .44815 .5119 .44774 .50559 .43819 Mtetra
.539 .62 .881 r
.50559 .43819 .5119 .44774 .52344 .44905 .51714 .43815 Mtetra
.476 .558 .86 r
.51714 .43815 .52344 .44905 .53507 .45264 .52877 .44004 Mtetra
.398 .482 .829 r
.52877 .44004 .53507 .45264 .54682 .45905 .54051 .44445 Mtetra
.31 .396 .79 r
.54051 .44445 .54682 .45905 .55872 .46864 .55237 .45195 Mtetra
.22 .311 .746 r
.55237 .45195 .55872 .46864 .57082 .4815 .56442 .46293 Mtetra
.135 .235 .704 r
.56442 .46293 .57082 .4815 .58314 .49727 .57667 .47746 Mtetra
.059 .172 .669 r
.57667 .47746 .58314 .49727 .5957 .51501 .58918 .49508 Mtetra
0 .125 .645 r
.58918 .49508 .5957 .51501 .60848 .53321 .60194 .51473 Mtetra
0 .096 .635 r
.60194 .51473 .60848 .53321 .62143 .54985 .61494 .53471 Mtetra
0 .089 .643 r
.61494 .53471 .62143 .54985 .63448 .56273 .62812 .55281 Mtetra
0 .121 .667 r
.62812 .55281 .63448 .56273 .64749 .56979 .64137 .56659 Mtetra
.357 0 0 r
.64137 .56659 .64749 .56979 .66035 .56961 .65457 .57388 Mtetra
.274 0 0 r
.65457 .57388 .66035 .56961 .67296 .56166 .66757 .57317 Mtetra
.133 0 .033 r
.66757 .57317 .67296 .56166 .68525 .54649 .68027 .56401 Mtetra
.049 0 .13 r
.68027 .56401 .68525 .54649 .69722 .52558 .69261 .54712 Mtetra
0 0 .164 r
.69261 .54712 .69722 .52558 .7089 .50099 .70457 .52418 Mtetra
0 0 .166 r
.70457 .52418 .7089 .50099 .7204 .47494 .71623 .49749 Mtetra
0 0 .144 r
.71623 .49749 .7204 .47494 .73182 .44941 .72769 .46947 Mtetra
0 0 .096 r
.72769 .46947 .73182 .44941 .74326 .4259 .73907 .44222 Mtetra
0 0 .013 r
.73907 .44222 .74326 .4259 .7548 .40532 .75048 .41732 Mtetra
0 0 0 r
.75048 .41732 .7548 .40532 .76652 .38803 .76202 .39567 Mtetra
.76202 .39567 .76652 .38803 .77845 .37391 .77375 .37759 Mtetra
.713 .931 .605 r
.77375 .37759 .77845 .37391 .79058 .36258 .78571 .36292 Mtetra
.806 1 .819 r
.78571 .36292 .79058 .36258 .8029 .3535 .79789 .35122 Mtetra
.803 .96 .913 r
.79789 .35122 .8029 .3535 .8154 .34612 .81028 .3419 Mtetra
.764 .891 .934 r
.81028 .3419 .8154 .34612 .82804 .33995 .82286 .33436 Mtetra
.727 .834 .931 r
.82286 .33436 .82804 .33995 .84081 .33458 .83559 .32808 Mtetra
.701 .795 .923 r
.83559 .32808 .84081 .33458 .85368 .32971 .84845 .32263 Mtetra
.685 .771 .917 r
.84845 .32263 .85368 .32971 .86664 .32513 .86142 .31769 Mtetra
.675 .757 .913 r
.86142 .31769 .86664 .32513 .87966 .32071 .87447 .31305 Mtetra
.669 .749 .911 r
.87447 .31305 .87966 .32071 .89276 .31637 .8876 .30858 Mtetra
.664 .741 .908 r
.28827 .49491 .29517 .50134 .30585 .49786 .29897 .49141 Mtetra
.29897 .49141 .30585 .49786 .31656 .49437 .30971 .48789 Mtetra
.30971 .48789 .31656 .49437 .32732 .49087 .3205 .48436 Mtetra
.3205 .48436 .32732 .49087 .33812 .48735 .33133 .48082 Mtetra
.33133 .48082 .33812 .48735 .34897 .48382 .3422 .47726 Mtetra
.3422 .47726 .34897 .48382 .35986 .48027 .35312 .47368 Mtetra
.35312 .47368 .35986 .48027 .3708 .47671 .36408 .47009 Mtetra
.36408 .47009 .3708 .47671 .38178 .47313 .37509 .46649 Mtetra
.37509 .46649 .38178 .47313 .39281 .46954 .38615 .46287 Mtetra
.663 .741 .908 r
.38615 .46287 .39281 .46954 .40388 .46594 .39725 .45924 Mtetra
.39725 .45924 .40388 .46594 .415 .46233 .40839 .4556 Mtetra
.40839 .4556 .415 .46233 .42616 .45872 .41959 .45195 Mtetra
.663 .74 .908 r
.41959 .45195 .42616 .45872 .43737 .45512 .43083 .44829 Mtetra
.662 .739 .908 r
.43083 .44829 .43737 .45512 .44862 .45157 .44211 .44466 Mtetra
.659 .737 .907 r
.44211 .44466 .44862 .45157 .45992 .44811 .45344 .44107 Mtetra
.655 .733 .906 r
.45344 .44107 .45992 .44811 .47127 .44485 .46482 .43759 Mtetra
.648 .725 .905 r
.46482 .43759 .47127 .44485 .48266 .44194 .47624 .43432 Mtetra
.635 .711 .901 r
.47624 .43432 .48266 .44194 .4941 .4396 .48772 .43142 Mtetra
.614 .688 .896 r
.48772 .43142 .4941 .4396 .50559 .43819 .49924 .42914 Mtetra
.582 .653 .885 r
.49924 .42914 .50559 .43819 .51714 .43815 .51081 .42783 Mtetra
.537 .603 .867 r
.51081 .42783 .51714 .43815 .52877 .44004 .52245 .42797 Mtetra
.478 .537 .84 r
.52245 .42797 .52877 .44004 .54051 .44445 .53418 .43013 Mtetra
.409 .462 .803 r
.53418 .43013 .54051 .44445 .55237 .45195 .54601 .4349 Mtetra
.34 .384 .762 r
.54601 .4349 .55237 .45195 .56442 .46293 .55799 .44287 Mtetra
.277 .314 .72 r
.55799 .44287 .56442 .46293 .57667 .47746 .57016 .45441 Mtetra
.227 .258 .686 r
.57016 .45441 .57667 .47746 .58918 .49508 .58256 .46953 Mtetra
.192 .219 .661 r
.58256 .46953 .58918 .49508 .60194 .51473 .59522 .48772 Mtetra
.172 .2 .648 r
.59522 .48772 .60194 .51473 .61494 .53471 .60814 .50785 Mtetra
.17 .2 .65 r
.60814 .50785 .61494 .53471 .62812 .55281 .62131 .52812 Mtetra
.188 .227 .671 r
.62131 .52812 .62812 .55281 .64137 .56659 .63464 .54625 Mtetra
.236 .294 .72 r
.63464 .54625 .64137 .56659 .65457 .57388 .64803 .55976 Mtetra
.342 .438 .815 r
.64803 .55976 .65457 .57388 .66757 .57317 .66134 .56647 Mtetra
.555 .732 .958 r
.66134 .56647 .66757 .57317 .68027 .56401 .67443 .56494 Mtetra
.735 .992 .843 r
.67443 .56494 .68027 .56401 .69261 .54712 .68719 .55483 Mtetra
.59 .81 .41 r
.68719 .55483 .69261 .54712 .70457 .52418 .69955 .53697 Mtetra
0 0 0 r
.69955 .53697 .70457 .52418 .71623 .49749 .71153 .51317 Mtetra
.71153 .51317 .71623 .49749 .72769 .46947 .7232 .4858 Mtetra
.7232 .4858 .72769 .46947 .73907 .44222 .73467 .45729 Mtetra
.73467 .45729 .73907 .44222 .75048 .41732 .74607 .42977 Mtetra
.74607 .42977 .75048 .41732 .76202 .39567 .75752 .40476 Mtetra
.75752 .40476 .76202 .39567 .77375 .37759 .76912 .38311 Mtetra
.7 .879 .488 r
.76912 .38311 .77375 .37759 .78571 .36292 .78092 .3651 Mtetra
.803 .981 .701 r
.78092 .3651 .78571 .36292 .79789 .35122 .79296 .35052 Mtetra
.834 .994 .852 r
.79296 .35052 .79789 .35122 .81028 .3419 .80523 .33891 Mtetra
.806 .941 .916 r
.80523 .33891 .81028 .3419 .82286 .33436 .81772 .32966 Mtetra
.762 .876 .93 r
.81772 .32966 .82286 .33436 .83559 .32808 .83039 .32216 Mtetra
.725 .825 .927 r
.83039 .32216 .83559 .32808 .84845 .32263 .84322 .31589 Mtetra
.7 .79 .921 r
.84322 .31589 .84845 .32263 .86142 .31769 .85619 .31043 Mtetra
.684 .769 .916 r
.85619 .31043 .86142 .31769 .87447 .31305 .86925 .30547 Mtetra
.674 .756 .912 r
.86925 .30547 .87447 .31305 .8876 .30858 .88241 .30079 Mtetra
.664 .741 .908 r
.28131 .48843 .28827 .49491 .29897 .49141 .29204 .48491 Mtetra
.29204 .48491 .29897 .49141 .30971 .48789 .30281 .48136 Mtetra
.30281 .48136 .30971 .48789 .3205 .48436 .31362 .47781 Mtetra
.31362 .47781 .3205 .48436 .33133 .48082 .32448 .47423 Mtetra
.32448 .47423 .33133 .48082 .3422 .47726 .33538 .47065 Mtetra
.33538 .47065 .3422 .47726 .35312 .47368 .34633 .46705 Mtetra
.34633 .46705 .35312 .47368 .36408 .47009 .35732 .46343 Mtetra
.35732 .46343 .36408 .47009 .37509 .46649 .36835 .4598 Mtetra
.36835 .4598 .37509 .46649 .38615 .46287 .37944 .45615 Mtetra
.37944 .45615 .38615 .46287 .39725 .45924 .39057 .45249 Mtetra
.663 .741 .908 r
.39057 .45249 .39725 .45924 .40839 .4556 .40174 .44882 Mtetra
.40174 .44882 .40839 .4556 .41959 .45195 .41296 .44513 Mtetra
.41296 .44513 .41959 .45195 .43083 .44829 .42423 .44143 Mtetra
.663 .74 .908 r
.42423 .44143 .43083 .44829 .44211 .44466 .43555 .43774 Mtetra
.662 .739 .907 r
.43555 .43774 .44211 .44466 .45344 .44107 .44691 .43406 Mtetra
.659 .736 .907 r
.44691 .43406 .45344 .44107 .46482 .43759 .45832 .43043 Mtetra
.655 .732 .906 r
.45832 .43043 .46482 .43759 .47624 .43432 .46978 .42691 Mtetra
.648 .723 .903 r
.46978 .42691 .47624 .43432 .48772 .43142 .48128 .4236 Mtetra
.635 .708 .899 r
.48128 .4236 .48772 .43142 .49924 .42914 .49283 .42066 Mtetra
.615 .683 .891 r
.49283 .42066 .49924 .42914 .51081 .42783 .50444 .41835 Mtetra
.584 .645 .877 r
.50444 .41835 .51081 .42783 .52245 .42797 .5161 .417 Mtetra
.541 .593 .855 r
.5161 .417 .52245 .42797 .53418 .43013 .52783 .41709 Mtetra
.489 .528 .824 r
.52783 .41709 .53418 .43013 .54601 .4349 .53964 .41915 Mtetra
.431 .456 .785 r
.53964 .41915 .54601 .4349 .55799 .44287 .55158 .42377 Mtetra
.377 .387 .744 r
.55158 .42377 .55799 .44287 .57016 .45441 .56366 .43148 Mtetra
.333 .329 .705 r
.56366 .43148 .57016 .45441 .58256 .46953 .57594 .44262 Mtetra
.303 .286 .675 r
.57594 .44262 .58256 .46953 .59522 .48772 .58844 .45714 Mtetra
.287 .26 .653 r
.58844 .45714 .59522 .48772 .60814 .50785 .60121 .47451 Mtetra
.288 .251 .643 r
.60121 .47451 .60814 .50785 .62131 .52812 .61424 .49358 Mtetra
.304 .259 .642 r
.61424 .49358 .62131 .52812 .63464 .54625 .62749 .51257 Mtetra
.337 .286 .653 r
.62749 .51257 .63464 .54625 .64803 .55976 .6409 .52927 Mtetra
.393 .337 .675 r
.6409 .52927 .64803 .55976 .66134 .56647 .65435 .54135 Mtetra
.479 .419 .712 r
.65435 .54135 .66134 .56647 .67443 .56494 .6677 .54679 Mtetra
.605 .545 .76 r
.6677 .54679 .67443 .56494 .68719 .55483 .68082 .5443 Mtetra
.772 .719 .802 r
.68082 .5443 .68719 .55483 .69955 .53697 .6936 .53367 Mtetra
.923 .891 .782 r
.6936 .53367 .69955 .53697 .71153 .51317 .706 .51579 Mtetra
.949 .952 .653 r
.706 .51579 .71153 .51317 .7232 .4858 .71803 .49245 Mtetra
.873 .908 .5 r
.71803 .49245 .7232 .4858 .73467 .45729 .72976 .46592 Mtetra
.795 .855 .404 r
.72976 .46592 .73467 .45729 .74607 .42977 .74132 .43852 Mtetra
.756 .836 .379 r
.74132 .43852 .74607 .42977 .75752 .40476 .75282 .41221 Mtetra
.759 .858 .42 r
.75282 .41221 .75752 .40476 .76912 .38311 .76438 .38838 Mtetra
.796 .912 .519 r
.76438 .38838 .76912 .38311 .78092 .3651 .7761 .3678 Mtetra
.843 .972 .659 r
.7761 .3678 .78092 .3651 .79296 .35052 .78803 .35069 Mtetra
.864 .996 .794 r
.78803 .35069 .79296 .35052 .80523 .33891 .8002 .33682 Mtetra
.843 .968 .881 r
.8002 .33682 .80523 .33891 .81772 .32966 .81259 .32572 Mtetra
.798 .911 .918 r
.81259 .32572 .81772 .32966 .83039 .32216 .8252 .31683 Mtetra
.753 .855 .925 r
.8252 .31683 .83039 .32216 .84322 .31589 .83799 .30955 Mtetra
.719 .812 .923 r
.83799 .30955 .84322 .31589 .85619 .31043 .85094 .30341 Mtetra
.696 .783 .918 r
.85094 .30341 .85619 .31043 .86925 .30547 .86401 .298 Mtetra
.682 .765 .914 r
.86401 .298 .86925 .30547 .88241 .30079 .87718 .29305 Mtetra
.664 .741 .908 r
.27431 .48191 .28131 .48843 .29204 .48491 .28506 .47835 Mtetra
.28506 .47835 .29204 .48491 .30281 .48136 .29585 .47478 Mtetra
.29585 .47478 .30281 .48136 .31362 .47781 .30669 .4712 Mtetra
.30669 .4712 .31362 .47781 .32448 .47423 .31758 .4676 Mtetra
.31758 .4676 .32448 .47423 .33538 .47065 .3285 .46399 Mtetra
.3285 .46399 .33538 .47065 .34633 .46705 .33948 .46036 Mtetra
.33948 .46036 .34633 .46705 .35732 .46343 .3505 .45671 Mtetra
.3505 .45671 .35732 .46343 .36835 .4598 .36156 .45306 Mtetra
.36156 .45306 .36835 .4598 .37944 .45615 .37268 .44938 Mtetra
.37268 .44938 .37944 .45615 .39057 .45249 .38383 .44569 Mtetra
.38383 .44569 .39057 .45249 .40174 .44882 .39504 .44199 Mtetra
.663 .741 .908 r
.39504 .44199 .40174 .44882 .41296 .44513 .40629 .43827 Mtetra
.40629 .43827 .41296 .44513 .42423 .44143 .41759 .43454 Mtetra
.41759 .43454 .42423 .44143 .43555 .43774 .42893 .4308 Mtetra
.663 .74 .908 r
.42893 .4308 .43555 .43774 .44691 .43406 .44033 .42706 Mtetra
.662 .739 .907 r
.44033 .42706 .44691 .43406 .45832 .43043 .45177 .42333 Mtetra
.66 .736 .907 r
.45177 .42333 .45832 .43043 .46978 .42691 .46326 .41965 Mtetra
.656 .731 .905 r
.46326 .41965 .46978 .42691 .48128 .4236 .47479 .41608 Mtetra
.649 .722 .902 r
.47479 .41608 .48128 .4236 .49283 .42066 .48638 .4127 Mtetra
.637 .706 .897 r
.48638 .4127 .49283 .42066 .50444 .41835 .49801 .40967 Mtetra
.618 .681 .888 r
.49801 .40967 .50444 .41835 .5161 .417 .5097 .40723 Mtetra
.589 .643 .872 r
.5097 .40723 .5161 .417 .52783 .41709 .52145 .40569 Mtetra
.551 .592 .848 r
.52145 .40569 .52783 .41709 .53964 .41915 .53327 .40548 Mtetra
.506 .529 .815 r
.53327 .40548 .53964 .41915 .55158 .42377 .54517 .4071 Mtetra
.458 .463 .775 r
.54517 .4071 .55158 .42377 .56366 .43148 .5572 .41107 Mtetra
.415 .401 .735 r
.5572 .41107 .56366 .43148 .57594 .44262 .56937 .41784 Mtetra
.383 .351 .699 r
.56937 .41784 .57594 .44262 .58844 .45714 .58173 .42768 Mtetra
.363 .315 .67 r
.58173 .42768 .58844 .45714 .60121 .47451 .59431 .44053 Mtetra
.356 .295 .65 r
.59431 .44053 .60121 .47451 .61424 .49358 .60714 .45582 Mtetra
.363 .29 .639 r
.60714 .45582 .61424 .49358 .62749 .51257 .6202 .47247 Mtetra
.382 .298 .636 r
.6202 .47247 .62749 .51257 .6409 .52927 .63348 .48885 Mtetra
.414 .32 .64 r
.63348 .48885 .6409 .52927 .65435 .54135 .64688 .50296 Mtetra
.46 .357 .651 r
.64688 .50296 .65435 .54135 .6677 .54679 .66031 .51273 Mtetra
.522 .411 .668 r
.66031 .51273 .6677 .54679 .68082 .5443 .67364 .51643 Mtetra
.602 .484 .691 r
.67364 .51643 .68082 .5443 .6936 .53367 .68675 .51301 Mtetra
.701 .58 .715 r
.68675 .51301 .6936 .53367 .706 .51579 .69954 .50237 Mtetra
.811 .692 .733 r
.69954 .50237 .706 .51579 .71803 .49245 .71198 .4854 Mtetra
.909 .804 .731 r
.71198 .4854 .71803 .49245 .72976 .46592 .72409 .46373 Mtetra
.965 .887 .702 r
.72409 .46373 .72976 .46592 .74132 .43852 .73595 .4394 Mtetra
.972 .928 .661 r
.73595 .4394 .74132 .43852 .75282 .41221 .74766 .41443 Mtetra
.953 .946 .637 r
.74766 .41443 .75282 .41221 .76438 .38838 .75934 .39056 Mtetra
.933 .959 .652 r
.75934 .39056 .76438 .38838 .7761 .3678 .77109 .36897 Mtetra
.92 .975 .706 r
.77109 .36897 .7761 .3678 .78803 .35069 .783 .35033 Mtetra
.904 .982 .782 r
.783 .35033 .78803 .35069 .8002 .33682 .79511 .33477 Mtetra
.874 .965 .853 r
.79511 .33477 .8002 .33682 .81259 .32572 .80744 .32209 Mtetra
.829 .924 .897 r
.80744 .32209 .81259 .32572 .8252 .31683 .82 .31184 Mtetra
.781 .875 .916 r
.82 .31184 .8252 .31683 .83799 .30955 .83275 .30352 Mtetra
.74 .831 .92 r
.83275 .30352 .83799 .30955 .85094 .30341 .84567 .29661 Mtetra
.711 .797 .918 r
.84567 .29661 .85094 .30341 .86401 .298 .85874 .29067 Mtetra
.691 .774 .915 r
.85874 .29067 .86401 .298 .87718 .29305 .87193 .28537 Mtetra
.664 .741 .908 r
.26725 .47533 .27431 .48191 .28506 .47835 .27802 .47175 Mtetra
.27802 .47175 .28506 .47835 .29585 .47478 .28884 .46816 Mtetra
.28884 .46816 .29585 .47478 .30669 .4712 .29971 .46454 Mtetra
.29971 .46454 .30669 .4712 .31758 .4676 .31062 .46092 Mtetra
.31062 .46092 .31758 .4676 .3285 .46399 .32158 .45728 Mtetra
.32158 .45728 .3285 .46399 .33948 .46036 .33258 .45362 Mtetra
.33258 .45362 .33948 .46036 .3505 .45671 .34363 .44995 Mtetra
.34363 .44995 .3505 .45671 .36156 .45306 .35472 .44626 Mtetra
.35472 .44626 .36156 .45306 .37268 .44938 .36586 .44256 Mtetra
.36586 .44256 .37268 .44938 .38383 .44569 .37705 .43884 Mtetra
.37705 .43884 .38383 .44569 .39504 .44199 .38828 .43511 Mtetra
.38828 .43511 .39504 .44199 .40629 .43827 .39956 .43136 Mtetra
.663 .741 .908 r
.39956 .43136 .40629 .43827 .41759 .43454 .41089 .42759 Mtetra
.41089 .42759 .41759 .43454 .42893 .4308 .42227 .42382 Mtetra
.42227 .42382 .42893 .4308 .44033 .42706 .43369 .42003 Mtetra
.663 .74 .908 r
.43369 .42003 .44033 .42706 .45177 .42333 .44516 .41624 Mtetra
.662 .739 .907 r
.44516 .41624 .45177 .42333 .46326 .41965 .45669 .41246 Mtetra
.66 .736 .906 r
.45669 .41246 .46326 .41965 .47479 .41608 .46825 .40873 Mtetra
.656 .731 .905 r
.46825 .40873 .47479 .41608 .48638 .4127 .47987 .40508 Mtetra
.65 .723 .902 r
.47987 .40508 .48638 .4127 .49801 .40967 .49154 .40161 Mtetra
.64 .707 .896 r
.49154 .40161 .49801 .40967 .5097 .40723 .50326 .39845 Mtetra
.623 .683 .886 r
.50326 .39845 .5097 .40723 .52145 .40569 .51503 .39581 Mtetra
.598 .647 .869 r
.51503 .39581 .52145 .40569 .53327 .40548 .52686 .39396 Mtetra
.566 .598 .845 r
.52686 .39396 .53327 .40548 .54517 .4071 .53877 .39326 Mtetra
.527 .54 .812 r
.53877 .39326 .54517 .4071 .5572 .41107 .55076 .39415 Mtetra
.487 .479 .773 r
.55076 .39415 .5572 .41107 .56937 .41784 .56287 .39707 Mtetra
.452 .422 .735 r
.56287 .39707 .56937 .41784 .58173 .42768 .57511 .40237 Mtetra
.426 .377 .7 r
.57511 .40237 .58173 .42768 .59431 .44053 .58754 .41026 Mtetra
.412 .345 .672 r
.58754 .41026 .59431 .44053 .60714 .45582 .60016 .42063 Mtetra
.409 .327 .653 r
.60016 .42063 .60714 .45582 .6202 .47247 .613 .43297 Mtetra
.416 .322 .64 r
.613 .43297 .6202 .47247 .63348 .48885 .62606 .44629 Mtetra
.433 .328 .635 r
.62606 .44629 .63348 .48885 .64688 .50296 .63929 .4592 Mtetra
.46 .345 .635 r
.63929 .4592 .64688 .50296 .66031 .51273 .65264 .47001 Mtetra
.497 .373 .641 r
.65264 .47001 .66031 .51273 .67364 .51643 .66599 .47701 Mtetra
.544 .411 .651 r
.66599 .47701 .67364 .51643 .68675 .51301 .67926 .47882 Mtetra
.601 .462 .664 r
.67926 .47882 .68675 .51301 .69954 .50237 .69232 .47464 Mtetra
.668 .525 .681 r
.69232 .47464 .69954 .50237 .71198 .4854 .70512 .46448 Mtetra
.743 .6 .699 r
.70512 .46448 .71198 .4854 .72409 .46373 .71763 .44913 Mtetra
.819 .683 .714 r
.71763 .44913 .72409 .46373 .73595 .4394 .72986 .42998 Mtetra
.884 .765 .725 r
.72986 .42998 .73595 .4394 .74766 .41443 .74189 .40874 Mtetra
.928 .835 .732 r
.74189 .40874 .74766 .41443 .75934 .39056 .75382 .38709 Mtetra
.946 .886 .741 r
.75382 .38709 .75934 .39056 .77109 .36897 .76573 .36644 Mtetra
.942 .918 .762 r
.76573 .36644 .77109 .36897 .783 .35033 .77773 .34776 Mtetra
.921 .934 .797 r
.77773 .34776 .783 .35033 .79511 .33477 .78987 .33157 Mtetra
.889 .931 .84 r
.78987 .33157 .79511 .33477 .80744 .32209 .8022 .31795 Mtetra
.847 .909 .878 r
.8022 .31795 .80744 .32209 .82 .31184 .81473 .30673 Mtetra
.801 .876 .902 r
.81473 .30673 .82 .31184 .83275 .30352 .82746 .29752 Mtetra
.759 .839 .913 r
.82746 .29752 .83275 .30352 .84567 .29661 .84037 .28989 Mtetra
.725 .807 .915 r
.84037 .28989 .84567 .29661 .85874 .29067 .85344 .28342 Mtetra
.701 .782 .914 r
.85344 .28342 .85874 .29067 .87193 .28537 .86663 .27773 Mtetra
.664 .741 .908 r
.26013 .46871 .26725 .47533 .27802 .47175 .27093 .4651 Mtetra
.27093 .4651 .27802 .47175 .28884 .46816 .28178 .46148 Mtetra
.28178 .46148 .28884 .46816 .29971 .46454 .29268 .45784 Mtetra
.29268 .45784 .29971 .46454 .31062 .46092 .30361 .45418 Mtetra
.30361 .45418 .31062 .46092 .32158 .45728 .3146 .45051 Mtetra
.3146 .45051 .32158 .45728 .33258 .45362 .32563 .44683 Mtetra
.32563 .44683 .33258 .45362 .34363 .44995 .3367 .44313 Mtetra
.3367 .44313 .34363 .44995 .35472 .44626 .34783 .43941 Mtetra
.34783 .43941 .35472 .44626 .36586 .44256 .35899 .43568 Mtetra
.35899 .43568 .36586 .44256 .37705 .43884 .37021 .43193 Mtetra
.37021 .43193 .37705 .43884 .38828 .43511 .38147 .42817 Mtetra
.38147 .42817 .38828 .43511 .39956 .43136 .39278 .42439 Mtetra
.39278 .42439 .39956 .43136 .41089 .42759 .40414 .4206 Mtetra
.663 .741 .908 r
.40414 .4206 .41089 .42759 .42227 .42382 .41555 .41679 Mtetra
.41555 .41679 .42227 .42382 .43369 .42003 .427 .41297 Mtetra
.427 .41297 .43369 .42003 .44516 .41624 .43851 .40913 Mtetra
.663 .74 .908 r
.43851 .40913 .44516 .41624 .45669 .41246 .45006 .40529 Mtetra
.662 .739 .907 r
.45006 .40529 .45669 .41246 .46825 .40873 .46166 .40146 Mtetra
.66 .737 .906 r
.46166 .40146 .46825 .40873 .47987 .40508 .47331 .39766 Mtetra
.657 .732 .905 r
.47331 .39766 .47987 .40508 .49154 .40161 .48501 .39394 Mtetra
.652 .724 .901 r
.48501 .39394 .49154 .40161 .50326 .39845 .49676 .39036 Mtetra
.643 .71 .896 r
.49676 .39036 .50326 .39845 .51503 .39581 .50857 .38703 Mtetra
.629 .688 .886 r
.50857 .38703 .51503 .39581 .52686 .39396 .52042 .38413 Mtetra
.609 .655 .87 r
.52042 .38413 .52686 .39396 .53877 .39326 .53234 .38189 Mtetra
.582 .611 .847 r
.53234 .38189 .53877 .39326 .55076 .39415 .54433 .38059 Mtetra
.55 .558 .815 r
.54433 .38059 .55076 .39415 .56287 .39707 .55641 .38059 Mtetra
.517 .502 .779 r
.55641 .38059 .56287 .39707 .57511 .40237 .56859 .38221 Mtetra
.487 .45 .741 r
.56859 .38221 .57511 .40237 .58754 .41026 .5809 .38575 Mtetra
.465 .407 .708 r
.5809 .38575 .58754 .41026 .60016 .42063 .59336 .39134 Mtetra
.453 .377 .68 r
.59336 .39134 .60016 .42063 .613 .43297 .60601 .39884 Mtetra
.45 .358 .66 r
.60601 .39884 .613 .43297 .62606 .44629 .61884 .40781 Mtetra
.457 .352 .647 r
.61884 .40781 .62606 .44629 .63929 .4592 .63185 .41743 Mtetra
.471 .355 .64 r
.63185 .41743 .63929 .4592 .65264 .47001 .64501 .42657 Mtetra
.493 .367 .637 r
.64501 .42657 .65264 .47001 .66599 .47701 .65826 .4339 Mtetra
.522 .388 .64 r
.65826 .4339 .66599 .47701 .67926 .47882 .67152 .4381 Mtetra
.558 .418 .646 r
.67152 .4381 .67926 .47882 .69232 .47464 .6847 .43813 Mtetra
.601 .456 .656 r
.6847 .43813 .69232 .47464 .70512 .46448 .69772 .43344 Mtetra
.651 .503 .669 r
.69772 .43344 .70512 .46448 .71763 .44913 .71054 .42409 Mtetra
.705 .558 .685 r
.71054 .42409 .71763 .44913 .72986 .42998 .72313 .41075 Mtetra
.761 .62 .703 r
.72313 .41075 .72986 .42998 .74189 .40874 .73552 .39453 Mtetra
.814 .686 .723 r
.73552 .39453 .74189 .40874 .75382 .38709 .74776 .37676 Mtetra
.856 .749 .745 r
.74776 .37676 .75382 .38709 .76573 .36644 .75993 .35876 Mtetra
.88 .803 .769 r
.75993 .35876 .76573 .36644 .77773 .34776 .77211 .3416 Mtetra
.885 .842 .797 r
.77211 .3416 .77773 .34776 .78987 .33157 .78438 .32604 Mtetra
.871 .864 .829 r
.78438 .32604 .78987 .33157 .8022 .31795 .79678 .31244 Mtetra
.843 .866 .86 r
.79678 .31244 .8022 .31795 .81473 .30673 .80935 .30087 Mtetra
.806 .853 .885 r
.80935 .30087 .81473 .30673 .82746 .29752 .8221 .29117 Mtetra
.769 .831 .901 r
.8221 .29117 .82746 .29752 .84037 .28989 .83501 .28303 Mtetra
.736 .807 .908 r
.83501 .28303 .84037 .28989 .85344 .28342 .84809 .27611 Mtetra
.71 .786 .911 r
.84809 .27611 .85344 .28342 .86663 .27773 .8613 .27006 Mtetra
.664 .741 .908 r
.25296 .46203 .26013 .46871 .27093 .4651 .26379 .4584 Mtetra
.26379 .4584 .27093 .4651 .28178 .46148 .27467 .45475 Mtetra
.27467 .45475 .28178 .46148 .29268 .45784 .28559 .45108 Mtetra
.28559 .45108 .29268 .45784 .30361 .45418 .29655 .4474 Mtetra
.29655 .4474 .30361 .45418 .3146 .45051 .30756 .4437 Mtetra
.30756 .4437 .3146 .45051 .32563 .44683 .31862 .43998 Mtetra
.31862 .43998 .32563 .44683 .3367 .44313 .32973 .43626 Mtetra
.32973 .43626 .3367 .44313 .34783 .43941 .34088 .43251 Mtetra
.34088 .43251 .34783 .43941 .35899 .43568 .35207 .42875 Mtetra
.35207 .42875 .35899 .43568 .37021 .43193 .36332 .42497 Mtetra
.36332 .42497 .37021 .43193 .38147 .42817 .37461 .42118 Mtetra
.37461 .42118 .38147 .42817 .39278 .42439 .38595 .41737 Mtetra
.38595 .41737 .39278 .42439 .40414 .4206 .39734 .41355 Mtetra
.39734 .41355 .40414 .4206 .41555 .41679 .40878 .40971 Mtetra
.40878 .40971 .41555 .41679 .427 .41297 .42026 .40585 Mtetra
.663 .741 .908 r
.42026 .40585 .427 .41297 .43851 .40913 .4318 .40198 Mtetra
.4318 .40198 .43851 .40913 .45006 .40529 .44338 .3981 Mtetra
.663 .74 .908 r
.44338 .3981 .45006 .40529 .46166 .40146 .45502 .39421 Mtetra
.662 .739 .907 r
.45502 .39421 .46166 .40146 .47331 .39766 .4667 .39032 Mtetra
.661 .737 .906 r
.4667 .39032 .47331 .39766 .48501 .39394 .47843 .38646 Mtetra
.659 .733 .905 r
.47843 .38646 .48501 .39394 .49676 .39036 .49022 .38265 Mtetra
.654 .726 .902 r
.49022 .38265 .49676 .39036 .50857 .38703 .50205 .37895 Mtetra
.647 .715 .897 r
.50205 .37895 .50857 .38703 .52042 .38413 .51394 .37545 Mtetra
.636 .695 .888 r
.51394 .37545 .52042 .38413 .53234 .38189 .52588 .37228 Mtetra
.62 .667 .874 r
.52588 .37228 .53234 .38189 .54433 .38059 .53789 .36962 Mtetra
.599 .629 .852 r
.53789 .36962 .54433 .38059 .55641 .38059 .54996 .36768 Mtetra
.573 .582 .824 r
.54996 .36768 .55641 .38059 .56859 .38221 .56211 .36673 Mtetra
.546 .531 .79 r
.56211 .36673 .56859 .38221 .5809 .38575 .57436 .36702 Mtetra
.521 .483 .755 r
.57436 .36702 .5809 .38575 .59336 .39134 .58673 .36874 Mtetra
.501 .442 .722 r
.58673 .36874 .59336 .39134 .60601 .39884 .59923 .37197 Mtetra
.49 .411 .695 r
.59923 .37197 .60601 .39884 .61884 .40781 .61188 .37659 Mtetra
.486 .392 .674 r
.61188 .37659 .61884 .40781 .63185 .41743 .62469 .38224 Mtetra
.49 .383 .659 r
.62469 .38224 .63185 .41743 .64501 .42657 .63765 .38828 Mtetra
.501 .383 .65 r
.63765 .38828 .64501 .42657 .65826 .4339 .65072 .39384 Mtetra
.519 .391 .646 r
.65072 .39384 .65826 .4339 .67152 .4381 .66387 .39793 Mtetra
.542 .407 .647 r
.66387 .39793 .67152 .4381 .6847 .43813 .67704 .39962 Mtetra
.571 .43 .651 r
.67704 .39962 .6847 .43813 .69772 .43344 .69015 .39817 Mtetra
.604 .46 .659 r
.69015 .39817 .69772 .43344 .71054 .42409 .70314 .39321 Mtetra
.642 .497 .67 r
.70314 .39321 .71054 .42409 .72313 .41075 .71599 .38483 Mtetra
.684 .541 .685 r
.71599 .38483 .72313 .41075 .73552 .39453 .72868 .37357 Mtetra
.726 .591 .704 r
.72868 .37357 .73552 .39453 .74776 .37676 .74124 .36025 Mtetra
.766 .644 .727 r
.74124 .36025 .74776 .37676 .75993 .35876 .7537 .34585 Mtetra
.799 .697 .753 r
.7537 .34585 .75993 .35876 .77211 .3416 .76613 .33135 Mtetra
.82 .745 .781 r
.76613 .33135 .77211 .3416 .78438 .32604 .77859 .31751 Mtetra
.826 .783 .812 r
.77859 .31751 .78438 .32604 .79678 .31244 .79114 .30487 Mtetra
.816 .806 .841 r
.79114 .30487 .79678 .31244 .80935 .30087 .8038 .2937 Mtetra
.795 .813 .867 r
.8038 .2937 .80935 .30087 .8221 .29117 .81661 .28403 Mtetra
.767 .809 .886 r
.81661 .28403 .8221 .29117 .83501 .28303 .82957 .27573 Mtetra
.739 .797 .899 r
.82957 .27573 .83501 .28303 .84809 .27611 .84268 .26856 Mtetra
.715 .783 .905 r
.84268 .26856 .84809 .27611 .8613 .27006 .85592 .26227 Mtetra
.664 .741 .908 r
.24574 .45531 .25296 .46203 .26379 .4584 .25659 .45164 Mtetra
.25659 .45164 .26379 .4584 .27467 .45475 .2675 .44796 Mtetra
.2675 .44796 .27467 .45475 .28559 .45108 .27844 .44427 Mtetra
.27844 .44427 .28559 .45108 .29655 .4474 .28944 .44056 Mtetra
.28944 .44056 .29655 .4474 .30756 .4437 .30048 .43683 Mtetra
.30048 .43683 .30756 .4437 .31862 .43998 .31156 .43309 Mtetra
.31156 .43309 .31862 .43998 .32973 .43626 .32269 .42933 Mtetra
.32269 .42933 .32973 .43626 .34088 .43251 .33387 .42556 Mtetra
.33387 .42556 .34088 .43251 .35207 .42875 .3451 .42177 Mtetra
.3451 .42177 .35207 .42875 .36332 .42497 .35637 .41796 Mtetra
.35637 .41796 .36332 .42497 .37461 .42118 .3677 .41414 Mtetra
.3677 .41414 .37461 .42118 .38595 .41737 .37907 .4103 Mtetra
.37907 .4103 .38595 .41737 .39734 .41355 .39048 .40644 Mtetra
.39048 .40644 .39734 .41355 .40878 .40971 .40195 .40257 Mtetra
.40195 .40257 .40878 .40971 .42026 .40585 .41347 .39869 Mtetra
.41347 .39869 .42026 .40585 .4318 .40198 .42503 .39478 Mtetra
.663 .741 .908 r
.42503 .39478 .4318 .40198 .44338 .3981 .43665 .39087 Mtetra
.43665 .39087 .44338 .3981 .45502 .39421 .44832 .38693 Mtetra
.44832 .38693 .45502 .39421 .4667 .39032 .46003 .38299 Mtetra
.662 .74 .907 r
.46003 .38299 .4667 .39032 .47843 .38646 .4718 .37905 Mtetra
.661 .738 .907 r
.4718 .37905 .47843 .38646 .49022 .38265 .48362 .37513 Mtetra
.66 .735 .906 r
.48362 .37513 .49022 .38265 .50205 .37895 .49548 .37124 Mtetra
.656 .73 .903 r
.49548 .37124 .50205 .37895 .51394 .37545 .50741 .36743 Mtetra
.651 .72 .899 r
.50741 .36743 .51394 .37545 .52588 .37228 .51938 .36377 Mtetra
.643 .705 .892 r
.51938 .36377 .52588 .37228 .53789 .36962 .53141 .36034 Mtetra
.631 .682 .88 r
.53141 .36034 .53789 .36962 .54996 .36768 .5435 .35727 Mtetra
.615 .65 .861 r
.5435 .35727 .54996 .36768 .56211 .36673 .55566 .35473 Mtetra
.595 .61 .837 r
.55566 .35473 .56211 .36673 .57436 .36702 .56789 .35288 Mtetra
.573 .566 .807 r
.56789 .35288 .57436 .36702 .58673 .36874 .58021 .35191 Mtetra
.552 .521 .775 r
.58021 .35191 .58673 .36874 .59923 .37197 .59263 .35195 Mtetra
.535 .482 .744 r
.59263 .35195 .59923 .37197 .61188 .37659 .60516 .35304 Mtetra
.524 .451 .716 r
.60516 .35304 .61188 .37659 .62469 .38224 .61782 .35508 Mtetra
.519 .43 .694 r
.61782 .35508 .62469 .38224 .63765 .38828 .63061 .35778 Mtetra
.521 .418 .678 r
.63061 .35778 .63765 .38828 .65072 .39384 .64352 .36069 Mtetra
.529 .415 .668 r
.64352 .36069 .65072 .39384 .66387 .39793 .65652 .36318 Mtetra
.542 .419 .662 r
.65652 .36318 .66387 .39793 .67704 .39962 .66959 .36458 Mtetra
.56 .431 .661 r
.66959 .36458 .67704 .39962 .69015 .39817 .68268 .36422 Mtetra
.583 .449 .664 r
.68268 .36422 .69015 .39817 .70314 .39321 .69574 .36163 Mtetra
.61 .474 .671 r
.69574 .36163 .70314 .39321 .71599 .38483 .70874 .35659 Mtetra
.639 .504 .682 r
.70874 .35659 .71599 .38483 .72868 .37357 .72164 .34919 Mtetra
.671 .541 .697 r
.72164 .34919 .72868 .37357 .74124 .36025 .73445 .33982 Mtetra
.704 .582 .716 r
.73445 .33982 .74124 .36025 .7537 .34585 .74717 .32906 Mtetra
.734 .627 .739 r
.74717 .32906 .7537 .34585 .76613 .33135 .75986 .3176 Mtetra
.758 .671 .766 r
.75986 .3176 .76613 .33135 .77859 .31751 .77254 .30611 Mtetra
.774 .712 .795 r
.77254 .30611 .77859 .31751 .79114 .30487 .78526 .2951 Mtetra
.777 .745 .824 r
.78526 .2951 .79114 .30487 .8038 .2937 .79807 .28495 Mtetra
.77 .767 .85 r
.79807 .28495 .8038 .2937 .81661 .28403 .81098 .27583 Mtetra
.754 .777 .872 r
.81098 .27583 .81661 .28403 .82957 .27573 .82402 .26775 Mtetra
.734 .778 .888 r
.82402 .26775 .82957 .27573 .84268 .26856 .83718 .2606 Mtetra
.715 .773 .898 r
.83718 .2606 .84268 .26856 .85592 .26227 .85046 .25424 Mtetra
.664 .741 .908 r
.23846 .44853 .24574 .45531 .25659 .45164 .24934 .44484 Mtetra
.24934 .44484 .25659 .45164 .2675 .44796 .26027 .44113 Mtetra
.26027 .44113 .2675 .44796 .27844 .44427 .27124 .4374 Mtetra
.27124 .4374 .27844 .44427 .28944 .44056 .28226 .43366 Mtetra
.28226 .43366 .28944 .44056 .30048 .43683 .29333 .42991 Mtetra
.29333 .42991 .30048 .43683 .31156 .43309 .30445 .42614 Mtetra
.30445 .42614 .31156 .43309 .32269 .42933 .31561 .42235 Mtetra
.31561 .42235 .32269 .42933 .33387 .42556 .32681 .41855 Mtetra
.32681 .41855 .33387 .42556 .3451 .42177 .33807 .41473 Mtetra
.33807 .41473 .3451 .42177 .35637 .41796 .34937 .41089 Mtetra
.34937 .41089 .35637 .41796 .3677 .41414 .36072 .40704 Mtetra
.36072 .40704 .3677 .41414 .37907 .4103 .37213 .40317 Mtetra
.37213 .40317 .37907 .4103 .39048 .40644 .38357 .39929 Mtetra
.38357 .39929 .39048 .40644 .40195 .40257 .39507 .39538 Mtetra
.39507 .39538 .40195 .40257 .41347 .39869 .40662 .39147 Mtetra
.663 .741 .908 r
.40662 .39147 .41347 .39869 .42503 .39478 .41822 .38753 Mtetra
.41822 .38753 .42503 .39478 .43665 .39087 .42986 .38359 Mtetra
.42986 .38359 .43665 .39087 .44832 .38693 .44156 .37963 Mtetra
.44156 .37963 .44832 .38693 .46003 .38299 .45331 .37566 Mtetra
.45331 .37566 .46003 .38299 .4718 .37905 .46511 .37168 Mtetra
.662 .741 .909 r
.46511 .37168 .4718 .37905 .48362 .37513 .47696 .36771 Mtetra
.661 .74 .909 r
.47696 .36771 .48362 .37513 .49548 .37124 .48886 .36374 Mtetra
.66 .739 .908 r
.48886 .36374 .49548 .37124 .50741 .36743 .50082 .3598 Mtetra
.658 .735 .907 r
.50082 .3598 .50741 .36743 .51938 .36377 .51282 .3559 Mtetra
.654 .728 .903 r
.51282 .3559 .51938 .36377 .53141 .36034 .52489 .35209 Mtetra
.649 .717 .897 r
.52489 .35209 .53141 .36034 .5435 .35727 .537 .34842 Mtetra
.641 .699 .888 r
.537 .34842 .5435 .35727 .55566 .35473 .54918 .34498 Mtetra
.63 .673 .873 r
.54918 .34498 .55566 .35473 .56789 .35288 .56142 .34188 Mtetra
.616 .641 .853 r
.56142 .34188 .56789 .35288 .58021 .35191 .57373 .33924 Mtetra
.599 .603 .827 r
.57373 .33924 .58021 .35191 .59263 .35195 .58612 .33719 Mtetra
.582 .564 .799 r
.58612 .33719 .59263 .35195 .60516 .35304 .5986 .3358 Mtetra
.567 .527 .77 r
.5986 .3358 .60516 .35304 .61782 .35508 .61117 .33511 Mtetra
.556 .496 .744 r
.61117 .33511 .61782 .35508 .63061 .35778 .62385 .33502 Mtetra
.55 .474 .722 r
.62385 .33502 .63061 .35778 .64352 .36069 .63663 .33535 Mtetra
.55 .459 .705 r
.63663 .33535 .64352 .36069 .65652 .36318 .64951 .33576 Mtetra
.555 .453 .693 r
.64951 .33576 .65652 .36318 .66959 .36458 .66247 .33585 Mtetra
.565 .454 .686 r
.66247 .33585 .66959 .36458 .68268 .36422 .67549 .33516 Mtetra
.579 .462 .684 r
.67549 .33516 .68268 .36422 .69574 .36163 .68854 .33327 Mtetra
.597 .476 .686 r
.68854 .33327 .69574 .36163 .70874 .35659 .70159 .32989 Mtetra
.618 .497 .693 r
.70159 .32989 .70874 .35659 .72164 .34919 .71461 .32488 Mtetra
.641 .523 .703 r
.71461 .32488 .72164 .34919 .73445 .33982 .72758 .31834 Mtetra
.666 .554 .718 r
.72758 .31834 .73445 .33982 .74717 .32906 .74051 .31052 Mtetra
.69 .589 .737 r
.74051 .31052 .74717 .32906 .75986 .3176 .75341 .30182 Mtetra
.712 .627 .76 r
.75341 .30182 .75986 .3176 .77254 .30611 .7663 .2927 Mtetra
.729 .664 .786 r
.7663 .2927 .77254 .30611 .78526 .2951 .77921 .28357 Mtetra
.739 .699 .813 r
.77921 .28357 .78526 .2951 .79807 .28495 .79217 .27478 Mtetra
.741 .726 .838 r
.79217 .27478 .79807 .28495 .81098 .27583 .80521 .26656 Mtetra
.734 .745 .861 r
.80521 .26656 .81098 .27583 .82402 .26775 .81835 .25901 Mtetra
.723 .755 .878 r
.81835 .25901 .82402 .26775 .83718 .2606 .83159 .25214 Mtetra
.709 .758 .891 r
.83159 .25214 .83718 .2606 .85046 .25424 .84494 .24587 Mtetra
.664 .741 .908 r
.23112 .4417 .23846 .44853 .24934 .44484 .24203 .43798 Mtetra
.24203 .43798 .24934 .44484 .26027 .44113 .25299 .43424 Mtetra
.25299 .43424 .26027 .44113 .27124 .4374 .26399 .43049 Mtetra
.26399 .43049 .27124 .4374 .28226 .43366 .27504 .42672 Mtetra
.27504 .42672 .28226 .43366 .29333 .42991 .28613 .42293 Mtetra
.28613 .42293 .29333 .42991 .30445 .42614 .29727 .41913 Mtetra
.29727 .41913 .30445 .42614 .31561 .42235 .30846 .41532 Mtetra
.30846 .41532 .31561 .42235 .32681 .41855 .3197 .41148 Mtetra
.3197 .41148 .32681 .41855 .33807 .41473 .33099 .40763 Mtetra
.33099 .40763 .33807 .41473 .34937 .41089 .34232 .40377 Mtetra
.34232 .40377 .34937 .41089 .36072 .40704 .3537 .39988 Mtetra
.3537 .39988 .36072 .40704 .37213 .40317 .36513 .39599 Mtetra
.36513 .39599 .37213 .40317 .38357 .39929 .37661 .39207 Mtetra
.663 .741 .908 r
.37661 .39207 .38357 .39929 .39507 .39538 .38814 .38814 Mtetra
.38814 .38814 .39507 .39538 .40662 .39147 .39972 .3842 Mtetra
.39972 .3842 .40662 .39147 .41822 .38753 .41134 .38024 Mtetra
.663 .742 .909 r
.41134 .38024 .41822 .38753 .42986 .38359 .42302 .37628 Mtetra
.662 .742 .909 r
.42302 .37628 .42986 .38359 .44156 .37963 .43475 .37232 Mtetra
.662 .743 .91 r
.43475 .37232 .44156 .37963 .45331 .37566 .44653 .36836 Mtetra
.661 .744 .911 r
.44653 .36836 .45331 .37566 .46511 .37168 .45836 .36441 Mtetra
.66 .745 .913 r
.45836 .36441 .46511 .37168 .47696 .36771 .47025 .36045 Mtetra
.66 .746 .914 r
.47025 .36045 .47696 .36771 .48886 .36374 .48218 .35649 Mtetra
.66 .747 .915 r
.48218 .35649 .48886 .36374 .50082 .3598 .49417 .35252 Mtetra
.49417 .35252 .50082 .3598 .51282 .3559 .50621 .34852 Mtetra
.66 .746 .913 r
.50621 .34852 .51282 .3559 .52489 .35209 .51831 .34451 Mtetra
.659 .74 .91 r
.51831 .34451 .52489 .35209 .537 .34842 .53046 .34051 Mtetra
.656 .731 .905 r
.53046 .34051 .537 .34842 .54918 .34498 .54267 .33657 Mtetra
.652 .717 .896 r
.54267 .33657 .54918 .34498 .56142 .34188 .55493 .33275 Mtetra
.644 .696 .884 r
.55493 .33275 .56142 .34188 .57373 .33924 .56726 .32915 Mtetra
.634 .67 .868 r
.56726 .32915 .57373 .33924 .58612 .33719 .57965 .32585 Mtetra
.621 .64 .848 r
.57965 .32585 .58612 .33719 .5986 .3358 .59211 .32292 Mtetra
.608 .607 .824 r
.59211 .32292 .5986 .3358 .61117 .33511 .60465 .32043 Mtetra
.596 .575 .8 r
.60465 .32043 .61117 .33511 .62385 .33502 .61727 .31838 Mtetra
.586 .546 .777 r
.61727 .31838 .62385 .33502 .63663 .33535 .62998 .3167 Mtetra
.58 .523 .756 r
.62998 .3167 .63663 .33535 .64951 .33576 .64278 .31525 Mtetra
.578 .507 .739 r
.64278 .31525 .64951 .33576 .66247 .33585 .65566 .31382 Mtetra
.581 .498 .727 r
.65566 .31382 .66247 .33585 .67549 .33516 .66862 .31216 Mtetra
.587 .497 .719 r
.66862 .31216 .67549 .33516 .68854 .33327 .68163 .30998 Mtetra
.598 .502 .716 r
.68163 .30998 .68854 .33327 .70159 .32989 .69467 .30702 Mtetra
.612 .513 .718 r
.69467 .30702 .70159 .32989 .71461 .32488 .70773 .30312 Mtetra
.628 .53 .724 r
.70773 .30312 .71461 .32488 .72758 .31834 .7208 .2982 Mtetra
.646 .552 .734 r
.7208 .2982 .72758 .31834 .74051 .31052 .73386 .29233 Mtetra
.664 .578 .749 r
.73386 .29233 .74051 .31052 .75341 .30182 .74691 .28568 Mtetra
.682 .608 .767 r
.74691 .28568 .75341 .30182 .7663 .2927 .75997 .2785 Mtetra
.697 .64 .788 r
.75997 .2785 .7663 .2927 .77921 .28357 .77305 .27107 Mtetra
.708 .671 .811 r
.77305 .27107 .77921 .28357 .79217 .27478 .78616 .26366 Mtetra
.714 .698 .834 r
.78616 .26366 .79217 .27478 .80521 .26656 .79933 .25645 Mtetra
.713 .72 .854 r
.79933 .25645 .80521 .26656 .81835 .25901 .81258 .24961 Mtetra
.708 .735 .872 r
.81258 .24961 .81835 .25901 .83159 .25214 .82591 .24317 Mtetra
.7 .744 .885 r
.82591 .24317 .83159 .25214 .84494 .24587 .83933 .23715 Mtetra
.664 .741 .908 r
.22373 .43482 .23112 .4417 .24203 .43798 .23467 .43107 Mtetra
.23467 .43107 .24203 .43798 .25299 .43424 .24565 .4273 Mtetra
.24565 .4273 .25299 .43424 .26399 .43049 .25668 .42352 Mtetra
.25668 .42352 .26399 .43049 .27504 .42672 .26775 .41972 Mtetra
.26775 .41972 .27504 .42672 .28613 .42293 .27888 .4159 Mtetra
.27888 .4159 .28613 .42293 .29727 .41913 .29005 .41207 Mtetra
.29005 .41207 .29727 .41913 .30846 .41532 .30127 .40823 Mtetra
.30127 .40823 .30846 .41532 .3197 .41148 .31253 .40436 Mtetra
.31253 .40436 .3197 .41148 .33099 .40763 .32384 .40048 Mtetra
.32384 .40048 .33099 .40763 .34232 .40377 .33521 .39659 Mtetra
.663 .741 .908 r
.33521 .39659 .34232 .40377 .3537 .39988 .34662 .39267 Mtetra
.34662 .39267 .3537 .39988 .36513 .39599 .35808 .38875 Mtetra
.35808 .38875 .36513 .39599 .37661 .39207 .36959 .38481 Mtetra
.36959 .38481 .37661 .39207 .38814 .38814 .38115 .38086 Mtetra
.662 .742 .909 r
.38115 .38086 .38814 .38814 .39972 .3842 .39276 .37692 Mtetra
.661 .742 .91 r
.39276 .37692 .39972 .3842 .41134 .38024 .40441 .37298 Mtetra
.66 .743 .912 r
.40441 .37298 .41134 .38024 .42302 .37628 .41612 .36907 Mtetra
.659 .745 .914 r
.41612 .36907 .42302 .37628 .43475 .37232 .42788 .36518 Mtetra
.657 .748 .917 r
.42788 .36518 .43475 .37232 .44653 .36836 .43969 .36133 Mtetra
.655 .752 .921 r
.43969 .36133 .44653 .36836 .45836 .36441 .45155 .3575 Mtetra
.655 .756 .924 r
.45155 .3575 .45836 .36441 .47025 .36045 .46347 .35367 Mtetra
.656 .761 .927 r
.46347 .35367 .47025 .36045 .48218 .35649 .47544 .34978 Mtetra
.658 .765 .929 r
.47544 .34978 .48218 .35649 .49417 .35252 .48746 .34581 Mtetra
.661 .767 .929 r
.48746 .34581 .49417 .35252 .50621 .34852 .49954 .34173 Mtetra
.665 .767 .926 r
.49954 .34173 .50621 .34852 .51831 .34451 .51168 .33754 Mtetra
.667 .763 .922 r
.51168 .33754 .51831 .34451 .53046 .34051 .52387 .33325 Mtetra
.668 .756 .916 r
.52387 .33325 .53046 .34051 .54267 .33657 .53611 .32893 Mtetra
.666 .745 .909 r
.53611 .32893 .54267 .33657 .55493 .33275 .54841 .32464 Mtetra
.662 .731 .901 r
.54841 .32464 .55493 .33275 .56726 .32915 .56076 .32045 Mtetra
.655 .714 .891 r
.56076 .32045 .56726 .32915 .57965 .32585 .57317 .31644 Mtetra
.647 .694 .88 r
.57317 .31644 .57965 .32585 .59211 .32292 .58564 .31264 Mtetra
.638 .671 .865 r
.58564 .31264 .59211 .32292 .60465 .32043 .59818 .3091 Mtetra
.629 .646 .848 r
.59818 .3091 .60465 .32043 .61727 .31838 .61079 .30582 Mtetra
.62 .62 .83 r
.61079 .30582 .61727 .31838 .62998 .3167 .62348 .30281 Mtetra
.612 .596 .811 r
.62348 .30281 .62998 .3167 .64278 .31525 .63624 .30001 Mtetra
.607 .576 .793 r
.63624 .30001 .64278 .31525 .65566 .31382 .64907 .29733 Mtetra
.605 .56 .778 r
.64907 .29733 .65566 .31382 .66862 .31216 .66198 .29464 Mtetra
.606 .551 .766 r
.66198 .29464 .66862 .31216 .68163 .30998 .67496 .29179 Mtetra
.61 .547 .759 r
.67496 .29179 .68163 .30998 .69467 .30702 .68799 .2886 Mtetra
.617 .55 .756 r
.68799 .2886 .69467 .30702 .70773 .30312 .70107 .28494 Mtetra
.627 .558 .757 r
.70107 .28494 .70773 .30312 .7208 .2982 .71418 .28071 Mtetra
.639 .571 .762 r
.71418 .28071 .7208 .2982 .73386 .29233 .72731 .27588 Mtetra
.652 .59 .772 r
.72731 .27588 .73386 .29233 .74691 .28568 .74047 .2705 Mtetra
.665 .612 .785 r
.74047 .2705 .74691 .28568 .75997 .2785 .75364 .26465 Mtetra
.677 .636 .801 r
.75364 .26465 .75997 .2785 .77305 .27107 .76685 .25851 Mtetra
.687 .661 .819 r
.76685 .25851 .77305 .27107 .78616 .26366 .78009 .25222 Mtetra
.693 .685 .837 r
.78009 .25222 .78616 .26366 .79933 .25645 .79338 .24594 Mtetra
.695 .705 .855 r
.79338 .24594 .79933 .25645 .81258 .24961 .80673 .23979 Mtetra
.694 .721 .87 r
.80673 .23979 .81258 .24961 .82591 .24317 .82015 .23384 Mtetra
.69 .732 .883 r
.82015 .23384 .82591 .24317 .83933 .23715 .83366 .22813 Mtetra
.664 .741 .908 r
.21628 .42788 .22373 .43482 .23467 .43107 .22724 .4241 Mtetra
.22724 .4241 .23467 .43107 .24565 .4273 .23825 .4203 Mtetra
.23825 .4203 .24565 .4273 .25668 .42352 .24931 .41649 Mtetra
.24931 .41649 .25668 .42352 .26775 .41972 .26041 .41266 Mtetra
.26041 .41266 .26775 .41972 .27888 .4159 .27156 .40882 Mtetra
.27156 .40882 .27888 .4159 .29005 .41207 .28276 .40496 Mtetra
.28276 .40496 .29005 .41207 .30127 .40823 .29401 .40108 Mtetra
.29401 .40108 .30127 .40823 .31253 .40436 .3053 .39719 Mtetra
.3053 .39719 .31253 .40436 .32384 .40048 .31665 .39328 Mtetra
.663 .741 .908 r
.31665 .39328 .32384 .40048 .33521 .39659 .32804 .38935 Mtetra
.32804 .38935 .33521 .39659 .34662 .39267 .33948 .38542 Mtetra
.33948 .38542 .34662 .39267 .35808 .38875 .35097 .38148 Mtetra
.662 .742 .909 r
.35097 .38148 .35808 .38875 .36959 .38481 .36251 .37754 Mtetra
.661 .742 .911 r
.36251 .37754 .36959 .38481 .38115 .38086 .3741 .37363 Mtetra
.658 .744 .913 r
.3741 .37363 .38115 .38086 .39276 .37692 .38573 .36977 Mtetra
.655 .746 .917 r
.38573 .36977 .39276 .37692 .40441 .37298 .39741 .36599 Mtetra
.651 .75 .922 r
.39741 .36599 .40441 .37298 .41612 .36907 .40915 .3623 Mtetra
.646 .757 .93 r
.40915 .3623 .41612 .36907 .42788 .36518 .42093 .35871 Mtetra
.642 .766 .938 r
.42093 .35871 .42788 .36518 .43969 .36133 .43276 .35519 Mtetra
.64 .777 .946 r
.43276 .35519 .43969 .36133 .45155 .3575 .44465 .35166 Mtetra
.641 .788 .953 r
.44465 .35166 .45155 .3575 .46347 .35367 .4566 .34805 Mtetra
.646 .798 .956 r
.4566 .34805 .46347 .35367 .47544 .34978 .46861 .34423 Mtetra
.656 .804 .954 r
.46861 .34423 .47544 .34978 .48746 .34581 .48068 .34016 Mtetra
.666 .805 .949 r
.48068 .34016 .48746 .34581 .49954 .34173 .49281 .33581 Mtetra
.675 .8 .941 r
.49281 .33581 .49954 .34173 .51168 .33754 .50499 .33122 Mtetra
.681 .789 .932 r
.50499 .33122 .51168 .33754 .52387 .33325 .51722 .32649 Mtetra
.681 .777 .923 r
.51722 .32649 .52387 .33325 .53611 .32893 .5295 .32171 Mtetra
.679 .763 .915 r
.5295 .32171 .53611 .32893 .54841 .32464 .54183 .31698 Mtetra
.674 .75 .908 r
.54183 .31698 .54841 .32464 .56076 .32045 .55422 .31238 Mtetra
.668 .737 .902 r
.55422 .31238 .56076 .32045 .57317 .31644 .56666 .30794 Mtetra
.662 .725 .896 r
.56666 .30794 .57317 .31644 .58564 .31264 .57916 .30367 Mtetra
.655 .711 .889 r
.57916 .30367 .58564 .31264 .59818 .3091 .59172 .29957 Mtetra
.649 .696 .88 r
.59172 .29957 .59818 .3091 .61079 .30582 .60434 .29563 Mtetra
.643 .679 .869 r
.60434 .29563 .61079 .30582 .62348 .30281 .61703 .29185 Mtetra
.637 .66 .856 r
.61703 .29185 .62348 .30281 .63624 .30001 .62979 .28821 Mtetra
.633 .643 .842 r
.62979 .28821 .63624 .30001 .64907 .29733 .64261 .28467 Mtetra
.629 .626 .829 r
.64261 .28467 .64907 .29733 .66198 .29464 .65551 .28118 Mtetra
.627 .613 .817 r
.65551 .28118 .66198 .29464 .67496 .29179 .66847 .27767 Mtetra
.628 .605 .808 r
.66847 .27767 .67496 .29179 .68799 .2886 .6815 .27405 Mtetra
.63 .6 .801 r
.6815 .27405 .68799 .2886 .70107 .28494 .69458 .27022 Mtetra
.635 .601 .798 r
.69458 .27022 .70107 .28494 .71418 .28071 .70771 .26612 Mtetra
.642 .607 .799 r
.70771 .26612 .71418 .28071 .72731 .27588 .72089 .2617 Mtetra
.65 .617 .804 r
.72089 .2617 .72731 .27588 .74047 .2705 .73411 .25693 Mtetra
.658 .631 .812 r
.73411 .25693 .74047 .2705 .75364 .26465 .74736 .25185 Mtetra
.666 .648 .822 r
.74736 .25185 .75364 .26465 .76685 .25851 .76066 .24651 Mtetra
.674 .666 .835 r
.76066 .24651 .76685 .25851 .78009 .25222 .774 .24101 Mtetra
.679 .684 .848 r
.774 .24101 .78009 .25222 .79338 .24594 .78739 .23542 Mtetra
.682 .701 .861 r
.78739 .23542 .79338 .24594 .80673 .23979 .80083 .22984 Mtetra
.682 .715 .873 r
.80083 .22984 .80673 .23979 .82015 .23384 .81434 .22432 Mtetra
.681 .725 .883 r
.81434 .22432 .82015 .23384 .83366 .22813 .82792 .21891 Mtetra
.664 .741 .908 r
.20877 .42089 .21628 .42788 .22724 .4241 .21976 .41708 Mtetra
.21976 .41708 .22724 .4241 .23825 .4203 .2308 .41325 Mtetra
.2308 .41325 .23825 .4203 .24931 .41649 .24188 .40941 Mtetra
.24188 .40941 .24931 .41649 .26041 .41266 .25302 .40555 Mtetra
.25302 .40555 .26041 .41266 .27156 .40882 .26419 .40168 Mtetra
.26419 .40168 .27156 .40882 .28276 .40496 .27542 .39779 Mtetra
.27542 .39779 .28276 .40496 .29401 .40108 .2867 .39388 Mtetra
.663 .741 .908 r
.2867 .39388 .29401 .40108 .3053 .39719 .29802 .38996 Mtetra
.29802 .38996 .3053 .39719 .31665 .39328 .30939 .38602 Mtetra
.30939 .38602 .31665 .39328 .32804 .38935 .32081 .38209 Mtetra
.662 .742 .909 r
.32081 .38209 .32804 .38935 .33948 .38542 .33228 .37816 Mtetra
.66 .742 .911 r
.33228 .37816 .33948 .38542 .35097 .38148 .3438 .37427 Mtetra
.657 .744 .914 r
.3438 .37427 .35097 .38148 .36251 .37754 .35536 .37045 Mtetra
.652 .747 .919 r
.35536 .37045 .36251 .37754 .3741 .37363 .36696 .36677 Mtetra
.644 .752 .928 r
.36696 .36677 .3741 .37363 .38573 .36977 .37861 .36327 Mtetra
.633 .761 .94 r
.37861 .36327 .38573 .36977 .39741 .36599 .39031 .36001 Mtetra
.619 .775 .955 r
.39031 .36001 .39741 .36599 .40915 .3623 .40205 .35697 Mtetra
.603 .793 .972 r
.40205 .35697 .40915 .3623 .42093 .35871 .41385 .35409 Mtetra
.589 .814 .986 r
.41385 .35409 .42093 .35871 .43276 .35519 .4257 .35122 Mtetra
.584 .837 .993 r
.4257 .35122 .43276 .35519 .44465 .35166 .43763 .34814 Mtetra
.595 .857 .993 r
.43763 .34814 .44465 .35166 .4566 .34805 .44962 .34466 Mtetra
.622 .871 .989 r
.44962 .34466 .4566 .34805 .46861 .34423 .46168 .34062 Mtetra
.656 .873 .98 r
.46168 .34062 .46861 .34423 .48068 .34016 .47381 .336 Mtetra
.685 .862 .966 r
.47381 .336 .48068 .34016 .49281 .33581 .48599 .33089 Mtetra
.7 .841 .95 r
.48599 .33089 .49281 .33581 .50499 .33122 .49823 .32548 Mtetra
.704 .815 .934 r
.49823 .32548 .50499 .33122 .51722 .32649 .5105 .31998 Mtetra
.7 .792 .921 r
.5105 .31998 .51722 .32649 .5295 .32171 .52283 .31459 Mtetra
.692 .772 .913 r
.52283 .31459 .5295 .32171 .54183 .31698 .5352 .3094 Mtetra
.683 .757 .907 r
.5352 .3094 .54183 .31698 .55422 .31238 .54762 .30447 Mtetra
.675 .746 .904 r
.54762 .30447 .55422 .31238 .56666 .30794 .5601 .29976 Mtetra
.668 .737 .902 r
.5601 .29976 .56666 .30794 .57916 .30367 .57263 .29525 Mtetra
.663 .73 .899 r
.57263 .29525 .57916 .30367 .59172 .29957 .58522 .29088 Mtetra
.659 .722 .895 r
.58522 .29088 .59172 .29957 .60434 .29563 .59787 .28661 Mtetra
.656 .713 .89 r
.59787 .28661 .60434 .29563 .61703 .29185 .61059 .28243 Mtetra
.652 .703 .884 r
.61059 .28243 .61703 .29185 .62979 .28821 .62336 .27833 Mtetra
.649 .692 .876 r
.62336 .27833 .62979 .28821 .64261 .28467 .6362 .27428 Mtetra
.647 .68 .867 r
.6362 .27428 .64261 .28467 .65551 .28118 .64911 .27027 Mtetra
.645 .669 .859 r
.64911 .27027 .65551 .28118 .66847 .27767 .66208 .26628 Mtetra
.644 .659 .851 r
.66208 .26628 .66847 .27767 .6815 .27405 .67511 .26226 Mtetra
.644 .653 .844 r
.67511 .26226 .6815 .27405 .69458 .27022 .6882 .25816 Mtetra
.645 .649 .839 r
.6882 .25816 .69458 .27022 .70771 .26612 .70136 .25395 Mtetra
.648 .649 .837 r
.70136 .25395 .70771 .26612 .72089 .2617 .71457 .24958 Mtetra
.652 .653 .838 r
.71457 .24958 .72089 .2617 .73411 .25693 .72783 .24503 Mtetra
.657 .66 .841 r
.72783 .24503 .73411 .25693 .74736 .25185 .74114 .24029 Mtetra
.662 .67 .847 r
.74114 .24029 .74736 .25185 .76066 .24651 .7545 .23538 Mtetra
.667 .681 .854 r
.7545 .23538 .76066 .24651 .774 .24101 .76791 .23033 Mtetra
.67 .693 .862 r
.76791 .23033 .774 .24101 .78739 .23542 .78138 .22518 Mtetra
.673 .705 .871 r
.78138 .22518 .78739 .23542 .80083 .22984 .7949 .21999 Mtetra
.674 .715 .88 r
.7949 .21999 .80083 .22984 .81434 .22432 .80849 .21479 Mtetra
.674 .724 .887 r
.80849 .21479 .81434 .22432 .82792 .21891 .82214 .20962 Mtetra
.664 .741 .908 r
.2012 .41384 .20877 .42089 .21976 .41708 .21222 .41 Mtetra
.21222 .41 .21976 .41708 .2308 .41325 .22329 .40615 Mtetra
.22329 .40615 .2308 .41325 .24188 .40941 .2344 .40227 Mtetra
.2344 .40227 .24188 .40941 .25302 .40555 .24556 .39839 Mtetra
.24556 .39839 .25302 .40555 .26419 .40168 .25677 .39448 Mtetra
.663 .741 .908 r
.25677 .39448 .26419 .40168 .27542 .39779 .26802 .39056 Mtetra
.26802 .39056 .27542 .39779 .2867 .39388 .27932 .38663 Mtetra
.27932 .38663 .2867 .39388 .29802 .38996 .29068 .38269 Mtetra
.662 .742 .909 r
.29068 .38269 .29802 .38996 .30939 .38602 .30208 .37876 Mtetra
.66 .742 .911 r
.30208 .37876 .30939 .38602 .32081 .38209 .31352 .37488 Mtetra
.656 .743 .914 r
.31352 .37488 .32081 .38209 .33228 .37816 .32501 .37108 Mtetra
.649 .746 .92 r
.32501 .37108 .33228 .37816 .3438 .37427 .33654 .36747 Mtetra
.637 .752 .931 r
.33654 .36747 .3438 .37427 .35536 .37045 .3481 .36414 Mtetra
.617 .762 .948 r
.3481 .36414 .35536 .37045 .36696 .36677 .3597 .3612 Mtetra
.585 .778 .972 r
.3597 .3612 .36696 .36677 .37861 .36327 .37134 .35875 Mtetra
.533 .797 .994 r
.37134 .35875 .37861 .36327 .39031 .36001 .38302 .35677 Mtetra
.456 .811 .997 r
.38302 .35677 .39031 .36001 .40205 .35697 .39475 .3551 Mtetra
.366 .806 .958 r
.39475 .3551 .40205 .35697 .41385 .35409 .40655 .35344 Mtetra
.307 .793 .894 r
.40655 .35344 .41385 .35409 .4257 .35122 .41843 .35137 Mtetra
.323 .809 .859 r
.41843 .35137 .4257 .35122 .43763 .34814 .43041 .34847 Mtetra
.42 .866 .879 r
.43041 .34847 .43763 .34814 .44962 .34466 .44248 .34446 Mtetra
.557 .927 .929 r
.44248 .34446 .44962 .34466 .46168 .34062 .45463 .33932 Mtetra
.671 .945 .96 r
.45463 .33932 .46168 .34062 .47381 .336 .46684 .33323 Mtetra
.729 .917 .957 r
.46684 .33323 .47381 .336 .48599 .33089 .4791 .3266 Mtetra
.743 .871 .939 r
.4791 .3266 .48599 .33089 .49823 .32548 .4914 .31984 Mtetra
.735 .827 .922 r
.4914 .31984 .49823 .32548 .5105 .31998 .50373 .31331 Mtetra
.719 .793 .91 r
.50373 .31331 .5105 .31998 .52283 .31459 .5161 .30722 Mtetra
.703 .769 .904 r
.5161 .30722 .52283 .31459 .5352 .3094 .52851 .30162 Mtetra
.688 .755 .902 r
.52851 .30162 .5352 .3094 .54762 .30447 .54097 .29645 Mtetra
.678 .746 .902 r
.54097 .29645 .54762 .30447 .5601 .29976 .55348 .29161 Mtetra
.671 .741 .903 r
.55348 .29161 .5601 .29976 .57263 .29525 .56605 .28699 Mtetra
.666 .737 .903 r
.56605 .28699 .57263 .29525 .58522 .29088 .57868 .28251 Mtetra
.663 .734 .902 r
.57868 .28251 .58522 .29088 .59787 .28661 .59137 .27809 Mtetra
.661 .73 .901 r
.59137 .27809 .59787 .28661 .61059 .28243 .60411 .27372 Mtetra
.659 .725 .898 r
.60411 .27372 .61059 .28243 .62336 .27833 .61692 .26938 Mtetra
.658 .72 .894 r
.61692 .26938 .62336 .27833 .6362 .27428 .62979 .26506 Mtetra
.656 .713 .89 r
.62979 .26506 .6362 .27428 .64911 .27027 .64272 .26076 Mtetra
.655 .706 .885 r
.64272 .26076 .64911 .27027 .66208 .26628 .65571 .25646 Mtetra
.654 .7 .88 r
.65571 .25646 .66208 .26628 .67511 .26226 .66877 .25216 Mtetra
.654 .694 .875 r
.66877 .25216 .67511 .26226 .6882 .25816 .68188 .24783 Mtetra
.654 .69 .871 r
.68188 .24783 .6882 .25816 .70136 .25395 .69506 .24345 Mtetra
.655 .687 .868 r
.69506 .24345 .70136 .25395 .71457 .24958 .7083 .239 Mtetra
.657 .687 .867 r
.7083 .239 .71457 .24958 .72783 .24503 .7216 .23446 Mtetra
.659 .689 .867 r
.7216 .23446 .72783 .24503 .74114 .24029 .73496 .22982 Mtetra
.661 .693 .869 r
.73496 .22982 .74114 .24029 .7545 .23538 .74837 .22508 Mtetra
.664 .699 .873 r
.74837 .22508 .7545 .23538 .76791 .23033 .76184 .22024 Mtetra
.666 .706 .877 r
.76184 .22024 .76791 .23033 .78138 .22518 .77537 .21532 Mtetra
.668 .713 .882 r
.77537 .21532 .78138 .22518 .7949 .21999 .78895 .21035 Mtetra
.669 .72 .887 r
.78895 .21035 .7949 .21999 .80849 .21479 .8026 .20535 Mtetra
.669 .726 .892 r
.8026 .20535 .80849 .21479 .82214 .20962 .81631 .20033 Mtetra
.664 .741 .908 r
.19358 .40674 .2012 .41384 .21222 .41 .20462 .40287 Mtetra
.20462 .40287 .21222 .41 .22329 .40615 .21571 .39899 Mtetra
.21571 .39899 .22329 .40615 .2344 .40227 .22685 .39508 Mtetra
.663 .741 .908 r
.22685 .39508 .2344 .40227 .24556 .39839 .23804 .39116 Mtetra
.23804 .39116 .24556 .39839 .25677 .39448 .24928 .38723 Mtetra
.24928 .38723 .25677 .39448 .26802 .39056 .26056 .38329 Mtetra
.662 .741 .909 r
.26056 .38329 .26802 .39056 .27932 .38663 .27189 .37936 Mtetra
.661 .742 .91 r
.27189 .37936 .27932 .38663 .29068 .38269 .28327 .37546 Mtetra
.657 .743 .913 r
.28327 .37546 .29068 .38269 .30208 .37876 .29468 .37166 Mtetra
.649 .745 .92 r
.29468 .37166 .30208 .37876 .31352 .37488 .30614 .36805 Mtetra
.634 .75 .932 r
.30614 .36805 .31352 .37488 .32501 .37108 .31762 .36479 Mtetra
.606 .76 .952 r
.31762 .36479 .32501 .37108 .33654 .36747 .32913 .3621 Mtetra
.552 .773 .981 r
.32913 .3621 .33654 .36747 .3481 .36414 .34065 .36016 Mtetra
.438 .777 .997 r
.34065 .36016 .3481 .36414 .3597 .3612 .35218 .35914 Mtetra
.214 .711 .915 r
.35218 .35914 .3597 .3612 .37134 .35875 .36375 .35898 Mtetra
.069 0 0 r
.36375 .35898 .37134 .35875 .38302 .35677 .37537 .35939 Mtetra
.24 0 0 r
.37537 .35939 .38302 .35677 .39475 .3551 .38707 .35978 Mtetra
.276 0 0 r
.38707 .35978 .39475 .3551 .40655 .35344 .39889 .35937 Mtetra
.217 0 0 r
.39889 .35937 .40655 .35344 .41843 .35137 .41085 .3574 Mtetra
.065 0 0 r
.41085 .3574 .41843 .35137 .43041 .34847 .42295 .35339 Mtetra
0 0 0 r
.42295 .35339 .43041 .34847 .44248 .34446 .43515 .34728 Mtetra
.542 .917 .767 r
.43515 .34728 .44248 .34446 .45463 .33932 .44744 .3395 Mtetra
.748 .985 .904 r
.44744 .3395 .45463 .33932 .46684 .33323 .45978 .33078 Mtetra
.798 .931 .921 r
.45978 .33078 .46684 .33323 .4791 .3266 .47214 .32191 Mtetra
.785 .862 .907 r
.47214 .32191 .4791 .3266 .4914 .31984 .48451 .31352 Mtetra
.757 .811 .896 r
.48451 .31352 .4914 .31984 .50373 .31331 .4969 .30597 Mtetra
.729 .778 .891 r
.4969 .30597 .50373 .31331 .5161 .30722 .50932 .29933 Mtetra
.706 .758 .892 r
.50932 .29933 .5161 .30722 .52851 .30162 .52177 .29349 Mtetra
.689 .747 .896 r
.52177 .29349 .52851 .30162 .54097 .29645 .53427 .28825 Mtetra
.677 .742 .9 r
.53427 .28825 .54097 .29645 .55348 .29161 .54682 .28339 Mtetra
.67 .74 .903 r
.54682 .28339 .55348 .29161 .56605 .28699 .55942 .27875 Mtetra
.666 .739 .905 r
.55942 .27875 .56605 .28699 .57868 .28251 .57209 .27422 Mtetra
.664 .738 .905 r
.57209 .27422 .57868 .28251 .59137 .27809 .58481 .26974 Mtetra
.663 .737 .905 r
.58481 .26974 .59137 .27809 .60411 .27372 .5976 .26527 Mtetra
.662 .735 .904 r
.5976 .26527 .60411 .27372 .61692 .26938 .61044 .26082 Mtetra
.661 .733 .903 r
.61044 .26082 .61692 .26938 .62979 .26506 .62334 .25635 Mtetra
.661 .73 .901 r
.62334 .25635 .62979 .26506 .64272 .26076 .6363 .25189 Mtetra
.66 .727 .898 r
.6363 .25189 .64272 .26076 .65571 .25646 .64933 .24742 Mtetra
.66 .723 .896 r
.64933 .24742 .65571 .25646 .66877 .25216 .66242 .24295 Mtetra
.659 .719 .893 r
.66242 .24295 .66877 .25216 .68188 .24783 .67557 .23845 Mtetra
.659 .716 .891 r
.67557 .23845 .68188 .24783 .69506 .24345 .68878 .23393 Mtetra
.659 .714 .888 r
.68878 .23393 .69506 .24345 .7083 .239 .70205 .22938 Mtetra
.66 .712 .887 r
.70205 .22938 .7083 .239 .7216 .23446 .71539 .22478 Mtetra
.661 .712 .886 r
.71539 .22478 .7216 .23446 .73496 .22982 .72878 .22013 Mtetra
.662 .713 .887 r
.72878 .22013 .73496 .22982 .74837 .22508 .74224 .21541 Mtetra
.663 .716 .888 r
.74224 .21541 .74837 .22508 .76184 .22024 .75576 .21064 Mtetra
.664 .719 .89 r
.75576 .21064 .76184 .22024 .77537 .21532 .76934 .20582 Mtetra
.665 .723 .892 r
.76934 .20582 .77537 .21532 .78895 .21035 .78298 .20094 Mtetra
.666 .726 .895 r
.78298 .20094 .78895 .21035 .8026 .20535 .79669 .19603 Mtetra
.666 .73 .897 r
.79669 .19603 .8026 .20535 .81631 .20033 .81045 .19109 Mtetra
.664 .741 .908 r
.18589 .39958 .19358 .40674 .20462 .40287 .19696 .39568 Mtetra
.19696 .39568 .20462 .40287 .21571 .39899 .20808 .39177 Mtetra
.663 .741 .908 r
.20808 .39177 .21571 .39899 .22685 .39508 .21925 .38784 Mtetra
.21925 .38784 .22685 .39508 .23804 .39116 .23046 .38389 Mtetra
.23046 .38389 .23804 .39116 .24928 .38723 .24173 .37995 Mtetra
.661 .742 .91 r
.24173 .37995 .24928 .38723 .26056 .38329 .25303 .37603 Mtetra
.658 .742 .912 r
.25303 .37603 .26056 .38329 .27189 .37936 .26438 .37219 Mtetra
.651 .744 .918 r
.26438 .37219 .27189 .37936 .28327 .37546 .27577 .36853 Mtetra
.636 .748 .929 r
.27577 .36853 .28327 .37546 .29468 .37166 .28718 .36524 Mtetra
.606 .755 .95 r
.28718 .36524 .29468 .37166 .30614 .36805 .29859 .36258 Mtetra
.538 .765 .981 r
.29859 .36258 .30614 .36805 .31762 .36479 .31001 .3609 Mtetra
.368 .747 .989 r
.31001 .3609 .31762 .36479 .32913 .3621 .3214 .36056 Mtetra
0 .558 .778 r
.3214 .36056 .32913 .3621 .34065 .36016 .33277 .36179 Mtetra
.384 0 0 r
.33277 .36179 .34065 .36016 .35218 .35914 .34415 .3645 Mtetra
.517 .015 0 r
.34415 .3645 .35218 .35914 .36375 .35898 .35558 .36815 Mtetra
.536 .091 .139 r
.35558 .36815 .36375 .35898 .37537 .35939 .36713 .3717 Mtetra
.506 .092 .189 r
.36713 .3717 .37537 .35939 .38707 .35978 .37885 .37381 Mtetra
.439 .038 .181 r
.37885 .37381 .38707 .35978 .39889 .35937 .39078 .37318 Mtetra
.316 0 .111 r
.39078 .37318 .39889 .35937 .41085 .3574 .40293 .36901 Mtetra
.084 0 0 r
.40293 .36901 .41085 .3574 .42295 .35339 .41526 .3613 Mtetra
0 0 0 r
.41526 .3613 .42295 .35339 .43515 .34728 .4277 .35081 Mtetra
.749 .986 .765 r
.4277 .35081 .43515 .34728 .44744 .3395 .44019 .33884 Mtetra
.862 .964 .865 r
.44019 .33884 .44744 .3395 .45978 .33078 .45267 .32673 Mtetra
.842 .878 .868 r
.45267 .32673 .45978 .33078 .47214 .32191 .46514 .31554 Mtetra
.799 .815 .864 r
.46514 .31554 .47214 .32191 .48451 .31352 .47758 .30582 Mtetra
.76 .775 .866 r
.47758 .30582 .48451 .31352 .4969 .30597 .49002 .29767 Mtetra
.727 .754 .874 r
.49002 .29767 .4969 .30597 .50932 .29933 .50248 .29086 Mtetra
.702 .743 .883 r
.50248 .29086 .50932 .29933 .52177 .29349 .51497 .28505 Mtetra
.685 .739 .892 r
.51497 .28505 .52177 .29349 .53427 .28825 .5275 .27988 Mtetra
.674 .739 .899 r
.5275 .27988 .53427 .28825 .54682 .28339 .54009 .27508 Mtetra
.668 .739 .903 r
.54009 .27508 .54682 .28339 .55942 .27875 .55274 .27046 Mtetra
.665 .74 .906 r
.55274 .27046 .55942 .27875 .57209 .27422 .56544 .26592 Mtetra
.664 .74 .907 r
.56544 .26592 .57209 .27422 .58481 .26974 .5782 .2614 Mtetra
.663 .74 .907 r
.5782 .2614 .58481 .26974 .5976 .26527 .59103 .25689 Mtetra
.663 .739 .907 r
.59103 .25689 .5976 .26527 .61044 .26082 .60391 .25236 Mtetra
.663 .738 .906 r
.60391 .25236 .61044 .26082 .62334 .25635 .61685 .24782 Mtetra
.663 .737 .905 r
.61685 .24782 .62334 .25635 .6363 .25189 .62985 .24327 Mtetra
.662 .736 .904 r
.62985 .24327 .6363 .25189 .64933 .24742 .64291 .2387 Mtetra
.662 .734 .903 r
.64291 .2387 .64933 .24742 .66242 .24295 .65604 .23412 Mtetra
.662 .732 .902 r
.65604 .23412 .66242 .24295 .67557 .23845 .66922 .22952 Mtetra
.662 .731 .901 r
.66922 .22952 .67557 .23845 .68878 .23393 .68247 .2249 Mtetra
.662 .729 .899 r
.68247 .2249 .68878 .23393 .70205 .22938 .69579 .22026 Mtetra
.662 .728 .898 r
.69579 .22026 .70205 .22938 .71539 .22478 .70916 .21559 Mtetra
.662 .727 .898 r
.70916 .21559 .71539 .22478 .72878 .22013 .7226 .21089 Mtetra
.662 .727 .897 r
.7226 .21089 .72878 .22013 .74224 .21541 .7361 .20615 Mtetra
.663 .728 .898 r
.7361 .20615 .74224 .21541 .75576 .21064 .74966 .20137 Mtetra
.663 .729 .898 r
.74966 .20137 .75576 .21064 .76934 .20582 .76329 .19655 Mtetra
.664 .73 .899 r
.76329 .19655 .76934 .20582 .78298 .20094 .77698 .1917 Mtetra
.664 .732 .9 r
.77698 .1917 .78298 .20094 .79669 .19603 .79073 .18681 Mtetra
.665 .734 .902 r
.79073 .18681 .79669 .19603 .81045 .19109 .80455 .18189 Mtetra
.663 .741 .908 r
.17814 .39237 .18589 .39958 .19696 .39568 .18924 .38844 Mtetra
.18924 .38844 .19696 .39568 .20808 .39177 .20039 .3845 Mtetra
.20039 .3845 .20808 .39177 .21925 .38784 .21158 .38055 Mtetra
.662 .741 .909 r
.21158 .38055 .21925 .38784 .23046 .38389 .22282 .37661 Mtetra
.66 .742 .911 r
.22282 .37661 .23046 .38389 .24173 .37995 .23411 .37272 Mtetra
.654 .743 .915 r
.23411 .37272 .24173 .37995 .25303 .37603 .24542 .36897 Mtetra
.642 .745 .924 r
.24542 .36897 .25303 .37603 .26438 .37219 .25677 .36554 Mtetra
.615 .751 .942 r
.25677 .36554 .26438 .37219 .27577 .36853 .26811 .3627 Mtetra
.551 .758 .974 r
.26811 .3627 .27577 .36853 .28718 .36524 .27944 .36092 Mtetra
.376 .737 .99 r
.27944 .36092 .28718 .36524 .29859 .36258 .29071 .36072 Mtetra
0 .499 .746 r
.29071 .36072 .29859 .36258 .31001 .3609 .30191 .36269 Mtetra
.506 0 0 r
.30191 .36269 .31001 .3609 .3214 .36056 .31303 .36715 Mtetra
.623 .161 .136 r
.31303 .36715 .3214 .36056 .33277 .36179 .32413 .37394 Mtetra
.636 .235 .267 r
.32413 .37394 .33277 .36179 .34415 .3645 .33526 .38216 Mtetra
.616 .248 .323 r
.33526 .38216 .34415 .3645 .35558 .36815 .34656 .39012 Mtetra
.575 .225 .339 r
.34656 .39012 .35558 .36815 .36713 .3717 .35812 .39567 Mtetra
.508 .167 .323 r
.35812 .39567 .36713 .3717 .37885 .37381 .37003 .39676 Mtetra
.397 .056 .266 r
.37003 .39676 .37885 .37381 .39078 .37318 .38228 .39218 Mtetra
.183 0 .124 r
.38228 .39218 .39078 .37318 .40293 .36901 .3948 .38201 Mtetra
0 0 0 r
.3948 .38201 .40293 .36901 .41526 .3613 .4075 .3676 Mtetra
.797 .966 .656 r
.4075 .3676 .41526 .3613 .4277 .35081 .42024 .35102 Mtetra
.921 .948 .797 r
.42024 .35102 .4277 .35081 .44019 .33884 .43295 .33442 Mtetra
.882 .854 .81 r
.43295 .33442 .44019 .33884 .45267 .32673 .44557 .3194 Mtetra
.83 .791 .815 r
.44557 .3194 .45267 .32673 .46514 .31554 .45812 .30676 Mtetra
.784 .755 .827 r
.45812 .30676 .46514 .31554 .47758 .30582 .47062 .2966 Mtetra
.746 .738 .845 r
.47062 .2966 .47758 .30582 .49002 .29767 .4831 .28854 Mtetra
.715 .732 .864 r
.4831 .28854 .49002 .29767 .50248 .29086 .49559 .282 Mtetra
.693 .732 .88 r
.49559 .282 .50248 .29086 .51497 .28505 .50811 .27644 Mtetra
.679 .735 .893 r
.50811 .27644 .51497 .28505 .5275 .27988 .52068 .27144 Mtetra
.671 .737 .9 r
.52068 .27144 .5275 .27988 .54009 .27508 .53331 .26672 Mtetra
.666 .739 .904 r
.53331 .26672 .54009 .27508 .55274 .27046 .546 .26213 Mtetra
.665 .74 .906 r
.546 .26213 .55274 .27046 .56544 .26592 .55874 .25757 Mtetra
.664 .741 .907 r
.55874 .25757 .56544 .26592 .5782 .2614 .57154 .25303 Mtetra
.57154 .25303 .5782 .2614 .59103 .25689 .5844 .24847 Mtetra
.663 .741 .907 r
.5844 .24847 .59103 .25689 .60391 .25236 .59732 .2439 Mtetra
.663 .74 .907 r
.59732 .2439 .60391 .25236 .61685 .24782 .6103 .23931 Mtetra
.6103 .23931 .61685 .24782 .62985 .24327 .62334 .23469 Mtetra
.663 .739 .907 r
.62334 .23469 .62985 .24327 .64291 .2387 .63645 .23006 Mtetra
.663 .739 .906 r
.63645 .23006 .64291 .2387 .65604 .23412 .64961 .22542 Mtetra
.663 .738 .906 r
.64961 .22542 .65604 .23412 .66922 .22952 .66284 .22075 Mtetra
.663 .737 .905 r
.66284 .22075 .66922 .22952 .68247 .2249 .67613 .21606 Mtetra
.663 .736 .905 r
.67613 .21606 .68247 .2249 .69579 .22026 .68948 .21135 Mtetra
.663 .736 .904 r
.68948 .21135 .69579 .22026 .70916 .21559 .7029 .20662 Mtetra
.663 .735 .904 r
.7029 .20662 .70916 .21559 .7226 .21089 .71638 .20186 Mtetra
.663 .735 .903 r
.71638 .20186 .7226 .21089 .7361 .20615 .72992 .19707 Mtetra
.72992 .19707 .7361 .20615 .74966 .20137 .74353 .19226 Mtetra
.74353 .19226 .74966 .20137 .76329 .19655 .7572 .18742 Mtetra
.663 .736 .903 r
.7572 .18742 .76329 .19655 .77698 .1917 .77094 .18254 Mtetra
.664 .736 .904 r
.77094 .18254 .77698 .1917 .79073 .18681 .78474 .17764 Mtetra
.664 .737 .904 r
.78474 .17764 .79073 .18681 .80455 .18189 .79861 .17271 Mtetra
.663 .741 .908 r
.17033 .3851 .17814 .39237 .18924 .38844 .18146 .38115 Mtetra
.18146 .38115 .18924 .38844 .20039 .3845 .19263 .37719 Mtetra
.661 .742 .909 r
.19263 .37719 .20039 .3845 .21158 .38055 .20385 .37326 Mtetra
.658 .742 .912 r
.20385 .37326 .21158 .38055 .22282 .37661 .2151 .36942 Mtetra
.649 .743 .918 r
.2151 .36942 .22282 .37661 .23411 .37272 .22639 .3658 Mtetra
.629 .747 .932 r
.22639 .3658 .23411 .37272 .24542 .36897 .23768 .36267 Mtetra
.581 .752 .959 r
.23768 .36267 .24542 .36897 .25677 .36554 .24894 .36046 Mtetra
.448 .745 .992 r
.24894 .36046 .25677 .36554 .26811 .3627 .26014 .35982 Mtetra
.035 .571 .852 r
.26014 .35982 .26811 .3627 .27944 .36092 .27122 .36157 Mtetra
.51 0 0 r
.27122 .36157 .27944 .36092 .29071 .36072 .28215 .36651 Mtetra
.667 .209 .156 r
.28215 .36651 .29071 .36072 .30191 .36269 .29292 .37513 Mtetra
.688 .3 .307 r
.29292 .37513 .30191 .36269 .31303 .36715 .30361 .38713 Mtetra
.675 .324 .372 r
.30361 .38713 .31303 .36715 .32413 .37394 .31433 .40114 Mtetra
.647 .316 .398 r
.31433 .40114 .32413 .37394 .33526 .38216 .32527 .41464 Mtetra
.603 .284 .402 r
.32527 .41464 .33526 .38216 .34656 .39012 .33661 .42439 Mtetra
.537 .223 .383 r
.33661 .42439 .34656 .39012 .35812 .39567 .34848 .42742 Mtetra
.422 .11 .329 r
.34848 .42742 .35812 .39567 .37003 .39676 .36087 .42203 Mtetra
.183 0 .184 r
.36087 .42203 .37003 .39676 .38228 .39218 .3737 .40849 Mtetra
0 0 0 r
.3737 .40849 .38228 .39218 .3948 .38201 .38677 .38893 Mtetra
.911 .965 .649 r
.38677 .38893 .3948 .38201 .4075 .3676 .39989 .3665 Mtetra
.946 .883 .739 r
.39989 .3665 .4075 .3676 .42024 .35102 .41293 .34431 Mtetra
.889 .794 .749 r
.41293 .34431 .42024 .35102 .43295 .33442 .4258 .32461 Mtetra
.837 .743 .76 r
.4258 .32461 .43295 .33442 .44557 .3194 .43851 .30847 Mtetra
.793 .717 .781 r
.43851 .30847 .44557 .3194 .45812 .30676 .4511 .29594 Mtetra
.756 .71 .808 r
.4511 .29594 .45812 .30676 .47062 .2966 .46362 .2864 Mtetra
.725 .712 .838 r
.46362 .2864 .47062 .2966 .4831 .28854 .47612 .27902 Mtetra
.7 .72 .864 r
.47612 .27902 .4831 .28854 .49559 .282 .48864 .27301 Mtetra
.683 .728 .884 r
.48864 .27301 .49559 .282 .50811 .27644 .5012 .26779 Mtetra
.673 .734 .896 r
.5012 .26779 .50811 .27644 .52068 .27144 .51381 .26297 Mtetra
.667 .737 .902 r
.51381 .26297 .52068 .27144 .53331 .26672 .52647 .25833 Mtetra
.665 .74 .906 r
.52647 .25833 .53331 .26672 .546 .26213 .5392 .25374 Mtetra
.664 .741 .907 r
.5392 .25374 .546 .26213 .55874 .25757 .55198 .24917 Mtetra
.664 .741 .908 r
.55198 .24917 .55874 .25757 .57154 .25303 .56482 .2446 Mtetra
.56482 .2446 .57154 .25303 .5844 .24847 .57772 .24 Mtetra
.57772 .24 .5844 .24847 .59732 .2439 .59068 .23538 Mtetra
.663 .741 .908 r
.59068 .23538 .59732 .2439 .6103 .23931 .6037 .23075 Mtetra
.6037 .23075 .6103 .23931 .62334 .23469 .61678 .22609 Mtetra
.61678 .22609 .62334 .23469 .63645 .23006 .62993 .22141 Mtetra
.663 .741 .907 r
.62993 .22141 .63645 .23006 .64961 .22542 .64313 .21671 Mtetra
.663 .74 .907 r
.64313 .21671 .64961 .22542 .66284 .22075 .6564 .21199 Mtetra
.6564 .21199 .66284 .22075 .67613 .21606 .66973 .20725 Mtetra
.66973 .20725 .67613 .21606 .68948 .21135 .68313 .20249 Mtetra
.663 .739 .906 r
.68313 .20249 .68948 .21135 .7029 .20662 .69659 .1977 Mtetra
.69659 .1977 .7029 .20662 .71638 .20186 .71011 .19289 Mtetra
.71011 .19289 .71638 .20186 .72992 .19707 .7237 .18806 Mtetra
.7237 .18806 .72992 .19707 .74353 .19226 .73735 .1832 Mtetra
.73735 .1832 .74353 .19226 .7572 .18742 .75107 .17832 Mtetra
.75107 .17832 .7572 .18742 .77094 .18254 .76485 .17341 Mtetra
.664 .739 .906 r
.76485 .17341 .77094 .18254 .78474 .17764 .7787 .16847 Mtetra
.7787 .16847 .78474 .17764 .79861 .17271 .79262 .16351 Mtetra
.662 .741 .909 r
.16246 .37778 .17033 .3851 .18146 .38115 .17361 .37382 Mtetra
.66 .742 .91 r
.17361 .37382 .18146 .38115 .19263 .37719 .1848 .36991 Mtetra
.655 .742 .914 r
.1848 .36991 .19263 .37719 .20385 .37326 .19603 .36612 Mtetra
.642 .744 .923 r
.19603 .36612 .20385 .37326 .2151 .36942 .20727 .36267 Mtetra
.612 .748 .942 r
.20727 .36267 .2151 .36942 .22639 .3658 .2185 .3599 Mtetra
.531 .75 .976 r
.2185 .3599 .22639 .3658 .23768 .36267 .22967 .35842 Mtetra
.27 .686 .968 r
.22967 .35842 .23768 .36267 .24894 .36046 .24071 .35912 Mtetra
.361 0 0 r
.24071 .35912 .24894 .36046 .26014 .35982 .25154 .36312 Mtetra
.67 .179 .076 r
.25154 .36312 .26014 .35982 .27122 .36157 .26213 .37148 Mtetra
.718 .32 .294 r
.26213 .37148 .27122 .36157 .28215 .36651 .27246 .38483 Mtetra
.714 .363 .381 r
.27246 .38483 .28215 .36651 .29292 .37513 .28263 .40273 Mtetra
.695 .368 .419 r
.28263 .40273 .29292 .37513 .30361 .38713 .29283 .42323 Mtetra
.665 .352 .434 r
.29283 .42323 .30361 .38713 .31433 .40114 .30331 .44283 Mtetra
.621 .316 .432 r
.30331 .44283 .31433 .40114 .32527 .41464 .31437 .45709 Mtetra
.551 .249 .41 r
.31437 .45709 .32527 .41464 .33661 .42439 .32619 .46198 Mtetra
.419 .119 .347 r
.32619 .46198 .33661 .42439 .34848 .42742 .33879 .45529 Mtetra
.095 0 .157 r
.33879 .45529 .34848 .42742 .36087 .42203 .352 .43763 Mtetra
.682 .823 .382 r
.352 .43763 .36087 .42203 .3737 .40849 .36557 .41209 Mtetra
.977 .905 .673 r
.36557 .41209 .3737 .40849 .38677 .38893 .37918 .38308 Mtetra
.923 .788 .694 r
.37918 .38308 .38677 .38893 .39989 .3665 .39263 .35477 Mtetra
.866 .719 .698 r
.39263 .35477 .39989 .3665 .41293 .34431 .40582 .33007 Mtetra
.822 .684 .712 r
.40582 .33007 .41293 .34431 .4258 .32461 .41875 .31025 Mtetra
.786 .671 .737 r
.41875 .31025 .4258 .32461 .43851 .30847 .43146 .29526 Mtetra
.756 .674 .771 r
.43146 .29526 .43851 .30847 .4511 .29594 .44404 .28423 Mtetra
.728 .686 .81 r
.44404 .28423 .4511 .29594 .46362 .2864 .45657 .27601 Mtetra
.704 .703 .846 r
.45657 .27601 .46362 .2864 .47612 .27902 .46909 .26957 Mtetra
.686 .718 .874 r
.46909 .26957 .47612 .27902 .48864 .27301 .48164 .26413 Mtetra
.674 .729 .891 r
.48164 .26413 .48864 .27301 .5012 .26779 .49423 .25921 Mtetra
.668 .735 .9 r
.49423 .25921 .5012 .26779 .51381 .26297 .50687 .25451 Mtetra
.665 .739 .905 r
.50687 .25451 .51381 .26297 .52647 .25833 .51958 .2499 Mtetra
.664 .74 .907 r
.51958 .2499 .52647 .25833 .5392 .25374 .53234 .24531 Mtetra
.664 .741 .907 r
.53234 .24531 .5392 .25374 .55198 .24917 .54516 .24071 Mtetra
.664 .741 .908 r
.54516 .24071 .55198 .24917 .56482 .2446 .55804 .23609 Mtetra
.55804 .23609 .56482 .2446 .57772 .24 .57098 .23146 Mtetra
.57098 .23146 .57772 .24 .59068 .23538 .58398 .2268 Mtetra
.58398 .2268 .59068 .23538 .6037 .23075 .59704 .22212 Mtetra
.59704 .22212 .6037 .23075 .61678 .22609 .61017 .21742 Mtetra
.61017 .21742 .61678 .22609 .62993 .22141 .62335 .2127 Mtetra
.663 .741 .908 r
.62335 .2127 .62993 .22141 .64313 .21671 .6366 .20796 Mtetra
.6366 .20796 .64313 .21671 .6564 .21199 .64991 .20319 Mtetra
.64991 .20319 .6564 .21199 .66973 .20725 .66329 .19841 Mtetra
.66329 .19841 .66973 .20725 .68313 .20249 .67672 .1936 Mtetra
.663 .741 .907 r
.67672 .1936 .68313 .20249 .69659 .1977 .69023 .18876 Mtetra
.663 .74 .907 r
.69023 .18876 .69659 .1977 .71011 .19289 .70379 .18391 Mtetra
.70379 .18391 .71011 .19289 .7237 .18806 .71743 .17903 Mtetra
.71743 .17903 .7237 .18806 .73735 .1832 .73112 .17412 Mtetra
.73112 .17412 .73735 .1832 .75107 .17832 .74489 .1692 Mtetra
.74489 .1692 .75107 .17832 .76485 .17341 .75872 .16424 Mtetra
.664 .74 .907 r
.75872 .16424 .76485 .17341 .7787 .16847 .77261 .15926 Mtetra
.77261 .15926 .7787 .16847 .79262 .16351 .78658 .15426 Mtetra
.659 .742 .911 r
.15452 .37045 .16246 .37778 .17361 .37382 .16568 .36655 Mtetra
.652 .743 .916 r
.16568 .36655 .17361 .37382 .1848 .36991 .17688 .36283 Mtetra
.635 .745 .927 r
.17688 .36283 .1848 .36991 .19603 .36612 .18808 .35954 Mtetra
.592 .748 .952 r
.18808 .35954 .19603 .36612 .20727 .36267 .19924 .35714 Mtetra
.466 .739 .987 r
.19924 .35714 .20727 .36267 .2185 .3599 .2103 .35642 Mtetra
.034 .558 .863 r
.2103 .35642 .2185 .3599 .22967 .35842 .22116 .35848 Mtetra
.577 .011 0 r
.22116 .35848 .22967 .35842 .24071 .35912 .23173 .36473 Mtetra
.725 .288 .213 r
.23173 .36473 .24071 .35912 .25154 .36312 .24193 .37649 Mtetra
.74 .373 .356 r
.24193 .37649 .25154 .36312 .26213 .37148 .25177 .39448 Mtetra
.73 .397 .415 r
.25177 .39448 .26213 .37148 .27246 .38483 .26136 .4181 Mtetra
.709 .394 .442 r
.26136 .4181 .27246 .38483 .28263 .40273 .27096 .44481 Mtetra
.68 .374 .45 r
.27096 .44481 .28263 .40273 .29283 .42323 .28095 .47012 Mtetra
.635 .334 .444 r
.28095 .47012 .29283 .42323 .30331 .44283 .2917 .48841 Mtetra
.558 .259 .416 r
.2917 .48841 .30331 .44283 .31437 .45709 .30347 .49464 Mtetra
.389 .089 .331 r
.30347 .49464 .31437 .45709 .32619 .46198 .3163 .48623 Mtetra
0 0 0 r
.3163 .48623 .32619 .46198 .33879 .45529 .32997 .46421 Mtetra
.967 .93 .616 r
.32997 .46421 .33879 .45529 .352 .43763 .34408 .43273 Mtetra
.938 .784 .664 r
.34408 .43273 .352 .43763 .36557 .41209 .35825 .39742 Mtetra
.873 .695 .658 r
.35825 .39742 .36557 .41209 .37918 .38308 .37217 .36343 Mtetra
.828 .65 .661 r
.37217 .36343 .37918 .38308 .39263 .35477 .38572 .3342 Mtetra
.796 .629 .675 r
.38572 .3342 .39263 .35477 .40582 .33007 .39888 .31115 Mtetra
.77 .626 .701 r
.39888 .31115 .40582 .33007 .41875 .31025 .41173 .29404 Mtetra
.747 .637 .738 r
.41173 .29404 .41875 .31025 .43146 .29526 .42439 .28174 Mtetra
.725 .659 .783 r
.42439 .28174 .43146 .29526 .44404 .28423 .43694 .27283 Mtetra
.705 .685 .828 r
.43694 .27283 .44404 .28423 .45657 .27601 .44946 .26603 Mtetra
.688 .708 .863 r
.44946 .26603 .45657 .27601 .46909 .26957 .462 .26042 Mtetra
.676 .724 .886 r
.462 .26042 .46909 .26957 .48164 .26413 .47457 .25542 Mtetra
.669 .733 .898 r
.47457 .25542 .48164 .26413 .49423 .25921 .4872 .25068 Mtetra
.666 .738 .904 r
.4872 .25068 .49423 .25921 .50687 .25451 .49988 .24604 Mtetra
.664 .74 .906 r
.49988 .24604 .50687 .25451 .51958 .2499 .51262 .24142 Mtetra
.664 .741 .907 r
.51262 .24142 .51958 .2499 .53234 .24531 .52542 .23681 Mtetra
.664 .741 .908 r
.52542 .23681 .53234 .24531 .54516 .24071 .53828 .23217 Mtetra
.53828 .23217 .54516 .24071 .55804 .23609 .5512 .22752 Mtetra
.5512 .22752 .55804 .23609 .57098 .23146 .56418 .22284 Mtetra
.56418 .22284 .57098 .23146 .58398 .2268 .57722 .21815 Mtetra
.57722 .21815 .58398 .2268 .59704 .22212 .59033 .21343 Mtetra
.59033 .21343 .59704 .22212 .61017 .21742 .60349 .20869 Mtetra
.60349 .20869 .61017 .21742 .62335 .2127 .61672 .20392 Mtetra
.61672 .20392 .62335 .2127 .6366 .20796 .63001 .19914 Mtetra
.63001 .19914 .6366 .20796 .64991 .20319 .64336 .19433 Mtetra
.64336 .19433 .64991 .20319 .66329 .19841 .65678 .1895 Mtetra
.65678 .1895 .66329 .19841 .67672 .1936 .67026 .18464 Mtetra
.67026 .18464 .67672 .1936 .69023 .18876 .68381 .17976 Mtetra
.68381 .17976 .69023 .18876 .70379 .18391 .69742 .17486 Mtetra
.69742 .17486 .70379 .18391 .71743 .17903 .7111 .16994 Mtetra
.7111 .16994 .71743 .17903 .73112 .17412 .72484 .16499 Mtetra
.72484 .16499 .73112 .17412 .74489 .1692 .73865 .16002 Mtetra
.73865 .16002 .74489 .1692 .75872 .16424 .75253 .15502 Mtetra
.75253 .15502 .75872 .16424 .77261 .15926 .76647 .15 Mtetra
.76647 .15 .77261 .15926 .78658 .15426 .78049 .14495 Mtetra
.65 .743 .917 r
.1465 .36317 .15452 .37045 .16568 .36655 .15766 .35951 Mtetra
.628 .745 .931 r
.15766 .35951 .16568 .36655 .17688 .36283 .16882 .35636 Mtetra
.573 .747 .959 r
.16882 .35636 .17688 .36283 .18808 .35954 .17991 .35429 Mtetra
.399 .72 .988 r
.17991 .35429 .18808 .35954 .19924 .35714 .19086 .3542 Mtetra
0 .411 .718 r
.19086 .3542 .19924 .35714 .2103 .35642 .20155 .35741 Mtetra
.664 .14 0 r
.20155 .35741 .2103 .35642 .22116 .35848 .21186 .36551 Mtetra
.75 .34 .274 r
.21186 .36551 .22116 .35848 .23173 .36473 .22169 .38002 Mtetra
.755 .401 .383 r
.22169 .38002 .23173 .36473 .24193 .37649 .23106 .4017 Mtetra
.743 .417 .43 r
.23106 .4017 .24193 .37649 .25177 .39448 .2401 .42974 Mtetra
.723 .412 .451 r
.2401 .42974 .25177 .39448 .26136 .4181 .24915 .46113 Mtetra
.695 .39 .456 r
.24915 .46113 .26136 .4181 .27096 .44481 .25867 .49056 Mtetra
.65 .347 .445 r
.25867 .49056 .27096 .44481 .28095 .47012 .26913 .51148 Mtetra
.563 .256 .405 r
.26913 .51148 .28095 .47012 .2917 .48841 .28089 .51815 Mtetra
.299 0 .249 r
.28089 .51815 .2917 .48841 .30347 .49464 .29395 .50783 Mtetra
.819 .915 .52 r
.29395 .50783 .30347 .49464 .3163 .48623 .30805 .48204 Mtetra
.94 .788 .664 r
.30805 .48204 .3163 .48623 .32997 .46421 .32268 .44585 Mtetra
.865 .672 .64 r
.32268 .44585 .32997 .46421 .34408 .43273 .33736 .4058 Mtetra
.82 .62 .632 r
.33736 .4058 .34408 .43273 .35825 .39742 .35172 .36774 Mtetra
.79 .594 .636 r
.35172 .36774 .35825 .39742 .37217 .36343 .36558 .3354 Mtetra
.767 .584 .65 r
.36558 .3354 .37217 .36343 .38572 .3342 .37896 .31021 Mtetra
.749 .588 .676 r
.37896 .31021 .38572 .3342 .39888 .31115 .39194 .29176 Mtetra
.733 .605 .714 r
.39194 .29176 .39888 .31115 .41173 .29404 .40466 .27868 Mtetra
.718 .633 .762 r
.40466 .27868 .41173 .29404 .42439 .28174 .41723 .26936 Mtetra
.702 .667 .813 r
.41723 .26936 .42439 .28174 .43694 .27283 .42976 .26235 Mtetra
.687 .698 .854 r
.42976 .26235 .43694 .27283 .44946 .26603 .44228 .25665 Mtetra
.676 .719 .881 r
.44228 .25665 .44946 .26603 .462 .26042 .45484 .25159 Mtetra
.669 .731 .896 r
.45484 .25159 .462 .26042 .47457 .25542 .46745 .24682 Mtetra
.666 .737 .903 r
.46745 .24682 .47457 .25542 .4872 .25068 .48011 .24216 Mtetra
.664 .74 .906 r
.48011 .24216 .4872 .25068 .49988 .24604 .49283 .23753 Mtetra
.664 .741 .907 r
.49283 .23753 .49988 .24604 .51262 .24142 .50561 .23289 Mtetra
.664 .741 .908 r
.50561 .23289 .51262 .24142 .52542 .23681 .51844 .22824 Mtetra
.51844 .22824 .52542 .23681 .53828 .23217 .53134 .22357 Mtetra
.53134 .22357 .53828 .23217 .5512 .22752 .5443 .21887 Mtetra
.5443 .21887 .5512 .22752 .56418 .22284 .55732 .21416 Mtetra
.55732 .21416 .56418 .22284 .57722 .21815 .57041 .20942 Mtetra
.57041 .20942 .57722 .21815 .59033 .21343 .58355 .20466 Mtetra
.58355 .20466 .59033 .21343 .60349 .20869 .59676 .19987 Mtetra
.59676 .19987 .60349 .20869 .61672 .20392 .61003 .19507 Mtetra
.61003 .19507 .61672 .20392 .63001 .19914 .62336 .19024 Mtetra
.62336 .19024 .63001 .19914 .64336 .19433 .63676 .18539 Mtetra
.63676 .18539 .64336 .19433 .65678 .1895 .65022 .18051 Mtetra
.65022 .18051 .65678 .1895 .67026 .18464 .66374 .17562 Mtetra
.66374 .17562 .67026 .18464 .68381 .17976 .67734 .17069 Mtetra
.67734 .17069 .68381 .17976 .69742 .17486 .69099 .16575 Mtetra
.69099 .16575 .69742 .17486 .7111 .16994 .70472 .16078 Mtetra
.70472 .16078 .7111 .16994 .72484 .16499 .7185 .15578 Mtetra
.7185 .15578 .72484 .16499 .73865 .16002 .73236 .15077 Mtetra
.73236 .15077 .73865 .16002 .75253 .15502 .74629 .14572 Mtetra
.74629 .14572 .75253 .15502 .76647 .15 .76028 .14066 Mtetra
.76028 .14066 .76647 .15 .78049 .14495 .77434 .13556 Mtetra
.624 .745 .934 r
.13837 .35614 .1465 .36317 .15766 .35951 .14949 .35309 Mtetra
.56 .745 .963 r
.14949 .35309 .15766 .35951 .16882 .35636 .16053 .35122 Mtetra
.353 .703 .984 r
.16053 .35122 .16882 .35636 .17991 .35429 .17138 .35153 Mtetra
.272 0 0 r
.17138 .35153 .17991 .35429 .19086 .3542 .18193 .35541 Mtetra
.696 .19 .032 r
.18193 .35541 .19086 .3542 .20155 .35741 .19203 .36458 Mtetra
.763 .362 .292 r
.19203 .36458 .20155 .35741 .21186 .36551 .20159 .38059 Mtetra
.767 .416 .39 r
.20159 .38059 .21186 .36551 .22169 .38002 .2106 .40417 Mtetra
.756 .43 .432 r
.2106 .40417 .22169 .38002 .23106 .4017 .21924 .43434 Mtetra
.739 .424 .45 r
.21924 .43434 .23106 .4017 .2401 .42974 .22788 .46775 Mtetra
.713 .403 .451 r
.22788 .46775 .2401 .42974 .24915 .46113 .23707 .49864 Mtetra
.67 .355 .433 r
.23707 .49864 .24915 .46113 .25867 .49056 .24736 .52007 Mtetra
.565 .231 .361 r
.24736 .52007 .25867 .49056 .26913 .51148 .25911 .52609 Mtetra
0 0 0 r
.25911 .52609 .26913 .51148 .28089 .51815 .27236 .5141 Mtetra
.928 .808 .707 r
.27236 .5141 .28089 .51815 .29395 .50783 .28677 .48604 Mtetra
.843 .65 .641 r
.28677 .48604 .29395 .50783 .30805 .48204 .30177 .44748 Mtetra
.801 .592 .619 r
.30177 .44748 .30805 .48204 .32268 .44585 .3168 .4054 Mtetra
.775 .564 .614 r
.3168 .4054 .32268 .44585 .33736 .4058 .33145 .36584 Mtetra
.755 .551 .619 r
.33145 .36584 .33736 .4058 .35172 .36774 .34553 .33253 Mtetra
.741 .549 .634 r
.34553 .33253 .35172 .36774 .36558 .3354 .35905 .30679 Mtetra
.729 .558 .66 r
.35905 .30679 .36558 .3354 .37896 .31021 .37211 .28807 Mtetra
.718 .58 .699 r
.37211 .28807 .37896 .31021 .39194 .29176 .38487 .27488 Mtetra
.708 .614 .749 r
.38487 .27488 .39194 .29176 .40466 .27868 .39746 .26552 Mtetra
.697 .654 .803 r
.39746 .26552 .40466 .27868 .41723 .26936 .40998 .2585 Mtetra
.685 .69 .849 r
.40998 .2585 .41723 .26936 .42976 .26235 .42249 .25279 Mtetra
.675 .715 .879 r
.42249 .25279 .42976 .26235 .44228 .25665 .43503 .24772 Mtetra
.669 .729 .895 r
.43503 .24772 .44228 .25665 .45484 .25159 .44762 .24294 Mtetra
.665 .736 .903 r
.44762 .24294 .45484 .25159 .46745 .24682 .46026 .23826 Mtetra
.664 .739 .906 r
.46026 .23826 .46745 .24682 .48011 .24216 .47296 .23361 Mtetra
.664 .741 .907 r
.47296 .23361 .48011 .24216 .49283 .23753 .48571 .22896 Mtetra
.664 .741 .908 r
.48571 .22896 .49283 .23753 .50561 .23289 .49853 .22429 Mtetra
.49853 .22429 .50561 .23289 .51844 .22824 .51141 .2196 Mtetra
.51141 .2196 .51844 .22824 .53134 .22357 .52435 .21488 Mtetra
.52435 .21488 .53134 .22357 .5443 .21887 .53735 .21015 Mtetra
.53735 .21015 .5443 .21887 .55732 .21416 .55041 .20539 Mtetra
.55041 .20539 .55732 .21416 .57041 .20942 .56353 .20061 Mtetra
.56353 .20061 .57041 .20942 .58355 .20466 .57672 .19581 Mtetra
.57672 .19581 .58355 .20466 .59676 .19987 .58996 .19098 Mtetra
.58996 .19098 .59676 .19987 .61003 .19507 .60328 .18614 Mtetra
.60328 .18614 .61003 .19507 .62336 .19024 .61665 .18126 Mtetra
.61665 .18126 .62336 .19024 .63676 .18539 .63009 .17637 Mtetra
.63009 .17637 .63676 .18539 .65022 .18051 .6436 .17145 Mtetra
.6436 .17145 .65022 .18051 .66374 .17562 .65717 .16651 Mtetra
.65717 .16651 .66374 .17562 .67734 .17069 .6708 .16154 Mtetra
.6708 .16154 .67734 .17069 .69099 .16575 .68451 .15655 Mtetra
.68451 .15655 .69099 .16575 .70472 .16078 .69828 .15154 Mtetra
.69828 .15154 .70472 .16078 .7185 .15578 .71211 .1465 Mtetra
.71211 .1465 .7185 .15578 .73236 .15077 .72601 .14144 Mtetra
.72601 .14144 .73236 .15077 .74629 .14572 .73999 .13635 Mtetra
.73999 .13635 .74629 .14572 .76028 .14066 .75403 .13123 Mtetra
.75403 .13123 .76028 .14066 .77434 .13556 .76814 .1261 Mtetra
.557 .743 .964 r
.1301 .34967 .13837 .35614 .14949 .35309 .1411 .34784 Mtetra
.349 .698 .983 r
.1411 .34784 .14949 .35309 .16053 .35122 .1519 .3482 Mtetra
.267 0 0 r
.1519 .3482 .16053 .35122 .17138 .35153 .16237 .35215 Mtetra
.698 .185 .011 r
.16237 .35215 .17138 .35153 .18193 .35541 .17236 .36134 Mtetra
.771 .362 .277 r
.17236 .36134 .18193 .35541 .19203 .36458 .18177 .37725 Mtetra
.778 .42 .377 r
.18177 .37725 .19203 .36458 .20159 .38059 .19062 .40048 Mtetra
.771 .437 .42 r
.19062 .40048 .20159 .38059 .2106 .40417 .19909 .42993 Mtetra
.758 .434 .436 r
.19909 .42993 .2106 .40417 .21924 .43434 .20759 .46214 Mtetra
.738 .413 .432 r
.20759 .46214 .21924 .43434 .22788 .46775 .21667 .49143 Mtetra
.701 .359 .395 r
.21667 .49143 .22788 .46775 .23707 .49864 .22691 .51107 Mtetra
.548 .124 .189 r
.22691 .51107 .23707 .49864 .24736 .52007 .23869 .51547 Mtetra
.849 .851 .844 r
.23869 .51547 .24736 .52007 .25911 .52609 .25202 .50247 Mtetra
.8 .622 .66 r
.25202 .50247 .25911 .52609 .27236 .5141 .26654 .47423 Mtetra
.771 .564 .619 r
.26654 .47423 .27236 .5141 .28677 .48604 .28166 .4363 Mtetra
.752 .538 .605 r
.28166 .4363 .28677 .48604 .30177 .44748 .2968 .39542 Mtetra
.738 .524 .604 r
.2968 .39542 .30177 .44748 .3168 .4054 .31153 .3573 Mtetra
.727 .519 .61 r
.31153 .3573 .3168 .4054 .33145 .36584 .32567 .32539 Mtetra
.718 .523 .626 r
.32567 .32539 .33145 .36584 .34553 .33253 .33922 .30081 Mtetra
.71 .537 .652 r
.33922 .30081 .34553 .33253 .35905 .30679 .35229 .28296 Mtetra
.704 .563 .692 r
.35229 .28296 .35905 .30679 .37211 .28807 .36505 .27035 Mtetra
.699 .601 .744 r
.36505 .27035 .37211 .28807 .38487 .27488 .37763 .26132 Mtetra
.691 .646 .8 r
.37763 .26132 .38487 .27488 .39746 .26552 .39013 .25449 Mtetra
.682 .686 .847 r
.39013 .25449 .39746 .26552 .40998 .2585 .40262 .24886 Mtetra
.673 .713 .878 r
.40262 .24886 .40998 .2585 .42249 .25279 .41514 .24381 Mtetra
.668 .729 .895 r
.41514 .24381 .42249 .25279 .43503 .24772 .42771 .23903 Mtetra
.665 .736 .903 r
.42771 .23903 .43503 .24772 .44762 .24294 .44033 .23434 Mtetra
.664 .739 .906 r
.44033 .23434 .44762 .24294 .46026 .23826 .453 .22968 Mtetra
.664 .741 .907 r
.453 .22968 .46026 .23826 .47296 .23361 .46574 .22501 Mtetra
.664 .741 .908 r
.46574 .22501 .47296 .23361 .48571 .22896 .47854 .22032 Mtetra
.47854 .22032 .48571 .22896 .49853 .22429 .49139 .21561 Mtetra
.49139 .21561 .49853 .22429 .51141 .2196 .50431 .21088 Mtetra
.50431 .21088 .51141 .2196 .52435 .21488 .51729 .20612 Mtetra
.51729 .20612 .52435 .21488 .53735 .21015 .53033 .20135 Mtetra
.53033 .20135 .53735 .21015 .55041 .20539 .54343 .19655 Mtetra
.54343 .19655 .55041 .20539 .56353 .20061 .55659 .19173 Mtetra
.55659 .19173 .56353 .20061 .57672 .19581 .56982 .18688 Mtetra
.56982 .18688 .57672 .19581 .58996 .19098 .58311 .18202 Mtetra
.58311 .18202 .58996 .19098 .60328 .18614 .59647 .17712 Mtetra
.59647 .17712 .60328 .18614 .61665 .18126 .60989 .17221 Mtetra
.60989 .17221 .61665 .18126 .63009 .17637 .62337 .16727 Mtetra
.62337 .16727 .63009 .17637 .6436 .17145 .63692 .16231 Mtetra
.63692 .16231 .6436 .17145 .65717 .16651 .65053 .15732 Mtetra
.65053 .15732 .65717 .16651 .6708 .16154 .66421 .15231 Mtetra
.66421 .15231 .6708 .16154 .68451 .15655 .67796 .14728 Mtetra
.67796 .14728 .68451 .15655 .69828 .15154 .69178 .14222 Mtetra
.69178 .14222 .69828 .15154 .71211 .1465 .70566 .13713 Mtetra
.70566 .13713 .71211 .1465 .72601 .14144 .71961 .13202 Mtetra
.71961 .13202 .72601 .14144 .73999 .13635 .73363 .12689 Mtetra
.73363 .12689 .73999 .13635 .75403 .13123 .74772 .12173 Mtetra
.74772 .12173 .75403 .13123 .76814 .1261 .76188 .11654 Mtetra
.388 .708 .985 r
.12164 .34412 .1301 .34967 .1411 .34784 .13242 .34419 Mtetra
0 .414 .748 r
.13242 .34419 .1411 .34784 .1519 .3482 .14288 .34756 Mtetra
.66 .118 0 r
.14288 .34756 .1519 .3482 .16237 .35215 .15288 .35573 Mtetra
.771 .337 .22 r
.15288 .35573 .16237 .35215 .17236 .36134 .16233 .36995 Mtetra
.788 .41 .34 r
.16233 .36995 .17236 .36134 .18177 .37725 .17124 .39066 Mtetra
.788 .435 .389 r
.17124 .39066 .18177 .37725 .19062 .40048 .17982 .41671 Mtetra
.782 .437 .403 r
.17982 .41671 .19062 .40048 .19909 .42993 .18844 .44482 Mtetra
.774 .419 .383 r
.18844 .44482 .19909 .42993 .20759 .46214 .19766 .46984 Mtetra
.753 .342 .272 r
.19766 .46984 .20759 .46214 .21667 .49143 .20801 .48585 Mtetra
.156 .591 .933 r
.20801 .48585 .21667 .49143 .22691 .51107 .21983 .48811 Mtetra
.713 .577 .701 r
.21983 .48811 .22691 .51107 .23869 .51547 .23311 .47501 Mtetra
.726 .532 .628 r
.23311 .47501 .23869 .51547 .25202 .50247 .2475 .44868 Mtetra
.722 .512 .605 r
.2475 .44868 .25202 .50247 .26654 .47423 .26246 .41416 Mtetra
.716 .502 .598 r
.26246 .41416 .26654 .47423 .28166 .4363 .27742 .37737 Mtetra
.71 .497 .599 r
.27742 .37737 .28166 .4363 .2968 .39542 .29199 .34326 Mtetra
.703 .498 .607 r
.29199 .34326 .2968 .39542 .31153 .3573 .30601 .31477 Mtetra
.698 .506 .624 r
.30601 .31477 .31153 .3573 .32567 .32539 .31947 .29279 Mtetra
.695 .524 .652 r
.31947 .29279 .32567 .32539 .33922 .30081 .33248 .27673 Mtetra
.693 .554 .693 r
.33248 .27673 .33922 .30081 .35229 .28296 .34519 .26524 Mtetra
.69 .597 .747 r
.34519 .26524 .35229 .28296 .36505 .27035 .35773 .25685 Mtetra
.685 .645 .804 r
.35773 .25685 .36505 .27035 .37763 .26132 .37021 .25034 Mtetra
.678 .687 .851 r
.37021 .25034 .37763 .26132 .39013 .25449 .38268 .24486 Mtetra
.672 .714 .88 r
.38268 .24486 .39013 .25449 .40262 .24886 .39518 .23988 Mtetra
.667 .729 .896 r
.39518 .23988 .40262 .24886 .41514 .24381 .40772 .23511 Mtetra
.665 .737 .903 r
.40772 .23511 .41514 .24381 .42771 .23903 .42032 .23041 Mtetra
.664 .74 .906 r
.42032 .23041 .42771 .23903 .44033 .23434 .43297 .22573 Mtetra
.664 .741 .907 r
.43297 .22573 .44033 .23434 .453 .22968 .44569 .22104 Mtetra
.664 .741 .908 r
.44569 .22104 .453 .22968 .46574 .22501 .45846 .21634 Mtetra
.45846 .21634 .46574 .22501 .47854 .22032 .4713 .21161 Mtetra
.4713 .21161 .47854 .22032 .49139 .21561 .48419 .20686 Mtetra
.48419 .20686 .49139 .21561 .50431 .21088 .49715 .20209 Mtetra
.49715 .20209 .50431 .21088 .51729 .20612 .51017 .19729 Mtetra
.51017 .19729 .51729 .20612 .53033 .20135 .52325 .19247 Mtetra
.52325 .19247 .53033 .20135 .54343 .19655 .53639 .18763 Mtetra
.53639 .18763 .54343 .19655 .55659 .19173 .5496 .18277 Mtetra
.5496 .18277 .55659 .19173 .56982 .18688 .56287 .17788 Mtetra
.56287 .17788 .56982 .18688 .58311 .18202 .5762 .17297 Mtetra
.5762 .17297 .58311 .18202 .59647 .17712 .5896 .16803 Mtetra
.5896 .16803 .59647 .17712 .60989 .17221 .60306 .16307 Mtetra
.60306 .16307 .60989 .17221 .62337 .16727 .61659 .15809 Mtetra
.61659 .15809 .62337 .16727 .63692 .16231 .63018 .15308 Mtetra
.63018 .15308 .63692 .16231 .65053 .15732 .64384 .14805 Mtetra
.64384 .14805 .65053 .15732 .66421 .15231 .65757 .143 Mtetra
.65757 .143 .66421 .15231 .67796 .14728 .67136 .13792 Mtetra
.67136 .13792 .67796 .14728 .69178 .14222 .68522 .13281 Mtetra
.68522 .13281 .69178 .14222 .70566 .13713 .69915 .12768 Mtetra
.69915 .12768 .70566 .13713 .71961 .13202 .71315 .12252 Mtetra
.71315 .12252 .71961 .13202 .73363 .12689 .72722 .11734 Mtetra
.72722 .11734 .73363 .12689 .74772 .12173 .74135 .11213 Mtetra
.74135 .11213 .74772 .12173 .76188 .11654 .75556 .1069 Mtetra
.059 .553 .889 r
.11295 .33959 .12164 .34412 .13242 .34419 .12347 .34189 Mtetra
.535 0 0 r
.12347 .34189 .13242 .34419 .14288 .34756 .13359 .34821 Mtetra
.747 .262 .088 r
.13359 .34821 .14288 .34756 .15288 .35573 .14323 .35956 Mtetra
.792 .374 .255 r
.14323 .35956 .15288 .35573 .16233 .36995 .15241 .37618 Mtetra
.804 .416 .318 r
.15241 .37618 .16233 .36995 .17124 .39066 .16132 .39696 Mtetra
.811 .425 .323 r
.16132 .39696 .17124 .39066 .17982 .41671 .17031 .41908 Mtetra
.819 .399 .245 r
.17031 .41908 .17982 .41671 .18844 .44482 .17986 .43824 Mtetra
.638 .108 0 r
.17986 .43824 .18844 .44482 .19766 .46984 .19041 .44968 Mtetra
.527 .488 .757 r
.19041 .44968 .19766 .46984 .20801 .48585 .20226 .44977 Mtetra
.657 .492 .65 r
.20226 .44977 .20801 .48585 .21983 .48811 .21537 .43743 Mtetra
.683 .486 .613 r
.21537 .43743 .21983 .48811 .23311 .47501 .22944 .41457 Mtetra
.689 .481 .599 r
.22944 .41457 .23311 .47501 .2475 .44868 .24399 .38533 Mtetra
.69 .478 .596 r
.24399 .38533 .2475 .44868 .26246 .41416 .25855 .3545 Mtetra
.688 .479 .599 r
.25855 .3545 .26246 .41416 .27742 .37737 .27277 .326 Mtetra
.685 .485 .609 r
.27277 .326 .27742 .37737 .29199 .34326 .28651 .30216 Mtetra
.683 .497 .629 r
.28651 .30216 .29199 .34326 .30601 .31477 .29978 .28363 Mtetra
.683 .52 .659 r
.29978 .28363 .30601 .31477 .31947 .29279 .31266 .26989 Mtetra
.683 .556 .704 r
.31266 .26989 .31947 .29279 .33248 .27673 .32529 .25982 Mtetra
.683 .602 .759 r
.32529 .25982 .33248 .27673 .34519 .26524 .33778 .25223 Mtetra
.68 .651 .814 r
.33778 .25223 .34519 .26524 .35773 .25685 .35022 .24613 Mtetra
.675 .691 .858 r
.35022 .24613 .35773 .25685 .37021 .25034 .36266 .24083 Mtetra
.67 .717 .884 r
.36266 .24083 .37021 .25034 .38268 .24486 .37513 .23592 Mtetra
.666 .731 .898 r
.37513 .23592 .38268 .24486 .39518 .23988 .38766 .23116 Mtetra
.665 .737 .904 r
.38766 .23116 .39518 .23988 .40772 .23511 .40023 .22646 Mtetra
.664 .74 .907 r
.40023 .22646 .40772 .23511 .42032 .23041 .41286 .22177 Mtetra
.664 .741 .907 r
.41286 .22177 .42032 .23041 .43297 .22573 .42556 .21706 Mtetra
.664 .741 .908 r
.42556 .21706 .43297 .22573 .44569 .22104 .43831 .21234 Mtetra
.43831 .21234 .44569 .22104 .45846 .21634 .45112 .20759 Mtetra
.45112 .20759 .45846 .21634 .4713 .21161 .46399 .20282 Mtetra
.46399 .20282 .4713 .21161 .48419 .20686 .47693 .19803 Mtetra
.47693 .19803 .48419 .20686 .49715 .20209 .48993 .19321 Mtetra
.48993 .19321 .49715 .20209 .51017 .19729 .50298 .18838 Mtetra
.50298 .18838 .51017 .19729 .52325 .19247 .5161 .18352 Mtetra
.5161 .18352 .52325 .19247 .53639 .18763 .52929 .17863 Mtetra
.52929 .17863 .53639 .18763 .5496 .18277 .54254 .17372 Mtetra
.54254 .17372 .5496 .18277 .56287 .17788 .55585 .16879 Mtetra
.55585 .16879 .56287 .17788 .5762 .17297 .56922 .16384 Mtetra
.56922 .16384 .5762 .17297 .5896 .16803 .58266 .15886 Mtetra
.58266 .15886 .5896 .16803 .60306 .16307 .59617 .15386 Mtetra
.59617 .15386 .60306 .16307 .61659 .15809 .60974 .14883 Mtetra
.60974 .14883 .61659 .15809 .63018 .15308 .62338 .14378 Mtetra
.62338 .14378 .63018 .15308 .64384 .14805 .63708 .1387 Mtetra
.63708 .1387 .64384 .14805 .65757 .143 .65086 .1336 Mtetra
.65086 .1336 .65757 .143 .67136 .13792 .6647 .12847 Mtetra
.6647 .12847 .67136 .13792 .68522 .13281 .6786 .12332 Mtetra
.6786 .12332 .68522 .13281 .69915 .12768 .69258 .11814 Mtetra
.69258 .11814 .69915 .12768 .71315 .12252 .70663 .11294 Mtetra
.70663 .11294 .71315 .12252 .72722 .11734 .72074 .10771 Mtetra
.72074 .10771 .72722 .11734 .74135 .11213 .73493 .10245 Mtetra
.73493 .10245 .74135 .11213 .75556 .1069 .74918 .09717 Mtetra
0 .351 .703 r
.1041 .33558 .11295 .33959 .12347 .34189 .11441 .33963 Mtetra
.628 .065 0 r
.11441 .33963 .12347 .34189 .13359 .34821 .12434 .34752 Mtetra
.759 .265 .054 r
.12434 .34752 .13359 .34821 .14323 .35956 .13393 .35934 Mtetra
.8 .34 .143 r
.13393 .35934 .14323 .35956 .15241 .37618 .14332 .37414 Mtetra
.815 .346 .102 r
.14332 .37414 .15241 .37618 .16132 .39696 .15281 .38965 Mtetra
.703 .193 0 r
.15281 .38965 .16132 .39696 .17031 .41908 .16278 .4026 Mtetra
.22 .346 .78 r
.16278 .4026 .17031 .41908 .17986 .43824 .17359 .40949 Mtetra
.558 .449 .686 r
.17359 .40949 .17986 .43824 .19041 .44968 .18544 .40776 Mtetra
.632 .461 .633 r
.18544 .40776 .19041 .44968 .20226 .44977 .19831 .39677 Mtetra
.657 .463 .61 r
.19831 .39677 .20226 .44977 .21537 .43743 .21193 .37808 Mtetra
.667 .464 .601 r
.21193 .37808 .21537 .43743 .22944 .41457 .22593 .35482 Mtetra
.67 .466 .599 r
.22593 .35482 .22944 .41457 .24399 .38533 .23994 .33052 Mtetra
.671 .471 .605 r
.23994 .33052 .24399 .38533 .25855 .3545 .2537 .30809 Mtetra
.672 .48 .618 r
.2537 .30809 .25855 .3545 .27277 .326 .26708 .2892 Mtetra
.673 .498 .641 r
.26708 .2892 .27277 .326 .28651 .30216 .28009 .27431 Mtetra
.675 .526 .676 r
.28009 .27431 .28651 .30216 .29978 .28363 .2928 .26299 Mtetra
.677 .567 .723 r
.2928 .26299 .29978 .28363 .31266 .26989 .30533 .25439 Mtetra
.678 .616 .779 r
.30533 .25439 .31266 .26989 .32529 .25982 .31776 .24761 Mtetra
.676 .663 .83 r
.31776 .24761 .32529 .25982 .33778 .25223 .33016 .24191 Mtetra
.672 .699 .867 r
.33016 .24191 .33778 .25223 .35022 .24613 .34257 .23679 Mtetra
.668 .721 .889 r
.34257 .23679 .35022 .24613 .36266 .24083 .35501 .23194 Mtetra
.665 .733 .9 r
.35501 .23194 .36266 .24083 .37513 .23592 .36751 .2272 Mtetra
.664 .738 .905 r
.36751 .2272 .37513 .23592 .38766 .23116 .38006 .2225 Mtetra
.664 .74 .907 r
.38006 .2225 .38766 .23116 .40023 .22646 .39267 .21779 Mtetra
.664 .741 .908 r
.39267 .21779 .40023 .22646 .41286 .22177 .40534 .21307 Mtetra
.40534 .21307 .41286 .22177 .42556 .21706 .41807 .20832 Mtetra
.41807 .20832 .42556 .21706 .43831 .21234 .43086 .20356 Mtetra
.43086 .20356 .43831 .21234 .45112 .20759 .44372 .19877 Mtetra
.44372 .19877 .45112 .20759 .46399 .20282 .45663 .19396 Mtetra
.45663 .19396 .46399 .20282 .47693 .19803 .4696 .18912 Mtetra
.4696 .18912 .47693 .19803 .48993 .19321 .48264 .18427 Mtetra
.48264 .18427 .48993 .19321 .50298 .18838 .49574 .17939 Mtetra
.49574 .17939 .50298 .18838 .5161 .18352 .5089 .17448 Mtetra
.5089 .17448 .5161 .18352 .52929 .17863 .52212 .16955 Mtetra
.52212 .16955 .52929 .17863 .54254 .17372 .53541 .1646 Mtetra
.53541 .1646 .54254 .17372 .55585 .16879 .54877 .15963 Mtetra
.54877 .15963 .55585 .16879 .56922 .16384 .56218 .15463 Mtetra
.56218 .15463 .56922 .16384 .58266 .15886 .57567 .1496 Mtetra
.57567 .1496 .58266 .15886 .59617 .15386 .58922 .14455 Mtetra
.58922 .14455 .59617 .15386 .60974 .14883 .60283 .13948 Mtetra
.60283 .13948 .60974 .14883 .62338 .14378 .61652 .13438 Mtetra
.61652 .13438 .62338 .14378 .63708 .1387 .63027 .12926 Mtetra
.63027 .12926 .63708 .1387 .65086 .1336 .64408 .12411 Mtetra
.64408 .12411 .65086 .1336 .6647 .12847 .65797 .11894 Mtetra
.65797 .11894 .6647 .12847 .6786 .12332 .67193 .11374 Mtetra
.67193 .11374 .6786 .12332 .69258 .11814 .68595 .10851 Mtetra
.68595 .10851 .69258 .11814 .70663 .11294 .70004 .10326 Mtetra
.70004 .10326 .70663 .11294 .72074 .10771 .71421 .09798 Mtetra
.71421 .09798 .72074 .10771 .73493 .10245 .72844 .09268 Mtetra
.72844 .09268 .73493 .10245 .74918 .09717 .74275 .08735 Mtetra
0 .335 .713 r
.09524 .33091 .1041 .33558 .11441 .33963 .1055 .33537 Mtetra
.519 0 0 r
.1055 .33537 .11441 .33963 .12434 .34752 .11553 .34253 Mtetra
.615 .059 0 r
.11553 .34253 .12434 .34752 .13393 .35934 .12544 .35163 Mtetra
.497 0 0 r
.12544 .35163 .13393 .35934 .14332 .37414 .13546 .36103 Mtetra
.048 .3 .789 r
.13546 .36103 .14332 .37414 .15281 .38965 .14587 .36843 Mtetra
.445 .424 .742 r
.14587 .36843 .15281 .38965 .16278 .4026 .15692 .37143 Mtetra
.573 .447 .671 r
.15692 .37143 .16278 .4026 .17359 .40949 .16875 .36839 Mtetra
.62 .453 .634 r
.16875 .36839 .17359 .40949 .18544 .40776 .18133 .35899 Mtetra
.642 .456 .616 r
.18133 .35899 .18544 .40776 .19831 .39677 .19447 .34438 Mtetra
.652 .459 .609 r
.19447 .34438 .19831 .39677 .21193 .37808 .20789 .32674 Mtetra
.657 .463 .611 r
.20789 .32674 .21193 .37808 .22593 .35482 .22133 .30849 Mtetra
.66 .472 .619 r
.22133 .30849 .22593 .35482 .23994 .33052 .23459 .29161 Mtetra
.663 .487 .636 r
.23459 .29161 .23994 .33052 .2537 .30809 .2476 .27722 Mtetra
.666 .51 .663 r
.2476 .27722 .2537 .30809 .26708 .2892 .26034 .2656 Mtetra
.67 .544 .702 r
.26034 .2656 .26708 .2892 .28009 .27431 .27288 .25644 Mtetra
.674 .588 .752 r
.27288 .25644 .28009 .27431 .2928 .26299 .2853 .24914 Mtetra
.675 .637 .804 r
.2853 .24914 .2928 .26299 .30533 .25439 .29766 .24307 Mtetra
.673 .679 .848 r
.29766 .24307 .30533 .25439 .31776 .24761 .31001 .23772 Mtetra
.669 .709 .878 r
.31001 .23772 .31776 .24761 .33016 .24191 .32239 .23275 Mtetra
.666 .726 .894 r
.32239 .23275 .33016 .24191 .34257 .23679 .33481 .22796 Mtetra
.665 .735 .902 r
.33481 .22796 .34257 .23679 .35501 .23194 .34729 .22323 Mtetra
.664 .739 .906 r
.34729 .22323 .35501 .23194 .36751 .2272 .35982 .21852 Mtetra
.664 .74 .907 r
.35982 .21852 .36751 .2272 .38006 .2225 .3724 .21379 Mtetra
.664 .741 .908 r
.3724 .21379 .38006 .2225 .39267 .21779 .38505 .20905 Mtetra
.38505 .20905 .39267 .21779 .40534 .21307 .39776 .20429 Mtetra
.39776 .20429 .40534 .21307 .41807 .20832 .41053 .19951 Mtetra
.41053 .19951 .41807 .20832 .43086 .20356 .42335 .1947 Mtetra
.42335 .1947 .43086 .20356 .44372 .19877 .43624 .18987 Mtetra
.43624 .18987 .44372 .19877 .45663 .19396 .4492 .18501 Mtetra
.4492 .18501 .45663 .19396 .4696 .18912 .46221 .18014 Mtetra
.46221 .18014 .4696 .18912 .48264 .18427 .47529 .17524 Mtetra
.47529 .17524 .48264 .18427 .49574 .17939 .48843 .17031 Mtetra
.48843 .17031 .49574 .17939 .5089 .17448 .50163 .16537 Mtetra
.50163 .16537 .5089 .17448 .52212 .16955 .51489 .16039 Mtetra
.51489 .16039 .52212 .16955 .53541 .1646 .52823 .1554 Mtetra
.52823 .1554 .53541 .1646 .54877 .15963 .54162 .15038 Mtetra
.54162 .15038 .54877 .15963 .56218 .15463 .55508 .14533 Mtetra
.55508 .14533 .56218 .15463 .57567 .1496 .56861 .14026 Mtetra
.56861 .14026 .57567 .1496 .58922 .14455 .5822 .13517 Mtetra
.5822 .13517 .58922 .14455 .60283 .13948 .59586 .13005 Mtetra
.59586 .13005 .60283 .13948 .61652 .13438 .60959 .12491 Mtetra
.60959 .12491 .61652 .13438 .63027 .12926 .62339 .11974 Mtetra
.62339 .11974 .63027 .12926 .64408 .12411 .63725 .11454 Mtetra
.63725 .11454 .64408 .12411 .65797 .11894 .65119 .10932 Mtetra
.65119 .10932 .65797 .11894 .67193 .11374 .66519 .10407 Mtetra
.66519 .10407 .67193 .11374 .68595 .10851 .67926 .0988 Mtetra
.67926 .0988 .68595 .10851 .70004 .10326 .6934 .0935 Mtetra
.6934 .0935 .70004 .10326 .71421 .09798 .70762 .08817 Mtetra
.70762 .08817 .71421 .09798 .72844 .09268 .7219 .08282 Mtetra
.7219 .08282 .72844 .09268 .74275 .08735 .73626 .07744 Mtetra
.08 .507 .9 r
.08655 .32428 .09524 .33091 .1055 .33537 .09699 .32749 Mtetra
.027 .433 .868 r
.09699 .32749 .1055 .33537 .11553 .34253 .10737 .33188 Mtetra
.178 .444 .873 r
.10737 .33188 .11553 .34253 .12544 .35163 .11786 .33632 Mtetra
.392 .466 .817 r
.11786 .33632 .12544 .35163 .13546 .36103 .12864 .33933 Mtetra
.523 .467 .736 r
.12864 .33933 .13546 .36103 .14587 .36843 .13988 .33941 Mtetra
.586 .464 .68 r
.13988 .33941 .14587 .36843 .15692 .37143 .15167 .33556 Mtetra
.618 .462 .649 r
.15167 .33556 .15692 .37143 .16875 .36839 .16398 .32767 Mtetra
.635 .463 .633 r
.16398 .32767 .16875 .36839 .18133 .35899 .17667 .31651 Mtetra
.644 .466 .628 r
.17667 .31651 .18133 .35899 .19447 .34438 .18958 .30349 Mtetra
.65 .473 .632 r
.18958 .30349 .19447 .34438 .20789 .32674 .2025 .29016 Mtetra
.655 .486 .643 r
.2025 .29016 .20789 .32674 .22133 .30849 .21532 .27775 Mtetra
.659 .505 .665 r
.21532 .27775 .22133 .30849 .23459 .29161 .22798 .26696 Mtetra
.664 .534 .697 r
.22798 .26696 .23459 .29161 .2476 .27722 .24048 .25794 Mtetra
.668 .573 .739 r
.24048 .25794 .2476 .27722 .26034 .2656 .25286 .25048 Mtetra
.672 .618 .787 r
.25286 .25048 .26034 .2656 .27288 .25644 .26518 .24419 Mtetra
.672 .662 .832 r
.26518 .24419 .27288 .25644 .2853 .24914 .27748 .23867 Mtetra
.67 .696 .866 r
.27748 .23867 .2853 .24914 .29766 .24307 .28979 .23359 Mtetra
.667 .719 .887 r
.28979 .23359 .29766 .24307 .31001 .23772 .30214 .22873 Mtetra
.665 .731 .899 r
.30214 .22873 .31001 .23772 .32239 .23275 .31453 .22398 Mtetra
.664 .737 .904 r
.31453 .22398 .32239 .23275 .33481 .22796 .32698 .21925 Mtetra
.664 .74 .906 r
.32698 .21925 .33481 .22796 .34729 .22323 .33949 .21452 Mtetra
.664 .741 .907 r
.33949 .21452 .34729 .22323 .35982 .21852 .35205 .20978 Mtetra
.664 .741 .908 r
.35205 .20978 .35982 .21852 .3724 .21379 .36468 .20503 Mtetra
.36468 .20503 .3724 .21379 .38505 .20905 .37736 .20024 Mtetra
.37736 .20024 .38505 .20905 .39776 .20429 .39011 .19544 Mtetra
.39011 .19544 .39776 .20429 .41053 .19951 .40291 .19061 Mtetra
.40291 .19061 .41053 .19951 .42335 .1947 .41578 .18576 Mtetra
.41578 .18576 .42335 .1947 .43624 .18987 .42871 .18089 Mtetra
.42871 .18089 .43624 .18987 .4492 .18501 .4417 .17599 Mtetra
.4417 .17599 .4492 .18501 .46221 .18014 .45475 .17107 Mtetra
.45475 .17107 .46221 .18014 .47529 .17524 .46787 .16613 Mtetra
.46787 .16613 .47529 .17524 .48843 .17031 .48105 .16116 Mtetra
.48105 .16116 .48843 .17031 .50163 .16537 .49429 .15617 Mtetra
.49429 .15617 .50163 .16537 .51489 .16039 .5076 .15115 Mtetra
.5076 .15115 .51489 .16039 .52823 .1554 .52097 .14611 Mtetra
.52097 .14611 .52823 .1554 .54162 .15038 .53441 .14104 Mtetra
.53441 .14104 .54162 .15038 .55508 .14533 .54792 .13595 Mtetra
.54792 .13595 .55508 .14533 .56861 .14026 .56149 .13084 Mtetra
.56149 .13084 .56861 .14026 .5822 .13517 .57513 .1257 Mtetra
.57513 .1257 .5822 .13517 .59586 .13005 .58883 .12053 Mtetra
.58883 .12053 .59586 .13005 .60959 .12491 .60261 .11534 Mtetra
.60261 .11534 .60959 .12491 .62339 .11974 .61645 .11012 Mtetra
.61645 .11012 .62339 .11974 .63725 .11454 .63036 .10488 Mtetra
.63036 .10488 .63725 .11454 .65119 .10932 .64434 .09961 Mtetra
.64434 .09961 .65119 .10932 .66519 .10407 .65839 .09431 Mtetra
.65839 .09431 .66519 .10407 .67926 .0988 .67251 .08899 Mtetra
.67251 .08899 .67926 .0988 .6934 .0935 .6867 .08364 Mtetra
.6867 .08364 .6934 .0935 .70762 .08817 .70096 .07827 Mtetra
.70096 .07827 .70762 .08817 .7219 .08282 .71529 .07286 Mtetra
.71529 .07286 .7219 .08282 .73626 .07744 .7297 .06743 Mtetra
.411 .613 .932 r
.07814 .31509 .08655 .32428 .09699 .32749 .0889 .31598 Mtetra
.452 .573 .885 r
.0889 .31598 .09699 .32749 .10737 .33188 .09974 .31682 Mtetra
.517 .538 .817 r
.09974 .31682 .10737 .33188 .11786 .33632 .1108 .31672 Mtetra
.568 .512 .752 r
.1108 .31672 .11786 .33632 .12864 .33933 .12218 .31482 Mtetra
.602 .496 .706 r
.12218 .31482 .12864 .33933 .13988 .33941 .13391 .31055 Mtetra
.622 .488 .678 r
.13391 .31055 .13988 .33941 .15167 .33556 .14599 .30389 Mtetra
.635 .486 .663 r
.14599 .30389 .15167 .33556 .16398 .32767 .15833 .29533 Mtetra
.643 .489 .659 r
.15833 .29533 .16398 .32767 .17667 .31651 .17081 .28572 Mtetra
.649 .498 .665 r
.17081 .28572 .17667 .31651 .18958 .30349 .18332 .27596 Mtetra
.654 .515 .681 r
.18332 .27596 .18958 .30349 .2025 .29016 .19579 .26678 Mtetra
.659 .539 .706 r
.19579 .26678 .2025 .29016 .21532 .27775 .20817 .25856 Mtetra
.665 .572 .741 r
.20817 .25856 .21532 .27775 .22798 .26696 .22048 .2514 Mtetra
.669 .611 .782 r
.22048 .2514 .22798 .26696 .24048 .25794 .23273 .24514 Mtetra
.67 .652 .823 r
.23273 .24514 .24048 .25794 .25286 .25048 .24496 .23956 Mtetra
.67 .687 .857 r
.24496 .23956 .25286 .25048 .26518 .24419 .25721 .23441 Mtetra
.668 .712 .881 r
.25721 .23441 .26518 .24419 .27748 .23867 .26948 .2295 Mtetra
.666 .727 .895 r
.26948 .2295 .27748 .23867 .28979 .23359 .2818 .22472 Mtetra
.664 .735 .902 r
.2818 .22472 .28979 .23359 .30214 .22873 .29417 .21998 Mtetra
.664 .739 .906 r
.29417 .21998 .30214 .22873 .31453 .22398 .30659 .21526 Mtetra
.664 .74 .907 r
.30659 .21526 .31453 .22398 .32698 .21925 .31908 .21052 Mtetra
.664 .741 .908 r
.31908 .21052 .32698 .21925 .33949 .21452 .33162 .20576 Mtetra
.33162 .20576 .33949 .21452 .35205 .20978 .34422 .20098 Mtetra
.34422 .20098 .35205 .20978 .36468 .20503 .35688 .19618 Mtetra
.35688 .19618 .36468 .20503 .37736 .20024 .3696 .19136 Mtetra
.3696 .19136 .37736 .20024 .39011 .19544 .38239 .18651 Mtetra
.38239 .18651 .39011 .19544 .40291 .19061 .39523 .18164 Mtetra
.39523 .18164 .40291 .19061 .41578 .18576 .40813 .17675 Mtetra
.40813 .17675 .41578 .18576 .42871 .18089 .4211 .17183 Mtetra
.4211 .17183 .42871 .18089 .4417 .17599 .43413 .16689 Mtetra
.43413 .16689 .4417 .17599 .45475 .17107 .44723 .16193 Mtetra
.44723 .16193 .45475 .17107 .46787 .16613 .46038 .15694 Mtetra
.46038 .15694 .46787 .16613 .48105 .16116 .4736 .15192 Mtetra
.4736 .15192 .48105 .16116 .49429 .15617 .48689 .14689 Mtetra
.48689 .14689 .49429 .15617 .5076 .15115 .50024 .14183 Mtetra
.50024 .14183 .5076 .15115 .52097 .14611 .51366 .13674 Mtetra
.51366 .13674 .52097 .14611 .53441 .14104 .52714 .13163 Mtetra
.52714 .13163 .53441 .14104 .54792 .13595 .54069 .12649 Mtetra
.54069 .12649 .54792 .13595 .56149 .13084 .5543 .12133 Mtetra
.5543 .12133 .56149 .13084 .57513 .1257 .56798 .11614 Mtetra
.56798 .11614 .57513 .1257 .58883 .12053 .58173 .11093 Mtetra
.58173 .11093 .58883 .12053 .60261 .11534 .59555 .10569 Mtetra
.59555 .10569 .60261 .11534 .61645 .11012 .60944 .10042 Mtetra
.60944 .10042 .61645 .11012 .63036 .10488 .6234 .09513 Mtetra
.6234 .09513 .63036 .10488 .64434 .09961 .63742 .08981 Mtetra
.63742 .08981 .64434 .09961 .65839 .09431 .65152 .08447 Mtetra
.65152 .08447 .65839 .09431 .67251 .08899 .66569 .0791 Mtetra
.66569 .0791 .67251 .08899 .6867 .08364 .67993 .0737 Mtetra
.67993 .0737 .6867 .08364 .70096 .07827 .69424 .06827 Mtetra
.69424 .06827 .70096 .07827 .71529 .07286 .70863 .06282 Mtetra
.70863 .06282 .71529 .07286 .7297 .06743 .72309 .05734 Mtetra
.559 .63 .879 r
.06994 .30393 .07814 .31509 .0889 .31598 .08104 .30241 Mtetra
.58 .594 .831 r
.08104 .30241 .0889 .31598 .09974 .31682 .09228 .30031 Mtetra
.602 .563 .783 r
.09228 .30031 .09974 .31682 .1108 .31672 .10373 .29718 Mtetra
.619 .542 .745 r
.10373 .29718 .1108 .31672 .12218 .31482 .11541 .29273 Mtetra
.632 .53 .72 r
.11541 .29273 .12218 .31482 .13391 .31055 .12732 .28697 Mtetra
.641 .526 .707 r
.12732 .28697 .13391 .31055 .14599 .30389 .13939 .28018 Mtetra
.647 .529 .705 r
.13939 .28018 .14599 .30389 .15833 .29533 .15156 .27283 Mtetra
.653 .54 .714 r
.15156 .27283 .15833 .29533 .17081 .28572 .16378 .26543 Mtetra
.658 .559 .731 r
.16378 .26543 .17081 .28572 .18332 .27596 .17598 .25835 Mtetra
.663 .585 .758 r
.17598 .25835 .18332 .27596 .19579 .26678 .18817 .2518 Mtetra
.667 .618 .79 r
.18817 .2518 .19579 .26678 .20817 .25856 .20033 .24582 Mtetra
.669 .652 .825 r
.20033 .24582 .20817 .25856 .22048 .2514 .21248 .24032 Mtetra
.669 .683 .855 r
.21248 .24032 .22048 .2514 .23273 .24514 .22465 .23518 Mtetra
.667 .707 .878 r
.22465 .23518 .23273 .24514 .24496 .23956 .23685 .23026 Mtetra
.666 .723 .892 r
.23685 .23026 .24496 .23956 .25721 .23441 .24909 .22546 Mtetra
.665 .733 .9 r
.24909 .22546 .25721 .23441 .26948 .2295 .26138 .22072 Mtetra
.664 .738 .905 r
.26138 .22072 .26948 .2295 .2818 .22472 .27372 .21599 Mtetra
.664 .74 .907 r
.27372 .21599 .2818 .22472 .29417 .21998 .28613 .21125 Mtetra
.664 .741 .907 r
.28613 .21125 .29417 .21998 .30659 .21526 .29858 .20649 Mtetra
.664 .741 .908 r
.29858 .20649 .30659 .21526 .31908 .21052 .3111 .20172 Mtetra
.3111 .20172 .31908 .21052 .33162 .20576 .32368 .19692 Mtetra
.32368 .19692 .33162 .20576 .34422 .20098 .33632 .1921 Mtetra
.33632 .1921 .34422 .20098 .35688 .19618 .34902 .18726 Mtetra
.34902 .18726 .35688 .19618 .3696 .19136 .36178 .18239 Mtetra
.36178 .18239 .3696 .19136 .38239 .18651 .3746 .1775 Mtetra
.3746 .1775 .38239 .18651 .39523 .18164 .38748 .17259 Mtetra
.38748 .17259 .39523 .18164 .40813 .17675 .40042 .16765 Mtetra
.40042 .16765 .40813 .17675 .4211 .17183 .41343 .16269 Mtetra
.41343 .16269 .4211 .17183 .43413 .16689 .4265 .15771 Mtetra
.4265 .15771 .43413 .16689 .44723 .16193 .43963 .1527 Mtetra
.43963 .1527 .44723 .16193 .46038 .15694 .45283 .14766 Mtetra
.45283 .14766 .46038 .15694 .4736 .15192 .46609 .14261 Mtetra
.46609 .14261 .4736 .15192 .48689 .14689 .47942 .13752 Mtetra
.47942 .13752 .48689 .14689 .50024 .14183 .49281 .13242 Mtetra
.49281 .13242 .50024 .14183 .51366 .13674 .50627 .12728 Mtetra
.50627 .12728 .51366 .13674 .52714 .13163 .5198 .12212 Mtetra
.5198 .12212 .52714 .13163 .54069 .12649 .53339 .11694 Mtetra
.53339 .11694 .54069 .12649 .5543 .12133 .54705 .11173 Mtetra
.54705 .11173 .5543 .12133 .56798 .11614 .56078 .1065 Mtetra
.56078 .1065 .56798 .11614 .58173 .11093 .57457 .10123 Mtetra
.57457 .10123 .58173 .11093 .59555 .10569 .58844 .09595 Mtetra
.58844 .09595 .59555 .10569 .60944 .10042 .60237 .09063 Mtetra
.60237 .09063 .60944 .10042 .6234 .09513 .61637 .08529 Mtetra
.61637 .08529 .6234 .09513 .63742 .08981 .63045 .07992 Mtetra
.63045 .07992 .63742 .08981 .65152 .08447 .64459 .07453 Mtetra
.64459 .07453 .65152 .08447 .66569 .0791 .65881 .06911 Mtetra
.65881 .06911 .66569 .0791 .67993 .0737 .6731 .06366 Mtetra
.6731 .06366 .67993 .0737 .69424 .06827 .68746 .05818 Mtetra
.68746 .05818 .69424 .06827 .70863 .06282 .7019 .05267 Mtetra
.7019 .05267 .70863 .06282 .72309 .05734 .71641 .04714 Mtetra
.618 .642 .852 r
.06178 .2921 .06994 .30393 .08104 .30241 .07313 .28883 Mtetra
.628 .617 .82 r
.07313 .28883 .08104 .30241 .09228 .30031 .08461 .28501 Mtetra
.637 .596 .792 r
.08461 .28501 .09228 .30031 .10373 .29718 .09625 .2805 Mtetra
.644 .584 .772 r
.09625 .2805 .10373 .29718 .11541 .29273 .10803 .27532 Mtetra
.65 .579 .762 r
.10803 .27532 .11541 .29273 .12732 .28697 .11992 .26962 Mtetra
.655 .583 .762 r
.11992 .26962 .12732 .28697 .13939 .28018 .13189 .26364 Mtetra
.659 .594 .771 r
.13189 .26364 .13939 .28018 .15156 .27283 .1439 .25764 Mtetra
.663 .613 .788 r
.1439 .25764 .15156 .27283 .16378 .26543 .15593 .25181 Mtetra
.666 .636 .811 r
.15593 .25181 .16378 .26543 .17598 .25835 .16798 .24624 Mtetra
.667 .663 .836 r
.16798 .24624 .17598 .25835 .18817 .2518 .18004 .24095 Mtetra
.668 .687 .859 r
.18004 .24095 .18817 .2518 .20033 .24582 .19213 .23589 Mtetra
.667 .708 .878 r
.19213 .23589 .20033 .24582 .21248 .24032 .20424 .23099 Mtetra
.666 .722 .891 r
.20424 .23099 .21248 .24032 .22465 .23518 .21641 .2262 Mtetra
.665 .732 .899 r
.21641 .2262 .22465 .23518 .23685 .23026 .22862 .22145 Mtetra
.664 .737 .904 r
.22862 .22145 .23685 .23026 .24909 .22546 .24088 .21672 Mtetra
.664 .739 .906 r
.24088 .21672 .24909 .22546 .26138 .22072 .2532 .21198 Mtetra
.664 .74 .907 r
.2532 .21198 .26138 .22072 .27372 .21599 .26558 .20723 Mtetra
.664 .741 .908 r
.26558 .20723 .27372 .21599 .28613 .21125 .27801 .20245 Mtetra
.27801 .20245 .28613 .21125 .29858 .20649 .29051 .19766 Mtetra
.29051 .19766 .29858 .20649 .3111 .20172 .30306 .19284 Mtetra
.30306 .19284 .3111 .20172 .32368 .19692 .31567 .188 Mtetra
.31567 .188 .32368 .19692 .33632 .1921 .32835 .18314 Mtetra
.32835 .18314 .33632 .1921 .34902 .18726 .34108 .17826 Mtetra
.34108 .17826 .34902 .18726 .36178 .18239 .35388 .17335 Mtetra
.35388 .17335 .36178 .18239 .3746 .1775 .36674 .16841 Mtetra
.36674 .16841 .3746 .1775 .38748 .17259 .37966 .16346 Mtetra
.37966 .16346 .38748 .17259 .40042 .16765 .39264 .15847 Mtetra
.39264 .15847 .40042 .16765 .41343 .16269 .40569 .15347 Mtetra
.40569 .15347 .41343 .16269 .4265 .15771 .4188 .14844 Mtetra
.4188 .14844 .4265 .15771 .43963 .1527 .43197 .14339 Mtetra
.43197 .14339 .43963 .1527 .45283 .14766 .44521 .13831 Mtetra
.44521 .13831 .45283 .14766 .46609 .14261 .45852 .1332 Mtetra
.45852 .1332 .46609 .14261 .47942 .13752 .47188 .12807 Mtetra
.47188 .12807 .47942 .13752 .49281 .13242 .48532 .12292 Mtetra
.48532 .12292 .49281 .13242 .50627 .12728 .49882 .11774 Mtetra
.49882 .11774 .50627 .12728 .5198 .12212 .51239 .11253 Mtetra
.51239 .11253 .5198 .12212 .53339 .11694 .52603 .1073 Mtetra
.52603 .1073 .53339 .11694 .54705 .11173 .53973 .10205 Mtetra
.53973 .10205 .54705 .11173 .56078 .1065 .5535 .09676 Mtetra
.5535 .09676 .56078 .1065 .57457 .10123 .56734 .09145 Mtetra
.56734 .09145 .57457 .10123 .58844 .09595 .58125 .08612 Mtetra
.58125 .08612 .58844 .09595 .60237 .09063 .59523 .08075 Mtetra
.59523 .08075 .60237 .09063 .61637 .08529 .60929 .07536 Mtetra
.60929 .07536 .61637 .08529 .63045 .07992 .62341 .06994 Mtetra
.62341 .06994 .63045 .07992 .64459 .07453 .6376 .0645 Mtetra
.6376 .0645 .64459 .07453 .65881 .06911 .65187 .05902 Mtetra
.65187 .05902 .65881 .06911 .6731 .06366 .66621 .05352 Mtetra
.66621 .05352 .6731 .06366 .68746 .05818 .68062 .04799 Mtetra
.68062 .04799 .68746 .05818 .7019 .05267 .6951 .04244 Mtetra
.6951 .04244 .7019 .05267 .71641 .04714 .70966 .03685 Mtetra
.645 .664 .853 r
.05348 .28077 .06178 .2921 .07313 .28883 .06497 .27659 Mtetra
.65 .649 .836 r
.06497 .27659 .07313 .28883 .08461 .28501 .07657 .27207 Mtetra
.654 .64 .823 r
.07657 .27207 .08461 .28501 .09625 .2805 .08826 .26723 Mtetra
.658 .637 .817 r
.08826 .26723 .09625 .2805 .10803 .27532 .10003 .26214 Mtetra
.661 .64 .818 r
.10003 .26214 .10803 .27532 .11992 .26962 .11187 .25691 Mtetra
.664 .649 .826 r
.11187 .25691 .11992 .26962 .13189 .26364 .12376 .25167 Mtetra
.665 .664 .838 r
.12376 .25167 .13189 .26364 .1439 .25764 .13568 .24651 Mtetra
.666 .681 .854 r
.13568 .24651 .1439 .25764 .15593 .25181 .14764 .24145 Mtetra
.667 .698 .869 r
.14764 .24145 .15593 .25181 .16798 .24624 .15963 .23652 Mtetra
.666 .712 .883 r
.15963 .23652 .16798 .24624 .18004 .24095 .17167 .23169 Mtetra
.665 .724 .893 r
.17167 .23169 .18004 .24095 .19213 .23589 .18375 .22691 Mtetra
.664 .732 .9 r
.18375 .22691 .19213 .23589 .20424 .23099 .19587 .22217 Mtetra
.664 .736 .904 r
.19587 .22217 .20424 .23099 .21641 .2262 .20806 .21744 Mtetra
.664 .739 .906 r
.20806 .21744 .21641 .2262 .22862 .22145 .22029 .21271 Mtetra
.664 .74 .907 r
.22029 .21271 .22862 .22145 .24088 .21672 .23259 .20796 Mtetra
.664 .741 .908 r
.23259 .20796 .24088 .21672 .2532 .21198 .24494 .20319 Mtetra
.24494 .20319 .2532 .21198 .26558 .20723 .25735 .1984 Mtetra
.25735 .1984 .26558 .20723 .27801 .20245 .26982 .19359 Mtetra
.26982 .19359 .27801 .20245 .29051 .19766 .28235 .18875 Mtetra
.28235 .18875 .29051 .19766 .30306 .19284 .29494 .18389 Mtetra
.29494 .18389 .30306 .19284 .31567 .188 .30759 .17901 Mtetra
.30759 .17901 .31567 .188 .32835 .18314 .32031 .1741 Mtetra
.32031 .1741 .32835 .18314 .34108 .17826 .33308 .16917 Mtetra
.33308 .16917 .34108 .17826 .35388 .17335 .34591 .16422 Mtetra
.34591 .16422 .35388 .17335 .36674 .16841 .35881 .15924 Mtetra
.35881 .15924 .36674 .16841 .37966 .16346 .37177 .15424 Mtetra
.37177 .15424 .37966 .16346 .39264 .15847 .38479 .14922 Mtetra
.38479 .14922 .39264 .15847 .40569 .15347 .39788 .14417 Mtetra
.39788 .14417 .40569 .15347 .4188 .14844 .41103 .13909 Mtetra
.41103 .13909 .4188 .14844 .43197 .14339 .42424 .13399 Mtetra
.42424 .13399 .43197 .14339 .44521 .13831 .43752 .12886 Mtetra
.43752 .12886 .44521 .13831 .45852 .1332 .45087 .12371 Mtetra
.45087 .12371 .45852 .1332 .47188 .12807 .46428 .11854 Mtetra
.46428 .11854 .47188 .12807 .48532 .12292 .47776 .11334 Mtetra
.47776 .11334 .48532 .12292 .49882 .11774 .4913 .10811 Mtetra
.4913 .10811 .49882 .11774 .51239 .11253 .50491 .10286 Mtetra
.50491 .10286 .51239 .11253 .52603 .1073 .51859 .09758 Mtetra
.51859 .09758 .52603 .1073 .53973 .10205 .53234 .09227 Mtetra
.53234 .09227 .53973 .10205 .5535 .09676 .54616 .08694 Mtetra
.54616 .08694 .5535 .09676 .56734 .09145 .56005 .08158 Mtetra
.56005 .08158 .56734 .09145 .58125 .08612 .574 .07619 Mtetra
.574 .07619 .58125 .08612 .59523 .08075 .58803 .07078 Mtetra
.58803 .07078 .59523 .08075 .60929 .07536 .60213 .06534 Mtetra
.60213 .06534 .60929 .07536 .62341 .06994 .6163 .05987 Mtetra
.6163 .05987 .62341 .06994 .6376 .0645 .63054 .05437 Mtetra
.63054 .05437 .6376 .0645 .65187 .05902 .64486 .04885 Mtetra
.64486 .04885 .65187 .05902 .66621 .05352 .65925 .04329 Mtetra
.65925 .04329 .66621 .05352 .68062 .04799 .67371 .03771 Mtetra
.67371 .03771 .68062 .04799 .6951 .04244 .68825 .0321 Mtetra
.68825 .0321 .6951 .04244 .70966 .03685 .70286 .02646 Mtetra
.658 .69 .869 r
.04496 .27046 .05348 .28077 .06497 .27659 .05652 .26594 Mtetra
.66 .685 .862 r
.05652 .26594 .06497 .27659 .07657 .27207 .06815 .26127 Mtetra
.662 .683 .86 r
.06815 .26127 .07657 .27207 .08826 .26723 .07985 .25649 Mtetra
.664 .686 .861 r
.07985 .25649 .08826 .26723 .10003 .26214 .09161 .25163 Mtetra
.665 .692 .866 r
.09161 .25163 .10003 .26214 .11187 .25691 .10341 .24677 Mtetra
.665 .701 .873 r
.10341 .24677 .11187 .25691 .12376 .25167 .11527 .24192 Mtetra
.666 .711 .881 r
.11527 .24192 .12376 .25167 .13568 .24651 .12717 .23712 Mtetra
.665 .72 .889 r
.12717 .23712 .13568 .24651 .14764 .24145 .13912 .23235 Mtetra
.665 .727 .896 r
.13912 .23235 .14764 .24145 .15963 .23652 .15111 .22761 Mtetra
.664 .733 .901 r
.15111 .22761 .15963 .23652 .17167 .23169 .16316 .22289 Mtetra
.664 .737 .904 r
.16316 .22289 .17167 .23169 .18375 .22691 .17526 .21817 Mtetra
.664 .739 .906 r
.17526 .21817 .18375 .22691 .19587 .22217 .18741 .21344 Mtetra
.664 .74 .907 r
.18741 .21344 .19587 .22217 .20806 .21744 .19963 .20869 Mtetra
.664 .741 .908 r
.19963 .20869 .20806 .21744 .22029 .21271 .2119 .20392 Mtetra
.2119 .20392 .22029 .21271 .23259 .20796 .22423 .19914 Mtetra
.22423 .19914 .23259 .20796 .24494 .20319 .23661 .19433 Mtetra
.23661 .19433 .24494 .20319 .25735 .1984 .24906 .1895 Mtetra
.24906 .1895 .25735 .1984 .26982 .19359 .26157 .18464 Mtetra
.26157 .18464 .26982 .19359 .28235 .18875 .27413 .17976 Mtetra
.27413 .17976 .28235 .18875 .29494 .18389 .28676 .17486 Mtetra
.28676 .17486 .29494 .18389 .30759 .17901 .29944 .16993 Mtetra
.29944 .16993 .30759 .17901 .32031 .1741 .31219 .16498 Mtetra
.31219 .16498 .32031 .1741 .33308 .16917 .325 .16001 Mtetra
.325 .16001 .33308 .16917 .34591 .16422 .33788 .15501 Mtetra
.33788 .15501 .34591 .16422 .35881 .15924 .35081 .14999 Mtetra
.35081 .14999 .35881 .15924 .37177 .15424 .36381 .14494 Mtetra
.36381 .14494 .37177 .15424 .38479 .14922 .37687 .13987 Mtetra
.37687 .13987 .38479 .14922 .39788 .14417 .39 .13478 Mtetra
.39 .13478 .39788 .14417 .41103 .13909 .40319 .12965 Mtetra
.40319 .12965 .41103 .13909 .42424 .13399 .41644 .12451 Mtetra
.41644 .12451 .42424 .13399 .43752 .12886 .42976 .11934 Mtetra
.42976 .11934 .43752 .12886 .45087 .12371 .44315 .11414 Mtetra
.44315 .11414 .45087 .12371 .46428 .11854 .4566 .10892 Mtetra
.4566 .10892 .46428 .11854 .47776 .11334 .47013 .10367 Mtetra
.47013 .10367 .47776 .11334 .4913 .10811 .48371 .09839 Mtetra
.48371 .09839 .4913 .10811 .50491 .10286 .49737 .09309 Mtetra
.49737 .09309 .50491 .10286 .51859 .09758 .51109 .08776 Mtetra
.51109 .08776 .51859 .09758 .53234 .09227 .52489 .0824 Mtetra
.52489 .0824 .53234 .09227 .54616 .08694 .53875 .07702 Mtetra
.53875 .07702 .54616 .08694 .56005 .08158 .55268 .07161 Mtetra
.55268 .07161 .56005 .08158 .574 .07619 .56669 .06618 Mtetra
.56669 .06618 .574 .07619 .58803 .07078 .58076 .06071 Mtetra
.58076 .06071 .58803 .07078 .60213 .06534 .59491 .05522 Mtetra
.59491 .05522 .60213 .06534 .6163 .05987 .60913 .0497 Mtetra
.60913 .0497 .6163 .05987 .63054 .05437 .62342 .04415 Mtetra
.62342 .04415 .63054 .05437 .64486 .04885 .63778 .03857 Mtetra
.63778 .03857 .64486 .04885 .65925 .04329 .65222 .03297 Mtetra
.65222 .03297 .65925 .04329 .67371 .03771 .66673 .02733 Mtetra
.66673 .02733 .67371 .03771 .68825 .0321 .68132 .02167 Mtetra
.68132 .02167 .68825 .0321 .70286 .02646 .69599 .01598 Mtetra
.662 .714 .886 r
.03622 .26105 .04496 .27046 .05652 .26594 .04781 .25646 Mtetra
.663 .713 .885 r
.04781 .25646 .05652 .26594 .06815 .26127 .05946 .25181 Mtetra
.664 .715 .886 r
.05946 .25181 .06815 .26127 .07985 .25649 .07117 .24713 Mtetra
.665 .718 .889 r
.07117 .24713 .07985 .25649 .09161 .25163 .08292 .24242 Mtetra
.665 .723 .892 r
.08292 .24242 .09161 .25163 .10341 .24677 .09473 .23771 Mtetra
.664 .727 .896 r
.09473 .23771 .10341 .24677 .11527 .24192 .10659 .23301 Mtetra
.664 .732 .9 r
.10659 .23301 .11527 .24192 .12717 .23712 .1185 .22831 Mtetra
.664 .735 .903 r
.1185 .22831 .12717 .23712 .13912 .23235 .13047 .2236 Mtetra
.664 .738 .905 r
.13047 .2236 .13912 .23235 .15111 .22761 .14249 .21889 Mtetra
.664 .739 .906 r
.14249 .21889 .15111 .22761 .16316 .22289 .15456 .21416 Mtetra
.664 .74 .907 r
.15456 .21416 .16316 .22289 .17526 .21817 .16669 .20942 Mtetra
.664 .741 .908 r
.16669 .20942 .17526 .21817 .18741 .21344 .17888 .20466 Mtetra
.17888 .20466 .18741 .21344 .19963 .20869 .19112 .19988 Mtetra
.19112 .19988 .19963 .20869 .2119 .20392 .20343 .19507 Mtetra
.20343 .19507 .2119 .20392 .22423 .19914 .21579 .19024 Mtetra
.21579 .19024 .22423 .19914 .23661 .19433 .22821 .18539 Mtetra
.22821 .18539 .23661 .19433 .24906 .1895 .24069 .18051 Mtetra
.24069 .18051 .24906 .1895 .26157 .18464 .25323 .17561 Mtetra
.25323 .17561 .26157 .18464 .27413 .17976 .26583 .17069 Mtetra
.26583 .17069 .27413 .17976 .28676 .17486 .2785 .16575 Mtetra
.2785 .16575 .28676 .17486 .29944 .16993 .29122 .16078 Mtetra
.29122 .16078 .29944 .16993 .31219 .16498 .30401 .15578 Mtetra
.30401 .15578 .31219 .16498 .325 .16001 .31685 .15076 Mtetra
.31685 .15076 .325 .16001 .33788 .15501 .32977 .14572 Mtetra
.32977 .14572 .33788 .15501 .35081 .14999 .34274 .14065 Mtetra
.34274 .14065 .35081 .14999 .36381 .14494 .35578 .13556 Mtetra
.35578 .13556 .36381 .14494 .37687 .13987 .36888 .13044 Mtetra
.36888 .13044 .37687 .13987 .39 .13478 .38204 .1253 Mtetra
.38204 .1253 .39 .13478 .40319 .12965 .39527 .12013 Mtetra
.39527 .12013 .40319 .12965 .41644 .12451 .40857 .11494 Mtetra
.40857 .11494 .41644 .12451 .42976 .11934 .42193 .10972 Mtetra
.42193 .10972 .42976 .11934 .44315 .11414 .43536 .10448 Mtetra
.43536 .10448 .44315 .11414 .4566 .10892 .44886 .0992 Mtetra
.44886 .0992 .4566 .10892 .47013 .10367 .46242 .09391 Mtetra
.46242 .09391 .47013 .10367 .48371 .09839 .47605 .08858 Mtetra
.47605 .08858 .48371 .09839 .49737 .09309 .48975 .08323 Mtetra
.48975 .08323 .49737 .09309 .51109 .08776 .50352 .07785 Mtetra
.50352 .07785 .51109 .08776 .52489 .0824 .51736 .07245 Mtetra
.51736 .07245 .52489 .0824 .53875 .07702 .53127 .06701 Mtetra
.53127 .06701 .53875 .07702 .55268 .07161 .54525 .06155 Mtetra
.54525 .06155 .55268 .07161 .56669 .06618 .5593 .05607 Mtetra
.5593 .05607 .56669 .06618 .58076 .06071 .57342 .05055 Mtetra
.57342 .05055 .58076 .06071 .59491 .05522 .58762 .04501 Mtetra
.58762 .04501 .59491 .05522 .60913 .0497 .60188 .03943 Mtetra
.60188 .03943 .60913 .0497 .62342 .04415 .61623 .03383 Mtetra
.61623 .03383 .62342 .04415 .63778 .03857 .63064 .0282 Mtetra
.63064 .0282 .63778 .03857 .65222 .03297 .64513 .02254 Mtetra
.64513 .02254 .65222 .03297 .66673 .02733 .65969 .01685 Mtetra
.65969 .01685 .66673 .02733 .68132 .02167 .67433 .01113 Mtetra
.67433 .01113 .68132 .02167 .69599 .01598 .68905 .00539 Mtetra
0 g
.68874 0 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.68874 0 m
.03716 .25514 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 0.522676 0.477324 0.97619 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.49505 0.5 0.49505 [
[ 0 0 -0.125 0 ]
[ 0 0 -0.125 0 ]
[ 0 1 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
0 0 m
1 0 L
s
0 0 m
0 1 L
s
0 1 m
1 1 L
s
1 0 m
1 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
1 .5 0 r
.015 w
.03175 .1355 Mdot
.03435 .12523 Mdot
.11137 .12765 Mdot
.14107 .18841 Mdot
.16218 .24538 Mdot
.17294 .21053 Mdot
.18267 .18577 Mdot
.18434 .1304 Mdot
.18553 .30956 Mdot
.20401 .239 Mdot
.21247 .27571 Mdot
.21687 .20845 Mdot
.22376 .2799 Mdot
.22832 .27485 Mdot
.29063 .20974 Mdot
.29686 .25079 Mdot
.30487 .22936 Mdot
.30683 .34623 Mdot
.32055 .20902 Mdot
.32574 .21979 Mdot
.34472 .28521 Mdot
.35998 .36393 Mdot
.36335 .24976 Mdot
.3794 .36608 Mdot
.42386 .66992 Mdot
.44391 .74519 Mdot
.45059 .34198 Mdot
.47208 .67586 Mdot
.47436 .71381 Mdot
.49778 .59825 Mdot
.50874 .91643 Mdot
.51516 .76219 Mdot
.53655 .61374 Mdot
.56563 .75219 Mdot
.59189 .65665 Mdot
.59581 .61604 Mdot
.59923 .6556 Mdot
.60292 .68499 Mdot
.62656 .67779 Mdot
.63555 .72451 Mdot
.63919 .652 Mdot
.64169 .6004 Mdot
.64246 .58611 Mdot
.64496 .54267 Mdot
.64608 .77288 Mdot
.65077 .64308 Mdot
.66065 .57816 Mdot
.67474 .59169 Mdot
.69296 .563 Mdot
.72815 .65902 Mdot
.73169 .58879 Mdot
.74669 .61318 Mdot
.74821 .65474 Mdot
.75963 .63781 Mdot
.79673 .57809 Mdot
.80925 .55852 Mdot
.81525 .58444 Mdot
.83417 .62985 Mdot
.83598 .55526 Mdot
.91595 .49319 Mdot
0 0 1 r
.005 w
.16128 .17044 m
.18734 .17269 L
.21339 .17909 L
.2345 .18734 L
.23945 .19126 L
.2655 .20415 L
.27874 .21339 L
.29156 .22295 L
.31204 .23945 L
.31761 .24533 L
.33549 .2655 L
.34367 .28342 L
.34499 .29156 L
.34367 .29797 L
.31761 .3104 L
.29156 .30711 L
.2655 .30014 L
.24507 .29156 L
.23945 .28747 L
.21339 .27402 L
.20155 .2655 L
.18734 .25472 L
.16884 .23945 L
.16128 .2313 L
.14618 .21339 L
.13806 .18734 L
.16128 .17044 L
s
.65633 .57699 m
.68239 .5684 L
.70844 .56312 L
.7345 .56167 L
.76055 .5752 L
.76359 .57817 L
.76859 .60422 L
.76055 .62333 L
.75628 .63028 L
.7345 .65486 L
.73299 .65633 L
.70844 .6775 L
.69924 .68239 L
.68239 .69295 L
.65633 .7058 L
.64985 .70844 L
.63028 .7154 L
.60422 .72268 L
.57817 .72651 L
.55211 .7214 L
.53145 .70844 L
.52926 .68239 L
.54238 .65633 L
.55211 .63981 L
.56623 .63028 L
.57817 .61928 L
.60117 .60422 L
.60422 .60225 L
.63028 .58724 L
.6531 .57817 L
.65633 .57699 L
s
0 g
.03 w
.24141 .24033 Mdot
.64872 .64417 Mdot
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.522676 0.522676 0.97619 0.97619 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.49505 0.5 0.49505 [
[ 0 0 -0.125 0 ]
[ 0 0 -0.125 0 ]
[ 0 1 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
0 0 m
1 0 L
s
0 0 m
0 1 L
s
0 1 m
1 1 L
s
1 0 m
1 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
1 .5 0 r
.015 w
.03175 .1355 Mdot
.03435 .12523 Mdot
.11137 .12765 Mdot
.14107 .18841 Mdot
.16218 .24538 Mdot
.17294 .21053 Mdot
.18267 .18577 Mdot
.18434 .1304 Mdot
.18553 .30956 Mdot
.20401 .239 Mdot
.21247 .27571 Mdot
.21687 .20845 Mdot
.22376 .2799 Mdot
.22832 .27485 Mdot
.29063 .20974 Mdot
.29686 .25079 Mdot
.30487 .22936 Mdot
.30683 .34623 Mdot
.32055 .20902 Mdot
.32574 .21979 Mdot
.34472 .28521 Mdot
.35998 .36393 Mdot
.36335 .24976 Mdot
.3794 .36608 Mdot
.42386 .66992 Mdot
.44391 .74519 Mdot
.45059 .34198 Mdot
.47208 .67586 Mdot
.47436 .71381 Mdot
.49778 .59825 Mdot
.50874 .91643 Mdot
.51516 .76219 Mdot
.53655 .61374 Mdot
.56563 .75219 Mdot
.59189 .65665 Mdot
.59581 .61604 Mdot
.59923 .6556 Mdot
.60292 .68499 Mdot
.62656 .67779 Mdot
.63555 .72451 Mdot
.63919 .652 Mdot
.64169 .6004 Mdot
.64246 .58611 Mdot
.64496 .54267 Mdot
.64608 .77288 Mdot
.65077 .64308 Mdot
.66065 .57816 Mdot
.67474 .59169 Mdot
.69296 .563 Mdot
.72815 .65902 Mdot
.73169 .58879 Mdot
.74669 .61318 Mdot
.74821 .65474 Mdot
.75963 .63781 Mdot
.79673 .57809 Mdot
.80925 .55852 Mdot
.81525 .58444 Mdot
.83417 .62985 Mdot
.83598 .55526 Mdot
.91595 .49319 Mdot
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{400, 400},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40006@0001T2000`400?l00000o`00003ooooooonA
ooooo`00oooooonAooooo`00oooooonAooooo`00oooooonAooooo`00oooooonAooooo`00oooooonA
ooooo`00oooooonAooooo`00oooooonAooooo`00oooooonAooooo`00oooooonAooooo`002Ooooonf
00000=7ooooo0009ooooo`0300000?oooooooooo0;;ooooo00<00000ooooooooool0coooool000Wo
oooo00<00000ooooooooool0/_ooool00`00003oooooooooo`3?ooooo`002Oooool00`00003ooooo
ooooo`2booooo`0300000?oooooooooo0<oooooo0009ooooo`0300000?oooooooooo0;;ooooo00<0
0000ooooooooool0coooool000Wooooo00@00000oooooooooooooooo[@000004ooooo`0300000?oo
oooooooo0<oooooo0009ooooo`0400000?ooooooooooooooojd000001?ooool00`00003ooooooooo
o`3?ooooo`002Oooool01000003ooooooooooooooon]000000Cooooo00<00000ooooooooool0cooo
ool000Wooooo00@00000oooooooooooooooo[@000004ooooo`0300000?oooooooooo0<oooooo0009
ooooo`0400000?ooooooooooooooojd000001?ooool00`00003oooooooooo`3?ooooo`002Oooool0
1000003ooooooooooooooon]000000Cooooo00<00000ooooooooool0coooool000Wooooo00@00000
oooooooooooooooo[@000004ooooo`0300000?oooooooooo0<oooooo0009ooooo`0400000?oooooo
ooooooooojd000001?ooool00`00003oooooooooo`3?ooooo`002Oooool01000003ooooooooooooo
oon]000000Cooooo00<00000ooooooooool0coooool000Wooooo00@00000oooooooooooooooo[@00
0004ooooo`0300000?oooooooooo0<oooooo0009ooooo`0400000?ooooooooooooooojd000001?oo
ool00`00003oooooooooo`3?ooooo`002Oooool01000003ooooooooooooooon]000000Cooooo00<0
0000ooooooooool0coooool000Wooooo00@00000oooooooooooooooo[@000004ooooo`0300000?oo
oooooooo08_ooooo0_l00012ooooo`002Oooool01000003oooooooooooooool400000003o`000000
00006ATI00`06ATI00<00000o`0000000000U`000004ooooo`0300000?oooooooooo08Sooooo0ol0
00000ooooooo0000ooooo`11ooooo`002Oooool01000003oooooooooooooool3000001@06ATIUP00
0004ooooo`0300000?oooooooooo08Kooooo0_l00003ooooo`03ojVmj?l0003o0000047ooooo0009
ooooo`0400000?ooooooooooooooo`8000006@0I6AVB000000Cooooo00<00000ooooooooool0Pooo
ool3o`0000;ooooo1?nY_NP00ol0003oooooo`000010ooooo`002Oooool01@00003ooooooooooooo
oooo000001d06ATIS`000004ooooo`0300000?oooooooooo083ooooo0ol00002ooooo`OoZKgX00?o
0000ooooool00000@?ooool000Wooooo00D00000ooooooooooooooooo`00000;01TI6@/000002P0I
6AV<000000Cooooo00<00000ooooooooool0O_ooool2o`0000?ooooo2OnY_NP01?l0003oZKgXoooo
ool0000oooooo`002Oooool01000003oooooooooooooool901TI6@<000002`0c<c<4000000L06ATI
R`000004ooooo`0300000?oooooooooo07_ooooo0ol00002ooooo`coZKgX00Go0000ojVmj?oooooo
ooooo`00000nooooo`002Oooool01000003oooooooooooooool801TI6@030000000c<c<0<c<c0100
<c<c0`0000000ol000006ATI01TI6@0401TI6@80000000?o0000000000000000P`000004ooooo`03
00000?oooooooooo07Wooooo0_l00003ooooo`koZKgX00Go0000ojVmj?nY_NSoooooo`00000noooo
o`002Oooool01000003oooooooooooooool801TI6@030000000c<c<0<c<c00D0<c<c2`00000403<c
<`<000001P0I6AV5000000Cooooo00<00000ooooooooool0M_ooool3o`0000;ooooo4OnY_NP01_l0
003oZKgXojVmj?nY_NSoooooo`0003gooooo0009ooooo`0400000?ooooooooooooooo`P06ATI00<0
000003<c<`0c<c<00`0c<c<2000000/0C4a<0`00000403<c<`8000001@0I6AV4000000Cooooo00<0
0000ooooooooool0M?ooool2o`0000;ooooo5?nY_NP00ol0003oZKgXojVmj002ojVmj003o`000?oo
oooooooo03_ooooo0009ooooo`0500000?ooooooooooooooool000001P0I6AT00`000000<c<c03<c
<`0303<c<`030000001<C4`0C4a<00<0C4a<2000000304a<C0@000000P0c<c<2000000D06ATIPP00
0004ooooo`0300000?oooooooooo077ooooo0ol00002oooooaKoZKgX00?o0000ojVmj?nY_NP00onY
_NP00ol0003oooooooooo`0jooooo`002Oooool01@00003oooooooooooooool0000000H06ATI00<0
000003<c<`0c<c<00P0c<c<00`000000C4a<04a<C00204a<C003o`0000000000IVIV00L0IVIV00Co
000000000000000000000`1<C4`200000080<c<c00?o0000000000000000100I6AT00`00003o0000
0000001m000000Cooooo00<00000ooooooooool0K_ooool3o`0000;ooooo6OnY_NP00ol0003oZKgX
ojVmj003ojVmj003ooooool0003ooooo03[ooooo0009ooooo`0500000?ooooooooooooooo`000000
1P0I6AT00`000000<c<c03<c<`0203<c<`030000001<C4`0C4a<0080C4a<00<0000006IVIP1VIVH0
0P1VIVH5o`0000@0IVIV0`00000204a<C08000000`0c<c<2000000@06ATIOP000004ooooo`030000
0?oooooooooo06cooooo0_l00003oooooacoZKgX00?o0000ojVmj?nY_NP00onY_NP00ol0003ooooo
ooooo`0iooooo`002Oooool01000003oooooooooooooool2000000D06ATI00D0000003<c<`0c<c<0
<c<c0000000404a<C0040000001VIVH0IVIV06IVIP;o00001@1oOgl7o`0000<0000000@0C4a<0000
0000000000000P0c<c<2000000<06ATIO@000004ooooo`0300000?oooooooooo06Wooooo0ol00002
oooooaooZKgX00?o0000ojVmj?nY_NP00onY_NP00ooooooo0000ooooo`0iooooo`002Oooool01000
003oooooooooooooool2000000D06ATI00D0000003<c<`0c<c<0<c<c0000000304a<C0050000001V
IVH0IVIV06IVI_l000001P1oOgl4000000@0Ogmo0_l000001P1VIVH00000000000000000C4a<o`00
0080000000<0<c<co`0000000000100I6AUj000000Cooooo00<00000ooooooooool0Ioooool2o`00
00?ooooo8OnY_NP00ol0003oZKgXojVmj004ojVmj003ooooool0003ooooo03Sooooo0009ooooo`04
00000?ooooooooooooooo`8000001@0I6AT01@000000<c<c03<c<`0c<c<0000000<0C4a<00D00000
06IVIP1VIVH0IVIVo`00000407moO`800000102IVIT400000080Ogmo0_l0000206IVIP050000001<
C4`0C4a<04a<C00000000P0c<c<00`0000006ATI01TI6@0301TI6GP000001?ooool00`00003ooooo
ooooo`1Tooooo`?o00000_oooolTojVmj003o`000?nY_NSoZKgX00CoZKgX00?oooooo`000?ooool0
>?ooool000Wooooo00@00000oooooooooooooooo0`00000501TI6@050000000c<c<0<c<c03<c<`00
00000P1<C4`01@000000IVIV06IVIP1VIVKo000000<0Ogmo00@0000009VIV@2IVIT0VIVI1ol00003
0000000407moOol0003o0000o`00008000000P1<C4`20000000303<c<`000000000000@06ATIM`00
0004ooooo`0300000?oooooooooo06;ooooo0_l00003ooooobKoZKgX00?o0000ojVmj?nY_NP01OnY
_NP00ooooooo0000ooooo`0gooooo`002Oooool01000003oooooooooooooool300000003o`00000I
6AT06ATI00806ATI00D0000003<c<`0c<c<0<c<c0000000304a<C0030000001VIVKo000000<0Ogmo
00D0000009VIV@2IVIT0VIVIo`0000070;>c/`?o00000`0000000`1oOgoo000006IVIP0200000080
C4a<00<0000003<c<`0c<c<00P00000301TI6GH000001?ooool00`00003oooooooooo`1Oooooo`?o
00000_oooolYojVmj003o`000?nY_NSoZKgX00KoZKgX00?oooooo`000?ooool0=_ooool000Wooooo
00@00000oooooooooooooooo1000000501TI6@050000000c<c<0<c<c03<c<`0000000P1<C4`00`00
0000IVIVo`00000207moO`050000002IVIT0VIVI09VIVOl00000102c/k<6o`0000030;>c/ol0003o
000000;o000000@0Ogmoo`000?l0003o00000P0000000`1<C4`000000000000203<c<`8000000`0I
6AUd000000Cooooo00<00000ooooooooool0GOooool2o`0000?ooooo:onY_NP00ol0003oZKgXojVm
j007ojVmj003o`000?oooooooooo03Gooooo0009ooooo`0400000?ooooooooooooooo`D00000100I
6AT01@000000<c<c03<c<`0c<c<000000080C4a<00<0000006IVI_l000000P1oOgl01@000000VIVI
09VIV@2IVIWo00000080/k>c0_l000060<c<c0;o00000P2c/k<00ol0000000000000000207moO`;o
000000<0000004a<C01<C4`00P00000203<c<`030000000I6AT06ATI00806ATILP000004ooooo`03
00000?oooooooooo05[ooooo0ol00002ooooobkoZKgX00?o0000ojVmj?nY_NP02?nY_NP00ol0003o
ooooooooo`0dooooo`002Oooool01000003oooooooooooooool6000000@06ATI00D0000003<c<`0c
<c<0<c<c0000000204a<C0030000001VIVKo00000080Ogmo00<0000009VIVOl000000P2c/k<00ol0
0000c<c<0<c<c0030<c<c0Co000000<0c<c<o`000?l000001?l0000010000000Ogmo07moOol00003
0000000404a<C?l00000<c<c03<c<`800000100I6AU`000000Cooooo00<00000ooooooooool0Eooo
ool3o`0000?ooooo<?nY_NP00ol0003oZKgXojVmj008ojVmj003ooooool0003ooooo03Cooooo0009
ooooo`0400000?ooooooooooooooo`H0000000?o000001TI6@0I6AT00P0I6AT01ol00000<c<c03<c
<`0c<c?o000004a<C00000000P1VIVH01Ol00000Ogmo0000002IVIWo00000080/k>c00Co00000<c<
c03<c<`0c<c<0_l000040>KViPKo000000D0/k>co`000?l00000000007moO`02o`00000406IVI_l0
0000C4a<000000<0<c<c00<0000001TI6@0I6AT00P0I6AU_000000Cooooo00<00000ooooooooool0
EOooool2o`0000?ooooo<onY_NP00ol0003oZKgXojVmj009ojVmj003o`000?oooooooooo03?ooooo
0009ooooo`0400000?ooooooooooooooo`P00000100I6AT01P000000<c<c03<c<`000000C4a<0000
0080IVIV00Go000007moO`000000VIVIo`0000020;>c/`05o`00003<c<`0c<c<0<c<c?l000002@3V
i^H6o`0000080000001oOgl0Ogmoo`00001VIVH0000004a<C000000303<c<`050000000I6AT06ATI
01TI6Ol00000KP000004ooooo`0300000?oooooooooo05;ooooo0ol00003ooooocGoZKgX00?o0000
ojVmj?nY_NP02OnY_NP00ooooooo0000ooooo`0cooooo`002Oooool01000003oooooooooooooool8
000000D06ATI00P0000003<c<`0c<c<0000004a<C0000000IVIVo`000080Ogmo00D0000009VIVOl0
0000/k>co`0000030<c<c003o`00003Vi^H0i^KV0080i^KV1?l000030>KViP05o`00003<c<co0000
0;>c/ol000000P0000001@1oOgoo000006IVIP000000C4a<008000000P0c<c<00`0000006ATI01TI
6@0201TI6Fd000001?ooool00`00003oooooooooo`1@ooooo`;o00001?oooolgojVmj003o`000?nY
_NSoZKgX00[oZKgX00?o0000ooooooooool0<_ooool000Wooooo00@00000oooooooooooooooo2@00
000501TI6@080000000c<c<0<c<c0000001<C4`0000006IVI_l0000207moO`0500000?l00000/k>c
0;>c/ol000000P3<c<`00ol00000i^KV0>KViP02o`0000@0oooo00oo00000>KViP3Vi^H0i^KVo`00
003<c<co00000;>c/ol00000VIVI0000001oOgoo000006IVIP0000000P1<C4`010000000<c<c03<c
<`00000501TI6F/000001?ooool00`00003oooooooooo`1=ooooo`?o00000oooooljojVmj003o`00
0?nY_NSoZKgX00[oZKgX00?oooooo`000?ooool0<_ooool000Wooooo00@00000oooooooooooooooo
2@0000000ol000006ATI01TI6@0201TI6@06o`0000000000<c<c03<c<ol00000C4a<0P0000001Ol0
0000Ogmoo`00002IVIWo00000080/k>c00?o00000<c<c?l000000P3Vi^H00ol00000oooo0?ooo`04
0?ooo`;o00000P3Vi^H7o`00000300000?l0003o00000080000000D0C4a<o`0000000000<c<co`00
000401TI6@03o`0000000000000006P000001?ooool00`00003oooooooooo`1;ooooo`;o00001?oo
oollojVmj003o`000?nY_NSoZKgX00_oZKgX00?oooooo`000?ooool0<Oooool000Wooooo00@00000
oooooooooooooooo3000000401TI6@030000000c<c<0000000<0C4a<00D00000o`00001oOgl00000
09VIV@02o`0000060;>c/ol00000c<c<o`00003Vi^Ko0000203oool2o`000080i^KV00_o00000<c<
c?l00000/k>co`00002IVIT0000007moOol00000IVIV0000000204a<C0040000000c<c<000000000
00@06ATIJ@000004ooooo`0300000?oooooooooo04Sooooo0ol00003ooooocooZKgX00?o0000ojVm
j?nY_NP03?nY_NP00ol0003oooooooooo`0`ooooo`002Oooool01000003oooooooooooooool=0000
00@06ATI00<0000003<c<`0000000`1<C4`01000003o0000o`000000000209VIV@07o`00002c/k?o
00000<c<c?l00000i^KVo`0000090?ooo`;o000000`0i^KVo`00003<c<co00000;>c/ol00000VIVI
0000001oOgoo000006IVIP00000204a<C0040000000c<c<0<c<c000000@06ATIJ0000004ooooo`03
00000?oooooooooo04Gooooo0ol00002oooood?oZKgX00?o0000ojVmj?nY_NP03?nY_NP00ooooooo
0000ooooo`0`ooooo`002Oooool01000003oooooooooooooool=00000003o`00000I6AT06ATI0080
6ATI00Co000003<c<`00003o00000P1<C4`030000000IVIVo`000000003o000009VIVOl00000/k>c
o`00003<c<co00000>KViP;o00002@3oool03Ol00000i^KVo`00003<c<co00000;>c/ol00000VIVI
0000001oOgoo000006IVIP0000000P1<C4`01?l00000<c<c03<c<ol0000401TI6@03o`0000000000
000006@000001?ooool00`00003oooooooooo`13ooooo`;o00000_oooom6ojVmj003o`000?nY_NSo
ZKgX00goZKgX00?oooooo`000?ooool0;oooool000Wooooo00@00000oooooooooooooooo3`000003
01TI6@090000000c<c<0<c<c03<c<`000000C4a<o`00001VIVKo00000080Ogmo00D0000009VIVOl0
003o00000<c<c002o`000080i^KV0_l000070?ooo`03o`00003Vi^Ko00000080c<c<00Co00000;>c
/ol0000000000P1oOgl01Ol00000IVIV0000001<C4`0000000<0<c<c00<0000001TI6@0I6AT00P0I
6AUV000000Cooooo00<00000ooooooooool0@?ooool3o`0000;oooooB?nY_NP00ol0003oZKgXojVm
j00=ojVmj003ooooool0003ooooo02oooooo0009ooooo`0400000?oooooooooooooooa0000000`0I
6AT020000000<c<c03<c<`0c<c<0000004a<C0000000IVIV0_l000000`1oOgl0000009VIV@02o`00
0080c<c<0_l000020>KViP03o`00003oool0oooo00@0oooo00Ko00000>KViP3Vi^Ko00000<c<c?l0
00020;>c/`09o`0000000000Ogmo07moOol00000IVIV0000001<C4`0000000<0<c<c00<0000001TI
6@0I6AT00P0I6AUU000000Cooooo00<00000ooooooooool0?_ooool2o`0000?oooooB_nY_NP00ol0
003oZKgXojVmj00>ojVmj003ooooool0003ooooo02kooooo0009ooooo`0400000?oooooooooooooo
oa4000000`0I6AT200000080<c<c00<0000004a<C00000000P1VIVH01?l00000Ogmo0000002IVIT3
o`000080c<c<00?o00000>KViP3Vi^H00_l000050?ooo`0<o`00003Vi^H0i^KVo`00003<c<co0000
0;>c/ol00000VIVI0000001oOgoo00000P1VIVH00ol00000C4a<0000000303<c<`030000000I6AT0
6ATI00806ATII0000004ooooo`0300000?oooooooooo03_ooooo0ol00002ooooodgoZKgX00?o0000
ojVmj?nY_NP03OnY_NP2ojVmi`03ooooool0003ooooo02gooooo0009ooooo`0400000?oooooooooo
oooooa800000100I6AT20000000603<c<ol00000000000000?l0000000000ol000000`00003o0000
o`000002o`0000030<c<c?l0003o00000080i^KV1_l000030>KViP08o`00003<c<co00000;>c/ol0
0000VIVIo`0000000002o`00000506IVIP000000C4a<o`00000000000P0c<c<00`0000006ATI01TI
6@0201TI6@03o`00000000000000060000001?ooool00`00003oooooooooo`0iooooo`;o00000ooo
oom?ojVmj003o`000?nY_NSoZKgX00SoZKgX1_nY_NL2ojVli`03o`000?oooooooooo02cooooo0009
ooooo`0400000?oooooooooooooooa<000001@0I6AT20000000803<c<`000000000004a<C0000000
IVIVo`00001oOgl2000000Co000000<0c<c<o`000?l000002@3Vi^H01Ol00000c<c<o`00002c/k?o
00000080VIVI00D0000007moO`1oOgoo00000000000204a<C0040000000c<c<0<c<c000000@06ATI
H`000004ooooo`0300000?oooooooooo03Kooooo0ol00003oooooe7oZKgX00?o0000ojVmj?nY_NP0
1_nY_NP6ojVmi`GoZKcW00?o0000ooooooooool0:oooool000Wooooo00@00000oooooooooooooooo
5000000601TI6@050000000c<c<0<c<c0000001<C4`00P0000001Ol00000Ogmo07moO`000000VIVI
00?o00000P3<c<`2o`0000H0i^KV00Oo00000<c<c03<c<`0c<c<o`00002c/k?o00000080VIVI00D0
000007moOol00000IVIV0000000204a<C0040000000c<c<0<c<c000000@06ATIHP000004ooooo`03
00000?oooooooooo03?ooooo0ol00004oooooe?oZKgX00?o0000ojVmj?nY_NP00onY_NP6ojVmi`Oo
ZKcW00?oZ[_Vo`000?ooool0;?ooool000Wooooo00@00000oooooooooooooooo500000000ol00000
00000000000401TI6@040000000c<c<0<c<c00000080C4a<00L00000o`000?l0003o000000000?l0
0000000000_o00000`3<c<`2o`000080/k>c00?o000009VIV@0000000P1oOgl00ol00000IVIVo`00
000204a<C004o`00000c<c<0<c<c000000@06ATI00<00000o`0000000000GP000004ooooo`030000
0?oooooooooo037ooooo0_l00004oooooeOoZKgX00?o0000ojVmj?nY_NP01_nY_NL6ojVli`03ojVk
i_nZ^nKoZ[_V00;oZ[_V00?o0000ooooooooool0:_ooool000Wooooo00@00000oooooooooooooooo
6000000301TI6@0;o`0000000000<c<c03<c<ol00000000004a<C?l00000000006IVI_l000000P1o
Ogl00`00003o0000o`0000020;>c/`?o00001@3<c<`00ol00000/k>c0;>c/`020;>c/`03o`00002I
VIT000000080Ogmo00Co000006IVIP1VIVH000000P1<C4`010000000<c<c03<c<`00000401TI6F00
00001?ooool00`00003oooooooooo`0^ooooo`?o00000_oooomKojVmj003o`000?nY_NOoZKgW00Co
ZKgW1_nY_>L2ojVjiP;oZK_V0_nZ^nH2ojZji@03o`000?oooooooooo02Wooooo0009ooooo`040000
0?oooooooooooooooaT00000100I6AT200000080<c<c00<0000004a<C01<C4`00P000002o`000003
07moO`000000000000;o00000`2c/k<5o`0000D0/k>c00?o000009VIV@0000000P1oOgl01?l00000
IVIV06IVIP00000204a<C0050000000c<c<0<c<c03<c<`000000100I6AUO000000Cooooo00<00000
ooooooooool0;?ooool2o`0000?oooooFonY_NP2ojVmi`04o`000?nY_NOoZKgWojVmi`KoZKcW0_nY
^^D2ojVjiP04ojZii?nZ^NGoZ[WUojZii@;oZ[[U00?oZkWTo`000?ooool0:_ooool000Wooooo00@0
0000oooooooooooooooo6P00000501TI6@040000000c<c<0<c<c000000<0C4a<00<0000006IVI_l0
00000P1oOgl2000000?o00002@2c/k<01Ol00000VIVI09VIV@2IVIT000000080Ogmo00Co000006IV
IP1VIVH000000P1<C4`010000000<c<c03<c<`00000401TI6El000001?ooool00`00003ooooooooo
o`0Yooooo`?o00000_oooomNojVmj0;oZKgW00?o0000ojVmionY_>L00_nY_>L6ojVji@03ojVhhonZ
^NCoZ[WT00;oZ[WT00?oZ[WUoj^hhon[^N@00on[^N@00ol0003oooooooooo`0Xooooo`002Oooool0
1000003ooooooooooooooolJ00000003o`0000000000000000<06ATI00Co00000000000c<c?o0000
0P0000000`1<C4co000000000003o`00000407moO`0000000000000000Oo000000<0/k>co`000?l0
00000`2IVIT010000000Ogmo07moOol0000206IVIP040000001<C4`0C4a<000000<0<c<c00<00000
01TI6@0I6AT00P0I6AT00`00003o00000000001K000000Cooooo00<00000ooooooooool09oooool2
o`0000?ooooo4?nY_NP00onY_NOoZKgXojVmj01<ojVmj0?oZKcW00?o0000ojVlionY_>L01_nY^^D0
1?nY]n?oZKSSojVhhonY^><2ojZii004oj^fhOn[^>?oZkSSoj^hh`;oZkWT00?o[;WSooooool00000
:Oooool000Wooooo00@00000oooooooooooooooo7P00000401TI6@8000000P0c<c<20000000404a<
C0000000000006IVIP?o000000@0Ogmo0000000000000000102IVIT00ol00000VIVI09VIV@0209VI
V@050000001oOgl0Ogmo07moOol000000P1VIVH010000000C4a<04a<C000000303<c<`030000000I
6AT06ATI00<06ATIG@000004ooooo`0300000?oooooooooo02Cooooo0ol00003ooooo`?oZKgW0onY
_NP2ojVmi`;oZKgX00CoZKcWojVmionY_NOoZKgW0_nY_NP01?nY_>OoZKgWojVmionY_NL2ojVmj003
ojVlionY_NSoZKgX00;oZKgX0_nY_NL4ojVmj0;oZKgW>onY_NP6ojVli`03o`000?nY^^GoZK[U00?o
ZK[U00?oZKKSojVghonY]n<00_nY]n<00onY^>?oZ[CPoj^fh@03oj^fh@03oj^hhon/]n7o[;WS00?o
[;WS00?o0000ooooooooool09oooool000Wooooo00@00000oooooooooooooooo7`00000501TI6@80
00000P0c<c<00`000000C4a<04a<C00200000080IVIV00Co000007moO`1oOgl0Ogmo1000000209VI
V@<000000`1oOgl01Ol00000IVIV06IVIP1VIVH0000000<0C4a<00D0000003<c<`0c<c<0<c<c0000
000501TI6E`000001?ooool00`00003oooooooooo`0Rooooo`;o00001?ooool2ojVli`;oZKgW00Go
ZK_VojVlionY_>OoZKcWojVmi`02ojVkiP?oZKcW00?oZKgWojZki_nZ^nH00onY_>L00onY_NOoZ[_V
ojZkiP03ojVli`03ojVmj?nY_>KoZKcV00?oZKgW00CoZKgXojVlionY_>OoZKcW0_nY_NL00onY_NSo
ZKgWojVmi`02ojVmj003ojVlionY_NSoZKgX033oZKgX1_nY_>L00onY^^KoZK[Uo`000003ojVji@04
ojVfh_nY]^?oZKKSojVfh`;oZKOS00CoZK;OojZdh?nZ]>3oZ[CP0_n[]^401?n/]=ko[;OQojbghOn/
]n42ojbih`;o[[WR00?o0000ooooooooool09_ooool000Wooooo00@00000oooooooooooooooo7`00
00000ol00000000001TI6@0401TI6@80000000<0<c<c00000?l000000`0000000ol000000000o`00
0003o`0000<0Ogmo0P00000607moO`05o`00001VIVH0IVIV06IVIP0000000`1<C4`01@000000<c<c
03<c<`0c<c<0000000D06ATIG0000004ooooo`0300000?oooooooooo01oooooo0ol000000ooooooo
ZK_VojVkiP04ojVli`;oZ[[U0onY^nH00onY_>OoZ[WTojZii003ojVkiP03ojVlionZ^>CoZ[ST00?o
Z[_V00?oZKcWojZii?nZ^N@00onZ^nH00onY_>OoZ[[UojZji@03ojVliP03ojVmionZ^nKoZ[_V00;o
ZKcW00GoZ[WTojZli_nZ_>KoZ[cVojVmi`02ojZkiP?oZKcW00?oZKgXojZlionZ_>L01?nY_NP2ojVm
ibKoZKgX0_nY_NL3ojVli`?oZK_V0_nY^^H00ol0003oZ;KSojRfh`03ojVfhP03ojVfhonY/MkoZK7N
00?oZK;O00?oZ[CPoj^ag?n/]=h00on/]=h00on/]n7o[[OOojjgg`02ojjihP03ok2kh_oooooo0000
02Oooooo0009ooooo`0400000?ooooooooooooooob8000001P0I6AT00`000000<c<c03<c<`0203<c
<`80000000D0C4a<000000000000000006IVIP0;o`0000@0IVIV00D0000004a<C01<C4`0C4a<0000
000303<c<`030000000I6AT06ATI00<06ATIG0000004ooooo`0300000?oooooooooo01cooooo0ol0
0002ooooo`;oZK[U0onY^nH00onY_>OoZ[SSojZhh`03ojZji@03ojVki_nZ]^;oZ[KR00?oZ[WT00?o
ZK_VojZeh?nZ^>@00onZ^>@00onZ^nKoZ[CPojZdh003ojZii004ojZki_n[]^7oZkKQojZji@;oZk;M
0onZ^><00onZ^nKoZkGPoj^eh003ojZii003ojZli_n[^>?oZkSS00?oZ[_V00?oZKcWojZkiOnZ^nD0
0onZ_>L00onY_NSoZ[cWojZli`03ojVmi`03ojVmj?nY_NOoZKgW00;oZKgX00?oZKgWojVmj?nY_NP0
7?nY_NP2ojVmi`03ojVkionY^nKoZK_V00?oZK_V00CoZ;OTojRfhonX]^?o00000onX]^<00onY]^;o
Z;3MojVagP03ojVagP03ojVbgonZ[][oZk7L00;oZk7L0_n/]=h01?n^/mco[[OOojjggon^]ml4ok2k
hP03o`000?oooooooooo02Gooooo0009ooooo`0400000?ooooooooooooooob@000001@0I6AT20000
00@0<c<c00@0000004a<C01<C4`0C4a<1000000:06IVIP800000101<C4`01@000000<c<c03<c<`0c
<c<0000000H06ATIF`000004ooooo`0300000?oooooooooo01[ooooo0_l00003ooooo`;oZ[WT0onY
^^D00onY^nKoZ[KQojZfh@03ojZhh`03ojZjiOnZ/]koZ[KR00?oZ[KR00?oZ[WToj^_fonZ]N000_nZ
]N02ojZhi0;oZjkJ00?oZ[CPoj^Vd_n[Y]800on[[m/00on[]^7o[:WDojbYe003oj^bg@03ojZhhon/
[MWoZkGP00?oZkGP00?oZ[WTojbbgOn[^><00on[^><00onZ^nKoZkORoj^ghP03ojZki@04ojZlionZ
^^GoZ[[UojZli`;oZk[U0onZ_>L00onY_NOoZ[cWojZli`03ojVmi`03ojVmj?nY_NOoZKgX01WoZKgX
00?oZKcWojVkionY^nL00_nY^nL00onY^nKoZ;STojRgi003ojRgi003ojRfhol0003oZ:oM00?oZ:oM
0_nX/=d2ojVagP05ojV[f?nZ[][oZZkJojZ^f_n[/M`00_n][mT3ojjcg003ojjggona^=ko/KSN00;o
/;_R00?o/kkRooooool000009_ooool000Wooooo00@00000oooooooooooooooo9P00000501TI6@80
00000`0c<c<3000000@0C4a<0`00000506IVIP8000001@1<C4`00`000000<c<c03<c<`0203<c<`03
0000000I6AT06ATI00@06ATIF`000004ooooo`0300000?oooooooooo01Oooooo0ol00003ooooo`;o
Z[OS0onZ^N@00onY^^GoZ[?OojZfh@03ojZfh@03ojZhhonZ[][oZ[;N00;oZ[;N0_nZ]^801OnZZMKo
ZjoKoj^_fon[[m_oZ[GP00;oZjKC0on[[]X4oj^VdP03oj^_fon/W/Wo[:WD00?o[:WD00?oZk;MojbS
cOn/[MT00_n/[MT2oj^eh004ojfYe?n//]go[;;Mojbbg@;oZkSS0_n//=/00on[]n;o[JoIojf_f@03
ojbfh@03ojZjiOn/]^3oZk[U00?oZk[U00?oZ[cWoj^jiOnZ_>L00onZ_>L00onY_NOoZ[cWojZli`02
ojVmi`;oZKgX0_nY_NLCojVmj0CoZKcW0_nY^nL01?nX^NGoZ;STojRhi?nX^>@2ojRgi004ojN`g_l0
003o0000ojN_gP;oZ:oM00?oYZOFojRXeonXZ=L01?nYZmP00onZ[][o[:[Eojf_f@03ojf_f@05ojjc
g?na]=[o/KCJok6hg_ne_=l01?nc_^800ooooooo0000ooooo`0Tooooo`002Oooool01000003ooooo
oooooooooolY000000@06ATI0`00000303<c<`0400000?l000000000000000<0C4a<1@00000704a<
C003o`00000c<c<0<c<c0080<c<c00<0000001TI6@0I6AT01@0I6AUJ000000Cooooo00<00000oooo
ooooool05_ooool2o`0000?ooooo00?oZKORojZghonZ]n<00_nZ]n<00onZ^NCoZ[7MojZcg`02ojZc
g`;oZ[KQ00GoZZWFojZ^f_nZ[][oZZkJojZbgP02ojZRc`?oZZWF00?oZjoKojZNb_nZW/X00on[Y]<0
0on[[][oZic8oj^Lb003oj^VdP?o[9k90_n/ZM@01On/U/3o[:?=ojbScOn/Xlgo[:gI00;o[Ig70on]
ZM@00on//]go[ZK@ojjVd003ojb`f`Co[JoI00?o[;KQojj_f?n/]^000_n/]^02oj^ji@04ojbghOn[
^^GoZk[Uoj^ji@;oZ[cW0_n[^nD00onZ_>OoZk_UojZli`03ojZli`03ojVmionZ_NOoZKgX013oZKgX
1OnY_>L2ojRji@?oZ;WU00?oZ;STojNagol000000_l000000onW/=ko0000ojFVeP04ojJWeP;oZ:SG
0_nYZmP01?nZYM;o[:[EojbZeOn/Z]D2ojf_f@04ok6_e_na]=[o/KCJok6dfP?o]KcO0_nc_^82okG2
i003o`000?oooooooooo02?ooooo0009ooooo`0400000?ooooooooooooooob/000001@0I6AT30000
00@0<c<c0`00000:04a<C08000001@0c<c<00`0000006ATI01TI6@0501TI6EX000001?ooool00`00
003oooooooooo`0Fooooo`03o`000?oooooo000000;oZKKR0_nY]n82ojZgh`05ojV_g?nZ/MgoZ[7M
ojZagOnZ/ml00_nYY]<3ojZYeP03ojZ^f_nYW<WoZIc900?oZZ;?00?oZZWFojVE`_nZW/X00onZW/X0
0on[Y]?oZY:moj^Lb003oj^Lb003oj^Vd_n[T[goZi:m00;o[9k900Co[:WDojbF`?n/U/3o[9K00_n/
Xld4ojfMa`03ojfYe?n^V/;o[ZK@00?o[ZK@00?o[;3KojnUcOn_YLd00_n][mT01On`YLco[ZoHojj_
f?n^[mSo[;KP00;o[k3I0on/]n401_n[^^Go[KSQojfhhOn]^>7oZk_UojfihP?oZk_U0_nZ_>L01?n[
_>KoZ[gWojZmionZ_NL2ojVmj003ojZmionY_NSoZKgX00[oZKgX0_nY_>L01?nY^nOoZK[VojVji_nY
^^H3ojRji@04ojRiiOl0003o0000o`0000;oYk7O00GoYk3NojFVe_nUY]Ko0000ojFVeP03ojJWeP03
ojRXeonXXLooZZGB00?oZZGB00?o[:[EojnYdOna[mH00ona[mH01?na]=[o][SJokJhf_ne_=l2okW1
h0;o]L;T00?o]lGUooooool000009?ooool000Wooooo00@00000oooooooooooooooo;@00000601TI
6@<00000100c<c<:000000H0<c<c00<0000001TI6@0I6AT01P0I6AUJ000000Cooooo00<00000oooo
ooooool05_ooool01?l0003oZKKRojVfh_nY]^82ojR_g0?oZJkL0_nY[m`00onZ/MgoZJ?AojVSd@03
ojVVd`03ojZYe_nXV<GoZIc900?oZIc900?oZZ;?ojR?^onYUL800_nYUL82ojZNbP04ojR9]?nZT[go
ZY:mojZB_@;oZic800KoZHRboj^B_On[T[goZi:mojbNbOn[Rk<4ojbF`003ojbScOn]TKWo[I6i00?o
[Ig70on^V/82ojjVd004ok2H_on_YLgo[jG=ojnUc@Co/:G<00?o[ZoHok:WcOn_/=T00on_/=T00on/
]n7o[k;JojnbfP02ojfhh@05ok2eg?n]^N;o[KWRojfih_n[^nD00_n/^^@3oj^liP03ojZmionZ_>Ko
Z[cV00?oZ[gW00?oZKgXojZmionZ_NL01onY_NP2ojVli`?oZK_W00?oZK[VojNfhonW]>800ol00002
ojNch@;oYk7O00?oY:OHojFVe_nUY]H00_nUY]H01?l0003oYYg=ojJMcOnVWLd3ojRQc`;oZZGB00Co
[J;=ojnYdOn_ZM7o[jWA0_na[mH2okJbe@03okJhf_nk_]co^L7P00;o^L7P1?ngaND00ol0003ooooo
ooooo`0Rooooo`002Oooool01000003oooooooooooooool`000000H06ATI00@00000o`0000000000
0000400c<c<00ol000006ATI01TI6@0601TI6EX000001?ooool00`00003oooooooooo`0Fooooo`04
o`000?nY]^;oZ;3NojR`gP?oZ:oL00?oZJkLojNSd_nXXm400_nXXm43ojVSd@03ojVVdonWUL?oZ9S5
00;oZ9S50_nYW<T01?nWR[KoZ8nkojR?^onXSk/2ojVE`PCoZ8Vd0_nZT[d4ojV8/P;oZi:m0on[Rk<3
ojbF`0Co[I6i00?o[Ig7ojj>]?n^S[@00_n^V/84ok2H_`03ojnUcOnbVKko/YVn00?o/:G<0onbYld2
ojn`f@;o/j[@00?o[k;JokB_dond[m<00on`]M`00on]^N;o[kOOojbji003ojbji004oj^li_n/^nGo
[;_UojZliP;oZkcV1_nZ_NL4ojVmj0GoZKcW00?oZK_WojRhi?l000000_l00002ojNdhP03ojF[fonT
Z=WoY:SI00CoY:OH00GoYJKFoj:Ic?nTVlcoY9_<o`000003ojJMc@03ojRQconZW<So[J;=00?o[J;=
00?o[jWAokF[conf/]D00_nf/]D01Onm^MKo^kkLok^ng?nk_]co^L7P00;o^lOS0_ngaND2okO8i`03
o`000?oooooooooo027ooooo0009ooooo`0400000?oooooooooooooooc800000200I6AT4000000T0
<c<c0`00000901TI6EX000001?ooool00`00003oooooooooo`0Eooooo`03o`000?oooooooooo00?o
Z;3N00?oZ:oLojJVe_nWXm800_nWXm83ojRSd@03ojVSdOnVU<?oYiG300;oYiG30_nXV<D3ojN:]P?o
Z8nk00?oZIG2ojN3[_nWPjh00onXRK@00onZT[goZ86ZojV8/P03ojV8/P03oj^B_OnZPZWoZh^c00?o
Zh^c00?o[9K0ojb6[On/QZd00_n]TKT01On^QJSo[Xjdojj>]?n^S[Co[Y[200;o/Hfa0on`V;l4ok:I
_P03ok2Uc?neWKoo]Ifo00;o/ZO=00Co]j;3ok>Zd?ncZ]3o/j[@1?nd[m<00on`]Mco];?Hojngg`02
ojngg`;o[;[T0_n^^^800on/^nGo[KcToj^liP03oj^liP03ojZmion[_NOoZ[gW00?oZ[gW00?oZKgX
ojVlionY_>L01?nY_>L3o`000004ojRhi?nW]^?oYJkMojF^g@?oYJ_K0_nTZ=T2ojBWf009oj6IcOnR
VLcoXYW<oj:Ic?nTVlco0000ojBKc?nVWLgoYYO500?oZYc80on]X/d3okF[c`05okJbeOnm^MKo_KWF
okfie_nk_]`00_o1a]l00onkan?o_LcVokg<iP02okO8i`;o]LWY00?o0000ooooooooool08?ooool0
00Wooooo00@00000oooooooooooooooo=000000:01TI6@T00000300I6AUJ000000Cooooo00<00000
ooooooooool05Oooool01_l0003oooooooooooooooooZ;3NojFYfP?oYZKF0_nWXm82ojRSd@04ojBE
aOnVU<?oYYC3ojJD``;oYiG300?oZ9S5ojF7]?nUQk@00onWR[H2ojR?^`?oYh>^0onXRK@3ojR1ZP?o
ZHRb0onZPZT2oj^;/`05ojaoY?n/QZgo[8J]ojb6[On]TKT00_n^QJP3ojj>]0Co/Hfa00?o/9RookB@
/OndT;400_nbVKh01OngU;;o]IfookFM_oneWKoo/ZO=00?o]j;300?o/j[@okVXb?niZ<P00_nd[m<0
1Onj[loo];?HokBcf?nd/mSo[kOO00?o/kSM00?o[[[Rok6khOn]_>@00_n]_>@2oj^liP;o[;gV0_n[
_NL4ojZmi`03ojVlionY^nKoZK[V00?o000000CoZ;WUojJch_nV/N3oY[7P1?nU[]d01?nUZm_oX9cA
oj2Jc_nPV/h4oj6Ic@;oXYW<0_nTVl`01?l0003oYYO5ojJGaOnVUlD3ojZLb005ojfRcOnbXlWo/Z?9
okF[conm/]000onm^MH01_o5a=Wo`LKOol76goo1a]ooa<oRokg<iP;o_<kX0_nebNT00oncb>Wo0000
ooooo`0Qooooo`002Oooool01000003ooooooooooooooolf000001`06ATIF`000004ooooo`030000
0?oooooooooo01Gooooo00Co0000oooooooooooooooo0onUZMX2ojJVeP03ojNSd_nSV<[oY9G500?o
Y9G50_nVU<<00onWUL?oY8JdojF7]002ojF7]0?oYhZf00?oZ8nkojIoZ_nWPjh00_nWPjh3ojR9]0?o
Z86Z0_nYR;801OnYO:;oZX:YojZ2ZOnZPZWoZh^c00;o[7nT0on/QZd4ojj5Z0;o[Xjd1?naSK43okB@
/@04ok:I__ngU;;o]iBbokND/P;o]Ifo0ongX/<01OnoXkco^JS8okVXb?niZ<So]:oC00?o^Zo?00?o
];?HokVfe_ni]]H00_nc^=d01Ong^mgo/K_Qok6khOna^n7o[KcT00?o[kgT00?o[;gVojfmi_n[_NL0
0_n[_NL2ojZmi`05ojZliol0003o0000o`000?nY^^H00_nW]^<3ojJchP;oY[7P0_nU[]d01?nQX=Co
X9cAoj2LdOnPW=42oj2JcP?oXIW=00?oXYW<oj2>`OnST/<00_nST/<00ol0003oYYO5ojJGa@02ojZL
b004ojjKa?nbXlWo/Z?9ok:Sb@?o_K;@00Go_KWFolG4fOo5a=WoaLCIol76g`02olC?hP?o_<kX1?nc
b>T00ol0003oooooooooo`0Oooooo`002Oooool01000003ooooooooooooooolf00000004o`000000
00000000000001P06ATIF`000004ooooo`0300000?oooooooooo01Gooooo00?o0000ooooooooool0
0_ooool00onUZM[oWZCJoj2Md@02oj2Md@;oXiS:0onTULD01?nVU<?oXHNhojB6]?nTQ[@3ojF7]0?o
YhZf0onVOjX3ojN3[P03ojR9]?nWO:CoZ86Z00;oZ86Z00?oZHRbojUlX_nYO:800onZPZT4ojaoY0;o
[8J]1?n^QJP00on^S[Co/HJVok66YP03ok6=/@?o]92a1?ngU;801?neWKoo^iZfok^J]_ngX/<3oknS
_0;o^JS800Co`Jc5okZ_conj[loo^Zo?0oni]]H01Onn_=So]k_MokNkgOng^mgo/K_Q00;o/kkR0_n_
_N@01?n`_nGo[KgVojfmi_n]_NH2oj^mi`?o000000?oZ[cWojVki_nX^>D01?nW]^<01?nV/n;oXjSK
oj:TeonRY=L4oj6Pe0;oX9cA00?oX9[>oib<`_nMS<400_nMS<43oj2>`@?oXi;300?o0000ojVC_on^
Vl@00on^Vl@00onbXlWo^ZW9okZYb@02okfbd003olJnd_o5a=WoaLCI00;obm3M00Coa<oRolCDi_o4
e>Ko_<kX0_nic^X2ok?8j@;o/<KZ00?o0000ooooooooool07_ooool000Wooooo00@00000oooooooo
oooooooo?P00000C01TI6E`000001?ooool00`00003oooooooooo`0Eooooo`03o`000?oooooooooo
00?ooooo0_nNY=X3oj2Md@;oXiS:00CoY9G5oij:__nQQkSoXHNh0onTQ[@3ojF7]003ojN:]_nTOJSo
YWnZ00;oYWnZ0_nWPjh01?nVNJ7oYgbTojMlY?nWO:@2ojR1ZPCoZGbR0_nZPZT4ojaoY003ojb6[On^
Oj7o[XFX00?o[XFX0onaQZH2ok6=/@;o]HVV0_ndT;401?njSZSo]iBbokND/_ngU;83ok^J]PCo_j>l
00Go^JS8ol6/aOo1[<Go`Jc5okZ_c`02ol6ecP05okVfe_nn_=So_[cHokjlf?ng^md00_nj`Ml00onc
_^;o]<;TokC2i003ok2oi@04ojfmi_n]_^Ko0000o`0000;oZkgW00?oZ[cWojVji_nY^^H00_nX^>D2
ojNfh`04ojB]g_nSZ=_oXjSKoj>Xf`;oXZCG0_nQX=@00onJSlOoVhg4oi^=a003oib<`P?oWHc10_nP
S/42oj>B``04ojF=^ol0003oZI>oojVC_`;o[Y_400Go]Z32okZYbOnjZLWo^ZW9okfbd002olJndP?o
bm3M0_o>f^801?o4e>Ko`]KYol;FjOnic^X2okK<j`;o/<KZ00?o[/?Yo`000?ooool07oooool000Wo
oooo00@00000oooooooooooooooo@@00000=01TI6El000001?ooool00`00003oooooooooo`0Eoooo
o`03o`000?oooooooooo00Cooooo0_nNY=X01?nPWM7oU9SDoiZ@b?nJT<P2oij:_P?oXHNh0_nTQ[@2
ojF7]004oj9lZOnTOJSoY7fXojAmZ0;oYWnZ00?oYh>^ojIiXOnVNJ400onWO:@2ojR1ZPCoZGbR00?o
ZX:YojajW_n/Oj@00on/Oj@00on/QZgo[WnQojioX@03ojj5Z0?o/HJV00Go/HfaokF9Y_neRJKo]HVV
okB@/@02okZ>Z0?o]iBb00Co_iJ]ok^J]_nkV[KoaJ2c0onoXk`3ol6/a@05ol^gaoo1]Lko`KG>ol6e
c_o8`M<00_nn_=P2ol;6g@03ok[1gonjanCo]<;T00?o]<;T00Co/;oUo`000?l0003o00000_n/_^L3
oj^liP03ojVji_nW]^?oY[;Q00?oY[;Q0_nT[Mh01?nSZ=_oW9S?oi^CbonKTl/3oiZ?a`?oVhg40_nL
S<83oif<`@03oj2>`OnPQkWoYHfk00?oYHfk00?o0000ojVC_on^Vl@00onfX<82okZYb@05olJfboo6
_];od<kGom3>eoo;d=d00_o>f^82olgPiP04ol;FjOnme>_o_MC[okK<j`;o//S[0on^`nT00ol0003o
ooooooooo`0Mooooo`002Oooool01000003ooooooooooooooom900000003o`000000000000000640
00001?ooool00`00003oooooooooo`0Dooooo`03o`000?oooooooooo00Gooooo0_n?XN43oiBHe0;o
VY380_nNR[h2oj67^003ojB6]?nOO:goXWbY00;oXWbY0onTOJP2ojIoZP?oYWVQ0onWO:@00onXPJ[o
Z7RNojUlXP03ojUlXP03ojZ2ZOn/NYko[7ZN00?o[7nT0on^Oj42ojj5Z004ok:1WonaQZKo/HJVok66
YPCo]HVV00Go]92aokZ>Z?njSZSo^XjXokND/P02oknF[@05ok^J]_o5X;?oaJ2colFP/onoXk`00_o9
Zk`01Oo1[<GobkO7ol^gaoo;]lOo`KG>00;ob<7C00Coc=3Mol;6gOo2a]go`/KM0onjan@01_nd`^Co
0000o`000?l0003o/<7Vojk1j0Co[;kW00?oZkcVojViiOnW]^<00_nW]^<2ojJbh@03oj6UfOnNW]Co
WYkD00?oW9S?0_nKTl/3oiZ?a`;oVhg40onLS<800onMS<7oW8>goj27^@02oj27^@?oYHfk00?oZI>o
o`000?nfX<800onfX<800onjZLWoa[K;olJfb`03om3>e`04omOMg?o>f^;ocN3VolgPiP;oamoZ00Go
_MC[okS?k?nhcnco//S[ojo4jP04ojc1j@03o`000?oooooooooo01cooooo0009ooooo`0400000?oo
ooooooooooooojd000001?ooool00`00003oooooooooo`0Dooooo`03o`000?oooooooooo00Kooooo
0_n?XN42oiBHe0;oVY380_nNR[h01?nQQkSoVWjdoiml[OnOO:d4oj9lZ@;oY7fX00?oYWnZojAgX?nV
NJ400onVNJ42ojMlY0?oZ7RN0onYO:83ojajWP?o[7nT0on^Oj401?n^QJSo/X6Ook:1WonbPIl2ok66
YP04okN5X?neRJKo]HVVokF9YPCo^XjX0onoUZd4olFP/`?obJ^l00Koe[k2ol^gaoo;]lOobkO7omC:
d?o8`M<3olc@g@03ol;6gOo1cnGo`LoU00?o000000Co^<_Xok?4ionaaNWo/LGY0_n^`NP2ojbni`;o
ZkcV0_nY^ND00onW]^?oXj_Moj6Uf@03oj6Uf@;oWYkD0_nLV<l3oi^Cb`;oVXo700?oVhg4oiIo^?nI
P;L00_nIP;L2oib3]`?oX8Ni0onUSK/2ok2F_004o`000?nfX<;o]Z32ol:[a0?oa[K;00KodlS?om3>
eooGgMcoemgLomSXh?o=h>H2olOOjP;o`=[/00?o^<o/ok?:jon_a>X00_n_a>X2ojc1j@03oj^ojOl0
003ooooo01gooooo0009ooooo`0400000?ooooooooooooooojd000001?ooool00`00003ooooooooo
o`0Dooooo`03o`000?oooooooooo00Oooooo0_mYW>h00omcT^;oQ8WAohB9d@02oi63`0;oVWjd0_nO
O:d4oj9lZ@;oY7fX0_nTMj04ojIiX@;oYgbT0onXN9h3ojUlXP?o[7ZN0_n/Oj@01?n_O9_o[WnQojio
XOn^Oj44ok:1W`03ok66Y_ngQJ3o]hFP00?o]HVV1?njSZP3oknF[@CoaJ2c00?odZnfolV[_?o9Zk`0
0_oF_/801?o;]lOoe<[@omC:d?oGh=h2olc@g@05olSLj?l0003o0000o`000?nldn`00_nhbnP2ok?:
j`03ok75jOn]`n[o[;oX00;o[;oX0_n[_>H00onW]^CoYK7QojFah@03oj>[g@?oXJGI00CoWYkDoiJ;
a_nDQL7oU8G10onCPKd2oiAo^P?oUWnh0_nIP;L3oib3]`?oX8Ni00KoYHfkojZ=]on`U[co/9Jlo`00
0?nfX<83ol:[a006olJfbooCb<oodlS?omkMe?oGgMcof>SP0_oDk>D00oo<jN_o`=[/ol3Jk002okWC
k@;o/l[[00?o[lCZojc1jOn/`NT00_n[_nT00onZ_^So0000ooooo`0Looooo`002Oooool01000003o
oooooooooooooon]000000Cooooo00<00000ooooooooool05?ooool00ol0003oooooooooo`08oooo
o`;oJIc^00CoLi;RohB9dOnAPl3oTH?00_nJO[@3oiml[@?oXWbY00?oY7fXoj9fX_nTMj000_nTMj03
ojIiX@03ojMlY?nXMYcoZ7RN00;oZ7RN0_nYO:801On[N9[o[7ZNojajW_n/NYko[7nT00?o[gbK0_n^
Oj44ok:1W`03ok66Y_ngQJ3o]hFP00;o]HVV0_nmS:82okZ>Z0;oa9FV00?o_iJ]ol^Q[?o;XJ`00_o5
X;<2om:_]P06olV[_?oF_/;oe[k2omJn`_oQf/ooe<[@0_oGh=h3o`0000;o_]k`00Ko_=?/okC@kond
d>oo]=3_ok?:jon^a^`3ojg3jP03ojboj?nY^nKoZK_V00?oYkKT0_nU/N400onSZmgoVi_BoiRCc002
oiRCc0;oUX_60onDQL42oi>1_@;oU7nj0onFOkP3oiV0]`;oW8>g0_nPQkT01?nTQK?oZXfgojZ=]onZ
SKL2ok2F_006o`000?o2ZlCo`Z_4ol:[a?oA_/OodlS?0_oNgM@00ooSk]OogoOJomC/i@02olcYj`04
ol?Pk_nidngo^M?]ok?;k0?o[lGZ00?o[<7Yoj^ojOnZ_^P00_nZ_^P00ooooooo0000ooooo`0Koooo
o`002Oooool01000003ooooooooooooooon]000000Cooooo00<00000ooooooooool05?ooool00ol0
003oooooooooo`09ooooo`04oaB1i_l6K]koQ8WAohB9d@;oTH?00_nJO[@2oiml[@;oXWbY00?oWWJV
oj9fX_nRMZ800onTMj03ojIiX@;oZ7JL0onXN9h00onYO:;oZgRJoj]hVP03ojajWPCo[gbK00?o[WnQ
ok=oVonbPIl00onbPIl4okN5X004okF9Y_nmS:;o_HbRokZ>Z0?oa9FV00Co_iJ]ol^Q[?o;XJcoaJ2c
0ooB[kH3omJn`P;ohM[?0ol000001?o<k^_o^^[dok[Zm?nng_02ok?Gl`;o]=3_0_n^bNh2ojk6k003
ojg3j_nZ_^SoZ[kX00?oZK_V00CoYkKToj:[g_nNXmWoWZ?I0onKVm83oiRCc0;oUX_60_nDQL43oi>1
_@;oU7nj0onFOkP2oiV0]`03oib3]onNOk7oY8Fc00;oY8Fc0onZSKL01On`U[co^j2mok^P_Ol0003o
`Z_400;odKk700Ooh]O<omkMe?oSk]OohnkGomogf_oGmn7oc>W[00;o`n3^0oncbn`2ojo5jP;o[<;Y
0_n[_nT3ojZnj003o`000?oooooooooo01[ooooo0009ooooo`0400000?ooooooooooooooojd00000
1?ooool00`00003oooooooooo`0Dooooo`03o`000?oooooooooo00_ooooo00Co1VkNobeagonAPl3o
TH?00_nJO[@2oiml[@03oj9lZOnNMZKoWWJV00;oXWJR0onTMj02ojIiX@04ojIeVonXMYcoZ7JLojQf
W0;oZ7RN1?n[N9X2ojajWPCo[gbK00?o[WnQok=oVonbPIl00onbPIl4okN5X0?o_HbR00Go^XjXolBE
Y_o4UJKoa9FVoknF[@02ol^Q[006omfh/_oB[kKodZnfom:_]_oSbkooe[k20ol000001OoLm]go_ocW
oj_amOn[lOGo^^[d00;o[mcg00Ko/mOcojc<l?n/c?3o[<c`ojk9k_nZ`n`3oj_1jP03ojZnj?nV]nGo
Y[OU00?oY;;R0_nRZmh2oijSf@?oVi_B0_nHTl`2oiJ;aP?oU8G10_nCPKd2oiAo^P;oUWnh00?oU7J_
oiQi[onHNJl00onNOk43ojB5/`;oZXfg0onkX;d02Ol0003odKk7om6naooA_/Ooh]O<on__c?oSk]Oo
goOJomOgh@02olk`jP04ol?Pk_njeNko^]G^ok?;k0;o[lG[0_n/`^T00on[_nWoZ[kXojZnj002ojZn
j003ojVmj?oooooo000001_ooooo0009ooooo`0400000?ooooooooooooooojd000001?ooool00`00
003oooooooooo`0Cooooo`03o`000?oooooooooo00gooooo00?o05VcofAgdOmTMm400_nJO[@00onO
O:goUWJ^oiifYP02oiifYP?oXWJR0_nTMj000onVNJ7oYWFKojIeV`03ojQfW0;oZ7RN1?n[N9X00on/
NYko/7ZIojmlV`03ojmlV`03ojioXOncOi_o/gnK00;o/X6O00?o^XBLokN5X?ngQJ000_ngQJ03okf<
XPCoa9FV0oo;XJ`2omfh/P08om:_]_l0003o0000o`000?o[l/co_oc3omcfgOnoo>L2oj_am@;oYmoj
00?o[mcgoj[>l_nZc_800_n/c?02oj[4k@;oZ/?/00?oZl7ZojNkionV]nD00onV]nD01?nT/^;oWJCJ
oiVJdonIV]<2oiB@c0?oTHK50_n>O[h2ohai^0?oS7Fd0_n>Lk42oi1d[`?oU7J_0_nHNJl3oiio/@?o
Y8Fc00?oZXfgokBD]ondU;L00_nkX;d00oo<//3o0000om6na`02on;Gc005on__c?oWnlSogOk;omGn
f_o>l>X00_o3i>l01?njeNko/lc/ok?<k?n_aN/2ojc1j@?oZkoY0onZ_^P2ojVmj003o`000?oooooo
oooo01Wooooo0009ooooo`0400000?ooooooooooooooojd000001?ooool00`00003oooooooooo`0C
ooooo`03o`000?oooooooooo00oooooo00?oI7OAohEg_?n5Mk`00_nFMZh3oiifYP?oXWJR0_nTMj03
ojIeV`?oZ7JL00?oZ7RNoj]gVOn[N9X00on[N9X00on/NYko/7ZIojmlV`03ojmlV`?o/gnK0_nbPIl2
okZ4W0;o]hFP00Co`HfNokf<X_nmS:;o_HbR1?o4UJH01?oCYZWobj6/omfh/_oM^;82o`0000;ohl^o
00?ojo;<okol`onHfoh00_nHfoh00onOg_goYLcdojG<m002ojO=m006oj[>l_nYa>goZLC]ojW4kOnZ
a>goZ;kY0onX_NP2ojNki`;oY[OU00CoXJcOoifTf_nMY=[oWJCJ0_nIV]<2oiB@c0?oTHK500?oSWjn
ohai^?n<NKP00on<MK@2ohic/@?oT7B_0_nDMZl3oiQi[`?oWWna00?oY8Fcoj^:/_ndU;L00_ndU;L0
1_nkX;goc;;0olbb`?o<//3o0000on;Gc0;ojno<00Goio_8omGnf_o=mNWocOGYol?Tk`02okWFkP05
ok?<k?n^aN_o[/G[ojc1jOn[_nT01OnZ_^P4ojVmj003o`000?oooooooooo01Sooooo0009ooooo`04
00000?ooooooooooooooojd000001?ooool00`00003oooooooooo`0Cooooo`03o`000?oooooooooo
013ooooo00CoI7OAohEg_?nFMZkoUWJ^1?nNMZH2oj9fXP;oY7NP0onVMI/3ojQfW003ojQhW_n[MiWo
ZgRJ00?oZgRJ00?o[7ZNok1jVOn`NYT00on_O9/3ok=oV`04ok:1WonjQ9co^XBLokZ4W0;o]hFP0_o1
SIh00onmS:;obYRRolZHXP02olBEYP;odjJY0ol000001?oM^;;ol^:mon?;_oo[l/`2oiGFoP;oV=_n
0_nTbO<00onUc?CoYl;]ojS3k@02ojS3k@;oZLC]00KoZ;oZojRnjOnX_^WoZ;kYojRmj?nV]nD4ojBb
h`;oXJcO0_nMY=X2oiVJd`;oU93<0onAQ/D2ohin_P;oS7Vh0on<MK@2ohic/@;oT7B_0onDMZl2oiQi
[`;oWWna00CoXh6^oj^:/_n[R[;oZhZb0_ndU;L02Oo4Y;[oc;;0olbb`?o<//3ohLg4o`000?o[klco
io_8omGnfP02olgej@03ol;Ul?nie^ko^MK^00;o//_/00?o[/G[ojc1jOn[_nT00_n[_nT2ojZnj0;o
ZKkX1OnY_NP00ol0003oooooooooo`0Gooooo`002Oooool01000003ooooooooooooooon]000000Co
oooo00<00000ooooooooool04oooool00ol0003oooooooooo`0Aooooo`04ogl00?n5MkcoUWJ^oiIf
[P?oWWJV0_nRMZ800onTMj3oY7BMojIeV`02ojIeV`?oZ7JL0_n[MiT4oj]hVP?o/7ZI0_n_O9/01One
OiWo/gnKok=oVoncOi_o/X6O00?o^XBL00Go]hFPol6=W_o1SIko`HfNokf<XP02olZHXP04olBEY_l0
003o0000o`0000?ogKRb0_obh[d01?nFd?coY<C`ojC4l?nTa?02oj?6lP03ojC9lonW`NcoYl7/00;o
Yl;]00?oZ<?]ojRoj_nX_nX00onX_nX00onX_^WoYk[WojNji`02ojJgi@;oY;;S00?oWJKLoiRLe_nH
W=H00_nBT<h2ohf5aP;oR7^n0on6LkL2ohA^/@;oS7Vh0on<MK@2ohic/@;oT7B_0onDMZl2oiQi[`03
oiio/OnSPJkoXh6^00?oZhZb00Go]9BgolBT^_o4Y;[oa:Bjolbb`002on7=a006o`000?o[nKCocO^c
olkodOo;mn[o`^G`0_nheNl2ok;;k0;o[/C[0_n/`NT00on[_nWoZ[kXojZnj002ojVnj0KoZKgX00?o
0000ooooooooool05oooool000Wooooo00@00000oooooooooooooooo[@000004ooooo`0300000?oo
oooooooo01?ooooo00?o0000ooooooooool04Oooool01?mo003oQGNloiIf[_nFMZh3oiifYP;oXWJR
0_nTM9d3ojIeV`?oZ7JL0on[MiT3oj]hVP?o/7ZI0_n_O9/01?neOiWo/gnKok=oVoncOi/4okZ4W005
okN5X?o1SIko`HfNol6=W_nmS:800ol00003om>VZ@03onc9/OoM^;;ol^:m00;ol^:m00CoYL7^ojC4
l?nTa?3oZ;oZ0onW`>/00onW`NcoZ;kYojRnj@02ojRnj@;oZ;oZ00KoZ;gXojRlj?nX_>SoZ;cXojNj
ionT]>@3oj6^h@?oWJKL0_nHW=H2oi:@cP;oSHG60_n8Nkh2ohIc]`;oQ6ja0_n5Jjd3ohMZZ`;oSW>a
0on@M:l2oiAf[`03oiQi[onLNJ_oXh6^00?oXh6^0_n[R[84olBT^P07om^o__oQcLColN_3oo7[`ol0
003oc_oAol_gjP02ol3Tl@03okSEkonabNco/LW/00;o[/C[00GoZl3YojZoj?nZ_nSoZ[oXojZnj00:
ojVmj003o`000?oooooooooo01Kooooo0009ooooo`0400000?ooooooooooooooojd000001?ooool0
0`00003oooooooooo`0Cooooo`03o`000?oooooooooo01;ooooo00?oO`00oiIf[_nFMZh00onNMZH0
1?nRMZ;oWW>RojAdWOnTM9d3ojIeV`;oZ7JL00CoZWJIoj]gVOn[MiWoZgNI0_n[N9X01On`NYSo/7ZI
ok1jVOn`NYWo[gbK00;o]GnI0oncOi/4okZ4W0;o`HfN0ol00002olZHXP?odjJY0_o/bK42onWgYP03
oo;R_OnU`NkoZ;kY00;oZ;kY0_nX_nX00onW`>_oZKkYojVnj@03ojRnj@?oZKgX0_nX_NP00onX_>So
Y[SVojJhiP02ojBdi0?oXJkQ00CoWJKLoi:Dd_n;Ql[oRhO:0_nBT<h2ohf5aP;oR7^n0on6LkL01?n4
K[7oQF^]ohE[[On5Jjd2ohMZZ`;oRV^Y0on?KZT2oiEbZ@?oW7V[0onSPJh2oj^:/P03okVG]?o4Y;[o
a:Bj00;ofknn00Ool^:moo7[`onchGco]^jJo`000?o7m^co`>Ca00;o]];_00?o/LW/ojg3j_n]`nX0
0on[`>T00onZ_nSoZ[kXojZnj00;ojVmj003o`000?oooooooooo01Gooooo0009ooooo`0400000?oo
ooooooooooooohH000003`0I6ATH000000Cooooo00<00000ooooooooool04_ooool00ol0003ooooo
ooooo`0Dooooo`;oLFbm0onBLZ/2oiicXP?oY7BM0_nVMI/00onXMYcoZWJIojYfV@03oj]gV@;oZgRJ
00Go/7ZHok1jVOn`NYWo/7ZIojmlV`03okEoV@;o/gnK0onjQ9`3o`0000;o`HfN0oo:V:800ooO/JSo
djJYom>VZ@02onc9/@03onWgY_nV_ncoZ;kY00?oZ;kY00GoZKgXojVnj?nY_^SoZKkXojVnj@06ojVm
j006ojRlionW^^OoYk[WojNjionV^>KoX[7S0_nNZ]l3oiVQfP?oTYCB00?oRhO:ohEk`On5Nl400_n0
LKP3ogeY/@;oQW>g0_n4K[42ohE[[@;oQfZ[0on:JjT2ohm^Z@;oUG:Y0onLNJ/3oj>1[P04oj^:/_ni
UkCo^INdolBT^P?ofknn00Sol^:mol_YQ?nfkY[oa_k=olOfk?l0003o_N3aokKBk`;o[lS/00?o[L?Z
oj_0jOnZ_^P01?nZ_^P<ojVmj003o`000?oooooooooo01Gooooo0009ooooo`0400000?oooooooooo
oooooh8000005P0I6ATE000000Cooooo00<00000ooooooooool04_ooool00ol0003oooooooooo`0D
ooooo`03o`a<bOmaK;goTW:[00;oTW:[0_nNLj83ojAdW@;oYWFK00?oZ7JLojYfVOnZMYT00on[MiT0
0on[N9[o/7ZHok1jV003ok1jV@Co]GnI00?o/gnKokb6V_l000000_l000000oo6T9go`HfNol6=WP02
ol6=WP;obYRR0ooO/JP00ooCYZWok<VaonWgYP02ojVmj0;oZ;kY1?nY_NP00onY_^SoZKgXojVmj004
ojVmj0;oZKcX0_nX_>L00onW^^OoYKOUoj:ah`02oj:ah`;oWZ[O0onIXMX2oi:DdP;oRhO:00CoQG_1
oh1a^?n0LKSoP76h0_mmJK42ogaT[0;oQ6ja0_n5Jjd2ohMZZ`?oRV^Y0_n?KZT3oiEbZ@;oW7V[0onS
PJh3okVG]0?ofknn0_obh[d01Ol0003oX^:<olCbkoo4l^oo000000;o/lo^00?o[lS/ojc2j_n/`^X0
0_n[`>T3ojZnj0koZKgX00?o0000ooooooooool05?ooool000Wooooo00@00000oooooooooooooooo
N@0000000ol0000000000000000O01TI6@03o`0000000000000000l000001?ooool00`00003ooooo
ooooo`0Booooo`03o`000?oooooooooo01Gooooo00CoLFbmoi9bZonBLZ_oTW:[0onNLj82ojAdW@;o
YWFK1?nZMYT2oj]gV@03oj]hV_n`NYSo/7ZH00?o/7ZI0oneOiT3o`000004okb6V_njQ9co^XBLolJ@
W@?o`HfN0_oAWZ401_o:V:;ogk6XomnaZ?oO/JSon^N/onc9/A3oZKgX00?oZKcXojRkionW^NH00_nW
^NH2ojFgi@03oj:ahonKYmkoU9cH00;oU9cH0_n<S]02ohB0a`;oO7>m0_n5Nl42oh1a^0;oOFVa0_ml
I:`2ogeRZ0?oQF^]0_n7JZ/2ohY[Z@?oSfjY0_nELZT3oiaiZ`03oj>1[_n_RZoo^INd00;o^INd00Ko
d:niom^o__obh[gol^:mo`000?nRhX`2olCbk`;o^M_a00Go0000ojk5jon^aN_o[<;Zoj^oj@04ojZn
j13oZKgX00?o0000ooooooooool04oooool000Wooooo00@00000ooooooooooooooooN000000T01TI
6A4000001?ooool00`00003oooooooooo`0Booooo`03o`000?oooooooooo01Kooooo00?oLFbmoi9b
ZonBLZ/00onNLj82ojAdW@;oYWFK1?nZMYT2oj]gV@?o/7ZH0_n`NYT01_ngP9Wo]GnIo`000?l0003o
]GnIok=oV`;o_8JJ00Co^XBLolJ@WOo6T9goaY2M0_o1SIh2om6NX@05olZHX_oO/JSogk6XomnaZ?oj
ij`04?nY_NP2ojVli`;oZ;_W00?oYkWVojBeiOnQ/>800_nQ/>82oi^WgP?oU9cH0_n<S]000on4P<Oo
O7>mogac_@02ogMX]@;oP76h0_mmJK42ogaT[0;oOF:X0on0HZH2ohMZZ`?oRV^Y0_n?KZT2oiEbZ@;o
W7V[00GoY7n[ojn:[on_RZoo[hZ_okVG]002om2_^@04ongE^oobh[go`]][ol3ng0;o_n_b0_nifo40
0onabngo[/G[o`000002oj_1j@;oZkoY00?oZ[kXojVnj?nY_^P04?nY_NP00ol0003oooooooooo`0C
ooooo`002Oooool01000003ooooooooooooooomg000002L06ATI3`000004ooooo`0300000?oooooo
oooo01;ooooo00?o0000ooooooooool05_ooool00omaK;goTW:[oi9bZ`03oiicXP;oY7BM00?oYWFK
ojQfW?nZMYT00onZMYT2oj]gV@?o/7ZH00Co/7ZIo`000?l0003o00000oneOiT3okb6VP05okZ4W?o6
T9goaY2MolJ@WOo1SIh00ooAWZ43omnaZ0;on^N/4?nY_NP00onY_>OoZ;_WojJiiP02ojJiiP;oY;GU
00CoXK3RoiVUg_n@VMSoT9WH0on6R/l2ogaja@;oQ83700?oO7>mogMX]OmgJ;D00omcH:h2ogeY/@03
ogaT[?mmHZSoOF:X00?oP6:V0_n4I:D3ohY[Z@;oSfjY00?oUG:YoiYeZ?nTOj/00_nTOj/3ojn:[`08
okVG]?o@[kWod:niongE^ooclZ?o0000ol3kjOnojo82okKDl005ok7;kOn]`n_o[L?[oj_1jOl00000
1?nZ_^P00onY_^SoZKgXojVmj00@ojVmj003o`000?oooooooooo01;ooooo0009ooooo`0400000?oo
ooooooooooooog@00000300I6AT@000000l06ATI3P000004ooooo`0300000?oooooooooo01;ooooo
00?o0000ooooooooool05oooool2oi9bZ`?oWW>R0_nTM9d2ojQfW0CoZWJI00?oZgNIok1kVOn`NYP0
0ol00002okN0V@Co]GnI0onlQYX01OnjQ9coaY2MolJ@WOo6T9go`HfN00?odIjQ0ooO/JP00oojijco
ZKgXojVmj00>ojVmj0;oZ;cW0_nX^nL01?nV^NKoXkCUoin^h_nO[^83oiVUgP;oT9WH0on6R/l00oml
N/GoLfblog=/_002ogac_@;oMfRe0_mcH:h01?mcFjSoOFVaogaT[?mlI:`2ogeRZ0;oP6:V0_n4I:D3
ohYXY@;oTVjV0onJMJP3ojAoZ`;o[hZ_0_o@[kT2ongE^`05ol;KJoo0nnWo^n;cok_Rlonfe?000_n_
b>`01?n]`n_oZl3Yoj_0jOl00003ojZnj1CoZKgX00?o0000ooooooooool04_ooool000Wooooo00@0
0000ooooooooooooooooK`0000000ol000006ATI01TI6@0901TI6@D0000000?o000003<c<`0c<c<0
3@0c<c<2000000d06ATI3P000004ooooo`0300000?oooooooooo01;ooooo00?o0000ooooooooool0
5oooool2ocQHa`?oWW>R00CoY7BMoj5fX_nXMYcoZ7JL1?nZMYT3o`0000;o/7ZH00Co/7ZIokN0VOng
P9Wo]h2I0oneOiT3okb6VPCoaY2M00Ko`HfNom6NXOoAWZ7odIjQoo38ZOoO/JP2oo[W[13oZKgX00?o
Z;cWojNkionV^NH00_nV^NH2oj>di@;oWjkR00?oVJGNohfGfOn1Qm000_n1Qm02ohJ:c`03ogajaOmc
K;coLfbl00;oKF2c0_mgJ;D2og=P[P;oLe^X0_mlI:`2ogeRZ0;oP6:V0_n4I:D3ohYXY@;oTVjV0onJ
MJP3ojAoZ`07ojn:[oo2W[?o`Yjcom2_^Oo]eK_olo:So`000002okKHlP;o//k_00Co[lS/ojc2j_n/
`^[oZl3Y0_nZ_^P00ol0003oZ[kXojZnj00EojVmj003o`000?oooooooooo017ooooo0009ooooo`04
00000?ooooooooooooooofh000002P0I6AT3000001L0<c<c0P00000;01TI6@h000001?ooool00`00
003oooooooooo`0Aooooo`03o`000?oooooooooo01Wooooo00Co>5S7ohib[on>LZooSW:_0_nQMZ83
ojQfW0?o000000?oZgNIok1kVOn`NYP00_n`NYP01?n`NYWo]h2IokN0VOngP9T2okEoV@04ol29V_nl
QY[o_8JJokb6VPCoaY2M0ooAWZ42oo38Z@03omnaZ?nY_NSoZKgX00ooZKgX0_nX_>L2ojNki`04ojJi
i_nS]>GoWZkSoij^h`?oUZCO0_n=UmT2oh67d0;oMGK600?oJVJlogajaOmcK;`00_m]H;<2ofUH[0;o
Lf2^0_mcFjP01?mdFZGoO6B/ogeRZ?mmHZP2oh1RYP?oQ6BU0_n:J:D2oi9^YP?oVWFX0onTOj/3ol:N
/`06on;3^Oo]eK_olo:Sok[Um?nff?;o[lW]0on]a>/00on/`^[oZ[oYojZoj@03ojZnj003o`000?nY
_NSoZKgX01GoZKgX00?o0000ooooooooool04?ooool000Wooooo00@00000ooooooooooooooooK000
000901TI6@<00000700c<c<00`0000006ATI01TI6@0801TI6@h000001?ooool00`00003ooooooooo
o`0Aooooo`03o`000?oooooooooo01[ooooo00?o>5S7ohib[on>LZl00_nQMZ83o`0000?oZWJI0on`
NiT2ok1jV0Co]h2I0_neOiT01?o0RI[o_8JJokb6V_nlQYX4olJ@W@?odIjQ0_o`b:TBojVmj003ojRl
ionW^nOoY[SV00;oY[SV0_nS]>D2oij^h`?oUZCO0_n=UmT2oh67d003ogEfa_mZI[coJVJl00;oLfbl
0_m]H;<2ofUH[0;oLf2^00?oLe^XogAJYOmdFZD00ommHZP2oh1RYP;oQ6BU0on:J:D2oi9^YP?oVWFX
0_nTOj/3ol:N/`03on;3^OohkJWo000000;o/]3_0_n_bNd01On]a>_oZl3Yoj_0jOnZ_nWoZ[kX00Co
ZKgX00?o0000ojVmj?nY_NP05?nY_NP00ol0003oooooooooo`0@ooooo`002Oooool01000003ooooo
oooooooooomZ000000L06ATI00@00000o`000000000000001P0c<c<4000000;o00003000000803<c
<`030000000I6AT06ATI00P06ATI3@000004ooooo`0300000?oooooooooo017ooooo00?o0000oooo
ooooool06_ooool00olhF<OoSW:_o`000002o`000003oj5fX_nXMYcoZ7JL00?oZWJI0on`NiT2ok1j
V0Co]h2I00Ko]GnIol29V_o0RI[o`8VJokb6V_o=Uih3olJ@W@;ogJbS00CodIjQoo38ZOo`b:Wol<RY
4OnY_NP2ojRlj0;oYk_W00CoY[SVoj:ei_nM[^CoWJkT0onEYN02ohZGfP;oOHOB0_m^M<P2ogEfaP03
ofYV_?mRFK;oHUVb00;oKF2c0_mYF:`00omXDjOoLf2^og=KZ002ogAJY@?oN5ZS0_n0HZH2ohATY@?o
RVRU0_nBKZH3oiYeZ004ojAoZondSZoo]8j_ol:N/`;oh/>i00Con>fYok;@konbd>oo[LG[0on/`^X0
0on[`>WoZ[kXojZnj002ojZnj0?oZKgX00?o0000ojVmj?nY_NP05OnY_NP00ol0003oooooooooo`0?
ooooo`002Oooool01000003ooooooooooooooomW000000T06ATI00<0000003<c<`0c<c<01@0c<c<3
00000180C4a<00<0000003<c<`0c<c<01@0c<c<00`0000006ATI01TI6@0801TI6@d000001?ooool0
0`00003oooooooooo`0Aooooo`03o`000?oooooooooo01Wooooo0ol000001?n>LZooXGJRoj5fX_nQ
MZ82ojQfW0;oZWJI00Ko[WbLok1kVOn`NiWo/7^Iok1jV?nhPiX4okN0V@05okEoVOo0RI[o`8VJol29
V_nlQYX00_o=Uih2olJ@W@;ogJbS00?odIjQoo38ZOo`b:T04_nY_NP00onX_>SoYk_WojFii`02ojFi
i`;oX[GV0_nM[^@3oiFUh0;oRYOJ0_mmQm801?m^M<SoH6>nof1S__mZI[`2of9I/P04oea@Zom]H;?o
JER/ofUH[0;oJ5>W0_mcFjP01_mdFZGoN5ZSogQJXomhFZ?oOUfSoh1RYP?oQ6BU0_n:J:D2oi9^YP;o
VWFX00WoYX2[okB>[ondSZoo]8j_ol:N/ooR`kWon>fYol7FHOn_bNd00_n]aN/2ojc2jP;oZ[oY00?o
Z[kXojVnj?nY_NP01OnY_NP00ol0003oZKgXojVmj00EojVmj003o`000?oooooooooo00kooooo0009
ooooo`0400000?ooooooooooooooofD00000200I6AT3000000@0<c<c1000000F04a<C08000001P0c
<c<00`0000006ATI01TI6@0701TI6@d000001?ooool00`00003oooooooooo`0Aooooo`03o`000?oo
oooooooo01Kooooo0ol00003ooooo`04ohib[onQMZ;oXGJRoj5fXP;oZ7JL00?oZWJIojilW?n^O9`0
0on`NiT00on`NYSo^8>JokN0V@03okN0V@05okEoVOo0RI[o`8VJol29V_nlQYX00_o=Uih01?o6T9go
gJbSomf/XooM[:<2ooO^W@03oo38ZOnY_NSoZKgX00ooZKgX0_nX_>P2ojNki`03ojFiionR]^KoWK3U
00;oWK3U0onDYn800on9V]goNXWGogZ9e`02ofQfc@;oKWC800CoH6>noeED]?mZI[coHUVb0_mLD:/0
1?m]H;?oJER/ofQCYomXDjL2og=KZ0;oM5ZU0_mhFZ<2ogiMX`?oQ6BU0_n:J:D2oi9^YP03oiYeZ?nV
P:_oYX2[00?o]8j_0_oR`kT01?ohkJWo[lW]ojc2j_n/`^X2oj_0j@;oZ[oY0_nZ_^P2ojVnj0KoZKgX
00?o0000ojVmj?nY_NP05?nY_NP00ol0003oooooooooo`0>ooooo`002Oooool01000003ooooooooo
oooooomS000000L06ATI0`00000403<c<`<000001P1<C4`=00000003o`0000000000000000H0C4a<
00<0000003<c<`0c<c<0100c<c<00`0000006ATI01TI6@0601TI6@d000001?ooool00`00003ooooo
ooooo`0Aooooo`03o`000?oooooooooo01Cooooo0_l00006ooooo`04ohib[onQMZ;oXGJRoj5fXP;o
Z7JL0on^O9`3ok1kV@03ok1jV?nhPi[o]h2I00?o]h2I1?o0RIX01?nlQY[ocINNolfGW_o6T9d3omf/
X`;omnjM4_nY_NP00onX_>SoYk_WojFii`02ojFii`;oX[KV00?oWK3UoiFZi?nEZ^@00_n9W^42ogV>
g0;oNXWG00CoJ7K=oeMR`omGH/?oH6>n0_mEE;@01?mRFK;oG52[oea@ZomLD:/2ofUH[003ofQCYomZ
DZ?oLe^X00;oM5ZU0_mhFZ<2ogiMX`?oQF>S0_n>JjD2oiUdY`CoYX2[0_ndSZl01_oA[[Koh/>iol_J
Ion]a>_o[<;ZojZoj@GoZ[kX2_nY_NP00ol0003oZKgXojVmj00@ojVmj0?ooooo00?o0000oooooooo
ool03_ooool000Wooooo00@00000ooooooooooooooooH@0000000ol000006ATI01TI6@0501TI6@03
0000000c<c<0<c<c00@0<c<c00<0000004a<C01<C4`01@1<C4`00`00003o000006IVIP0?06IVIP03
0000001<C4`0C4a<00<0C4a<00<0000003<c<`0c<c<0100c<c<00`0000006ATI01TI6@0601TI6@d0
00001?ooool00`00003oooooooooo`0@ooooo`03o`000?oooooooooo01;ooooo0ol00009ooooo`?o
XGJR00?oZ7JLojQmY_n^O9`00_n^O9`3ok1kV@?o^8>J0ongP9T4ol29VP?ocINN00?oaY2Momf/XooM
[:<00_ogkYdBojVmj0;oZ;cX0_nW^nL00onU^NOoXkOWoj>gi`03oifbiP;oUJ[T0_n9W^400omiS]co
IG_DofEke002ofQfc@04oeMR`om6D;SoH6>noeED]0;oHUVb0_mLD:/2ofUH[003ofQCYomZDZ?oJU:S
00;oM5ZU0_mhFZ<2ogiMX`?oQF>S0_n>JjD3oiUdY`?oYX2[00Go]8j_om6^]_oA[[Komn>cojg4j`02
oj_0j@;oZ[oY00?oZ[kXojVmj?nY_NP02onY_NP00ol0003oZKgXojVmj00>ojVmj0Gooooo00?o0000
ooooooooool03_ooool000Wooooo00@00000ooooooooooooooooH000000701TI6@800000100c<c<3
000000@0C4a<1000000306IVIPSo0000201VIVH00`000000C4a<04a<C00304a<C0030000000c<c<0
<c<c00<0<c<c00<0000001TI6@0I6AT01P0I6AT=000000Cooooo00<00000ooooooooool04?ooool0
0ol0003oooooooooo`0?ooooo`?o00003?ooool3ohIl`@;oZ7fV0on^O9`3ok1kV@?o^8>J0_ngP9T0
0oo5T9ko`8VJol29VP02ol29VP?ocINN0ooM[:<00oogkYgoZKgXojVmj00AojVmj003ojRlj?nW^nSo
Yk_X00;oY[[W00?oXkOWoindionO]>L00_nG[^H2ohbTi@;oO9KQ0_mVQ=`01?mUNmCoCfG:odmUb_mG
H/<2odI@^003oeED]?m=BJcoHUVb00;oG52[00?oFd^VofUH[?mXDjL00_mZDZ<2ofiCXP03ogAJYOmh
FZ?oN5ZS00;oOUfS0_n5Hj<2ohi[Y@?oVGBW0onVP:/3om6^]P03ol_JIon[`N[oZl3Y00CoZ[kX3_nY
_NP00ol0003oZKgXojVmj009ojVmj0[ooooo00?o0000ooooooooool03Oooool000Wooooo00@00000
ooooooooooooooooGP00000801TI6@030000000c<c<0<c<c0080<c<c0P00000404a<C0<00000101V
IVH3o`0000P0Ogmo1?l0000506IVIP030000001<C4`0C4a<00<0C4a<00?o000003<c<`0c<c<00P0c
<c<00`0000006ATI01TI6@0601TI6@d000001?ooool00`00003oooooooooo`0@ooooo`03o`000?oo
oooooooo00cooooo0ol0000@ooooo`;oQWc10_nXOJH3ojilW0?o/7^I0onhPiX2okN0V@03olF@W_o0
RI[o`8VJ00;o`8VJ0oo=Uih00oo`bJWogJbSomf/X`0BojVmj0?oZ;cX00?oYk_XojJjj?nV^^P00onS
^>L2oindi`;oUjkV0_n<Y>D2ogbFh@07ofJ4g?m;KM?oBfgCodmUb_lhCkkoEf;3odI@^002oeED]003
ode9[?mLD:_oG52[00;oFd^V0_mXDjL01?mZDZ?oKU>RofiCX_m^Dj82ogQJX`;oOUfS0_n5Hj<3ohi[
Y@;oVGBW0onVP:/01?nnVK;odJjfooOS/oo;fVL2ojZoj@?oZ[kX4?nY_NP00ol0003oZKgXojVmj005
ojVmj0gooooo00?o0000ooooooooool03Oooool000Wooooo00@00000ooooooooooooooooG0000000
0ol000006ATI01TI6@0401TI6@0300000?l00000000000<0<c<c00<00000o`00001<C4`00P1<C4`3
000000<0IVIV1?l0000?07moO`03o`00001VIVH0IVIV00<0IVIV00<0000004a<C01<C4`00P1<C4`0
0`000000<c<c03<c<`0203<c<`030000000I6AT06ATI00H06ATI00?o00000000000000002P000004
ooooo`0300000?oooooooooo013ooooo00?o0000ooooooooool02Oooool3o`0001?ooooo0_n6O<43
ojQmYP;o[WbL0_n`NiT01OniR:3o^8>JokR3V_nhPi[o]h2I00?oaI2N0_o0RIX00ooGYZCocINNolfG
WP03oo39Z@03ooO^WOnY_NSoZKgX017oZKgX1?nX_>P2ojJjj003oj>hionQ]nSoV[;X00;oV[;X0_n@
Z^L00on2WnKoK93Tofb@i002odmlgP09od]]dol/E<SoCfG:ocQ?__m6D;So>T:_oeED]?m=BJcoBD:W
00;oG52[00?oFd^VofQCYomXDjL00_mZDZ<2ofiCXP04ogEHX_mhFZ?oOUfSogiMX`?oQF>S0_n>JjD3
oiUdY`05ojJ0ZonnVK;o_YVbom6^]_oghk<00_nZ_nT2ojVnj1;oZKgX00Co0000ojVmj?nY_NSoZKgX
4Oooool00ol0003oooooooooo`0=ooooo`002Oooool01000003ooooooooooooooomL000000H06ATI
00<0000003<c<`0c<c<00P0c<c<2000000<0C4a<0P00000306IVIP?o0000101oOgl;o`0000@0Ogmo
00?o000006IVIP1VIVH00`1VIVH00`000000C4a<04a<C00204a<C0030000000c<c<0<c<c0080<c<c
00<0000001TI6@0I6AT01@0I6AT>000000Cooooo00<00000ooooooooool04?ooool00ol0003ooooo
ooooo`06ooooo`?o00005oooool2ohIl`@;oZ7fV0_n^O9`00on`NiWo^HRPokV8X003okR3VP04okN0
VOo5T9koaI2NolF@WP;o`8VJ0_oGYZ@01?o=Uikol<VYoo39ZOo`bJTBojVmj0GoZ;cX00CoYk_XojBi
j?nT^NSoY;WX0_nQ]nP01?nJ/^SoU[3YohVYj_n9ZNX2ogNNjP;oK93T00GoCgcNobURe?m;KM?o;5C8
ocQ?_P02odI@^008ocY2[om=BJcoCDV/odU2YomLD:_oFd^Voea:XomXDjL2ofYBX`;oKU>R0_meF:83
ogiMX`;oQF>S0_n>JjD2oiUdY`06oj^6[_nnVK;o_YVbokjI/_oXcK_ognQo0_nZ_^P00onY_^SoZKgX
ojVmj00BojVmj003o`000?oooooooooo017ooooo00?o0000ooooooooool03Oooool000Wooooo00@0
0000ooooooooooooooooF`00000501TI6@8000000`0c<c<2000000<0C4a<0P00000206IVIP?o0000
0`1oOgl4o`0000/0VIVI0_l0000307moO`03o`00001VIVH0IVIV0080IVIV00<0000004a<C01<C4`0
0P1<C4`00`000000<c<c03<c<`0203<c<`030000000I6AT06ATI00D06ATI3P000004ooooo`030000
0?oooooooooo013ooooo00?o0000ooooooooool00oooool3o`0001[ooooo0_n6O<42ojQmYP;o[WbL
00?o/7^IokV8X?niR:000onhPiX01OngP9WoaI2NolF@W_o5T9ko`8VJ00?oejJT00CocINNoo39ZOo`
bJWol<VY4onY_NP4ojRlj0;oYk_X00?oY;WXoj:ij?nR^NP00_nM]NT2oiJ`j@;oRJWZ0_mgW^X02omL
S^So=7SRocAhh_lYH]Co;5C8o`Xj^_lhCkkoAU2hocY2[ola>:WoCDV/00;oBD:W00?oFd^Voea:XomL
BZ<00_mZDZ<2ofiCXP;oMERR0omoGj@2ohESX`;oSV^U00?oVGBWoj^6[_n[QZh00onnVK800ooXcK_o
Z[kXojZnj00BojVmj0Gooooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`0=ooooo`00
2Oooool01000003ooooooooooooooomI000000D06ATI0P00000303<c<`8000000`1<C4`200000080
IVIV0_l0000207moO`Co00000`2IVIT9o`0000D0VIVI00Go000007moO`1oOgl0Ogmoo`00000306IV
IP030000001<C4`0C4a<0080C4a<00?o000003<c<`0c<c<00P0c<c<00`0000006ATI01TI6@0401TI
6@l000001?ooool00`00003oooooooooo`0?ooooo`04o`000?ooooooooooooooo`?o00007_ooool0
0on6O<7oZ7fVojQmYP02ojilW0Co^HRP0_nhPiX4olF@WP04ol29V_oGYZCoejJTomNVY0?ol<VY5_nY
_NP00onX_>SoYkcXojNlj002ojFkj003oj:ij?nQ^>WoVkG[00;oVkG[0_nA/N`2oh>ZkP;oKZ3_00Oo
CI7^ocAhh_l0Em;o05OBo`12a?l:>[[o8Sbd00;o>T:_00?o<CRYodU2Yom9@ZL00_mKBjH00omLBZ?o
HDbRofYBX`02ofiCXP;oMERR0omoGj@2oh]YYP03ohi[YOnIMZWoZhJ^00?oZhJ^00Co_YVbonS=^ooO
j7ooZKkX4OnY_NP8ooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool03Oooool000Wo
oooo00@00000ooooooooooooooooEP0000000ol000006ATI01TI6@0401TI6@030000000c<c<0<c<c
0080<c<c00<0000004a<C01<C4`00P1<C4`00`00003o000006IVIP02o`000080Ogmo0_l0000409VI
V@?o00002@2c/k<00ol00000VIVI09VIV@0209VIV@05o`00001oOgl0Ogmo07moOol000000`1VIVH0
0`000000C4a<04a<C00204a<C0030000000c<c<0<c<c0080<c<c00<0000001TI6@0I6AT0100I6AT?
000000Cooooo00<00000ooooooooool03oooool4o`0002;ooooo0_nXOJH00on^O9co]Y>cokV8X003
okV8X0;o^8>J1?o5T9h01_o0RI[oejJTomNVY?oGYZCodNZ5oo39ZAGoZKgX0onX_>P00onW_>SoY[cX
ojBjj@02ojBjj@;oXKSY00?oVkG[oiVfk?n?/nl00_n?/nl2oh6^lP;oJZOe00SoAicdoa]iiOl0Em;o
02^]o`Xj^_l08:_o3bb[ocY2[`;o<CRY00CoBD:WodU0Y?mKBjKoG4ZS0_mQC:801?mZDZ?oKU>RofiC
X_meF:83ogmOY0;oRfVV0onIMZT3oj^6[P03okjI/_oXcK_ognQo00koZKgX3?ooool00ol0003ooooo
ooooo`0?ooooo`03o`000?oooooooooo00gooooo0009ooooo`0400000?oooooooooooooooeH00000
1P0I6AT00`000000<c<c03<c<`0203<c<`040000001<C4`0C4a<04a<C08000000P1VIVH00ol00000
Ogmo07moO`02o`0000<0VIVI0ol0000<0;>c/`03o`00002IVIT0VIVI0080VIVI00Go000007moO`1o
Ogl0Ogmoo`00000306IVIP030000001<C4`0C4a<0080C4a<00D0000003<c<`0c<c<0<c<c00000007
01TI6@l000001?ooool00`00003oooooooooo`0?ooooo`;o00009Oooool00olWUnko]Y>cokJC/`04
okV8X003okR3V_o<WjSoaI2N00?oaI2N1?oGYZ@00ooAjXGoZKgXojVmj00EojVmj0?oZ;cX0_nV_>P0
0onT^^WoXk[Yoj>jj@02oinij`;oVKK/00?oSk?_oi2glOn@]o400_n3]OD2ofnbn@07odn/nOl?QNCo
3hGTo`0[[Ol:>[[o022[o`l/Z`02oc4hZ@03odU2Yom9@:CoBD2T00;oG4ZS0_mQC:82ofiCXP04ogEH
X_moGjCoOenTogmOY0;oRfVV0onIMZT3oj^6[P03olna^ooXcK_oZKgX00coZKgX3oooool00ol0003o
ooooooooo`0?ooooo`03o`000?oooooooooo00cooooo0009ooooo`0400000?oooooooooooooooeD0
00001P0I6AT00`000000<c<c03<c<`0203<c<`050000001<C4`0C4a<04a<C00000000P1VIVH2o`00
0080Ogmo00Co000009VIV@2IVIT0VIVI0_l000040;>c/`Oo00001@2c/k<00ol00000VIVI09VIV@02
09VIV@04o`00001oOgl0Ogmoo`0000<0IVIV00D0000004a<C01<C4`0C4a<0000000403<c<`030000
000I6AT06ATI00@06ATI40000004ooooo`0300000?oooooooooo017ooooo00?o0000ooooooooool0
8_ooool01?lWUnko]Y>cokJC/onfTk<3okV8X003okR3V_o<WjSoc9nX00?oaI2N0ooGYZ@00ooAjXGo
ZKgXojVmj00GojVmj003ojRlj?nW_>SoYkcX00;oY[_Y00?oXk[Yoj>kj_nS^nX00_nO^^`2oiVhkP03
oi2glOnC^o;oTk_b00;oRKcg0_mk_O`2ofJnoP;oAk[e0_l08:/01Ol?;:_o<CRYob`cYOm9@ZOoBD2T
00;oG4ZS0_mQC:801?mYDJ?oKU>RogEHX_meF:82ogmOY0;oRfVV0onIMZT3oj^6[P03olna^oobljOo
ZKgX00SoZKgX5?ooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo00cooooo0009oooo
o`0400000?oooooooooooooooe@000001@0I6AT2000000<0<c<c0P00000204a<C00300000?l00000
IVIV00;o00000P1oOgl2o`000080VIVI0_l000020;>c/`Co00001`3<c<`2o`0000@0/k>c00Go0000
09VIV@2IVIT0VIVIo`00000207moO`05o`00001VIVH0IVIV06IVIP0000000`1<C4`01@000000<c<c
03<c<`0c<c<0000000L06ATI00?o00000000000000003@000004ooooo`0300000?oooooooooo01;o
oooo00?o0000ooooooooool08_ooool00olWUnko]Y>cokJC/`03okV8X003okR3V_o<WjSoc9nX00;o
aI2N0_o]c[@00ooGYZCodNZ5ojVmj00GojVmj0?oZ;gX0_nW_>P3ojFlj@03oj>kj_nS_>_oWk_/00;o
Wk_/0_nJ^nl00onC^o;oVKoboiVolP02oi;2m`04oh_5nonHb?SoV<ShoiS8n0;oULgk00So022[o`l/
Zola>:Wo<CRYodU2Yom9@:CoCD:Toea:X`;oHDbR0_mYDJ<2ogEHXP?oOenT0_n;JJH3oiUfZ@03oj^6
[_o?/K_ock6k00GoZKgX6_ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00cooooo
0009ooooo`0400000?oooooooooooooooe<000001@0I6AT00`000000<c<c03<c<`0203<c<`030000
001<C4`0C4a<0080000000<0IVIVo`000?l000000P1oOgl2o`00000509VIVOl0003o0000o`00002c
/k<00ol0000<0<c<c003o`00002c/k<0/k>c0080/k>c00Go000009VIV@2IVIT0VIVIo`00000207mo
O`05o`00001VIVH0IVIV06IVIP0000000`1<C4`01@000000<c<c03<c<`0c<c<0000000H06ATI4@00
0004ooooo`0300000?oooooooooo01?ooooo00?o0000ooooooooool08Oooool00olWUnko]Y>cokJC
/`02okV8X005omWIf?o<WjSoc9nXolbOZ?o5T9h00oo]c[@00ooGYZCoooooojVmj00HojVmj0?oZ;gX
0_nW_>P3ojFlj@;oXkc[00?oWk_/oj6mkOnQ_Nd00_nM_^l00onI_o;oW/7aoik1l@03oi_4m00:oiS8
n?nQao?oXLOcoj7:mOnVa_3o022[o`l/Zola>:Wo;3>UodU0Y0;oCD:T00KoG4ZSof5<X_mYDJ?oJE6S
ogEKY_meF:83ogmOY0;oRfVV0_nIMZT01?ncU;Oock6kolna^oobljL3ojVmj1cooooo00?o0000oooo
ooooool03Oooool00ol0003oooooooooo`0<ooooo`002Oooool01000003ooooooooooooooomB0000
00D06ATI00<0000003<c<`0c<c<00P0c<c<010000000C4a<04a<C000000206IVIP05o`00001oOgl0
Ogmo07moOol000000P2IVIT00ol00000/k>c0;>c/`02o`0000H0c<c<1?l000060<c<c004o`00002c
/k<0/k>co`0000<0VIVI00Co000007moO`1oOgoo00000`1VIVH01@000000C4a<04a<C01<C4`00000
00<0<c<c00<0000001TI6@0I6AT0100I6ATB000000Cooooo00<00000ooooooooool05?ooool2o`00
02;ooooo0_nfTk<00oniR:3ofMWHomWIf003olbOZ004olF@W_o]c[CokLjdong>]0?ooooo6OnY_NP3
ojRmj0;oYkcY00?oYKcYojJmj_nV_NX00_nT_N/00onQ_NgoXkk/oj>nk002oj6okP04oik1lOnS`^oo
Xl;_oj?2k`;oX/Ca00SoXLOcojK4konVa>ooY/K`ojS2k?l01iWo01nUob`cY@;oBD2T0_m=@Z@2of5<
XP03ofUAXomeFjKoME^V00?oOenT0_n;JJH01_nIMZWo/iBgok>D]oncU;Oock6koo;cYb3ooooo00?o
0000ooooooooool03?ooool00ol0003oooooooooo`0<ooooo`002Oooool01000003ooooooooooooo
oom?00000003o`00000000006ATI00@06ATI00<0000003<c<`0c<c<00P0c<c<010000000C4a<04a<
C000000206IVIP06o`00001oOgl0Ogmo07moOol00000VIVI0_l000020;>c/`03o`00003<c<`0c<c<
0080c<c<1?l000040>KViP03o`00003<c<`0c<c<00<0c<c<00Co00000;>c/`2c/k?o00000`2IVIT0
1?l00000Ogmo07moOol0000206IVIP05o`00001<C4`0C4a<04a<C?l000000`0c<c<00`0000006ATI
01TI6@0401TI6A<000001?ooool00`00003oooooooooo`0Fooooo`03o`000?oooooooooo02?ooooo
0_oIfMP2olbOZ0;ooooo00?okLjdooooooooool00ooooolIojVmj0?oZ;gX0_nW_NT3ojJmjP;oYKg[
00CoXkk/ojFok?nU_ncoYKo/0_nT`>d00onS`^ooY/7]ojK1k@02ojK3kP09ojK4konX`^coZ<;/ojS2
k?nY`>[o01nUob`cYOl[<jKoBD2T00;oCD:T0_mQC:800omYDJ?oME^VogEKYP03ohEYZ`03oh]YY_nJ
Nk3o/iBg00?o/iBg00?ok>C8ooooooooool08?ooool00ol0003oooooooooo`0;ooooo`03o`000?oo
oooooooo00cooooo0009ooooo`0400000?ooooooooooooooodl000001P0I6AT00`000000<c<c03<c
<`0203<c<`04o`00001<C4`0C4a<o`0000<0IVIV00Ko000007moO`1oOgoo000009VIVOl000030;>c
/`04o`00003<c<`0c<c<0<c<c0;o0000203Vi^H00ol00000c<c<0<c<c0030<c<c004o`00002c/k<0
/k>co`0000<0VIVI00?o000007moOol000000`1VIVH010000000C4a<04a<C000000403<c<`030000
000I6AT06ATI00@06ATI4`000004ooooo`0300000?oooooooooo01Oooooo00?o0000ooooooooool0
9?ooool00oo<WjSoooooooooo`08oooooaOoZKgX1_nX_NP2ojNmj@03ojJmj_nW_NWoYkgY00;oY[k[
00?oYKo/ojNojonW_n/00_nV`>`00onV`NgoZ<3[ojS0j`02ojS1k008ojS2k?nY`>[oZL3ZojW0j_nY
_^Wo01RRob`cYOm9@:@2ode2Y004oeI9YomQC:;oJE6SofUAX`;oME^V0_n5JJ/2oiYk/0Co/iBg00?o
k>C8ooooooooool08Oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00cooooo0009
ooooo`0400000?ooooooooooooooodh000001P0I6AT00`000000<c<c03<c<`0203<c<`040000001<
C4`0C4a<000000<0IVIV00Ko000007moO`1oOgoo000009VIVOl000030;>c/`03o`00003<c<`0c<c<
00;o00002P3Vi^H00ol00000c<c<0<c<c0020<c<c004o`00002c/k<0/k>co`0000<0VIVI00Co0000
07moO`1oOgoo00000P1VIVH01@000000C4a<04a<C01<C4`0000000<0<c<c00<0000001TI6@0I6AT0
100I6ATD000000Cooooo00<00000ooooooooool06?ooool00ol0003oooooooooo`0_oooooaOoZKgX
00?oZ;gXojVmj?nY_NP00_nX_NP3ojRmj@03ojNmjOnX_^WoYkkZ00;oYkkZ00?oYko[ojRnj_nX_^X0
0_nX_nX00onX`>_oZKoYojVoj@02ojVojP07ojW0j_nY_^WoZKkYojVnjOl07jGo;3>Uob/cYP02ode2
Y0;oETVW0_mYDJ<2ogEKYP;oQFV[0onJNk02ok>D]`03oncTb?oooooooooo02;ooooo00?o0000oooo
ooooool02oooool00ol0003oooooooooo`0;ooooo`002Oooool01000003ooooooooooooooom=0000
00H06ATI00<0000003<c<`0c<c<00P0c<c<010000000C4a<04a<C000000306IVIP06o`00001oOgl0
Ogmoo`00002IVIWo00000`2c/k<01?l00000c<c<0<c<c?l0000<0>KViP03o`00003<c<`0c<c<0080
c<c<00Co00000;>c/`2c/k?o00000P2IVIT2o`00000507moOol00000IVIV06IVIP0000000`1<C4`0
10000000<c<c03<c<`0c<c<2000000D06ATI00?o00000000000000004P000004ooooo`0300000?oo
oooooooo01Wooooo0_l0000`oooooa[oZKgX0_nX_NP3ojRmj@;oZ;kY00CoYkkZojRnjOnX_^WoZ;kZ
1?nY_^T00onY_nWoZKkYojVnj@03ojVnj@?oZKkX00?o01RRob/cY_l`>Z/00_m=@Z@00omFBJOoI5J/
ofUAX`02ogEKYP?oQFV[0_nJNk000oncU;Ook>C8oncTb00Uooooo`03o`000?oooooooooo00[ooooo
00?o0000ooooooooool02oooool000Wooooo00@00000ooooooooooooooooB`0000000ol000006ATI
01TI6@0401TI6@06o`00000c<c<0<c<c03<c<ol0000000000P1<C4`00`000000IVIV06IVIP02o`00
0080Ogmo00Co000009VIV@2IVIWo00000P2c/k<01Ol00000c<c<0<c<c03<c<co000000`0i^KV00Go
00000<c<c03<c<`0c<c<o`0000020;>c/`04o`00002IVIT0VIVIo`000080Ogmo00Co000006IVIP1V
IVKo00000`1<C4`01Ol00000<c<c03<c<`0c<c<0000000L06ATI5@000004ooooo`0300000?oooooo
oooo01_ooooo00?o0000ooooooooool0;_oooolLojVmj003ojRmjOnY_NSoZKgX00?oZ;kY2?nY_^T5
ojVnj0;oZKgX00Ko01RRo`0FY?l[<jKo<3Z[ode2Y?mFBJL2ofAF[0?oME^V0_n5JJ/2oiYk/0;oaKS=
9oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00_ooooo0009ooooo`0400000?oo
oooooooooooood`000001P0I6AT01@000000<c<c03<c<`0c<c<0000000<0C4a<00@0000006IVIP1V
IVKo00000P1oOgl01?l00000VIVI09VIVOl000020;>c/`05o`00003<c<`0c<c<0<c<c?l00000303V
i^H01Ol00000c<c<0<c<c03<c<co000000<0/k>c00?o000009VIVOl000000`1oOgl00ol00000IVIV
0000000304a<C0050000000c<c<0<c<c03<c<`0000001`0I6ATF000000Cooooo00<00000oooooooo
ool07?ooool00ol0003oooooooooo`0^oooooaooZKgX0_nY_^P00onY_^WoZKkXojVnj002ojVnj003
ojVnjOnY_^SoZKkX00?oZKkX0onY_NP2ooooo`04o`0HX_l05ZCo<3Z[oc0jZ`;oETVW00CoI5J/ogY[
]_mjJkKoNV^f0_n5JJ/01?nJNk3oaKS=olFhcOo5^<dXooooo`03o`000?oooooooooo00Sooooo00?o
0000ooooooooool02oooool000Wooooo00@00000ooooooooooooooooB`00000601TI6@050000000c
<c<0<c<c03<c<`0000000`1<C4`010000000IVIV06IVI_l0000207moO`04o`00002IVIT0VIVIo`00
0080/k>c00Go00000<c<c03<c<`0c<c<o`00000<0>KViP05o`00003<c<`0c<c<0<c<c?l000000`2c
/k<00ol00000VIVIo`00000207moO`;o000000<0IVIV0000001<C4`00P1<C4`01@000000<c<c03<c
<`0c<c?o000000L06ATI5`000004ooooo`0300000?oooooooooo01gooooo00?o0000ooooooooool0
;_oooolQojVmj003ojVnj?nY_NSoZKgX00;oZKgX00?oZKkXojVmj?nY_NP00onY_NP5ooooo`;o01JT
00?o<3Z[oca;^?mFBJL00_mTEZ`2ogY[]P;oVX_20oo5^<dYooooo`03o`000?oooooooooo00Sooooo
00?o0000ooooooooool02oooool000Wooooo00@00000ooooooooooooooooB00000000ol000000000
01TI6@0401TI6@03o`0000000000<c<c0080<c<c00D0000004a<C01<C4`0C4a<0000000206IVIP04
o`00001oOgl0Ogmoo`000080VIVI00Co00000;>c/`2c/k?o00000`3<c<`00ol00000i^KV0>KViP09
0>KViP;o00000P3<c<`2o`0000060;>c/ol0003o0000o`00002IVIWo00000P1oOgl01?l00000IVIV
06IVIP00000304a<C0050000000c<c<0<c<c03<c<`0000001P0I6AT00`00003o00000000000F0000
00Cooooo00<00000ooooooooool07_ooool2o`0002oooooo9onY_NP;ooooo`03oc0jZollBkSo?4^h
00;oI5J/0omjJkH2oiZ;`P03olFhcOoooooooooo02Wooooo00?o0000ooooooooool01oooool00ol0
003oooooooooo`0;ooooo`002Oooool01000003ooooooooooooooom9000000H06ATI00D0000003<c
<`0c<c<0<c<co`00000304a<C0040000001VIVH0IVIVo`000080Ogmo00Go000009VIV@2IVIT0VIVI
o`0000020;>c/`03o`00003<c<`0c<c<0080c<c<00?o00000>KViP3Vi^H01`3Vi^H01Ol00000c<c<
0<c<c03<c<co00000080/k>c00Go000009VIV@2IVIT0VIVIo`00000207moO`05o`00001VIVH0IVIV
06IVIP0000000P1<C4`00`000000<c<c03<c<`0203<c<`030000000I6AT06ATI00@06ATI6@000004
ooooo`0300000?oooooooooo023ooooo00?o0000ooooooooool0;OoooolRojVmj13ooooo00Co<3Z[
oca;^?mGL=3oEg3@0omjJkH00onJRl;o_?gGooooo`0/ooooo`03o`000?oooooooooo00Oooooo00?o
0000ooooooooool02_ooool000Wooooo00@00000ooooooooooooooooB000000601TI6@030000000c
<c<0<c<c0080<c<c00@0000004a<C01<C4`000000`1VIVH01?l00000Ogmo07moOol0000209VIV@05
o`00002c/k<0/k>c0;>c/ol000001@3<c<`00ol00000i^KV0>KViP040>KViP;o00000P3<c<`2o`00
0080/k>c00?o000009VIV@2IVIT00_l0000207moO`03o`00001VIVH0IVIV008000000P1<C4`00`00
0000<c<c03<c<`0203<c<`030000000I6AT06ATI00@06ATI6P000004ooooo`0300000?oooooooooo
027ooooo00?o0000ooooooooool0;_oooolNojVmj1?ooooo0_llBkP2oeM`d003ogY[]_n>^oGoS[_e
02oooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`0:ooooo`002Oooool01000003o
oooooooooooooom8000000H06ATI00D0000003<c<`0c<c<0<c<c0000000304a<C0040000001VIVH0
IVIVo`000080Ogmo00Go000009VIV@2IVIT0VIVIo`0000020;>c/`03o`00003<c<`0c<c<00D0c<c<
1_l000030<c<c005o`00002c/k<0/k>c0;>c/ol000000P2IVIT01Ol00000Ogmo07moO`1oOgoo0000
0080IVIV00D0000004a<C01<C4`0C4a<0000000303<c<`8000001P0I6AT00ol0000000000000000H
000000Cooooo00<00000ooooooooool08_ooool00ol0003oooooooooo`0^oooooaWoZKgX6Oooool3
oeM`d003ohjkmOoooooooooo02kooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`0:
ooooo`002Oooool01000003ooooooooooooooom7000000H06ATI00<0000003<c<`0c<c<00P0c<c<0
10000000C4a<04a<C000000306IVIP04o`00001oOgl0Ogmoo`000080VIVI00Go00000;>c/`2c/k<0
/k>co`00000=0<c<c0?o00000`2c/k<01Ol00000VIVI09VIVOl00000Ogmo00?o000000<0IVIV0000
0?l000000`1<C4`01Ol00000<c<c03<c<`0c<c<0000000H06ATI7@000004ooooo`0300000?oooooo
oooo02?ooooo00?o0000ooooooooool0;_oooolDojVmj5;ooooo00?o0000ooooooooool01Oooool0
0ol0003oooooooooo`0:ooooo`002Oooool01000003ooooooooooooooom500000003o`00000I6AT0
6ATI00@06ATI00?o000003<c<`0c<c<00`0c<c<010000000C4a<04a<C000000306IVIP04o`00001o
Ogl0Ogmoo`000080VIVI00Go00000;>c/`2c/k<0/k>co`00000<0<c<c004o`00002c/k<0/k>c0;>c
/`?o000000D0VIVIo`000?l00000Ogmoo`00000306IVIP040000001<C4`0C4a<04a<C08000000`0c
<c<00`0000006ATI01TI6@0401TI6Ah000001?ooool00`00003oooooooooo`0Tooooo`;o0000;ooo
ool@ojVmj5Kooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`0:ooooo`002Oooool0
1000003ooooooooooooooom6000000H06ATI00<0000003<c<`0c<c<00P0c<c<010000000C4a<04a<
C000000306IVIP05o`00001oOgl0Ogmo07moOol000000`2IVIT01?l00000/k>c0;>c/`2c/k<3o`00
00H0c<c<0ol00000102c/k?o0000o`000?l0000309VIV@04o`00001oOgl0Ogmoo`0000<0IVIV00<0
000004a<C01<C4`00P00000303<c<`8000001@0I6ATP000000Cooooo00<00000ooooooooool09_oo
ool00ol0003oooooooooo`0]ooooo`goZKgXF?ooool00ol0003oooooooooo`04ooooo`03o`000?oo
oooooooo00[ooooo0009ooooo`0400000?ooooooooooooooodD000001P0I6AT00`000000<c<c03<c
<`0203<c<`050000001<C4`0C4a<04a<C00000000`1VIVH01Ol00000Ogmo07moO`1oOgoo000000<0
VIVI00?o00000;>c/`2c/k<0102c/k<6o`0000<0/k>c00Co000009VIV@2IVIT0VIVI0ol00000101o
Ogoo0000o`00001VIVH200000004o`00001<C4`00000000000@0<c<c00?o000001TI6@0I6AT0100I
6ATQ000000Cooooo00<00000ooooooooool09oooool00ol0003oooooooooo`0]ooooo`SoZKgXGOoo
ool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00[ooooo0009ooooo`0400000?oooooo
ooooooooodD000001P0I6AT00`000000<c<c03<c<`0203<c<`050000001<C4`0C4a<04a<C0000000
0`1VIVH01Ol00000Ogmo07moO`1oOgoo000000<0VIVI00?o00000;>c/`2c/k<02P2c/k<3o`000004
09VIVOl0003o0000o`0000<0Ogmo00Co000006IVIP1VIVH000000`1<C4`00`000000<c<c03<c<`02
03<c<`8000001`0I6ATQ000000Cooooo00<00000ooooooooool0:?ooool00ol0003oooooooooo`0]
ooooo`?oZKgXH_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Wooooo0009oooo
o`0400000?oooooooooooooood@000001`0I6AT00`000000<c<c03<c<`0203<c<`050000001<C4`0
C4a<04a<C00000000`1VIVH00ol00000Ogmo07moO`0207moO`04o`00002IVIT0VIVI09VIV@co0000
0`2IVIT01?l00000Ogmo07moO`1oOgl3o`00000306IVIP00000000000080C4a<0P00000403<c<`03
0000000I6AT06ATI00D06ATI8`000004ooooo`0300000?oooooooooo02Wooooo0_l0000]ooooo`03
o`000?oooooooooo06?ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`09ooooo`00
2Oooool01000003ooooooooooooooom4000000H06ATI00<0000003<c<`0c<c<00`0c<c<01@000000
C4a<04a<C01<C4`0000000<0IVIV00?o000007moO`1oOgl00P1oOgl00ol00000VIVI09VIV@0>09VI
V@;o00000P1oOgl2o`0000<0IVIV00D0000004a<C01<C4`0C4a<0000000503<c<`030000000I6AT0
6ATI00D06ATI90000004ooooo`0300000?oooooooooo02_ooooo00?o0000ooooooooool0:_ooool0
0ol0003oooooooooo`1Sooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool02Oooool0
00Wooooo00@00000oooooooooooooooo@`00000701TI6@030000000c<c<0<c<c0080<c<c00<00000
04a<C01<C4`00P1<C4`01@000000IVIV06IVIP1VIVKo000000D0Ogmo0ol0000909VIV@Co00000P1o
Ogl2o`000080IVIV0`000000101<C4`0000000000?l0000403<c<`8000001@0I6AT200000003o`00
000000000000028000001?ooool00`00003oooooooooo`0/ooooo`03o`000?oooooooooo02Wooooo
00?o0000ooooooooool0I?ooool01Ol0003ooooooooooooooooo000000_ooooo0009ooooo`040000
0?oooooooooooooood80000000?o000001TI6@0I6AT01@0I6AT00`000000<c<c03<c<`0203<c<`03
0000001<C4`0C4a<0080C4a<00<0000006IVIP1VIVH00P1VIVH00ol00000Ogmo07moO`0507moO`Wo
00000`1oOgl3o`00000406IVIP0000000000000000<0C4a<00<0000003<c<`0c<c<0100c<c<00`00
00006ATI01TI6@0401TI6BP000001?ooool00`00003oooooooooo`0]ooooo`03o`000?oooooooooo
02Sooooo00?o0000ooooooooool0IOooool01?l0003oooooooooool0000;ooooo`002Oooool01000
003ooooooooooooooom3000000L06ATI00<0000003<c<`0c<c<00`0c<c<00`000000C4a<04a<C002
04a<C0030000001VIVH0IVIV0080IVIV0ol0000=07moO`?o00000`1VIVH00`000000C4a<04a<C002
04a<C08000001@0c<c<2000000D06ATI:P000004ooooo`0300000?oooooooooo02kooooo0_l0000X
ooooo`03o`000?oooooooooo06Kooooo00?o0000ooooool000002oooool000Wooooo00@00000oooo
oooooooooooo@P00000801TI6@030000000c<c<0<c<c00<0<c<c00?o000004a<C01<C4`00`1<C4`0
0`000000IVIV06IVIP0406IVIPgo00000`1VIVH200000004o`00001<C4`0C4a<04a<C08000000`0c
<c<200000003o`00000000006ATI00@06ATI;0000004ooooo`0300000?oooooooooo033ooooo00?o
0000ooooooooool09Oooool00ol0003oooooooooo`1Vooooo`03o`000?oooooo000000_ooooo0009
ooooo`0400000?oooooooooooooood800000200I6AT00`000000<c<c03<c<`0303<c<`030000001<
C4`0C4a<00<0C4a<00?o00000000000000004@1VIVH3000000@0C4a<0P00000403<c<`030000000I
6AT06ATI00H06ATI;@000004ooooo`0300000?oooooooooo037ooooo00?o0000ooooooooool09?oo
ool00ol0003oooooooooo`1Wooooo`03o`000?oooooo000000[ooooo0009ooooo`0400000?oooooo
oooooooood800000200I6AT00`000000<c<c03<c<`0403<c<`030000001<C4`0C4a<00D0C4a<1000
000906IVIP@000000`1<C4`4000000@0<c<c0P00000801TI6Bh000001?ooool00`00003ooooooooo
o`0booooo`03o`000?oooooooooo02?ooooo00?o0000ooooooooool0J?ooool2o`0000[ooooo0009
ooooo`0400000?oooooooooooooood8000002@0I6AT00`000000<c<c03<c<`0403<c<`030000001<
C4`0C4a<00P0C4a<2@00000504a<C003o`0000000000<c<c00H0<c<c00<0000001TI6@0I6AT01`0I
6AT_000000Cooooo00<00000ooooooooool0<oooool2o`0002?ooooo00?o0000ooooooooool0Iooo
ool3o`0000[ooooo0009ooooo`0400000?oooooooooooooood8000002@0I6AT00`000000<c<c03<c
<`0503<c<`<00000401<C4`5000000H0<c<c0P0000000ol000006ATI01TI6@0501TI6@80000000?o
0000000000000000;@000004ooooo`0300000?oooooooooo03Gooooo00?o0000ooooooooool08?oo
ool00ol0003oooooooooo`1Sooooo`Co00003Oooool000Wooooo00@00000oooooooooooooooo@P00
000901TI6@030000000c<c<0<c<c00P0<c<c0`00000:04a<C0<000001`0c<c<4000000L06ATI=@00
0004ooooo`0300000?oooooooooo03Kooooo00?o0000ooooooooool07oooool00ol0003ooooooooo
o`1Pooooo`?o00004Oooool000Wooooo00@00000oooooooooooooooo@`00000901TI6@8000002`0c
<c<:000000L0<c<c0`00000:01TI6CH000001?ooool00`00003oooooooooo`0gooooo`03o`000?oo
oooooooo01kooooo00?o0000ooooooooool0G?ooool4o`0001Cooooo0009ooooo`0400000?oooooo
oooooooood<000002`0I6AT2000001H0<c<c0`0000000ol000006ATI01TI6@0801TI6@80000000?o
0000000000000000=0000004ooooo`0300000?oooooooooo03Sooooo0_l0000Nooooo`03o`000?oo
oooooooo05Sooooo1?l0000Hooooo`002Oooool01000003ooooooooooooooom3000000d06ATI0`00
000@03<c<`<000002`0I6ATl000000Cooooo00<00000ooooooooool0>_ooool00ol0003ooooooooo
o`0Kooooo`03o`000?oooooooooo05Cooooo1?l0000Looooo`002Oooool01000003ooooooooooooo
oom4000000l06ATI0`00000603<c<`L000003@0I6ATm000000Cooooo00<00000ooooooooool0>ooo
ool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo057ooooo0ol0000Pooooo`002Oooool0
1000003ooooooooooooooom4000001806ATI1P00000B01TI6Cl000001?ooool00`00003ooooooooo
o`0looooo`03o`000?oooooooooo01Wooooo00?o0000ooooooooool0COooool4o`0002?ooooo0009
ooooo`0400000?ooooooooooooooodD000009@0I6AU3000000Cooooo00<00000ooooooooool0?Ooo
ool2o`0001Wooooo00?o0000ooooooooool0BOooool4o`0002Oooooo0009ooooo`0400000?oooooo
ooooooooodD0000000?o00000000000I6AT07P0I6AU7000000Cooooo00<00000ooooooooool0?ooo
ool00ol0003oooooooooo`0Fooooo`03o`000?oooooooooo04Gooooo1?l0000[ooooo`002Oooool0
1000003ooooooooooooooom9000001X06ATIBP000004ooooo`0300000?oooooooooo043ooooo00?o
0000ooooooooool05?ooool00ol0003oooooooooo`13ooooo`?o0000;oooool000Wooooo00@00000
ooooooooooooooooC000000C01TI6Dh000001?ooool00`00003oooooooooo`11ooooo`03o`000?oo
oooooooo01?ooooo00?o0000ooooooooool0?oooool4o`0003;ooooo0009ooooo`0400000?oooooo
oooooooooe<000001@0I6AUE000000Cooooo00<00000ooooooooool0@_ooool2o`0001?ooooo00?o
0000ooooooooool0>oooool4o`0003Kooooo0009ooooo`0400000?ooooooooooooooojd000001?oo
ool00`00003oooooooooo`14ooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool0=ooo
ool4o`0003[ooooo0009ooooo`0400000?ooooooooooooooojd000001?ooool00`00003ooooooooo
o`15ooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool0<oooool4o`0003kooooo0009
ooooo`0400000?ooooooooooooooojd000001?ooool00`00003oooooooooo`16ooooo`03o`000?oo
oooooooo00kooooo00?o0000ooooooooool0<?ooool3o`0004;ooooo0009ooooo`0400000?oooooo
ooooooooojd000001?ooool00`00003oooooooooo`17ooooo`03o`000?oooooooooo00gooooo00?o
0000ooooooooool0;?ooool4o`0004Gooooo0009ooooo`0400000?ooooooooooooooojd000001?oo
ool00`00003oooooooooo`18ooooo`;o00003Oooool00ol0003oooooooooo`0Xooooo`Co0000BOoo
ool000Wooooo00@00000oooooooooooooooo[@000004ooooo`0300000?oooooooooo04[ooooo00?o
0000ooooooooool02_ooool00ol0003oooooooooo`0Tooooo`Co0000COooool000Wooooo00@00000
oooooooooooooooo[@000004ooooo`0300000?oooooooooo04_ooooo00?o0000ooooooooool02Ooo
ool00ol0003oooooooooo`0Qooooo`?o0000DOooool000Wooooo00@00000oooooooooooooooo[@00
0004ooooo`0300000?oooooooooo04cooooo00?o0000ooooooooool02?ooool00ol0003ooooooooo
o`0Mooooo`Co0000E?ooool000Wooooo00@00000oooooooooooooooo[@000004ooooo`0300000?oo
oooooooo04gooooo0_l00008ooooo`03o`000?oooooooooo01Wooooo1?l0001Hooooo`002Oooool0
1000003ooooooooooooooon]000000Cooooo00<00000ooooooooool0Coooool00ol0003ooooooooo
o`05ooooo`03o`000?oooooooooo01Gooooo1?l0001Looooo`002Oooool01000003ooooooooooooo
oon]000000Cooooo00<00000ooooooooool0D?ooool00ol0003oooooooooo`04ooooo`03o`000?oo
oooooooo01;ooooo0ol0001Pooooo`002Oooool01000003ooooooooooooooon]000000Cooooo00<0
0000ooooooooool0DOooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00kooooo1?l0
001Sooooo`002Oooool01000003ooooooooooooooon]000000Cooooo00<00000ooooooooool0D_oo
ool2o`0000?ooooo00?o0000ooooooooool02_ooool4o`0006Oooooo0009ooooo`0400000?oooooo
ooooooooojd000001?ooool00`00003oooooooooo`1Dooooo`04o`000?ooooooooooo`0000Sooooo
1?l0001[ooooo`002Oooool01000003ooooooooooooooon]000000Cooooo00<00000ooooooooool0
EOooool00ol0003oooooo`000005ooooo`?o0000Koooool000Wooooo00@00000oooooooooooooooo
[@000004ooooo`0300000?oooooooooo05Kooooo0_l000000ooooooo0000o`000002o`0007;ooooo
0009ooooo`0400000?ooooooooooooooojd000001?ooool00`00003oooooooooo`1Gooooo`;o0000
M_ooool000Wooooo00@00000oooooooooooooooo[@000004ooooo`0300000?oooooooooo0<oooooo
0009ooooo`0400000?ooooooooooooooojd000001?ooool00`00003oooooooooo`3?ooooo`002Ooo
ool01000003ooooooooooooooon]000000Cooooo00<00000ooooooooool0coooool000Wooooo00@0
0000oooooooooooooooo[@000004ooooo`0300000?oooooooooo0<oooooo0009ooooo`0400000?oo
ooooooooooooojd000001?ooool00`00003oooooooooo`3?ooooo`002Oooool01000003ooooooooo
oooooon]000000Cooooo00<00000ooooooooool0coooool000Wooooo00@00000oooooooooooooooo
[@000004ooooo`0300000?oooooooooo0<oooooo0009ooooo`0400000?ooooooooooooooojd00000
1?ooool00`00003oooooooooo`3?ooooo`002Oooool01000003ooooooooooooooon]000000Cooooo
00<00000ooooooooool0coooool000Wooooo00@00000oooooooooooooooo[@000004ooooo`030000
0?oooooooooo0<oooooo0009ooooo`0400000?ooooooooooooooojd000001?ooool00`00003ooooo
ooooo`3?ooooo`002Oooool01000003ooooooooooooooon]000000Cooooo00<00000ooooooooool0
coooool000Wooooo00@00000oooooooooooooooo[@000004ooooo`0300000?oooooooooo0<oooooo
0009ooooo`0300000?oooooooooo0;;ooooo00<00000ooooooooool0coooool000Wooooo00<00000
ooooooooool0/_ooool00`00003oooooooooo`3?ooooo`002Oooool00`00003oooooooooo`2boooo
o`0300000?oooooooooo0<oooooo0009oooookH00000dOooool00?ooooooTOooool00?ooooooTOoo
ool00?ooooooTOooool00?ooooooTOooool00?ooooooTOooool00?ooooooTOooool00?ooooooTOoo
ool00?ooooooTOooool00?ooooooTOooool00?ooooooTOooool00?ooooooTOooool00?ooooooTOoo
ool00?ooooooTOooool00?ooooooTOooool00?ooooooTOooool00?ooooooTOooool00?ooooooTOoo
ool000Wooooo]_l0000AoooookKo00002_ooool000Wooooo00?o0000ooooooooool0/_ooool00ol0
003oooooooooo`0?ooooo`03o`000?oooooooooo0;;ooooo00?o0000ooooooooool02?ooool000Wo
oooo00?o0000ooooooooool0/_ooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo0;;o
oooo00?o0000ooooooooool02?ooool000Wooooo00?o0000ooooooooool0/_ooool00ol0003ooooo
ooooo`0?ooooo`03o`000?oooooooooo0;;ooooo00?o0000ooooooooool02?ooool000Wooooo00?o
0000ooooooooool0/_ooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo0;;ooooo00?o
0000ooooooooool02?ooool000Wooooo00?o0000ooooooooool0/_ooool00ol0003oooooooooo`0?
ooooo`03o`000?oooooooooo0;;ooooo00?o0000ooooooooool02?ooool000Wooooo00?o0000oooo
ooooool0/_ooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo0;;ooooo00?o0000oooo
ooooool02?ooool000Wooooo00?o0000ooooooooool0/_ooool00ol0003oooooooooo`0?ooooo`03
o`000?oooooooooo0;;ooooo00?o0000ooooooooool02?ooool000Wooooo00?o0000ooooooooool0
/_ooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo0;;ooooo00?o0000ooooooooool0
2?ooool000Wooooo00?o0000ooooooooool0/_ooool00ol0003oooooooooo`0?ooooo`03o`000?oo
oooooooo0;;ooooo00?o0000ooooooooool02?ooool000Wooooo00?o0000ooooooooool0/_ooool0
0ol0003oooooooooo`0?ooooo`03o`000?oooooooooo0;;ooooo00?o0000ooooooooool02?ooool0
00Wooooo00?o0000ooooooooool0/_ooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo
0;;ooooo00?o0000ooooooooool02?ooool000Wooooo00?o0000ooooooooool0/_ooool00ol0003o
ooooooooo`0?ooooo`03o`000?oooooooooo0;;ooooo00?o0000ooooooooool02?ooool000Wooooo
00?o0000ooooooooool0/_ooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo0;;ooooo
00?o0000ooooooooool02?ooool000Wooooo00?o0000ooooooooool0/_ooool00ol0003ooooooooo
o`0?ooooo`03o`000?oooooooooo0;;ooooo00?o0000ooooooooool02?ooool000Wooooo00?o0000
ooooooooool0/_ooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo0;;ooooo00?o0000
ooooooooool02?ooool000Wooooo00?o0000ooooooooool0/_ooool00ol0003oooooooooo`0?oooo
o`03o`000?oooooooooo0;;ooooo00?o0000ooooooooool02?ooool000Wooooo00?o0000oooooooo
ool0/_ooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo0;;ooooo00?o0000oooooooo
ool02?ooool000Wooooo00?o0000ooooooooool0/_ooool00ol0003oooooooooo`0?ooooo`03o`00
0?oooooooooo0;;ooooo00?o0000ooooooooool02?ooool000Wooooo00?o0000ooooooooool0/_oo
ool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo0;;ooooo00?o0000ooooooooool02?oo
ool000Wooooo00?o0000ooooooooool0/_ooool00ol0003oooooooooo`0?ooooo`03o`000?oooooo
oooo0;;ooooo00?o0000ooooooooool02?ooool000Wooooo00?o0000ooooooooool0/_ooool00ol0
003oooooooooo`0?ooooo`03o`000?oooooooooo0;;ooooo00?o0000ooooooooool02?ooool000Wo
oooo00?o0000ooooooooool0/_ooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo0;;o
oooo00?o0000ooooooooool02?ooool000Wooooo00?o0000ooooooooool00oooool20?mo00_ooooo
0P3oO`2Pooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool00oooool20?mo00_ooooo
0P3oO`2Pooooo`03o`000?oooooooooo00Sooooo0009ooooo`03o`000?oooooooooo00;ooooo0`3o
O`0;ooooo`80ogl03?ooool20?mo09;ooooo00?o0000ooooooooool03oooool00ol0003ooooooooo
o`02ooooo`<0ogl02oooool20?mo00cooooo0P3oO`2Booooo`03o`000?oooooooooo00Sooooo0009
ooooo`03o`000?oooooooooo00;ooooo0P3oO`0Jooooo`80ogl0T_ooool00ol0003oooooooooo`0?
ooooo`03o`000?oooooooooo00;ooooo0P3oO`0Jooooo`80ogl0T_ooool00ol0003oooooooooo`08
ooooo`002Oooool00ol0003oooooooooo`2booooo`03o`000?oooooooooo00oooooo00?o0000oooo
ooooool0/_ooool00ol0003oooooooooo`08ooooo`002Oooool00ol0003oooooooooo`2booooo`03
o`000?oooooooooo00oooooo00?o0000ooooooooool0/_ooool00ol0003oooooooooo`08ooooo`00
2Oooool00ol0003oooooooooo`2booooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool0
/_ooool00ol0003oooooooooo`08ooooo`002Oooool00ol0003oooooooooo`2booooo`03o`000?oo
oooooooo00oooooo00?o0000ooooooooool0/_ooool00ol0003oooooooooo`08ooooo`002Oooool0
0ol0003oooooooooo`2booooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool0/_ooool0
0ol0003oooooooooo`08ooooo`002Oooool00ol0003oooooooooo`0Iooooo`So003oTOooool00ol0
003oooooooooo`0?ooooo`03o`000?oooooooooo0;;ooooo00?o0000ooooooooool02?ooool000Wo
oooo00?o0000ooooooooool06?ooool00ol00?ooooooooooo`06ooooo`?o003oS_ooool00ol0003o
ooooooooo`0?ooooo`03o`000?oooooooooo0;;ooooo00?o0000ooooooooool02?ooool000Wooooo
00?o0000ooooooooool05oooool00ol00?ooooooooooo`0:ooooo`?o003oRoooool00ol0003ooooo
ooooo`0?ooooo`03o`000?oooooooooo0;;ooooo00?o0000ooooooooool02?ooool000Wooooo00?o
0000ooooooooool05_ooool00ol00?l0ogl0ooooo`04ooooo`80ogl02?ooool00ol00?oooooooooo
o`28ooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool05_ooool20?mo00Gooooo0P3o
O`2Cooooo`03o`000?oooooooooo00Sooooo0009ooooo`03o`000?oooooooooo01Kooooo00?o003o
0?mo0?ooool01?ooool20?mo00Wooooo0_l00?n8ooooo`03o`000?oooooooooo00oooooo00?o0000
ooooooooool05_ooool20?mo00Gooooo0P3oO`2Cooooo`03o`000?oooooooooo00Sooooo0009oooo
o`03o`000?oooooooooo01Oooooo00?o003oooooooooool04?ooool3o`00ohGooooo00?o0000oooo
ooooool03oooool00ol0003oooooooooo`2booooo`03o`000?oooooooooo00Sooooo0009ooooo`03
o`000?oooooooooo01Oooooo00?o003oooooooooool04oooool00ol00?ooooooooooo`22ooooo`03
o`000?oooooooooo00oooooo00?o0000ooooooooool0/_ooool00ol0003oooooooooo`08ooooo`00
2Oooool00ol0003oooooooooo`0Gooooo`03o`00oooooooooooo00;ooooo0P3oO`06ooooo`80ogl0
2?ooool00ol00?ooooooooooo`020?mo00?ooooo0P3oO`1jooooo`03o`000?oooooooooo00oooooo
00?o0000ooooooooool07?ooool20?mo00Kooooo0P3oO`0;ooooo`80ogl00oooool20?mo07[ooooo
00?o0000ooooooooool02?ooool000Wooooo00?o0000ooooooooool06?ooool01?l00?oooooooooo
ooooool20?mo00Kooooo0P3oO`09ooooo`?o003o00@0ogl0oooooooooooooooo0P3oO`1jooooo`03
o`000?oooooooooo00oooooo00?o0000ooooooooool07?ooool20?mo00Kooooo0P3oO`0;ooooo`80
ogl00oooool20?mo07[ooooo00?o0000ooooooooool02?ooool000Wooooo00?o0000ooooooooool0
6?ooool00ol00?ooooooooooo`0Gooooo`;o003o0oooool20?mo07Wooooo00?o0000ooooooooool0
3oooool00ol0003oooooooooo`0gooooo`80ogl0NOooool00ol0003oooooooooo`08ooooo`002Ooo
ool00ol0003oooooooooo`0Iooooo`03o`00oooooooooooo01Oooooo00@0ogl0o`00oooooooooooo
0P3oO`1iooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool0<oooool20?mo00;ooooo
0P3oO`1iooooo`03o`000?oooooooooo00Sooooo0009ooooo`03o`000?oooooooooo01[ooooo0_l0
0?l<ooooo`<000002?ooool20?mo0003o`00oooooooooooo07[ooooo00?o0000ooooooooool03ooo
ool00ol0003oooooooooo`0cooooo`80ogl0OOooool00ol0003oooooooooo`08ooooo`002Oooool0
0ol0003oooooooooo`0Looooo`03o`00oooooooooooo00;ooooo0P3oO`04ooooo`D000002_ooool0
0ol00?ooooooooooo`1iooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool08Oooool2
0?mo08oooooo00?o0000ooooooooool02?ooool000Wooooo00?o0000ooooooooool06_ooool20?mo
0003ooooool00?oooooo00;ooooo0P3oO`04ooooo`D000002_ooool00ol00?ooooooooooo`1ioooo
o`03o`000?oooooooooo00oooooo00?o0000ooooooooool06_ooool20?mo00Gooooo0P3oO`2?oooo
o`03o`000?oooooooooo00Sooooo0009ooooo`03o`000?oooooooooo01[ooooo0P3oO`02ooooo`03
o`00oooooooooooo00Kooooo1@000006ooooo`80ogl00oooool00ol00?ooooooooooo`04ooooo`80
ogl0L_ooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo01[ooooo0P3oO`0Fooooo`80
ogl02_ooool20?mo07;ooooo00?o0000ooooooooool02?ooool000Wooooo00?o0000ooooooooool0
7oooool2o`00o`Oooooo0`000007ooooo`80ogl01?ooool00ol00?ooooooooooo`03ooooo`80ogl0
L_ooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo03;ooooo0P3oO`0:ooooo`80ogl0
L_ooool00ol0003oooooooooo`08ooooo`002Oooool00ol0003oooooooooo`0Qooooo`03o`00oooo
oooooooo01Gooooo00?o003oooooooooool0M_ooool00ol0003oooooooooo`0?ooooo`03o`000?oo
oooooooo0;;ooooo00?o0000ooooooooool02?ooool000Wooooo00?o0000ooooooooool08_ooool0
0ol00?ooooooooooo`0Eooooo`03o`00oooooooooooo07Gooooo00?o0000ooooooooool03oooool0
0ol0003oooooooooo`2booooo`03o`000?oooooooooo00Sooooo0009ooooo`03o`000?oooooooooo
02?ooooo00?o003oooooooooool05?ooool00ol00?ooooooooooo`1eooooo`03o`000?oooooooooo
00oooooo00?o0000ooooooooool0/_ooool00ol0003oooooooooo`08ooooo`002Oooool00ol0003o
ooooooooo`0Sooooo`030?mo0?l00?oo003o0080ogl04oooool00ol00?ooooooooooo`1dooooo`03
o`000?oooooooooo00oooooo00?o0000ooooooooool08oooool20?mo0003ooooo`3oO`00ogl008[o
oooo00?o0000ooooooooool02?ooool000Wooooo00?o0000ooooooooool08oooool30?mo00;o003o
4oooool00ol00?ooooooooooo`1dooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool0
8oooool50?mo08[ooooo00?o0000ooooooooool02?ooool000Wooooo00?o0000ooooooooool09Ooo
ool20?mo0003ooooool00?oooooo017ooooo00?o003o0?mo0?ooool0M?ooool00ol0003ooooooooo
o`0?ooooo`03o`000?oooooooooo02Gooooo0P3oO`0Dooooo`80ogl0MOooool00ol0003ooooooooo
o`08ooooo`002Oooool00ol0003oooooooooo`0Yooooo`?o003o3oooool00ol00?l0ogl0ooooo`1d
ooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool0>oooool20?mo07Gooooo00?o0000
ooooooooool02?ooool000Wooooo00?o0000ooooooooool0;?ooool3o`00o`_ooooo0_l00?mfoooo
o`03o`000?oooooooooo00oooooo00?o0000ooooooooool0/_ooool00ol0003oooooooooo`08oooo
o`002Oooool00ol0003oooooooooo`0_ooooo`?o003o1_ooool2o`00ogSooooo00?o0000oooooooo
ool03oooool00ol0003oooooooooo`2booooo`03o`000?oooooooooo00Sooooo0009ooooo`03o`00
0?oooooooooo01kooooo0P3oO`0Booooo`Ko003oN_ooool00ol0003oooooooooo`0?ooooo`03o`00
0?oooooooooo01kooooo0P3oO`2Booooo`03o`000?oooooooooo00Sooooo0009ooooo`03o`000?oo
oooooooo01kooooo0P3oO`2Booooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool07_oo
ool20?mo09;ooooo00?o0000ooooooooool02?ooool000Wooooo00?o0000ooooooooool0/_ooool0
0ol0003oooooooooo`0?ooooo`03o`000?oooooooooo0;;ooooo00?o0000ooooooooool02?ooool0
00Wooooo00?o0000ooooooooool0/_ooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo
0;;ooooo00?o0000ooooooooool02?ooool000Wooooo00?o0000ooooooooool0/_ooool00ol0003o
ooooooooo`0?ooooo`03o`000?oooooooooo0;;ooooo00?o0000ooooooooool02?ooool000Wooooo
00?o0000ooooooooool0/_ooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo0;;ooooo
00?o0000ooooooooool02?ooool000Wooooo00?o0000ooooooooool0C_ooool20?mo06;ooooo00?o
0000ooooooooool03oooool00ol0003oooooooooo`1>ooooo`80ogl0H_ooool00ol0003ooooooooo
o`08ooooo`002Oooool00ol0003oooooooooo`0dooooo`80ogl06?ooool20?mo06;ooooo00?o0000
ooooooooool03oooool00ol0003oooooooooo`0dooooo`80ogl06?ooool20?mo06;ooooo00?o0000
ooooooooool02?ooool000Wooooo00?o0000ooooooooool0=?ooool20?mo07cooooo00?o0000oooo
ooooool03oooool00ol0003oooooooooo`0dooooo`80ogl0O?ooool00ol0003oooooooooo`08oooo
o`002Oooool00ol0003oooooooooo`2booooo`03o`000?oooooooooo00oooooo00?o0000oooooooo
ool0/_ooool00ol0003oooooooooo`08ooooo`002Oooool00ol0003oooooooooo`0mooooo`80ogl0
0_ooool20?mo06oooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`0mooooo`80ogl0
0_ooool20?mo06oooooo00?o0000ooooooooool02?ooool000Wooooo00?o0000ooooooooool0?Ooo
ool20?mo00;ooooo0P3oO`1_ooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool0?Ooo
ool20?mo00;ooooo0P3oO`1_ooooo`03o`000?oooooooooo00Sooooo0009ooooo`03o`000?oooooo
oooo0;;ooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`2booooo`03o`000?oooooo
oooo00Sooooo0009ooooo`03o`000?oooooooooo0;;ooooo00?o0000ooooooooool03oooool00ol0
003oooooooooo`2booooo`03o`000?oooooooooo00Sooooo0009ooooo`03o`000?oooooooooo0;;o
oooo00?o0000ooooooooool03oooool00ol0003oooooooooo`2booooo`03o`000?oooooooooo00So
oooo0009ooooo`03o`000?oooooooooo0;;ooooo00?o0000ooooooooool03oooool00ol0003ooooo
ooooo`2booooo`03o`000?oooooooooo00Sooooo0009ooooo`03o`000?oooooooooo0;;ooooo00?o
0000ooooooooool03oooool00ol0003oooooooooo`2booooo`03o`000?oooooooooo00Sooooo0009
ooooo`03o`000?oooooooooo0;;ooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`2b
ooooo`03o`000?oooooooooo00Sooooo0009ooooo`03o`000?oooooooooo0;;ooooo00?o0000oooo
ooooool03oooool00ol0003oooooooooo`2booooo`03o`000?oooooooooo00Sooooo0009ooooo`03
o`000?oooooooooo0;;ooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`2booooo`03
o`000?oooooooooo00Sooooo0009ooooo`03o`000?oooooooooo0;;ooooo00?o0000ooooooooool0
3oooool00ol0003oooooooooo`2booooo`03o`000?oooooooooo00Sooooo0009ooooo`03o`000?oo
oooooooo0;;ooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`2booooo`03o`000?oo
oooooooo00Sooooo0009ooooo`03o`000?oooooooooo0;;ooooo00?o0000ooooooooool03oooool0
0ol0003oooooooooo`2booooo`03o`000?oooooooooo00Sooooo0009ooooo`03o`000?oooooooooo
0;;ooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`2booooo`03o`000?oooooooooo
00Sooooo0009ooooo`03o`000?oooooooooo0;;ooooo00?o0000ooooooooool03oooool00ol0003o
ooooooooo`2booooo`03o`000?oooooooooo00Sooooo0009ooooo`03o`000?oooooooooo0;;ooooo
00?o0000ooooooooool03oooool00ol0003oooooooooo`2booooo`03o`000?oooooooooo00Sooooo
0009ooooo`03o`000?oooooooooo0;;ooooo00?o0000ooooooooool03oooool00ol0003ooooooooo
o`2booooo`03o`000?oooooooooo00Sooooo0009ooooo`03o`000?oooooooooo0;;ooooo00?o0000
ooooooooool03oooool00ol0003oooooooooo`2booooo`03o`000?oooooooooo00Sooooo0009oooo
o`03o`000?oooooooooo0;;ooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`2boooo
o`03o`000?oooooooooo00Sooooo0009ooooo`03o`000?oooooooooo0;;ooooo00?o0000oooooooo
ool03oooool00ol0003oooooooooo`2booooo`03o`000?oooooooooo00Sooooo0009ooooo`03o`00
0?oooooooooo0;;ooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`2booooo`03o`00
0?oooooooooo00Sooooo0009ooooo`03o`000?oooooooooo0;;ooooo00?o0000ooooooooool03ooo
ool00ol0003oooooooooo`2booooo`03o`000?oooooooooo00Sooooo0009ooooo`03o`000?oooooo
oooo0;;ooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`2booooo`03o`000?oooooo
oooo00Sooooo0009ooooo`03o`000?oooooooooo0:;ooooo0P3oO`0>ooooo`03o`000?oooooooooo
00oooooo00?o0000ooooooooool0X_ooool20?mo00kooooo00?o0000ooooooooool02?ooool000Wo
oooo00?o0000ooooooooool0X_ooool20?mo00kooooo00?o0000ooooooooool03oooool00ol0003o
ooooooooo`2Rooooo`80ogl03_ooool00ol0003oooooooooo`08ooooo`002Oooool00ol0003ooooo
ooooo`2booooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool0/_ooool00ol0003ooooo
ooooo`08ooooo`002Oooool00ol0003oooooooooo`2booooo`03o`000?oooooooooo00oooooo00?o
0000ooooooooool0/_ooool00ol0003oooooooooo`08ooooo`002Oooool00ol0003oooooooooo`2b
ooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool0/_ooool00ol0003oooooooooo`08
ooooo`002Oooool00ol0003oooooooooo`2booooo`03o`000?oooooooooo00oooooo00?o0000oooo
ooooool0/_ooool00ol0003oooooooooo`08ooooo`002Oooool00ol0003oooooooooo`2booooo`03
o`000?oooooooooo00oooooo00?o0000ooooooooool0/_ooool00ol0003oooooooooo`08ooooo`00
2Oooool00ol0003oooooooooo`2booooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool0
/_ooool00ol0003oooooooooo`08ooooo`002Oooool00ol0003oooooooooo`2booooo`03o`000?oo
oooooooo00oooooo00?o0000ooooooooool0/_ooool00ol0003oooooooooo`08ooooo`002Oooool0
0ol0003oooooooooo`1aooooo`80ogl0?oooool00ol0003oooooooooo`0?ooooo`03o`000?oooooo
oooo077ooooo0P3oO`0oooooo`03o`000?oooooooooo00Sooooo0009ooooo`03o`000?oooooooooo
077ooooo0P3oO`0oooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool0LOooool20?mo
03oooooo00?o0000ooooooooool02?ooool000Wooooo00?o0000ooooooooool0Toooool20?mo01go
oooo00?o0000ooooooooool03oooool00ol0003oooooooooo`2Cooooo`80ogl07Oooool00ol0003o
ooooooooo`08ooooo`002Oooool00ol0003oooooooooo`2?ooooo`80ogl00_ooool20?mo01gooooo
00?o0000ooooooooool03oooool00ol0003oooooooooo`2?ooooo`80ogl00_ooool20?mo01gooooo
00?o0000ooooooooool02?ooool000Wooooo00?o0000ooooooooool0N_ooool00`3oO`3o003oo`00
o`07o`00o`_ooooo0P3oO`0Qooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool0N_oo
ool20?mo01?ooooo0P3oO`0Qooooo`03o`000?oooooooooo00Sooooo0009ooooo`03o`000?oooooo
oooo07Kooooo1Ol00?l00`3oO`3oooooooooo`06ooooo`?o003o:oooool00ol0003oooooooooo`0?
ooooo`03o`000?oooooooooo07[ooooo0P3oO`0fooooo`03o`000?oooooooooo00Sooooo0009oooo
o`03o`000?oooooooooo07Cooooo0_l00?lAooooo`03o`00oooooooooooo00;ooooo0P3oO`0Toooo
o`03o`000?oooooooooo00oooooo00?o0000ooooooooool0M?ooool20?mo01Kooooo0P3oO`0Toooo
o`03o`000?oooooooooo00Sooooo0009ooooo`03o`000?oooooooooo077ooooo0ol00?l20?mo017o
oooo00?o003oooooooooool00_ooool20?mo02Cooooo00?o0000ooooooooool03oooool00ol0003o
ooooooooo`1dooooo`80ogl05_ooool20?mo02Cooooo00?o0000ooooooooool02?ooool000Wooooo
00?o0000ooooooooool0K_ooool3o`00o`030?mo0?oooooooooo00gooooo0P3oO`04ooooo`03o`00
oooooooooooo00Kooooo0P3oO`0Pooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool0
L?ooool20?mo00oooooo0P3oO`0=ooooo`80ogl08?ooool00ol0003oooooooooo`08ooooo`002Ooo
ool00ol0003oooooooooo`1/ooooo`;o003o0_ooool20?mo00Cooooo0P3oO`09ooooo`80ogl01?oo
ool00ol00?ooooooooooo`06ooooo`80ogl08?ooool00ol0003oooooooooo`0?ooooo`03o`000?oo
oooooooo073ooooo0P3oO`04ooooo`80ogl02Oooool20?mo00gooooo0P3oO`0Pooooo`03o`000?oo
oooooooo00Sooooo0009ooooo`03o`000?oooooooooo05Kooooo0P3oO`0Cooooo`03o`00oooooooo
oooo00;ooooo0P3oO`04ooooo`80ogl04?ooool00ol00?ooooooooooo`0Wooooo`03o`000?oooooo
oooo00oooooo00?o0000ooooooooool0E_ooool20?mo01Sooooo0P3oO`04ooooo`80ogl0>_ooool0
0ol0003oooooooooo`08ooooo`002Oooool00ol0003oooooooooo`1Fooooo`80ogl04Oooool2o`00
o`Gooooo0P3oO`0Fooooo`03o`00oooooooooooo02Oooooo00?o0000ooooooooool03oooool00ol0
003oooooooooo`1Fooooo`80ogl06?ooool20?mo043ooooo00?o0000ooooooooool02?ooool000Wo
oooo00?o0000ooooooooool0J?ooool00ol00?ooooooooooo`0Mooooo`03o`00oooooooooooo02Oo
oooo00?o0000ooooooooool03oooool00ol0003oooooooooo`2booooo`03o`000?oooooooooo00So
oooo0009ooooo`03o`000?oooooooooo05gooooo0P3oO`08ooooo`03o`00o`3oO`00ogl001Wooooo
0P3oO`03ooooo`03o`00oooooooooooo02Oooooo00?o0000ooooooooool03oooool00ol0003ooooo
ooooo`1Mooooo`80ogl02Oooool20?mo01Wooooo0P3oO`0]ooooo`03o`000?oooooooooo00Sooooo
0009ooooo`03o`000?oooooooooo05gooooo0P3oO`06ooooo`;o003o00?ooooo0?mo003oO`006Ooo
ool20?mo00;ooooo00?o003oooooooooool0:?ooool00ol0003oooooooooo`0?ooooo`03o`000?oo
oooooooo05gooooo0P3oO`09ooooo`80ogl06Oooool20?mo02gooooo00?o0000ooooooooool02?oo
ool000Wooooo00?o0000ooooooooool0I?ooool00ol00?ooooooooooo`0Pooooo`03o`00oooooooo
oooo02Sooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`2booooo`03o`000?oooooo
oooo00Sooooo0009ooooo`03o`000?oooooooooo06?ooooo00?o003oooooooooool08?ooool00ol0
0?ooooooooooo`0:ooooo`80ogl07Oooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo
09?ooooo0P3oO`0Mooooo`03o`000?oooooooooo00Sooooo0009ooooo`03o`000?oooooooooo06;o
oooo00?o003oooooooooool03?ooool3000001;ooooo00?o003o0?mo0?ooool02_ooool20?mo01go
oooo00?o0000ooooooooool03oooool00ol0003oooooooooo`26ooooo`80ogl02oooool20?mo01go
oooo00?o0000ooooooooool02?ooool000Wooooo00?o0000ooooooooool0HOooool00ol00?oooooo
ooooo`0<ooooo`D000004?ooool00ol00?l0ogl00?mo000Zooooo`03o`000?oooooooooo00oooooo
00?o0000ooooooooool0L_ooool20?mo01;ooooo0P3oO`0Zooooo`03o`000?oooooooooo00Sooooo
0009ooooo`03o`000?oooooooooo067ooooo00?o003oooooooooool03?ooool5000000oooooo00?o
003oooooooooool0:oooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo07;ooooo0P3o
O`0nooooo`03o`000?oooooooooo00Sooooo0009ooooo`03o`000?oooooooooo063ooooo00?o003o
ooooooooool01_ooool20?mo00Gooooo1@00000>ooooo`03o`00o`3oO`00ogl002cooooo00?o0000
ooooooooool03oooool00ol0003oooooooooo`1Yooooo`80ogl01Oooool20?mo01;ooooo0P3oO`0/
ooooo`03o`000?oooooooooo00Sooooo0009ooooo`03o`000?oooooooooo05oooooo00?o003ooooo
ooooool01Oooool40?mo00Gooooo00@0ogl000000000000000003?ooool0103oO`3o003oo`00oooo
ool20?mo02cooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`1Wooooo`@0ogl01Ooo
ool20?mo00kooooo0P3oO`02ooooo`80ogl0;?ooool00ol0003oooooooooo`08ooooo`002Oooool0
0ol0003oooooooooo`1Oooooo`03o`00oooooooooooo00Gooooo0P3oO`0Gooooo`03o`00o`3oO`3o
oooo02oooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`1Wooooo`80ogl05oooool2
0?mo033ooooo00?o0000ooooooooool02?ooool000Wooooo00?o0000ooooooooool0BOooool20?mo
01?ooooo00?o003oooooooooool07_ooool00ol00?ooooooooooo`0`ooooo`03o`000?oooooooooo
00oooooo00?o0000ooooooooool0BOooool20?mo06Oooooo00?o0000ooooooooool02?ooool000Wo
oooo00?o0000ooooooooool0BOooool20?mo00Oooooo0P3oO`0:ooooo`03o`00oooooooooooo00go
oooo0P3oO`0>ooooo`03o`00oooooooooooo037ooooo00?o0000ooooooooool03oooool00ol0003o
ooooooooo`19ooooo`80ogl01oooool20?mo01[ooooo0P3oO`12ooooo`03o`000?oooooooooo00So
oooo0009ooooo`03o`000?oooooooooo05;ooooo0P3oO`09ooooo`03o`00oooooooooooo00kooooo
0P3oO`0:ooooo`Co003o=?ooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo05;ooooo
0P3oO`0Jooooo`80ogl0@_ooool00ol0003oooooooooo`08ooooo`002Oooool00ol0003ooooooooo
o`1Mooooo`03o`00oooooooooooo00Wooooo0P3oO`0>ooooo`03o`00oooooooooooo03Kooooo00?o
0000ooooooooool03oooool00ol0003oooooooooo`1Yooooo`80ogl0Aoooool00ol0003ooooooooo
o`08ooooo`002Oooool00ol0003oooooooooo`1Mooooo`03o`00oooooooooooo00Wooooo0P3oO`0<
ooooo`;o003o>Oooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo06Wooooo0P3oO`17
ooooo`03o`000?oooooooooo00Sooooo0009ooooo`03o`000?oooooooooo05gooooo00?o003ooooo
ooooool05_ooool00ol00?ooooooooooo`0iooooo`03o`000?oooooooooo00oooooo00?o0000oooo
ooooool0/_ooool00ol0003oooooooooo`08ooooo`002Oooool00ol0003oooooooooo`1Mooooo`03
o`00oooooooooooo01Gooooo00?o003oooooooooool0>_ooool00ol0003oooooooooo`0?ooooo`03
o`000?oooooooooo0;;ooooo00?o0000ooooooooool02?ooool000Wooooo00?o0000ooooooooool0
GOooool2o`00oa;ooooo1?l00?lmooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool0
/_ooool00ol0003oooooooooo`08ooooo`002Oooool00ol0003oooooooooo`1Booooo`80ogl02ooo
ool00ol00?ooooooooooo`0<ooooo`?o003o@Oooool00ol0003oooooooooo`0?ooooo`03o`000?oo
oooooooo05;ooooo0P3oO`1Nooooo`03o`000?oooooooooo00Sooooo0009ooooo`03o`000?oooooo
oooo05;ooooo0P3oO`0<ooooo`03o`00oooooooooooo00Sooooo0ol00?m4ooooo`03o`000?oooooo
oooo00oooooo00?o0000ooooooooool0D_ooool20?mo05kooooo00?o0000ooooooooool02?ooool0
00Wooooo00?o0000ooooooooool0HOooool:o`00o`Cooooo0P3oO`11ooooo`03o`000?oooooooooo
00oooooo00?o0000ooooooooool0Koooool20?mo047ooooo00?o0000ooooooooool02?ooool000Wo
oooo00?o0000ooooooooool0Koooool20?mo047ooooo00?o0000ooooooooool03oooool00ol0003o
ooooooooo`1_ooooo`80ogl0@Oooool00ol0003oooooooooo`08ooooo`002Oooool00ol0003ooooo
ooooo`2booooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool0/_ooool00ol0003ooooo
ooooo`08ooooo`002Oooool00ol0003oooooooooo`2booooo`03o`000?oooooooooo00oooooo00?o
0000ooooooooool0/_ooool00ol0003oooooooooo`08ooooo`002Oooool00ol0003oooooooooo`1=
ooooo`80ogl0Hoooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo04gooooo0P3oO`1S
ooooo`03o`000?oooooooooo00Sooooo0009ooooo`03o`000?oooooooooo04gooooo0P3oO`0Doooo
o`80ogl0COooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo04gooooo0P3oO`0Doooo
o`80ogl0COooool00ol0003oooooooooo`08ooooo`002Oooool00ol0003oooooooooo`1Sooooo`80
ogl0COooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo06?ooooo0P3oO`1=ooooo`03
o`000?oooooooooo00Sooooo0009ooooo`03o`000?oooooooooo05Wooooo0P3oO`1Gooooo`03o`00
0?oooooooooo00oooooo00?o0000ooooooooool0FOooool20?mo05Oooooo00?o0000ooooooooool0
2?ooool000Wooooo00?o0000ooooooooool0FOooool20?mo05Oooooo00?o0000ooooooooool03ooo
ool00ol0003oooooooooo`1Iooooo`80ogl0Eoooool00ol0003oooooooooo`08ooooo`002Oooool0
0ol0003oooooooooo`1aooooo`80ogl0?oooool00ol0003oooooooooo`0?ooooo`03o`000?oooooo
oooo077ooooo0P3oO`0oooooo`03o`000?oooooooooo00Sooooo0009ooooo`03o`000?oooooooooo
077ooooo0P3oO`0oooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool0LOooool20?mo
03oooooo00?o0000ooooooooool02?ooool000Wooooo00?o0000ooooooooool0/_ooool00ol0003o
ooooooooo`0?ooooo`03o`000?oooooooooo0;;ooooo00?o0000ooooooooool02?ooool000Wooooo
00?o0000ooooooooool0/_ooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo0;;ooooo
00?o0000ooooooooool02?ooool000Wooooo00?o0000ooooooooool0/_ooool00ol0003ooooooooo
o`0?ooooo`03o`000?oooooooooo0;;ooooo00?o0000ooooooooool02?ooool000Wooooo00?o0000
ooooooooool0/_ooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo0;;ooooo00?o0000
ooooooooool02?ooool000Wooooo00?o0000ooooooooool0/_ooool00ol0003oooooooooo`0?oooo
o`03o`000?oooooooooo0;;ooooo00?o0000ooooooooool02?ooool000Wooooo00?o0000oooooooo
ool0/_ooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo0;;ooooo00?o0000oooooooo
ool02?ooool000Wooooo00?o0000ooooooooool0/_ooool00ol0003oooooooooo`0?ooooo`03o`00
0?oooooooooo0;;ooooo00?o0000ooooooooool02?ooool000Wooooo00?o0000ooooooooool0/_oo
ool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo0;;ooooo00?o0000ooooooooool02?oo
ool000Wooooo00?o0000ooooooooool0/_ooool00ol0003oooooooooo`0?ooooo`03o`000?oooooo
oooo0;;ooooo00?o0000ooooooooool02?ooool000Wooooo00?o0000ooooooooool0/_ooool00ol0
003oooooooooo`0?ooooo`03o`000?oooooooooo0;;ooooo00?o0000ooooooooool02?ooool000Wo
oooo00?o0000ooooooooool0/_ooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo0;;o
oooo00?o0000ooooooooool02?ooool000Wooooo00?o0000ooooooooool0/_ooool00ol0003ooooo
ooooo`0?ooooo`03o`000?oooooooooo0;;ooooo00?o0000ooooooooool02?ooool000Wooooo00?o
0000ooooooooool0/_ooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo0;;ooooo00?o
0000ooooooooool02?ooool000Wooooo00?o0000ooooooooool0/_ooool00ol0003oooooooooo`0?
ooooo`03o`000?oooooooooo0;;ooooo00?o0000ooooooooool02?ooool000Wooooo00?o0000oooo
ooooool0/_ooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo0;;ooooo00?o0000oooo
ooooool02?ooool000Wooooo00?o0000ooooooooool0/_ooool00ol0003oooooooooo`0?ooooo`03
o`000?oooooooooo0;;ooooo00?o0000ooooooooool02?ooool000Wooooo00?o0000ooooooooool0
/_ooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo0;;ooooo00?o0000ooooooooool0
2?ooool000Wooooo00?o0000ooooooooool0/_ooool00ol0003oooooooooo`0?ooooo`03o`000?oo
oooooooo0;;ooooo00?o0000ooooooooool02?ooool000Wooooo00?o0000ooooooooool0/_ooool0
0ol0003oooooooooo`0?ooooo`03o`000?oooooooooo0;;ooooo00?o0000ooooooooool02?ooool0
00Wooooo00?o0000ooooooooool0/_ooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo
0;;ooooo00?o0000ooooooooool02?ooool000Wooooo00?o0000ooooooooool0/_ooool00ol0003o
ooooooooo`0?ooooo`03o`000?oooooooooo0;;ooooo00?o0000ooooooooool02?ooool000Wooooo
00?o0000ooooooooool0/_ooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo0;;ooooo
00?o0000ooooooooool02?ooool000Wooooo00?o0000ooooooooool0/_ooool00ol0003ooooooooo
o`0?ooooo`03o`000?oooooooooo0;;ooooo00?o0000ooooooooool02?ooool000Wooooo00?o0000
ooooooooool0/_ooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo0;;ooooo00?o0000
ooooooooool02?ooool000Wooooo00?o0000ooooooooool0F?ooool20?mo05Sooooo00?o0000oooo
ooooool03oooool00ol0003oooooooooo`1Hooooo`80ogl0F?ooool00ol0003oooooooooo`08oooo
o`002Oooool00ol0003oooooooooo`1Hooooo`80ogl0F?ooool00ol0003oooooooooo`0?ooooo`03
o`000?oooooooooo05Sooooo0P3oO`1Hooooo`03o`000?oooooooooo00Sooooo0009ooooo`03o`00
0?oooooooooo0;;ooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`2booooo`03o`00
0?oooooooooo00Sooooo0009ooooo`03o`000?oooooooooo0;;ooooo00?o0000ooooooooool03ooo
ool00ol0003oooooooooo`2booooo`03o`000?oooooooooo00Sooooo0009ooooo`03o`000?oooooo
oooo0;;ooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`2booooo`03o`000?oooooo
oooo00Sooooo0009ooooo`03o`000?oooooooooo0;;ooooo00?o0000ooooooooool03oooool00ol0
003oooooooooo`2booooo`03o`000?oooooooooo00Sooooo0009ooooo`03o`000?oooooooooo0;;o
oooo00?o0000ooooooooool03oooool00ol0003oooooooooo`2booooo`03o`000?oooooooooo00So
oooo0009ooooo`03o`000?oooooooooo0;;ooooo00?o0000ooooooooool03oooool00ol0003ooooo
ooooo`2booooo`03o`000?oooooooooo00Sooooo0009ooooo`03o`000?oooooooooo0;;ooooo00?o
0000ooooooooool03oooool00ol0003oooooooooo`2booooo`03o`000?oooooooooo00Sooooo0009
ooooo`03o`000?oooooooooo0;;ooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`2b
ooooo`03o`000?oooooooooo00Sooooo0009ooooo`03o`000?oooooooooo0;;ooooo00?o0000oooo
ooooool03oooool00ol0003oooooooooo`2booooo`03o`000?oooooooooo00Sooooo0009ooooo`03
o`000?oooooooooo0;;ooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`2booooo`03
o`000?oooooooooo00Sooooo0009ooooo`03o`000?oooooooooo0;;ooooo00?o0000ooooooooool0
3oooool00ol0003oooooooooo`2booooo`03o`000?oooooooooo00Sooooo0009ooooo`03o`000?oo
oooooooo0;;ooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`2booooo`03o`000?oo
oooooooo00Sooooo0009ooooo`03o`000?oooooooooo0;;ooooo00?o0000ooooooooool03oooool0
0ol0003oooooooooo`2booooo`03o`000?oooooooooo00Sooooo0009oooookKo00004Ooooonfo`00
00[ooooo003ooooooi7ooooo003ooooooi7ooooo003ooooooi7ooooo003ooooooi7ooooo003ooooo
oi7ooooo003ooooooi7ooooo003ooooooi7ooooo003ooooooi7ooooo003ooooooi7ooooo0000\
\>"],
  ImageRangeCache->{{{0, 399}, {399, 0}} -> {-0.0500105, -0.0500105, \
0.00526322, 0.00526322}, {{9.5, 190.438}, {389.5, 208.5}} -> {-1.15081, \
-1.15117, 0.0115117, 0.0115117}, {{208.5, 389.438}, {389.5, 208.5}} -> \
{-1.09771, -0.0754011, 0.0052648, 0.0052648}, {{9.5, 190.438}, {190.438, \
9.5}} -> {-1.11761, -3.34306, 0.0111796, 0.0111796}, {{208.5, 389.438}, \
{190.438, 9.5}} -> {-3.34236, -3.34306, 0.0111796, 0.0111796}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
%%ImageSize: 400 400 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.47619 0.0238095 0.47619 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.0238095 0.477324 0.477324 MathSubStart
%% ContourGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.480769 0.5 0.480769 [
[ 0 0 -0.125 0 ]
[ 0 0 -0.125 0 ]
[ 0 1 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
0 0 m
1 0 L
s
0 0 m
0 1 L
s
0 1 m
1 1 L
s
1 0 m
1 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
.01923 .98077 m
.98077 .98077 L
.98077 .01923 L
.01923 .01923 L
F
.5 Mabswid
.1 g
.01923 .14789 m
.02076 .15385 L
.02872 .17308 L
.03846 .18928 L
.04079 .19231 L
.05562 .21154 L
.05769 .21419 L
.07306 .23077 L
.07692 .2348 L
.09275 .25 L
.09615 .25296 L
.11457 .26923 L
.11538 .26979 L
.13462 .28478 L
.13927 .28846 L
.15385 .29805 L
.16669 .30769 L
.17308 .31081 L
.19231 .32393 L
.19675 .32692 L
.21154 .33398 L
.23067 .34615 L
.23077 .34621 L
.25 .35437 L
.26923 .36502 L
.26995 .36538 L
.28846 .37164 L
.30769 .38029 L
.31809 .38462 L
.32692 .38649 L
.34615 .39213 L
.36538 .39757 L
.38462 .40168 L
.4009 .40385 L
.40385 .40404 L
.42308 .4044 L
.43172 .40385 L
.44231 .40217 L
.46154 .39533 L
.47331 .38462 L
.48017 .36538 L
.4781 .34615 L
.47064 .32692 L
.46154 .30978 L
.45991 .30769 L
.44559 .28846 L
.44231 .28416 L
.42874 .26923 L
.42308 .26317 L
.40955 .25 L
.40385 .24484 L
.38809 .23077 L
.38462 .22817 L
.36538 .21228 L
.36446 .21154 L
.34615 .19884 L
.3375 .19231 L
.32692 .18644 L
.30826 .17308 L
.30769 .1729 L
.28846 .16256 L
.27494 .15385 L
.26923 .15204 L
.25 .14187 L
.23713 .13462 L
.23077 .13296 L
.21154 .12457 L
.19231 .11563 L
.19174 .11538 L
.17308 .11033 L
.15385 .10379 L
.13462 .09815 L
.12705 .09615 L
.11538 .09465 L
.09615 .09234 L
.07692 .09151 L
.05769 .09317 L
.04504 .09615 L
.03846 .09912 L
.02176 .11538 L
.01923 .12157 L
F
0 g
.01923 .14789 m
.02076 .15385 L
.02872 .17308 L
.03846 .18928 L
.04079 .19231 L
.05562 .21154 L
.05769 .21419 L
.07306 .23077 L
.07692 .2348 L
.09275 .25 L
.09615 .25296 L
.11457 .26923 L
.11538 .26979 L
.13462 .28478 L
.13927 .28846 L
.15385 .29805 L
.16669 .30769 L
.17308 .31081 L
.19231 .32393 L
.19675 .32692 L
.21154 .33398 L
.23067 .34615 L
.23077 .34621 L
.25 .35437 L
.26923 .36502 L
.26995 .36538 L
.28846 .37164 L
.30769 .38029 L
.31809 .38462 L
.32692 .38649 L
.34615 .39213 L
.36538 .39757 L
.38462 .40168 L
.4009 .40385 L
.40385 .40404 L
.42308 .4044 L
.43172 .40385 L
.44231 .40217 L
.46154 .39533 L
.47331 .38462 L
.48017 .36538 L
.4781 .34615 L
.47064 .32692 L
.46154 .30978 L
.45991 .30769 L
.44559 .28846 L
.44231 .28416 L
.42874 .26923 L
.42308 .26317 L
.40955 .25 L
Mistroke
.40385 .24484 L
.38809 .23077 L
.38462 .22817 L
.36538 .21228 L
.36446 .21154 L
.34615 .19884 L
.3375 .19231 L
.32692 .18644 L
.30826 .17308 L
.30769 .1729 L
.28846 .16256 L
.27494 .15385 L
.26923 .15204 L
.25 .14187 L
.23713 .13462 L
.23077 .13296 L
.21154 .12457 L
.19231 .11563 L
.19174 .11538 L
.17308 .11033 L
.15385 .10379 L
.13462 .09815 L
.12705 .09615 L
.11538 .09465 L
.09615 .09234 L
.07692 .09151 L
.05769 .09317 L
.04504 .09615 L
.03846 .09912 L
.02176 .11538 L
.01923 .12157 L
Mfstroke
.2 g
.07692 .1245 m
.09615 .11965 L
.11538 .11898 L
.13462 .12091 L
.15385 .12474 L
.17308 .12989 L
.19012 .13462 L
.19231 .13545 L
.21154 .14327 L
.23077 .15141 L
.23752 .15385 L
.25 .16037 L
.26923 .17048 L
.27509 .17308 L
.28846 .18134 L
.30731 .19231 L
.30769 .19257 L
.32692 .20613 L
.33517 .21154 L
.34615 .22002 L
.36002 .23077 L
.36538 .23531 L
.38186 .25 L
.38462 .25259 L
.4007 .26923 L
.40385 .27259 L
.41643 .28846 L
.42308 .29699 L
.42879 .30769 L
.43701 .32692 L
.43906 .34615 L
.42901 .36538 L
.42308 .36966 L
.40385 .37564 L
.38462 .37664 L
.36538 .37492 L
.34615 .37135 L
.32692 .36675 L
.3211 .36538 L
.30769 .36069 L
.28846 .3531 L
.26976 .34615 L
.26923 .3459 L
.25 .33612 L
.23077 .32703 L
.23048 .32692 L
.21154 .31545 L
.19741 .30769 L
.19231 .3043 L
.17308 .29124 L
.16858 .28846 L
.15385 .27725 L
.14313 .26923 L
.13462 .26214 L
.12063 .25 L
.11538 .24516 L
.1011 .23077 L
.09615 .22557 L
.08464 .21154 L
.07692 .20174 L
.07142 .19231 L
.06213 .17308 L
.05841 .15385 L
.06457 .13462 L
F
0 g
.07692 .1245 m
.09615 .11965 L
.11538 .11898 L
.13462 .12091 L
.15385 .12474 L
.17308 .12989 L
.19012 .13462 L
.19231 .13545 L
.21154 .14327 L
.23077 .15141 L
.23752 .15385 L
.25 .16037 L
.26923 .17048 L
.27509 .17308 L
.28846 .18134 L
.30731 .19231 L
.30769 .19257 L
.32692 .20613 L
.33517 .21154 L
.34615 .22002 L
.36002 .23077 L
.36538 .23531 L
.38186 .25 L
.38462 .25259 L
.4007 .26923 L
.40385 .27259 L
.41643 .28846 L
.42308 .29699 L
.42879 .30769 L
.43701 .32692 L
.43906 .34615 L
.42901 .36538 L
.42308 .36966 L
.40385 .37564 L
.38462 .37664 L
.36538 .37492 L
.34615 .37135 L
.32692 .36675 L
.3211 .36538 L
.30769 .36069 L
.28846 .3531 L
.26976 .34615 L
.26923 .3459 L
.25 .33612 L
.23077 .32703 L
.23048 .32692 L
.21154 .31545 L
.19741 .30769 L
.19231 .3043 L
.17308 .29124 L
Mistroke
.16858 .28846 L
.15385 .27725 L
.14313 .26923 L
.13462 .26214 L
.12063 .25 L
.11538 .24516 L
.1011 .23077 L
.09615 .22557 L
.08464 .21154 L
.07692 .20174 L
.07142 .19231 L
.06213 .17308 L
.05841 .15385 L
.06457 .13462 L
.07692 .1245 L
Mfstroke
.3 g
.09615 .14112 m
.11538 .13705 L
.13462 .13642 L
.15385 .13858 L
.17308 .1428 L
.19231 .14849 L
.20891 .15385 L
.21154 .15492 L
.23077 .16328 L
.25 .17202 L
.25249 .17308 L
.26923 .18234 L
.28729 .19231 L
.28846 .19304 L
.30769 .20571 L
.31667 .21154 L
.32692 .2191 L
.34219 .23077 L
.34615 .23403 L
.36419 .25 L
.36538 .2511 L
.38274 .26923 L
.38462 .2711 L
.39766 .28846 L
.40385 .29348 L
.40841 .30769 L
.41342 .32692 L
.40779 .34615 L
.40385 .35095 L
.38462 .3583 L
.36538 .35929 L
.34615 .35733 L
.32692 .35334 L
.30769 .34806 L
.30099 .34615 L
.28846 .34141 L
.26923 .33329 L
.25411 .32692 L
.25 .32483 L
.23077 .31447 L
.21783 .30769 L
.21154 .30382 L
.19231 .29153 L
.18735 .28846 L
.17308 .27814 L
.16105 .26923 L
.15385 .26342 L
.13827 .25 L
.13462 .24668 L
.11893 .23077 L
.11538 .22715 L
.10315 .21154 L
.09615 .2036 L
.09134 .19231 L
.0848 .17308 L
.08708 .15385 L
F
0 g
.09615 .14112 m
.11538 .13705 L
.13462 .13642 L
.15385 .13858 L
.17308 .1428 L
.19231 .14849 L
.20891 .15385 L
.21154 .15492 L
.23077 .16328 L
.25 .17202 L
.25249 .17308 L
.26923 .18234 L
.28729 .19231 L
.28846 .19304 L
.30769 .20571 L
.31667 .21154 L
.32692 .2191 L
.34219 .23077 L
.34615 .23403 L
.36419 .25 L
.36538 .2511 L
.38274 .26923 L
.38462 .2711 L
.39766 .28846 L
.40385 .29348 L
.40841 .30769 L
.41342 .32692 L
.40779 .34615 L
.40385 .35095 L
.38462 .3583 L
.36538 .35929 L
.34615 .35733 L
.32692 .35334 L
.30769 .34806 L
.30099 .34615 L
.28846 .34141 L
.26923 .33329 L
.25411 .32692 L
.25 .32483 L
.23077 .31447 L
.21783 .30769 L
.21154 .30382 L
.19231 .29153 L
.18735 .28846 L
.17308 .27814 L
.16105 .26923 L
.15385 .26342 L
.13827 .25 L
.13462 .24668 L
.11893 .23077 L
Mistroke
.11538 .22715 L
.10315 .21154 L
.09615 .2036 L
.09134 .19231 L
.0848 .17308 L
.08708 .15385 L
.09615 .14112 L
Mfstroke
.4 g
.13462 .15051 m
.15385 .15059 L
.17308 .15343 L
.17564 .15385 L
.19231 .15832 L
.21154 .1649 L
.23077 .17241 L
.23246 .17308 L
.25 .18155 L
.26923 .19151 L
.27079 .19231 L
.28846 .20306 L
.30186 .21154 L
.30769 .21559 L
.32692 .22988 L
.32807 .23077 L
.34615 .24623 L
.35016 .25 L
.36538 .26553 L
.36844 .26923 L
.38256 .28846 L
.38462 .29202 L
.3914 .30769 L
.39203 .32692 L
.38462 .3373 L
.36538 .34516 L
.34615 .34533 L
.32692 .34269 L
.30769 .3379 L
.28846 .33158 L
.27547 .32692 L
.26923 .3242 L
.25 .31515 L
.23484 .30769 L
.23077 .30542 L
.21154 .29397 L
.20246 .28846 L
.19231 .28155 L
.17522 .26923 L
.17308 .26759 L
.15385 .25148 L
.15221 .25 L
.13462 .23256 L
.13306 .23077 L
.11796 .21154 L
.11538 .20748 L
.10779 .19231 L
.10476 .17308 L
.11538 .15667 L
.12086 .15385 L
F
0 g
.13462 .15051 m
.15385 .15059 L
.17308 .15343 L
.17564 .15385 L
.19231 .15832 L
.21154 .1649 L
.23077 .17241 L
.23246 .17308 L
.25 .18155 L
.26923 .19151 L
.27079 .19231 L
.28846 .20306 L
.30186 .21154 L
.30769 .21559 L
.32692 .22988 L
.32807 .23077 L
.34615 .24623 L
.35016 .25 L
.36538 .26553 L
.36844 .26923 L
.38256 .28846 L
.38462 .29202 L
.3914 .30769 L
.39203 .32692 L
.38462 .3373 L
.36538 .34516 L
.34615 .34533 L
.32692 .34269 L
.30769 .3379 L
.28846 .33158 L
.27547 .32692 L
.26923 .3242 L
.25 .31515 L
.23484 .30769 L
.23077 .30542 L
.21154 .29397 L
.20246 .28846 L
.19231 .28155 L
.17522 .26923 L
.17308 .26759 L
.15385 .25148 L
.15221 .25 L
.13462 .23256 L
.13306 .23077 L
.11796 .21154 L
.11538 .20748 L
.10779 .19231 L
.10476 .17308 L
.11538 .15667 L
.12086 .15385 L
Mistroke
.13462 .15051 L
Mfstroke
.5 g
.13462 .16338 m
.15385 .16153 L
.17308 .16323 L
.19231 .16737 L
.21135 .17308 L
.21154 .17317 L
.23077 .18073 L
.25 .18963 L
.25556 .19231 L
.26923 .19983 L
.28846 .2114 L
.28869 .21154 L
.30769 .22472 L
.31571 .23077 L
.32692 .23977 L
.33807 .25 L
.34615 .25733 L
.35599 .26923 L
.36538 .2783 L
.36902 .28846 L
.37545 .30769 L
.36758 .32692 L
.36538 .32865 L
.34615 .33376 L
.32692 .33266 L
.30769 .32888 L
.29908 .32692 L
.28846 .32325 L
.26923 .31581 L
.25086 .30769 L
.25 .30726 L
.23077 .29704 L
.21593 .28846 L
.21154 .28571 L
.19231 .27257 L
.18771 .26923 L
.17308 .25771 L
.16436 .25 L
.15385 .2404 L
.14542 .23077 L
.13462 .21873 L
.13118 .21154 L
.12297 .19231 L
.12555 .17308 L
F
0 g
.13462 .16338 m
.15385 .16153 L
.17308 .16323 L
.19231 .16737 L
.21135 .17308 L
.21154 .17317 L
.23077 .18073 L
.25 .18963 L
.25556 .19231 L
.26923 .19983 L
.28846 .2114 L
.28869 .21154 L
.30769 .22472 L
.31571 .23077 L
.32692 .23977 L
.33807 .25 L
.34615 .25733 L
.35599 .26923 L
.36538 .2783 L
.36902 .28846 L
.37545 .30769 L
.36758 .32692 L
.36538 .32865 L
.34615 .33376 L
.32692 .33266 L
.30769 .32888 L
.29908 .32692 L
.28846 .32325 L
.26923 .31581 L
.25086 .30769 L
.25 .30726 L
.23077 .29704 L
.21593 .28846 L
.21154 .28571 L
.19231 .27257 L
.18771 .26923 L
.17308 .25771 L
.16436 .25 L
.15385 .2404 L
.14542 .23077 L
.13462 .21873 L
.13118 .21154 L
.12297 .19231 L
.12555 .17308 L
.13462 .16338 L
s
.6 g
.15385 .17502 m
.17308 .17314 L
.19231 .17566 L
.21154 .18107 L
.23077 .18836 L
.24018 .19231 L
.25 .19702 L
.26923 .20749 L
.27614 .21154 L
.28846 .21933 L
.30431 .23077 L
.30769 .23311 L
.3269 .25 L
.32692 .25 L
.34441 .26923 L
.34615 .27162 L
.3561 .28846 L
.35891 .30769 L
.34615 .31981 L
.32692 .32367 L
.30769 .3205 L
.28846 .31523 L
.26923 .30825 L
.26778 .30769 L
.25 .29969 L
.23077 .28948 L
.22894 .28846 L
.21154 .27775 L
.19928 .26923 L
.19231 .26431 L
.1755 .25 L
.17308 .24857 L
.15682 .23077 L
.15385 .22701 L
.14368 .21154 L
.13835 .19231 L
F
0 g
.15385 .17502 m
.17308 .17314 L
.19231 .17566 L
.21154 .18107 L
.23077 .18836 L
.24018 .19231 L
.25 .19702 L
.26923 .20749 L
.27614 .21154 L
.28846 .21933 L
.30431 .23077 L
.30769 .23311 L
.3269 .25 L
.32692 .25 L
.34441 .26923 L
.34615 .27162 L
.3561 .28846 L
.35891 .30769 L
.34615 .31981 L
.32692 .32367 L
.30769 .3205 L
.28846 .31523 L
.26923 .30825 L
.26778 .30769 L
.25 .29969 L
.23077 .28948 L
.22894 .28846 L
.21154 .27775 L
.19928 .26923 L
.19231 .26431 L
.1755 .25 L
.17308 .24857 L
.15682 .23077 L
.15385 .22701 L
.14368 .21154 L
.13835 .19231 L
.15385 .17502 L
s
.7 g
.17308 .18111 m
.19231 .18417 L
.21154 .18901 L
.22351 .19231 L
.23077 .19546 L
.25 .20433 L
.26355 .21154 L
.26923 .21461 L
.28846 .22735 L
.2931 .23077 L
.30769 .24172 L
.31606 .25 L
.32692 .25751 L
.33301 .26923 L
.34284 .28846 L
.33594 .30769 L
.32692 .31196 L
.30769 .3114 L
.29028 .30769 L
.28846 .30736 L
.26923 .30109 L
.25 .29234 L
.2422 .28846 L
.23077 .28236 L
.21154 .2698 L
.21073 .26923 L
.19231 .25551 L
.18637 .25 L
.17308 .23853 L
.16803 .23077 L
.15635 .21154 L
.15706 .19231 L
F
0 g
.17308 .18111 m
.19231 .18417 L
.21154 .18901 L
.22351 .19231 L
.23077 .19546 L
.25 .20433 L
.26355 .21154 L
.26923 .21461 L
.28846 .22735 L
.2931 .23077 L
.30769 .24172 L
.31606 .25 L
.32692 .25751 L
.33301 .26923 L
.34284 .28846 L
.33594 .30769 L
.32692 .31196 L
.30769 .3114 L
.29028 .30769 L
.28846 .30736 L
.26923 .30109 L
.25 .29234 L
.2422 .28846 L
.23077 .28236 L
.21154 .2698 L
.21073 .26923 L
.19231 .25551 L
.18637 .25 L
.17308 .23853 L
.16803 .23077 L
.15635 .21154 L
.15706 .19231 L
.17308 .18111 L
s
.8 g
.17308 .20181 m
.19231 .19485 L
.21154 .19477 L
.23077 .20283 L
.24954 .21154 L
.25 .21168 L
.26923 .22201 L
.28172 .23077 L
.28846 .23286 L
.30506 .25 L
.30769 .25283 L
.32135 .26923 L
.32692 .28453 L
.32703 .28846 L
.32692 .28896 L
.30769 .30072 L
.28846 .30057 L
.26923 .29331 L
.25628 .28846 L
.25 .2859 L
.23077 .27467 L
.22245 .26923 L
.21154 .2634 L
.1973 .25 L
.19231 .24506 L
.1794 .23077 L
.17308 .21922 L
.17058 .21154 L
F
0 g
.17308 .20181 m
.19231 .19485 L
.21154 .19477 L
.23077 .20283 L
.24954 .21154 L
.25 .21168 L
.26923 .22201 L
.28172 .23077 L
.28846 .23286 L
.30506 .25 L
.30769 .25283 L
.32135 .26923 L
.32692 .28453 L
.32703 .28846 L
.32692 .28896 L
.30769 .30072 L
.28846 .30057 L
.26923 .29331 L
.25628 .28846 L
.25 .2859 L
.23077 .27467 L
.22245 .26923 L
.21154 .2634 L
.1973 .25 L
.19231 .24506 L
.1794 .23077 L
.17308 .21922 L
.17058 .21154 L
.17308 .20181 L
s
.9 g
.19231 .2099 m
.21154 .20493 L
.22939 .21154 L
.23077 .21201 L
.25 .21651 L
.26892 .23077 L
.26923 .2313 L
.28846 .24353 L
.293 .25 L
.30737 .26923 L
.29815 .28846 L
.28846 .28875 L
.28659 .28846 L
.26923 .28435 L
.25 .2784 L
.23457 .26923 L
.23077 .26576 L
.21154 .25224 L
.20955 .25 L
.19243 .23077 L
.19231 .23006 L
.19045 .21154 L
F
0 g
.19231 .2099 m
.21154 .20493 L
.22939 .21154 L
.23077 .21201 L
.25 .21651 L
.26892 .23077 L
.26923 .2313 L
.28846 .24353 L
.293 .25 L
.30737 .26923 L
.29815 .28846 L
.28846 .28875 L
.28659 .28846 L
.26923 .28435 L
.25 .2784 L
.23457 .26923 L
.23077 .26576 L
.21154 .25224 L
.20955 .25 L
.19243 .23077 L
.19231 .23006 L
.19045 .21154 L
.19231 .2099 L
s
1 g
.21154 .22563 m
.23077 .22325 L
.25 .23024 L
.25095 .23077 L
.26923 .2428 L
.28153 .25 L
.287 .26923 L
.26923 .27299 L
.25677 .26923 L
.25 .26621 L
.23077 .25463 L
.22268 .25 L
.21154 .23356 L
.20994 .23077 L
F
0 g
.21154 .22563 m
.23077 .22325 L
.25 .23024 L
.25095 .23077 L
.26923 .2428 L
.28153 .25 L
.287 .26923 L
.26923 .27299 L
.25677 .26923 L
.25 .26621 L
.23077 .25463 L
.22268 .25 L
.21154 .23356 L
.20994 .23077 L
.21154 .22563 L
s
.1 g
.71154 .47745 m
.73077 .47292 L
.75 .46901 L
.76923 .46606 L
.78846 .46428 L
.80769 .46384 L
.82692 .46498 L
.84615 .46812 L
.86538 .47403 L
.87891 .48077 L
.88462 .48459 L
.89921 .5 L
.90385 .50854 L
.9073 .51923 L
.90867 .53846 L
.90544 .55769 L
.90385 .56476 L
.89845 .57692 L
.88838 .59615 L
.88462 .60249 L
.87552 .61538 L
.86538 .62857 L
.86017 .63462 L
.84615 .64994 L
.84227 .65385 L
.82692 .66845 L
.82177 .67308 L
.80769 .68491 L
.79859 .69231 L
.78846 .6998 L
.77262 .71154 L
.76923 .71369 L
.75 .72639 L
.74328 .73077 L
.73077 .73776 L
.71154 .74911 L
.70997 .75 L
.69231 .75853 L
.67308 .76833 L
.67122 .76923 L
.65385 .77615 L
.63462 .78426 L
.6241 .78846 L
.61538 .79106 L
.59615 .79711 L
.57692 .80285 L
.55805 .80769 L
.55769 .80776 L
.53846 .81108 L
.51923 .81379 L
.5 .81551 L
.48077 .81597 L
.46154 .81488 L
.44231 .81181 L
.42762 .80769 L
.42308 .80589 L
.40385 .7951 L
.39643 .78846 L
.38462 .77092 L
.38407 .76923 L
.38013 .75 L
.38152 .73077 L
.38462 .71814 L
.3869 .71154 L
.39576 .69231 L
.40385 .67811 L
.40729 .67308 L
.42157 .65385 L
.42308 .65194 L
.43848 .63462 L
.44231 .63056 L
.45782 .61538 L
.46154 .61199 L
.47967 .59615 L
.48077 .59529 L
.5 .58028 L
.50443 .57692 L
.51923 .56676 L
.53228 .55769 L
.53846 .55409 L
.55769 .54212 L
.56366 .53846 L
.57692 .53169 L
.59615 .5211 L
.59967 .51923 L
.61538 .51244 L
.63462 .50351 L
.64254 .5 L
.65385 .49616 L
.67308 .48916 L
.69231 .4825 L
.69773 .48077 L
F
0 g
.71154 .47745 m
.73077 .47292 L
.75 .46901 L
.76923 .46606 L
.78846 .46428 L
.80769 .46384 L
.82692 .46498 L
.84615 .46812 L
.86538 .47403 L
.87891 .48077 L
.88462 .48459 L
.89921 .5 L
.90385 .50854 L
.9073 .51923 L
.90867 .53846 L
.90544 .55769 L
.90385 .56476 L
.89845 .57692 L
.88838 .59615 L
.88462 .60249 L
.87552 .61538 L
.86538 .62857 L
.86017 .63462 L
.84615 .64994 L
.84227 .65385 L
.82692 .66845 L
.82177 .67308 L
.80769 .68491 L
.79859 .69231 L
.78846 .6998 L
.77262 .71154 L
.76923 .71369 L
.75 .72639 L
.74328 .73077 L
.73077 .73776 L
.71154 .74911 L
.70997 .75 L
.69231 .75853 L
.67308 .76833 L
.67122 .76923 L
.65385 .77615 L
.63462 .78426 L
.6241 .78846 L
.61538 .79106 L
.59615 .79711 L
.57692 .80285 L
.55805 .80769 L
.55769 .80776 L
.53846 .81108 L
.51923 .81379 L
Mistroke
.5 .81551 L
.48077 .81597 L
.46154 .81488 L
.44231 .81181 L
.42762 .80769 L
.42308 .80589 L
.40385 .7951 L
.39643 .78846 L
.38462 .77092 L
.38407 .76923 L
.38013 .75 L
.38152 .73077 L
.38462 .71814 L
.3869 .71154 L
.39576 .69231 L
.40385 .67811 L
.40729 .67308 L
.42157 .65385 L
.42308 .65194 L
.43848 .63462 L
.44231 .63056 L
.45782 .61538 L
.46154 .61199 L
.47967 .59615 L
.48077 .59529 L
.5 .58028 L
.50443 .57692 L
.51923 .56676 L
.53228 .55769 L
.53846 .55409 L
.55769 .54212 L
.56366 .53846 L
.57692 .53169 L
.59615 .5211 L
.59967 .51923 L
.61538 .51244 L
.63462 .50351 L
.64254 .5 L
.65385 .49616 L
.67308 .48916 L
.69231 .4825 L
.69773 .48077 L
.71154 .47745 L
Mfstroke
.2 g
.75 .49779 m
.76923 .49656 L
.78846 .49698 L
.80769 .49964 L
.80947 .5 L
.82692 .5057 L
.84615 .51868 L
.84667 .51923 L
.85782 .53846 L
.85974 .55769 L
.85589 .57692 L
.84781 .59615 L
.84615 .59948 L
.83604 .61538 L
.82692 .62775 L
.82111 .63462 L
.80769 .64926 L
.80306 .65385 L
.78846 .66738 L
.78185 .67308 L
.76923 .68321 L
.75728 .69231 L
.75 .69737 L
.73077 .71035 L
.72892 .71154 L
.71154 .72175 L
.69569 .73077 L
.69231 .73243 L
.67308 .74186 L
.65564 .75 L
.65385 .7507 L
.63462 .75814 L
.61538 .76513 L
.60279 .76923 L
.59615 .77099 L
.57692 .77572 L
.55769 .77957 L
.53846 .78225 L
.51923 .78351 L
.5 .78303 L
.48077 .78028 L
.46154 .77409 L
.45249 .76923 L
.44231 .76168 L
.43442 .75 L
.42913 .73077 L
.43069 .71154 L
.43705 .69231 L
.44231 .68069 L
.44723 .67308 L
.46076 .65385 L
.46154 .65284 L
.47751 .63462 L
.48077 .6312 L
.4973 .61538 L
.5 .613 L
.51923 .597 L
.52031 .59615 L
.53846 .58288 L
.547 .57692 L
.55769 .57015 L
.57692 .55826 L
.57789 .55769 L
.59615 .54795 L
.61455 .53846 L
.61538 .5381 L
.63462 .52975 L
.65385 .52178 L
.66046 .51923 L
.67308 .51515 L
.69231 .50929 L
.71154 .50425 L
.73077 .50031 L
.73165 .5 L
F
0 g
.75 .49779 m
.76923 .49656 L
.78846 .49698 L
.80769 .49964 L
.80947 .5 L
.82692 .5057 L
.84615 .51868 L
.84667 .51923 L
.85782 .53846 L
.85974 .55769 L
.85589 .57692 L
.84781 .59615 L
.84615 .59948 L
.83604 .61538 L
.82692 .62775 L
.82111 .63462 L
.80769 .64926 L
.80306 .65385 L
.78846 .66738 L
.78185 .67308 L
.76923 .68321 L
.75728 .69231 L
.75 .69737 L
.73077 .71035 L
.72892 .71154 L
.71154 .72175 L
.69569 .73077 L
.69231 .73243 L
.67308 .74186 L
.65564 .75 L
.65385 .7507 L
.63462 .75814 L
.61538 .76513 L
.60279 .76923 L
.59615 .77099 L
.57692 .77572 L
.55769 .77957 L
.53846 .78225 L
.51923 .78351 L
.5 .78303 L
.48077 .78028 L
.46154 .77409 L
.45249 .76923 L
.44231 .76168 L
.43442 .75 L
.42913 .73077 L
.43069 .71154 L
.43705 .69231 L
.44231 .68069 L
.44723 .67308 L
Mistroke
.46076 .65385 L
.46154 .65284 L
.47751 .63462 L
.48077 .6312 L
.4973 .61538 L
.5 .613 L
.51923 .597 L
.52031 .59615 L
.53846 .58288 L
.547 .57692 L
.55769 .57015 L
.57692 .55826 L
.57789 .55769 L
.59615 .54795 L
.61455 .53846 L
.61538 .5381 L
.63462 .52975 L
.65385 .52178 L
.66046 .51923 L
.67308 .51515 L
.69231 .50929 L
.71154 .50425 L
.73077 .50031 L
.73165 .5 L
.75 .49779 L
Mfstroke
.3 g
.73077 .51874 m
.75 .5173 L
.76923 .51778 L
.78032 .51923 L
.78846 .52098 L
.80769 .52865 L
.81899 .53846 L
.82692 .55323 L
.82799 .55769 L
.82764 .57692 L
.82692 .58025 L
.82143 .59615 L
.81075 .61538 L
.80769 .62006 L
.79619 .63462 L
.78846 .64337 L
.77802 .65385 L
.76923 .662 L
.75616 .67308 L
.75 .6779 L
.73077 .69195 L
.73025 .69231 L
.71154 .70426 L
.69934 .71154 L
.69231 .71533 L
.67308 .72525 L
.66152 .73077 L
.65385 .73401 L
.63462 .74169 L
.61538 .74846 L
.61062 .75 L
.59615 .75389 L
.57692 .75821 L
.55769 .76125 L
.53846 .76273 L
.51923 .76221 L
.5 .75895 L
.48077 .75082 L
.47952 .75 L
.46329 .73077 L
.46154 .72529 L
.46022 .71154 L
.46154 .70166 L
.46409 .69231 L
.47294 .67308 L
.48077 .66024 L
.48582 .65385 L
.5 .63708 L
.50239 .63462 L
.51923 .61835 L
.52262 .61538 L
.53846 .60241 L
.54672 .59615 L
.55769 .58846 L
.57526 .57692 L
.57692 .57594 L
.59615 .56491 L
.60967 .55769 L
.61538 .55497 L
.63462 .5462 L
.65345 .53846 L
.65385 .53832 L
.67308 .53184 L
.69231 .52623 L
.71154 .52179 L
.72565 .51923 L
F
0 g
.73077 .51874 m
.75 .5173 L
.76923 .51778 L
.78032 .51923 L
.78846 .52098 L
.80769 .52865 L
.81899 .53846 L
.82692 .55323 L
.82799 .55769 L
.82764 .57692 L
.82692 .58025 L
.82143 .59615 L
.81075 .61538 L
.80769 .62006 L
.79619 .63462 L
.78846 .64337 L
.77802 .65385 L
.76923 .662 L
.75616 .67308 L
.75 .6779 L
.73077 .69195 L
.73025 .69231 L
.71154 .70426 L
.69934 .71154 L
.69231 .71533 L
.67308 .72525 L
.66152 .73077 L
.65385 .73401 L
.63462 .74169 L
.61538 .74846 L
.61062 .75 L
.59615 .75389 L
.57692 .75821 L
.55769 .76125 L
.53846 .76273 L
.51923 .76221 L
.5 .75895 L
.48077 .75082 L
.47952 .75 L
.46329 .73077 L
.46154 .72529 L
.46022 .71154 L
.46154 .70166 L
.46409 .69231 L
.47294 .67308 L
.48077 .66024 L
.48582 .65385 L
.5 .63708 L
.50239 .63462 L
.51923 .61835 L
Mistroke
.52262 .61538 L
.53846 .60241 L
.54672 .59615 L
.55769 .58846 L
.57526 .57692 L
.57692 .57594 L
.59615 .56491 L
.60967 .55769 L
.61538 .55497 L
.63462 .5462 L
.65345 .53846 L
.65385 .53832 L
.67308 .53184 L
.69231 .52623 L
.71154 .52179 L
.72565 .51923 L
.73077 .51874 L
Mfstroke
.4 g
.71154 .53617 m
.73077 .53408 L
.75 .53407 L
.76923 .53711 L
.77409 .53846 L
.78846 .54454 L
.79932 .55769 L
.80383 .57692 L
.79995 .59615 L
.79045 .61538 L
.78846 .61876 L
.77635 .63462 L
.76923 .64279 L
.75805 .65385 L
.75 .66118 L
.73545 .67308 L
.73077 .67661 L
.71154 .68999 L
.70793 .69231 L
.69231 .70161 L
.67389 .71154 L
.67308 .71193 L
.65385 .7208 L
.63462 .72859 L
.6287 .73077 L
.61538 .73499 L
.59615 .74015 L
.57692 .74392 L
.55769 .74601 L
.53846 .74597 L
.51923 .74298 L
.5 .73417 L
.49619 .73077 L
.48568 .71154 L
.48641 .69231 L
.49365 .67308 L
.5 .66086 L
.5058 .65385 L
.51923 .63763 L
.52225 .63462 L
.53846 .61916 L
.54293 .61538 L
.55769 .6037 L
.5682 .59615 L
.57692 .59035 L
.59615 .57858 L
.59907 .57692 L
.61538 .56838 L
.63462 .55932 L
.63834 .55769 L
.65385 .55167 L
.67308 .54514 L
.69231 .5399 L
.69731 .53846 L
F
0 g
.71154 .53617 m
.73077 .53408 L
.75 .53407 L
.76923 .53711 L
.77409 .53846 L
.78846 .54454 L
.79932 .55769 L
.80383 .57692 L
.79995 .59615 L
.79045 .61538 L
.78846 .61876 L
.77635 .63462 L
.76923 .64279 L
.75805 .65385 L
.75 .66118 L
.73545 .67308 L
.73077 .67661 L
.71154 .68999 L
.70793 .69231 L
.69231 .70161 L
.67389 .71154 L
.67308 .71193 L
.65385 .7208 L
.63462 .72859 L
.6287 .73077 L
.61538 .73499 L
.59615 .74015 L
.57692 .74392 L
.55769 .74601 L
.53846 .74597 L
.51923 .74298 L
.5 .73417 L
.49619 .73077 L
.48568 .71154 L
.48641 .69231 L
.49365 .67308 L
.5 .66086 L
.5058 .65385 L
.51923 .63763 L
.52225 .63462 L
.53846 .61916 L
.54293 .61538 L
.55769 .6037 L
.5682 .59615 L
.57692 .59035 L
.59615 .57858 L
.59907 .57692 L
.61538 .56838 L
.63462 .55932 L
.63834 .55769 L
Mistroke
.65385 .55167 L
.67308 .54514 L
.69231 .5399 L
.69731 .53846 L
.71154 .53617 L
Mfstroke
.5 g
.67308 .55697 m
.69231 .55223 L
.71154 .5492 L
.73077 .54832 L
.75 .55055 L
.76737 .55769 L
.76923 .55921 L
.78109 .57692 L
.78044 .59615 L
.77239 .61538 L
.76923 .6215 L
.75885 .63462 L
.75 .64479 L
.74041 .65385 L
.73077 .66235 L
.7169 .67308 L
.71154 .67691 L
.69231 .68938 L
.68731 .69231 L
.67308 .70002 L
.65385 .70921 L
.6485 .71154 L
.63462 .71688 L
.61538 .72317 L
.59615 .72791 L
.57771 .73077 L
.57692 .73085 L
.55769 .73161 L
.54716 .73077 L
.53846 .72939 L
.51923 .72272 L
.51109 .71154 L
.50702 .69231 L
.5122 .67308 L
.51923 .6601 L
.52345 .65385 L
.53846 .63577 L
.53976 .63462 L
.55769 .618 L
.56098 .61538 L
.57692 .60336 L
.58771 .59615 L
.59615 .59093 L
.61538 .58017 L
.6218 .57692 L
.63462 .57103 L
.65385 .56326 L
.67049 .55769 L
F
0 g
.67308 .55697 m
.69231 .55223 L
.71154 .5492 L
.73077 .54832 L
.75 .55055 L
.76737 .55769 L
.76923 .55921 L
.78109 .57692 L
.78044 .59615 L
.77239 .61538 L
.76923 .6215 L
.75885 .63462 L
.75 .64479 L
.74041 .65385 L
.73077 .66235 L
.7169 .67308 L
.71154 .67691 L
.69231 .68938 L
.68731 .69231 L
.67308 .70002 L
.65385 .70921 L
.6485 .71154 L
.63462 .71688 L
.61538 .72317 L
.59615 .72791 L
.57771 .73077 L
.57692 .73085 L
.55769 .73161 L
.54716 .73077 L
.53846 .72939 L
.51923 .72272 L
.51109 .71154 L
.50702 .69231 L
.5122 .67308 L
.51923 .6601 L
.52345 .65385 L
.53846 .63577 L
.53976 .63462 L
.55769 .618 L
.56098 .61538 L
.57692 .60336 L
.58771 .59615 L
.59615 .59093 L
.61538 .58017 L
.6218 .57692 L
.63462 .57103 L
.65385 .56326 L
.67049 .55769 L
.67308 .55697 L
s
.6 g
.65385 .57428 m
.67308 .5682 L
.69231 .56397 L
.71154 .56196 L
.73077 .5628 L
.75 .56903 L
.75626 .57692 L
.76117 .59615 L
.75516 .61538 L
.75 .62832 L
.74234 .63462 L
.73077 .64787 L
.72371 .65385 L
.71154 .66414 L
.69899 .67308 L
.69231 .67752 L
.67308 .68884 L
.66635 .69231 L
.65385 .6982 L
.63462 .70595 L
.61678 .71154 L
.61538 .71188 L
.59615 .71604 L
.57692 .71797 L
.55769 .71673 L
.54126 .71154 L
.53846 .7087 L
.52799 .69231 L
.5301 .67308 L
.53846 .65643 L
.54016 .65385 L
.55629 .63462 L
.55769 .63315 L
.57692 .61631 L
.57822 .61538 L
.59615 .60268 L
.60698 .59615 L
.61538 .59146 L
.63462 .58196 L
.64661 .57692 L
F
0 g
.65385 .57428 m
.67308 .5682 L
.69231 .56397 L
.71154 .56196 L
.73077 .5628 L
.75 .56903 L
.75626 .57692 L
.76117 .59615 L
.75516 .61538 L
.75 .62832 L
.74234 .63462 L
.73077 .64787 L
.72371 .65385 L
.71154 .66414 L
.69899 .67308 L
.69231 .67752 L
.67308 .68884 L
.66635 .69231 L
.65385 .6982 L
.63462 .70595 L
.61678 .71154 L
.61538 .71188 L
.59615 .71604 L
.57692 .71797 L
.55769 .71673 L
.54126 .71154 L
.53846 .7087 L
.52799 .69231 L
.5301 .67308 L
.53846 .65643 L
.54016 .65385 L
.55629 .63462 L
.55769 .63315 L
.57692 .61631 L
.57822 .61538 L
.59615 .60268 L
.60698 .59615 L
.61538 .59146 L
.63462 .58196 L
.64661 .57692 L
.65385 .57428 L
s
.7 g
.69231 .57643 m
.71154 .57642 L
.71478 .57692 L
.73077 .58294 L
.7402 .59615 L
.73757 .61538 L
.73077 .62774 L
.72581 .63462 L
.71154 .6511 L
.70689 .65385 L
.69231 .66558 L
.68035 .67308 L
.67308 .67742 L
.65385 .68735 L
.64188 .69231 L
.63462 .69487 L
.61538 .70063 L
.59615 .70408 L
.57692 .70473 L
.55769 .69978 L
.55258 .69231 L
.54874 .67308 L
.55702 .65385 L
.55769 .65242 L
.57284 .63462 L
.57692 .6304 L
.59586 .61538 L
.59615 .61517 L
.61538 .60264 L
.628 .59615 L
.63462 .59303 L
.65385 .58513 L
.67308 .57947 L
.68813 .57692 L
F
0 g
.69231 .57643 m
.71154 .57642 L
.71478 .57692 L
.73077 .58294 L
.7402 .59615 L
.73757 .61538 L
.73077 .62774 L
.72581 .63462 L
.71154 .6511 L
.70689 .65385 L
.69231 .66558 L
.68035 .67308 L
.67308 .67742 L
.65385 .68735 L
.64188 .69231 L
.63462 .69487 L
.61538 .70063 L
.59615 .70408 L
.57692 .70473 L
.55769 .69978 L
.55258 .69231 L
.54874 .67308 L
.55702 .65385 L
.55769 .65242 L
.57284 .63462 L
.57692 .6304 L
.59586 .61538 L
.59615 .61517 L
.61538 .60264 L
.628 .59615 L
.63462 .59303 L
.65385 .58513 L
.67308 .57947 L
.68813 .57692 L
.69231 .57643 L
s
.8 g
.67308 .59203 m
.69231 .58992 L
.71067 .59615 L
.71154 .59679 L
.71784 .61538 L
.71154 .62925 L
.70799 .63462 L
.69231 .65061 L
.68862 .65385 L
.67308 .66587 L
.65836 .67308 L
.65385 .67527 L
.63462 .6836 L
.61538 .68931 L
.59615 .68904 L
.57692 .68281 L
.57063 .67308 L
.5754 .65385 L
.57692 .65136 L
.59069 .63462 L
.59615 .62879 L
.61538 .61561 L
.61569 .61538 L
.63462 .60427 L
.65385 .5968 L
.65749 .59615 L
F
0 g
.67308 .59203 m
.69231 .58992 L
.71067 .59615 L
.71154 .59679 L
.71784 .61538 L
.71154 .62925 L
.70799 .63462 L
.69231 .65061 L
.68862 .65385 L
.67308 .66587 L
.65836 .67308 L
.65385 .67527 L
.63462 .6836 L
.61538 .68931 L
.59615 .68904 L
.57692 .68281 L
.57063 .67308 L
.5754 .65385 L
.57692 .65136 L
.59069 .63462 L
.59615 .62879 L
.61538 .61561 L
.61569 .61538 L
.63462 .60427 L
.65385 .5968 L
.65749 .59615 L
.67308 .59203 L
s
.9 g
.65385 .61123 m
.67308 .60952 L
.68836 .61538 L
.68703 .63462 L
.67308 .64748 L
.66688 .65385 L
.65385 .66367 L
.63462 .66774 L
.61538 .67052 L
.59929 .65385 L
.61306 .63462 L
.61538 .63281 L
.63462 .62017 L
.64503 .61538 L
F
0 g
.65385 .61123 m
.67308 .60952 L
.68836 .61538 L
.68703 .63462 L
.67308 .64748 L
.66688 .65385 L
.65385 .66367 L
.63462 .66774 L
.61538 .67052 L
.59929 .65385 L
.61306 .63462 L
.61538 .63281 L
.63462 .62017 L
.64503 .61538 L
.65385 .61123 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.522676 0.0238095 0.97619 0.477324 MathSubStart
%% SurfaceGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.11022e-16 1.04977 -0.0679587 1.04977 [
[ 0 0 0 0 ]
[ 1 .81114 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.39787 .81114 L
s
.39787 .81114 m
.40529 .59895 L
s
.40529 .59895 m
.03716 .25514 L
s
.68874 0 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.68874 0 m
.03716 .25514 L
s
.40529 .59895 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.39787 .81114 L
s
.39787 .81114 m
.40529 .59895 L
s
0 0 m
1 0 L
1 .81114 L
0 .81114 L
closepath
clip
newpath
.664 .741 .908 r
.39902 .59803 .40512 .60371 .41537 .60064 .40929 .59494 Mtetra
.40929 .59494 .41537 .60064 .42565 .59755 .4196 .59183 Mtetra
.4196 .59183 .42565 .59755 .43597 .59446 .42994 .58871 Mtetra
.42994 .58871 .43597 .59446 .44633 .59135 .44033 .58558 Mtetra
.44033 .58558 .44633 .59135 .45674 .58823 .45076 .58244 Mtetra
.45076 .58244 .45674 .58823 .46718 .5851 .46122 .57928 Mtetra
.663 .741 .908 r
.46122 .57928 .46718 .5851 .47766 .58195 .47173 .57612 Mtetra
.47173 .57612 .47766 .58195 .48818 .5788 .48228 .57294 Mtetra
.48228 .57294 .48818 .5788 .49874 .57563 .49287 .56975 Mtetra
.49287 .56975 .49874 .57563 .50935 .57245 .5035 .56655 Mtetra
.5035 .56655 .50935 .57245 .51999 .56926 .51417 .56334 Mtetra
.663 .742 .908 r
.51417 .56334 .51999 .56926 .53068 .56605 .52489 .56011 Mtetra
.52489 .56011 .53068 .56605 .54141 .56284 .53564 .55688 Mtetra
.53564 .55688 .54141 .56284 .55218 .55961 .54644 .55363 Mtetra
.54644 .55363 .55218 .55961 .56299 .55636 .55728 .55036 Mtetra
.55728 .55036 .56299 .55636 .57385 .55311 .56816 .54709 Mtetra
.56816 .54709 .57385 .55311 .58474 .54984 .57909 .54379 Mtetra
.664 .742 .909 r
.57909 .54379 .58474 .54984 .59568 .54656 .59006 .54049 Mtetra
.59006 .54049 .59568 .54656 .60667 .54326 .60107 .53717 Mtetra
.664 .742 .908 r
.60107 .53717 .60667 .54326 .61769 .53995 .61213 .53383 Mtetra
.61213 .53383 .61769 .53995 .62876 .53663 .62323 .53048 Mtetra
.62323 .53048 .62876 .53663 .63988 .53329 .63437 .52712 Mtetra
.63437 .52712 .63988 .53329 .65104 .52994 .64556 .52374 Mtetra
.64556 .52374 .65104 .52994 .66224 .52658 .65679 .52035 Mtetra
.65679 .52035 .66224 .52658 .67349 .52321 .66807 .51695 Mtetra
.66807 .51695 .67349 .52321 .68478 .51982 .67939 .51353 Mtetra
.67939 .51353 .68478 .51982 .69612 .51642 .69076 .5101 Mtetra
.664 .741 .908 r
.69076 .5101 .69612 .51642 .7075 .513 .70218 .50666 Mtetra
.70218 .50666 .7075 .513 .71893 .50957 .71364 .50321 Mtetra
.71364 .50321 .71893 .50957 .73041 .50613 .72515 .49974 Mtetra
.72515 .49974 .73041 .50613 .74193 .50267 .7367 .49625 Mtetra
.7367 .49625 .74193 .50267 .7535 .4992 .7483 .49276 Mtetra
.7483 .49276 .7535 .4992 .76511 .49572 .75995 .48925 Mtetra
.75995 .48925 .76511 .49572 .77677 .49222 .77165 .48572 Mtetra
.77165 .48572 .77677 .49222 .78848 .48871 .78339 .48218 Mtetra
.78339 .48218 .78848 .48871 .80024 .48518 .79518 .47863 Mtetra
.79518 .47863 .80024 .48518 .81205 .48164 .80702 .47506 Mtetra
.80702 .47506 .81205 .48164 .8239 .47808 .81891 .47148 Mtetra
.81891 .47148 .8239 .47808 .8358 .47451 .83085 .46788 Mtetra
.83085 .46788 .8358 .47451 .84775 .47092 .84283 .46427 Mtetra
.84283 .46427 .84775 .47092 .85976 .46732 .85487 .46064 Mtetra
.85487 .46064 .85976 .46732 .87181 .46371 .86696 .45699 Mtetra
.86696 .45699 .87181 .46371 .88391 .46008 .87909 .45334 Mtetra
.87909 .45334 .88391 .46008 .89606 .45643 .89128 .44966 Mtetra
.89128 .44966 .89606 .45643 .90826 .45277 .90352 .44598 Mtetra
.90352 .44598 .90826 .45277 .92051 .4491 .91581 .44227 Mtetra
.91581 .44227 .92051 .4491 .93281 .44541 .92815 .43855 Mtetra
.92815 .43855 .93281 .44541 .94517 .4417 .94054 .43482 Mtetra
.94054 .43482 .94517 .4417 .95757 .43798 .95299 .43107 Mtetra
.95299 .43107 .95757 .43798 .97003 .43424 .96548 .4273 Mtetra
.39287 .59231 .39902 .59803 .40929 .59494 .40317 .58919 Mtetra
.40317 .58919 .40929 .59494 .4196 .59183 .4135 .58606 Mtetra
.4135 .58606 .4196 .59183 .42994 .58871 .42387 .58292 Mtetra
.42387 .58292 .42994 .58871 .44033 .58558 .43428 .57977 Mtetra
.43428 .57977 .44033 .58558 .45076 .58244 .44474 .5766 Mtetra
.663 .741 .908 r
.44474 .5766 .45076 .58244 .46122 .57928 .45523 .57343 Mtetra
.45523 .57343 .46122 .57928 .47173 .57612 .46576 .57024 Mtetra
.46576 .57024 .47173 .57612 .48228 .57294 .47634 .56704 Mtetra
.47634 .56704 .48228 .57294 .49287 .56975 .48695 .56383 Mtetra
.48695 .56383 .49287 .56975 .5035 .56655 .49761 .56061 Mtetra
.663 .742 .908 r
.49761 .56061 .5035 .56655 .51417 .56334 .50831 .55738 Mtetra
.50831 .55738 .51417 .56334 .52489 .56011 .51905 .55414 Mtetra
.663 .742 .909 r
.51905 .55414 .52489 .56011 .53564 .55688 .52983 .55089 Mtetra
.52983 .55089 .53564 .55688 .54644 .55363 .54066 .54762 Mtetra
.54066 .54762 .54644 .55363 .55728 .55036 .55153 .54434 Mtetra
.663 .743 .909 r
.55153 .54434 .55728 .55036 .56816 .54709 .56244 .54105 Mtetra
.56244 .54105 .56816 .54709 .57909 .54379 .5734 .53774 Mtetra
.5734 .53774 .57909 .54379 .59006 .54049 .58439 .53441 Mtetra
.664 .743 .909 r
.58439 .53441 .59006 .54049 .60107 .53717 .59544 .53107 Mtetra
.59544 .53107 .60107 .53717 .61213 .53383 .60652 .52771 Mtetra
.60652 .52771 .61213 .53383 .62323 .53048 .61765 .52433 Mtetra
.61765 .52433 .62323 .53048 .63437 .52712 .62882 .52093 Mtetra
.62882 .52093 .63437 .52712 .64556 .52374 .64004 .51752 Mtetra
.64004 .51752 .64556 .52374 .65679 .52035 .65131 .5141 Mtetra
.65131 .5141 .65679 .52035 .66807 .51695 .66262 .51067 Mtetra
.664 .742 .908 r
.66262 .51067 .66807 .51695 .67939 .51353 .67397 .50722 Mtetra
.67397 .50722 .67939 .51353 .69076 .5101 .68537 .50376 Mtetra
.68537 .50376 .69076 .5101 .70218 .50666 .69682 .50028 Mtetra
.69682 .50028 .70218 .50666 .71364 .50321 .70831 .4968 Mtetra
.70831 .4968 .71364 .50321 .72515 .49974 .71985 .4933 Mtetra
.664 .741 .908 r
.71985 .4933 .72515 .49974 .7367 .49625 .73144 .48979 Mtetra
.73144 .48979 .7367 .49625 .7483 .49276 .74307 .48627 Mtetra
.74307 .48627 .7483 .49276 .75995 .48925 .75475 .48273 Mtetra
.75475 .48273 .75995 .48925 .77165 .48572 .76648 .47918 Mtetra
.76648 .47918 .77165 .48572 .78339 .48218 .77826 .47561 Mtetra
.77826 .47561 .78339 .48218 .79518 .47863 .79008 .47203 Mtetra
.79008 .47203 .79518 .47863 .80702 .47506 .80196 .46843 Mtetra
.80196 .46843 .80702 .47506 .81891 .47148 .81388 .46482 Mtetra
.81388 .46482 .81891 .47148 .83085 .46788 .82585 .4612 Mtetra
.82585 .4612 .83085 .46788 .84283 .46427 .83788 .45756 Mtetra
.83788 .45756 .84283 .46427 .85487 .46064 .84995 .4539 Mtetra
.84995 .4539 .85487 .46064 .86696 .45699 .86207 .45023 Mtetra
.86207 .45023 .86696 .45699 .87909 .45334 .87424 .44654 Mtetra
.87424 .44654 .87909 .45334 .89128 .44966 .88647 .44284 Mtetra
.88647 .44284 .89128 .44966 .90352 .44598 .89874 .43913 Mtetra
.89874 .43913 .90352 .44598 .91581 .44227 .91107 .43539 Mtetra
.91107 .43539 .91581 .44227 .92815 .43855 .92345 .43164 Mtetra
.92345 .43164 .92815 .43855 .94054 .43482 .93588 .42788 Mtetra
.93588 .42788 .94054 .43482 .95299 .43107 .94836 .4241 Mtetra
.94836 .4241 .95299 .43107 .96548 .4273 .9609 .4203 Mtetra
.38668 .58654 .39287 .59231 .40317 .58919 .397 .5834 Mtetra
.397 .5834 .40317 .58919 .4135 .58606 .40736 .58025 Mtetra
.40736 .58025 .4135 .58606 .42387 .58292 .41776 .57709 Mtetra
.41776 .57709 .42387 .58292 .43428 .57977 .42819 .57392 Mtetra
.663 .741 .908 r
.42819 .57392 .43428 .57977 .44474 .5766 .43867 .57073 Mtetra
.43867 .57073 .44474 .5766 .45523 .57343 .44919 .56753 Mtetra
.44919 .56753 .45523 .57343 .46576 .57024 .45975 .56432 Mtetra
.45975 .56432 .46576 .57024 .47634 .56704 .47035 .56111 Mtetra
.47035 .56111 .47634 .56704 .48695 .56383 .48099 .55788 Mtetra
.663 .742 .908 r
.48099 .55788 .48695 .56383 .49761 .56061 .49168 .55464 Mtetra
.663 .742 .909 r
.49168 .55464 .49761 .56061 .50831 .55738 .5024 .5514 Mtetra
.5024 .5514 .50831 .55738 .51905 .55414 .51317 .54814 Mtetra
.51317 .54814 .51905 .55414 .52983 .55089 .52398 .54488 Mtetra
.662 .743 .91 r
.52398 .54488 .52983 .55089 .54066 .54762 .53484 .54161 Mtetra
.53484 .54161 .54066 .54762 .55153 .54434 .54574 .53832 Mtetra
.662 .744 .911 r
.54574 .53832 .55153 .54434 .56244 .54105 .55668 .53502 Mtetra
.663 .745 .911 r
.55668 .53502 .56244 .54105 .5734 .53774 .56766 .53171 Mtetra
.56766 .53171 .5734 .53774 .58439 .53441 .57869 .52837 Mtetra
.663 .746 .912 r
.57869 .52837 .58439 .53441 .59544 .53107 .58976 .52501 Mtetra
.58976 .52501 .59544 .53107 .60652 .52771 .60087 .52162 Mtetra
.664 .746 .912 r
.60087 .52162 .60652 .52771 .61765 .52433 .61203 .51822 Mtetra
.664 .746 .911 r
.61203 .51822 .61765 .52433 .62882 .52093 .62324 .51479 Mtetra
.62324 .51479 .62882 .52093 .64004 .51752 .63449 .51134 Mtetra
.63449 .51134 .64004 .51752 .65131 .5141 .64578 .50787 Mtetra
.664 .745 .91 r
.64578 .50787 .65131 .5141 .66262 .51067 .65712 .50439 Mtetra
.664 .744 .91 r
.65712 .50439 .66262 .51067 .67397 .50722 .66851 .5009 Mtetra
.664 .744 .909 r
.66851 .5009 .67397 .50722 .68537 .50376 .67994 .4974 Mtetra
.664 .743 .909 r
.67994 .4974 .68537 .50376 .69682 .50028 .69142 .49388 Mtetra
.69142 .49388 .69682 .50028 .70831 .4968 .70294 .49036 Mtetra
.664 .742 .908 r
.70294 .49036 .70831 .4968 .71985 .4933 .71451 .48683 Mtetra
.71451 .48683 .71985 .4933 .73144 .48979 .72613 .48329 Mtetra
.72613 .48329 .73144 .48979 .74307 .48627 .7378 .47973 Mtetra
.7378 .47973 .74307 .48627 .75475 .48273 .74951 .47616 Mtetra
.664 .741 .908 r
.74951 .47616 .75475 .48273 .76648 .47918 .76127 .47258 Mtetra
.76127 .47258 .76648 .47918 .77826 .47561 .77309 .46899 Mtetra
.77309 .46899 .77826 .47561 .79008 .47203 .78495 .46538 Mtetra
.78495 .46538 .79008 .47203 .80196 .46843 .79686 .46176 Mtetra
.79686 .46176 .80196 .46843 .81388 .46482 .80881 .45812 Mtetra
.80881 .45812 .81388 .46482 .82585 .4612 .82082 .45446 Mtetra
.82082 .45446 .82585 .4612 .83788 .45756 .83288 .4508 Mtetra
.83288 .4508 .83788 .45756 .84995 .4539 .84499 .44711 Mtetra
.84499 .44711 .84995 .4539 .86207 .45023 .85715 .44341 Mtetra
.85715 .44341 .86207 .45023 .87424 .44654 .86936 .4397 Mtetra
.86936 .4397 .87424 .44654 .88647 .44284 .88162 .43597 Mtetra
.88162 .43597 .88647 .44284 .89874 .43913 .89393 .43222 Mtetra
.89393 .43222 .89874 .43913 .91107 .43539 .9063 .42846 Mtetra
.9063 .42846 .91107 .43539 .92345 .43164 .91871 .42468 Mtetra
.91871 .42468 .92345 .43164 .93588 .42788 .93118 .42089 Mtetra
.93118 .42089 .93588 .42788 .94836 .4241 .94371 .41708 Mtetra
.94371 .41708 .94836 .4241 .9609 .4203 .95628 .41325 Mtetra
.38045 .58074 .38668 .58654 .397 .5834 .39079 .57758 Mtetra
.39079 .57758 .397 .5834 .40736 .58025 .40117 .5744 Mtetra
.40117 .5744 .40736 .58025 .41776 .57709 .4116 .57122 Mtetra
.4116 .57122 .41776 .57709 .42819 .57392 .42206 .56802 Mtetra
.663 .741 .908 r
.42206 .56802 .42819 .57392 .43867 .57073 .43256 .56481 Mtetra
.43256 .56481 .43867 .57073 .44919 .56753 .44311 .56159 Mtetra
.44311 .56159 .44919 .56753 .45975 .56432 .45369 .55837 Mtetra
.45369 .55837 .45975 .56432 .47035 .56111 .46432 .55513 Mtetra
.46432 .55513 .47035 .56111 .48099 .55788 .47499 .55188 Mtetra
.663 .742 .909 r
.47499 .55188 .48099 .55788 .49168 .55464 .4857 .54863 Mtetra
.662 .742 .909 r
.4857 .54863 .49168 .55464 .5024 .5514 .49646 .54538 Mtetra
.662 .742 .91 r
.49646 .54538 .5024 .5514 .51317 .54814 .50725 .54212 Mtetra
.662 .743 .91 r
.50725 .54212 .51317 .54814 .52398 .54488 .51809 .53887 Mtetra
.661 .744 .911 r
.51809 .53887 .52398 .54488 .53484 .54161 .52897 .5356 Mtetra
.661 .745 .912 r
.52897 .5356 .53484 .54161 .54574 .53832 .5399 .53234 Mtetra
.661 .746 .913 r
.5399 .53234 .54574 .53832 .55668 .53502 .55087 .52906 Mtetra
.661 .748 .914 r
.55087 .52906 .55668 .53502 .56766 .53171 .56188 .52576 Mtetra
.661 .749 .915 r
.56188 .52576 .56766 .53171 .57869 .52837 .57294 .52244 Mtetra
.662 .751 .916 r
.57294 .52244 .57869 .52837 .58976 .52501 .58404 .51908 Mtetra
.663 .752 .917 r
.58404 .51908 .58976 .52501 .60087 .52162 .59519 .51569 Mtetra
.663 .753 .917 r
.59519 .51569 .60087 .52162 .61203 .51822 .60638 .51226 Mtetra
.664 .753 .916 r
.60638 .51226 .61203 .51822 .62324 .51479 .61762 .50879 Mtetra
.665 .753 .916 r
.61762 .50879 .62324 .51479 .63449 .51134 .6289 .50529 Mtetra
.665 .752 .915 r
.6289 .50529 .63449 .51134 .64578 .50787 .64022 .50177 Mtetra
.666 .751 .914 r
.64022 .50177 .64578 .50787 .65712 .50439 .65159 .49822 Mtetra
.666 .75 .913 r
.65159 .49822 .65712 .50439 .66851 .5009 .66301 .49466 Mtetra
.666 .748 .912 r
.66301 .49466 .66851 .5009 .67994 .4974 .67447 .49109 Mtetra
.665 .747 .911 r
.67447 .49109 .67994 .4974 .69142 .49388 .68598 .48751 Mtetra
.665 .745 .91 r
.68598 .48751 .69142 .49388 .70294 .49036 .69753 .48393 Mtetra
.665 .744 .909 r
.69753 .48393 .70294 .49036 .71451 .48683 .70914 .48035 Mtetra
.664 .743 .909 r
.70914 .48035 .71451 .48683 .72613 .48329 .72079 .47676 Mtetra
.72079 .47676 .72613 .48329 .7378 .47973 .73249 .47316 Mtetra
.664 .742 .908 r
.73249 .47316 .7378 .47973 .74951 .47616 .74423 .46956 Mtetra
.74423 .46956 .74951 .47616 .76127 .47258 .75603 .46594 Mtetra
.75603 .46594 .76127 .47258 .77309 .46899 .76788 .46232 Mtetra
.664 .741 .908 r
.76788 .46232 .77309 .46899 .78495 .46538 .77977 .45868 Mtetra
.77977 .45868 .78495 .46538 .79686 .46176 .79171 .45503 Mtetra
.79171 .45503 .79686 .46176 .80881 .45812 .80371 .45136 Mtetra
.80371 .45136 .80881 .45812 .82082 .45446 .81575 .44768 Mtetra
.81575 .44768 .82082 .45446 .83288 .4508 .82785 .44398 Mtetra
.82785 .44398 .83288 .4508 .84499 .44711 .83999 .44027 Mtetra
.83999 .44027 .84499 .44711 .85715 .44341 .85219 .43654 Mtetra
.85219 .43654 .85715 .44341 .86936 .4397 .86443 .4328 Mtetra
.86443 .4328 .86936 .4397 .88162 .43597 .87673 .42904 Mtetra
.87673 .42904 .88162 .43597 .89393 .43222 .88908 .42526 Mtetra
.88908 .42526 .89393 .43222 .9063 .42846 .90148 .42147 Mtetra
.90148 .42147 .9063 .42846 .91871 .42468 .91394 .41767 Mtetra
.91394 .41767 .91871 .42468 .93118 .42089 .92645 .41384 Mtetra
.92645 .41384 .93118 .42089 .94371 .41708 .93901 .41 Mtetra
.93901 .41 .94371 .41708 .95628 .41325 .95162 .40615 Mtetra
.37417 .57489 .38045 .58074 .39079 .57758 .38454 .57171 Mtetra
.38454 .57171 .39079 .57758 .40117 .5744 .39494 .56851 Mtetra
.39494 .56851 .40117 .5744 .4116 .57122 .40539 .56531 Mtetra
.663 .741 .908 r
.40539 .56531 .4116 .57122 .42206 .56802 .41588 .56209 Mtetra
.41588 .56209 .42206 .56802 .43256 .56481 .42641 .55885 Mtetra
.42641 .55885 .43256 .56481 .44311 .56159 .43698 .55561 Mtetra
.43698 .55561 .44311 .56159 .45369 .55837 .44759 .55236 Mtetra
.44759 .55236 .45369 .55837 .46432 .55513 .45825 .54911 Mtetra
.663 .741 .909 r
.45825 .54911 .46432 .55513 .47499 .55188 .46894 .54585 Mtetra
.662 .742 .909 r
.46894 .54585 .47499 .55188 .4857 .54863 .47968 .54259 Mtetra
.662 .742 .91 r
.47968 .54259 .4857 .54863 .49646 .54538 .49046 .53933 Mtetra
.661 .742 .91 r
.49046 .53933 .49646 .54538 .50725 .54212 .50129 .53609 Mtetra
.66 .743 .912 r
.50129 .53609 .50725 .54212 .51809 .53887 .51215 .53285 Mtetra
.659 .744 .913 r
.51215 .53285 .51809 .53887 .52897 .5356 .52306 .52962 Mtetra
.658 .746 .915 r
.52306 .52962 .52897 .5356 .5399 .53234 .53402 .52641 Mtetra
.657 .749 .917 r
.53402 .52641 .5399 .53234 .55087 .52906 .54502 .52319 Mtetra
.657 .751 .919 r
.54502 .52319 .55087 .52906 .56188 .52576 .55606 .51996 Mtetra
.657 .755 .922 r
.55606 .51996 .56188 .52576 .57294 .52244 .56715 .51671 Mtetra
.658 .758 .924 r
.56715 .51671 .57294 .52244 .58404 .51908 .57829 .51341 Mtetra
.659 .761 .925 r
.57829 .51341 .58404 .51908 .59519 .51569 .58947 .51006 Mtetra
.661 .764 .926 r
.58947 .51006 .59519 .51569 .60638 .51226 .60069 .50664 Mtetra
.663 .766 .927 r
.60069 .50664 .60638 .51226 .61762 .50879 .61196 .50316 Mtetra
.665 .767 .926 r
.61196 .50316 .61762 .50879 .6289 .50529 .62327 .49961 Mtetra
.666 .767 .925 r
.62327 .49961 .6289 .50529 .64022 .50177 .63463 .496 Mtetra
.668 .765 .923 r
.63463 .496 .64022 .50177 .65159 .49822 .64603 .49235 Mtetra
.668 .762 .921 r
.64603 .49235 .65159 .49822 .66301 .49466 .65748 .48867 Mtetra
.668 .759 .919 r
.65748 .48867 .66301 .49466 .67447 .49109 .66897 .48498 Mtetra
.668 .756 .916 r
.66897 .48498 .67447 .49109 .68598 .48751 .68051 .48129 Mtetra
.667 .753 .914 r
.68051 .48129 .68598 .48751 .69753 .48393 .69209 .4776 Mtetra
.667 .75 .913 r
.69209 .4776 .69753 .48393 .70914 .48035 .70373 .47392 Mtetra
.666 .748 .911 r
.70373 .47392 .70914 .48035 .72079 .47676 .71541 .47026 Mtetra
.665 .746 .91 r
.71541 .47026 .72079 .47676 .73249 .47316 .72714 .46659 Mtetra
.665 .744 .909 r
.72714 .46659 .73249 .47316 .74423 .46956 .73892 .46294 Mtetra
.664 .743 .909 r
.73892 .46294 .74423 .46956 .75603 .46594 .75075 .45928 Mtetra
.664 .742 .908 r
.75075 .45928 .75603 .46594 .76788 .46232 .76263 .45561 Mtetra
.76263 .45561 .76788 .46232 .77977 .45868 .77456 .45194 Mtetra
.77456 .45194 .77977 .45868 .79171 .45503 .78653 .44825 Mtetra
.664 .741 .908 r
.78653 .44825 .79171 .45503 .80371 .45136 .79856 .44456 Mtetra
.79856 .44456 .80371 .45136 .81575 .44768 .81064 .44084 Mtetra
.81064 .44084 .81575 .44768 .82785 .44398 .82277 .43712 Mtetra
.82277 .43712 .82785 .44398 .83999 .44027 .83495 .43338 Mtetra
.83495 .43338 .83999 .44027 .85219 .43654 .84719 .42962 Mtetra
.84719 .42962 .85219 .43654 .86443 .4328 .85947 .42585 Mtetra
.85947 .42585 .86443 .4328 .87673 .42904 .87181 .42206 Mtetra
.87181 .42206 .87673 .42904 .88908 .42526 .88419 .41825 Mtetra
.88419 .41825 .88908 .42526 .90148 .42147 .89664 .41443 Mtetra
.89664 .41443 .90148 .42147 .91394 .41767 .90913 .4106 Mtetra
.90913 .4106 .91394 .41767 .92645 .41384 .92168 .40674 Mtetra
.92168 .40674 .92645 .41384 .93901 .41 .93428 .40287 Mtetra
.93428 .40287 .93901 .41 .95162 .40615 .94693 .39899 Mtetra
.36785 .56901 .37417 .57489 .38454 .57171 .37824 .5658 Mtetra
.37824 .5658 .38454 .57171 .39494 .56851 .38867 .56258 Mtetra
.38867 .56258 .39494 .56851 .40539 .56531 .39914 .55935 Mtetra
.663 .741 .908 r
.39914 .55935 .40539 .56531 .41588 .56209 .40966 .55611 Mtetra
.40966 .55611 .41588 .56209 .42641 .55885 .42022 .55285 Mtetra
.42022 .55285 .42641 .55885 .43698 .55561 .43081 .54959 Mtetra
.43081 .54959 .43698 .55561 .44759 .55236 .44145 .54632 Mtetra
.44145 .54632 .44759 .55236 .45825 .54911 .45213 .54304 Mtetra
.662 .741 .909 r
.45213 .54304 .45825 .54911 .46894 .54585 .46285 .53977 Mtetra
.46285 .53977 .46894 .54585 .47968 .54259 .47362 .5365 Mtetra
.661 .742 .91 r
.47362 .5365 .47968 .54259 .49046 .53933 .48443 .53325 Mtetra
.659 .742 .911 r
.48443 .53325 .49046 .53933 .50129 .53609 .49528 .53002 Mtetra
.658 .743 .913 r
.49528 .53002 .50129 .53609 .51215 .53285 .50617 .52683 Mtetra
.656 .745 .915 r
.50617 .52683 .51215 .53285 .52306 .52962 .51711 .52367 Mtetra
.654 .747 .919 r
.51711 .52367 .52306 .52962 .53402 .52641 .5281 .52055 Mtetra
.652 .751 .922 r
.5281 .52055 .53402 .52641 .54502 .52319 .53913 .51746 Mtetra
.65 .756 .927 r
.53913 .51746 .54502 .52319 .55606 .51996 .5502 .51438 Mtetra
.649 .762 .931 r
.5502 .51438 .55606 .51996 .56715 .51671 .56133 .51129 Mtetra
.649 .768 .936 r
.56133 .51129 .56715 .51671 .57829 .51341 .5725 .50816 Mtetra
.651 .776 .94 r
.5725 .50816 .57829 .51341 .58947 .51006 .58371 .50495 Mtetra
.653 .783 .943 r
.58371 .50495 .58947 .51006 .60069 .50664 .59497 .50164 Mtetra
.657 .789 .945 r
.59497 .50164 .60069 .50664 .61196 .50316 .60628 .49821 Mtetra
.661 .793 .945 r
.60628 .49821 .61196 .50316 .62327 .49961 .61763 .49464 Mtetra
.665 .794 .944 r
.61763 .49464 .62327 .49961 .63463 .496 .62902 .49096 Mtetra
.669 .793 .941 r
.62902 .49096 .63463 .496 .64603 .49235 .64045 .48717 Mtetra
.671 .79 .938 r
.64045 .48717 .64603 .49235 .65748 .48867 .65193 .48331 Mtetra
.673 .785 .933 r
.65193 .48331 .65748 .48867 .66897 .48498 .66345 .47941 Mtetra
.673 .778 .929 r
.66345 .47941 .66897 .48498 .68051 .48129 .67502 .4755 Mtetra
.673 .771 .924 r
.67502 .4755 .68051 .48129 .69209 .4776 .68663 .47161 Mtetra
.672 .765 .92 r
.68663 .47161 .69209 .4776 .70373 .47392 .69829 .46774 Mtetra
.67 .759 .917 r
.69829 .46774 .70373 .47392 .71541 .47026 .71 .46392 Mtetra
.669 .754 .914 r
.71 .46392 .71541 .47026 .72714 .46659 .72176 .46012 Mtetra
.667 .75 .912 r
.72176 .46012 .72714 .46659 .73892 .46294 .73357 .45636 Mtetra
.666 .747 .911 r
.73357 .45636 .73892 .46294 .75075 .45928 .74543 .45262 Mtetra
.665 .745 .91 r
.74543 .45262 .75075 .45928 .76263 .45561 .75734 .44889 Mtetra
.665 .743 .909 r
.75734 .44889 .76263 .45561 .77456 .45194 .7693 .44516 Mtetra
.664 .742 .908 r
.7693 .44516 .77456 .45194 .78653 .44825 .78132 .44144 Mtetra
.78132 .44144 .78653 .44825 .79856 .44456 .79338 .4377 Mtetra
.79338 .4377 .79856 .44456 .81064 .44084 .80549 .43396 Mtetra
.664 .741 .908 r
.80549 .43396 .81064 .44084 .82277 .43712 .81766 .4302 Mtetra
.81766 .4302 .82277 .43712 .83495 .43338 .82988 .42643 Mtetra
.82988 .42643 .83495 .43338 .84719 .42962 .84215 .42264 Mtetra
.84215 .42264 .84719 .42962 .85947 .42585 .85447 .41884 Mtetra
.85447 .41884 .85947 .42585 .87181 .42206 .86684 .41502 Mtetra
.86684 .41502 .87181 .42206 .88419 .41825 .87927 .41119 Mtetra
.87927 .41119 .88419 .41825 .89664 .41443 .89175 .40734 Mtetra
.89175 .40734 .89664 .41443 .90913 .4106 .90428 .40347 Mtetra
.90428 .40347 .90913 .4106 .92168 .40674 .91687 .39958 Mtetra
.91687 .39958 .92168 .40674 .93428 .40287 .92951 .39568 Mtetra
.92951 .39568 .93428 .40287 .94693 .39899 .9422 .39177 Mtetra
.36148 .56307 .36785 .56901 .37824 .5658 .37189 .55985 Mtetra
.37189 .55985 .37824 .5658 .38867 .56258 .38235 .5566 Mtetra
.38235 .5566 .38867 .56258 .39914 .55935 .39285 .55335 Mtetra
.663 .741 .908 r
.39285 .55335 .39914 .55935 .40966 .55611 .40339 .55008 Mtetra
.40339 .55008 .40966 .55611 .42022 .55285 .41397 .5468 Mtetra
.41397 .5468 .42022 .55285 .43081 .54959 .4246 .54352 Mtetra
.4246 .54352 .43081 .54959 .44145 .54632 .43526 .54022 Mtetra
.43526 .54022 .44145 .54632 .45213 .54304 .44597 .53693 Mtetra
.662 .741 .909 r
.44597 .53693 .45213 .54304 .46285 .53977 .45672 .53364 Mtetra
.661 .741 .909 r
.45672 .53364 .46285 .53977 .47362 .5365 .46751 .53036 Mtetra
.66 .741 .91 r
.46751 .53036 .47362 .5365 .48443 .53325 .47835 .52712 Mtetra
.657 .742 .912 r
.47835 .52712 .48443 .53325 .49528 .53002 .48922 .52392 Mtetra
.655 .742 .914 r
.48922 .52392 .49528 .53002 .50617 .52683 .50015 .52078 Mtetra
.651 .744 .918 r
.50015 .52078 .50617 .52683 .51711 .52367 .51111 .51772 Mtetra
.647 .747 .922 r
.51111 .51772 .51711 .52367 .5281 .52055 .52213 .51475 Mtetra
.642 .752 .928 r
.52213 .51475 .5281 .52055 .53913 .51746 .53319 .51186 Mtetra
.638 .758 .935 r
.53319 .51186 .53913 .51746 .5502 .51438 .5443 .50905 Mtetra
.634 .767 .944 r
.5443 .50905 .5502 .51438 .56133 .51129 .55546 .50627 Mtetra
.631 .779 .952 r
.55546 .50627 .56133 .51129 .5725 .50816 .56666 .50347 Mtetra
.629 .792 .96 r
.56666 .50347 .5725 .50816 .58371 .50495 .57792 .50059 Mtetra
.63 .807 .967 r
.57792 .50059 .58371 .50495 .59497 .50164 .58923 .49758 Mtetra
.634 .821 .972 r
.58923 .49758 .59497 .50164 .60628 .49821 .60058 .49436 Mtetra
.641 .833 .974 r
.60058 .49436 .60628 .49821 .61763 .49464 .61197 .49092 Mtetra
.65 .841 .974 r
.61197 .49092 .61763 .49464 .62902 .49096 .6234 .48723 Mtetra
.659 .845 .971 r
.6234 .48723 .62902 .49096 .64045 .48717 .63488 .48331 Mtetra
.669 .843 .967 r
.63488 .48331 .64045 .48717 .65193 .48331 .64639 .47922 Mtetra
.676 .836 .96 r
.64639 .47922 .65193 .48331 .66345 .47941 .65794 .475 Mtetra
.68 .826 .953 r
.65794 .475 .66345 .47941 .67502 .4755 .66953 .47072 Mtetra
.682 .813 .945 r
.66953 .47072 .67502 .4755 .68663 .47161 .68116 .46644 Mtetra
.681 .799 .937 r
.68116 .46644 .68663 .47161 .69829 .46774 .69284 .46221 Mtetra
.679 .786 .93 r
.69284 .46221 .69829 .46774 .71 .46392 .70458 .45805 Mtetra
.676 .774 .924 r
.70458 .45805 .71 .46392 .72176 .46012 .71636 .45398 Mtetra
.673 .764 .919 r
.71636 .45398 .72176 .46012 .73357 .45636 .72819 .45 Mtetra
.67 .757 .916 r
.72819 .45 .73357 .45636 .74543 .45262 .74008 .44608 Mtetra
.668 .752 .913 r
.74008 .44608 .74543 .45262 .75734 .44889 .75202 .44223 Mtetra
.667 .748 .911 r
.75202 .44223 .75734 .44889 .7693 .44516 .76401 .43841 Mtetra
.665 .745 .91 r
.76401 .43841 .7693 .44516 .78132 .44144 .77606 .43461 Mtetra
.665 .743 .909 r
.77606 .43461 .78132 .44144 .79338 .4377 .78816 .43082 Mtetra
.664 .743 .908 r
.78816 .43082 .79338 .4377 .80549 .43396 .80031 .42703 Mtetra
.664 .742 .908 r
.80031 .42703 .80549 .43396 .81766 .4302 .81251 .42324 Mtetra
.81251 .42324 .81766 .4302 .82988 .42643 .82476 .41943 Mtetra
.664 .741 .908 r
.82476 .41943 .82988 .42643 .84215 .42264 .83707 .41561 Mtetra
.83707 .41561 .84215 .42264 .85447 .41884 .84943 .41178 Mtetra
.84943 .41178 .85447 .41884 .86684 .41502 .86184 .40793 Mtetra
.86184 .40793 .86684 .41502 .87927 .41119 .8743 .40406 Mtetra
.8743 .40406 .87927 .41119 .89175 .40734 .88682 .40018 Mtetra
.88682 .40018 .89175 .40734 .90428 .40347 .89939 .39628 Mtetra
.89939 .39628 .90428 .40347 .91687 .39958 .91202 .39237 Mtetra
.91202 .39237 .91687 .39958 .92951 .39568 .9247 .38844 Mtetra
.9247 .38844 .92951 .39568 .9422 .39177 .93743 .38449 Mtetra
.35506 .5571 .36148 .56307 .37189 .55985 .3655 .55385 Mtetra
.3655 .55385 .37189 .55985 .38235 .5566 .37599 .55058 Mtetra
.37599 .55058 .38235 .5566 .39285 .55335 .38651 .5473 Mtetra
.663 .741 .908 r
.38651 .5473 .39285 .55335 .40339 .55008 .39708 .54401 Mtetra
.39708 .54401 .40339 .55008 .41397 .5468 .40769 .54071 Mtetra
.40769 .54071 .41397 .5468 .4246 .54352 .41834 .5374 Mtetra
.41834 .5374 .4246 .54352 .43526 .54022 .42903 .53408 Mtetra
.42903 .53408 .43526 .54022 .44597 .53693 .43976 .53077 Mtetra
.662 .741 .909 r
.43976 .53077 .44597 .53693 .45672 .53364 .45054 .52746 Mtetra
.661 .741 .909 r
.45054 .52746 .45672 .53364 .46751 .53036 .46136 .52417 Mtetra
.659 .741 .91 r
.46136 .52417 .46751 .53036 .47835 .52712 .47222 .52093 Mtetra
.656 .741 .912 r
.47222 .52093 .47835 .52712 .48922 .52392 .48312 .51775 Mtetra
.652 .741 .915 r
.48312 .51775 .48922 .52392 .50015 .52078 .49407 .51467 Mtetra
.646 .742 .919 r
.49407 .51467 .50015 .52078 .51111 .51772 .50507 .51173 Mtetra
.639 .745 .925 r
.50507 .51173 .51111 .51772 .52213 .51475 .51611 .50894 Mtetra
.63 .749 .933 r
.51611 .50894 .52213 .51475 .53319 .51186 .5272 .50633 Mtetra
.62 .756 .944 r
.5272 .50633 .53319 .51186 .5443 .50905 .53834 .50389 Mtetra
.608 .768 .956 r
.53834 .50389 .5443 .50905 .55546 .50627 .54954 .50159 Mtetra
.596 .783 .97 r
.54954 .50159 .55546 .50627 .56666 .50347 .56079 .49936 Mtetra
.584 .803 .983 r
.56079 .49936 .56666 .50347 .57792 .50059 .57209 .4971 Mtetra
.573 .826 .993 r
.57209 .4971 .57792 .50059 .58923 .49758 .58345 .49469 Mtetra
.566 .849 .997 r
.58345 .49469 .58923 .49758 .60058 .49436 .59485 .49202 Mtetra
.565 .871 .995 r
.59485 .49202 .60058 .49436 .61197 .49092 .6063 .48899 Mtetra
.573 .889 .989 r
.6063 .48899 .61197 .49092 .6234 .48723 .61779 .48553 Mtetra
.59 .904 .983 r
.61779 .48553 .6234 .48723 .63488 .48331 .62932 .48163 Mtetra
.615 .913 .98 r
.62932 .48163 .63488 .48331 .64639 .47922 .64087 .47733 Mtetra
.642 .916 .979 r
.64087 .47733 .64639 .47922 .65794 .475 .65246 .4727 Mtetra
.667 .909 .978 r
.65246 .4727 .65794 .475 .66953 .47072 .66407 .46788 Mtetra
.683 .893 .973 r
.66407 .46788 .66953 .47072 .68116 .46644 .67573 .46297 Mtetra
.692 .87 .966 r
.67573 .46297 .68116 .46644 .69284 .46221 .68743 .45808 Mtetra
.694 .845 .956 r
.68743 .45808 .69284 .46221 .70458 .45805 .69917 .4533 Mtetra
.691 .821 .945 r
.69917 .4533 .70458 .45805 .71636 .45398 .71096 .44867 Mtetra
.686 .8 .935 r
.71096 .44867 .71636 .45398 .72819 .45 .72281 .44422 Mtetra
.681 .782 .927 r
.72281 .44422 .72819 .45 .74008 .44608 .73472 .43994 Mtetra
.676 .769 .921 r
.73472 .43994 .74008 .44608 .75202 .44223 .74668 .4358 Mtetra
.672 .759 .916 r
.74668 .4358 .75202 .44223 .76401 .43841 .7587 .43178 Mtetra
.669 .752 .913 r
.7587 .43178 .76401 .43841 .77606 .43461 .77077 .42784 Mtetra
.667 .748 .911 r
.77077 .42784 .77606 .43461 .78816 .43082 .7829 .42395 Mtetra
.666 .745 .91 r
.7829 .42395 .78816 .43082 .80031 .42703 .79508 .42009 Mtetra
.665 .743 .909 r
.79508 .42009 .80031 .42703 .81251 .42324 .80732 .41624 Mtetra
.664 .742 .908 r
.80732 .41624 .81251 .42324 .82476 .41943 .81961 .41239 Mtetra
.81961 .41239 .82476 .41943 .83707 .41561 .83195 .40853 Mtetra
.83195 .40853 .83707 .41561 .84943 .41178 .84435 .40466 Mtetra
.664 .741 .908 r
.84435 .40466 .84943 .41178 .86184 .40793 .8568 .40078 Mtetra
.8568 .40078 .86184 .40793 .8743 .40406 .8693 .39689 Mtetra
.8693 .39689 .8743 .40406 .88682 .40018 .88186 .39297 Mtetra
.88186 .39297 .88682 .40018 .89939 .39628 .89447 .38904 Mtetra
.89447 .38904 .89939 .39628 .91202 .39237 .90713 .3851 Mtetra
.90713 .3851 .91202 .39237 .9247 .38844 .91985 .38114 Mtetra
.91985 .38114 .9247 .38844 .93743 .38449 .93263 .37715 Mtetra
.3486 .55109 .35506 .5571 .3655 .55385 .35907 .54781 Mtetra
.35907 .54781 .3655 .55385 .37599 .55058 .36958 .54452 Mtetra
.36958 .54452 .37599 .55058 .38651 .5473 .38013 .54122 Mtetra
.38013 .54122 .38651 .5473 .39708 .54401 .39072 .5379 Mtetra
.663 .741 .908 r
.39072 .5379 .39708 .54401 .40769 .54071 .40135 .53458 Mtetra
.40135 .53458 .40769 .54071 .41834 .5374 .41203 .53124 Mtetra
.41203 .53124 .41834 .5374 .42903 .53408 .42275 .5279 Mtetra
.42275 .5279 .42903 .53408 .43976 .53077 .43351 .52455 Mtetra
.662 .741 .909 r
.43351 .52455 .43976 .53077 .45054 .52746 .44431 .52122 Mtetra
.66 .74 .909 r
.44431 .52122 .45054 .52746 .46136 .52417 .45516 .51791 Mtetra
.658 .74 .91 r
.45516 .51791 .46136 .52417 .47222 .52093 .46605 .51466 Mtetra
.655 .739 .912 r
.46605 .51466 .47222 .52093 .48312 .51775 .47698 .5115 Mtetra
.649 .739 .915 r
.47698 .5115 .48312 .51775 .49407 .51467 .48796 .50846 Mtetra
.641 .739 .92 r
.48796 .50846 .49407 .51467 .50507 .51173 .49898 .50562 Mtetra
.631 .74 .926 r
.49898 .50562 .50507 .51173 .51611 .50894 .51005 .50303 Mtetra
.616 .743 .936 r
.51005 .50303 .51611 .50894 .5272 .50633 .52117 .50073 Mtetra
.598 .748 .949 r
.52117 .50073 .5272 .50633 .53834 .50389 .53234 .49875 Mtetra
.574 .758 .965 r
.53234 .49875 .53834 .50389 .54954 .50159 .54357 .49707 Mtetra
.544 .773 .983 r
.54357 .49707 .54954 .50159 .56079 .49936 .55487 .49564 Mtetra
.504 .791 .997 r
.55487 .49564 .56079 .49936 .57209 .4971 .56622 .49433 Mtetra
.455 .809 .997 r
.56622 .49433 .57209 .4971 .58345 .49469 .57763 .49297 Mtetra
.397 .818 .97 r
.57763 .49297 .58345 .49469 .59485 .49202 .58911 .49134 Mtetra
.341 .812 .911 r
.58911 .49134 .59485 .49202 .6063 .48899 .60063 .48924 Mtetra
.303 .797 .838 r
.60063 .48924 .6063 .48899 .61779 .48553 .61219 .4865 Mtetra
.296 .791 .779 r
.61219 .4865 .61779 .48553 .62932 .48163 .62379 .483 Mtetra
.326 .806 .755 r
.62379 .483 .62932 .48163 .64087 .47733 .63541 .47875 Mtetra
.389 .844 .771 r
.63541 .47875 .64087 .47733 .65246 .4727 .64705 .4738 Mtetra
.474 .894 .82 r
.64705 .4738 .65246 .4727 .66407 .46788 .6587 .46833 Mtetra
.564 .937 .882 r
.6587 .46833 .66407 .46788 .67573 .46297 .67038 .46253 Mtetra
.638 .955 .933 r
.67038 .46253 .67573 .46297 .68743 .45808 .68209 .45661 Mtetra
.684 .944 .961 r
.68209 .45661 .68743 .45808 .69917 .4533 .69383 .45076 Mtetra
.704 .913 .967 r
.69383 .45076 .69917 .4533 .71096 .44867 .70562 .44512 Mtetra
.707 .876 .96 r
.70562 .44512 .71096 .44867 .72281 .44422 .71747 .43977 Mtetra
.701 .84 .949 r
.71747 .43977 .72281 .44422 .73472 .43994 .72937 .43475 Mtetra
.693 .81 .938 r
.72937 .43475 .73472 .43994 .74668 .4358 .74134 .43003 Mtetra
.685 .787 .928 r
.74134 .43003 .74668 .4358 .7587 .43178 .75337 .42556 Mtetra
.678 .771 .921 r
.75337 .42556 .7587 .43178 .77077 .42784 .76546 .42131 Mtetra
.673 .76 .916 r
.76546 .42131 .77077 .42784 .7829 .42395 .77761 .4172 Mtetra
.669 .752 .913 r
.77761 .4172 .7829 .42395 .79508 .42009 .78982 .41319 Mtetra
.667 .747 .911 r
.78982 .41319 .79508 .42009 .80732 .41624 .80209 .40924 Mtetra
.665 .745 .909 r
.80209 .40924 .80732 .41624 .81961 .41239 .81442 .40532 Mtetra
.665 .743 .909 r
.81442 .40532 .81961 .41239 .83195 .40853 .82679 .40141 Mtetra
.664 .742 .908 r
.82679 .40141 .83195 .40853 .84435 .40466 .83923 .3975 Mtetra
.83923 .3975 .84435 .40466 .8568 .40078 .85171 .39358 Mtetra
.664 .741 .908 r
.85171 .39358 .8568 .40078 .8693 .39689 .86426 .38965 Mtetra
.86426 .38965 .8693 .39689 .88186 .39297 .87685 .38571 Mtetra
.87685 .38571 .88186 .39297 .89447 .38904 .8895 .38175 Mtetra
.8895 .38175 .89447 .38904 .90713 .3851 .90221 .37777 Mtetra
.90221 .37777 .90713 .3851 .91985 .38114 .91497 .37377 Mtetra
.91497 .37377 .91985 .38114 .93263 .37715 .92778 .36976 Mtetra
.34209 .54503 .3486 .55109 .35907 .54781 .35259 .54172 Mtetra
.35259 .54172 .35907 .54781 .36958 .54452 .36312 .53841 Mtetra
.36312 .53841 .36958 .54452 .38013 .54122 .3737 .53508 Mtetra
.3737 .53508 .38013 .54122 .39072 .5379 .38431 .53174 Mtetra
.663 .741 .908 r
.38431 .53174 .39072 .5379 .40135 .53458 .39497 .52839 Mtetra
.39497 .52839 .40135 .53458 .41203 .53124 .40568 .52503 Mtetra
.40568 .52503 .41203 .53124 .42275 .5279 .41642 .52166 Mtetra
.41642 .52166 .42275 .5279 .43351 .52455 .42721 .51829 Mtetra
.662 .741 .908 r
.42721 .51829 .43351 .52455 .44431 .52122 .43804 .51493 Mtetra
.661 .74 .909 r
.43804 .51493 .44431 .52122 .45516 .51791 .44891 .5116 Mtetra
.658 .739 .91 r
.44891 .5116 .45516 .51791 .46605 .51466 .45983 .50832 Mtetra
.654 .738 .911 r
.45983 .50832 .46605 .51466 .47698 .5115 .47079 .50514 Mtetra
.648 .737 .914 r
.47079 .50514 .47698 .5115 .48796 .50846 .4818 .50212 Mtetra
.638 .735 .918 r
.4818 .50212 .48796 .50846 .49898 .50562 .49284 .49934 Mtetra
.625 .733 .925 r
.49284 .49934 .49898 .50562 .51005 .50303 .50394 .4969 Mtetra
.605 .733 .935 r
.50394 .4969 .51005 .50303 .52117 .50073 .51509 .49487 Mtetra
.577 .733 .949 r
.51509 .49487 .52117 .50073 .53234 .49875 .52629 .49335 Mtetra
.538 .737 .967 r
.52629 .49335 .53234 .49875 .54357 .49707 .53755 .49237 Mtetra
.482 .742 .985 r
.53755 .49237 .54357 .49707 .55487 .49564 .54889 .49191 Mtetra
.4 .744 .993 r
.54889 .49191 .55487 .49564 .56622 .49433 .56029 .49184 Mtetra
.279 .728 .96 r
.56029 .49184 .56622 .49433 .57763 .49297 .57177 .49196 Mtetra
.124 .665 .842 r
.57177 .49196 .57763 .49297 .58911 .49134 .58332 .49197 Mtetra
.022 0 0 r
.58332 .49197 .58911 .49134 .60063 .48924 .59493 .49152 Mtetra
.112 0 0 r
.59493 .49152 .60063 .48924 .61219 .4865 .60659 .49027 Mtetra
.142 0 0 r
.60659 .49027 .61219 .4865 .62379 .483 .61829 .48793 Mtetra
.128 0 0 r
.61829 .48793 .62379 .483 .63541 .47875 .63001 .48435 Mtetra
.081 0 0 r
.63001 .48435 .63541 .47875 .64705 .4738 .64173 .47952 Mtetra
.004 0 0 r
.64173 .47952 .64705 .4738 .6587 .46833 .65345 .47357 Mtetra
0 0 0 r
.65345 .47357 .6587 .46833 .67038 .46253 .66517 .46679 Mtetra
.66517 .46679 .67038 .46253 .68209 .45661 .67689 .45951 Mtetra
.424 .834 .646 r
.67689 .45951 .68209 .45661 .69383 .45076 .68863 .45208 Mtetra
.581 .941 .813 r
.68863 .45208 .69383 .45076 .70562 .44512 .70041 .4448 Mtetra
.679 .971 .918 r
.70041 .4448 .70562 .44512 .71747 .43977 .71223 .4379 Mtetra
.717 .943 .957 r
.71223 .4379 .71747 .43977 .72937 .43475 .7241 .43151 Mtetra
.719 .895 .959 r
.7241 .43151 .72937 .43475 .74134 .43003 .73605 .42566 Mtetra
.709 .849 .949 r
.73605 .42566 .74134 .43003 .75337 .42556 .74807 .42031 Mtetra
.697 .813 .937 r
.74807 .42031 .75337 .42556 .76546 .42131 .76016 .4154 Mtetra
.686 .787 .927 r
.76016 .4154 .76546 .42131 .77761 .4172 .77232 .41082 Mtetra
.678 .769 .92 r
.77232 .41082 .77761 .4172 .78982 .41319 .78454 .40649 Mtetra
.672 .758 .915 r
.78454 .40649 .78982 .41319 .80209 .40924 .79684 .40233 Mtetra
.669 .751 .912 r
.79684 .40233 .80209 .40924 .81442 .40532 .80919 .39828 Mtetra
.666 .746 .91 r
.80919 .39828 .81442 .40532 .82679 .40141 .8216 .39428 Mtetra
.665 .744 .909 r
.8216 .39428 .82679 .40141 .83923 .3975 .83407 .3903 Mtetra
.664 .743 .908 r
.83407 .3903 .83923 .3975 .85171 .39358 .84659 .38634 Mtetra
.664 .742 .908 r
.84659 .38634 .85171 .39358 .86426 .38965 .85917 .38237 Mtetra
.85917 .38237 .86426 .38965 .87685 .38571 .87181 .37839 Mtetra
.664 .741 .908 r
.87181 .37839 .87685 .38571 .8895 .38175 .8845 .37439 Mtetra
.8845 .37439 .8895 .38175 .90221 .37777 .89724 .37038 Mtetra
.89724 .37038 .90221 .37777 .91497 .37377 .91004 .36635 Mtetra
.91004 .36635 .91497 .37377 .92778 .36976 .9229 .36231 Mtetra
.33554 .53892 .34209 .54503 .35259 .54172 .34605 .5356 Mtetra
.34605 .5356 .35259 .54172 .36312 .53841 .35661 .53226 Mtetra
.35661 .53226 .36312 .53841 .3737 .53508 .36722 .52891 Mtetra
.36722 .52891 .3737 .53508 .38431 .53174 .37786 .52554 Mtetra
.663 .741 .908 r
.37786 .52554 .38431 .53174 .39497 .52839 .38855 .52217 Mtetra
.38855 .52217 .39497 .52839 .40568 .52503 .39928 .51878 Mtetra
.39928 .51878 .40568 .52503 .41642 .52166 .41005 .51538 Mtetra
.41005 .51538 .41642 .52166 .42721 .51829 .42086 .51198 Mtetra
.662 .741 .908 r
.42086 .51198 .42721 .51829 .43804 .51493 .43172 .50859 Mtetra
.661 .74 .909 r
.43172 .50859 .43804 .51493 .44891 .5116 .44262 .50521 Mtetra
.659 .739 .909 r
.44262 .50521 .44891 .5116 .45983 .50832 .45357 .5019 Mtetra
.655 .737 .91 r
.45357 .5019 .45983 .50832 .47079 .50514 .46456 .49868 Mtetra
.648 .735 .913 r
.46456 .49868 .47079 .50514 .4818 .50212 .47559 .49563 Mtetra
.638 .732 .916 r
.47559 .49563 .4818 .50212 .49284 .49934 .48666 .49286 Mtetra
.622 .727 .922 r
.48666 .49286 .49284 .49934 .50394 .4969 .49779 .49047 Mtetra
.598 .722 .931 r
.49779 .49047 .50394 .4969 .51509 .49487 .50896 .48862 Mtetra
.564 .716 .943 r
.50896 .48862 .51509 .49487 .52629 .49335 .52019 .48745 Mtetra
.512 .708 .96 r
.52019 .48745 .52629 .49335 .53755 .49237 .53148 .48709 Mtetra
.434 .698 .976 r
.53148 .48709 .53755 .49237 .54889 .49191 .54285 .48757 Mtetra
.311 .674 .976 r
.54285 .48757 .54889 .49191 .56029 .49184 .5543 .48886 Mtetra
.121 .611 .91 r
.5543 .48886 .56029 .49184 .57177 .49196 .56583 .49076 Mtetra
0 .471 .709 r
.56583 .49076 .57177 .49196 .58332 .49197 .57746 .49292 Mtetra
.304 0 0 r
.57746 .49292 .58332 .49197 .59493 .49152 .58917 .49488 Mtetra
.385 0 0 r
.58917 .49488 .59493 .49152 .60659 .49027 .60096 .49608 Mtetra
.397 0 0 r
.60096 .49608 .60659 .49027 .61829 .48793 .61279 .49599 Mtetra
.375 0 .068 r
.61279 .49599 .61829 .48793 .63001 .48435 .62465 .49417 Mtetra
.335 0 .108 r
.62465 .49417 .63001 .48435 .64173 .47952 .6365 .4904 Mtetra
.282 0 .115 r
.6365 .4904 .64173 .47952 .65345 .47357 .64834 .48467 Mtetra
.216 0 .092 r
.64834 .48467 .65345 .47357 .66517 .46679 .66013 .47726 Mtetra
.132 0 .037 r
.66013 .47726 .66517 .46679 .67689 .45951 .6719 .46858 Mtetra
.02 0 0 r
.6719 .46858 .67689 .45951 .68863 .45208 .68365 .4592 Mtetra
0 0 0 r
.68365 .4592 .68863 .45208 .70041 .4448 .6954 .44965 Mtetra
.6954 .44965 .70041 .4448 .71223 .4379 .70717 .4404 Mtetra
.548 .906 .705 r
.70717 .4404 .71223 .4379 .7241 .43151 .71899 .43177 Mtetra
.686 .979 .88 r
.71899 .43177 .7241 .43151 .73605 .42566 .73088 .42396 Mtetra
.731 .954 .947 r
.73088 .42396 .73605 .42566 .74807 .42031 .74285 .41699 Mtetra
.729 .897 .955 r
.74285 .41699 .74807 .42031 .76016 .4154 .7549 .41082 Mtetra
.713 .846 .945 r
.7549 .41082 .76016 .4154 .77232 .41082 .76704 .40531 Mtetra
.697 .808 .934 r
.76704 .40531 .77232 .41082 .78454 .40649 .77927 .40033 Mtetra
.685 .782 .924 r
.77927 .40033 .78454 .40649 .79684 .40233 .79157 .39573 Mtetra
.677 .765 .918 r
.79157 .39573 .79684 .40233 .80919 .39828 .80394 .39138 Mtetra
.671 .755 .913 r
.80394 .39138 .80919 .39828 .8216 .39428 .81638 .3872 Mtetra
.668 .749 .911 r
.81638 .3872 .8216 .39428 .83407 .3903 .82887 .38311 Mtetra
.666 .745 .909 r
.82887 .38311 .83407 .3903 .84659 .38634 .84143 .37906 Mtetra
.665 .743 .909 r
.84143 .37906 .84659 .38634 .85917 .38237 .85405 .37504 Mtetra
.664 .742 .908 r
.85405 .37504 .85917 .38237 .87181 .37839 .86672 .37101 Mtetra
.86672 .37101 .87181 .37839 .8845 .37439 .87945 .36698 Mtetra
.664 .741 .908 r
.87945 .36698 .8845 .37439 .89724 .37038 .89224 .36293 Mtetra
.89224 .36293 .89724 .37038 .91004 .36635 .90508 .35887 Mtetra
.90508 .35887 .91004 .36635 .9229 .36231 .91798 .35479 Mtetra
.32893 .53277 .33554 .53892 .34605 .5356 .33948 .52942 Mtetra
.33948 .52942 .34605 .5356 .35661 .53226 .35006 .52606 Mtetra
.35006 .52606 .35661 .53226 .36722 .52891 .36069 .52268 Mtetra
.36069 .52268 .36722 .52891 .37786 .52554 .37136 .51929 Mtetra
.37136 .51929 .37786 .52554 .38855 .52217 .38207 .51589 Mtetra
.663 .741 .908 r
.38207 .51589 .38855 .52217 .39928 .51878 .39283 .51248 Mtetra
.39283 .51248 .39928 .51878 .41005 .51538 .40363 .50905 Mtetra
.40363 .50905 .41005 .51538 .42086 .51198 .41447 .50562 Mtetra
.41447 .50562 .42086 .51198 .43172 .50859 .42536 .50219 Mtetra
.661 .74 .908 r
.42536 .50219 .43172 .50859 .44262 .50521 .43629 .49878 Mtetra
.66 .739 .909 r
.43629 .49878 .44262 .50521 .45357 .5019 .44726 .49541 Mtetra
.656 .737 .91 r
.44726 .49541 .45357 .5019 .46456 .49868 .45828 .49213 Mtetra
.65 .734 .911 r
.45828 .49213 .46456 .49868 .47559 .49563 .46934 .48902 Mtetra
.64 .73 .914 r
.46934 .48902 .47559 .49563 .48666 .49286 .48044 .48617 Mtetra
.624 .723 .918 r
.48044 .48617 .48666 .49286 .49779 .49047 .49159 .48373 Mtetra
.599 .713 .924 r
.49159 .48373 .49779 .49047 .50896 .48862 .50279 .4819 Mtetra
.562 .7 .934 r
.50279 .4819 .50896 .48862 .52019 .48745 .51404 .48087 Mtetra
.505 .682 .946 r
.51404 .48087 .52019 .48745 .53148 .48709 .52536 .48088 Mtetra
.417 .656 .958 r
.52536 .48088 .53148 .48709 .54285 .48757 .53675 .48208 Mtetra
.279 .61 .956 r
.53675 .48208 .54285 .48757 .5543 .48886 .54824 .48454 Mtetra
.06 .52 .894 r
.54824 .48454 .5543 .48886 .56583 .49076 .55982 .48818 Mtetra
0 .35 .691 r
.55982 .48818 .56583 .49076 .57746 .49292 .57152 .49269 Mtetra
.453 0 0 r
.57152 .49269 .57746 .49292 .58917 .49488 .58333 .49756 Mtetra
.539 0 0 r
.58333 .49756 .58917 .49488 .60096 .49608 .59524 .50206 Mtetra
.54 .068 .082 r
.59524 .50206 .60096 .49608 .61279 .49599 .60723 .50539 Mtetra
.508 .089 .18 r
.60723 .50539 .61279 .49599 .62465 .49417 .61927 .50675 Mtetra
.462 .083 .232 r
.61927 .50675 .62465 .49417 .6365 .4904 .63131 .50552 Mtetra
.411 .06 .256 r
.63131 .50552 .6365 .4904 .64834 .48467 .64332 .50139 Mtetra
.356 .024 .259 r
.64332 .50139 .64834 .48467 .66013 .47726 .65526 .49439 Mtetra
.295 0 .243 r
.65526 .49439 .66013 .47726 .6719 .46858 .66713 .48495 Mtetra
.226 0 .206 r
.66713 .48495 .6719 .46858 .68365 .4592 .67892 .47374 Mtetra
.142 0 .143 r
.67892 .47374 .68365 .4592 .6954 .44965 .69066 .46158 Mtetra
.029 0 .037 r
.69066 .46158 .6954 .44965 .70717 .4404 .70239 .44927 Mtetra
0 0 0 r
.70239 .44927 .70717 .4404 .71899 .43177 .71413 .43747 Mtetra
.71413 .43747 .71899 .43177 .73088 .42396 .72593 .42665 Mtetra
.581 .915 .688 r
.72593 .42665 .73088 .42396 .74285 .41699 .7378 .41705 Mtetra
.717 .986 .882 r
.7378 .41705 .74285 .41699 .7549 .41082 .74978 .4087 Mtetra
.745 .946 .946 r
.74978 .4087 .7549 .41082 .76704 .40531 .76186 .40151 Mtetra
.731 .883 .95 r
.76186 .40151 .76704 .40531 .77927 .40033 .77404 .39529 Mtetra
.711 .832 .94 r
.77404 .39529 .77927 .40033 .79157 .39573 .78632 .38982 Mtetra
.694 .796 .929 r
.78632 .38982 .79157 .39573 .80394 .39138 .79868 .38489 Mtetra
.682 .773 .92 r
.79868 .38489 .80394 .39138 .81638 .3872 .81113 .38033 Mtetra
.674 .759 .915 r
.81113 .38033 .81638 .3872 .82887 .38311 .82365 .376 Mtetra
.669 .751 .912 r
.82365 .376 .82887 .38311 .84143 .37906 .83624 .37181 Mtetra
.667 .746 .91 r
.83624 .37181 .84143 .37906 .85405 .37504 .84889 .36769 Mtetra
.665 .744 .909 r
.84889 .36769 .85405 .37504 .86672 .37101 .8616 .3636 Mtetra
.664 .742 .908 r
.8616 .3636 .86672 .37101 .87945 .36698 .87437 .35952 Mtetra
.87437 .35952 .87945 .36698 .89224 .36293 .88719 .35543 Mtetra
.88719 .35543 .89224 .36293 .90508 .35887 .90008 .35133 Mtetra
.664 .741 .908 r
.90008 .35133 .90508 .35887 .91798 .35479 .91302 .34722 Mtetra
.32228 .52658 .32893 .53277 .33948 .52942 .33285 .5232 Mtetra
.33285 .5232 .33948 .52942 .35006 .52606 .34346 .51982 Mtetra
.34346 .51982 .35006 .52606 .36069 .52268 .35411 .51641 Mtetra
.35411 .51641 .36069 .52268 .37136 .51929 .36481 .513 Mtetra
.36481 .513 .37136 .51929 .38207 .51589 .37555 .50957 Mtetra
.663 .741 .908 r
.37555 .50957 .38207 .51589 .39283 .51248 .38633 .50613 Mtetra
.38633 .50613 .39283 .51248 .40363 .50905 .39716 .50268 Mtetra
.39716 .50268 .40363 .50905 .41447 .50562 .40803 .49922 Mtetra
.40803 .49922 .41447 .50562 .42536 .50219 .41895 .49575 Mtetra
.662 .74 .908 r
.41895 .49575 .42536 .50219 .43629 .49878 .4299 .4923 Mtetra
.661 .739 .908 r
.4299 .4923 .43629 .49878 .44726 .49541 .44091 .48887 Mtetra
.658 .738 .909 r
.44091 .48887 .44726 .49541 .45828 .49213 .45195 .48552 Mtetra
.652 .735 .91 r
.45195 .48552 .45828 .49213 .46934 .48902 .46304 .4823 Mtetra
.644 .73 .911 r
.46304 .4823 .46934 .48902 .48044 .48617 .47417 .47932 Mtetra
.629 .722 .914 r
.47417 .47932 .48044 .48617 .49159 .48373 .48535 .47674 Mtetra
.606 .709 .918 r
.48535 .47674 .49159 .48373 .50279 .4819 .49657 .47475 Mtetra
.57 .692 .923 r
.49657 .47475 .50279 .4819 .51404 .48087 .50785 .47362 Mtetra
.515 .666 .93 r
.50785 .47362 .51404 .48087 .52536 .48088 .51919 .47364 Mtetra
.432 .628 .936 r
.51919 .47364 .52536 .48088 .53675 .48208 .5306 .47512 Mtetra
.304 .57 .933 r
.5306 .47512 .53675 .48208 .54824 .48454 .54211 .47827 Mtetra
.106 .476 .895 r
.54211 .47827 .54824 .48454 .55982 .48818 .55373 .48318 Mtetra
0 .32 .765 r
.55373 .48318 .55982 .48818 .57152 .49269 .56547 .48971 Mtetra
.466 0 0 r
.56547 .48971 .57152 .49269 .58333 .49756 .57736 .49742 Mtetra
.624 .063 0 r
.57736 .49742 .58333 .49756 .59524 .50206 .58938 .50556 Mtetra
.649 .151 .052 r
.58938 .50556 .59524 .50206 .60723 .50539 .60153 .51313 Mtetra
.614 .177 .188 r
.60153 .51313 .60723 .50539 .61927 .50675 .61376 .51897 Mtetra
.558 .171 .264 r
.61376 .51897 .61927 .50675 .63131 .50552 .62603 .52198 Mtetra
.498 .148 .304 r
.62603 .52198 .63131 .50552 .64332 .50139 .63828 .52132 Mtetra
.438 .116 .321 r
.63828 .52132 .64332 .50139 .65526 .49439 .65045 .51659 Mtetra
.378 .077 .322 r
.65045 .51659 .65526 .49439 .66713 .48495 .6625 .5079 Mtetra
.318 .031 .31 r
.6625 .5079 .66713 .48495 .67892 .47374 .67442 .49589 Mtetra
.254 0 .282 r
.67442 .49589 .67892 .47374 .69066 .46158 .68622 .48154 Mtetra
.182 0 .236 r
.68622 .48154 .69066 .46158 .70239 .44927 .69793 .466 Mtetra
.091 0 .161 r
.69793 .466 .70239 .44927 .71413 .43747 .7096 .45038 Mtetra
0 0 .038 r
.7096 .45038 .71413 .43747 .72593 .42665 .72128 .43557 Mtetra
0 0 0 r
.72128 .43557 .72593 .42665 .7378 .41705 .73302 .42219 Mtetra
.73302 .42219 .7378 .41705 .74978 .4087 .74486 .41052 Mtetra
.668 .964 .76 r
.74486 .41052 .74978 .4087 .76186 .40151 .75683 .4006 Mtetra
.753 .981 .913 r
.75683 .4006 .76186 .40151 .77404 .39529 .76891 .39226 Mtetra
.75 .919 .948 r
.76891 .39226 .77404 .39529 .78632 .38982 .78113 .38523 Mtetra
.725 .856 .943 r
.78113 .38523 .78632 .38982 .79868 .38489 .79346 .37922 Mtetra
.703 .811 .932 r
.79346 .37922 .79868 .38489 .81113 .38033 .80589 .37394 Mtetra
.687 .782 .923 r
.80589 .37394 .81113 .38033 .82365 .376 .81842 .36915 Mtetra
.677 .764 .916 r
.81842 .36915 .82365 .376 .83624 .37181 .83102 .36467 Mtetra
.671 .753 .913 r
.83102 .36467 .83624 .37181 .84889 .36769 .8437 .36037 Mtetra
.667 .748 .91 r
.8437 .36037 .84889 .36769 .8616 .3636 .85644 .35617 Mtetra
.665 .744 .909 r
.85644 .35617 .8616 .3636 .87437 .35952 .86925 .35202 Mtetra
.664 .743 .908 r
.86925 .35202 .87437 .35952 .88719 .35543 .88211 .34788 Mtetra
.664 .742 .908 r
.88211 .34788 .88719 .35543 .90008 .35133 .89503 .34374 Mtetra
.89503 .34374 .90008 .35133 .91302 .34722 .90801 .33959 Mtetra
.664 .741 .908 r
.31558 .52034 .32228 .52658 .33285 .5232 .32617 .51694 Mtetra
.32617 .51694 .33285 .5232 .34346 .51982 .33681 .51353 Mtetra
.33681 .51353 .34346 .51982 .35411 .51641 .34749 .5101 Mtetra
.34749 .5101 .35411 .51641 .36481 .513 .35821 .50666 Mtetra
.35821 .50666 .36481 .513 .37555 .50957 .36898 .5032 Mtetra
.36898 .5032 .37555 .50957 .38633 .50613 .37979 .49974 Mtetra
.663 .741 .908 r
.37979 .49974 .38633 .50613 .39716 .50268 .39064 .49626 Mtetra
.39064 .49626 .39716 .50268 .40803 .49922 .40154 .49277 Mtetra
.40154 .49277 .40803 .49922 .41895 .49575 .41248 .48927 Mtetra
.41248 .48927 .41895 .49575 .4299 .4923 .42347 .48577 Mtetra
.662 .74 .908 r
.42347 .48577 .4299 .4923 .44091 .48887 .4345 .48229 Mtetra
.659 .738 .908 r
.4345 .48229 .44091 .48887 .45195 .48552 .44558 .47886 Mtetra
.655 .736 .909 r
.44558 .47886 .45195 .48552 .46304 .4823 .45669 .47553 Mtetra
.648 .731 .909 r
.45669 .47553 .46304 .4823 .47417 .47932 .46786 .47239 Mtetra
.636 .723 .91 r
.46786 .47239 .47417 .47932 .48535 .47674 .47906 .46958 Mtetra
.617 .71 .912 r
.47906 .46958 .48535 .47674 .49657 .47475 .49032 .46731 Mtetra
.586 .691 .914 r
.49032 .46731 .49657 .47475 .50785 .47362 .50162 .46584 Mtetra
.538 .661 .916 r
.50162 .46584 .50785 .47362 .51919 .47364 .51298 .46553 Mtetra
.466 .619 .916 r
.51298 .46553 .51919 .47364 .5306 .47512 .52441 .46676 Mtetra
.361 .557 .909 r
.52441 .46676 .5306 .47512 .54211 .47827 .53593 .46991 Mtetra
.207 .469 .885 r
.53593 .46991 .54211 .47827 .55373 .48318 .54756 .47528 Mtetra
0 .343 .822 r
.54756 .47528 .55373 .48318 .56547 .48971 .55932 .48295 Mtetra
0 .171 .679 r
.55932 .48295 .56547 .48971 .57736 .49742 .57125 .49271 Mtetra
.556 .021 0 r
.57125 .49271 .57736 .49742 .58938 .50556 .58335 .50397 Mtetra
.704 .165 0 r
.58335 .50397 .58938 .50556 .60153 .51313 .59562 .51573 Mtetra
.718 .227 .074 r
.59562 .51573 .60153 .51313 .61376 .51897 .60803 .52662 Mtetra
.663 .231 .211 r
.60803 .52662 .61376 .51897 .62603 .52198 .62054 .53513 Mtetra
.588 .207 .287 r
.62054 .53513 .62603 .52198 .63828 .52132 .63306 .53982 Mtetra
.511 .171 .327 r
.63306 .53982 .63828 .52132 .65045 .51659 .64552 .5396 Mtetra
.439 .131 .344 r
.64552 .5396 .65045 .51659 .6625 .5079 .65786 .534 Mtetra
.372 .087 .345 r
.65786 .534 .6625 .5079 .67442 .49589 .67001 .52326 Mtetra
.308 .04 .334 r
.67001 .52326 .67442 .49589 .68622 .48154 .68196 .50826 Mtetra
.245 0 .311 r
.68196 .50826 .68622 .48154 .69793 .466 .69373 .49036 Mtetra
.177 0 .273 r
.69373 .49036 .69793 .466 .7096 .45038 .70538 .47108 Mtetra
.096 0 .213 r
.70538 .47108 .7096 .45038 .72128 .43557 .71697 .45186 Mtetra
0 0 .115 r
.71697 .45186 .72128 .43557 .73302 .42219 .72857 .43383 Mtetra
0 0 0 r
.72857 .43383 .73302 .42219 .74486 .41052 .74024 .41774 Mtetra
.74024 .41774 .74486 .41052 .75683 .4006 .75203 .40392 Mtetra
.617 .911 .632 r
.75203 .40392 .75683 .4006 .76891 .39226 .76397 .39238 Mtetra
.752 .994 .862 r
.76397 .39238 .76891 .39226 .78113 .38523 .77607 .38286 Mtetra
.766 .947 .937 r
.77607 .38286 .78113 .38523 .79346 .37922 .78831 .37503 Mtetra
.739 .877 .944 r
.78831 .37503 .79346 .37922 .80589 .37394 .80069 .36847 Mtetra
.712 .824 .934 r
.80069 .36847 .80589 .37394 .81842 .36915 .81319 .36284 Mtetra
.693 .789 .925 r
.81319 .36284 .81842 .36915 .83102 .36467 .82579 .35782 Mtetra
.68 .768 .918 r
.82579 .35782 .83102 .36467 .8437 .36037 .83848 .35319 Mtetra
.673 .756 .913 r
.83848 .35319 .8437 .36037 .85644 .35617 .85125 .34878 Mtetra
.668 .749 .911 r
.85125 .34878 .85644 .35617 .86925 .35202 .86409 .34451 Mtetra
.666 .745 .909 r
.86409 .34451 .86925 .35202 .88211 .34788 .87699 .34029 Mtetra
.665 .743 .909 r
.87699 .34029 .88211 .34788 .89503 .34374 .88995 .33609 Mtetra
.664 .742 .908 r
.88995 .33609 .89503 .34374 .90801 .33959 .90297 .3319 Mtetra
.664 .741 .908 r
.30883 .51405 .31558 .52034 .32617 .51694 .31945 .51063 Mtetra
.31945 .51063 .32617 .51694 .33681 .51353 .33011 .50719 Mtetra
.33011 .50719 .33681 .51353 .34749 .5101 .34082 .50374 Mtetra
.34082 .50374 .34749 .5101 .35821 .50666 .35157 .50027 Mtetra
.35157 .50027 .35821 .50666 .36898 .5032 .36236 .49679 Mtetra
.36236 .49679 .36898 .5032 .37979 .49974 .3732 .4933 Mtetra
.3732 .4933 .37979 .49974 .39064 .49626 .38408 .48979 Mtetra
.663 .741 .908 r
.38408 .48979 .39064 .49626 .40154 .49277 .39501 .48627 Mtetra
.39501 .48627 .40154 .49277 .41248 .48927 .40598 .48274 Mtetra
.40598 .48274 .41248 .48927 .42347 .48577 .41699 .4792 Mtetra
.662 .74 .908 r
.41699 .4792 .42347 .48577 .4345 .48229 .42805 .47568 Mtetra
.661 .739 .908 r
.42805 .47568 .4345 .48229 .44558 .47886 .43915 .47217 Mtetra
.658 .737 .908 r
.43915 .47217 .44558 .47886 .45669 .47553 .4503 .46874 Mtetra
.653 .733 .908 r
.4503 .46874 .45669 .47553 .46786 .47239 .46149 .46544 Mtetra
.644 .726 .908 r
.46149 .46544 .46786 .47239 .47906 .46958 .47273 .46239 Mtetra
.629 .715 .908 r
.47273 .46239 .47906 .46958 .49032 .46731 .48401 .45976 Mtetra
.604 .696 .908 r
.48401 .45976 .49032 .46731 .50162 .46584 .49534 .45781 Mtetra
.566 .667 .906 r
.49534 .45781 .50162 .46584 .51298 .46553 .50673 .4569 Mtetra
.508 .625 .902 r
.50673 .4569 .51298 .46553 .52441 .46676 .51817 .45744 Mtetra
.425 .566 .891 r
.51817 .45744 .52441 .46676 .53593 .46991 .5297 .45991 Mtetra
.312 .485 .87 r
.5297 .45991 .53593 .46991 .54756 .47528 .54133 .46478 Mtetra
.163 .383 .831 r
.54133 .46478 .54756 .47528 .55932 .48295 .5531 .4724 Mtetra
0 .258 .766 r
.5531 .4724 .55932 .48295 .57125 .49271 .56503 .48284 Mtetra
0 .113 .662 r
.56503 .48284 .57125 .49271 .58335 .50397 .57715 .49584 Mtetra
0 0 .5 r
.57715 .49584 .58335 .50397 .59562 .51573 .58948 .51062 Mtetra
.687 .177 0 r
.58948 .51062 .59562 .51573 .60803 .52662 .60201 .5259 Mtetra
.759 .247 0 r
.60201 .5259 .60803 .52662 .62054 .53513 .6147 .53999 Mtetra
.71 .247 .149 r
.6147 .53999 .62054 .53513 .63306 .53982 .62748 .55099 Mtetra
.611 .209 .256 r
.62748 .55099 .63306 .53982 .64552 .5396 .64026 .55711 Mtetra
.509 .16 .31 r
.64026 .55711 .64552 .5396 .65786 .534 .65294 .55708 Mtetra
.418 .11 .333 r
.65294 .55708 .65786 .534 .67001 .52326 .66542 .55038 Mtetra
.339 .061 .338 r
.66542 .55038 .67001 .52326 .68196 .50826 .67765 .53738 Mtetra
.269 .013 .329 r
.67765 .53738 .68196 .50826 .69373 .49036 .68962 .51927 Mtetra
.203 0 .308 r
.68962 .51927 .69373 .49036 .70538 .47108 .70135 .49778 Mtetra
.136 0 .274 r
.70135 .49778 .70538 .47108 .71697 .45186 .71292 .47481 Mtetra
.06 0 .22 r
.71292 .47481 .71697 .45186 .72857 .43383 .72441 .45211 Mtetra
0 0 .134 r
.72441 .45211 .72857 .43383 .74024 .41774 .73592 .43104 Mtetra
0 0 0 r
.73592 .43104 .74024 .41774 .75203 .40392 .74752 .41242 Mtetra
.74752 .41242 .75203 .40392 .76397 .39238 .75927 .39663 Mtetra
.601 .877 .555 r
.75927 .39663 .76397 .39238 .77607 .38286 .77119 .38361 Mtetra
.756 .994 .818 r
.77119 .38361 .77607 .38286 .78831 .37503 .78329 .37305 Mtetra
.78 .963 .924 r
.78329 .37305 .78831 .37503 .80069 .36847 .79557 .3645 Mtetra
.752 .891 .942 r
.79557 .3645 .80069 .36847 .81319 .36284 .80801 .35747 Mtetra
.72 .833 .935 r
.80801 .35747 .81319 .36284 .82579 .35782 .82058 .35153 Mtetra
.697 .795 .925 r
.82058 .35153 .82579 .35782 .83848 .35319 .83326 .34631 Mtetra
.683 .771 .918 r
.83326 .34631 .83848 .35319 .85125 .34878 .84604 .34154 Mtetra
.674 .757 .913 r
.84604 .34154 .85125 .34878 .86409 .34451 .85889 .33704 Mtetra
.669 .749 .911 r
.85889 .33704 .86409 .34451 .87699 .34029 .87183 .33269 Mtetra
.666 .745 .909 r
.87183 .33269 .87699 .34029 .88995 .33609 .88482 .32841 Mtetra
.665 .743 .909 r
.88482 .32841 .88995 .33609 .90297 .3319 .89788 .32415 Mtetra
.664 .741 .908 r
.30203 .50772 .30883 .51405 .31945 .51063 .31267 .50427 Mtetra
.31267 .50427 .31945 .51063 .33011 .50719 .32336 .5008 Mtetra
.32336 .5008 .33011 .50719 .34082 .50374 .33409 .49733 Mtetra
.33409 .49733 .34082 .50374 .35157 .50027 .34487 .49383 Mtetra
.34487 .49383 .35157 .50027 .36236 .49679 .35569 .49033 Mtetra
.35569 .49033 .36236 .49679 .3732 .4933 .36656 .48681 Mtetra
.36656 .48681 .3732 .4933 .38408 .48979 .37746 .48327 Mtetra
.663 .741 .908 r
.37746 .48327 .38408 .48979 .39501 .48627 .38842 .47973 Mtetra
.38842 .47973 .39501 .48627 .40598 .48274 .39942 .47617 Mtetra
.39942 .47617 .40598 .48274 .41699 .4792 .41046 .4726 Mtetra
.41046 .4726 .41699 .4792 .42805 .47568 .42155 .46902 Mtetra
.662 .74 .908 r
.42155 .46902 .42805 .47568 .43915 .47217 .43268 .46546 Mtetra
.66 .738 .908 r
.43268 .46546 .43915 .47217 .4503 .46874 .44386 .46193 Mtetra
.657 .736 .908 r
.44386 .46193 .4503 .46874 .46149 .46544 .45508 .45849 Mtetra
.651 .73 .907 r
.45508 .45849 .46149 .46544 .47273 .46239 .46635 .45522 Mtetra
.64 .721 .906 r
.46635 .45522 .47273 .46239 .48401 .45976 .47767 .45225 Mtetra
.622 .705 .905 r
.47767 .45225 .48401 .45976 .49534 .45781 .48903 .44979 Mtetra
.593 .68 .902 r
.48903 .44979 .49534 .45781 .50673 .4569 .50043 .44815 Mtetra
.549 .643 .895 r
.50043 .44815 .50673 .4569 .51817 .45744 .5119 .44773 Mtetra
.486 .589 .882 r
.5119 .44773 .51817 .45744 .5297 .45991 .52344 .44904 Mtetra
.402 .517 .86 r
.52344 .44904 .5297 .45991 .54133 .46478 .53507 .45264 Mtetra
.296 .429 .827 r
.53507 .45264 .54133 .46478 .5531 .4724 .54682 .45904 Mtetra
.174 .331 .783 r
.54682 .45904 .5531 .4724 .56503 .48284 .55872 .46863 Mtetra
.04 .228 .729 r
.55872 .46863 .56503 .48284 .57715 .49584 .57082 .4815 Mtetra
0 .127 .67 r
.57082 .4815 .57715 .49584 .58948 .51062 .58314 .49727 Mtetra
0 .029 .601 r
.58314 .49727 .58948 .51062 .60201 .5259 .5957 .51502 Mtetra
0 0 .508 r
.5957 .51502 .60201 .5259 .6147 .53999 .60848 .53322 Mtetra
.634 .15 0 r
.60848 .53322 .6147 .53999 .62748 .55099 .62144 .54987 Mtetra
.718 .184 0 r
.62144 .54987 .62748 .55099 .64026 .55711 .63448 .56275 Mtetra
.625 .148 .1 r
.63448 .56275 .64026 .55711 .65294 .55708 .64749 .56982 Mtetra
.478 .087 .219 r
.64749 .56982 .65294 .55708 .66542 .55038 .66035 .56964 Mtetra
.354 .03 .271 r
.66035 .56964 .66542 .55038 .67765 .53738 .67296 .56168 Mtetra
.258 0 .288 r
.67296 .56168 .67765 .53738 .68962 .51927 .68525 .54651 Mtetra
.182 0 .286 r
.68525 .54651 .68962 .51927 .70135 .49778 .69722 .5256 Mtetra
.115 0 .269 r
.69722 .5256 .70135 .49778 .71292 .47481 .70891 .501 Mtetra
.05 0 .238 r
.70891 .501 .71292 .47481 .72441 .45211 .7204 .47494 Mtetra
0 0 .186 r
.7204 .47494 .72441 .45211 .73592 .43104 .73182 .4494 Mtetra
0 0 .103 r
.73182 .4494 .73592 .43104 .74752 .41242 .74326 .42589 Mtetra
0 0 0 r
.74326 .42589 .74752 .41242 .75927 .39663 .7548 .40531 Mtetra
.7548 .40531 .75927 .39663 .77119 .38361 .76652 .38802 Mtetra
.636 .886 .548 r
.76652 .38802 .77119 .38361 .78329 .37305 .77844 .3739 Mtetra
.775 .996 .803 r
.77844 .3739 .78329 .37305 .79557 .3645 .79057 .36257 Mtetra
.793 .967 .915 r
.79057 .36257 .79557 .3645 .80801 .35747 .8029 .35349 Mtetra
.76 .896 .938 r
.8029 .35349 .80801 .35747 .82058 .35153 .8154 .34612 Mtetra
.725 .837 .933 r
.8154 .34612 .82058 .35153 .83326 .34631 .82804 .33995 Mtetra
.7 .797 .925 r
.82804 .33995 .83326 .34631 .84604 .34154 .84081 .33458 Mtetra
.684 .772 .918 r
.84081 .33458 .84604 .34154 .85889 .33704 .85368 .32971 Mtetra
.675 .758 .913 r
.85368 .32971 .85889 .33704 .87183 .33269 .86664 .32513 Mtetra
.669 .75 .911 r
.86664 .32513 .87183 .33269 .88482 .32841 .87966 .32071 Mtetra
.666 .745 .909 r
.87966 .32071 .88482 .32841 .89788 .32415 .89276 .31637 Mtetra
.664 .741 .908 r
.29517 .50134 .30203 .50772 .31267 .50427 .30585 .49786 Mtetra
.30585 .49786 .31267 .50427 .32336 .5008 .31656 .49437 Mtetra
.31656 .49437 .32336 .5008 .33409 .49733 .32732 .49087 Mtetra
.32732 .49087 .33409 .49733 .34487 .49383 .33812 .48735 Mtetra
.33812 .48735 .34487 .49383 .35569 .49033 .34897 .48382 Mtetra
.34897 .48382 .35569 .49033 .36656 .48681 .35986 .48027 Mtetra
.35986 .48027 .36656 .48681 .37746 .48327 .3708 .47671 Mtetra
.3708 .47671 .37746 .48327 .38842 .47973 .38178 .47313 Mtetra
.663 .741 .908 r
.38178 .47313 .38842 .47973 .39942 .47617 .39281 .46954 Mtetra
.39281 .46954 .39942 .47617 .41046 .4726 .40388 .46594 Mtetra
.40388 .46594 .41046 .4726 .42155 .46902 .415 .46233 Mtetra
.415 .46233 .42155 .46902 .43268 .46546 .42616 .45872 Mtetra
.662 .74 .908 r
.42616 .45872 .43268 .46546 .44386 .46193 .43737 .45512 Mtetra
.66 .738 .907 r
.43737 .45512 .44386 .46193 .45508 .45849 .44862 .45157 Mtetra
.656 .734 .907 r
.44862 .45157 .45508 .45849 .46635 .45522 .45992 .44811 Mtetra
.649 .727 .906 r
.45992 .44811 .46635 .45522 .47767 .45225 .47127 .44485 Mtetra
.637 .715 .904 r
.47127 .44485 .47767 .45225 .48903 .44979 .48266 .44193 Mtetra
.617 .696 .9 r
.48266 .44193 .48903 .44979 .50043 .44815 .4941 .4396 Mtetra
.585 .665 .894 r
.4941 .4396 .50043 .44815 .5119 .44773 .50559 .43819 Mtetra
.539 .62 .881 r
.50559 .43819 .5119 .44773 .52344 .44904 .51714 .43815 Mtetra
.476 .558 .86 r
.51714 .43815 .52344 .44904 .53507 .45264 .52877 .44003 Mtetra
.398 .482 .829 r
.52877 .44003 .53507 .45264 .54682 .45904 .54051 .44444 Mtetra
.31 .396 .79 r
.54051 .44444 .54682 .45904 .55872 .46863 .55237 .45194 Mtetra
.22 .312 .746 r
.55237 .45194 .55872 .46863 .57082 .4815 .56442 .46292 Mtetra
.136 .235 .704 r
.56442 .46292 .57082 .4815 .58314 .49727 .57667 .47745 Mtetra
.06 .172 .669 r
.57667 .47745 .58314 .49727 .5957 .51502 .58918 .49507 Mtetra
0 .125 .645 r
.58918 .49507 .5957 .51502 .60848 .53322 .60194 .51473 Mtetra
0 .096 .635 r
.60194 .51473 .60848 .53322 .62144 .54987 .61494 .53472 Mtetra
0 .089 .643 r
.61494 .53472 .62144 .54987 .63448 .56275 .62812 .55282 Mtetra
0 .121 .667 r
.62812 .55282 .63448 .56275 .64749 .56982 .64138 .56662 Mtetra
.357 0 0 r
.64138 .56662 .64749 .56982 .66035 .56964 .65457 .57391 Mtetra
.274 0 0 r
.65457 .57391 .66035 .56964 .67296 .56168 .66758 .5732 Mtetra
.134 0 .033 r
.66758 .5732 .67296 .56168 .68525 .54651 .68027 .56404 Mtetra
.049 0 .13 r
.68027 .56404 .68525 .54651 .69722 .5256 .69261 .54714 Mtetra
0 0 .164 r
.69261 .54714 .69722 .5256 .70891 .501 .70457 .5242 Mtetra
0 0 .166 r
.70457 .5242 .70891 .501 .7204 .47494 .71623 .4975 Mtetra
0 0 .144 r
.71623 .4975 .7204 .47494 .73182 .4494 .72769 .46947 Mtetra
0 0 .096 r
.72769 .46947 .73182 .4494 .74326 .42589 .73907 .44222 Mtetra
0 0 .013 r
.73907 .44222 .74326 .42589 .7548 .40531 .75048 .41731 Mtetra
0 0 0 r
.75048 .41731 .7548 .40531 .76652 .38802 .76202 .39566 Mtetra
.76202 .39566 .76652 .38802 .77844 .3739 .77375 .37758 Mtetra
.713 .931 .605 r
.77375 .37758 .77844 .3739 .79057 .36257 .78571 .36291 Mtetra
.806 1 .819 r
.78571 .36291 .79057 .36257 .8029 .35349 .79789 .35121 Mtetra
.803 .96 .913 r
.79789 .35121 .8029 .35349 .8154 .34612 .81028 .34189 Mtetra
.764 .89 .934 r
.81028 .34189 .8154 .34612 .82804 .33995 .82286 .33436 Mtetra
.727 .833 .931 r
.82286 .33436 .82804 .33995 .84081 .33458 .83559 .32808 Mtetra
.701 .795 .923 r
.83559 .32808 .84081 .33458 .85368 .32971 .84845 .32262 Mtetra
.685 .771 .917 r
.84845 .32262 .85368 .32971 .86664 .32513 .86142 .31769 Mtetra
.675 .757 .913 r
.86142 .31769 .86664 .32513 .87966 .32071 .87447 .31305 Mtetra
.669 .749 .911 r
.87447 .31305 .87966 .32071 .89276 .31637 .8876 .30858 Mtetra
.664 .741 .908 r
.28827 .49491 .29517 .50134 .30585 .49786 .29897 .49141 Mtetra
.29897 .49141 .30585 .49786 .31656 .49437 .30971 .48789 Mtetra
.30971 .48789 .31656 .49437 .32732 .49087 .3205 .48436 Mtetra
.3205 .48436 .32732 .49087 .33812 .48735 .33133 .48082 Mtetra
.33133 .48082 .33812 .48735 .34897 .48382 .3422 .47726 Mtetra
.3422 .47726 .34897 .48382 .35986 .48027 .35312 .47368 Mtetra
.35312 .47368 .35986 .48027 .3708 .47671 .36408 .47009 Mtetra
.36408 .47009 .3708 .47671 .38178 .47313 .37509 .46649 Mtetra
.37509 .46649 .38178 .47313 .39281 .46954 .38615 .46287 Mtetra
.663 .741 .908 r
.38615 .46287 .39281 .46954 .40388 .46594 .39725 .45924 Mtetra
.39725 .45924 .40388 .46594 .415 .46233 .40839 .4556 Mtetra
.40839 .4556 .415 .46233 .42616 .45872 .41959 .45195 Mtetra
.663 .74 .908 r
.41959 .45195 .42616 .45872 .43737 .45512 .43083 .44829 Mtetra
.662 .739 .908 r
.43083 .44829 .43737 .45512 .44862 .45157 .44211 .44466 Mtetra
.659 .737 .907 r
.44211 .44466 .44862 .45157 .45992 .44811 .45344 .44107 Mtetra
.655 .733 .906 r
.45344 .44107 .45992 .44811 .47127 .44485 .46482 .43759 Mtetra
.648 .725 .905 r
.46482 .43759 .47127 .44485 .48266 .44193 .47624 .43432 Mtetra
.635 .711 .901 r
.47624 .43432 .48266 .44193 .4941 .4396 .48772 .43141 Mtetra
.614 .688 .896 r
.48772 .43141 .4941 .4396 .50559 .43819 .49924 .42913 Mtetra
.582 .653 .885 r
.49924 .42913 .50559 .43819 .51714 .43815 .51081 .42783 Mtetra
.537 .603 .867 r
.51081 .42783 .51714 .43815 .52877 .44003 .52245 .42797 Mtetra
.478 .538 .84 r
.52245 .42797 .52877 .44003 .54051 .44444 .53418 .43012 Mtetra
.41 .462 .803 r
.53418 .43012 .54051 .44444 .55237 .45194 .54601 .43489 Mtetra
.34 .384 .762 r
.54601 .43489 .55237 .45194 .56442 .46292 .55799 .44286 Mtetra
.277 .314 .72 r
.55799 .44286 .56442 .46292 .57667 .47745 .57016 .45439 Mtetra
.227 .258 .685 r
.57016 .45439 .57667 .47745 .58918 .49507 .58256 .46951 Mtetra
.192 .219 .661 r
.58256 .46951 .58918 .49507 .60194 .51473 .59522 .48771 Mtetra
.172 .199 .648 r
.59522 .48771 .60194 .51473 .61494 .53472 .60814 .50785 Mtetra
.17 .2 .65 r
.60814 .50785 .61494 .53472 .62812 .55282 .62131 .52813 Mtetra
.188 .227 .671 r
.62131 .52813 .62812 .55282 .64138 .56662 .63464 .54626 Mtetra
.236 .294 .72 r
.63464 .54626 .64138 .56662 .65457 .57391 .64803 .55978 Mtetra
.341 .438 .815 r
.64803 .55978 .65457 .57391 .66758 .5732 .66134 .5665 Mtetra
.555 .732 .958 r
.66134 .5665 .66758 .5732 .68027 .56404 .67443 .56497 Mtetra
.735 .992 .843 r
.67443 .56497 .68027 .56404 .69261 .54714 .68719 .55486 Mtetra
.59 .81 .41 r
.68719 .55486 .69261 .54714 .70457 .5242 .69955 .537 Mtetra
0 0 0 r
.69955 .537 .70457 .5242 .71623 .4975 .71153 .51319 Mtetra
.71153 .51319 .71623 .4975 .72769 .46947 .7232 .48581 Mtetra
.7232 .48581 .72769 .46947 .73907 .44222 .73467 .4573 Mtetra
.73467 .4573 .73907 .44222 .75048 .41731 .74607 .42978 Mtetra
.74607 .42978 .75048 .41731 .76202 .39566 .75752 .40476 Mtetra
.75752 .40476 .76202 .39566 .77375 .37758 .76912 .38311 Mtetra
.7 .879 .488 r
.76912 .38311 .77375 .37758 .78571 .36291 .78092 .36509 Mtetra
.803 .981 .701 r
.78092 .36509 .78571 .36291 .79789 .35121 .79296 .35052 Mtetra
.834 .994 .852 r
.79296 .35052 .79789 .35121 .81028 .34189 .80523 .33891 Mtetra
.806 .941 .916 r
.80523 .33891 .81028 .34189 .82286 .33436 .81772 .32965 Mtetra
.762 .876 .93 r
.81772 .32965 .82286 .33436 .83559 .32808 .83039 .32216 Mtetra
.725 .825 .927 r
.83039 .32216 .83559 .32808 .84845 .32262 .84322 .31589 Mtetra
.699 .79 .921 r
.84322 .31589 .84845 .32262 .86142 .31769 .85619 .31043 Mtetra
.684 .769 .916 r
.85619 .31043 .86142 .31769 .87447 .31305 .86925 .30547 Mtetra
.674 .756 .912 r
.86925 .30547 .87447 .31305 .8876 .30858 .88241 .30079 Mtetra
.664 .741 .908 r
.28131 .48843 .28827 .49491 .29897 .49141 .29204 .48491 Mtetra
.29204 .48491 .29897 .49141 .30971 .48789 .30281 .48136 Mtetra
.30281 .48136 .30971 .48789 .3205 .48436 .31362 .47781 Mtetra
.31362 .47781 .3205 .48436 .33133 .48082 .32448 .47423 Mtetra
.32448 .47423 .33133 .48082 .3422 .47726 .33538 .47065 Mtetra
.33538 .47065 .3422 .47726 .35312 .47368 .34633 .46705 Mtetra
.34633 .46705 .35312 .47368 .36408 .47009 .35732 .46343 Mtetra
.35732 .46343 .36408 .47009 .37509 .46649 .36835 .4598 Mtetra
.36835 .4598 .37509 .46649 .38615 .46287 .37944 .45615 Mtetra
.37944 .45615 .38615 .46287 .39725 .45924 .39057 .45249 Mtetra
.663 .741 .908 r
.39057 .45249 .39725 .45924 .40839 .4556 .40174 .44882 Mtetra
.40174 .44882 .40839 .4556 .41959 .45195 .41296 .44513 Mtetra
.41296 .44513 .41959 .45195 .43083 .44829 .42423 .44143 Mtetra
.663 .74 .908 r
.42423 .44143 .43083 .44829 .44211 .44466 .43555 .43774 Mtetra
.662 .739 .907 r
.43555 .43774 .44211 .44466 .45344 .44107 .44691 .43406 Mtetra
.659 .736 .907 r
.44691 .43406 .45344 .44107 .46482 .43759 .45832 .43043 Mtetra
.655 .732 .906 r
.45832 .43043 .46482 .43759 .47624 .43432 .46978 .42691 Mtetra
.648 .723 .903 r
.46978 .42691 .47624 .43432 .48772 .43141 .48128 .4236 Mtetra
.635 .708 .899 r
.48128 .4236 .48772 .43141 .49924 .42913 .49283 .42066 Mtetra
.615 .683 .891 r
.49283 .42066 .49924 .42913 .51081 .42783 .50444 .41834 Mtetra
.584 .645 .877 r
.50444 .41834 .51081 .42783 .52245 .42797 .5161 .417 Mtetra
.541 .593 .855 r
.5161 .417 .52245 .42797 .53418 .43012 .52783 .41708 Mtetra
.489 .528 .824 r
.52783 .41708 .53418 .43012 .54601 .43489 .53964 .41914 Mtetra
.431 .456 .785 r
.53964 .41914 .54601 .43489 .55799 .44286 .55158 .42376 Mtetra
.377 .387 .744 r
.55158 .42376 .55799 .44286 .57016 .45439 .56366 .43147 Mtetra
.333 .329 .705 r
.56366 .43147 .57016 .45439 .58256 .46951 .57594 .4426 Mtetra
.303 .286 .674 r
.57594 .4426 .58256 .46951 .59522 .48771 .58844 .45712 Mtetra
.287 .26 .653 r
.58844 .45712 .59522 .48771 .60814 .50785 .60121 .4745 Mtetra
.288 .251 .642 r
.60121 .4745 .60814 .50785 .62131 .52813 .61424 .49357 Mtetra
.304 .259 .642 r
.61424 .49357 .62131 .52813 .63464 .54626 .62749 .51257 Mtetra
.337 .286 .653 r
.62749 .51257 .63464 .54626 .64803 .55978 .6409 .52928 Mtetra
.393 .337 .675 r
.6409 .52928 .64803 .55978 .66134 .5665 .65435 .54137 Mtetra
.479 .419 .712 r
.65435 .54137 .66134 .5665 .67443 .56497 .6677 .54681 Mtetra
.605 .544 .76 r
.6677 .54681 .67443 .56497 .68719 .55486 .68082 .54432 Mtetra
.772 .719 .802 r
.68082 .54432 .68719 .55486 .69955 .537 .6936 .5337 Mtetra
.923 .891 .782 r
.6936 .5337 .69955 .537 .71153 .51319 .706 .51582 Mtetra
.949 .952 .653 r
.706 .51582 .71153 .51319 .7232 .48581 .71803 .49247 Mtetra
.873 .908 .499 r
.71803 .49247 .7232 .48581 .73467 .4573 .72976 .46594 Mtetra
.794 .854 .403 r
.72976 .46594 .73467 .4573 .74607 .42978 .74132 .43853 Mtetra
.755 .836 .379 r
.74132 .43853 .74607 .42978 .75752 .40476 .75282 .41221 Mtetra
.759 .858 .419 r
.75282 .41221 .75752 .40476 .76912 .38311 .76438 .38838 Mtetra
.796 .912 .519 r
.76438 .38838 .76912 .38311 .78092 .36509 .7761 .3678 Mtetra
.843 .972 .659 r
.7761 .3678 .78092 .36509 .79296 .35052 .78803 .35068 Mtetra
.864 .996 .794 r
.78803 .35068 .79296 .35052 .80523 .33891 .8002 .33681 Mtetra
.843 .968 .881 r
.8002 .33681 .80523 .33891 .81772 .32965 .81259 .32572 Mtetra
.798 .911 .918 r
.81259 .32572 .81772 .32965 .83039 .32216 .8252 .31682 Mtetra
.753 .855 .925 r
.8252 .31682 .83039 .32216 .84322 .31589 .83799 .30955 Mtetra
.719 .812 .923 r
.83799 .30955 .84322 .31589 .85619 .31043 .85094 .30341 Mtetra
.696 .783 .918 r
.85094 .30341 .85619 .31043 .86925 .30547 .86401 .298 Mtetra
.682 .765 .914 r
.86401 .298 .86925 .30547 .88241 .30079 .87718 .29305 Mtetra
.664 .741 .908 r
.27431 .48191 .28131 .48843 .29204 .48491 .28506 .47835 Mtetra
.28506 .47835 .29204 .48491 .30281 .48136 .29585 .47478 Mtetra
.29585 .47478 .30281 .48136 .31362 .47781 .30669 .4712 Mtetra
.30669 .4712 .31362 .47781 .32448 .47423 .31758 .4676 Mtetra
.31758 .4676 .32448 .47423 .33538 .47065 .3285 .46399 Mtetra
.3285 .46399 .33538 .47065 .34633 .46705 .33948 .46036 Mtetra
.33948 .46036 .34633 .46705 .35732 .46343 .3505 .45671 Mtetra
.3505 .45671 .35732 .46343 .36835 .4598 .36156 .45306 Mtetra
.36156 .45306 .36835 .4598 .37944 .45615 .37268 .44938 Mtetra
.37268 .44938 .37944 .45615 .39057 .45249 .38383 .44569 Mtetra
.38383 .44569 .39057 .45249 .40174 .44882 .39504 .44199 Mtetra
.663 .741 .908 r
.39504 .44199 .40174 .44882 .41296 .44513 .40629 .43827 Mtetra
.40629 .43827 .41296 .44513 .42423 .44143 .41759 .43454 Mtetra
.41759 .43454 .42423 .44143 .43555 .43774 .42893 .4308 Mtetra
.663 .74 .908 r
.42893 .4308 .43555 .43774 .44691 .43406 .44033 .42706 Mtetra
.662 .739 .907 r
.44033 .42706 .44691 .43406 .45832 .43043 .45177 .42333 Mtetra
.66 .736 .907 r
.45177 .42333 .45832 .43043 .46978 .42691 .46326 .41965 Mtetra
.656 .731 .905 r
.46326 .41965 .46978 .42691 .48128 .4236 .47479 .41607 Mtetra
.649 .722 .902 r
.47479 .41607 .48128 .4236 .49283 .42066 .48638 .4127 Mtetra
.637 .706 .897 r
.48638 .4127 .49283 .42066 .50444 .41834 .49801 .40967 Mtetra
.618 .681 .888 r
.49801 .40967 .50444 .41834 .5161 .417 .5097 .40723 Mtetra
.589 .643 .872 r
.5097 .40723 .5161 .417 .52783 .41708 .52145 .40569 Mtetra
.552 .592 .848 r
.52145 .40569 .52783 .41708 .53964 .41914 .53327 .40548 Mtetra
.506 .529 .815 r
.53327 .40548 .53964 .41914 .55158 .42376 .54517 .40709 Mtetra
.458 .463 .775 r
.54517 .40709 .55158 .42376 .56366 .43147 .5572 .41105 Mtetra
.415 .401 .735 r
.5572 .41105 .56366 .43147 .57594 .4426 .56937 .41782 Mtetra
.383 .351 .699 r
.56937 .41782 .57594 .4426 .58844 .45712 .58173 .42766 Mtetra
.363 .315 .67 r
.58173 .42766 .58844 .45712 .60121 .4745 .59431 .44051 Mtetra
.356 .295 .65 r
.59431 .44051 .60121 .4745 .61424 .49357 .60714 .45581 Mtetra
.363 .29 .639 r
.60714 .45581 .61424 .49357 .62749 .51257 .6202 .47246 Mtetra
.382 .298 .636 r
.6202 .47246 .62749 .51257 .6409 .52928 .63348 .48884 Mtetra
.414 .32 .64 r
.63348 .48884 .6409 .52928 .65435 .54137 .64688 .50296 Mtetra
.46 .357 .651 r
.64688 .50296 .65435 .54137 .6677 .54681 .66031 .51274 Mtetra
.522 .411 .668 r
.66031 .51274 .6677 .54681 .68082 .54432 .67364 .51644 Mtetra
.602 .484 .691 r
.67364 .51644 .68082 .54432 .6936 .5337 .68675 .51303 Mtetra
.701 .58 .715 r
.68675 .51303 .6936 .5337 .706 .51582 .69954 .5024 Mtetra
.811 .692 .733 r
.69954 .5024 .706 .51582 .71803 .49247 .71198 .48543 Mtetra
.909 .804 .731 r
.71198 .48543 .71803 .49247 .72976 .46594 .72409 .46376 Mtetra
.966 .887 .702 r
.72409 .46376 .72976 .46594 .74132 .43853 .73595 .43941 Mtetra
.972 .928 .66 r
.73595 .43941 .74132 .43853 .75282 .41221 .74766 .41444 Mtetra
.953 .946 .637 r
.74766 .41444 .75282 .41221 .76438 .38838 .75934 .39056 Mtetra
.933 .959 .652 r
.75934 .39056 .76438 .38838 .7761 .3678 .77109 .36898 Mtetra
.919 .975 .706 r
.77109 .36898 .7761 .3678 .78803 .35068 .783 .35033 Mtetra
.904 .982 .782 r
.783 .35033 .78803 .35068 .8002 .33681 .79511 .33477 Mtetra
.874 .965 .853 r
.79511 .33477 .8002 .33681 .81259 .32572 .80744 .32208 Mtetra
.829 .924 .897 r
.80744 .32208 .81259 .32572 .8252 .31682 .82 .31184 Mtetra
.781 .875 .916 r
.82 .31184 .8252 .31682 .83799 .30955 .83275 .30352 Mtetra
.74 .831 .92 r
.83275 .30352 .83799 .30955 .85094 .30341 .84567 .29661 Mtetra
.711 .797 .918 r
.84567 .29661 .85094 .30341 .86401 .298 .85874 .29067 Mtetra
.691 .774 .915 r
.85874 .29067 .86401 .298 .87718 .29305 .87193 .28537 Mtetra
.664 .741 .908 r
.26725 .47533 .27431 .48191 .28506 .47835 .27802 .47175 Mtetra
.27802 .47175 .28506 .47835 .29585 .47478 .28884 .46816 Mtetra
.28884 .46816 .29585 .47478 .30669 .4712 .29971 .46454 Mtetra
.29971 .46454 .30669 .4712 .31758 .4676 .31062 .46092 Mtetra
.31062 .46092 .31758 .4676 .3285 .46399 .32158 .45728 Mtetra
.32158 .45728 .3285 .46399 .33948 .46036 .33258 .45362 Mtetra
.33258 .45362 .33948 .46036 .3505 .45671 .34363 .44995 Mtetra
.34363 .44995 .3505 .45671 .36156 .45306 .35472 .44626 Mtetra
.35472 .44626 .36156 .45306 .37268 .44938 .36586 .44256 Mtetra
.36586 .44256 .37268 .44938 .38383 .44569 .37705 .43884 Mtetra
.37705 .43884 .38383 .44569 .39504 .44199 .38828 .43511 Mtetra
.38828 .43511 .39504 .44199 .40629 .43827 .39956 .43136 Mtetra
.663 .741 .908 r
.39956 .43136 .40629 .43827 .41759 .43454 .41089 .42759 Mtetra
.41089 .42759 .41759 .43454 .42893 .4308 .42227 .42382 Mtetra
.42227 .42382 .42893 .4308 .44033 .42706 .43369 .42003 Mtetra
.663 .74 .908 r
.43369 .42003 .44033 .42706 .45177 .42333 .44516 .41624 Mtetra
.662 .739 .907 r
.44516 .41624 .45177 .42333 .46326 .41965 .45669 .41246 Mtetra
.66 .736 .906 r
.45669 .41246 .46326 .41965 .47479 .41607 .46825 .40873 Mtetra
.656 .731 .905 r
.46825 .40873 .47479 .41607 .48638 .4127 .47987 .40508 Mtetra
.65 .723 .902 r
.47987 .40508 .48638 .4127 .49801 .40967 .49154 .40161 Mtetra
.64 .707 .896 r
.49154 .40161 .49801 .40967 .5097 .40723 .50326 .39845 Mtetra
.623 .683 .886 r
.50326 .39845 .5097 .40723 .52145 .40569 .51503 .3958 Mtetra
.598 .647 .869 r
.51503 .3958 .52145 .40569 .53327 .40548 .52686 .39395 Mtetra
.566 .598 .845 r
.52686 .39395 .53327 .40548 .54517 .40709 .53877 .39326 Mtetra
.527 .54 .812 r
.53877 .39326 .54517 .40709 .5572 .41105 .55076 .39414 Mtetra
.487 .479 .774 r
.55076 .39414 .5572 .41105 .56937 .41782 .56287 .39705 Mtetra
.452 .422 .735 r
.56287 .39705 .56937 .41782 .58173 .42766 .57511 .40235 Mtetra
.426 .377 .7 r
.57511 .40235 .58173 .42766 .59431 .44051 .58753 .41024 Mtetra
.412 .345 .672 r
.58753 .41024 .59431 .44051 .60714 .45581 .60016 .42061 Mtetra
.409 .327 .653 r
.60016 .42061 .60714 .45581 .6202 .47246 .613 .43295 Mtetra
.416 .322 .64 r
.613 .43295 .6202 .47246 .63348 .48884 .62606 .44627 Mtetra
.433 .328 .635 r
.62606 .44627 .63348 .48884 .64688 .50296 .63929 .45919 Mtetra
.46 .345 .635 r
.63929 .45919 .64688 .50296 .66031 .51274 .65264 .47 Mtetra
.497 .373 .641 r
.65264 .47 .66031 .51274 .67364 .51644 .66599 .47701 Mtetra
.544 .411 .651 r
.66599 .47701 .67364 .51644 .68675 .51303 .67926 .47883 Mtetra
.601 .462 .664 r
.67926 .47883 .68675 .51303 .69954 .5024 .69232 .47466 Mtetra
.668 .525 .681 r
.69232 .47466 .69954 .5024 .71198 .48543 .70512 .4645 Mtetra
.743 .6 .698 r
.70512 .4645 .71198 .48543 .72409 .46376 .71763 .44915 Mtetra
.819 .683 .714 r
.71763 .44915 .72409 .46376 .73595 .43941 .72986 .43 Mtetra
.885 .765 .725 r
.72986 .43 .73595 .43941 .74766 .41444 .7419 .40876 Mtetra
.928 .835 .732 r
.7419 .40876 .74766 .41444 .75934 .39056 .75382 .3871 Mtetra
.946 .886 .741 r
.75382 .3871 .75934 .39056 .77109 .36898 .76573 .36645 Mtetra
.942 .918 .762 r
.76573 .36645 .77109 .36898 .783 .35033 .77773 .34777 Mtetra
.922 .934 .797 r
.77773 .34777 .783 .35033 .79511 .33477 .78987 .33157 Mtetra
.889 .931 .84 r
.78987 .33157 .79511 .33477 .80744 .32208 .8022 .31795 Mtetra
.847 .909 .878 r
.8022 .31795 .80744 .32208 .82 .31184 .81473 .30673 Mtetra
.801 .876 .902 r
.81473 .30673 .82 .31184 .83275 .30352 .82746 .29752 Mtetra
.759 .839 .913 r
.82746 .29752 .83275 .30352 .84567 .29661 .84037 .28989 Mtetra
.725 .807 .915 r
.84037 .28989 .84567 .29661 .85874 .29067 .85344 .28341 Mtetra
.701 .782 .914 r
.85344 .28341 .85874 .29067 .87193 .28537 .86663 .27773 Mtetra
.664 .741 .908 r
.26013 .46871 .26725 .47533 .27802 .47175 .27093 .4651 Mtetra
.27093 .4651 .27802 .47175 .28884 .46816 .28178 .46148 Mtetra
.28178 .46148 .28884 .46816 .29971 .46454 .29268 .45784 Mtetra
.29268 .45784 .29971 .46454 .31062 .46092 .30361 .45418 Mtetra
.30361 .45418 .31062 .46092 .32158 .45728 .3146 .45051 Mtetra
.3146 .45051 .32158 .45728 .33258 .45362 .32563 .44683 Mtetra
.32563 .44683 .33258 .45362 .34363 .44995 .3367 .44313 Mtetra
.3367 .44313 .34363 .44995 .35472 .44626 .34783 .43941 Mtetra
.34783 .43941 .35472 .44626 .36586 .44256 .35899 .43568 Mtetra
.35899 .43568 .36586 .44256 .37705 .43884 .37021 .43193 Mtetra
.37021 .43193 .37705 .43884 .38828 .43511 .38147 .42817 Mtetra
.38147 .42817 .38828 .43511 .39956 .43136 .39278 .42439 Mtetra
.39278 .42439 .39956 .43136 .41089 .42759 .40414 .4206 Mtetra
.663 .741 .908 r
.40414 .4206 .41089 .42759 .42227 .42382 .41555 .41679 Mtetra
.41555 .41679 .42227 .42382 .43369 .42003 .427 .41297 Mtetra
.427 .41297 .43369 .42003 .44516 .41624 .43851 .40913 Mtetra
.663 .74 .908 r
.43851 .40913 .44516 .41624 .45669 .41246 .45006 .40529 Mtetra
.662 .739 .907 r
.45006 .40529 .45669 .41246 .46825 .40873 .46166 .40146 Mtetra
.66 .737 .906 r
.46166 .40146 .46825 .40873 .47987 .40508 .47331 .39766 Mtetra
.657 .732 .905 r
.47331 .39766 .47987 .40508 .49154 .40161 .48501 .39394 Mtetra
.652 .724 .901 r
.48501 .39394 .49154 .40161 .50326 .39845 .49676 .39035 Mtetra
.643 .71 .896 r
.49676 .39035 .50326 .39845 .51503 .3958 .50857 .38703 Mtetra
.629 .688 .886 r
.50857 .38703 .51503 .3958 .52686 .39395 .52042 .38413 Mtetra
.609 .655 .87 r
.52042 .38413 .52686 .39395 .53877 .39326 .53234 .38188 Mtetra
.582 .611 .847 r
.53234 .38188 .53877 .39326 .55076 .39414 .54433 .38059 Mtetra
.55 .558 .815 r
.54433 .38059 .55076 .39414 .56287 .39705 .55641 .38058 Mtetra
.517 .502 .779 r
.55641 .38058 .56287 .39705 .57511 .40235 .56859 .3822 Mtetra
.487 .45 .741 r
.56859 .3822 .57511 .40235 .58753 .41024 .5809 .38574 Mtetra
.465 .407 .708 r
.5809 .38574 .58753 .41024 .60016 .42061 .59336 .39132 Mtetra
.453 .377 .68 r
.59336 .39132 .60016 .42061 .613 .43295 .60601 .39881 Mtetra
.45 .358 .66 r
.60601 .39881 .613 .43295 .62606 .44627 .61884 .40778 Mtetra
.457 .352 .647 r
.61884 .40778 .62606 .44627 .63929 .45919 .63185 .41741 Mtetra
.471 .355 .64 r
.63185 .41741 .63929 .45919 .65264 .47 .64501 .42655 Mtetra
.493 .367 .637 r
.64501 .42655 .65264 .47 .66599 .47701 .65826 .43389 Mtetra
.522 .388 .64 r
.65826 .43389 .66599 .47701 .67926 .47883 .67152 .43809 Mtetra
.558 .418 .646 r
.67152 .43809 .67926 .47883 .69232 .47466 .6847 .43813 Mtetra
.601 .456 .656 r
.6847 .43813 .69232 .47466 .70512 .4645 .69773 .43345 Mtetra
.651 .503 .669 r
.69773 .43345 .70512 .4645 .71763 .44915 .71054 .4241 Mtetra
.705 .558 .685 r
.71054 .4241 .71763 .44915 .72986 .43 .72313 .41076 Mtetra
.761 .62 .703 r
.72313 .41076 .72986 .43 .7419 .40876 .73552 .39454 Mtetra
.814 .686 .723 r
.73552 .39454 .7419 .40876 .75382 .3871 .74776 .37677 Mtetra
.856 .749 .745 r
.74776 .37677 .75382 .3871 .76573 .36645 .75993 .35877 Mtetra
.88 .803 .769 r
.75993 .35877 .76573 .36645 .77773 .34777 .77211 .34161 Mtetra
.885 .842 .797 r
.77211 .34161 .77773 .34777 .78987 .33157 .78438 .32604 Mtetra
.871 .864 .829 r
.78438 .32604 .78987 .33157 .8022 .31795 .79678 .31244 Mtetra
.843 .866 .86 r
.79678 .31244 .8022 .31795 .81473 .30673 .80935 .30087 Mtetra
.807 .853 .885 r
.80935 .30087 .81473 .30673 .82746 .29752 .8221 .29117 Mtetra
.769 .831 .901 r
.8221 .29117 .82746 .29752 .84037 .28989 .83501 .28303 Mtetra
.736 .807 .908 r
.83501 .28303 .84037 .28989 .85344 .28341 .84809 .27611 Mtetra
.71 .786 .911 r
.84809 .27611 .85344 .28341 .86663 .27773 .8613 .27006 Mtetra
.664 .741 .908 r
.25296 .46203 .26013 .46871 .27093 .4651 .26379 .4584 Mtetra
.26379 .4584 .27093 .4651 .28178 .46148 .27467 .45475 Mtetra
.27467 .45475 .28178 .46148 .29268 .45784 .28559 .45108 Mtetra
.28559 .45108 .29268 .45784 .30361 .45418 .29655 .4474 Mtetra
.29655 .4474 .30361 .45418 .3146 .45051 .30756 .4437 Mtetra
.30756 .4437 .3146 .45051 .32563 .44683 .31862 .43998 Mtetra
.31862 .43998 .32563 .44683 .3367 .44313 .32973 .43626 Mtetra
.32973 .43626 .3367 .44313 .34783 .43941 .34088 .43251 Mtetra
.34088 .43251 .34783 .43941 .35899 .43568 .35207 .42875 Mtetra
.35207 .42875 .35899 .43568 .37021 .43193 .36332 .42497 Mtetra
.36332 .42497 .37021 .43193 .38147 .42817 .37461 .42118 Mtetra
.37461 .42118 .38147 .42817 .39278 .42439 .38595 .41737 Mtetra
.38595 .41737 .39278 .42439 .40414 .4206 .39734 .41355 Mtetra
.39734 .41355 .40414 .4206 .41555 .41679 .40878 .40971 Mtetra
.40878 .40971 .41555 .41679 .427 .41297 .42026 .40585 Mtetra
.663 .741 .908 r
.42026 .40585 .427 .41297 .43851 .40913 .4318 .40198 Mtetra
.4318 .40198 .43851 .40913 .45006 .40529 .44338 .3981 Mtetra
.663 .74 .908 r
.44338 .3981 .45006 .40529 .46166 .40146 .45502 .39421 Mtetra
.662 .739 .907 r
.45502 .39421 .46166 .40146 .47331 .39766 .4667 .39032 Mtetra
.661 .737 .906 r
.4667 .39032 .47331 .39766 .48501 .39394 .47843 .38646 Mtetra
.659 .733 .905 r
.47843 .38646 .48501 .39394 .49676 .39035 .49022 .38265 Mtetra
.654 .726 .902 r
.49022 .38265 .49676 .39035 .50857 .38703 .50205 .37895 Mtetra
.647 .715 .897 r
.50205 .37895 .50857 .38703 .52042 .38413 .51394 .37545 Mtetra
.636 .696 .888 r
.51394 .37545 .52042 .38413 .53234 .38188 .52588 .37228 Mtetra
.62 .667 .874 r
.52588 .37228 .53234 .38188 .54433 .38059 .53789 .36961 Mtetra
.599 .629 .852 r
.53789 .36961 .54433 .38059 .55641 .38058 .54996 .36767 Mtetra
.573 .582 .824 r
.54996 .36767 .55641 .38058 .56859 .3822 .56211 .36672 Mtetra
.546 .531 .79 r
.56211 .36672 .56859 .3822 .5809 .38574 .57436 .367 Mtetra
.521 .483 .755 r
.57436 .367 .5809 .38574 .59336 .39132 .58673 .36872 Mtetra
.501 .442 .722 r
.58673 .36872 .59336 .39132 .60601 .39881 .59923 .37195 Mtetra
.49 .411 .695 r
.59923 .37195 .60601 .39881 .61884 .40778 .61188 .37657 Mtetra
.486 .392 .674 r
.61188 .37657 .61884 .40778 .63185 .41741 .62469 .38222 Mtetra
.49 .383 .659 r
.62469 .38222 .63185 .41741 .64501 .42655 .63765 .38826 Mtetra
.501 .383 .65 r
.63765 .38826 .64501 .42655 .65826 .43389 .65072 .39382 Mtetra
.519 .391 .646 r
.65072 .39382 .65826 .43389 .67152 .43809 .66387 .39792 Mtetra
.542 .407 .647 r
.66387 .39792 .67152 .43809 .6847 .43813 .67704 .39961 Mtetra
.571 .43 .651 r
.67704 .39961 .6847 .43813 .69773 .43345 .69014 .39816 Mtetra
.604 .46 .659 r
.69014 .39816 .69773 .43345 .71054 .4241 .70314 .39321 Mtetra
.642 .497 .67 r
.70314 .39321 .71054 .4241 .72313 .41076 .71599 .38484 Mtetra
.683 .541 .685 r
.71599 .38484 .72313 .41076 .73552 .39454 .72869 .37358 Mtetra
.726 .591 .704 r
.72869 .37358 .73552 .39454 .74776 .37677 .74124 .36026 Mtetra
.766 .644 .727 r
.74124 .36026 .74776 .37677 .75993 .35877 .7537 .34586 Mtetra
.799 .697 .752 r
.7537 .34586 .75993 .35877 .77211 .34161 .76613 .33135 Mtetra
.82 .745 .781 r
.76613 .33135 .77211 .34161 .78438 .32604 .77859 .31751 Mtetra
.826 .783 .812 r
.77859 .31751 .78438 .32604 .79678 .31244 .79114 .30488 Mtetra
.816 .806 .841 r
.79114 .30488 .79678 .31244 .80935 .30087 .8038 .2937 Mtetra
.795 .813 .867 r
.8038 .2937 .80935 .30087 .8221 .29117 .81661 .28403 Mtetra
.767 .809 .886 r
.81661 .28403 .8221 .29117 .83501 .28303 .82957 .27573 Mtetra
.739 .797 .899 r
.82957 .27573 .83501 .28303 .84809 .27611 .84268 .26856 Mtetra
.715 .783 .905 r
.84268 .26856 .84809 .27611 .8613 .27006 .85592 .26227 Mtetra
.664 .741 .908 r
.24574 .45531 .25296 .46203 .26379 .4584 .25659 .45164 Mtetra
.25659 .45164 .26379 .4584 .27467 .45475 .2675 .44796 Mtetra
.2675 .44796 .27467 .45475 .28559 .45108 .27844 .44427 Mtetra
.27844 .44427 .28559 .45108 .29655 .4474 .28944 .44056 Mtetra
.28944 .44056 .29655 .4474 .30756 .4437 .30048 .43683 Mtetra
.30048 .43683 .30756 .4437 .31862 .43998 .31156 .43309 Mtetra
.31156 .43309 .31862 .43998 .32973 .43626 .32269 .42933 Mtetra
.32269 .42933 .32973 .43626 .34088 .43251 .33387 .42556 Mtetra
.33387 .42556 .34088 .43251 .35207 .42875 .3451 .42177 Mtetra
.3451 .42177 .35207 .42875 .36332 .42497 .35637 .41796 Mtetra
.35637 .41796 .36332 .42497 .37461 .42118 .3677 .41414 Mtetra
.3677 .41414 .37461 .42118 .38595 .41737 .37907 .4103 Mtetra
.37907 .4103 .38595 .41737 .39734 .41355 .39048 .40644 Mtetra
.39048 .40644 .39734 .41355 .40878 .40971 .40195 .40257 Mtetra
.40195 .40257 .40878 .40971 .42026 .40585 .41347 .39869 Mtetra
.41347 .39869 .42026 .40585 .4318 .40198 .42503 .39478 Mtetra
.663 .741 .908 r
.42503 .39478 .4318 .40198 .44338 .3981 .43665 .39087 Mtetra
.43665 .39087 .44338 .3981 .45502 .39421 .44832 .38693 Mtetra
.44832 .38693 .45502 .39421 .4667 .39032 .46003 .38299 Mtetra
.662 .74 .907 r
.46003 .38299 .4667 .39032 .47843 .38646 .4718 .37905 Mtetra
.661 .738 .907 r
.4718 .37905 .47843 .38646 .49022 .38265 .48362 .37513 Mtetra
.66 .735 .906 r
.48362 .37513 .49022 .38265 .50205 .37895 .49548 .37124 Mtetra
.656 .73 .903 r
.49548 .37124 .50205 .37895 .51394 .37545 .50741 .36743 Mtetra
.651 .72 .899 r
.50741 .36743 .51394 .37545 .52588 .37228 .51938 .36377 Mtetra
.643 .705 .892 r
.51938 .36377 .52588 .37228 .53789 .36961 .53141 .36034 Mtetra
.631 .682 .88 r
.53141 .36034 .53789 .36961 .54996 .36767 .5435 .35727 Mtetra
.615 .65 .862 r
.5435 .35727 .54996 .36767 .56211 .36672 .55566 .35472 Mtetra
.595 .61 .837 r
.55566 .35472 .56211 .36672 .57436 .367 .56789 .35287 Mtetra
.573 .566 .807 r
.56789 .35287 .57436 .367 .58673 .36872 .58021 .3519 Mtetra
.552 .522 .775 r
.58021 .3519 .58673 .36872 .59923 .37195 .59263 .35194 Mtetra
.535 .482 .744 r
.59263 .35194 .59923 .37195 .61188 .37657 .60516 .35303 Mtetra
.524 .451 .716 r
.60516 .35303 .61188 .37657 .62469 .38222 .61782 .35506 Mtetra
.519 .43 .694 r
.61782 .35506 .62469 .38222 .63765 .38826 .63061 .35777 Mtetra
.521 .418 .678 r
.63061 .35777 .63765 .38826 .65072 .39382 .64351 .36067 Mtetra
.529 .415 .668 r
.64351 .36067 .65072 .39382 .66387 .39792 .65652 .36317 Mtetra
.542 .419 .662 r
.65652 .36317 .66387 .39792 .67704 .39961 .66959 .36456 Mtetra
.56 .431 .661 r
.66959 .36456 .67704 .39961 .69014 .39816 .68268 .36421 Mtetra
.583 .449 .664 r
.68268 .36421 .69014 .39816 .70314 .39321 .69574 .36163 Mtetra
.61 .474 .671 r
.69574 .36163 .70314 .39321 .71599 .38484 .70874 .35659 Mtetra
.639 .504 .682 r
.70874 .35659 .71599 .38484 .72869 .37358 .72164 .3492 Mtetra
.671 .541 .697 r
.72164 .3492 .72869 .37358 .74124 .36026 .73445 .33982 Mtetra
.704 .582 .716 r
.73445 .33982 .74124 .36026 .7537 .34586 .74718 .32907 Mtetra
.734 .626 .739 r
.74718 .32907 .7537 .34586 .76613 .33135 .75986 .31761 Mtetra
.758 .671 .766 r
.75986 .31761 .76613 .33135 .77859 .31751 .77254 .30611 Mtetra
.774 .712 .795 r
.77254 .30611 .77859 .31751 .79114 .30488 .78526 .29511 Mtetra
.777 .745 .824 r
.78526 .29511 .79114 .30488 .8038 .2937 .79807 .28496 Mtetra
.77 .767 .85 r
.79807 .28496 .8038 .2937 .81661 .28403 .81098 .27583 Mtetra
.754 .777 .872 r
.81098 .27583 .81661 .28403 .82957 .27573 .82402 .26775 Mtetra
.734 .778 .888 r
.82402 .26775 .82957 .27573 .84268 .26856 .83718 .26061 Mtetra
.715 .773 .898 r
.83718 .26061 .84268 .26856 .85592 .26227 .85046 .25424 Mtetra
.664 .741 .908 r
.23846 .44853 .24574 .45531 .25659 .45164 .24934 .44484 Mtetra
.24934 .44484 .25659 .45164 .2675 .44796 .26027 .44113 Mtetra
.26027 .44113 .2675 .44796 .27844 .44427 .27124 .4374 Mtetra
.27124 .4374 .27844 .44427 .28944 .44056 .28226 .43366 Mtetra
.28226 .43366 .28944 .44056 .30048 .43683 .29333 .42991 Mtetra
.29333 .42991 .30048 .43683 .31156 .43309 .30445 .42614 Mtetra
.30445 .42614 .31156 .43309 .32269 .42933 .31561 .42235 Mtetra
.31561 .42235 .32269 .42933 .33387 .42556 .32681 .41855 Mtetra
.32681 .41855 .33387 .42556 .3451 .42177 .33807 .41473 Mtetra
.33807 .41473 .3451 .42177 .35637 .41796 .34937 .41089 Mtetra
.34937 .41089 .35637 .41796 .3677 .41414 .36072 .40704 Mtetra
.36072 .40704 .3677 .41414 .37907 .4103 .37213 .40317 Mtetra
.37213 .40317 .37907 .4103 .39048 .40644 .38357 .39929 Mtetra
.38357 .39929 .39048 .40644 .40195 .40257 .39507 .39538 Mtetra
.39507 .39538 .40195 .40257 .41347 .39869 .40662 .39147 Mtetra
.663 .741 .908 r
.40662 .39147 .41347 .39869 .42503 .39478 .41822 .38753 Mtetra
.41822 .38753 .42503 .39478 .43665 .39087 .42986 .38359 Mtetra
.42986 .38359 .43665 .39087 .44832 .38693 .44156 .37963 Mtetra
.44156 .37963 .44832 .38693 .46003 .38299 .45331 .37566 Mtetra
.45331 .37566 .46003 .38299 .4718 .37905 .46511 .37168 Mtetra
.662 .741 .909 r
.46511 .37168 .4718 .37905 .48362 .37513 .47696 .36771 Mtetra
.661 .74 .909 r
.47696 .36771 .48362 .37513 .49548 .37124 .48886 .36374 Mtetra
.66 .739 .908 r
.48886 .36374 .49548 .37124 .50741 .36743 .50082 .3598 Mtetra
.658 .735 .907 r
.50082 .3598 .50741 .36743 .51938 .36377 .51282 .3559 Mtetra
.654 .728 .903 r
.51282 .3559 .51938 .36377 .53141 .36034 .52489 .35209 Mtetra
.649 .717 .897 r
.52489 .35209 .53141 .36034 .5435 .35727 .537 .34842 Mtetra
.641 .699 .888 r
.537 .34842 .5435 .35727 .55566 .35472 .54918 .34498 Mtetra
.63 .674 .873 r
.54918 .34498 .55566 .35472 .56789 .35287 .56142 .34187 Mtetra
.616 .641 .853 r
.56142 .34187 .56789 .35287 .58021 .3519 .57373 .33923 Mtetra
.599 .603 .827 r
.57373 .33923 .58021 .3519 .59263 .35194 .58612 .33718 Mtetra
.582 .564 .799 r
.58612 .33718 .59263 .35194 .60516 .35303 .59859 .33579 Mtetra
.567 .527 .77 r
.59859 .33579 .60516 .35303 .61782 .35506 .61117 .3351 Mtetra
.556 .496 .744 r
.61117 .3351 .61782 .35506 .63061 .35777 .62385 .33501 Mtetra
.55 .474 .722 r
.62385 .33501 .63061 .35777 .64351 .36067 .63663 .33533 Mtetra
.55 .459 .705 r
.63663 .33533 .64351 .36067 .65652 .36317 .64951 .33575 Mtetra
.555 .453 .693 r
.64951 .33575 .65652 .36317 .66959 .36456 .66247 .33584 Mtetra
.565 .454 .686 r
.66247 .33584 .66959 .36456 .68268 .36421 .67549 .33515 Mtetra
.579 .462 .684 r
.67549 .33515 .68268 .36421 .69574 .36163 .68854 .33326 Mtetra
.596 .476 .686 r
.68854 .33326 .69574 .36163 .70874 .35659 .70159 .32988 Mtetra
.618 .497 .693 r
.70159 .32988 .70874 .35659 .72164 .3492 .71461 .32488 Mtetra
.641 .523 .703 r
.71461 .32488 .72164 .3492 .73445 .33982 .72758 .31834 Mtetra
.666 .554 .718 r
.72758 .31834 .73445 .33982 .74718 .32907 .74051 .31052 Mtetra
.69 .589 .737 r
.74051 .31052 .74718 .32907 .75986 .31761 .75341 .30183 Mtetra
.712 .627 .76 r
.75341 .30183 .75986 .31761 .77254 .30611 .7663 .2927 Mtetra
.729 .664 .786 r
.7663 .2927 .77254 .30611 .78526 .29511 .77921 .28357 Mtetra
.739 .699 .813 r
.77921 .28357 .78526 .29511 .79807 .28496 .79217 .27478 Mtetra
.741 .726 .838 r
.79217 .27478 .79807 .28496 .81098 .27583 .80521 .26656 Mtetra
.734 .745 .861 r
.80521 .26656 .81098 .27583 .82402 .26775 .81835 .25901 Mtetra
.723 .755 .878 r
.81835 .25901 .82402 .26775 .83718 .26061 .83159 .25214 Mtetra
.709 .758 .891 r
.83159 .25214 .83718 .26061 .85046 .25424 .84494 .24587 Mtetra
.664 .741 .908 r
.23112 .4417 .23846 .44853 .24934 .44484 .24203 .43798 Mtetra
.24203 .43798 .24934 .44484 .26027 .44113 .25299 .43424 Mtetra
.25299 .43424 .26027 .44113 .27124 .4374 .26399 .43049 Mtetra
.26399 .43049 .27124 .4374 .28226 .43366 .27504 .42672 Mtetra
.27504 .42672 .28226 .43366 .29333 .42991 .28613 .42293 Mtetra
.28613 .42293 .29333 .42991 .30445 .42614 .29727 .41913 Mtetra
.29727 .41913 .30445 .42614 .31561 .42235 .30846 .41532 Mtetra
.30846 .41532 .31561 .42235 .32681 .41855 .3197 .41148 Mtetra
.3197 .41148 .32681 .41855 .33807 .41473 .33099 .40763 Mtetra
.33099 .40763 .33807 .41473 .34937 .41089 .34232 .40377 Mtetra
.34232 .40377 .34937 .41089 .36072 .40704 .3537 .39988 Mtetra
.3537 .39988 .36072 .40704 .37213 .40317 .36513 .39599 Mtetra
.36513 .39599 .37213 .40317 .38357 .39929 .37661 .39207 Mtetra
.663 .741 .908 r
.37661 .39207 .38357 .39929 .39507 .39538 .38814 .38814 Mtetra
.38814 .38814 .39507 .39538 .40662 .39147 .39972 .3842 Mtetra
.39972 .3842 .40662 .39147 .41822 .38753 .41134 .38024 Mtetra
.663 .742 .909 r
.41134 .38024 .41822 .38753 .42986 .38359 .42302 .37628 Mtetra
.662 .742 .909 r
.42302 .37628 .42986 .38359 .44156 .37963 .43475 .37232 Mtetra
.662 .743 .91 r
.43475 .37232 .44156 .37963 .45331 .37566 .44653 .36836 Mtetra
.661 .744 .911 r
.44653 .36836 .45331 .37566 .46511 .37168 .45836 .36441 Mtetra
.66 .745 .913 r
.45836 .36441 .46511 .37168 .47696 .36771 .47025 .36045 Mtetra
.66 .746 .914 r
.47025 .36045 .47696 .36771 .48886 .36374 .48218 .35649 Mtetra
.66 .747 .915 r
.48218 .35649 .48886 .36374 .50082 .3598 .49417 .35252 Mtetra
.66 .748 .915 r
.49417 .35252 .50082 .3598 .51282 .3559 .50621 .34852 Mtetra
.66 .746 .913 r
.50621 .34852 .51282 .3559 .52489 .35209 .51831 .34451 Mtetra
.659 .741 .91 r
.51831 .34451 .52489 .35209 .537 .34842 .53046 .34051 Mtetra
.656 .731 .905 r
.53046 .34051 .537 .34842 .54918 .34498 .54267 .33657 Mtetra
.652 .717 .896 r
.54267 .33657 .54918 .34498 .56142 .34187 .55493 .33275 Mtetra
.644 .696 .884 r
.55493 .33275 .56142 .34187 .57373 .33923 .56726 .32914 Mtetra
.634 .67 .868 r
.56726 .32914 .57373 .33923 .58612 .33718 .57965 .32584 Mtetra
.621 .64 .848 r
.57965 .32584 .58612 .33718 .59859 .33579 .59211 .32292 Mtetra
.608 .607 .825 r
.59211 .32292 .59859 .33579 .61117 .3351 .60465 .32043 Mtetra
.596 .575 .8 r
.60465 .32043 .61117 .3351 .62385 .33501 .61727 .31837 Mtetra
.586 .546 .777 r
.61727 .31837 .62385 .33501 .63663 .33533 .62998 .31669 Mtetra
.58 .523 .756 r
.62998 .31669 .63663 .33533 .64951 .33575 .64278 .31524 Mtetra
.578 .507 .739 r
.64278 .31524 .64951 .33575 .66247 .33584 .65566 .31381 Mtetra
.581 .498 .727 r
.65566 .31381 .66247 .33584 .67549 .33515 .66862 .31215 Mtetra
.587 .497 .719 r
.66862 .31215 .67549 .33515 .68854 .33326 .68162 .30997 Mtetra
.598 .502 .716 r
.68162 .30997 .68854 .33326 .70159 .32988 .69467 .30701 Mtetra
.612 .513 .718 r
.69467 .30701 .70159 .32988 .71461 .32488 .70773 .30311 Mtetra
.628 .53 .724 r
.70773 .30311 .71461 .32488 .72758 .31834 .7208 .2982 Mtetra
.646 .552 .734 r
.7208 .2982 .72758 .31834 .74051 .31052 .73386 .29233 Mtetra
.664 .578 .749 r
.73386 .29233 .74051 .31052 .75341 .30183 .74691 .28568 Mtetra
.682 .608 .767 r
.74691 .28568 .75341 .30183 .7663 .2927 .75997 .2785 Mtetra
.697 .64 .788 r
.75997 .2785 .7663 .2927 .77921 .28357 .77305 .27108 Mtetra
.708 .671 .811 r
.77305 .27108 .77921 .28357 .79217 .27478 .78616 .26366 Mtetra
.714 .698 .834 r
.78616 .26366 .79217 .27478 .80521 .26656 .79933 .25646 Mtetra
.713 .72 .854 r
.79933 .25646 .80521 .26656 .81835 .25901 .81258 .24961 Mtetra
.708 .735 .872 r
.81258 .24961 .81835 .25901 .83159 .25214 .82591 .24317 Mtetra
.7 .744 .885 r
.82591 .24317 .83159 .25214 .84494 .24587 .83933 .23715 Mtetra
.664 .741 .908 r
.22373 .43482 .23112 .4417 .24203 .43798 .23467 .43107 Mtetra
.23467 .43107 .24203 .43798 .25299 .43424 .24565 .4273 Mtetra
.24565 .4273 .25299 .43424 .26399 .43049 .25668 .42352 Mtetra
.25668 .42352 .26399 .43049 .27504 .42672 .26775 .41972 Mtetra
.26775 .41972 .27504 .42672 .28613 .42293 .27888 .4159 Mtetra
.27888 .4159 .28613 .42293 .29727 .41913 .29005 .41207 Mtetra
.29005 .41207 .29727 .41913 .30846 .41532 .30127 .40823 Mtetra
.30127 .40823 .30846 .41532 .3197 .41148 .31253 .40436 Mtetra
.31253 .40436 .3197 .41148 .33099 .40763 .32384 .40048 Mtetra
.32384 .40048 .33099 .40763 .34232 .40377 .33521 .39659 Mtetra
.663 .741 .908 r
.33521 .39659 .34232 .40377 .3537 .39988 .34662 .39267 Mtetra
.34662 .39267 .3537 .39988 .36513 .39599 .35808 .38875 Mtetra
.35808 .38875 .36513 .39599 .37661 .39207 .36959 .38481 Mtetra
.36959 .38481 .37661 .39207 .38814 .38814 .38115 .38086 Mtetra
.662 .742 .909 r
.38115 .38086 .38814 .38814 .39972 .3842 .39276 .37692 Mtetra
.661 .742 .91 r
.39276 .37692 .39972 .3842 .41134 .38024 .40441 .37298 Mtetra
.66 .743 .912 r
.40441 .37298 .41134 .38024 .42302 .37628 .41612 .36907 Mtetra
.659 .745 .914 r
.41612 .36907 .42302 .37628 .43475 .37232 .42788 .36518 Mtetra
.657 .748 .917 r
.42788 .36518 .43475 .37232 .44653 .36836 .43969 .36133 Mtetra
.655 .752 .921 r
.43969 .36133 .44653 .36836 .45836 .36441 .45155 .3575 Mtetra
.655 .756 .924 r
.45155 .3575 .45836 .36441 .47025 .36045 .46347 .35367 Mtetra
.656 .761 .927 r
.46347 .35367 .47025 .36045 .48218 .35649 .47544 .34978 Mtetra
.658 .765 .929 r
.47544 .34978 .48218 .35649 .49417 .35252 .48746 .34581 Mtetra
.661 .767 .929 r
.48746 .34581 .49417 .35252 .50621 .34852 .49954 .34173 Mtetra
.665 .767 .926 r
.49954 .34173 .50621 .34852 .51831 .34451 .51168 .33754 Mtetra
.667 .763 .922 r
.51168 .33754 .51831 .34451 .53046 .34051 .52387 .33325 Mtetra
.668 .756 .916 r
.52387 .33325 .53046 .34051 .54267 .33657 .53611 .32893 Mtetra
.666 .745 .909 r
.53611 .32893 .54267 .33657 .55493 .33275 .54841 .32464 Mtetra
.662 .731 .901 r
.54841 .32464 .55493 .33275 .56726 .32914 .56076 .32045 Mtetra
.655 .714 .891 r
.56076 .32045 .56726 .32914 .57965 .32584 .57317 .31643 Mtetra
.647 .694 .88 r
.57317 .31643 .57965 .32584 .59211 .32292 .58564 .31263 Mtetra
.638 .671 .865 r
.58564 .31263 .59211 .32292 .60465 .32043 .59818 .30909 Mtetra
.629 .646 .848 r
.59818 .30909 .60465 .32043 .61727 .31837 .61079 .30582 Mtetra
.62 .621 .83 r
.61079 .30582 .61727 .31837 .62998 .31669 .62348 .30281 Mtetra
.612 .597 .811 r
.62348 .30281 .62998 .31669 .64278 .31524 .63624 .30001 Mtetra
.607 .576 .793 r
.63624 .30001 .64278 .31524 .65566 .31381 .64907 .29732 Mtetra
.605 .56 .778 r
.64907 .29732 .65566 .31381 .66862 .31215 .66198 .29464 Mtetra
.606 .551 .766 r
.66198 .29464 .66862 .31215 .68162 .30997 .67496 .29178 Mtetra
.61 .547 .759 r
.67496 .29178 .68162 .30997 .69467 .30701 .68799 .2886 Mtetra
.617 .55 .756 r
.68799 .2886 .69467 .30701 .70773 .30311 .70107 .28494 Mtetra
.627 .558 .757 r
.70107 .28494 .70773 .30311 .7208 .2982 .71418 .28071 Mtetra
.639 .571 .762 r
.71418 .28071 .7208 .2982 .73386 .29233 .72731 .27588 Mtetra
.652 .59 .772 r
.72731 .27588 .73386 .29233 .74691 .28568 .74047 .2705 Mtetra
.665 .612 .785 r
.74047 .2705 .74691 .28568 .75997 .2785 .75364 .26465 Mtetra
.677 .636 .801 r
.75364 .26465 .75997 .2785 .77305 .27108 .76685 .25851 Mtetra
.687 .661 .819 r
.76685 .25851 .77305 .27108 .78616 .26366 .78009 .25222 Mtetra
.693 .684 .837 r
.78009 .25222 .78616 .26366 .79933 .25646 .79338 .24594 Mtetra
.695 .705 .855 r
.79338 .24594 .79933 .25646 .81258 .24961 .80673 .23979 Mtetra
.694 .721 .87 r
.80673 .23979 .81258 .24961 .82591 .24317 .82015 .23384 Mtetra
.69 .732 .883 r
.82015 .23384 .82591 .24317 .83933 .23715 .83366 .22813 Mtetra
.664 .741 .908 r
.21628 .42788 .22373 .43482 .23467 .43107 .22724 .4241 Mtetra
.22724 .4241 .23467 .43107 .24565 .4273 .23825 .4203 Mtetra
.23825 .4203 .24565 .4273 .25668 .42352 .24931 .41649 Mtetra
.24931 .41649 .25668 .42352 .26775 .41972 .26041 .41266 Mtetra
.26041 .41266 .26775 .41972 .27888 .4159 .27156 .40882 Mtetra
.27156 .40882 .27888 .4159 .29005 .41207 .28276 .40496 Mtetra
.28276 .40496 .29005 .41207 .30127 .40823 .29401 .40108 Mtetra
.29401 .40108 .30127 .40823 .31253 .40436 .3053 .39719 Mtetra
.3053 .39719 .31253 .40436 .32384 .40048 .31665 .39328 Mtetra
.663 .741 .908 r
.31665 .39328 .32384 .40048 .33521 .39659 .32804 .38935 Mtetra
.32804 .38935 .33521 .39659 .34662 .39267 .33948 .38542 Mtetra
.33948 .38542 .34662 .39267 .35808 .38875 .35097 .38148 Mtetra
.662 .742 .909 r
.35097 .38148 .35808 .38875 .36959 .38481 .36251 .37754 Mtetra
.661 .742 .911 r
.36251 .37754 .36959 .38481 .38115 .38086 .3741 .37363 Mtetra
.658 .744 .913 r
.3741 .37363 .38115 .38086 .39276 .37692 .38573 .36977 Mtetra
.655 .746 .917 r
.38573 .36977 .39276 .37692 .40441 .37298 .39741 .36599 Mtetra
.651 .75 .922 r
.39741 .36599 .40441 .37298 .41612 .36907 .40915 .3623 Mtetra
.646 .757 .93 r
.40915 .3623 .41612 .36907 .42788 .36518 .42093 .35871 Mtetra
.642 .766 .938 r
.42093 .35871 .42788 .36518 .43969 .36133 .43276 .35519 Mtetra
.64 .777 .946 r
.43276 .35519 .43969 .36133 .45155 .3575 .44465 .35166 Mtetra
.641 .788 .953 r
.44465 .35166 .45155 .3575 .46347 .35367 .4566 .34805 Mtetra
.646 .798 .956 r
.4566 .34805 .46347 .35367 .47544 .34978 .46861 .34423 Mtetra
.656 .804 .954 r
.46861 .34423 .47544 .34978 .48746 .34581 .48068 .34016 Mtetra
.666 .805 .949 r
.48068 .34016 .48746 .34581 .49954 .34173 .49281 .33581 Mtetra
.675 .8 .941 r
.49281 .33581 .49954 .34173 .51168 .33754 .50499 .33122 Mtetra
.681 .789 .932 r
.50499 .33122 .51168 .33754 .52387 .33325 .51722 .32649 Mtetra
.681 .777 .923 r
.51722 .32649 .52387 .33325 .53611 .32893 .5295 .32171 Mtetra
.679 .763 .915 r
.5295 .32171 .53611 .32893 .54841 .32464 .54183 .31698 Mtetra
.674 .75 .908 r
.54183 .31698 .54841 .32464 .56076 .32045 .55422 .31238 Mtetra
.668 .737 .902 r
.55422 .31238 .56076 .32045 .57317 .31643 .56666 .30794 Mtetra
.662 .725 .896 r
.56666 .30794 .57317 .31643 .58564 .31263 .57916 .30367 Mtetra
.655 .711 .889 r
.57916 .30367 .58564 .31263 .59818 .30909 .59172 .29956 Mtetra
.649 .696 .88 r
.59172 .29956 .59818 .30909 .61079 .30582 .60434 .29563 Mtetra
.643 .679 .869 r
.60434 .29563 .61079 .30582 .62348 .30281 .61703 .29185 Mtetra
.637 .661 .856 r
.61703 .29185 .62348 .30281 .63624 .30001 .62979 .2882 Mtetra
.633 .643 .842 r
.62979 .2882 .63624 .30001 .64907 .29732 .64261 .28466 Mtetra
.629 .627 .829 r
.64261 .28466 .64907 .29732 .66198 .29464 .65551 .28117 Mtetra
.627 .613 .817 r
.65551 .28117 .66198 .29464 .67496 .29178 .66847 .27766 Mtetra
.628 .605 .808 r
.66847 .27766 .67496 .29178 .68799 .2886 .6815 .27404 Mtetra
.63 .6 .801 r
.6815 .27404 .68799 .2886 .70107 .28494 .69458 .27022 Mtetra
.635 .601 .798 r
.69458 .27022 .70107 .28494 .71418 .28071 .70771 .26612 Mtetra
.642 .607 .799 r
.70771 .26612 .71418 .28071 .72731 .27588 .72089 .26169 Mtetra
.65 .617 .804 r
.72089 .26169 .72731 .27588 .74047 .2705 .73411 .25693 Mtetra
.658 .631 .812 r
.73411 .25693 .74047 .2705 .75364 .26465 .74736 .25185 Mtetra
.666 .648 .822 r
.74736 .25185 .75364 .26465 .76685 .25851 .76066 .24651 Mtetra
.674 .666 .835 r
.76066 .24651 .76685 .25851 .78009 .25222 .774 .24101 Mtetra
.679 .684 .848 r
.774 .24101 .78009 .25222 .79338 .24594 .78739 .23542 Mtetra
.682 .701 .861 r
.78739 .23542 .79338 .24594 .80673 .23979 .80083 .22984 Mtetra
.682 .715 .873 r
.80083 .22984 .80673 .23979 .82015 .23384 .81434 .22432 Mtetra
.681 .725 .883 r
.81434 .22432 .82015 .23384 .83366 .22813 .82792 .21891 Mtetra
.664 .741 .908 r
.20877 .42089 .21628 .42788 .22724 .4241 .21976 .41708 Mtetra
.21976 .41708 .22724 .4241 .23825 .4203 .2308 .41325 Mtetra
.2308 .41325 .23825 .4203 .24931 .41649 .24188 .40941 Mtetra
.24188 .40941 .24931 .41649 .26041 .41266 .25302 .40555 Mtetra
.25302 .40555 .26041 .41266 .27156 .40882 .26419 .40168 Mtetra
.26419 .40168 .27156 .40882 .28276 .40496 .27542 .39779 Mtetra
.27542 .39779 .28276 .40496 .29401 .40108 .2867 .39388 Mtetra
.663 .741 .908 r
.2867 .39388 .29401 .40108 .3053 .39719 .29802 .38996 Mtetra
.29802 .38996 .3053 .39719 .31665 .39328 .30939 .38602 Mtetra
.30939 .38602 .31665 .39328 .32804 .38935 .32081 .38209 Mtetra
.662 .742 .909 r
.32081 .38209 .32804 .38935 .33948 .38542 .33228 .37816 Mtetra
.66 .742 .911 r
.33228 .37816 .33948 .38542 .35097 .38148 .3438 .37427 Mtetra
.657 .744 .914 r
.3438 .37427 .35097 .38148 .36251 .37754 .35536 .37045 Mtetra
.652 .747 .919 r
.35536 .37045 .36251 .37754 .3741 .37363 .36696 .36677 Mtetra
.644 .752 .928 r
.36696 .36677 .3741 .37363 .38573 .36977 .37861 .36327 Mtetra
.633 .761 .94 r
.37861 .36327 .38573 .36977 .39741 .36599 .39031 .36001 Mtetra
.619 .775 .955 r
.39031 .36001 .39741 .36599 .40915 .3623 .40205 .35697 Mtetra
.603 .793 .972 r
.40205 .35697 .40915 .3623 .42093 .35871 .41385 .35409 Mtetra
.589 .814 .986 r
.41385 .35409 .42093 .35871 .43276 .35519 .4257 .35121 Mtetra
.584 .837 .993 r
.4257 .35121 .43276 .35519 .44465 .35166 .43763 .34814 Mtetra
.595 .857 .993 r
.43763 .34814 .44465 .35166 .4566 .34805 .44962 .34466 Mtetra
.622 .871 .989 r
.44962 .34466 .4566 .34805 .46861 .34423 .46168 .34062 Mtetra
.656 .873 .98 r
.46168 .34062 .46861 .34423 .48068 .34016 .47381 .336 Mtetra
.685 .862 .966 r
.47381 .336 .48068 .34016 .49281 .33581 .48599 .33089 Mtetra
.7 .841 .95 r
.48599 .33089 .49281 .33581 .50499 .33122 .49823 .32548 Mtetra
.704 .815 .934 r
.49823 .32548 .50499 .33122 .51722 .32649 .5105 .31998 Mtetra
.7 .792 .921 r
.5105 .31998 .51722 .32649 .5295 .32171 .52283 .31459 Mtetra
.692 .772 .913 r
.52283 .31459 .5295 .32171 .54183 .31698 .5352 .3094 Mtetra
.683 .757 .907 r
.5352 .3094 .54183 .31698 .55422 .31238 .54762 .30447 Mtetra
.675 .746 .904 r
.54762 .30447 .55422 .31238 .56666 .30794 .5601 .29976 Mtetra
.668 .737 .902 r
.5601 .29976 .56666 .30794 .57916 .30367 .57263 .29525 Mtetra
.663 .73 .899 r
.57263 .29525 .57916 .30367 .59172 .29956 .58522 .29088 Mtetra
.659 .722 .896 r
.58522 .29088 .59172 .29956 .60434 .29563 .59787 .28661 Mtetra
.656 .713 .89 r
.59787 .28661 .60434 .29563 .61703 .29185 .61059 .28243 Mtetra
.652 .703 .884 r
.61059 .28243 .61703 .29185 .62979 .2882 .62336 .27832 Mtetra
.649 .692 .876 r
.62336 .27832 .62979 .2882 .64261 .28466 .6362 .27428 Mtetra
.647 .68 .867 r
.6362 .27428 .64261 .28466 .65551 .28117 .64911 .27027 Mtetra
.645 .669 .859 r
.64911 .27027 .65551 .28117 .66847 .27766 .66208 .26627 Mtetra
.644 .66 .851 r
.66208 .26627 .66847 .27766 .6815 .27404 .67511 .26225 Mtetra
.644 .653 .844 r
.67511 .26225 .6815 .27404 .69458 .27022 .6882 .25816 Mtetra
.645 .649 .839 r
.6882 .25816 .69458 .27022 .70771 .26612 .70136 .25395 Mtetra
.648 .649 .837 r
.70136 .25395 .70771 .26612 .72089 .26169 .71457 .24958 Mtetra
.652 .653 .838 r
.71457 .24958 .72089 .26169 .73411 .25693 .72783 .24503 Mtetra
.657 .66 .841 r
.72783 .24503 .73411 .25693 .74736 .25185 .74114 .24029 Mtetra
.662 .67 .847 r
.74114 .24029 .74736 .25185 .76066 .24651 .7545 .23538 Mtetra
.667 .681 .854 r
.7545 .23538 .76066 .24651 .774 .24101 .76791 .23033 Mtetra
.67 .693 .862 r
.76791 .23033 .774 .24101 .78739 .23542 .78138 .22518 Mtetra
.673 .705 .871 r
.78138 .22518 .78739 .23542 .80083 .22984 .7949 .21999 Mtetra
.674 .715 .88 r
.7949 .21999 .80083 .22984 .81434 .22432 .80849 .21479 Mtetra
.674 .724 .887 r
.80849 .21479 .81434 .22432 .82792 .21891 .82214 .20962 Mtetra
.664 .741 .908 r
.2012 .41384 .20877 .42089 .21976 .41708 .21222 .41 Mtetra
.21222 .41 .21976 .41708 .2308 .41325 .22329 .40615 Mtetra
.22329 .40615 .2308 .41325 .24188 .40941 .2344 .40227 Mtetra
.2344 .40227 .24188 .40941 .25302 .40555 .24556 .39839 Mtetra
.24556 .39839 .25302 .40555 .26419 .40168 .25677 .39448 Mtetra
.663 .741 .908 r
.25677 .39448 .26419 .40168 .27542 .39779 .26802 .39056 Mtetra
.26802 .39056 .27542 .39779 .2867 .39388 .27932 .38663 Mtetra
.27932 .38663 .2867 .39388 .29802 .38996 .29068 .38269 Mtetra
.662 .742 .909 r
.29068 .38269 .29802 .38996 .30939 .38602 .30208 .37876 Mtetra
.66 .742 .911 r
.30208 .37876 .30939 .38602 .32081 .38209 .31352 .37488 Mtetra
.656 .743 .914 r
.31352 .37488 .32081 .38209 .33228 .37816 .32501 .37108 Mtetra
.649 .746 .92 r
.32501 .37108 .33228 .37816 .3438 .37427 .33654 .36747 Mtetra
.637 .752 .931 r
.33654 .36747 .3438 .37427 .35536 .37045 .3481 .36414 Mtetra
.617 .762 .948 r
.3481 .36414 .35536 .37045 .36696 .36677 .3597 .3612 Mtetra
.585 .778 .972 r
.3597 .3612 .36696 .36677 .37861 .36327 .37134 .35875 Mtetra
.533 .797 .994 r
.37134 .35875 .37861 .36327 .39031 .36001 .38302 .35677 Mtetra
.456 .811 .997 r
.38302 .35677 .39031 .36001 .40205 .35697 .39475 .3551 Mtetra
.366 .806 .958 r
.39475 .3551 .40205 .35697 .41385 .35409 .40655 .35344 Mtetra
.307 .793 .894 r
.40655 .35344 .41385 .35409 .4257 .35121 .41843 .35136 Mtetra
.323 .809 .859 r
.41843 .35136 .4257 .35121 .43763 .34814 .43041 .34847 Mtetra
.42 .866 .879 r
.43041 .34847 .43763 .34814 .44962 .34466 .44248 .34446 Mtetra
.557 .927 .929 r
.44248 .34446 .44962 .34466 .46168 .34062 .45463 .33932 Mtetra
.671 .945 .96 r
.45463 .33932 .46168 .34062 .47381 .336 .46684 .33323 Mtetra
.729 .917 .957 r
.46684 .33323 .47381 .336 .48599 .33089 .4791 .3266 Mtetra
.743 .871 .939 r
.4791 .3266 .48599 .33089 .49823 .32548 .4914 .31984 Mtetra
.735 .827 .922 r
.4914 .31984 .49823 .32548 .5105 .31998 .50373 .31331 Mtetra
.719 .793 .91 r
.50373 .31331 .5105 .31998 .52283 .31459 .5161 .30722 Mtetra
.703 .769 .904 r
.5161 .30722 .52283 .31459 .5352 .3094 .52851 .30162 Mtetra
.688 .755 .902 r
.52851 .30162 .5352 .3094 .54762 .30447 .54097 .29645 Mtetra
.678 .746 .902 r
.54097 .29645 .54762 .30447 .5601 .29976 .55348 .29161 Mtetra
.671 .741 .903 r
.55348 .29161 .5601 .29976 .57263 .29525 .56605 .28699 Mtetra
.666 .737 .903 r
.56605 .28699 .57263 .29525 .58522 .29088 .57868 .28251 Mtetra
.663 .734 .902 r
.57868 .28251 .58522 .29088 .59787 .28661 .59137 .27809 Mtetra
.661 .73 .901 r
.59137 .27809 .59787 .28661 .61059 .28243 .60411 .27372 Mtetra
.659 .726 .898 r
.60411 .27372 .61059 .28243 .62336 .27832 .61692 .26938 Mtetra
.658 .72 .894 r
.61692 .26938 .62336 .27832 .6362 .27428 .62979 .26506 Mtetra
.656 .713 .89 r
.62979 .26506 .6362 .27428 .64911 .27027 .64272 .26076 Mtetra
.655 .706 .885 r
.64272 .26076 .64911 .27027 .66208 .26627 .65571 .25646 Mtetra
.654 .7 .88 r
.65571 .25646 .66208 .26627 .67511 .26225 .66877 .25216 Mtetra
.654 .694 .875 r
.66877 .25216 .67511 .26225 .6882 .25816 .68188 .24783 Mtetra
.654 .69 .871 r
.68188 .24783 .6882 .25816 .70136 .25395 .69506 .24345 Mtetra
.655 .687 .868 r
.69506 .24345 .70136 .25395 .71457 .24958 .7083 .239 Mtetra
.657 .687 .867 r
.7083 .239 .71457 .24958 .72783 .24503 .7216 .23446 Mtetra
.659 .689 .867 r
.7216 .23446 .72783 .24503 .74114 .24029 .73496 .22982 Mtetra
.661 .693 .869 r
.73496 .22982 .74114 .24029 .7545 .23538 .74837 .22508 Mtetra
.664 .699 .873 r
.74837 .22508 .7545 .23538 .76791 .23033 .76184 .22024 Mtetra
.666 .706 .877 r
.76184 .22024 .76791 .23033 .78138 .22518 .77537 .21532 Mtetra
.668 .713 .882 r
.77537 .21532 .78138 .22518 .7949 .21999 .78895 .21035 Mtetra
.669 .72 .887 r
.78895 .21035 .7949 .21999 .80849 .21479 .8026 .20535 Mtetra
.669 .726 .892 r
.8026 .20535 .80849 .21479 .82214 .20962 .81631 .20033 Mtetra
.664 .741 .908 r
.19358 .40674 .2012 .41384 .21222 .41 .20462 .40287 Mtetra
.20462 .40287 .21222 .41 .22329 .40615 .21571 .39899 Mtetra
.21571 .39899 .22329 .40615 .2344 .40227 .22685 .39508 Mtetra
.663 .741 .908 r
.22685 .39508 .2344 .40227 .24556 .39839 .23804 .39116 Mtetra
.23804 .39116 .24556 .39839 .25677 .39448 .24928 .38723 Mtetra
.24928 .38723 .25677 .39448 .26802 .39056 .26056 .38329 Mtetra
.662 .741 .909 r
.26056 .38329 .26802 .39056 .27932 .38663 .27189 .37936 Mtetra
.661 .742 .91 r
.27189 .37936 .27932 .38663 .29068 .38269 .28327 .37546 Mtetra
.657 .743 .913 r
.28327 .37546 .29068 .38269 .30208 .37876 .29468 .37166 Mtetra
.649 .745 .92 r
.29468 .37166 .30208 .37876 .31352 .37488 .30614 .36805 Mtetra
.634 .75 .932 r
.30614 .36805 .31352 .37488 .32501 .37108 .31762 .36479 Mtetra
.606 .76 .952 r
.31762 .36479 .32501 .37108 .33654 .36747 .32913 .3621 Mtetra
.552 .773 .981 r
.32913 .3621 .33654 .36747 .3481 .36414 .34065 .36016 Mtetra
.438 .777 .997 r
.34065 .36016 .3481 .36414 .3597 .3612 .35218 .35914 Mtetra
.214 .711 .915 r
.35218 .35914 .3597 .3612 .37134 .35875 .36375 .35898 Mtetra
.069 0 0 r
.36375 .35898 .37134 .35875 .38302 .35677 .37537 .35939 Mtetra
.24 0 0 r
.37537 .35939 .38302 .35677 .39475 .3551 .38707 .35978 Mtetra
.276 0 0 r
.38707 .35978 .39475 .3551 .40655 .35344 .39889 .35937 Mtetra
.217 0 0 r
.39889 .35937 .40655 .35344 .41843 .35136 .41085 .3574 Mtetra
.065 0 0 r
.41085 .3574 .41843 .35136 .43041 .34847 .42295 .35339 Mtetra
0 0 0 r
.42295 .35339 .43041 .34847 .44248 .34446 .43515 .34728 Mtetra
.542 .917 .767 r
.43515 .34728 .44248 .34446 .45463 .33932 .44744 .3395 Mtetra
.748 .985 .904 r
.44744 .3395 .45463 .33932 .46684 .33323 .45978 .33078 Mtetra
.798 .931 .921 r
.45978 .33078 .46684 .33323 .4791 .3266 .47214 .32191 Mtetra
.785 .862 .907 r
.47214 .32191 .4791 .3266 .4914 .31984 .48451 .31352 Mtetra
.757 .811 .896 r
.48451 .31352 .4914 .31984 .50373 .31331 .4969 .30597 Mtetra
.729 .778 .891 r
.4969 .30597 .50373 .31331 .5161 .30722 .50932 .29933 Mtetra
.706 .758 .892 r
.50932 .29933 .5161 .30722 .52851 .30162 .52177 .29349 Mtetra
.689 .747 .896 r
.52177 .29349 .52851 .30162 .54097 .29645 .53427 .28825 Mtetra
.677 .742 .9 r
.53427 .28825 .54097 .29645 .55348 .29161 .54682 .28339 Mtetra
.67 .74 .903 r
.54682 .28339 .55348 .29161 .56605 .28699 .55942 .27875 Mtetra
.666 .739 .905 r
.55942 .27875 .56605 .28699 .57868 .28251 .57209 .27422 Mtetra
.664 .738 .905 r
.57209 .27422 .57868 .28251 .59137 .27809 .58481 .26974 Mtetra
.663 .737 .905 r
.58481 .26974 .59137 .27809 .60411 .27372 .5976 .26527 Mtetra
.662 .735 .904 r
.5976 .26527 .60411 .27372 .61692 .26938 .61044 .26081 Mtetra
.661 .733 .903 r
.61044 .26081 .61692 .26938 .62979 .26506 .62334 .25635 Mtetra
.661 .73 .901 r
.62334 .25635 .62979 .26506 .64272 .26076 .6363 .25189 Mtetra
.66 .727 .898 r
.6363 .25189 .64272 .26076 .65571 .25646 .64933 .24742 Mtetra
.66 .723 .896 r
.64933 .24742 .65571 .25646 .66877 .25216 .66242 .24294 Mtetra
.659 .719 .893 r
.66242 .24294 .66877 .25216 .68188 .24783 .67557 .23845 Mtetra
.659 .716 .891 r
.67557 .23845 .68188 .24783 .69506 .24345 .68878 .23393 Mtetra
.659 .714 .888 r
.68878 .23393 .69506 .24345 .7083 .239 .70205 .22938 Mtetra
.66 .712 .887 r
.70205 .22938 .7083 .239 .7216 .23446 .71539 .22478 Mtetra
.661 .712 .886 r
.71539 .22478 .7216 .23446 .73496 .22982 .72878 .22013 Mtetra
.662 .713 .887 r
.72878 .22013 .73496 .22982 .74837 .22508 .74224 .21541 Mtetra
.663 .716 .888 r
.74224 .21541 .74837 .22508 .76184 .22024 .75576 .21064 Mtetra
.664 .719 .89 r
.75576 .21064 .76184 .22024 .77537 .21532 .76934 .20582 Mtetra
.665 .723 .892 r
.76934 .20582 .77537 .21532 .78895 .21035 .78298 .20094 Mtetra
.666 .726 .895 r
.78298 .20094 .78895 .21035 .8026 .20535 .79669 .19603 Mtetra
.666 .73 .897 r
.79669 .19603 .8026 .20535 .81631 .20033 .81045 .19109 Mtetra
.664 .741 .908 r
.18589 .39958 .19358 .40674 .20462 .40287 .19696 .39568 Mtetra
.19696 .39568 .20462 .40287 .21571 .39899 .20808 .39177 Mtetra
.663 .741 .908 r
.20808 .39177 .21571 .39899 .22685 .39508 .21925 .38784 Mtetra
.21925 .38784 .22685 .39508 .23804 .39116 .23046 .38389 Mtetra
.23046 .38389 .23804 .39116 .24928 .38723 .24173 .37995 Mtetra
.661 .742 .91 r
.24173 .37995 .24928 .38723 .26056 .38329 .25303 .37603 Mtetra
.658 .742 .912 r
.25303 .37603 .26056 .38329 .27189 .37936 .26438 .37219 Mtetra
.651 .744 .918 r
.26438 .37219 .27189 .37936 .28327 .37546 .27577 .36853 Mtetra
.636 .748 .929 r
.27577 .36853 .28327 .37546 .29468 .37166 .28718 .36524 Mtetra
.606 .755 .95 r
.28718 .36524 .29468 .37166 .30614 .36805 .29859 .36258 Mtetra
.538 .765 .981 r
.29859 .36258 .30614 .36805 .31762 .36479 .31001 .3609 Mtetra
.368 .747 .989 r
.31001 .3609 .31762 .36479 .32913 .3621 .3214 .36056 Mtetra
0 .558 .779 r
.3214 .36056 .32913 .3621 .34065 .36016 .33277 .36179 Mtetra
.384 0 0 r
.33277 .36179 .34065 .36016 .35218 .35914 .34415 .3645 Mtetra
.517 .015 0 r
.34415 .3645 .35218 .35914 .36375 .35898 .35558 .36815 Mtetra
.536 .091 .139 r
.35558 .36815 .36375 .35898 .37537 .35939 .36713 .3717 Mtetra
.506 .092 .189 r
.36713 .3717 .37537 .35939 .38707 .35978 .37885 .37381 Mtetra
.439 .038 .181 r
.37885 .37381 .38707 .35978 .39889 .35937 .39078 .37318 Mtetra
.316 0 .111 r
.39078 .37318 .39889 .35937 .41085 .3574 .40293 .36901 Mtetra
.084 0 0 r
.40293 .36901 .41085 .3574 .42295 .35339 .41526 .3613 Mtetra
0 0 0 r
.41526 .3613 .42295 .35339 .43515 .34728 .4277 .35081 Mtetra
.749 .986 .765 r
.4277 .35081 .43515 .34728 .44744 .3395 .44019 .33884 Mtetra
.862 .964 .865 r
.44019 .33884 .44744 .3395 .45978 .33078 .45267 .32673 Mtetra
.842 .878 .868 r
.45267 .32673 .45978 .33078 .47214 .32191 .46514 .31554 Mtetra
.799 .815 .864 r
.46514 .31554 .47214 .32191 .48451 .31352 .47758 .30582 Mtetra
.76 .775 .866 r
.47758 .30582 .48451 .31352 .4969 .30597 .49002 .29767 Mtetra
.727 .754 .874 r
.49002 .29767 .4969 .30597 .50932 .29933 .50248 .29086 Mtetra
.702 .743 .883 r
.50248 .29086 .50932 .29933 .52177 .29349 .51497 .28505 Mtetra
.685 .739 .892 r
.51497 .28505 .52177 .29349 .53427 .28825 .5275 .27988 Mtetra
.674 .739 .899 r
.5275 .27988 .53427 .28825 .54682 .28339 .54009 .27508 Mtetra
.668 .739 .903 r
.54009 .27508 .54682 .28339 .55942 .27875 .55274 .27046 Mtetra
.665 .74 .906 r
.55274 .27046 .55942 .27875 .57209 .27422 .56544 .26592 Mtetra
.664 .74 .907 r
.56544 .26592 .57209 .27422 .58481 .26974 .5782 .2614 Mtetra
.663 .74 .907 r
.5782 .2614 .58481 .26974 .5976 .26527 .59103 .25689 Mtetra
.663 .739 .907 r
.59103 .25689 .5976 .26527 .61044 .26081 .60391 .25236 Mtetra
.663 .738 .906 r
.60391 .25236 .61044 .26081 .62334 .25635 .61685 .24782 Mtetra
.663 .737 .905 r
.61685 .24782 .62334 .25635 .6363 .25189 .62985 .24327 Mtetra
.662 .736 .904 r
.62985 .24327 .6363 .25189 .64933 .24742 .64291 .2387 Mtetra
.662 .734 .903 r
.64291 .2387 .64933 .24742 .66242 .24294 .65604 .23412 Mtetra
.662 .732 .902 r
.65604 .23412 .66242 .24294 .67557 .23845 .66922 .22952 Mtetra
.662 .731 .901 r
.66922 .22952 .67557 .23845 .68878 .23393 .68247 .2249 Mtetra
.662 .729 .899 r
.68247 .2249 .68878 .23393 .70205 .22938 .69579 .22026 Mtetra
.662 .728 .898 r
.69579 .22026 .70205 .22938 .71539 .22478 .70916 .21559 Mtetra
.662 .727 .898 r
.70916 .21559 .71539 .22478 .72878 .22013 .7226 .21089 Mtetra
.662 .727 .897 r
.7226 .21089 .72878 .22013 .74224 .21541 .7361 .20615 Mtetra
.663 .728 .898 r
.7361 .20615 .74224 .21541 .75576 .21064 .74966 .20137 Mtetra
.663 .729 .898 r
.74966 .20137 .75576 .21064 .76934 .20582 .76329 .19655 Mtetra
.664 .73 .899 r
.76329 .19655 .76934 .20582 .78298 .20094 .77698 .1917 Mtetra
.664 .732 .9 r
.77698 .1917 .78298 .20094 .79669 .19603 .79073 .18681 Mtetra
.665 .734 .902 r
.79073 .18681 .79669 .19603 .81045 .19109 .80455 .18189 Mtetra
.663 .741 .908 r
.17814 .39237 .18589 .39958 .19696 .39568 .18924 .38844 Mtetra
.18924 .38844 .19696 .39568 .20808 .39177 .20039 .3845 Mtetra
.20039 .3845 .20808 .39177 .21925 .38784 .21158 .38055 Mtetra
.662 .741 .909 r
.21158 .38055 .21925 .38784 .23046 .38389 .22282 .37661 Mtetra
.66 .742 .911 r
.22282 .37661 .23046 .38389 .24173 .37995 .23411 .37272 Mtetra
.654 .743 .915 r
.23411 .37272 .24173 .37995 .25303 .37603 .24542 .36897 Mtetra
.642 .745 .924 r
.24542 .36897 .25303 .37603 .26438 .37219 .25677 .36554 Mtetra
.615 .751 .942 r
.25677 .36554 .26438 .37219 .27577 .36853 .26811 .3627 Mtetra
.551 .758 .974 r
.26811 .3627 .27577 .36853 .28718 .36524 .27944 .36092 Mtetra
.376 .737 .99 r
.27944 .36092 .28718 .36524 .29859 .36258 .29071 .36072 Mtetra
0 .499 .746 r
.29071 .36072 .29859 .36258 .31001 .3609 .30191 .36269 Mtetra
.506 0 0 r
.30191 .36269 .31001 .3609 .3214 .36056 .31303 .36715 Mtetra
.623 .161 .136 r
.31303 .36715 .3214 .36056 .33277 .36179 .32413 .37394 Mtetra
.636 .235 .267 r
.32413 .37394 .33277 .36179 .34415 .3645 .33526 .38216 Mtetra
.616 .248 .323 r
.33526 .38216 .34415 .3645 .35558 .36815 .34656 .39012 Mtetra
.575 .225 .339 r
.34656 .39012 .35558 .36815 .36713 .3717 .35812 .39567 Mtetra
.508 .167 .323 r
.35812 .39567 .36713 .3717 .37885 .37381 .37003 .39676 Mtetra
.397 .056 .266 r
.37003 .39676 .37885 .37381 .39078 .37318 .38228 .39218 Mtetra
.183 0 .124 r
.38228 .39218 .39078 .37318 .40293 .36901 .3948 .38201 Mtetra
0 0 0 r
.3948 .38201 .40293 .36901 .41526 .3613 .4075 .3676 Mtetra
.796 .966 .656 r
.4075 .3676 .41526 .3613 .4277 .35081 .42024 .35102 Mtetra
.921 .948 .797 r
.42024 .35102 .4277 .35081 .44019 .33884 .43295 .33442 Mtetra
.882 .854 .81 r
.43295 .33442 .44019 .33884 .45267 .32673 .44557 .3194 Mtetra
.83 .791 .815 r
.44557 .3194 .45267 .32673 .46514 .31554 .45812 .30677 Mtetra
.784 .755 .827 r
.45812 .30677 .46514 .31554 .47758 .30582 .47062 .2966 Mtetra
.746 .738 .845 r
.47062 .2966 .47758 .30582 .49002 .29767 .4831 .28854 Mtetra
.715 .732 .864 r
.4831 .28854 .49002 .29767 .50248 .29086 .49559 .282 Mtetra
.693 .732 .88 r
.49559 .282 .50248 .29086 .51497 .28505 .50811 .27644 Mtetra
.679 .735 .893 r
.50811 .27644 .51497 .28505 .5275 .27988 .52068 .27144 Mtetra
.671 .737 .9 r
.52068 .27144 .5275 .27988 .54009 .27508 .53331 .26672 Mtetra
.666 .739 .904 r
.53331 .26672 .54009 .27508 .55274 .27046 .546 .26213 Mtetra
.665 .74 .906 r
.546 .26213 .55274 .27046 .56544 .26592 .55874 .25757 Mtetra
.664 .741 .907 r
.55874 .25757 .56544 .26592 .5782 .2614 .57154 .25303 Mtetra
.57154 .25303 .5782 .2614 .59103 .25689 .5844 .24847 Mtetra
.663 .741 .907 r
.5844 .24847 .59103 .25689 .60391 .25236 .59732 .2439 Mtetra
.663 .74 .907 r
.59732 .2439 .60391 .25236 .61685 .24782 .6103 .23931 Mtetra
.6103 .23931 .61685 .24782 .62985 .24327 .62334 .23469 Mtetra
.663 .739 .907 r
.62334 .23469 .62985 .24327 .64291 .2387 .63645 .23006 Mtetra
.663 .739 .906 r
.63645 .23006 .64291 .2387 .65604 .23412 .64961 .22542 Mtetra
.663 .738 .906 r
.64961 .22542 .65604 .23412 .66922 .22952 .66284 .22075 Mtetra
.663 .737 .905 r
.66284 .22075 .66922 .22952 .68247 .2249 .67613 .21606 Mtetra
.663 .736 .905 r
.67613 .21606 .68247 .2249 .69579 .22026 .68948 .21135 Mtetra
.663 .736 .904 r
.68948 .21135 .69579 .22026 .70916 .21559 .7029 .20662 Mtetra
.663 .735 .904 r
.7029 .20662 .70916 .21559 .7226 .21089 .71638 .20186 Mtetra
.663 .735 .903 r
.71638 .20186 .7226 .21089 .7361 .20615 .72992 .19707 Mtetra
.72992 .19707 .7361 .20615 .74966 .20137 .74353 .19226 Mtetra
.74353 .19226 .74966 .20137 .76329 .19655 .7572 .18742 Mtetra
.663 .736 .903 r
.7572 .18742 .76329 .19655 .77698 .1917 .77094 .18254 Mtetra
.664 .736 .904 r
.77094 .18254 .77698 .1917 .79073 .18681 .78474 .17764 Mtetra
.664 .737 .904 r
.78474 .17764 .79073 .18681 .80455 .18189 .79861 .17271 Mtetra
.663 .741 .908 r
.17033 .3851 .17814 .39237 .18924 .38844 .18146 .38115 Mtetra
.18146 .38115 .18924 .38844 .20039 .3845 .19263 .37719 Mtetra
.661 .742 .909 r
.19263 .37719 .20039 .3845 .21158 .38055 .20385 .37326 Mtetra
.658 .742 .912 r
.20385 .37326 .21158 .38055 .22282 .37661 .2151 .36942 Mtetra
.649 .743 .918 r
.2151 .36942 .22282 .37661 .23411 .37272 .22639 .3658 Mtetra
.629 .747 .932 r
.22639 .3658 .23411 .37272 .24542 .36897 .23768 .36267 Mtetra
.581 .752 .959 r
.23768 .36267 .24542 .36897 .25677 .36554 .24894 .36046 Mtetra
.448 .745 .992 r
.24894 .36046 .25677 .36554 .26811 .3627 .26014 .35982 Mtetra
.035 .571 .852 r
.26014 .35982 .26811 .3627 .27944 .36092 .27122 .36157 Mtetra
.51 0 0 r
.27122 .36157 .27944 .36092 .29071 .36072 .28215 .36651 Mtetra
.667 .209 .156 r
.28215 .36651 .29071 .36072 .30191 .36269 .29292 .37513 Mtetra
.688 .3 .307 r
.29292 .37513 .30191 .36269 .31303 .36715 .30361 .38713 Mtetra
.675 .324 .372 r
.30361 .38713 .31303 .36715 .32413 .37394 .31433 .40114 Mtetra
.647 .316 .398 r
.31433 .40114 .32413 .37394 .33526 .38216 .32527 .41464 Mtetra
.603 .284 .402 r
.32527 .41464 .33526 .38216 .34656 .39012 .33661 .42439 Mtetra
.537 .223 .383 r
.33661 .42439 .34656 .39012 .35812 .39567 .34848 .42742 Mtetra
.422 .11 .329 r
.34848 .42742 .35812 .39567 .37003 .39676 .36087 .42203 Mtetra
.183 0 .185 r
.36087 .42203 .37003 .39676 .38228 .39218 .3737 .4085 Mtetra
0 0 0 r
.3737 .4085 .38228 .39218 .3948 .38201 .38677 .38893 Mtetra
.911 .965 .649 r
.38677 .38893 .3948 .38201 .4075 .3676 .39989 .3665 Mtetra
.946 .883 .739 r
.39989 .3665 .4075 .3676 .42024 .35102 .41293 .34431 Mtetra
.889 .794 .749 r
.41293 .34431 .42024 .35102 .43295 .33442 .4258 .32461 Mtetra
.837 .743 .76 r
.4258 .32461 .43295 .33442 .44557 .3194 .43851 .30848 Mtetra
.793 .717 .781 r
.43851 .30848 .44557 .3194 .45812 .30677 .4511 .29594 Mtetra
.756 .71 .808 r
.4511 .29594 .45812 .30677 .47062 .2966 .46362 .2864 Mtetra
.725 .712 .838 r
.46362 .2864 .47062 .2966 .4831 .28854 .47612 .27902 Mtetra
.7 .72 .864 r
.47612 .27902 .4831 .28854 .49559 .282 .48864 .27301 Mtetra
.683 .728 .884 r
.48864 .27301 .49559 .282 .50811 .27644 .5012 .26779 Mtetra
.673 .734 .896 r
.5012 .26779 .50811 .27644 .52068 .27144 .51381 .26297 Mtetra
.667 .737 .902 r
.51381 .26297 .52068 .27144 .53331 .26672 .52647 .25833 Mtetra
.665 .74 .906 r
.52647 .25833 .53331 .26672 .546 .26213 .5392 .25374 Mtetra
.664 .741 .907 r
.5392 .25374 .546 .26213 .55874 .25757 .55198 .24917 Mtetra
.664 .741 .908 r
.55198 .24917 .55874 .25757 .57154 .25303 .56482 .2446 Mtetra
.56482 .2446 .57154 .25303 .5844 .24847 .57772 .24 Mtetra
.57772 .24 .5844 .24847 .59732 .2439 .59068 .23538 Mtetra
.663 .741 .908 r
.59068 .23538 .59732 .2439 .6103 .23931 .6037 .23075 Mtetra
.6037 .23075 .6103 .23931 .62334 .23469 .61678 .22609 Mtetra
.61678 .22609 .62334 .23469 .63645 .23006 .62993 .22141 Mtetra
.663 .741 .907 r
.62993 .22141 .63645 .23006 .64961 .22542 .64313 .21671 Mtetra
.663 .74 .907 r
.64313 .21671 .64961 .22542 .66284 .22075 .6564 .21199 Mtetra
.6564 .21199 .66284 .22075 .67613 .21606 .66973 .20725 Mtetra
.66973 .20725 .67613 .21606 .68948 .21135 .68313 .20249 Mtetra
.663 .739 .906 r
.68313 .20249 .68948 .21135 .7029 .20662 .69659 .1977 Mtetra
.69659 .1977 .7029 .20662 .71638 .20186 .71011 .19289 Mtetra
.71011 .19289 .71638 .20186 .72992 .19707 .7237 .18806 Mtetra
.7237 .18806 .72992 .19707 .74353 .19226 .73735 .1832 Mtetra
.73735 .1832 .74353 .19226 .7572 .18742 .75107 .17832 Mtetra
.75107 .17832 .7572 .18742 .77094 .18254 .76485 .17341 Mtetra
.664 .739 .906 r
.76485 .17341 .77094 .18254 .78474 .17764 .7787 .16847 Mtetra
.7787 .16847 .78474 .17764 .79861 .17271 .79262 .16351 Mtetra
.662 .741 .909 r
.16246 .37778 .17033 .3851 .18146 .38115 .17361 .37382 Mtetra
.66 .742 .91 r
.17361 .37382 .18146 .38115 .19263 .37719 .1848 .36991 Mtetra
.655 .742 .914 r
.1848 .36991 .19263 .37719 .20385 .37326 .19603 .36612 Mtetra
.642 .744 .923 r
.19603 .36612 .20385 .37326 .2151 .36942 .20727 .36267 Mtetra
.612 .748 .942 r
.20727 .36267 .2151 .36942 .22639 .3658 .2185 .3599 Mtetra
.531 .75 .976 r
.2185 .3599 .22639 .3658 .23768 .36267 .22967 .35842 Mtetra
.27 .686 .968 r
.22967 .35842 .23768 .36267 .24894 .36046 .24071 .35912 Mtetra
.361 0 0 r
.24071 .35912 .24894 .36046 .26014 .35982 .25154 .36312 Mtetra
.67 .179 .076 r
.25154 .36312 .26014 .35982 .27122 .36157 .26213 .37148 Mtetra
.718 .32 .294 r
.26213 .37148 .27122 .36157 .28215 .36651 .27246 .38483 Mtetra
.714 .363 .381 r
.27246 .38483 .28215 .36651 .29292 .37513 .28263 .40273 Mtetra
.695 .368 .419 r
.28263 .40273 .29292 .37513 .30361 .38713 .29283 .42323 Mtetra
.665 .352 .434 r
.29283 .42323 .30361 .38713 .31433 .40114 .30331 .44283 Mtetra
.621 .316 .432 r
.30331 .44283 .31433 .40114 .32527 .41464 .31437 .45709 Mtetra
.551 .249 .41 r
.31437 .45709 .32527 .41464 .33661 .42439 .32619 .46198 Mtetra
.419 .119 .347 r
.32619 .46198 .33661 .42439 .34848 .42742 .33879 .45529 Mtetra
.095 0 .158 r
.33879 .45529 .34848 .42742 .36087 .42203 .352 .43763 Mtetra
.682 .822 .382 r
.352 .43763 .36087 .42203 .3737 .4085 .36557 .4121 Mtetra
.977 .905 .673 r
.36557 .4121 .3737 .4085 .38677 .38893 .37918 .38308 Mtetra
.923 .788 .694 r
.37918 .38308 .38677 .38893 .39989 .3665 .39263 .35477 Mtetra
.866 .719 .698 r
.39263 .35477 .39989 .3665 .41293 .34431 .40582 .33007 Mtetra
.822 .684 .712 r
.40582 .33007 .41293 .34431 .4258 .32461 .41875 .31025 Mtetra
.786 .671 .737 r
.41875 .31025 .4258 .32461 .43851 .30848 .43146 .29526 Mtetra
.756 .674 .771 r
.43146 .29526 .43851 .30848 .4511 .29594 .44404 .28423 Mtetra
.728 .686 .81 r
.44404 .28423 .4511 .29594 .46362 .2864 .45657 .27601 Mtetra
.704 .703 .846 r
.45657 .27601 .46362 .2864 .47612 .27902 .46909 .26957 Mtetra
.686 .718 .874 r
.46909 .26957 .47612 .27902 .48864 .27301 .48164 .26413 Mtetra
.674 .729 .891 r
.48164 .26413 .48864 .27301 .5012 .26779 .49423 .25921 Mtetra
.668 .735 .9 r
.49423 .25921 .5012 .26779 .51381 .26297 .50687 .25451 Mtetra
.665 .739 .905 r
.50687 .25451 .51381 .26297 .52647 .25833 .51958 .2499 Mtetra
.664 .74 .907 r
.51958 .2499 .52647 .25833 .5392 .25374 .53234 .24531 Mtetra
.664 .741 .907 r
.53234 .24531 .5392 .25374 .55198 .24917 .54516 .24071 Mtetra
.664 .741 .908 r
.54516 .24071 .55198 .24917 .56482 .2446 .55804 .23609 Mtetra
.55804 .23609 .56482 .2446 .57772 .24 .57098 .23146 Mtetra
.57098 .23146 .57772 .24 .59068 .23538 .58398 .2268 Mtetra
.58398 .2268 .59068 .23538 .6037 .23075 .59704 .22212 Mtetra
.59704 .22212 .6037 .23075 .61678 .22609 .61017 .21742 Mtetra
.61017 .21742 .61678 .22609 .62993 .22141 .62335 .2127 Mtetra
.663 .741 .908 r
.62335 .2127 .62993 .22141 .64313 .21671 .6366 .20796 Mtetra
.6366 .20796 .64313 .21671 .6564 .21199 .64991 .20319 Mtetra
.64991 .20319 .6564 .21199 .66973 .20725 .66329 .19841 Mtetra
.66329 .19841 .66973 .20725 .68313 .20249 .67672 .1936 Mtetra
.663 .741 .907 r
.67672 .1936 .68313 .20249 .69659 .1977 .69023 .18876 Mtetra
.663 .74 .907 r
.69023 .18876 .69659 .1977 .71011 .19289 .70379 .18391 Mtetra
.70379 .18391 .71011 .19289 .7237 .18806 .71743 .17903 Mtetra
.71743 .17903 .7237 .18806 .73735 .1832 .73112 .17412 Mtetra
.73112 .17412 .73735 .1832 .75107 .17832 .74489 .1692 Mtetra
.74489 .1692 .75107 .17832 .76485 .17341 .75872 .16424 Mtetra
.664 .74 .907 r
.75872 .16424 .76485 .17341 .7787 .16847 .77261 .15926 Mtetra
.77261 .15926 .7787 .16847 .79262 .16351 .78658 .15426 Mtetra
.659 .742 .911 r
.15452 .37045 .16246 .37778 .17361 .37382 .16568 .36655 Mtetra
.652 .743 .916 r
.16568 .36655 .17361 .37382 .1848 .36991 .17688 .36283 Mtetra
.635 .745 .927 r
.17688 .36283 .1848 .36991 .19603 .36612 .18808 .35954 Mtetra
.592 .748 .952 r
.18808 .35954 .19603 .36612 .20727 .36267 .19924 .35714 Mtetra
.466 .739 .987 r
.19924 .35714 .20727 .36267 .2185 .3599 .2103 .35642 Mtetra
.034 .558 .863 r
.2103 .35642 .2185 .3599 .22967 .35842 .22116 .35848 Mtetra
.577 .011 0 r
.22116 .35848 .22967 .35842 .24071 .35912 .23173 .36473 Mtetra
.725 .288 .213 r
.23173 .36473 .24071 .35912 .25154 .36312 .24193 .37649 Mtetra
.74 .373 .356 r
.24193 .37649 .25154 .36312 .26213 .37148 .25177 .39448 Mtetra
.73 .397 .415 r
.25177 .39448 .26213 .37148 .27246 .38483 .26136 .41809 Mtetra
.709 .394 .442 r
.26136 .41809 .27246 .38483 .28263 .40273 .27096 .4448 Mtetra
.68 .374 .45 r
.27096 .4448 .28263 .40273 .29283 .42323 .28095 .47012 Mtetra
.635 .334 .444 r
.28095 .47012 .29283 .42323 .30331 .44283 .2917 .48841 Mtetra
.558 .259 .416 r
.2917 .48841 .30331 .44283 .31437 .45709 .30347 .49464 Mtetra
.389 .089 .331 r
.30347 .49464 .31437 .45709 .32619 .46198 .3163 .48623 Mtetra
0 0 0 r
.3163 .48623 .32619 .46198 .33879 .45529 .32997 .46421 Mtetra
.967 .93 .616 r
.32997 .46421 .33879 .45529 .352 .43763 .34408 .43273 Mtetra
.938 .784 .664 r
.34408 .43273 .352 .43763 .36557 .4121 .35825 .39742 Mtetra
.873 .695 .658 r
.35825 .39742 .36557 .4121 .37918 .38308 .37217 .36343 Mtetra
.828 .65 .661 r
.37217 .36343 .37918 .38308 .39263 .35477 .38572 .33421 Mtetra
.796 .629 .675 r
.38572 .33421 .39263 .35477 .40582 .33007 .39888 .31115 Mtetra
.77 .626 .701 r
.39888 .31115 .40582 .33007 .41875 .31025 .41173 .29405 Mtetra
.747 .637 .738 r
.41173 .29405 .41875 .31025 .43146 .29526 .42439 .28174 Mtetra
.725 .659 .783 r
.42439 .28174 .43146 .29526 .44404 .28423 .43694 .27283 Mtetra
.705 .685 .828 r
.43694 .27283 .44404 .28423 .45657 .27601 .44946 .26603 Mtetra
.688 .708 .863 r
.44946 .26603 .45657 .27601 .46909 .26957 .462 .26042 Mtetra
.676 .724 .886 r
.462 .26042 .46909 .26957 .48164 .26413 .47457 .25542 Mtetra
.669 .733 .898 r
.47457 .25542 .48164 .26413 .49423 .25921 .4872 .25068 Mtetra
.666 .738 .904 r
.4872 .25068 .49423 .25921 .50687 .25451 .49988 .24604 Mtetra
.664 .74 .906 r
.49988 .24604 .50687 .25451 .51958 .2499 .51262 .24142 Mtetra
.664 .741 .907 r
.51262 .24142 .51958 .2499 .53234 .24531 .52542 .23681 Mtetra
.664 .741 .908 r
.52542 .23681 .53234 .24531 .54516 .24071 .53828 .23217 Mtetra
.53828 .23217 .54516 .24071 .55804 .23609 .5512 .22752 Mtetra
.5512 .22752 .55804 .23609 .57098 .23146 .56418 .22284 Mtetra
.56418 .22284 .57098 .23146 .58398 .2268 .57722 .21815 Mtetra
.57722 .21815 .58398 .2268 .59704 .22212 .59033 .21343 Mtetra
.59033 .21343 .59704 .22212 .61017 .21742 .60349 .20869 Mtetra
.60349 .20869 .61017 .21742 .62335 .2127 .61672 .20392 Mtetra
.61672 .20392 .62335 .2127 .6366 .20796 .63001 .19914 Mtetra
.63001 .19914 .6366 .20796 .64991 .20319 .64336 .19433 Mtetra
.64336 .19433 .64991 .20319 .66329 .19841 .65678 .1895 Mtetra
.65678 .1895 .66329 .19841 .67672 .1936 .67026 .18464 Mtetra
.67026 .18464 .67672 .1936 .69023 .18876 .68381 .17976 Mtetra
.68381 .17976 .69023 .18876 .70379 .18391 .69742 .17486 Mtetra
.69742 .17486 .70379 .18391 .71743 .17903 .7111 .16994 Mtetra
.7111 .16994 .71743 .17903 .73112 .17412 .72484 .16499 Mtetra
.72484 .16499 .73112 .17412 .74489 .1692 .73865 .16002 Mtetra
.73865 .16002 .74489 .1692 .75872 .16424 .75253 .15502 Mtetra
.75253 .15502 .75872 .16424 .77261 .15926 .76647 .15 Mtetra
.76647 .15 .77261 .15926 .78658 .15426 .78049 .14495 Mtetra
.65 .743 .917 r
.1465 .36317 .15452 .37045 .16568 .36655 .15766 .35951 Mtetra
.628 .745 .931 r
.15766 .35951 .16568 .36655 .17688 .36283 .16882 .35636 Mtetra
.573 .747 .959 r
.16882 .35636 .17688 .36283 .18808 .35954 .17991 .35429 Mtetra
.399 .72 .988 r
.17991 .35429 .18808 .35954 .19924 .35714 .19086 .3542 Mtetra
0 .411 .718 r
.19086 .3542 .19924 .35714 .2103 .35642 .20155 .35741 Mtetra
.664 .14 0 r
.20155 .35741 .2103 .35642 .22116 .35848 .21186 .36551 Mtetra
.75 .34 .274 r
.21186 .36551 .22116 .35848 .23173 .36473 .22169 .38002 Mtetra
.755 .401 .383 r
.22169 .38002 .23173 .36473 .24193 .37649 .23106 .40169 Mtetra
.743 .417 .43 r
.23106 .40169 .24193 .37649 .25177 .39448 .2401 .42974 Mtetra
.723 .412 .451 r
.2401 .42974 .25177 .39448 .26136 .41809 .24915 .46113 Mtetra
.695 .39 .456 r
.24915 .46113 .26136 .41809 .27096 .4448 .25867 .49056 Mtetra
.65 .347 .445 r
.25867 .49056 .27096 .4448 .28095 .47012 .26913 .51148 Mtetra
.563 .256 .405 r
.26913 .51148 .28095 .47012 .2917 .48841 .28089 .51815 Mtetra
.299 0 .249 r
.28089 .51815 .2917 .48841 .30347 .49464 .29395 .50783 Mtetra
.819 .915 .52 r
.29395 .50783 .30347 .49464 .3163 .48623 .30805 .48205 Mtetra
.94 .788 .664 r
.30805 .48205 .3163 .48623 .32997 .46421 .32268 .44585 Mtetra
.865 .672 .64 r
.32268 .44585 .32997 .46421 .34408 .43273 .33736 .4058 Mtetra
.82 .62 .632 r
.33736 .4058 .34408 .43273 .35825 .39742 .35172 .36774 Mtetra
.79 .594 .636 r
.35172 .36774 .35825 .39742 .37217 .36343 .36558 .3354 Mtetra
.767 .584 .65 r
.36558 .3354 .37217 .36343 .38572 .33421 .37896 .31021 Mtetra
.749 .588 .676 r
.37896 .31021 .38572 .33421 .39888 .31115 .39194 .29176 Mtetra
.733 .605 .714 r
.39194 .29176 .39888 .31115 .41173 .29405 .40466 .27868 Mtetra
.718 .633 .762 r
.40466 .27868 .41173 .29405 .42439 .28174 .41723 .26936 Mtetra
.702 .667 .813 r
.41723 .26936 .42439 .28174 .43694 .27283 .42976 .26235 Mtetra
.687 .698 .854 r
.42976 .26235 .43694 .27283 .44946 .26603 .44228 .25665 Mtetra
.676 .719 .881 r
.44228 .25665 .44946 .26603 .462 .26042 .45484 .25159 Mtetra
.669 .731 .896 r
.45484 .25159 .462 .26042 .47457 .25542 .46745 .24682 Mtetra
.666 .737 .903 r
.46745 .24682 .47457 .25542 .4872 .25068 .48011 .24216 Mtetra
.664 .74 .906 r
.48011 .24216 .4872 .25068 .49988 .24604 .49283 .23753 Mtetra
.664 .741 .907 r
.49283 .23753 .49988 .24604 .51262 .24142 .50561 .23289 Mtetra
.664 .741 .908 r
.50561 .23289 .51262 .24142 .52542 .23681 .51844 .22824 Mtetra
.51844 .22824 .52542 .23681 .53828 .23217 .53134 .22357 Mtetra
.53134 .22357 .53828 .23217 .5512 .22752 .5443 .21887 Mtetra
.5443 .21887 .5512 .22752 .56418 .22284 .55732 .21416 Mtetra
.55732 .21416 .56418 .22284 .57722 .21815 .57041 .20942 Mtetra
.57041 .20942 .57722 .21815 .59033 .21343 .58355 .20466 Mtetra
.58355 .20466 .59033 .21343 .60349 .20869 .59676 .19987 Mtetra
.59676 .19987 .60349 .20869 .61672 .20392 .61003 .19507 Mtetra
.61003 .19507 .61672 .20392 .63001 .19914 .62336 .19024 Mtetra
.62336 .19024 .63001 .19914 .64336 .19433 .63676 .18539 Mtetra
.63676 .18539 .64336 .19433 .65678 .1895 .65022 .18051 Mtetra
.65022 .18051 .65678 .1895 .67026 .18464 .66374 .17562 Mtetra
.66374 .17562 .67026 .18464 .68381 .17976 .67734 .17069 Mtetra
.67734 .17069 .68381 .17976 .69742 .17486 .69099 .16575 Mtetra
.69099 .16575 .69742 .17486 .7111 .16994 .70472 .16078 Mtetra
.70472 .16078 .7111 .16994 .72484 .16499 .7185 .15578 Mtetra
.7185 .15578 .72484 .16499 .73865 .16002 .73236 .15077 Mtetra
.73236 .15077 .73865 .16002 .75253 .15502 .74629 .14572 Mtetra
.74629 .14572 .75253 .15502 .76647 .15 .76028 .14066 Mtetra
.76028 .14066 .76647 .15 .78049 .14495 .77434 .13556 Mtetra
.624 .745 .934 r
.13837 .35614 .1465 .36317 .15766 .35951 .14949 .35309 Mtetra
.56 .745 .963 r
.14949 .35309 .15766 .35951 .16882 .35636 .16053 .35122 Mtetra
.353 .703 .984 r
.16053 .35122 .16882 .35636 .17991 .35429 .17138 .35153 Mtetra
.272 0 0 r
.17138 .35153 .17991 .35429 .19086 .3542 .18193 .35541 Mtetra
.696 .19 .031 r
.18193 .35541 .19086 .3542 .20155 .35741 .19203 .36458 Mtetra
.763 .362 .292 r
.19203 .36458 .20155 .35741 .21186 .36551 .20159 .38059 Mtetra
.767 .416 .39 r
.20159 .38059 .21186 .36551 .22169 .38002 .2106 .40417 Mtetra
.756 .43 .432 r
.2106 .40417 .22169 .38002 .23106 .40169 .21924 .43434 Mtetra
.739 .424 .45 r
.21924 .43434 .23106 .40169 .2401 .42974 .22788 .46775 Mtetra
.713 .403 .451 r
.22788 .46775 .2401 .42974 .24915 .46113 .23707 .49864 Mtetra
.67 .355 .433 r
.23707 .49864 .24915 .46113 .25867 .49056 .24736 .52007 Mtetra
.565 .231 .361 r
.24736 .52007 .25867 .49056 .26913 .51148 .25911 .52609 Mtetra
0 0 0 r
.25911 .52609 .26913 .51148 .28089 .51815 .27236 .5141 Mtetra
.928 .808 .707 r
.27236 .5141 .28089 .51815 .29395 .50783 .28677 .48604 Mtetra
.843 .65 .641 r
.28677 .48604 .29395 .50783 .30805 .48205 .30177 .44748 Mtetra
.801 .592 .619 r
.30177 .44748 .30805 .48205 .32268 .44585 .3168 .40541 Mtetra
.775 .564 .614 r
.3168 .40541 .32268 .44585 .33736 .4058 .33145 .36584 Mtetra
.755 .551 .619 r
.33145 .36584 .33736 .4058 .35172 .36774 .34553 .33254 Mtetra
.741 .549 .634 r
.34553 .33254 .35172 .36774 .36558 .3354 .35905 .30679 Mtetra
.729 .558 .66 r
.35905 .30679 .36558 .3354 .37896 .31021 .37211 .28807 Mtetra
.718 .58 .699 r
.37211 .28807 .37896 .31021 .39194 .29176 .38487 .27489 Mtetra
.708 .614 .749 r
.38487 .27489 .39194 .29176 .40466 .27868 .39746 .26552 Mtetra
.697 .654 .803 r
.39746 .26552 .40466 .27868 .41723 .26936 .40998 .2585 Mtetra
.685 .69 .849 r
.40998 .2585 .41723 .26936 .42976 .26235 .42249 .25279 Mtetra
.675 .715 .879 r
.42249 .25279 .42976 .26235 .44228 .25665 .43503 .24772 Mtetra
.669 .729 .895 r
.43503 .24772 .44228 .25665 .45484 .25159 .44762 .24294 Mtetra
.665 .736 .903 r
.44762 .24294 .45484 .25159 .46745 .24682 .46026 .23826 Mtetra
.664 .739 .906 r
.46026 .23826 .46745 .24682 .48011 .24216 .47296 .23361 Mtetra
.664 .741 .907 r
.47296 .23361 .48011 .24216 .49283 .23753 .48571 .22896 Mtetra
.664 .741 .908 r
.48571 .22896 .49283 .23753 .50561 .23289 .49853 .22429 Mtetra
.49853 .22429 .50561 .23289 .51844 .22824 .51141 .2196 Mtetra
.51141 .2196 .51844 .22824 .53134 .22357 .52435 .21488 Mtetra
.52435 .21488 .53134 .22357 .5443 .21887 .53735 .21015 Mtetra
.53735 .21015 .5443 .21887 .55732 .21416 .55041 .20539 Mtetra
.55041 .20539 .55732 .21416 .57041 .20942 .56353 .20061 Mtetra
.56353 .20061 .57041 .20942 .58355 .20466 .57672 .19581 Mtetra
.57672 .19581 .58355 .20466 .59676 .19987 .58996 .19098 Mtetra
.58996 .19098 .59676 .19987 .61003 .19507 .60328 .18614 Mtetra
.60328 .18614 .61003 .19507 .62336 .19024 .61665 .18126 Mtetra
.61665 .18126 .62336 .19024 .63676 .18539 .63009 .17637 Mtetra
.63009 .17637 .63676 .18539 .65022 .18051 .6436 .17145 Mtetra
.6436 .17145 .65022 .18051 .66374 .17562 .65717 .16651 Mtetra
.65717 .16651 .66374 .17562 .67734 .17069 .6708 .16154 Mtetra
.6708 .16154 .67734 .17069 .69099 .16575 .68451 .15655 Mtetra
.68451 .15655 .69099 .16575 .70472 .16078 .69828 .15154 Mtetra
.69828 .15154 .70472 .16078 .7185 .15578 .71211 .1465 Mtetra
.71211 .1465 .7185 .15578 .73236 .15077 .72601 .14144 Mtetra
.72601 .14144 .73236 .15077 .74629 .14572 .73999 .13635 Mtetra
.73999 .13635 .74629 .14572 .76028 .14066 .75403 .13123 Mtetra
.75403 .13123 .76028 .14066 .77434 .13556 .76814 .1261 Mtetra
.557 .743 .964 r
.1301 .34967 .13837 .35614 .14949 .35309 .1411 .34784 Mtetra
.349 .698 .983 r
.1411 .34784 .14949 .35309 .16053 .35122 .1519 .3482 Mtetra
.267 0 0 r
.1519 .3482 .16053 .35122 .17138 .35153 .16237 .35215 Mtetra
.698 .185 .011 r
.16237 .35215 .17138 .35153 .18193 .35541 .17236 .36134 Mtetra
.771 .362 .277 r
.17236 .36134 .18193 .35541 .19203 .36458 .18177 .37725 Mtetra
.778 .42 .377 r
.18177 .37725 .19203 .36458 .20159 .38059 .19062 .40048 Mtetra
.771 .437 .42 r
.19062 .40048 .20159 .38059 .2106 .40417 .19909 .42993 Mtetra
.758 .434 .436 r
.19909 .42993 .2106 .40417 .21924 .43434 .20759 .46214 Mtetra
.738 .413 .432 r
.20759 .46214 .21924 .43434 .22788 .46775 .21667 .49143 Mtetra
.701 .359 .395 r
.21667 .49143 .22788 .46775 .23707 .49864 .22691 .51106 Mtetra
.548 .124 .189 r
.22691 .51106 .23707 .49864 .24736 .52007 .23869 .51547 Mtetra
.849 .851 .844 r
.23869 .51547 .24736 .52007 .25911 .52609 .25202 .50247 Mtetra
.8 .622 .66 r
.25202 .50247 .25911 .52609 .27236 .5141 .26654 .47423 Mtetra
.771 .564 .619 r
.26654 .47423 .27236 .5141 .28677 .48604 .28166 .4363 Mtetra
.752 .538 .605 r
.28166 .4363 .28677 .48604 .30177 .44748 .2968 .39542 Mtetra
.738 .524 .604 r
.2968 .39542 .30177 .44748 .3168 .40541 .31153 .3573 Mtetra
.727 .519 .61 r
.31153 .3573 .3168 .40541 .33145 .36584 .32567 .32539 Mtetra
.718 .523 .626 r
.32567 .32539 .33145 .36584 .34553 .33254 .33922 .30082 Mtetra
.71 .537 .652 r
.33922 .30082 .34553 .33254 .35905 .30679 .35229 .28296 Mtetra
.704 .563 .692 r
.35229 .28296 .35905 .30679 .37211 .28807 .36505 .27035 Mtetra
.699 .601 .744 r
.36505 .27035 .37211 .28807 .38487 .27489 .37763 .26132 Mtetra
.691 .646 .8 r
.37763 .26132 .38487 .27489 .39746 .26552 .39013 .25449 Mtetra
.682 .686 .847 r
.39013 .25449 .39746 .26552 .40998 .2585 .40262 .24886 Mtetra
.673 .713 .878 r
.40262 .24886 .40998 .2585 .42249 .25279 .41514 .24381 Mtetra
.668 .729 .895 r
.41514 .24381 .42249 .25279 .43503 .24772 .42771 .23903 Mtetra
.665 .736 .903 r
.42771 .23903 .43503 .24772 .44762 .24294 .44033 .23434 Mtetra
.664 .739 .906 r
.44033 .23434 .44762 .24294 .46026 .23826 .453 .22968 Mtetra
.664 .741 .907 r
.453 .22968 .46026 .23826 .47296 .23361 .46574 .22501 Mtetra
.664 .741 .908 r
.46574 .22501 .47296 .23361 .48571 .22896 .47854 .22032 Mtetra
.47854 .22032 .48571 .22896 .49853 .22429 .49139 .21561 Mtetra
.49139 .21561 .49853 .22429 .51141 .2196 .50431 .21088 Mtetra
.50431 .21088 .51141 .2196 .52435 .21488 .51729 .20612 Mtetra
.51729 .20612 .52435 .21488 .53735 .21015 .53033 .20135 Mtetra
.53033 .20135 .53735 .21015 .55041 .20539 .54343 .19655 Mtetra
.54343 .19655 .55041 .20539 .56353 .20061 .55659 .19173 Mtetra
.55659 .19173 .56353 .20061 .57672 .19581 .56982 .18688 Mtetra
.56982 .18688 .57672 .19581 .58996 .19098 .58311 .18202 Mtetra
.58311 .18202 .58996 .19098 .60328 .18614 .59647 .17712 Mtetra
.59647 .17712 .60328 .18614 .61665 .18126 .60989 .17221 Mtetra
.60989 .17221 .61665 .18126 .63009 .17637 .62337 .16727 Mtetra
.62337 .16727 .63009 .17637 .6436 .17145 .63692 .16231 Mtetra
.63692 .16231 .6436 .17145 .65717 .16651 .65053 .15732 Mtetra
.65053 .15732 .65717 .16651 .6708 .16154 .66421 .15231 Mtetra
.66421 .15231 .6708 .16154 .68451 .15655 .67796 .14728 Mtetra
.67796 .14728 .68451 .15655 .69828 .15154 .69178 .14222 Mtetra
.69178 .14222 .69828 .15154 .71211 .1465 .70566 .13713 Mtetra
.70566 .13713 .71211 .1465 .72601 .14144 .71961 .13202 Mtetra
.71961 .13202 .72601 .14144 .73999 .13635 .73363 .12689 Mtetra
.73363 .12689 .73999 .13635 .75403 .13123 .74772 .12173 Mtetra
.74772 .12173 .75403 .13123 .76814 .1261 .76188 .11654 Mtetra
.388 .708 .985 r
.12164 .34412 .1301 .34967 .1411 .34784 .13242 .34419 Mtetra
0 .415 .748 r
.13242 .34419 .1411 .34784 .1519 .3482 .14288 .34756 Mtetra
.66 .118 0 r
.14288 .34756 .1519 .3482 .16237 .35215 .15288 .35572 Mtetra
.771 .337 .22 r
.15288 .35572 .16237 .35215 .17236 .36134 .16233 .36995 Mtetra
.788 .41 .34 r
.16233 .36995 .17236 .36134 .18177 .37725 .17124 .39066 Mtetra
.788 .435 .389 r
.17124 .39066 .18177 .37725 .19062 .40048 .17982 .41671 Mtetra
.782 .437 .403 r
.17982 .41671 .19062 .40048 .19909 .42993 .18844 .44482 Mtetra
.774 .419 .383 r
.18844 .44482 .19909 .42993 .20759 .46214 .19766 .46984 Mtetra
.753 .342 .272 r
.19766 .46984 .20759 .46214 .21667 .49143 .20801 .48584 Mtetra
.156 .591 .933 r
.20801 .48584 .21667 .49143 .22691 .51106 .21983 .48811 Mtetra
.713 .577 .701 r
.21983 .48811 .22691 .51106 .23869 .51547 .23311 .475 Mtetra
.726 .532 .628 r
.23311 .475 .23869 .51547 .25202 .50247 .2475 .44868 Mtetra
.722 .512 .605 r
.2475 .44868 .25202 .50247 .26654 .47423 .26246 .41416 Mtetra
.716 .502 .598 r
.26246 .41416 .26654 .47423 .28166 .4363 .27742 .37737 Mtetra
.71 .497 .599 r
.27742 .37737 .28166 .4363 .2968 .39542 .29199 .34326 Mtetra
.703 .498 .607 r
.29199 .34326 .2968 .39542 .31153 .3573 .30601 .31477 Mtetra
.698 .506 .624 r
.30601 .31477 .31153 .3573 .32567 .32539 .31947 .29279 Mtetra
.695 .524 .652 r
.31947 .29279 .32567 .32539 .33922 .30082 .33248 .27673 Mtetra
.693 .554 .693 r
.33248 .27673 .33922 .30082 .35229 .28296 .34519 .26524 Mtetra
.69 .597 .747 r
.34519 .26524 .35229 .28296 .36505 .27035 .35773 .25685 Mtetra
.685 .645 .804 r
.35773 .25685 .36505 .27035 .37763 .26132 .37021 .25034 Mtetra
.678 .687 .851 r
.37021 .25034 .37763 .26132 .39013 .25449 .38268 .24486 Mtetra
.672 .714 .88 r
.38268 .24486 .39013 .25449 .40262 .24886 .39518 .23988 Mtetra
.667 .729 .896 r
.39518 .23988 .40262 .24886 .41514 .24381 .40772 .23511 Mtetra
.665 .737 .903 r
.40772 .23511 .41514 .24381 .42771 .23903 .42032 .23041 Mtetra
.664 .74 .906 r
.42032 .23041 .42771 .23903 .44033 .23434 .43297 .22573 Mtetra
.664 .741 .907 r
.43297 .22573 .44033 .23434 .453 .22968 .44569 .22104 Mtetra
.664 .741 .908 r
.44569 .22104 .453 .22968 .46574 .22501 .45846 .21634 Mtetra
.45846 .21634 .46574 .22501 .47854 .22032 .4713 .21161 Mtetra
.4713 .21161 .47854 .22032 .49139 .21561 .48419 .20686 Mtetra
.48419 .20686 .49139 .21561 .50431 .21088 .49715 .20209 Mtetra
.49715 .20209 .50431 .21088 .51729 .20612 .51017 .19729 Mtetra
.51017 .19729 .51729 .20612 .53033 .20135 .52325 .19247 Mtetra
.52325 .19247 .53033 .20135 .54343 .19655 .53639 .18763 Mtetra
.53639 .18763 .54343 .19655 .55659 .19173 .5496 .18277 Mtetra
.5496 .18277 .55659 .19173 .56982 .18688 .56287 .17788 Mtetra
.56287 .17788 .56982 .18688 .58311 .18202 .5762 .17297 Mtetra
.5762 .17297 .58311 .18202 .59647 .17712 .5896 .16803 Mtetra
.5896 .16803 .59647 .17712 .60989 .17221 .60306 .16307 Mtetra
.60306 .16307 .60989 .17221 .62337 .16727 .61659 .15809 Mtetra
.61659 .15809 .62337 .16727 .63692 .16231 .63018 .15308 Mtetra
.63018 .15308 .63692 .16231 .65053 .15732 .64384 .14805 Mtetra
.64384 .14805 .65053 .15732 .66421 .15231 .65757 .143 Mtetra
.65757 .143 .66421 .15231 .67796 .14728 .67136 .13792 Mtetra
.67136 .13792 .67796 .14728 .69178 .14222 .68522 .13281 Mtetra
.68522 .13281 .69178 .14222 .70566 .13713 .69915 .12768 Mtetra
.69915 .12768 .70566 .13713 .71961 .13202 .71315 .12252 Mtetra
.71315 .12252 .71961 .13202 .73363 .12689 .72722 .11734 Mtetra
.72722 .11734 .73363 .12689 .74772 .12173 .74135 .11213 Mtetra
.74135 .11213 .74772 .12173 .76188 .11654 .75556 .1069 Mtetra
.06 .553 .889 r
.11295 .33959 .12164 .34412 .13242 .34419 .12347 .34189 Mtetra
.535 0 0 r
.12347 .34189 .13242 .34419 .14288 .34756 .13359 .34821 Mtetra
.747 .262 .088 r
.13359 .34821 .14288 .34756 .15288 .35572 .14323 .35956 Mtetra
.792 .374 .255 r
.14323 .35956 .15288 .35572 .16233 .36995 .15241 .37618 Mtetra
.804 .416 .318 r
.15241 .37618 .16233 .36995 .17124 .39066 .16132 .39696 Mtetra
.811 .425 .323 r
.16132 .39696 .17124 .39066 .17982 .41671 .17031 .41908 Mtetra
.819 .399 .245 r
.17031 .41908 .17982 .41671 .18844 .44482 .17986 .43824 Mtetra
.638 .108 0 r
.17986 .43824 .18844 .44482 .19766 .46984 .19041 .44968 Mtetra
.527 .488 .757 r
.19041 .44968 .19766 .46984 .20801 .48584 .20226 .44977 Mtetra
.657 .492 .65 r
.20226 .44977 .20801 .48584 .21983 .48811 .21537 .43742 Mtetra
.683 .486 .613 r
.21537 .43742 .21983 .48811 .23311 .475 .22944 .41457 Mtetra
.689 .481 .599 r
.22944 .41457 .23311 .475 .2475 .44868 .24399 .38533 Mtetra
.69 .478 .596 r
.24399 .38533 .2475 .44868 .26246 .41416 .25855 .3545 Mtetra
.688 .479 .599 r
.25855 .3545 .26246 .41416 .27742 .37737 .27277 .326 Mtetra
.685 .485 .609 r
.27277 .326 .27742 .37737 .29199 .34326 .28651 .30216 Mtetra
.683 .497 .629 r
.28651 .30216 .29199 .34326 .30601 .31477 .29978 .28363 Mtetra
.683 .52 .659 r
.29978 .28363 .30601 .31477 .31947 .29279 .31266 .26989 Mtetra
.683 .556 .704 r
.31266 .26989 .31947 .29279 .33248 .27673 .32529 .25982 Mtetra
.683 .602 .759 r
.32529 .25982 .33248 .27673 .34519 .26524 .33778 .25223 Mtetra
.68 .651 .814 r
.33778 .25223 .34519 .26524 .35773 .25685 .35022 .24613 Mtetra
.675 .691 .858 r
.35022 .24613 .35773 .25685 .37021 .25034 .36266 .24083 Mtetra
.67 .717 .884 r
.36266 .24083 .37021 .25034 .38268 .24486 .37513 .23592 Mtetra
.666 .731 .898 r
.37513 .23592 .38268 .24486 .39518 .23988 .38766 .23116 Mtetra
.665 .737 .904 r
.38766 .23116 .39518 .23988 .40772 .23511 .40023 .22646 Mtetra
.664 .74 .907 r
.40023 .22646 .40772 .23511 .42032 .23041 .41286 .22177 Mtetra
.664 .741 .907 r
.41286 .22177 .42032 .23041 .43297 .22573 .42556 .21706 Mtetra
.664 .741 .908 r
.42556 .21706 .43297 .22573 .44569 .22104 .43831 .21234 Mtetra
.43831 .21234 .44569 .22104 .45846 .21634 .45112 .20759 Mtetra
.45112 .20759 .45846 .21634 .4713 .21161 .46399 .20282 Mtetra
.46399 .20282 .4713 .21161 .48419 .20686 .47693 .19803 Mtetra
.47693 .19803 .48419 .20686 .49715 .20209 .48993 .19321 Mtetra
.48993 .19321 .49715 .20209 .51017 .19729 .50298 .18838 Mtetra
.50298 .18838 .51017 .19729 .52325 .19247 .5161 .18352 Mtetra
.5161 .18352 .52325 .19247 .53639 .18763 .52929 .17863 Mtetra
.52929 .17863 .53639 .18763 .5496 .18277 .54254 .17372 Mtetra
.54254 .17372 .5496 .18277 .56287 .17788 .55585 .16879 Mtetra
.55585 .16879 .56287 .17788 .5762 .17297 .56922 .16384 Mtetra
.56922 .16384 .5762 .17297 .5896 .16803 .58266 .15886 Mtetra
.58266 .15886 .5896 .16803 .60306 .16307 .59617 .15386 Mtetra
.59617 .15386 .60306 .16307 .61659 .15809 .60974 .14883 Mtetra
.60974 .14883 .61659 .15809 .63018 .15308 .62338 .14378 Mtetra
.62338 .14378 .63018 .15308 .64384 .14805 .63708 .1387 Mtetra
.63708 .1387 .64384 .14805 .65757 .143 .65086 .1336 Mtetra
.65086 .1336 .65757 .143 .67136 .13792 .6647 .12847 Mtetra
.6647 .12847 .67136 .13792 .68522 .13281 .6786 .12332 Mtetra
.6786 .12332 .68522 .13281 .69915 .12768 .69258 .11814 Mtetra
.69258 .11814 .69915 .12768 .71315 .12252 .70663 .11294 Mtetra
.70663 .11294 .71315 .12252 .72722 .11734 .72074 .10771 Mtetra
.72074 .10771 .72722 .11734 .74135 .11213 .73493 .10245 Mtetra
.73493 .10245 .74135 .11213 .75556 .1069 .74918 .09717 Mtetra
0 .351 .703 r
.1041 .33558 .11295 .33959 .12347 .34189 .11441 .33963 Mtetra
.628 .065 0 r
.11441 .33963 .12347 .34189 .13359 .34821 .12434 .34752 Mtetra
.759 .265 .054 r
.12434 .34752 .13359 .34821 .14323 .35956 .13393 .35934 Mtetra
.8 .34 .143 r
.13393 .35934 .14323 .35956 .15241 .37618 .14332 .37413 Mtetra
.815 .346 .102 r
.14332 .37413 .15241 .37618 .16132 .39696 .15281 .38965 Mtetra
.703 .193 0 r
.15281 .38965 .16132 .39696 .17031 .41908 .16279 .4026 Mtetra
.22 .346 .78 r
.16279 .4026 .17031 .41908 .17986 .43824 .17359 .40949 Mtetra
.558 .449 .686 r
.17359 .40949 .17986 .43824 .19041 .44968 .18544 .40776 Mtetra
.632 .461 .633 r
.18544 .40776 .19041 .44968 .20226 .44977 .19831 .39677 Mtetra
.657 .463 .61 r
.19831 .39677 .20226 .44977 .21537 .43742 .21193 .37808 Mtetra
.667 .464 .601 r
.21193 .37808 .21537 .43742 .22944 .41457 .22593 .35482 Mtetra
.67 .466 .599 r
.22593 .35482 .22944 .41457 .24399 .38533 .23994 .33052 Mtetra
.671 .471 .605 r
.23994 .33052 .24399 .38533 .25855 .3545 .2537 .30809 Mtetra
.672 .48 .618 r
.2537 .30809 .25855 .3545 .27277 .326 .26708 .2892 Mtetra
.673 .498 .641 r
.26708 .2892 .27277 .326 .28651 .30216 .28009 .27431 Mtetra
.675 .526 .676 r
.28009 .27431 .28651 .30216 .29978 .28363 .2928 .26299 Mtetra
.677 .567 .723 r
.2928 .26299 .29978 .28363 .31266 .26989 .30533 .25439 Mtetra
.678 .616 .779 r
.30533 .25439 .31266 .26989 .32529 .25982 .31776 .24761 Mtetra
.676 .663 .83 r
.31776 .24761 .32529 .25982 .33778 .25223 .33016 .24191 Mtetra
.672 .699 .867 r
.33016 .24191 .33778 .25223 .35022 .24613 .34257 .23679 Mtetra
.668 .721 .889 r
.34257 .23679 .35022 .24613 .36266 .24083 .35501 .23194 Mtetra
.665 .733 .9 r
.35501 .23194 .36266 .24083 .37513 .23592 .36751 .2272 Mtetra
.664 .738 .905 r
.36751 .2272 .37513 .23592 .38766 .23116 .38006 .2225 Mtetra
.664 .74 .907 r
.38006 .2225 .38766 .23116 .40023 .22646 .39267 .21779 Mtetra
.664 .741 .908 r
.39267 .21779 .40023 .22646 .41286 .22177 .40534 .21307 Mtetra
.40534 .21307 .41286 .22177 .42556 .21706 .41807 .20832 Mtetra
.41807 .20832 .42556 .21706 .43831 .21234 .43086 .20356 Mtetra
.43086 .20356 .43831 .21234 .45112 .20759 .44372 .19877 Mtetra
.44372 .19877 .45112 .20759 .46399 .20282 .45663 .19396 Mtetra
.45663 .19396 .46399 .20282 .47693 .19803 .4696 .18912 Mtetra
.4696 .18912 .47693 .19803 .48993 .19321 .48264 .18427 Mtetra
.48264 .18427 .48993 .19321 .50298 .18838 .49574 .17939 Mtetra
.49574 .17939 .50298 .18838 .5161 .18352 .5089 .17448 Mtetra
.5089 .17448 .5161 .18352 .52929 .17863 .52212 .16955 Mtetra
.52212 .16955 .52929 .17863 .54254 .17372 .53541 .1646 Mtetra
.53541 .1646 .54254 .17372 .55585 .16879 .54877 .15963 Mtetra
.54877 .15963 .55585 .16879 .56922 .16384 .56218 .15463 Mtetra
.56218 .15463 .56922 .16384 .58266 .15886 .57567 .1496 Mtetra
.57567 .1496 .58266 .15886 .59617 .15386 .58922 .14455 Mtetra
.58922 .14455 .59617 .15386 .60974 .14883 .60283 .13948 Mtetra
.60283 .13948 .60974 .14883 .62338 .14378 .61652 .13438 Mtetra
.61652 .13438 .62338 .14378 .63708 .1387 .63027 .12926 Mtetra
.63027 .12926 .63708 .1387 .65086 .1336 .64408 .12411 Mtetra
.64408 .12411 .65086 .1336 .6647 .12847 .65797 .11894 Mtetra
.65797 .11894 .6647 .12847 .6786 .12332 .67193 .11374 Mtetra
.67193 .11374 .6786 .12332 .69258 .11814 .68595 .10851 Mtetra
.68595 .10851 .69258 .11814 .70663 .11294 .70004 .10326 Mtetra
.70004 .10326 .70663 .11294 .72074 .10771 .71421 .09798 Mtetra
.71421 .09798 .72074 .10771 .73493 .10245 .72844 .09268 Mtetra
.72844 .09268 .73493 .10245 .74918 .09717 .74275 .08735 Mtetra
0 .335 .713 r
.09524 .33091 .1041 .33558 .11441 .33963 .1055 .33537 Mtetra
.519 0 0 r
.1055 .33537 .11441 .33963 .12434 .34752 .11553 .34253 Mtetra
.615 .059 0 r
.11553 .34253 .12434 .34752 .13393 .35934 .12544 .35163 Mtetra
.497 0 0 r
.12544 .35163 .13393 .35934 .14332 .37413 .13546 .36103 Mtetra
.048 .3 .789 r
.13546 .36103 .14332 .37413 .15281 .38965 .14587 .36843 Mtetra
.445 .424 .742 r
.14587 .36843 .15281 .38965 .16279 .4026 .15692 .37143 Mtetra
.573 .447 .671 r
.15692 .37143 .16279 .4026 .17359 .40949 .16875 .36839 Mtetra
.62 .453 .634 r
.16875 .36839 .17359 .40949 .18544 .40776 .18133 .35899 Mtetra
.642 .456 .616 r
.18133 .35899 .18544 .40776 .19831 .39677 .19447 .34438 Mtetra
.652 .459 .609 r
.19447 .34438 .19831 .39677 .21193 .37808 .20789 .32674 Mtetra
.657 .463 .611 r
.20789 .32674 .21193 .37808 .22593 .35482 .22133 .30849 Mtetra
.66 .472 .619 r
.22133 .30849 .22593 .35482 .23994 .33052 .23459 .29161 Mtetra
.663 .487 .636 r
.23459 .29161 .23994 .33052 .2537 .30809 .2476 .27722 Mtetra
.666 .51 .663 r
.2476 .27722 .2537 .30809 .26708 .2892 .26034 .2656 Mtetra
.67 .544 .702 r
.26034 .2656 .26708 .2892 .28009 .27431 .27288 .25644 Mtetra
.674 .588 .752 r
.27288 .25644 .28009 .27431 .2928 .26299 .2853 .24914 Mtetra
.675 .637 .804 r
.2853 .24914 .2928 .26299 .30533 .25439 .29766 .24307 Mtetra
.673 .679 .848 r
.29766 .24307 .30533 .25439 .31776 .24761 .31001 .23772 Mtetra
.669 .709 .878 r
.31001 .23772 .31776 .24761 .33016 .24191 .32239 .23275 Mtetra
.666 .726 .894 r
.32239 .23275 .33016 .24191 .34257 .23679 .33481 .22796 Mtetra
.665 .735 .902 r
.33481 .22796 .34257 .23679 .35501 .23194 .34729 .22323 Mtetra
.664 .739 .906 r
.34729 .22323 .35501 .23194 .36751 .2272 .35982 .21852 Mtetra
.664 .74 .907 r
.35982 .21852 .36751 .2272 .38006 .2225 .3724 .21379 Mtetra
.664 .741 .908 r
.3724 .21379 .38006 .2225 .39267 .21779 .38505 .20905 Mtetra
.38505 .20905 .39267 .21779 .40534 .21307 .39776 .20429 Mtetra
.39776 .20429 .40534 .21307 .41807 .20832 .41053 .19951 Mtetra
.41053 .19951 .41807 .20832 .43086 .20356 .42335 .1947 Mtetra
.42335 .1947 .43086 .20356 .44372 .19877 .43624 .18987 Mtetra
.43624 .18987 .44372 .19877 .45663 .19396 .4492 .18501 Mtetra
.4492 .18501 .45663 .19396 .4696 .18912 .46221 .18014 Mtetra
.46221 .18014 .4696 .18912 .48264 .18427 .47529 .17524 Mtetra
.47529 .17524 .48264 .18427 .49574 .17939 .48843 .17031 Mtetra
.48843 .17031 .49574 .17939 .5089 .17448 .50163 .16537 Mtetra
.50163 .16537 .5089 .17448 .52212 .16955 .51489 .16039 Mtetra
.51489 .16039 .52212 .16955 .53541 .1646 .52823 .1554 Mtetra
.52823 .1554 .53541 .1646 .54877 .15963 .54162 .15038 Mtetra
.54162 .15038 .54877 .15963 .56218 .15463 .55508 .14533 Mtetra
.55508 .14533 .56218 .15463 .57567 .1496 .56861 .14026 Mtetra
.56861 .14026 .57567 .1496 .58922 .14455 .5822 .13517 Mtetra
.5822 .13517 .58922 .14455 .60283 .13948 .59586 .13005 Mtetra
.59586 .13005 .60283 .13948 .61652 .13438 .60959 .12491 Mtetra
.60959 .12491 .61652 .13438 .63027 .12926 .62339 .11974 Mtetra
.62339 .11974 .63027 .12926 .64408 .12411 .63725 .11454 Mtetra
.63725 .11454 .64408 .12411 .65797 .11894 .65119 .10932 Mtetra
.65119 .10932 .65797 .11894 .67193 .11374 .66519 .10407 Mtetra
.66519 .10407 .67193 .11374 .68595 .10851 .67926 .0988 Mtetra
.67926 .0988 .68595 .10851 .70004 .10326 .6934 .0935 Mtetra
.6934 .0935 .70004 .10326 .71421 .09798 .70762 .08817 Mtetra
.70762 .08817 .71421 .09798 .72844 .09268 .7219 .08282 Mtetra
.7219 .08282 .72844 .09268 .74275 .08735 .73626 .07744 Mtetra
.08 .507 .9 r
.08655 .32428 .09524 .33091 .1055 .33537 .09699 .32749 Mtetra
.027 .433 .868 r
.09699 .32749 .1055 .33537 .11553 .34253 .10737 .33187 Mtetra
.178 .444 .873 r
.10737 .33187 .11553 .34253 .12544 .35163 .11786 .33632 Mtetra
.392 .466 .817 r
.11786 .33632 .12544 .35163 .13546 .36103 .12864 .33932 Mtetra
.523 .467 .736 r
.12864 .33932 .13546 .36103 .14587 .36843 .13988 .3394 Mtetra
.586 .464 .68 r
.13988 .3394 .14587 .36843 .15692 .37143 .15167 .33556 Mtetra
.618 .462 .649 r
.15167 .33556 .15692 .37143 .16875 .36839 .16398 .32766 Mtetra
.635 .463 .633 r
.16398 .32766 .16875 .36839 .18133 .35899 .17667 .3165 Mtetra
.644 .466 .628 r
.17667 .3165 .18133 .35899 .19447 .34438 .18958 .30349 Mtetra
.65 .473 .632 r
.18958 .30349 .19447 .34438 .20789 .32674 .2025 .29016 Mtetra
.655 .486 .643 r
.2025 .29016 .20789 .32674 .22133 .30849 .21532 .27775 Mtetra
.659 .505 .665 r
.21532 .27775 .22133 .30849 .23459 .29161 .22798 .26696 Mtetra
.664 .534 .697 r
.22798 .26696 .23459 .29161 .2476 .27722 .24048 .25794 Mtetra
.668 .573 .739 r
.24048 .25794 .2476 .27722 .26034 .2656 .25286 .25048 Mtetra
.672 .618 .787 r
.25286 .25048 .26034 .2656 .27288 .25644 .26518 .24419 Mtetra
.672 .662 .832 r
.26518 .24419 .27288 .25644 .2853 .24914 .27748 .23867 Mtetra
.67 .696 .866 r
.27748 .23867 .2853 .24914 .29766 .24307 .28979 .23359 Mtetra
.667 .719 .887 r
.28979 .23359 .29766 .24307 .31001 .23772 .30214 .22873 Mtetra
.665 .731 .899 r
.30214 .22873 .31001 .23772 .32239 .23275 .31453 .22398 Mtetra
.664 .737 .904 r
.31453 .22398 .32239 .23275 .33481 .22796 .32698 .21925 Mtetra
.664 .74 .906 r
.32698 .21925 .33481 .22796 .34729 .22323 .33949 .21452 Mtetra
.664 .741 .907 r
.33949 .21452 .34729 .22323 .35982 .21852 .35205 .20978 Mtetra
.664 .741 .908 r
.35205 .20978 .35982 .21852 .3724 .21379 .36468 .20503 Mtetra
.36468 .20503 .3724 .21379 .38505 .20905 .37736 .20024 Mtetra
.37736 .20024 .38505 .20905 .39776 .20429 .39011 .19544 Mtetra
.39011 .19544 .39776 .20429 .41053 .19951 .40291 .19061 Mtetra
.40291 .19061 .41053 .19951 .42335 .1947 .41578 .18576 Mtetra
.41578 .18576 .42335 .1947 .43624 .18987 .42871 .18089 Mtetra
.42871 .18089 .43624 .18987 .4492 .18501 .4417 .17599 Mtetra
.4417 .17599 .4492 .18501 .46221 .18014 .45475 .17107 Mtetra
.45475 .17107 .46221 .18014 .47529 .17524 .46787 .16613 Mtetra
.46787 .16613 .47529 .17524 .48843 .17031 .48105 .16116 Mtetra
.48105 .16116 .48843 .17031 .50163 .16537 .49429 .15617 Mtetra
.49429 .15617 .50163 .16537 .51489 .16039 .5076 .15115 Mtetra
.5076 .15115 .51489 .16039 .52823 .1554 .52097 .14611 Mtetra
.52097 .14611 .52823 .1554 .54162 .15038 .53441 .14104 Mtetra
.53441 .14104 .54162 .15038 .55508 .14533 .54792 .13595 Mtetra
.54792 .13595 .55508 .14533 .56861 .14026 .56149 .13084 Mtetra
.56149 .13084 .56861 .14026 .5822 .13517 .57513 .1257 Mtetra
.57513 .1257 .5822 .13517 .59586 .13005 .58883 .12053 Mtetra
.58883 .12053 .59586 .13005 .60959 .12491 .60261 .11534 Mtetra
.60261 .11534 .60959 .12491 .62339 .11974 .61645 .11012 Mtetra
.61645 .11012 .62339 .11974 .63725 .11454 .63036 .10488 Mtetra
.63036 .10488 .63725 .11454 .65119 .10932 .64434 .09961 Mtetra
.64434 .09961 .65119 .10932 .66519 .10407 .65839 .09431 Mtetra
.65839 .09431 .66519 .10407 .67926 .0988 .67251 .08899 Mtetra
.67251 .08899 .67926 .0988 .6934 .0935 .6867 .08364 Mtetra
.6867 .08364 .6934 .0935 .70762 .08817 .70096 .07827 Mtetra
.70096 .07827 .70762 .08817 .7219 .08282 .71529 .07286 Mtetra
.71529 .07286 .7219 .08282 .73626 .07744 .7297 .06743 Mtetra
.411 .613 .932 r
.07814 .31509 .08655 .32428 .09699 .32749 .0889 .31598 Mtetra
.452 .573 .885 r
.0889 .31598 .09699 .32749 .10737 .33187 .09974 .31682 Mtetra
.517 .538 .817 r
.09974 .31682 .10737 .33187 .11786 .33632 .1108 .31672 Mtetra
.568 .512 .752 r
.1108 .31672 .11786 .33632 .12864 .33932 .12218 .31482 Mtetra
.602 .496 .706 r
.12218 .31482 .12864 .33932 .13988 .3394 .13391 .31055 Mtetra
.622 .488 .678 r
.13391 .31055 .13988 .3394 .15167 .33556 .14599 .30389 Mtetra
.635 .486 .663 r
.14599 .30389 .15167 .33556 .16398 .32766 .15833 .29533 Mtetra
.643 .489 .66 r
.15833 .29533 .16398 .32766 .17667 .3165 .17081 .28572 Mtetra
.649 .498 .665 r
.17081 .28572 .17667 .3165 .18958 .30349 .18332 .27596 Mtetra
.654 .515 .681 r
.18332 .27596 .18958 .30349 .2025 .29016 .19579 .26678 Mtetra
.659 .539 .706 r
.19579 .26678 .2025 .29016 .21532 .27775 .20817 .25856 Mtetra
.665 .572 .741 r
.20817 .25856 .21532 .27775 .22798 .26696 .22048 .2514 Mtetra
.669 .611 .782 r
.22048 .2514 .22798 .26696 .24048 .25794 .23273 .24514 Mtetra
.67 .652 .823 r
.23273 .24514 .24048 .25794 .25286 .25048 .24496 .23956 Mtetra
.67 .687 .857 r
.24496 .23956 .25286 .25048 .26518 .24419 .25721 .23441 Mtetra
.668 .712 .881 r
.25721 .23441 .26518 .24419 .27748 .23867 .26948 .2295 Mtetra
.666 .727 .895 r
.26948 .2295 .27748 .23867 .28979 .23359 .2818 .22472 Mtetra
.664 .735 .902 r
.2818 .22472 .28979 .23359 .30214 .22873 .29417 .21998 Mtetra
.664 .739 .906 r
.29417 .21998 .30214 .22873 .31453 .22398 .30659 .21526 Mtetra
.664 .74 .907 r
.30659 .21526 .31453 .22398 .32698 .21925 .31908 .21052 Mtetra
.664 .741 .908 r
.31908 .21052 .32698 .21925 .33949 .21452 .33162 .20576 Mtetra
.33162 .20576 .33949 .21452 .35205 .20978 .34422 .20098 Mtetra
.34422 .20098 .35205 .20978 .36468 .20503 .35688 .19618 Mtetra
.35688 .19618 .36468 .20503 .37736 .20024 .3696 .19136 Mtetra
.3696 .19136 .37736 .20024 .39011 .19544 .38239 .18651 Mtetra
.38239 .18651 .39011 .19544 .40291 .19061 .39523 .18164 Mtetra
.39523 .18164 .40291 .19061 .41578 .18576 .40813 .17675 Mtetra
.40813 .17675 .41578 .18576 .42871 .18089 .4211 .17183 Mtetra
.4211 .17183 .42871 .18089 .4417 .17599 .43413 .16689 Mtetra
.43413 .16689 .4417 .17599 .45475 .17107 .44723 .16193 Mtetra
.44723 .16193 .45475 .17107 .46787 .16613 .46038 .15694 Mtetra
.46038 .15694 .46787 .16613 .48105 .16116 .4736 .15192 Mtetra
.4736 .15192 .48105 .16116 .49429 .15617 .48689 .14689 Mtetra
.48689 .14689 .49429 .15617 .5076 .15115 .50024 .14183 Mtetra
.50024 .14183 .5076 .15115 .52097 .14611 .51366 .13674 Mtetra
.51366 .13674 .52097 .14611 .53441 .14104 .52714 .13163 Mtetra
.52714 .13163 .53441 .14104 .54792 .13595 .54069 .12649 Mtetra
.54069 .12649 .54792 .13595 .56149 .13084 .5543 .12133 Mtetra
.5543 .12133 .56149 .13084 .57513 .1257 .56798 .11614 Mtetra
.56798 .11614 .57513 .1257 .58883 .12053 .58173 .11093 Mtetra
.58173 .11093 .58883 .12053 .60261 .11534 .59555 .10569 Mtetra
.59555 .10569 .60261 .11534 .61645 .11012 .60944 .10042 Mtetra
.60944 .10042 .61645 .11012 .63036 .10488 .6234 .09513 Mtetra
.6234 .09513 .63036 .10488 .64434 .09961 .63742 .08981 Mtetra
.63742 .08981 .64434 .09961 .65839 .09431 .65152 .08447 Mtetra
.65152 .08447 .65839 .09431 .67251 .08899 .66569 .0791 Mtetra
.66569 .0791 .67251 .08899 .6867 .08364 .67993 .0737 Mtetra
.67993 .0737 .6867 .08364 .70096 .07827 .69424 .06827 Mtetra
.69424 .06827 .70096 .07827 .71529 .07286 .70863 .06282 Mtetra
.70863 .06282 .71529 .07286 .7297 .06743 .72309 .05734 Mtetra
.559 .63 .879 r
.06994 .30393 .07814 .31509 .0889 .31598 .08104 .30241 Mtetra
.58 .594 .831 r
.08104 .30241 .0889 .31598 .09974 .31682 .09228 .30031 Mtetra
.602 .563 .783 r
.09228 .30031 .09974 .31682 .1108 .31672 .10373 .29718 Mtetra
.619 .542 .745 r
.10373 .29718 .1108 .31672 .12218 .31482 .11541 .29273 Mtetra
.632 .53 .72 r
.11541 .29273 .12218 .31482 .13391 .31055 .12732 .28697 Mtetra
.641 .526 .707 r
.12732 .28697 .13391 .31055 .14599 .30389 .13939 .28018 Mtetra
.647 .529 .705 r
.13939 .28018 .14599 .30389 .15833 .29533 .15156 .27283 Mtetra
.653 .54 .714 r
.15156 .27283 .15833 .29533 .17081 .28572 .16378 .26542 Mtetra
.658 .559 .731 r
.16378 .26542 .17081 .28572 .18332 .27596 .17598 .25835 Mtetra
.663 .585 .758 r
.17598 .25835 .18332 .27596 .19579 .26678 .18817 .2518 Mtetra
.667 .618 .79 r
.18817 .2518 .19579 .26678 .20817 .25856 .20033 .24582 Mtetra
.669 .652 .825 r
.20033 .24582 .20817 .25856 .22048 .2514 .21248 .24032 Mtetra
.669 .683 .855 r
.21248 .24032 .22048 .2514 .23273 .24514 .22465 .23518 Mtetra
.667 .707 .878 r
.22465 .23518 .23273 .24514 .24496 .23956 .23685 .23026 Mtetra
.666 .723 .892 r
.23685 .23026 .24496 .23956 .25721 .23441 .24909 .22546 Mtetra
.665 .733 .9 r
.24909 .22546 .25721 .23441 .26948 .2295 .26138 .22072 Mtetra
.664 .738 .905 r
.26138 .22072 .26948 .2295 .2818 .22472 .27372 .21599 Mtetra
.664 .74 .907 r
.27372 .21599 .2818 .22472 .29417 .21998 .28613 .21125 Mtetra
.664 .741 .907 r
.28613 .21125 .29417 .21998 .30659 .21526 .29858 .20649 Mtetra
.664 .741 .908 r
.29858 .20649 .30659 .21526 .31908 .21052 .3111 .20172 Mtetra
.3111 .20172 .31908 .21052 .33162 .20576 .32368 .19692 Mtetra
.32368 .19692 .33162 .20576 .34422 .20098 .33632 .1921 Mtetra
.33632 .1921 .34422 .20098 .35688 .19618 .34902 .18726 Mtetra
.34902 .18726 .35688 .19618 .3696 .19136 .36178 .18239 Mtetra
.36178 .18239 .3696 .19136 .38239 .18651 .3746 .1775 Mtetra
.3746 .1775 .38239 .18651 .39523 .18164 .38748 .17259 Mtetra
.38748 .17259 .39523 .18164 .40813 .17675 .40042 .16765 Mtetra
.40042 .16765 .40813 .17675 .4211 .17183 .41343 .16269 Mtetra
.41343 .16269 .4211 .17183 .43413 .16689 .4265 .15771 Mtetra
.4265 .15771 .43413 .16689 .44723 .16193 .43963 .1527 Mtetra
.43963 .1527 .44723 .16193 .46038 .15694 .45283 .14766 Mtetra
.45283 .14766 .46038 .15694 .4736 .15192 .46609 .14261 Mtetra
.46609 .14261 .4736 .15192 .48689 .14689 .47942 .13752 Mtetra
.47942 .13752 .48689 .14689 .50024 .14183 .49281 .13242 Mtetra
.49281 .13242 .50024 .14183 .51366 .13674 .50627 .12728 Mtetra
.50627 .12728 .51366 .13674 .52714 .13163 .5198 .12212 Mtetra
.5198 .12212 .52714 .13163 .54069 .12649 .53339 .11694 Mtetra
.53339 .11694 .54069 .12649 .5543 .12133 .54705 .11173 Mtetra
.54705 .11173 .5543 .12133 .56798 .11614 .56078 .1065 Mtetra
.56078 .1065 .56798 .11614 .58173 .11093 .57457 .10123 Mtetra
.57457 .10123 .58173 .11093 .59555 .10569 .58844 .09595 Mtetra
.58844 .09595 .59555 .10569 .60944 .10042 .60237 .09063 Mtetra
.60237 .09063 .60944 .10042 .6234 .09513 .61637 .08529 Mtetra
.61637 .08529 .6234 .09513 .63742 .08981 .63045 .07992 Mtetra
.63045 .07992 .63742 .08981 .65152 .08447 .64459 .07453 Mtetra
.64459 .07453 .65152 .08447 .66569 .0791 .65881 .06911 Mtetra
.65881 .06911 .66569 .0791 .67993 .0737 .6731 .06366 Mtetra
.6731 .06366 .67993 .0737 .69424 .06827 .68746 .05818 Mtetra
.68746 .05818 .69424 .06827 .70863 .06282 .7019 .05267 Mtetra
.7019 .05267 .70863 .06282 .72309 .05734 .71641 .04714 Mtetra
.618 .642 .852 r
.06178 .2921 .06994 .30393 .08104 .30241 .07313 .28883 Mtetra
.628 .617 .82 r
.07313 .28883 .08104 .30241 .09228 .30031 .08461 .28501 Mtetra
.637 .596 .792 r
.08461 .28501 .09228 .30031 .10373 .29718 .09625 .2805 Mtetra
.644 .584 .772 r
.09625 .2805 .10373 .29718 .11541 .29273 .10803 .27532 Mtetra
.65 .579 .762 r
.10803 .27532 .11541 .29273 .12732 .28697 .11992 .26962 Mtetra
.655 .583 .762 r
.11992 .26962 .12732 .28697 .13939 .28018 .13189 .26364 Mtetra
.659 .594 .771 r
.13189 .26364 .13939 .28018 .15156 .27283 .1439 .25764 Mtetra
.663 .613 .788 r
.1439 .25764 .15156 .27283 .16378 .26542 .15593 .25181 Mtetra
.666 .636 .811 r
.15593 .25181 .16378 .26542 .17598 .25835 .16798 .24624 Mtetra
.667 .663 .836 r
.16798 .24624 .17598 .25835 .18817 .2518 .18004 .24094 Mtetra
.668 .687 .859 r
.18004 .24094 .18817 .2518 .20033 .24582 .19213 .23589 Mtetra
.667 .708 .878 r
.19213 .23589 .20033 .24582 .21248 .24032 .20424 .23099 Mtetra
.666 .722 .891 r
.20424 .23099 .21248 .24032 .22465 .23518 .21641 .2262 Mtetra
.665 .732 .899 r
.21641 .2262 .22465 .23518 .23685 .23026 .22862 .22145 Mtetra
.664 .737 .904 r
.22862 .22145 .23685 .23026 .24909 .22546 .24088 .21672 Mtetra
.664 .739 .906 r
.24088 .21672 .24909 .22546 .26138 .22072 .2532 .21198 Mtetra
.664 .74 .907 r
.2532 .21198 .26138 .22072 .27372 .21599 .26558 .20723 Mtetra
.664 .741 .908 r
.26558 .20723 .27372 .21599 .28613 .21125 .27801 .20245 Mtetra
.27801 .20245 .28613 .21125 .29858 .20649 .29051 .19766 Mtetra
.29051 .19766 .29858 .20649 .3111 .20172 .30306 .19284 Mtetra
.30306 .19284 .3111 .20172 .32368 .19692 .31567 .188 Mtetra
.31567 .188 .32368 .19692 .33632 .1921 .32835 .18314 Mtetra
.32835 .18314 .33632 .1921 .34902 .18726 .34108 .17826 Mtetra
.34108 .17826 .34902 .18726 .36178 .18239 .35388 .17335 Mtetra
.35388 .17335 .36178 .18239 .3746 .1775 .36674 .16841 Mtetra
.36674 .16841 .3746 .1775 .38748 .17259 .37966 .16346 Mtetra
.37966 .16346 .38748 .17259 .40042 .16765 .39264 .15847 Mtetra
.39264 .15847 .40042 .16765 .41343 .16269 .40569 .15347 Mtetra
.40569 .15347 .41343 .16269 .4265 .15771 .4188 .14844 Mtetra
.4188 .14844 .4265 .15771 .43963 .1527 .43197 .14339 Mtetra
.43197 .14339 .43963 .1527 .45283 .14766 .44521 .13831 Mtetra
.44521 .13831 .45283 .14766 .46609 .14261 .45852 .1332 Mtetra
.45852 .1332 .46609 .14261 .47942 .13752 .47188 .12807 Mtetra
.47188 .12807 .47942 .13752 .49281 .13242 .48532 .12292 Mtetra
.48532 .12292 .49281 .13242 .50627 .12728 .49882 .11774 Mtetra
.49882 .11774 .50627 .12728 .5198 .12212 .51239 .11253 Mtetra
.51239 .11253 .5198 .12212 .53339 .11694 .52603 .1073 Mtetra
.52603 .1073 .53339 .11694 .54705 .11173 .53973 .10205 Mtetra
.53973 .10205 .54705 .11173 .56078 .1065 .5535 .09676 Mtetra
.5535 .09676 .56078 .1065 .57457 .10123 .56734 .09145 Mtetra
.56734 .09145 .57457 .10123 .58844 .09595 .58125 .08612 Mtetra
.58125 .08612 .58844 .09595 .60237 .09063 .59523 .08075 Mtetra
.59523 .08075 .60237 .09063 .61637 .08529 .60929 .07536 Mtetra
.60929 .07536 .61637 .08529 .63045 .07992 .62341 .06994 Mtetra
.62341 .06994 .63045 .07992 .64459 .07453 .6376 .0645 Mtetra
.6376 .0645 .64459 .07453 .65881 .06911 .65187 .05902 Mtetra
.65187 .05902 .65881 .06911 .6731 .06366 .66621 .05352 Mtetra
.66621 .05352 .6731 .06366 .68746 .05818 .68062 .04799 Mtetra
.68062 .04799 .68746 .05818 .7019 .05267 .6951 .04244 Mtetra
.6951 .04244 .7019 .05267 .71641 .04714 .70966 .03685 Mtetra
.645 .664 .854 r
.05348 .28077 .06178 .2921 .07313 .28883 .06497 .27659 Mtetra
.65 .649 .836 r
.06497 .27659 .07313 .28883 .08461 .28501 .07657 .27207 Mtetra
.654 .64 .823 r
.07657 .27207 .08461 .28501 .09625 .2805 .08826 .26723 Mtetra
.658 .637 .817 r
.08826 .26723 .09625 .2805 .10803 .27532 .10003 .26214 Mtetra
.661 .64 .818 r
.10003 .26214 .10803 .27532 .11992 .26962 .11187 .25691 Mtetra
.664 .649 .826 r
.11187 .25691 .11992 .26962 .13189 .26364 .12376 .25167 Mtetra
.665 .664 .838 r
.12376 .25167 .13189 .26364 .1439 .25764 .13568 .24651 Mtetra
.666 .681 .854 r
.13568 .24651 .1439 .25764 .15593 .25181 .14764 .24145 Mtetra
.667 .698 .869 r
.14764 .24145 .15593 .25181 .16798 .24624 .15963 .23652 Mtetra
.666 .712 .883 r
.15963 .23652 .16798 .24624 .18004 .24094 .17167 .23169 Mtetra
.665 .724 .893 r
.17167 .23169 .18004 .24094 .19213 .23589 .18375 .22691 Mtetra
.664 .732 .9 r
.18375 .22691 .19213 .23589 .20424 .23099 .19587 .22217 Mtetra
.664 .736 .904 r
.19587 .22217 .20424 .23099 .21641 .2262 .20806 .21744 Mtetra
.664 .739 .906 r
.20806 .21744 .21641 .2262 .22862 .22145 .22029 .21271 Mtetra
.664 .74 .907 r
.22029 .21271 .22862 .22145 .24088 .21672 .23259 .20796 Mtetra
.664 .741 .908 r
.23259 .20796 .24088 .21672 .2532 .21198 .24494 .20319 Mtetra
.24494 .20319 .2532 .21198 .26558 .20723 .25735 .1984 Mtetra
.25735 .1984 .26558 .20723 .27801 .20245 .26982 .19359 Mtetra
.26982 .19359 .27801 .20245 .29051 .19766 .28235 .18875 Mtetra
.28235 .18875 .29051 .19766 .30306 .19284 .29494 .18389 Mtetra
.29494 .18389 .30306 .19284 .31567 .188 .30759 .17901 Mtetra
.30759 .17901 .31567 .188 .32835 .18314 .32031 .1741 Mtetra
.32031 .1741 .32835 .18314 .34108 .17826 .33308 .16917 Mtetra
.33308 .16917 .34108 .17826 .35388 .17335 .34591 .16422 Mtetra
.34591 .16422 .35388 .17335 .36674 .16841 .35881 .15924 Mtetra
.35881 .15924 .36674 .16841 .37966 .16346 .37177 .15424 Mtetra
.37177 .15424 .37966 .16346 .39264 .15847 .38479 .14922 Mtetra
.38479 .14922 .39264 .15847 .40569 .15347 .39788 .14417 Mtetra
.39788 .14417 .40569 .15347 .4188 .14844 .41103 .13909 Mtetra
.41103 .13909 .4188 .14844 .43197 .14339 .42424 .13399 Mtetra
.42424 .13399 .43197 .14339 .44521 .13831 .43752 .12886 Mtetra
.43752 .12886 .44521 .13831 .45852 .1332 .45087 .12371 Mtetra
.45087 .12371 .45852 .1332 .47188 .12807 .46428 .11854 Mtetra
.46428 .11854 .47188 .12807 .48532 .12292 .47776 .11334 Mtetra
.47776 .11334 .48532 .12292 .49882 .11774 .4913 .10811 Mtetra
.4913 .10811 .49882 .11774 .51239 .11253 .50491 .10286 Mtetra
.50491 .10286 .51239 .11253 .52603 .1073 .51859 .09758 Mtetra
.51859 .09758 .52603 .1073 .53973 .10205 .53234 .09227 Mtetra
.53234 .09227 .53973 .10205 .5535 .09676 .54616 .08694 Mtetra
.54616 .08694 .5535 .09676 .56734 .09145 .56005 .08158 Mtetra
.56005 .08158 .56734 .09145 .58125 .08612 .574 .07619 Mtetra
.574 .07619 .58125 .08612 .59523 .08075 .58803 .07078 Mtetra
.58803 .07078 .59523 .08075 .60929 .07536 .60213 .06534 Mtetra
.60213 .06534 .60929 .07536 .62341 .06994 .6163 .05987 Mtetra
.6163 .05987 .62341 .06994 .6376 .0645 .63054 .05437 Mtetra
.63054 .05437 .6376 .0645 .65187 .05902 .64486 .04885 Mtetra
.64486 .04885 .65187 .05902 .66621 .05352 .65925 .04329 Mtetra
.65925 .04329 .66621 .05352 .68062 .04799 .67371 .03771 Mtetra
.67371 .03771 .68062 .04799 .6951 .04244 .68825 .0321 Mtetra
.68825 .0321 .6951 .04244 .70966 .03685 .70286 .02646 Mtetra
.658 .69 .869 r
.04496 .27046 .05348 .28077 .06497 .27659 .05652 .26594 Mtetra
.66 .685 .862 r
.05652 .26594 .06497 .27659 .07657 .27207 .06815 .26127 Mtetra
.662 .683 .86 r
.06815 .26127 .07657 .27207 .08826 .26723 .07985 .25649 Mtetra
.664 .686 .861 r
.07985 .25649 .08826 .26723 .10003 .26214 .09161 .25163 Mtetra
.665 .692 .866 r
.09161 .25163 .10003 .26214 .11187 .25691 .10341 .24677 Mtetra
.665 .701 .873 r
.10341 .24677 .11187 .25691 .12376 .25167 .11527 .24192 Mtetra
.666 .711 .881 r
.11527 .24192 .12376 .25167 .13568 .24651 .12717 .23712 Mtetra
.665 .72 .89 r
.12717 .23712 .13568 .24651 .14764 .24145 .13912 .23235 Mtetra
.665 .727 .896 r
.13912 .23235 .14764 .24145 .15963 .23652 .15111 .22761 Mtetra
.664 .733 .901 r
.15111 .22761 .15963 .23652 .17167 .23169 .16316 .22289 Mtetra
.664 .737 .904 r
.16316 .22289 .17167 .23169 .18375 .22691 .17526 .21817 Mtetra
.664 .739 .906 r
.17526 .21817 .18375 .22691 .19587 .22217 .18741 .21344 Mtetra
.664 .74 .907 r
.18741 .21344 .19587 .22217 .20806 .21744 .19963 .20869 Mtetra
.664 .741 .908 r
.19963 .20869 .20806 .21744 .22029 .21271 .2119 .20392 Mtetra
.2119 .20392 .22029 .21271 .23259 .20796 .22423 .19914 Mtetra
.22423 .19914 .23259 .20796 .24494 .20319 .23661 .19433 Mtetra
.23661 .19433 .24494 .20319 .25735 .1984 .24906 .1895 Mtetra
.24906 .1895 .25735 .1984 .26982 .19359 .26157 .18464 Mtetra
.26157 .18464 .26982 .19359 .28235 .18875 .27413 .17976 Mtetra
.27413 .17976 .28235 .18875 .29494 .18389 .28676 .17486 Mtetra
.28676 .17486 .29494 .18389 .30759 .17901 .29944 .16993 Mtetra
.29944 .16993 .30759 .17901 .32031 .1741 .31219 .16498 Mtetra
.31219 .16498 .32031 .1741 .33308 .16917 .325 .16001 Mtetra
.325 .16001 .33308 .16917 .34591 .16422 .33788 .15501 Mtetra
.33788 .15501 .34591 .16422 .35881 .15924 .35081 .14999 Mtetra
.35081 .14999 .35881 .15924 .37177 .15424 .36381 .14494 Mtetra
.36381 .14494 .37177 .15424 .38479 .14922 .37687 .13987 Mtetra
.37687 .13987 .38479 .14922 .39788 .14417 .39 .13478 Mtetra
.39 .13478 .39788 .14417 .41103 .13909 .40319 .12965 Mtetra
.40319 .12965 .41103 .13909 .42424 .13399 .41644 .12451 Mtetra
.41644 .12451 .42424 .13399 .43752 .12886 .42976 .11934 Mtetra
.42976 .11934 .43752 .12886 .45087 .12371 .44315 .11414 Mtetra
.44315 .11414 .45087 .12371 .46428 .11854 .4566 .10892 Mtetra
.4566 .10892 .46428 .11854 .47776 .11334 .47013 .10367 Mtetra
.47013 .10367 .47776 .11334 .4913 .10811 .48371 .09839 Mtetra
.48371 .09839 .4913 .10811 .50491 .10286 .49737 .09309 Mtetra
.49737 .09309 .50491 .10286 .51859 .09758 .51109 .08776 Mtetra
.51109 .08776 .51859 .09758 .53234 .09227 .52489 .0824 Mtetra
.52489 .0824 .53234 .09227 .54616 .08694 .53875 .07702 Mtetra
.53875 .07702 .54616 .08694 .56005 .08158 .55268 .07161 Mtetra
.55268 .07161 .56005 .08158 .574 .07619 .56669 .06618 Mtetra
.56669 .06618 .574 .07619 .58803 .07078 .58076 .06071 Mtetra
.58076 .06071 .58803 .07078 .60213 .06534 .59491 .05522 Mtetra
.59491 .05522 .60213 .06534 .6163 .05987 .60913 .0497 Mtetra
.60913 .0497 .6163 .05987 .63054 .05437 .62342 .04415 Mtetra
.62342 .04415 .63054 .05437 .64486 .04885 .63778 .03857 Mtetra
.63778 .03857 .64486 .04885 .65925 .04329 .65222 .03297 Mtetra
.65222 .03297 .65925 .04329 .67371 .03771 .66673 .02733 Mtetra
.66673 .02733 .67371 .03771 .68825 .0321 .68132 .02167 Mtetra
.68132 .02167 .68825 .0321 .70286 .02646 .69599 .01598 Mtetra
.662 .714 .886 r
.03622 .26105 .04496 .27046 .05652 .26594 .04781 .25646 Mtetra
.663 .713 .885 r
.04781 .25646 .05652 .26594 .06815 .26127 .05946 .25181 Mtetra
.664 .715 .886 r
.05946 .25181 .06815 .26127 .07985 .25649 .07117 .24713 Mtetra
.664 .718 .889 r
.07117 .24713 .07985 .25649 .09161 .25163 .08292 .24242 Mtetra
.665 .723 .892 r
.08292 .24242 .09161 .25163 .10341 .24677 .09473 .23771 Mtetra
.664 .727 .896 r
.09473 .23771 .10341 .24677 .11527 .24192 .10659 .23301 Mtetra
.664 .732 .9 r
.10659 .23301 .11527 .24192 .12717 .23712 .1185 .22831 Mtetra
.664 .735 .903 r
.1185 .22831 .12717 .23712 .13912 .23235 .13047 .2236 Mtetra
.664 .738 .905 r
.13047 .2236 .13912 .23235 .15111 .22761 .14249 .21889 Mtetra
.664 .739 .906 r
.14249 .21889 .15111 .22761 .16316 .22289 .15456 .21416 Mtetra
.664 .74 .907 r
.15456 .21416 .16316 .22289 .17526 .21817 .16669 .20942 Mtetra
.664 .741 .908 r
.16669 .20942 .17526 .21817 .18741 .21344 .17888 .20466 Mtetra
.17888 .20466 .18741 .21344 .19963 .20869 .19112 .19988 Mtetra
.19112 .19988 .19963 .20869 .2119 .20392 .20343 .19507 Mtetra
.20343 .19507 .2119 .20392 .22423 .19914 .21579 .19024 Mtetra
.21579 .19024 .22423 .19914 .23661 .19433 .22821 .18539 Mtetra
.22821 .18539 .23661 .19433 .24906 .1895 .24069 .18051 Mtetra
.24069 .18051 .24906 .1895 .26157 .18464 .25323 .17561 Mtetra
.25323 .17561 .26157 .18464 .27413 .17976 .26583 .17069 Mtetra
.26583 .17069 .27413 .17976 .28676 .17486 .2785 .16575 Mtetra
.2785 .16575 .28676 .17486 .29944 .16993 .29122 .16078 Mtetra
.29122 .16078 .29944 .16993 .31219 .16498 .30401 .15578 Mtetra
.30401 .15578 .31219 .16498 .325 .16001 .31685 .15076 Mtetra
.31685 .15076 .325 .16001 .33788 .15501 .32977 .14572 Mtetra
.32977 .14572 .33788 .15501 .35081 .14999 .34274 .14065 Mtetra
.34274 .14065 .35081 .14999 .36381 .14494 .35578 .13556 Mtetra
.35578 .13556 .36381 .14494 .37687 .13987 .36888 .13044 Mtetra
.36888 .13044 .37687 .13987 .39 .13478 .38204 .1253 Mtetra
.38204 .1253 .39 .13478 .40319 .12965 .39527 .12013 Mtetra
.39527 .12013 .40319 .12965 .41644 .12451 .40857 .11494 Mtetra
.40857 .11494 .41644 .12451 .42976 .11934 .42193 .10972 Mtetra
.42193 .10972 .42976 .11934 .44315 .11414 .43536 .10448 Mtetra
.43536 .10448 .44315 .11414 .4566 .10892 .44886 .0992 Mtetra
.44886 .0992 .4566 .10892 .47013 .10367 .46242 .09391 Mtetra
.46242 .09391 .47013 .10367 .48371 .09839 .47605 .08858 Mtetra
.47605 .08858 .48371 .09839 .49737 .09309 .48975 .08323 Mtetra
.48975 .08323 .49737 .09309 .51109 .08776 .50352 .07785 Mtetra
.50352 .07785 .51109 .08776 .52489 .0824 .51736 .07245 Mtetra
.51736 .07245 .52489 .0824 .53875 .07702 .53127 .06701 Mtetra
.53127 .06701 .53875 .07702 .55268 .07161 .54525 .06155 Mtetra
.54525 .06155 .55268 .07161 .56669 .06618 .5593 .05607 Mtetra
.5593 .05607 .56669 .06618 .58076 .06071 .57342 .05055 Mtetra
.57342 .05055 .58076 .06071 .59491 .05522 .58762 .04501 Mtetra
.58762 .04501 .59491 .05522 .60913 .0497 .60188 .03943 Mtetra
.60188 .03943 .60913 .0497 .62342 .04415 .61623 .03383 Mtetra
.61623 .03383 .62342 .04415 .63778 .03857 .63064 .0282 Mtetra
.63064 .0282 .63778 .03857 .65222 .03297 .64513 .02254 Mtetra
.64513 .02254 .65222 .03297 .66673 .02733 .65969 .01685 Mtetra
.65969 .01685 .66673 .02733 .68132 .02167 .67433 .01113 Mtetra
.67433 .01113 .68132 .02167 .69599 .01598 .68905 .00539 Mtetra
0 g
.68874 0 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.68874 0 m
.03716 .25514 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 0.522676 0.477324 0.97619 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.49505 0.5 0.49505 [
[ 0 0 -0.125 0 ]
[ 0 0 -0.125 0 ]
[ 0 1 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
0 0 m
1 0 L
s
0 0 m
0 1 L
s
0 1 m
1 1 L
s
1 0 m
1 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
1 .5 0 r
.015 w
.03175 .1355 Mdot
.03435 .12523 Mdot
.11137 .12765 Mdot
.14107 .18841 Mdot
.16218 .24538 Mdot
.17294 .21053 Mdot
.18267 .18577 Mdot
.18434 .1304 Mdot
.18553 .30956 Mdot
.20401 .239 Mdot
.21247 .27571 Mdot
.21687 .20845 Mdot
.22376 .2799 Mdot
.22832 .27485 Mdot
.29063 .20974 Mdot
.29686 .25079 Mdot
.30487 .22936 Mdot
.30683 .34623 Mdot
.32055 .20902 Mdot
.32574 .21979 Mdot
.34472 .28521 Mdot
.35998 .36393 Mdot
.36335 .24976 Mdot
.3794 .36608 Mdot
.42386 .66992 Mdot
.44391 .74519 Mdot
.45059 .34198 Mdot
.47208 .67586 Mdot
.47436 .71381 Mdot
.49778 .59825 Mdot
.50874 .91643 Mdot
.51516 .76219 Mdot
.53655 .61374 Mdot
.56563 .75219 Mdot
.59189 .65665 Mdot
.59581 .61604 Mdot
.59923 .6556 Mdot
.60292 .68499 Mdot
.62656 .67779 Mdot
.63555 .72451 Mdot
.63919 .652 Mdot
.64169 .6004 Mdot
.64246 .58611 Mdot
.64496 .54267 Mdot
.64608 .77288 Mdot
.65077 .64308 Mdot
.66065 .57816 Mdot
.67474 .59169 Mdot
.69296 .563 Mdot
.72815 .65902 Mdot
.73169 .58879 Mdot
.74669 .61318 Mdot
.74821 .65474 Mdot
.75963 .63781 Mdot
.79673 .57809 Mdot
.80925 .55852 Mdot
.81525 .58444 Mdot
.83417 .62985 Mdot
.83598 .55526 Mdot
.91595 .49319 Mdot
0 0 1 r
.005 w
.16128 .17044 m
.18734 .17269 L
.21339 .17909 L
.2345 .18734 L
.23945 .19126 L
.2655 .20415 L
.27874 .21339 L
.29156 .22295 L
.31204 .23945 L
.31761 .24532 L
.33549 .2655 L
.34367 .28341 L
.34499 .29156 L
.34367 .29798 L
.31761 .3104 L
.29156 .30711 L
.2655 .30014 L
.24507 .29156 L
.23945 .28747 L
.21339 .27402 L
.20155 .2655 L
.18734 .25472 L
.16884 .23945 L
.16128 .2313 L
.14618 .21339 L
.13806 .18734 L
.16128 .17044 L
s
.65633 .57701 m
.68239 .56842 L
.70844 .56313 L
.7345 .56168 L
.76055 .5752 L
.76359 .57817 L
.76859 .60422 L
.76055 .62333 L
.75627 .63028 L
.7345 .65485 L
.73298 .65633 L
.70844 .6775 L
.69922 .68239 L
.68239 .69294 L
.65633 .70579 L
.64983 .70844 L
.63028 .71539 L
.60422 .72268 L
.57817 .72651 L
.55211 .7214 L
.53145 .70844 L
.52926 .68239 L
.54239 .65633 L
.55211 .63983 L
.56625 .63028 L
.57817 .6193 L
.60119 .60422 L
.60422 .60227 L
.63028 .58726 L
.65315 .57817 L
.65633 .57701 L
s
0 g
.03 w
.24141 .24033 Mdot
.64872 .64417 Mdot
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.522676 0.522676 0.97619 0.97619 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.49505 0.5 0.49505 [
[ 0 0 -0.125 0 ]
[ 0 0 -0.125 0 ]
[ 0 1 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
0 0 m
1 0 L
s
0 0 m
0 1 L
s
0 1 m
1 1 L
s
1 0 m
1 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
1 .5 0 r
.015 w
.03175 .1355 Mdot
.03435 .12523 Mdot
.11137 .12765 Mdot
.14107 .18841 Mdot
.16218 .24538 Mdot
.17294 .21053 Mdot
.18267 .18577 Mdot
.18434 .1304 Mdot
.18553 .30956 Mdot
.20401 .239 Mdot
.21247 .27571 Mdot
.21687 .20845 Mdot
.22376 .2799 Mdot
.22832 .27485 Mdot
.29063 .20974 Mdot
.29686 .25079 Mdot
.30487 .22936 Mdot
.30683 .34623 Mdot
.32055 .20902 Mdot
.32574 .21979 Mdot
.34472 .28521 Mdot
.35998 .36393 Mdot
.36335 .24976 Mdot
.3794 .36608 Mdot
.42386 .66992 Mdot
.44391 .74519 Mdot
.45059 .34198 Mdot
.47208 .67586 Mdot
.47436 .71381 Mdot
.49778 .59825 Mdot
.50874 .91643 Mdot
.51516 .76219 Mdot
.53655 .61374 Mdot
.56563 .75219 Mdot
.59189 .65665 Mdot
.59581 .61604 Mdot
.59923 .6556 Mdot
.60292 .68499 Mdot
.62656 .67779 Mdot
.63555 .72451 Mdot
.63919 .652 Mdot
.64169 .6004 Mdot
.64246 .58611 Mdot
.64496 .54267 Mdot
.64608 .77288 Mdot
.65077 .64308 Mdot
.66065 .57816 Mdot
.67474 .59169 Mdot
.69296 .563 Mdot
.72815 .65902 Mdot
.73169 .58879 Mdot
.74669 .61318 Mdot
.74821 .65474 Mdot
.75963 .63781 Mdot
.79673 .57809 Mdot
.80925 .55852 Mdot
.81525 .58444 Mdot
.83417 .62985 Mdot
.83598 .55526 Mdot
.91595 .49319 Mdot
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{400, 400},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40006@0001T2000`400?l00000o`00003ooooooonA
ooooo`00oooooonAooooo`00oooooonAooooo`00oooooonAooooo`00oooooonAooooo`00oooooonA
ooooo`00oooooonAooooo`00oooooonAooooo`00oooooonAooooo`00oooooonAooooo`002Ooooonf
00000=7ooooo0009ooooo`0300000?oooooooooo0;;ooooo00<00000ooooooooool0coooool000Wo
oooo00<00000ooooooooool0/_ooool00`00003oooooooooo`3?ooooo`002Oooool00`00003ooooo
ooooo`2booooo`0300000?oooooooooo0<oooooo0009ooooo`0300000?oooooooooo0;;ooooo00<0
0000ooooooooool0coooool000Wooooo00@00000oooooooooooooooo[@000004ooooo`0300000?oo
oooooooo0<oooooo0009ooooo`0400000?ooooooooooooooojd000001?ooool00`00003ooooooooo
o`3?ooooo`002Oooool01000003ooooooooooooooon]000000Cooooo00<00000ooooooooool0cooo
ool000Wooooo00@00000oooooooooooooooo[@000004ooooo`0300000?oooooooooo0<oooooo0009
ooooo`0400000?ooooooooooooooojd000001?ooool00`00003oooooooooo`3?ooooo`002Oooool0
1000003ooooooooooooooon]000000Cooooo00<00000ooooooooool0coooool000Wooooo00@00000
oooooooooooooooo[@000004ooooo`0300000?oooooooooo0<oooooo0009ooooo`0400000?oooooo
ooooooooojd000001?ooool00`00003oooooooooo`3?ooooo`002Oooool01000003ooooooooooooo
oon]000000Cooooo00<00000ooooooooool0coooool000Wooooo00@00000oooooooooooooooo[@00
0004ooooo`0300000?oooooooooo0<oooooo0009ooooo`0400000?ooooooooooooooojd000001?oo
ool00`00003oooooooooo`3?ooooo`002Oooool01000003ooooooooooooooon]000000Cooooo00<0
0000ooooooooool0coooool000Wooooo00@00000oooooooooooooooo[@000004ooooo`0300000?oo
oooooooo08_ooooo0P000012ooooo`002Oooool01000003oooooooooooooool400000003o`000000
00006ATI00`06ATI00<00000o`0000000000U`000004ooooo`0300000?oooooooooo08Sooooo0`00
00000oooool00000ooooo`11ooooo`002Oooool01000003oooooooooooooool3000001@06ATIUP00
0004ooooo`0300000?oooooooooo08Kooooo0P000003ooooo`03ojVmj00000000000047ooooo0009
ooooo`0400000?ooooooooooooooo`8000006@0I6AVB000000Cooooo00<00000ooooooooool0Pooo
ool3000000;ooooo1?nY_NP00`00003ooooo00000010ooooo`002Oooool01@00003ooooooooooooo
oooo000001d06ATIS`000004ooooo`0300000?oooooooooo083ooooo0`000002ooooo`OoZKgX00<0
0000ooooo`000000@?ooool000Wooooo00D00000ooooooooooooooooo`00000;01TI6@/000002P0I
6AV<000000Cooooo00<00000ooooooooool0O_ooool2000000?ooooo2OnY_NP01000003oZKgXoooo
o`00000oooooo`002Oooool01000003oooooooooooooool901TI6@<000002`0c<c<4000000L06ATI
R`000004ooooo`0300000?oooooooooo07_ooooo0`000002ooooo`coZKgX00D00000ojVmj?oooooo
oooo0000000nooooo`002Oooool01000003oooooooooooooool801TI6@030000000c<c<0<c<c0100
<c<c0`0000000ol000006ATI01TI6@0401TI6@80000000?o0000000000000000P`000004ooooo`03
00000?oooooooooo07Wooooo0P000003ooooo`koZKgX00D00000ojVmj?nY_NSooooo0000000noooo
o`002Oooool01000003oooooooooooooool801TI6@030000000c<c<0<c<c00D0<c<c2`00000403<c
<`<000001P0I6AV5000000Cooooo00<00000ooooooooool0M_ooool3000000;ooooo4OnY_NP01P00
003oZKgXojVmj?nY_NSooooo000003gooooo0009ooooo`0400000?ooooooooooooooo`P06ATI00<0
000003<c<`0c<c<00`0c<c<2000000/0C4a<0`00000403<c<`8000001@0I6AV4000000Cooooo00<0
0000ooooooooool0M?ooool2000000;ooooo5?nY_NP00`00003oZKgXojVmj002ojVmj00300000?oo
oooooooo03_ooooo0009ooooo`0500000?ooooooooooooooool000001P0I6AT00`000000<c<c03<c
<`0303<c<`030000001<C4`0C4a<00<0C4a<2000000304a<C0@000000P0c<c<2000000D06ATIPP00
0004ooooo`0300000?oooooooooo077ooooo0`000002oooooaKoZKgX00<00000ojVmj?nY_NP00onY
_NP00`00003oooooooooo`0jooooo`002Oooool01@00003oooooooooooooool0000000H06ATI00<0
000003<c<`0c<c<00P0c<c<00`000000C4a<04a<C00204a<C003o`0000000000IVIV00L0IVIV00Co
000000000000000000000`1<C4`200000080<c<c00?o0000000000000000100I6AT00`00003o0000
0000001m000000Cooooo00<00000ooooooooool0K_ooool3000000;ooooo6OnY_NP00`00003oZKgX
ojVmj003ojVmj003ooooo`00003ooooo03[ooooo0009ooooo`0500000?ooooooooooooooo`000000
1P0I6AT00`000000<c<c03<c<`0203<c<`030000001<C4`0C4a<0080C4a<00<0000006IVIP1VIVH0
0P1VIVH5o`0000@0IVIV0`00000204a<C08000000`0c<c<2000000@06ATIOP000004ooooo`030000
0?oooooooooo06cooooo0P000003oooooacoZKgX00<00000ojVmj?nY_NP00onY_NP00`00003ooooo
ooooo`0iooooo`002Oooool01000003oooooooooooooool2000000D06ATI00D0000003<c<`0c<c<0
<c<c0000000404a<C0040000001VIVH0IVIV06IVIP;o00001@1oOgl7o`0000<0000000@0C4a<0000
0000000000000P0c<c<2000000<06ATIO@000004ooooo`0300000?oooooooooo06Wooooo0`000002
oooooaooZKgX00<00000ojVmj?nY_NP00onY_NP00oooool00000ooooo`0iooooo`002Oooool01000
003oooooooooooooool2000000D06ATI00D0000003<c<`0c<c<0<c<c0000000304a<C0050000001V
IVH0IVIV06IVI_l000001P1oOgl4000000@0Ogmo0_l000001P1VIVH00000000000000000C4a<o`00
0080000000<0<c<co`0000000000100I6AUj000000Cooooo00<00000ooooooooool0Ioooool20000
00?ooooo8OnY_NP00`00003oZKgXojVmj004ojVmj003ooooo`00003ooooo03Sooooo0009ooooo`04
00000?ooooooooooooooo`8000001@0I6AT01@000000<c<c03<c<`0c<c<0000000<0C4a<00D00000
06IVIP1VIVH0IVIVo`00000407moO`800000102IVIT400000080Ogmo0_l0000206IVIP050000001<
C4`0C4a<04a<C00000000P0c<c<00`0000006ATI01TI6@0301TI6GP000001?ooool00`00003ooooo
ooooo`1Tooooo`<000000_oooolTojVmj00300000?nY_NSoZKgX00CoZKgX00?ooooo00000?ooool0
>?ooool000Wooooo00@00000oooooooooooooooo0`00000501TI6@050000000c<c<0<c<c03<c<`00
00000P1<C4`01@000000IVIV06IVIP1VIVKo000000<0Ogmo00@0000009VIV@2IVIT0VIVI1ol00003
0000000407moOol0003o0000o`00008000000P1<C4`20000000303<c<`000000000000@06ATIM`00
0004ooooo`0300000?oooooooooo06;ooooo0P000003ooooobKoZKgX00<00000ojVmj?nY_NP01OnY
_NP00oooool00000ooooo`0gooooo`002Oooool01000003oooooooooooooool300000003o`00000I
6AT06ATI00806ATI00D0000003<c<`0c<c<0<c<c0000000304a<C0030000001VIVKo000000<0Ogmo
00D0000009VIV@2IVIT0VIVIo`0000070;>c/`?o00000`0000000`1oOgoo000006IVIP0200000080
C4a<00<0000003<c<`0c<c<00P00000301TI6GH000001?ooool00`00003oooooooooo`1Oooooo`<0
00000_oooolYojVmj00300000?nY_NSoZKgX00KoZKgX00?ooooo00000?ooool0=_ooool000Wooooo
00@00000oooooooooooooooo1000000501TI6@050000000c<c<0<c<c03<c<`0000000P1<C4`00`00
0000IVIVo`00000207moO`050000002IVIT0VIVI09VIVOl00000102c/k<6o`0000030;>c/ol0003o
000000;o000000@0Ogmoo`000?l0003o00000P0000000`1<C4`000000000000203<c<`8000000`0I
6AUd000000Cooooo00<00000ooooooooool0GOooool2000000?ooooo:onY_NP00`00003oZKgXojVm
j007ojVmj00300000?oooooooooo03Gooooo0009ooooo`0400000?ooooooooooooooo`D00000100I
6AT01@000000<c<c03<c<`0c<c<000000080C4a<00<0000006IVI_l000000P1oOgl01@000000VIVI
09VIV@2IVIWo00000080/k>c0_l000060<c<c0;o00000P2c/k<00ol0000000000000000207moO`;o
000000<0000004a<C01<C4`00P00000203<c<`030000000I6AT06ATI00806ATILP000004ooooo`03
00000?oooooooooo05[ooooo0`000002ooooobkoZKgX00<00000ojVmj?nY_NP02?nY_NP00`00003o
ooooooooo`0dooooo`002Oooool01000003oooooooooooooool6000000@06ATI00D0000003<c<`0c
<c<0<c<c0000000204a<C0030000001VIVKo00000080Ogmo00<0000009VIVOl000000P2c/k<00ol0
0000c<c<0<c<c0030<c<c0Co000000<0c<c<o`000?l000001?l0000010000000Ogmo07moOol00003
0000000404a<C?l00000<c<c03<c<`800000100I6AU`000000Cooooo00<00000ooooooooool0Eooo
ool3000000?ooooo<?nY_NP00`00003oZKgXojVmj008ojVmj003ooooo`00003ooooo03Cooooo0009
ooooo`0400000?ooooooooooooooo`H0000000?o000001TI6@0I6AT00P0I6AT01ol00000<c<c03<c
<`0c<c?o000004a<C00000000P1VIVH01Ol00000Ogmo0000002IVIWo00000080/k>c00Co00000<c<
c03<c<`0c<c<0_l000040>KViPKo000000D0/k>co`000?l00000000007moO`02o`00000406IVI_l0
0000C4a<000000<0<c<c00<0000001TI6@0I6AT00P0I6AU_000000Cooooo00<00000ooooooooool0
EOooool2000000?ooooo<onY_NP00`00003oZKgXojVmj009ojVmj00300000?oooooooooo03?ooooo
0009ooooo`0400000?ooooooooooooooo`P00000100I6AT01P000000<c<c03<c<`000000C4a<0000
0080IVIV00Go000007moO`000000VIVIo`0000020;>c/`05o`00003<c<`0c<c<0<c<c?l000002@3V
i^H6o`0000080000001oOgl0Ogmoo`00001VIVH0000004a<C000000303<c<`050000000I6AT06ATI
01TI6Ol00000KP000004ooooo`0300000?oooooooooo05;ooooo0`000003ooooocGoZKgX00<00000
ojVmj?nY_NP02OnY_NP00oooool00000ooooo`0cooooo`002Oooool01000003oooooooooooooool8
000000D06ATI00P0000003<c<`0c<c<0000004a<C0000000IVIVo`000080Ogmo00D0000009VIVOl0
0000/k>co`0000030<c<c003o`00003Vi^H0i^KV0080i^KV1?l000030>KViP05o`00003<c<co0000
0;>c/ol000000P0000001@1oOgoo000006IVIP000000C4a<008000000P0c<c<00`0000006ATI01TI
6@0201TI6Fd000001?ooool00`00003oooooooooo`1@ooooo`8000001?oooolgojVmj00300000?nY
_NSoZKgX00[oZKgX00<00000ooooooooool0<_ooool000Wooooo00@00000oooooooooooooooo2@00
000501TI6@080000000c<c<0<c<c0000001<C4`0000006IVI_l0000207moO`0500000?l00000/k>c
0;>c/ol000000P3<c<`00ol00000i^KV0>KViP02o`0000@0oooo00oo00000>KViP3Vi^H0i^KVo`00
003<c<co00000;>c/ol00000VIVI0000001oOgoo000006IVIP0000000P1<C4`010000000<c<c03<c
<`00000501TI6F/000001?ooool00`00003oooooooooo`1=ooooo`<000000oooooljojVmj0030000
0?nY_NSoZKgX00[oZKgX00?ooooo00000?ooool0<_ooool000Wooooo00@00000oooooooooooooooo
2@0000000ol000006ATI01TI6@0201TI6@06o`0000000000<c<c03<c<ol00000C4a<0P0000001Ol0
0000Ogmoo`00002IVIWo00000080/k>c00?o00000<c<c?l000000P3Vi^H00ol00000oooo0?ooo`04
0?ooo`;o00000P3Vi^H7o`00000300000?l0003o00000080000000D0C4a<o`0000000000<c<co`00
000401TI6@03o`0000000000000006P000001?ooool00`00003oooooooooo`1;ooooo`8000001?oo
oollojVmj00300000?nY_NSoZKgX00_oZKgX00?ooooo00000?ooool0<Oooool000Wooooo00@00000
oooooooooooooooo3000000401TI6@030000000c<c<0000000<0C4a<00D00000o`00001oOgl00000
09VIV@02o`0000060;>c/ol00000c<c<o`00003Vi^Ko0000203oool2o`000080i^KV00_o00000<c<
c?l00000/k>co`00002IVIT0000007moOol00000IVIV0000000204a<C0040000000c<c<000000000
00@06ATIJ@000004ooooo`0300000?oooooooooo04Sooooo0`000003ooooocooZKgX00<00000ojVm
j?nY_NP03?nY_NP00`00003oooooooooo`0`ooooo`002Oooool01000003oooooooooooooool=0000
00@06ATI00<0000003<c<`0000000`1<C4`01000003o0000o`000000000209VIV@07o`00002c/k?o
00000<c<c?l00000i^KVo`0000090?ooo`;o000000`0i^KVo`00003<c<co00000;>c/ol00000VIVI
0000001oOgoo000006IVIP00000204a<C0040000000c<c<0<c<c000000@06ATIJ0000004ooooo`03
00000?oooooooooo04Gooooo0`000002oooood?oZKgX00<00000ojVmj?nY_NP03?nY_NP00oooool0
0000ooooo`0`ooooo`002Oooool01000003oooooooooooooool=00000003o`00000I6AT06ATI0080
6ATI00Co000003<c<`00003o00000P1<C4`030000000IVIVo`000000003o000009VIVOl00000/k>c
o`00003<c<co00000>KViP;o00002@3oool03Ol00000i^KVo`00003<c<co00000;>c/ol00000VIVI
0000001oOgoo000006IVIP0000000P1<C4`01?l00000<c<c03<c<ol0000401TI6@03o`0000000000
000006@000001?ooool00`00003oooooooooo`13ooooo`8000000_oooom6ojVmj00300000?nY_NSo
ZKgX00goZKgX00?ooooo00000?ooool0;oooool000Wooooo00@00000oooooooooooooooo3`000003
01TI6@090000000c<c<0<c<c03<c<`000000C4a<o`00001VIVKo00000080Ogmo00D0000009VIVOl0
003o00000<c<c002o`000080i^KV0_l000070?ooo`03o`00003Vi^Ko00000080c<c<00Co00000;>c
/ol0000000000P1oOgl01Ol00000IVIV0000001<C4`0000000<0<c<c00<0000001TI6@0I6AT00P0I
6AUV000000Cooooo00<00000ooooooooool0@?ooool3000000;oooooB?nY_NP00`00003oZKgXojVm
j00=ojVmj003ooooo`00003ooooo02oooooo0009ooooo`0400000?oooooooooooooooa0000000`0I
6AT020000000<c<c03<c<`0c<c<0000004a<C0000000IVIV0_l000000`1oOgl0000009VIV@02o`00
0080c<c<0_l000020>KViP03o`00003oool0oooo00@0oooo00Ko00000>KViP3Vi^Ko00000<c<c?l0
00020;>c/`09o`0000000000Ogmo07moOol00000IVIV0000001<C4`0000000<0<c<c00<0000001TI
6@0I6AT00P0I6AUU000000Cooooo00<00000ooooooooool0?_ooool2000000?oooooB_nY_NP00`00
003oZKgXojVmj00>ojVmj003ooooo`00003ooooo02kooooo0009ooooo`0400000?oooooooooooooo
oa4000000`0I6AT200000080<c<c00<0000004a<C00000000P1VIVH01?l00000Ogmo0000002IVIT3
o`000080c<c<00?o00000>KViP3Vi^H00_l000050?ooo`0<o`00003Vi^H0i^KVo`00003<c<co0000
0;>c/ol00000VIVI0000001oOgoo00000P1VIVH00ol00000C4a<0000000303<c<`030000000I6AT0
6ATI00806ATII0000004ooooo`0300000?oooooooooo03_ooooo0`000002ooooodgoZKgX00<00000
ojVmj?nY_NP03OnY_NP2ojVmi`03ooooo`00003ooooo02gooooo0009ooooo`0400000?oooooooooo
oooooa800000100I6AT20000000603<c<ol00000000000000?l0000000000ol000000`00003o0000
o`000002o`0000030<c<c?l0003o00000080i^KV1_l000030>KViP08o`00003<c<co00000;>c/ol0
0000VIVIo`0000000002o`00000506IVIP000000C4a<o`00000000000P0c<c<00`0000006ATI01TI
6@0201TI6@03o`00000000000000060000001?ooool00`00003oooooooooo`0iooooo`8000000ooo
oom?ojVmj00300000?nY_NSoZKgX00SoZKgX1_nY_NL2ojVli`0300000?oooooooooo02cooooo0009
ooooo`0400000?oooooooooooooooa<000001@0I6AT20000000803<c<`000000000004a<C0000000
IVIVo`00001oOgl2000000Co000000<0c<c<o`000?l000002@3Vi^H01Ol00000c<c<o`00002c/k?o
00000080VIVI00D0000007moO`1oOgoo00000000000204a<C0040000000c<c<0<c<c000000D06ATI
HP000004ooooo`0300000?oooooooooo03Kooooo0`000003oooooe7oZKgX00<00000ojVmj?nY_NP0
1_nY_NP6ojVmi`GoZKcW00<00000ooooooooool0:oooool000Wooooo00@00000oooooooooooooooo
5000000601TI6@050000000c<c<0<c<c0000001<C4`00P0000001Ol00000Ogmo07moO`000000VIVI
00?o00000P3<c<`2o`0000H0i^KV00Oo00000<c<c03<c<`0c<c<o`00002c/k?o00000080VIVI00D0
000007moOol00000IVIV0000000204a<C0040000000c<c<0<c<c000000D06ATIH@000004ooooo`03
00000?oooooooooo03?ooooo0`000004oooooe?oZKgX00<00000ojVmj?nY_NP00onY_NP6ojVmi`Oo
ZKcW00?oZ[_V00000?ooool0;?ooool000Wooooo00@00000oooooooooooooooo500000000ol00000
00000000000401TI6@040000000c<c<0<c<c00000080C4a<00L00000o`000?l0003o000000000?l0
0000000000_o00000`3<c<`2o`000080/k>c00?o000009VIV@0000000P1oOgl00ol00000IVIVo`00
000204a<C004o`00000c<c<0<c<c000000D06ATI00?o0000000000000000G@000004ooooo`030000
0?oooooooooo037ooooo0P000004oooooeOoZKgX00<00000ojVmj?nY_NP01_nY_NL6ojVli`03ojVk
i_nZ^nKoZ[_V00;oZ[_V00<00000ooooooooool0:_ooool000Wooooo00@00000oooooooooooooooo
6000000301TI6@0;o`0000000000<c<c03<c<ol00000000004a<C?l00000000006IVI_l000000P1o
Ogl00`00003o0000o`0000020;>c/`?o00001@3<c<`00ol00000/k>c0;>c/`020;>c/`03o`00002I
VIT000000080Ogmo00Co000006IVIP1VIVH000000P1<C4`010000000<c<c03<c<`00000401TI6F00
00001?ooool00`00003oooooooooo`0^ooooo`<000000_oooomKojVmj00300000?nY_NOoZKgW00Co
ZKgW1_nY_>L2ojVjiP;oZK_V0_nZ^nH2ojZji@0300000?oooooooooo02Wooooo0009ooooo`040000
0?oooooooooooooooaT00000100I6AT200000080<c<c00<0000004a<C01<C4`00P000002o`000003
07moO`000000000000;o00000`2c/k<5o`0000D0/k>c00?o000009VIV@0000000P1oOgl01?l00000
IVIV06IVIP00000204a<C0050000000c<c<0<c<c03<c<`000000100I6AUO000000Cooooo00<00000
ooooooooool0;?ooool2000000?oooooFonY_NP2ojVmi`0400000?nY_NOoZKgWojVmi`KoZKcW0_nY
^^D2ojVjiP04ojZii?nZ^NGoZ[WUojZii@;oZ[[U00?oZkWT00000?ooool0:_ooool000Wooooo00@0
0000oooooooooooooooo6P00000501TI6@040000000c<c<0<c<c000000<0C4a<00<0000006IVI_l0
00000P1oOgl2000000?o00002@2c/k<01Ol00000VIVI09VIV@2IVIT000000080Ogmo00Co000006IV
IP1VIVH000000P1<C4`010000000<c<c03<c<`00000401TI6El000001?ooool00`00003ooooooooo
o`0Yooooo`<000000_oooomNojVmj0;oZKgW00<00000ojVmionY_>L00_nY_>L6ojVji@03ojVhhonZ
^NCoZ[WT00;oZ[WT00?oZ[WUoj^hhon[^N@00on[^N@00`00003oooooooooo`0Xooooo`002Oooool0
1000003ooooooooooooooolJ00000003o`0000000000000000<06ATI00Co00000000000c<c?o0000
0P0000000`1<C4co000000000003o`00000407moO`0000000000000000Oo000000<0/k>co`000?l0
00000`2IVIT010000000Ogmo07moOol0000206IVIP040000001<C4`0C4a<000000<0<c<c00<00000
01TI6@0I6AT00P0I6AT00`00003o00000000001K000000Cooooo00<00000ooooooooool09oooool2
000000?ooooo4?nY_NP00onY_NOoZKgXojVmj01<ojVmj0?oZKcW00<00000ojVlionY_>L01_nY^^D0
1?nY]n?oZKSSojVhhonY^><2ojZii004oj^fhOn[^>?oZkSSoj^hh`;oZkWT00?o[;WSooooo`000000
:Oooool000Wooooo00@00000oooooooooooooooo7P00000401TI6@8000000P0c<c<20000000404a<
C0000000000006IVIP?o000000@0Ogmo0000000000000000102IVIT00ol00000VIVI09VIV@0209VI
V@050000001oOgl0Ogmo07moOol000000P1VIVH010000000C4a<04a<C000000303<c<`030000000I
6AT06ATI00<06ATIG@000004ooooo`0300000?oooooooooo02Cooooo0`000003ooooo`?oZKgW0onY
_NP2ojVmi`;oZKgX00CoZKcWojVmionY_NOoZKgW0_nY_NP01?nY_>OoZKgWojVmionY_NL2ojVmj003
ojVlionY_NSoZKgX00;oZKgX0_nY_NL4ojVmj0;oZKgW>onY_NP6ojVli`0300000?nY^^GoZK[U00?o
ZK[U00?oZKKSojVghonY]n<00_nY]n<00onY^>?oZ[CPoj^fh@03oj^fh@03oj^hhon/]n7o[;WS00?o
[;WS00<00000ooooooooool09oooool000Wooooo00@00000oooooooooooooooo7`00000501TI6@80
00000P0c<c<00`000000C4a<04a<C00200000080IVIV00Co000007moO`1oOgl0Ogmo1000000209VI
V@<000000`1oOgl01Ol00000IVIV06IVIP1VIVH0000000<0C4a<00D0000003<c<`0c<c<0<c<c0000
000501TI6E`000001?ooool00`00003oooooooooo`0Rooooo`8000001?ooool2ojVli`;oZKgW00Go
ZK_VojVlionY_>OoZKcWojVmi`02ojVkiP?oZKcW00?oZKgWojZki_nZ^nH00onY_>L00onY_NOoZ[_V
ojZkiP03ojVli`03ojVmj?nY_>KoZKcV00?oZKgW00CoZKgXojVlionY_>OoZKcW0_nY_NL00onY_NSo
ZKgWojVmi`02ojVmj003ojVlionY_NSoZKgX033oZKgX1_nY_>L00onY^^KoZK[U00000003ojVji@04
ojVfh_nY]^?oZKKSojVfh`;oZKOS00CoZK;OojZdh?nZ]>3oZ[CP0_n[]^401?n/]=ko[;OQojbghOn/
]n42ojbih`;o[[WR00<00000ooooooooool09_ooool000Wooooo00@00000oooooooooooooooo7`00
00000ol00000000001TI6@0401TI6@80000000<0<c<c00000?l000000`0000000ol000000000o`00
0003o`0000<0Ogmo0P00000607moO`05o`00001VIVH0IVIV06IVIP0000000`1<C4`01@000000<c<c
03<c<`0c<c<0000000D06ATIG0000004ooooo`0300000?oooooooooo01oooooo0`0000000ooooooo
ZK_VojVkiP04ojVli`;oZ[[U0onY^nH00onY_>OoZ[WTojZii003ojVkiP03ojVlionZ^>CoZ[ST00?o
Z[_V00?oZKcWojZii?nZ^N@00onZ^nH00onY_>OoZ[[UojZji@03ojVliP03ojVmionZ^nKoZ[_V00;o
ZKcW00GoZ[WTojZli_nZ_>KoZ[cVojVmi`02ojZkiP?oZKcW00?oZKgXojZlionZ_>L01?nY_NP2ojVm
ibKoZKgX0_nY_NL3ojVli`?oZK_V0_nY^^H00`00003oZ;KSojRfh`03ojVfhP03ojVfhonY/MkoZK7N
00?oZK;O00?oZ[CPoj^ag?n/]=h00on/]=h00on/]n7o[[OOojjgg`02ojjihP03ok2kh_ooool00000
02Oooooo0009ooooo`0400000?ooooooooooooooob8000001P0I6AT00`000000<c<c03<c<`0203<c
<`80000000D0C4a<000000000000000006IVIP0;o`0000@0IVIV00D0000004a<C01<C4`0C4a<0000
000303<c<`030000000I6AT06ATI00<06ATIG0000004ooooo`0300000?oooooooooo01cooooo0`00
0002ooooo`;oZK[U0onY^nH00onY_>OoZ[SSojZhh`03ojZji@03ojVki_nZ]^;oZ[KR00?oZ[WT00?o
ZK_VojZeh?nZ^>@00onZ^>@00onZ^nKoZ[CPojZdh003ojZii004ojZki_n[]^7oZkKQojZji@;oZk;M
0onZ^><00onZ^nKoZkGPoj^eh003ojZii003ojZli_n[^>?oZkSS00?oZ[_V00?oZKcWojZkiOnZ^nD0
0onZ_>L00onY_NSoZ[cWojZli`03ojVmi`03ojVmj?nY_NOoZKgW00;oZKgX00?oZKgWojVmj?nY_NP0
7?nY_NP2ojVmi`03ojVkionY^nKoZK_V00?oZK_V00CoZ;OTojRfhonX]^<000000onX]^<00onY]^;o
Z;3MojVagP03ojVagP03ojVbgonZ[][oZk7L00;oZk7L0_n/]=h01?n^/mco[[OOojjggon^]ml4ok2k
hP0300000?oooooooooo02Gooooo0009ooooo`0400000?ooooooooooooooob@000001@0I6AT20000
00@0<c<c00@0000004a<C01<C4`0C4a<1000000:06IVIP800000101<C4`01@000000<c<c03<c<`0c
<c<0000000H06ATIF`000004ooooo`0300000?oooooooooo01[ooooo0P000003ooooo`;oZ[WT0onY
^^D00onY^nKoZ[KQojZfh@03ojZhh`03ojZjiOnZ/]koZ[KR00?oZ[KR00?oZ[WToj^_fonZ]N000_nZ
]N02ojZhi0;oZjkJ00?oZ[CPoj^Vd_n[Y]800on[[m/00on[]^7o[:WDojbYe003oj^bg@03ojZhhon/
[MWoZkGP00?oZkGP00?oZ[WTojbbgOn[^><00on[^><00onZ^nKoZkORoj^ghP03ojZki@04ojZlionZ
^^GoZ[[UojZli`;oZk[U0onZ_>L00onY_NOoZ[cWojZli`03ojVmi`03ojVmj?nY_NOoZKgX01WoZKgX
00?oZKcWojVkionY^nL00_nY^nL00onY^nKoZ;STojRgi003ojRgi003ojRfh`00003oZ:oM00?oZ:oM
0_nX/=d2ojVagP05ojV[f?nZ[][oZZkJojZ^f_n[/M`00_n][mT3ojjcg003ojjggona^=ko/KSN00;o
/;_R00?o/kkRooooo`0000009_ooool000Wooooo00@00000oooooooooooooooo9P00000501TI6@80
00000`0c<c<3000000@0C4a<0`00000506IVIP8000001@1<C4`00`000000<c<c03<c<`0203<c<`03
0000000I6AT06ATI00@06ATIF`000004ooooo`0300000?oooooooooo01Oooooo0`000003ooooo`;o
ZKOS0onZ^N@00onY^^GoZ[?OojZfh@03ojZfh@03ojZhhonZ[][oZ[;N00;oZ[;N0_nZ]^801OnZZMKo
ZjoKoj^_fon[[m_oZ[GP00;oZjKC0on[[]X4oj^VdP03oj^_fon/W/Wo[:WD00?o[:WD00?oZk;MojbS
cOn/[MT00_n/[MT2oj^eh004ojfYe?n//]go[;;Mojbbg@;oZkSS0_n//=/00on[]n;o[JoIojf_f@03
ojbfh@03ojZjiOn/]^3oZk[U00?oZk[U00?oZ[cWoj^jiOnZ_>L00onZ_>L00onY_NOoZ[cWojZli`02
ojVmi`;oZKgX0_nY_NLCojVmj0CoZKcW0_nY^nL01?nX^NGoZ;STojRhi?nX^>@2ojRgi004ojN`gP00
00000000ojN_gP;oZ:oM00?oYZOFojRXeonXZ=L01?nYZmP00onZ[][o[:[Eojf_f@03ojf_f@05ojjc
g?na]=[o/KCJok6hg_ne_=l01?nc_^800oooool00000ooooo`0Tooooo`002Oooool01000003ooooo
oooooooooolY000000@06ATI0`00000303<c<`0400000?l000000000000000<0C4a<1@00000704a<
C003o`00000c<c<0<c<c0080<c<c00<0000001TI6@0I6AT01@0I6AUJ000000Cooooo00<00000oooo
ooooool05_ooool00`00003o0000ooooo`02ooooo`03ojVgh_nY]n?oZKOS00;oZKOS00?oZ[WTojZa
gOnZ/ml00_nZ/ml2ojZfh@05ojZYe_nZ[][oZZkJojZ^f_nZ/]h00_nZX/l3ojZYeP03oj^_fonZW/[o
ZYk:00?oZjKC00?oZjkJoj^Lb?n[W<P00on[Y]83ojbNb@;o[:WD00Go[9K0ojbScOn/Xlgo[:?=ojb]
f@02ojfMa`?o[JWD00?o[;;MojjVd?n^Y]000on//=/4ojf_f@03ojbfhOn^[mSo[;KP00;o[;KP0_n[
^^D01?n/]n7oZk[Uoj^jiOn[^^D2ojZli`;oZk_U00?oZ[cWoj^kiOnZ_>L00onZ_>L00onY_NOoZ[gW
ojVmj00@ojVmj0GoZKcW0_nX^^D3ojRii@03ojRhi?nW/Ml000000080000000?oYk3N00000?nUY]H0
1?nVYmH2ojRXe`;oZJ_H00CoZZGBojbZeOn/Z]Go[:[E0_n][mT01?na[mKo/KCJok6df_na]=X3okFl
g`;o/kkR0_ne`^@00`00003oooooooooo`0Sooooo`002Oooool01000003oooooooooooooool[0000
00D06ATI0`00000403<c<`<000002P1<C4`2000000D0<c<c00<0000001TI6@0I6AT01@0I6AUJ0000
00Cooooo00<00000ooooooooool05_ooool00`00003oooooo`000002ojVfhP;oZKOR0_nY]n<01OnY
[mcoZ[7MojZagOnZ/MgoZ[?O00;oZJKC0onZZMH00onZ[][oZIc9ojVLb@03ojZRc`03ojZYe_nYUL;o
ZYk:00?oZYk:00?oZjKCojZB_On[W<P00on[W<P00on[Y];oZi:moj^B_@02ojbNb@04ojbYe?n/U/3o
[9K0ojbF`0;o[:?=1?n]WLL00on]ZMCo[Y[2ojjVd003ojjVd003ojb`fon_YLgo[jG=00;o[JoI00Go
/:G<ojj_f?n^[mSo[ZoHojbfh002ojn`f@?o[;OQ00KoZk[UojfhhOn]^>7o[KSQoj^kiOn]^N83oj^k
i@;oZ[cW00CoZkcVojZmionZ_NOoZ[gW0_nY_NP00onZ_NOoZKgXojVmj00:ojVmj0;oZKcW00CoZK_W
ojVji_nY^^KoZK[V0onX^^D01?nX^ND00000000000000002ojNag`05ojN`g_nUY]KoYJKF00000?nU
Y]H00onVYmH00onXZ=OoZ:7?ojZUdP03ojZUdP03ojbZeOn_ZM7o/JoF00?o/JoF00Co/KCJokJhf_nf
^=[o]KcO0_ni`N02okG2i003okO5iOooool0000002Cooooo0009ooooo`0400000?oooooooooooooo
obd000001P0I6AT3000000@0<c<c2P00000603<c<`030000000I6AT06ATI00H06ATIFP000004oooo
o`0300000?oooooooooo01Kooooo00@00000ojVfh_nY]^;oZKKR0_nX[m`3ojV^g0;oZJoL00?oZ[7M
ojVSdOnYXm400onYY]<00onZZMKoZ9S5ojVLb@03ojVLb@03ojZRconXSk_oZIG200;oZIG20_nZW/X0
1?nXRKCoZY:mojZB_OnZT[d2oj^Lb006ojV8/_n[T[goZi:moj^B_On/W/WoZh^c1?n/U/000on/Xlgo
[I6iojfA^@03ojfMa`?o[Y[20_n^Y]001?n`V;oo[jG=ojnUcOn_YLd4ok2Uc003ojj_f?nbYlgo[k3I
00?o[k3I00?o[;OQojnbf_n_/]X00_n]^>401On`]Mco[KWRojfih_n]^N;oZk_U00;o[;[T0on[_>H0
0onZ_NOoZ[cVojZliP03ojZmi`03ojVmj?nZ_NOoZ[gW00OoZKgX0_nY_>L3ojVki`03ojVji_nW]^?o
YkCR00<000000_nW/n42ojNag`03ojBWf?nUY]KoYJKF00;oYJKF00@00000ojJMcOnVWLgoYYg=0onX
XLl2ojZUdP04ojfRcOn_ZM7o[jWAojnYd@;o/JoF0_nf/]D00onf^=[o^kkLokW1h002okW1h0Co]lGU
00<00000ooooooooool08_ooool000Wooooo00@00000oooooooooooooooo<000000601TI6@040000
0?l00000000000000100<c<c00?o000001TI6@0I6AT01P0I6AUJ000000Cooooo00<00000oooooooo
ool05_ooool01000003oZKKRojR`g_nX/=h3ojR_g003ojV^g?nWXm;oZ:?A00;oZ:?A0onYXm400onY
Y]?oYiG3ojRHa@02ojRHa@;oZIc900CoYhZfojR?^onXSk_oZ8nk0_nYUL84ojR9]0;oZY:m1?nYR;82
oj^B_@?oZh^c0on/U/04ojfA^@03ojfMaon^S[Co[Xjd00;o[Y[21?n`V;l00on_YLgo/YVnok:I_P03
ok2Uc0?o/ZO=0_n_/=T2ok>Zd003ojnbf_nd[m?o]:oC00?o/;GL00?o[KWRojnggon/^^@00on/^^@0
1?n[_>Ko[;_UojbkiOnZ_>H2oj^liPKoZ[gW1?nY_NP5ojVli`03ojVkionX^>@00000008000000_nW
]>800onUZm_oY:SIojBXf@04ojBWf005ojFVe_nRVLcoY9_<ojBKc00000000onVWLd00onXXLooZYc8
ojfRc@03ojfRc@03ojnYdOneZloo][;E00;o][;E00Go_KWFok^ng?nk_]co^kkLokW1h002ok_7h`;o
]lGU0_ngb>L00`00003oooooooooo`0Qooooo`002Oooool01000003ooooooooooooooolb000000P0
6ATI1000000903<c<`<000002@0I6AUJ000000Cooooo00<00000ooooooooool05Oooool00`00003o
ooooooooo`03ojR`gP03ojR_g?nVY]KoYj?B00;oYj?B0onXXm400onYXm7oYYC3ojNE``02ojNE``;o
Z9S50onWR[H3ojR?^`03ojVE`_nWPjkoYh>^00?oZ8Vd00?oZY:mojR1Z_nYR;800onYR;800on[T[go
ZX:Yoj^;/`03oj^;/`03ojbF`?n/QZgo[8J]00;o[I6i00Go[XFXojj>]?n^S[Co[XjdojjJ`P02ok6=
/@?o/9Ro1?nbVKh00on`YLco]IfookFM_`02ok:Wc@04okNR`oncZ]3o/j[@ok>Zd0Co]:oC00?o/;GL
okBcf?n_]ml00_n_]ml2ojbji0;o[[[R00?o[;_Uojfli?n[_>H00on[_>H00onZ_NOoZkgWojZmi`03
ojZmi`03ojVmj?nY_>OoZKcW00CoZKcW0`0000001?nX^>CoYkKSojF^gOnU[]d3ojF[f`;oY:SI0_nT
YmP02OnQVLgoXYW<oj:Ic?nRVLcoY9_<00000?nTVlcoYYg=ojJGa@03ojZLb0?o[J;=0oneZll01Onf
/]Go_KWFokfie_nm^MKo^kkL00;o`LKO00?o^lOSokg<i_nmc>H00_ngb>L2okG9j@0300000?oooooo
oooo023ooooo0009ooooo`0400000?oooooooooooooooc@000002P0I6AT9000000`06ATIFP000004
ooooo`0300000?oooooooooo01Gooooo00H00000ooooooooooooooooojR`g_nUZMX3ojJVeP;oYj?B
0_nXXm401?nTULGoYYC3ojJD`onVU<<2ojNE``03ojRHaOnUQkCoYHNd00?oYhZf0_nXSk/3ojN3[P?o
Z8Vd0onXPJX3ojV8/P?oZX:Y0_n[Rk<01On/OjCo[8J]ojb6[On/QZgo[I6i00;o[XFX0on^S[@4ok6=
/@03ok2H_ondT;7o]92a00;o/YVn00Go]iBbokFM_oneWKoo]Ifook:Wc@03okNR``03ok>Zd?niZ<So
^JS800;o]:oC00Go^Zo?okBcf?nd/mSo];?Hojngg`03ok>hg@03ojjjh_na^n7o[KcT00;o[KcT0_n[
_>H2ojbmiP;oZkgW1?nZ_NL00onY_>OoZK_VojVjiP0300000004ojRiiOnV/n;oY[7PojJah0CoYJkM
00CoYJ_Koj2LdOnPV/koX9[>1?nQVLd2oj:Ic0;oY9_<00@00000ojJGaOnVUlGoYYO50onZW<P01On]
X/go/Z?9ok:SbOneZloo_K;@00?o_KWF00KoaLCIol76goo1a]oo`LKOolC?h_nmc>H2okc>j0;o]LWY
00?o/lSY00000?ooool08Oooool000Wooooo00@00000oooooooooooooooo=P00000L01TI6E/00000
1?ooool00`00003oooooooooo`0Eooooo`0400000?ooooooooooooooo`?oYJWJ0_nVY]H00onWXm;o
XiS:ojBEa@03ojBEa@;oYYC300?oYiG3ojB6]?nUQk@00_nUQk@3ojN:]P03ojR?^onVOj[oYh>^00;o
Yh>^0onXRK@3ojR1ZP;oZHRb00GoZGbRojZ2ZOnZPZWoZX:Yoj^;/`02ojaoY0?o[8J]1?n^QJP2ojj>
]0Co/Hfa0ondT;401?nbVKko]iBbokND/_ngU;82okFM_`?o]j;300Go_j>lokVXb?niZ<So^JS8okB_
d`03okZ_c`03okBcf?ni]]Ko^KKF00;o/kSM00Go]k_Mok6khOna^n7o/K_Qojfli003ojnmi003ojbm
i_n]_NKoZkgW00;oZkgW0_nZ_NL01OnZ_>L0000000000000003oZK[V00;oYkKS0onV/n82ojJah0;o
YJkM00CoXJ3Doj2LdOnPW=7oX9cA0_nPV/h3oj6Ic@03oj:Ic?nPS/7oXi;300;oXi;300<00000ojJG
aOnVUlD00_nZW<P01?n^VlCo/Z?9ok:SbOnbXlT3okfbd005okfie_o5a=WoaLCIolG4fOo1a]l00_o4
cn83okc>j0Co/lSY00<00000ooooooooool07oooool000Wooooo00@00000oooooooooooooooo=P00
00001?l00000000000000000000H01TI6E/000001?ooool00`00003oooooooooo`0Eooooo`030000
0?oooooooooo00;ooooo00?oYJWJoijTf_nPWM400_nPWM42oj>HbP?oY9G500CoYYC3oj67^?nTQ[Co
Y8Jd0onUQk@3ojN:]P?oYWnZ0onWPjh00onXRKCoYgbTojR1ZP02ojR1ZP03ojV8/_nYO:;oZGbR00?o
ZX:Y1?n/Oj@2ojb6[@Co[XFX00?o[Xjdok66Y_naQZH00onaSK43okB@/@Co]iBb00Co]Ifook^J]_nk
V[Ko]j;30onoXk`2okVXb004ol6/aOnj[loo^Zo?okZ_c`?o^KKF00Go_[cHokNkgOng^mgo]k_Mok6k
h@02ok>nhP;o[kgT00Co/;oUojfmi_n]_NKo[KgV0_n[_NL300000003ojZlionY^nKoZ;SU00CoYkKS
00CoY[?Roj>YfonRY=OoXZCG1?nQX=@2oj2Ld@03oj2Jc_nLS<;oWHc100;oWHc10onPS/43oj>B``03
00000?nYTkoo[Y_400?o[Y_400?o/Z?9okZYbOnjZLT00_nm/]000oo6_];oaLCIolG4f@02ol_@g@04
olC?h_o4e>Koa=CVokc>j0;o^LkZ0_ncb>T2ok36jP0300000?oooooooooo01kooooo0009ooooo`04
00000?oooooooooooooooch000004`0I6AUL000000Cooooo00<00000ooooooooool05Oooool00`00
003oooooooooo`03ooooo`;oWZCJ0onPWM42oj>HbP04ojBEaOnNR[koXHNhoj67^0?oY8Jd0onUQk@0
0onWR[KoY7fXojIoZP02ojIoZP;oYh>^00CoYWVQojMlY?nWO:CoYgbT0_nXPJX4ojUlXP;oZX:Y1?n/
Oj@00on/QZgo[WnQojj5Z003ojj5Z0?o/HJV0_naSK42okF9YP;o]92a00Co^XjXokND/_ngU;;o]iBb
0onkV[H4oknS_005okVXb?o1[<Go`Jc5ol6/aOnj[ll00_o1]Lh01Oni]]Ko_[cHokjlf?nn_=So]k_M
00;o^/7O00?o/kkRokC2i?nd`^@00on`_nD01?n]_NKo[KkV000000000002oj^mi`03ojZlionY^^Ko
ZK[V00;oZ;SU0_nW]^<01?nT[MkoXjWKoj>YfonSZM/2oj:Te`;oXJ3D00?oVXo7oi^=a?nKSL@00onL
S<83oif<`@;oX8k10_nST/<01?nUSK/00000ojVC_onYTkl2ojjKa005okJP`_njZLWo^ZW9okZYbOnm
/]000_o6_]83ol_@g@;oc][R00Coa=CVol;FjOo2e^Wo^LkZ0_nfc>/2ok36jP03ojk3j@00003ooooo
01oooooo0009ooooo`0400000?oooooooooooooood4000003@0I6AUO000000Cooooo00<00000oooo
ooooool05Oooool00`00003oooooooooo`04ooooo`;oWZCJ00CoX9gAoiBHe?nJT<SoVY380_nNR[h3
oj67^0;oY8Jd0_nUQk@01?nRO:WoY7fXojAmZ?nTOJP2ojIoZP03ojN3[_nVNJ7oYWVQ00?oYgbT0_nX
PJX4ojUlXP03ojZ2ZOn/NYko[7nT00?o[7nT00?o[8J]ojioXOn^Oj400on^QJP3ok66YP05ok6=/One
RJKo]HVVokF9Y_ndT;400_njSZP3okND/P04oknF[OnkV[Ko^iZfolFP/`?o_j>l0oo1[<D01Oo;]lOo
`KG>ol6ec_o1]Lkob<7C00;o_[cH0_o2a]d00onj`Moo^/OTokC2i003okC2i004ok2oi@0000000000
000000;o[;kW0on[_>H00onY^^KoYkKSojJbh@03ojJbh@;oY:gN00CoXjWKoibHconKTl_oVi?;0onJ
SlL3oi^=a0;oW8c20onMS<400onPS/7oX8NiojF=^`03ojF=^`0300000?nYTkoo[Y_400?o]Z320_nj
ZLT01Oo6]/_oa[kBom3>eoo@c]Oobm3M00;oc][R0_o=h>H01?o2e^Wo_MC[okgDjonfc>/2ok;8j`?o
[/?Y00<00000ooooooooool07Oooool000Wooooo00@00000ooooooooooooooooB@0000000ol00000
00000000001Q000000Cooooo00<00000ooooooooool05?ooool00`00003oooooooooo`05ooooo`;o
Sj7Q0onDV=@2oiZ@b0;oWXZn0_nQQkP00onTQ[CoWgb]oj9lZ@02oj9lZ@?oY7fX0_nVOjX3ojIiX@?o
YgbT00?oZ86ZojQhW_nYO:800onYO:800onZPZWo[7ZNojajWP03ojaoY0?o[WnQ0_n^QJP01?nbPIoo
/HJVok66Y_naQZH4okF9YP05okB@/OnjSZSo^XjXokZ>Z?ngU;800_noUZd01OnkV[KoaJ2colFP/oo5
X;?o_j>l00;obJ^l00Go`Jc5ol^gaoo;]lOobkO7ol6ecP02olS1d`04olc@gOo2a]go`/KMol;6g@?o
^/OT00Ko]<;T0000000000000000ok31i_n^`NP4ojbni`03oj^li_nY^NGoYkKS00;oYkKS0_nV/^40
0onQYMWoWYkDoijNe003oibHc`;oVi?;0onJSlL2oi^=a0?oW8c200?oWHc1oib3]onPQkT00_nPQkT3
ojF=^`03ojVC_`00003o]Z3200?o]Z3200?o^ZW9olJfboo6]//00oo@c]L01?oGgMcoc][RolgPi_o=
h>H2olOOjP05okgDjonhcnco^<o/ok;8jon_a>X01?n/`NT00`00003oooooooooo`0Looooo`002Ooo
ool01000003ooooooooooooooon]000000Cooooo00<00000ooooooooool05?ooool00`00003ooooo
ooooo`06ooooo`;oSj7Q0_nDV=@2oiZ@b0;oWXZn00CoXHNhoiYn]?nOO:goWgb]1?nRO:T2ojAmZ003
ojIoZ_nTMj3oYWVQ00?oYWVQ0_nWO:@3ojQhWP?oZGbR0on/NYh3ojaoY0?o[WnQ00Co[XFXok:1Wonb
PIoo/X6O0_naQZH01?ngQJ3o]HVVokF9Y_neRJH4okZ>Z0?o_iJ]1?o5X;<3olV[_006omJn`_o;]lOo
bkO7ol^gaooDb]3ob<7C0oo<d=d00oo2a]go`LoUol7?i@0300000004okS;j?nca>Oo/LGYok75j@;o
[/7X0_n/_^L2oj^liP;oZKWU00?oYkKSoj>[gOnQYMT00onQYMT2oijNe0;oW9S?0onKTl/2oiZ?a`03
oi^=a?nFOkSoVH2g00;oVH2g0_nLPkL3oj27^@?oYHfk0_n`U[`01000003o]Z32okJP`_o2Zl@3olJf
b`06om?8coo@c]OoemgLomOMg?oHj>3ocN3V0_o7gnX2ol3Jk003okS?k?nbb^_o[lCZ00;o[lCZ0_n/
`NT00on[_nT00000ooooo`0Mooooo`002Oooool01000003ooooooooooooooon]000000Cooooo00<0
0000ooooooooool05?ooool00`00003oooooooooo`07ooooo`;oJIc^00?oLi;RohB9dOn4RM400_nA
Pl02oiYn]0;oWgb]1?nRO:T2ojAmZ0;oY7NP1?nVNJ42ojMlY0?oZ7RN0onYO:83ojajWP;o[7nT00Co
[gbKojioXOn^Oj7o[WnQ1?nbPIl00onaQZKo]hFPokN5X003okF9YPCo^XjX0onoUZd4olFP/`03om:_
]_o9ZkcobJ^l00;oe[k200CobkO7omC:d?oDb]3oen3N0_o<d=d01Oo8g>P0000000000000003o_=?/
00;o^<_X0_ncb^/00onaaNWo[L?Zojboj002ojboj0;oZkcV00?oYkKTojFahOnU/N400onSZmd3oj6U
f@04oijNe?nFRlKoU8G1oiB5`@?oTh6m0_nDOkX3oiIo^0;oVH2g0onLPkL3oj27^@06ojF=^onZSKOo
/9Jlok2F_000003o]Z320oo2Zl@01_o6]/_odlS?om?8cooNgMCoemgLomSXh0;oe>cU00?oc>W[ol3J
k?o0f^`00_nidnd2ok;:j`03ojo4j_n/`NWo[<7Y00;oZkoY00?oZ[kX00000?ooool07?ooool000Wo
oooo00@00000oooooooooooooooo[@000004ooooo`0300000?oooooooooo01Cooooo00<00000oooo
ooooool02?ooool2ofVLkP04og>Bh_n4RM7oTH?0oi63`0;oVWjd0onOO:d3oj9lZ@03ojAmZ?nRMZ;o
Y7NP00;oY7NP0onVNJ400onWO:CoZ7JLojQhWP02ojQhWP;oZGbR00GoZgRJojajW_n/NYko[7ZNojao
Y003ojmlV`;o[WnQ1?nbPIl00onaQZKo]hFPokN5X002okF9YP;o_HbR0_njSZP2olBEYP03oknF[Oo;
XJcobj6/00;oaJ2c0_oB[kH01_o9Zkcoe[k2omJn`_oF_/;ohM[?omC:d0;oen3N0`000002okkNl006
okcCk?ndd>oo]=3_okC@koncb^_o[/K/0on]`nX00on/_nSoZK_VojVkiP03ojNfi0;oYK7Q00?oXj_M
oi^KdonHTl`00_nHTl`2oiJ;aP?oU8G10_nCPKd2oiAo^P?oUWnh0onIP;L2oib3]`;oX8Ni00CoY8Fc
ojZ=]onZSKOoZXfg0_n`U[`01P00003o`Z_4ol:[a?o2ZlCodKk7om?8c`;og]gD00?ohnkGomogf_oD
k>D00_o<jN/01?o3h>ko^M?]okWCkOncbn`3ojo5jP03ojc1jOn[_nWoZ[kX00;oZ[kX00?ooooo0000
0?ooool06oooool000Wooooo00@00000oooooooooooooooo[@000004ooooo`0300000?oooooooooo
01Cooooo00<00000ooooooooool02Oooool01?lDPNKo1VkNohB9dOn4RM42oi63`0;oVWjd0_nOO:d2
oj9lZ@03oiifY_nRMZ;oXWJR00?oY7NP0onVNJ42ojQfW0?oZ7RN00?oZGbRoj]hV_n[N9X00on/NYh4
ojmlV`03ojioXOncOi_o/X6O00?o/X6O1?ngQJ001?neRJKo_HbRokf<X_njSZP3olBEYP04oknF[Oo;
XJcobj6/olFP/`?odZnf0ooF_/82on7Jc`<0000000Coc>k[ok[Zm?njj_Co_]k`0_nceo<2okC@k`;o
[/W^0_n^a^`00on]`n[oZ[kXojZnj003ojVkiP04ojNfi?nRZmkoWZ?IoijSf@?oVi_C0onHTl`2oiJ;
aP;oU8G10onCPKd2oiAo^P?oUWnh0_nIP;L00onLPkOoWWnaojB5/`02ojB5/`?oZXfg00Go/9Jlok^P
_OnkX;d00000ol:[a002om6na`07on;Gc?oNgMCohnkGon?^eooOmm[oeoOQolcYj`02ol?PkP?o/l_/
0_n_aNX2ojc2j@;oZkoY0onZ_^P00`00003oooooooooo`0Jooooo`002Oooool01000003ooooooooo
oooooon]000000Cooooo00<00000ooooooooool05?ooool00`00003oooooooooo`0;ooooo`04o`I^
g_l]LMooTH?0oi63`0;oVWjd0_nOO:d00onRO:WoWWJVoiifYP02oj9fXP?oY7NP0_nVNJ401?nVMI_o
Z7JLojQfW?nXMY`2ojQhWPCoZgRJ0_n/NYh4ojmlV`03ojioXOncOi_o/X6O00?o/X6O1?ngQJ03okf<
XP05okZ>Z?o4UJKoa9FVolBEY_noUZd00_o;XJ`01_oM^;;odZnfom:_]_oB[kKohl^oomJn`P<00000
00Gog?KMokolion[lOGoZo7eok[Zm002ojoLm`06ok?Glon/c?3o[<c`ojc<l?n^bNkoZ/?/0on[`NX0
0onZ_^SoY[OUojJgi@03ojBbhP;oXZ_N0_nNXmT3oi^Kd`;oV9?<0_nFRlH3oiB5`@;oTh6m0_nDOkX2
oiIo^003oiAf[onHNJooV7V_00?oWWna0onTQK<2ojZ=]`?o^j2m00T00000om6naooA_/OodKk7on;G
c?o/klcohnkGomogf_oGmn400_o>l>X01?o3h>ko^]G^ok[Ek_ncbn`2ojo5j`;o[<;Y00?oZkoYojZn
j?nZ_^P00_nZ_^P00onY_NSooooo0000000Kooooo`002Oooool01000003ooooooooooooooon]0000
00Cooooo00<00000ooooooooool04oooool00`00003oooooooooo`0=ooooo`03o`1I/omTMm7oI7OA
00;oVWjd00?oWgb]oiIf[_nNMZH00_nNMZH3oj9fXP;oY7NP00?oYWVQojIeVonVMI/00onXMY`2ojQh
WPCoZgRJ00?o[7ZNok1jVOn_O9/00on_O9/00on^Oj7o/gnKok=oV`02ok:1W`03okZ4W?ngQJ3o]hFP
00;o]hFP0onmS:84olBEYP?obj6/0_oM^;802?oB[kH0000000000000003ojo;<okol`ooLm]go_ocW
0_n[lOD2ojOOnP03ojoLmonZc_;oZ/kb00;o[<c`0_nZa>d2oj[3k003oj_1j_nW^nOoY[OU00?oY[OU
00CoY;;RoifTf_nIV]?oVI[C0_nDT<`3oi66a@;oSWjn0_n<NKP3ohae]0;oSW>a0_n@M:l3oiAf[`;o
V7V_0onNOk43ojB5/`03ojZ=]ondU;Oo]9Bg00;o^j2m00?oc;;000000?oA_/L00_oRel`01Oo/klco
io_8omgnbooEo][oc_3Z00;o`n?_00Co^]G^ok?<k?ncc>co[lG[0_n/`NT3oj^oj@?oZ[kX0_nY_NP0
0`00003oooooooooo`0Iooooo`002Oooool01000003ooooooooooooooon]000000Cooooo00<00000
ooooooooool04oooool00`00003oooooooooo`0?ooooo`03ofAgdOn5MkcoQGNl00;oUWJ^0onNMZH3
oj9fXP;oY7NP0onVMI/3ojQfW003ojQhW_n[MiWoZgRJ00?oZgRJ00?o[7ZNok1jVOn_O9/00on_O9/3
ok=oV`;o/X6O0_njQ9`2okN5X004ol6=W_nmS:;o_HbRokf<XPCoa9FV00CodjJYol^Q[?oM^;;ogKRb
0P000002on?;_`03on_bc?noo<?oV=_n00;oV=_n00?oWmkmojG<m?nUc?@00_nWcO@01_nZc_;oZLC]
ojW4kOnYa>goZ/C]ojRnj@?oZ;gX0_nW^nL2ojJgi@04oj6/gonMY=[oWJCJoifTfP;oVI[C0_nDT<`3
oi66a@03ohin__n<NKSoS7Vh00?oS7Fd0_n>Lk43oi1d[`;oU7J_0onHNJl3oiio/@03ojB5/on[R[;o
]9Bg00;o]9Bg00Ko^j2molbb`?o<//3oc;;000000?oRel`2onc_c005onOkb?oEo][ocOGYolgejOo3
hnl00_nie^h01Oncc>co[/G[ojk5jon/`NWoZkoY00GoZ[kX1?nY_NP00`00003oooooooooo`0Hoooo
o`002Oooool01000003ooooooooooooooon]000000Cooooo00<00000ooooooooool04oooool00`00
003oooooooooo`0@ooooo`04ofAgdOn5MkcoUWJ^oiIf[PCoWWJV0_nRMZ82ojAgX0?oYWFK0onXMY`0
0onXN9koZgNIoj]hVP03oj]hVP03ojajW_n`NYWo/7ZI00?o[gbK0oncOi/01?nbPIoo^XBLokZ4W?nj
Q9`2okN5X0;o`HfN00?o_HbRolZHX_o:V:800_o4UJH2om>VZ@<0000000CogKRboo;R_OoSbkoojo;<
0_nEe_h2oiSKoP;oY<Wc00?oYLcdojO2kOnX`nd00_nX`nd2ojW4k@06ojRoj_nX_^WoZ;kYojRnjOnX
_NSoY[OU1?nT/^<2oj6/g`;oWJCJ0_nIV]<2oiB@c0?oTHK50_n>O[h2ohai^0?oS7Fd0_n>Lk42oi1d
[`?oU7J_0_nHNJl2oiio/@04oj>1[_n[R[;oZhZboj^:/P;o]9Bg00Woa:Bjolbb`?o<//3oc;;0on7=
a000003ok>o<onOkb?oEo]X00_o=mNT00oo2iO3o^MK^okWFkP02ok;;k003ojk5jon/`NWoZkoY00;o
ZkoY0_nZ_^P2ojVnj0GoZKgX00<00000ooooooooool05oooool000Wooooo00@00000oooooooooooo
oooo[@000004ooooo`0300000?oooooooooo01?ooooo00<00000ooooooooool04Oooool01?mo003o
QGNloiIf[_nFMZh3oiifYP;oXWJR00?oY7NPojAdWOnVMI/00_nVMI/3ojQfW0;oZgNI1?n[N9X3ok1j
V@;o[gbK00Go]GnIok=oVoncOi_o/gnKok:1W`03okZ4W005okN5X?o1SIko`HfNol6=W_nmS:800_o:
V:801?o4UJH00000000000000003omfh/P;ol^:m00CoU]3lojC4l?nTa?3oY<C`0_nSa_800onTbO?o
Yl7/ojO1k002ojO2k@03ojS3kOnX_n[oZ;oZ00?oZ;oZ00?oZ;kYojNjionW^^L00_nV]nD2ojBbh`03
oifVg?nHW=KoV9cF00;oTY3>0_n=QLH2ohQk_P?oQW>g0_n4K[42ohai^0?oS7Fd0_n>Lk42oi1d[`?o
U7J_0_nHNJl00onNOk7oXh6^oj>1[P03oj^:/P05okBD]oo4Y;[oa:BjolBT^_o<//000_oQcL@01P00
003ojoVdolgk/oo>om7oboOZol;Ul0;o^=G_0_nbbn`2ojk4j`;o[<7Y00?oZkoYojZnj?nZ_^P00_nY
_^P6ojVmj00300000?oooooooooo01Oooooo0009ooooo`0400000?ooooooooooooooojd000001?oo
ool00`00003oooooooooo`0Cooooo`0300000?oooooooooo017ooooo00CoO`00ohEg_?nFMZkoUWJ^
0onNMZH2oj9fXP;oY7BM0onVMI/3ojQfW0?oZgNI0on[N9X3ok1jV@;o[gbK00Co]GnIok=oVoncOi_o
/gnK1?njQ9`01OngQJ3o`HfNol6=W_o1SIko_HbR00<000000ooCYZT00oo/bK7ogKRboo;R_@02oo;R
_@04ojG1k_nTa?3oY<C`ojRojP?oYl3[00?oYl7/ojRnjOnX_^T00_nX_^T2ojRojP06ojRmj?nX_>So
Z;cXojRlj?nW^^OoY;CT0onQ[^43oifVg0;oV9cF0_nBT<h2ohf5aP;oR7^n0_n6LkL2ohA^/@;oQF^]
0on7JZ/2ohic/@?oT7B_0_nDMZl00onHNJooW7V[oj>1[P03oj>1[P;oZhZb1?o4Y;X01ooK_kkohLg4
oo7[`ooajl<00000olkodOo;mnX00_o0i?400onheNoo/LW/ok79k002ojk4j`05oj_0jOnZ_nSoZ[oX
ojZoj?nZ_^P02_nY_NP00`00003oooooooooo`0Fooooo`002Oooool01000003ooooooooooooooon]
000000Cooooo00<00000ooooooooool04oooool00`00003oooooooooo`0Booooo`03ogl00?nFMZko
UWJ^00?oWWJV00CoXWJRoiicX_nTM9goY7BM0onVMI/2ojQfW004ojYfVOn[MiWoZgNIoj]gV@;oZgRJ
00Go/7ZHok1jVOn`NYWo/7ZIojmlV`02okEoV@?o/gnK1?njQ9`2ol6=WP<000000_o:V:83om>VZ@;o
k<Va0_oYmjH00oobh[goYL7^ojRnj@02ojRnj@;oZ;oZ00?oYl3[ojVnjOnY_^T00onX_^T3ojVmj0;o
Z;gX00?oZ;cXojJhi_nV^>H00_nT]>@3oj6^h@04oifVg?nBU=;oRhO:oh^7bP;oTY3>0_n=QLH2ohQk
_P?oQW>g00CoQ6jaohE[[On5JjgoQF^]0_n7JZ/2ohY[Z@?oSfjY0_nELZT3oiaiZ`?oXh6^0_n[R[80
0oniUkCoa:BjolBT^P02om^o_P07oo;R_Ooajl?o/n5lokK^VP00003oaoK/ol3Tl@02okKBk`03ok79
k?n]`n[o[L?Z00?oZl3Y00?oZ[oXojZnj?nZ_^P02onY_NP00`00003oooooooooo`0Eooooo`002Ooo
ool01000003ooooooooooooooon6000000l06ATI60000004ooooo`0300000?oooooooooo01;ooooo
00<00000ooooooooool05?ooool2og5/_@?oTW:[0_nNLj83ojAdW@;oYWFK00?oZ7JLojYfVOnZMYT0
0on[MiT2oj]hVP05ok1jV?n`NYWo/7ZIok1jVOn_O9/00oneOiT2ok=oV`?o^XBL0`000002ol6=WP?o
bYRR00?ogk6Xom>VZOoCYZT00_o/bK400ooYmjKoY[o/ojRnj@03ojRnj@05ojVmj?nY_^SoZKkXojVn
j?nY_^T01_nY_NP01_nX_>OoYk[WojNjionW^^OoY[SVoj:bh`;oWZ[O0onIXMX3oi:DdP03oh^7b_n5
Nl7oQG_100;oP76h0ommJK42ohIc]`;oQ6ja0_n5Jjd2ohMZZ`?oRV^Y0_n?KZT2oiEbZ@?oW7V[0onS
PJh01?n[R[;o^INdokVG]?o4Y;X3om^o_P08oo;R_Oo;jHCo]^jJolKncOo7m^`00000okgPlOnfd^l2
ojo8k003ojg3j_n[`>WoZ[kX00CoZ[kX3?nY_NP00`00003oooooooooo`0Eooooo`002Oooool01000
003ooooooooooooooon2000001H06ATI5@000004ooooo`0300000?oooooooooo01;ooooo00<00000
ooooooooool05?ooool00ol<C<WoLFbmoi9bZ`02oi9bZ`;oWW>R0onTM9d2ojIeV`03ojQfW?nZMYWo
ZWJI00?oZgNI00?oZgRJok1jV?n`NYP00on`NYT4okEoV@03ok=oVonlQYX000000080000000?oaY2M
ol6=W_o1SIh00_o1SIh2olZHXP?ogk6X00?odjJYonc9/OoYmjH00_nY_NP2ojRnj@CoZKgX00?oZKkX
ojVmj?nY_NP01?nY_NP2ojVlj0;oZ;cW00?oYk[WojFgiOnR/^<00_nR/^<2oijZg`?oVJ7J0_nBU=82
oh^7bP04ohEk`On0LKSoP76hoh1a^0;oOFVa0_mlI:`2ohA^/@;oQF^]0_n7JZ/3ohY[Z@;oSfjY0onE
LZT2oiaiZ`?oXh6^0oniUk@3om^o_P;ol^:m00Go0000oj;RS?o4l^ooa?;_00000002ok??kP03ojo8
k?n/`^[o[<;Z00;oZl3Y0onZ_^P>ojVmj00300000?oooooooooo01Cooooo0009ooooo`0400000?oo
ooooooooooooogT0000000?o00000000000000007`0I6AT00ol0000000000000000?000000Cooooo
00<00000ooooooooool04_ooool00`00003oooooooooo`0Eooooo`04og5/_OnBLZ_oTW:[oi9bZ`?o
WW>R0_nTM9d2ojIeV`CoZWJI0_n[MiT00on[N9[o/7ZHok1jV003ok1jV@?o]GnI0`0000001?nlQY[o
^XBLokZ4W?o6T9d3ol6=WP;odIjQ00KobYRRomnaZ?oO/JSogk6Xoo[W[?o/bK4@ojVmj003ojVlj?nX
^nOoYkWV00;oYkWV0_nU]nD00onR/^?oVjONoiBLf002oiBLf0;oS8k@0_n4P<L2ogac_@;oQG_10_n0
LKP2ogeY/@;oO6B/0_mmHZP3ohE[[@;oQfZ[0_n:JjT3ohm^Z@;oUG:Y0onLNJ/00onSPJko[XZ_okVG
]002okVG]006om2_^OoK_kkol^:moo;R_Ol0003oX^:<0_o4l^l2okWKl@0500000?n^aN_o[/G[ojc2
j_n[_nT01?nZ_^P@ojVmj00300000?oooooooooo01?ooooo0009ooooo`0400000?oooooooooooooo
ogP00000900I6ATA000000Cooooo00<00000ooooooooool04_ooool00`00003oooooooooo`0Foooo
o`03og5/_OnBLZ_oTW:[00?oWW>R0_nTM9d2ojIeV`CoZWJI0_n[MiT3ok1jV0;o/7ZI00Ko]h2IokEo
V@0000000000okEoVOncOi/2okb6VP04okZ4W?o6T9goaY2MolJ@W@;o`HfN0_oAWZ401Oo:V:;ogk6X
omnaZ?oO/JSon^N/013oZKgX0_nY_>L2ojRki`03ojNii_nT]NGoXK3R00;oXK3R0_nKYmh3oiBLf0;o
S8k@00?oQ837ogac_OmlLkd00_mgJ;D2oh1a^0;oOFVa0_mlI:`2ogeRZ0?oP6:V0_n7JZ/3ohY[Z@;o
SfjY0_nELZT2oiaiZ`05ojAoZon^RZoo[XZ_ojj:[oniUk@00_o@[kT01?o]eK_ol^:mol;KJoo0o]`2
oko[lP;o^M_a00?o/L_]ojk5j`0000000_n[`NT2oj^oj@03ojZnj?nY_^SoZKkX013oZKgX00<00000
ooooooooool04oooool000Wooooo00@00000ooooooooooooooooM`00000W01TI6@l000001?ooool0
0`00003oooooooooo`0Booooo`0300000?oooooooooo01Kooooo00?oLFbmoi9bZonBLZ/00onNLj82
ojAdW@03ojIeVonXMYcoZWJI00?oZWJI0_n[MiT3ok1jV004ok1jV@0000000000000000?o]GnI0onl
QYX01OnjQ9coaY2MolJ@WOo6T9go`HfN00?odIjQ0ooO/JP2oo[W[13oZKgX00?oZKcWojRkionV^NH0
0_nV^NH2ojBei@04oj6`h_nIYMkoT9WHoi2If0?oQX[?0_mlN/H2ohB0a`03ogac_OmgJ;GoMfRe00?o
Lf2^0_mmJK400omlI:coOF:XogeRZ003oh1RYP;oQ6BU0on:JjT2ohm^Z@03oiEbZOnJMJSoY7n[00;o
Y7n[0on^RZl02?niUkCod:niom2_^Oo]eK_olo:So`000?o0nnWo_n_b0_nfe?001Onabngo[L?[ojg3
jon[`NT0000000CoZ[kX00?oZKkXojVmj?nY_NP04?nY_NP00`00003oooooooooo`0Booooo`002Ooo
ool01000003ooooooooooooooomd000000`06ATI4000000?01TI6@h000001?ooool00`00003ooooo
ooooo`0Booooo`0300000?oooooooooo01Oooooo0_nBLZ/3oiicXP;oY7BM0_nXMY`4ojYfV@03oj]g
VOn`NiWo/7ZH00<000000_ngP9T4okEoV@?o_8JJ00Go^XBLolJ@WOo6T9goaY2Mol6=WP03om6NX@?o
gk6X00?on^N/ojVmj?nY_NP03_nY_NP2ojRli`;oZ;_W00CoY[WVoj>diOnO[^;oWjkR0onIYMh2oi2I
f0?oQX[?00?oO7[6og=/_?mcK;`00_mlLkd2ogMX]@;oLf2^00CoLe^XogeY/OmlI:coO6B/0_mmHZP2
oh1RYP;oQ6BU0on:J:D2oi9^YP?oVWFX0onTOj/2ojj:[`;od:ni0_o]eK/01Oo2ff_o`?_Yok_Rlonk
h_?o]]C`00;o[lS/00Co[L?[oj_0jOn[`>T000000onZ_^PDojVmj00300000?oooooooooo01;ooooo
0009ooooo`0400000?ooooooooooooooofl0000000?o000001TI6@0I6AT02@0I6AT500000003o`00
000c<c<0<c<c00d0<c<c0P00000=01TI6@h000001?ooool00`00003oooooooooo`0Booooo`030000
0?oooooooooo01Oooooo0_lhF<L3oiicXP04ojAdWOnQMZ;oZ7JLojQfW0CoZWJI0`000002ok1jV004
ok1jVOngP9Wo]h2IokN0V@?o]GnI0onlQYX4olJ@W@06ol6=W_oAWZ7odIjQom6NXOo`b:Wogk6X0_oj
ij`@ojVmj003ojRlionW^nOoY[WV00;oY[WV0_nS]>D2oin^hP03oiVUg_n=UmWoPHO@00;oPHO@0_n6
R/l00omlN/KoLfblog=/_002ofeP/`;oMfRe0_mcH:h2og=KZ0;oO6B/0_mmHZP2oh1RYP;oQ6BU0on:
J:D2oi9^YP?oVWFX0onTOj/01on^RZoo`Yjcol:N/oo@[kWokMFkoo?bXol000000_nff?42ok;>k`04
ojo8k?n/`^[o[<;Zoj_0j@;oZ[kX00<00000ojZnj?nZ_^P05OnY_NP00`00003oooooooooo`0Aoooo
o`002Oooool01000003ooooooooooooooom^000000X06ATI0`00000G03<c<`8000002`0I6AT>0000
00Cooooo00<00000ooooooooool04Oooool00`00003oooooooooo`0Iooooo`04ocQHaon>LZooSW:_
ohib[`;oXGJR0onXMY`300000003oj]gVOn`NiWo/7ZH00;o/7ZH00Co/7ZIokN0VOngP9Wo]h2I0_ne
OiT01?o0RI[o_8JJokb6V_nlQYX4olJ@W@?odIjQ0_o`b:T00ooO/JSoZKgXojVmj00?ojVmj0;oZ;cW
0_nW^nL01?nV^NKoXkCUoij^honN[^<3oiJTg`;oSIOI0_n1Qm02ogEfaP03ofYV_?mlN/KoLfbl00;o
KF2c0_mYF:`2og=P[P;oLe^X00CoM5ZUogaT[?mmHZSoOF:X0_n0HZH3ohATY@;oRVRU0_nBKZH3oiYe
Z0?oY7n[0oo2W[<01_oR`kWokMFkoo?bXonjiOCo]]Saojo9k@?o[LC[00?o[<;ZojZojOnZ_nT00onZ
_^P00`00003oZKgXojVmj00EojVmj00300000?oooooooooo013ooooo0009ooooo`0400000?oooooo
ooooooooof`000002@0I6AT3000001`0<c<c00<0000001TI6@0I6AT0200I6AT>000000Cooooo00<0
0000ooooooooool04Oooool00`00003oooooooooo`0Jooooo`03ocQHaon>LZooSW:_00;oXGJR0`00
0003ojYfV@?o/7^I0_n`NYP4okN0V@;o]GnI00Co`8VJokb6V_nlQY[o_8JJ1?o6T9d3om6NX@;ol<RY
4_nY_NP00onX_>OoYk_WojJhiP02ojJhiP;oXkCU0_nN[^<3oiJTg`;oSIOI0_n1Qm000omeM/KoJVJl
ofYV_002og=/_0;oKF2c0_mYF:`2og=P[P03og=KZ?mdFZGoM5ZU00?oOF:X0_n0HZH2ohATY@?oRVRU
0_nBKZH3oiYeZ0;oY7n[0oo2W[<00ooR`kWon>fXo`000002ok;@k`;o[lW]00Go[LC[oj_0jOn[`>Wo
Z[oYojZnj004ojVmj00300000?nY_NSoZKgX01CoZKgX00<00000ooooooooool04?ooool000Wooooo
00@00000ooooooooooooooooJP00000701TI6@0400000?l000000000000000H0<c<c10000002o`00
00`00000200c<c<00`0000006ATI01TI6@0801TI6@d000001?ooool00`00003oooooooooo`0Aoooo
o`0300000?oooooooooo01[ooooo00?o>5S7ohib[`0000000P0000000onQMZ;oZ7JLojQfW003ojYf
V@?o/7^I0_n`NYP4okN0V@06okEoVOo0RI[o`8VJol29V_nlQY[ocINN0oo6T9d2omf/X`04om6NXOo`
b:Wol<RYoo38ZA7oZKgX0_nX_>P2ojNki`04ojJhi_nR]NKoWJkToif^i0?oUJGP0_n:UmX2ogf7dP;o
KWC80_meM/H00omZI[coHUVbof9I/P02ofeP/`;oJER/00?oJ5>Wog=P[_mcFjP00_mdFZD3ogQJX`;o
P6:V0_n4I:D3ohYXY@;oTVjV0onJMJP01?nTOj_o]8j_okB>[oo2W[<2on;3^@04ooS]Z?nbd>oo/]3_
ojg5j`?o[<;Z00?oZl3YojZnj?nZ_^P00_nZ_^P3ojVmj00300000?nY_NSoZKgX01GoZKgX00<00000
ooooooooool03oooool000Wooooo00@00000ooooooooooooooooI`00000901TI6@030000000c<c<0
<c<c00D0<c<c0`00000B04a<C0030000000c<c<0<c<c00D0<c<c00<0000001TI6@0I6AT0200I6AT=
000000Cooooo00<00000ooooooooool04Oooool00`00003oooooooooo`0Iooooo`<0000000CoSW:_
oj5fX_nQMZ;oXGJR0_nXMY`2ojYfV@06ojilW?n`NiWo/7^Iok1kVOn`NYSo^8>J1?ngP9T01OneOiWo
`8VJol29V_o0RI[o_8JJ00;ocINN0_o6T9d2omf/X`03om6NXOo`b:Wol<RY01;oZKgX00?oZ;cXojNk
ionU^NL00_nU^NL2oj:eiP;oWJkT0onEYN02ohZGfP;oOHOB00CoKWC8of1S__mPHkkoJVJl0_mRFK80
1?mLD:_oKF2cofUH[?mYF:`2ofQCY`;oLe^X00KoM5ZUogQJXomhFZ?oN5ZSogiMXon0HZH3ohATY@;o
RVRU0_nBKZH2oiYeZ009ojJ0ZondSZoo]8j_okB>[oo2W[?oh/>iooS]Z?o1eV7o[lW]00;o[LG[0_n/
`^X2ojZoj@03ojZnj?nY_^SoZKgX00GoZKgX00<00000ojVmj?nY_NP05OnY_NP00`00003ooooooooo
o`0>ooooo`002Oooool01000003ooooooooooooooomU000000P06ATI0`00000403<c<`@000005P1<
C4`2000000H0<c<c00<0000001TI6@0I6AT01`0I6AT=000000Cooooo00<00000ooooooooool04Ooo
ool00`00003oooooooooo`0Fooooo`<000000oooool01?n>LZooXGJRoj5fX_nQMZ82ojQfW003ojYf
VOn^O9co[WbL00?o/7^I00?o/7ZHokR3V_ngP9T00ongP9T01OneOiWo`8VJol29V_o0RI[o_8JJ00;o
cINN00CoaY2Momf/XooM[:?ogJbS0_ogkYd00oo`b:WoZKgXojVmj00?ojVmj0;oZ;cX0_nW^nL00onU
^NOoX[KVoif`i@02oif`i@?oU:OR00?oRI[MogZ9eomjRML00_mXM/d2ofidb004of1S__mEE;CoJVJl
of9I/P;oG52[00CoKF2cofUH[?mXDjOoJ5>W0_mcFjP2ogAJY@;oN5ZS0_mnGJ<3ohATY@;oRVRU0_nB
KZH00onJMJSoYX2[ojJ0Z`03okB>[`;oh/>i00Con>fXojo9kOn/`^[o[<;Z0_n[`>T2ojZoj@;oZ[kX
0_nY_^P6ojVmj00300000?nY_NSoZKgX01CoZKgX00<00000ooooooooool03_ooool000Wooooo00@0
0000ooooooooooooooooH`00000701TI6@<00000100c<c<3000000H0C4a<3@0000000ol000000000
0000000604a<C0030000000c<c<0<c<c00@0<c<c00<0000001TI6@0I6AT01P0I6AT=000000Cooooo
00<00000ooooooooool04Oooool00`00003oooooooooo`0Dooooo`8000001_ooool01?n>LZooXGJR
oj5fX_nQMZ82ojQfW0?o[WbL0on`NiT00on`NYSo^8>JokN0V@03okN0V@Co`8VJ00Co_8JJolfGW_o=
UikoaY2M0ooM[:<2ooO^WA;oZKgX00?oZ;cXojNkionU^NL00_nU^NL2oj:fiP03oif`iOnEZ^CoUJ[T
00;oRIkQ0_miS]`2ogZ9e`04ofQfcOmGH/?oEf;3of1S_P;oEEBd00CoHUVboea@ZomLD:_oG52[0_mY
F:`00omXDjOoJU:Sog=KZ002ogAJY@;oN5ZS0_mnGJ<3ohESX`;oSV^U0_nIM:L4ojJ0Z`;o]8j_00Ko
dJjfon;3^Oo;fVOo[LC[ojc2j_nZ_nT5ojZnj0[oZKgX00<00000ojVmj?nY_NP04?nY_NP3ooooo`03
00000?oooooooooo00kooooo0009ooooo`0400000?ooooooooooooooof40000000?o000001TI6@0I
6AT01@0I6AT00`000000<c<c03<c<`0403<c<`030000001<C4`0C4a<00D0C4a<00<00000o`00001V
IVH03`1VIVH00`000000C4a<04a<C00304a<C0030000000c<c<0<c<c00@0<c<c00<0000001TI6@0I
6AT01P0I6AT=000000Cooooo00<00000ooooooooool04?ooool00`00003oooooooooo`0Booooo`<0
00002Oooool3oj5fXP03ojQfW?nXOJKo[WbL00;o[WbL0on`NiT3okR3VP?o]h2I1?o0RIX3olfGWP03
olJ@WOoM[:?ogJbS00;omnjM4_nY_NP2ojRlj0;oYk_W00?oYKWWoj>gionS]nL00onM/^H2oiFZi0;o
RIkQ00?oNHkLofEke?mUNm@00_mXM/d01?mGH/?oAU2hof1S__mEE;@2of9I/P;oG52[0_mYF:`00omX
DjOoJU:SofYBX`02ogAJY@;oN5ZS0_mnGJ<3ohESX`;oSV^U0onIM:L3ojJ0Z`05okB>[ooA[[KodJjf
ooOS/on]a>/00_n[`>T2ojZoj@03ojZnj?nY_NSoZKgX00_oZKgX00<00000ojVmj?nY_NP03_nY_NP5
ooooo`0300000?oooooooooo00kooooo0009ooooo`0400000?ooooooooooooooof0000001`0I6AT2
000000@0<c<c0`00000404a<C0@000000`1VIVH8o`0000P0IVIV00<0000004a<C01<C4`00`1<C4`0
0`000000<c<c03<c<`0303<c<`030000000I6AT06ATI00H06ATI3@000004ooooo`0300000?oooooo
oooo013ooooo00<00000ooooooooool03oooool3000000cooooo0on6O<42ojQmYP?o[WbL0on`NiT3
okR3VP;o]h2I00?oaI2Nol29V_o0RIX00_o0RIX3olfGWP?ogJbS00?omnjMojVmj?nY_NP04OnY_NP0
0onX_>SoYk_XojNkj002ojJji`03oj>gionO]>OoWkCW00;oUjkV0_n<Y>D2ogbFh@;oIXCL00CoIG_D
odmUb_m?IL[oEf;30_m6D;P00omEE;CoCDV/of9I/P02oea@Z`03oe];Y_mYF:coJ5>W00;oJU:S0_m^
Dj800omdFZGoN5ZSogQJX`02ogiMX`;oQF>S0_n>JjD3oiUdY`?oYX2[0ooA[[H00oo;fVOoZl7Zoj_0
j@04ojZnj0koZKgX00<00000ojVmj?nY_NP02OnY_NP:ooooo`0300000?oooooooooo00gooooo0009
ooooo`0400000?oooooooooooooooeh00000200I6AT00`000000<c<c03<c<`0203<c<`800000101<
C4`3000000@0IVIV0ol0000807moO`Co00001@1VIVH00`000000C4a<04a<C00304a<C003o`00000c
<c<0<c<c0080<c<c00<0000001TI6@0I6AT01P0I6AT=000000Cooooo00<00000ooooooooool04?oo
ool00`00003oooooooooo`0<ooooo`<000004?ooool2ohIl`@;oZ7fV0on^O9`3ok1kV@?o^8>J0_ng
P9T00oo5T9ko`8VJol29VP02ol29VP?ocINN00?ol<VYomf/XooM[:<04_nY_NP3ojRlj003ojNkj?nV
^^SoY[[X00?oXkSW0_nO]>L2oiN^iP;oS:CU0_mlU^401omVQ=coBfgCod]]dom?IL[o>4nnoeMR`om6
D;P00_mEE;@00om=BJcoG52[oea@Z`02oe];YP;oJ5>W00CoJU:SofiCX_m^Dj;oKU>R0_mhFZ<2ogiM
X`;oQF>S0on>JjD2oiUdY`?oYX2[00Co_YVbom6^]_oghk?obmYW0_nZ_nT3ojZnj13oZKgX00<00000
ojVmj?nY_NP01OnY_NP=ooooo`0300000?oooooooooo00gooooo0009ooooo`0400000?oooooooooo
oooooe`0000000?o000001TI6@0I6AT0100I6AT00`00003o00000000000303<c<`0300000?l00000
C4a<0080C4a<0`00000306IVIPCo00003`1oOgl00ol00000IVIV06IVIP0306IVIP030000001<C4`0
C4a<0080C4a<00<0000003<c<`0c<c<00P0c<c<00`0000006ATI01TI6@0601TI6@03o`0000000000
000000X000001?ooool00`00003oooooooooo`0@ooooo`0300000?oooooooooo00Wooooo0`00000C
ooooo`;oQWc10onXOJH2ojilW0;o/7^I00Go^HRPokR3V_nhPi[o^8>JokN0V@03olF@WP;o`8VJ00?o
ejJTolfGW_o=Uih00oo`bJT00oogkYgoZKgXojVmj00AojVmj0CoZ;cX0_nV^^P00onS^>OoXKOXoiZb
j002oiZbj0;oT:[W00?oPYoVofb@i?m/T>@00_m?O=h02Om;KM?o;5C8odmUb_lhCkkoAU2hocY2[omE
E;CoCDV/odU2Y`02oea@Z`03oe];Y_mXDjOoJ5>W00;oJU:S0_m^Dj801?meF:;oN5ZSogiMXomnGJ<3
ohESX`;oSV^U0onIM:L01OnVP:_o_YVbokjI/_oA[[Komn>c00;oZ[oY0_nY_^PBojVmj00400000?nY
_NSoZKgXojVmj17ooooo00<00000ooooooooool03Oooool000Wooooo00@00000oooooooooooooooo
G000000601TI6@030000000c<c<0<c<c0080<c<c0P00000304a<C08000000`1VIVH3o`0000@0Ogmo
2ol0000407moO`03o`00001VIVH0IVIV00<0IVIV00<0000004a<C01<C4`00P1<C4`00`000000<c<c
03<c<`0203<c<`030000000I6AT06ATI00D06ATI3P000004ooooo`0300000?oooooooooo013ooooo
00<00000ooooooooool01_ooool3000001Oooooo0_n6O<42ojQmYP;o[WbL00?o/7^IokV8X?niR:00
0onhPiX01?ngP9WoaI2NolF@W_o5T9h2ol29VP;oejJT00CocINNoo39ZOo`bJWol<VY4_nY_NP5ojRl
j004ojNkj?nT^NSoY;WXojBij0;oXKOX00CoV[;XoiJ`jOn9ZN[oRJWZ0_mgW^X2ofb@i005odmlg_lY
H]CoBfgCobaDb?lhCkh00_m6D;P02?lj@ZooCDV/ode9[?m9@ZOoG52[oe];Y_mLBZ?oJ5>W0_mZDZ<2
ofiCXP;oMERR0omnGJ<2ohESX`;oSV^U0_nIM:L01_n[QZko_YVbokjI/_nnVK;oj<fkomoXO`;oZ[kX
00?oZKkXojVmj?nY_NP04_nY_NP00`00003oooooooooo`0Aooooo`0300000?oooooooooo00gooooo
0009ooooo`0400000?oooooooooooooooe/000001@0I6AT2000000<0<c<c0P00000304a<C0800000
0P1VIVH3o`0000<0Ogmo1?l0000;09VIV@;o00000`1oOgl00ol00000IVIV06IVIP0206IVIP030000
001<C4`0C4a<0080C4a<00<0000003<c<`0c<c<00P0c<c<00`0000006ATI01TI6@0501TI6@h00000
1?ooool00`00003oooooooooo`0@ooooo`0300000?oooooooooo00?ooooo0`00000Jooooo`;oQWc1
0_nXOJH2ojilW003ok1kVOniR:3o^HRP00?o^8>J00Go]h2IolF@W_o5T9koaI2Nol29VP03omNVY004
olfGW_o`bJWol<VYoo39ZA?oZKgX1?nX_>P2ojNkj003ojBij?nR^NSoX[WX00;oWKGY0_nF/>T2ohVY
jP;oMikZ00_oG8kXocAhh_ldN>;o:F;DobaDb?l:>[[o>4nnodI@^?lj@Zoo<CRYode9[002odU2Y`03
oe];Y_mLBZ?oG4ZS00;oJU:S0_m^Dj82ogEHXP?oOenT0_n5Hj<2ohi[Y@03oiUdYon[QZkoZhJ^00?o
_YVb00?oj<fkojZnj?nZ_^P04_nY_NP5ooooo`0300000?oooooooooo013ooooo00<00000oooooooo
ool03Oooool000Wooooo00@00000ooooooooooooooooF@00000501TI6@8000000`0c<c<2000000<0
C4a<0P00000206IVIP;o00000P1oOgl4o`0000<0VIVI2Ol0000509VIV@05o`00001oOgl0Ogmo07mo
Ool000000`1VIVH00`000000C4a<04a<C00204a<C003o`00000c<c<0<c<c0080<c<c00<0000001TI
6@0I6AT0100I6AT?000000Cooooo00<00000ooooooooool03oooool01000003oooooooooooooool3
000001kooooo00?oQWc1ojQmY_nXOJH00_n^O9`4okV8X0;o^8>J1?o5T9h01?o0RI[oejJTomNVY?oG
YZ@3oo39ZAKoZKgX00?oZ;cXojNlj?nW_>P00_nU^nP00onR^NSoXKSYoi^ej`02oi^ej`;oTK7/0_n3
Z^h2ofjPk`07odfAk_ldN>;o05OBo`1Gd_l0@/Co2SZjob8l]002ocY2[`03oc4hZOm9@ZOoBD:W00;o
Fd^V00?oG4ZSof5<X_mZDZ<00_m^Dj82ogEHXP?oOenT0_n;JJH00on>JjGoVGJYoj^6[P03oj^6[P04
okjI/_oXcK_ognQoojVnj17oZKgX2?ooool00`00003oooooooooo`0?ooooo`0300000?oooooooooo
00gooooo0009ooooo`0400000?oooooooooooooooeH0000000?o000001TI6@0I6AT0100I6AT00`00
0000<c<c03<c<`0203<c<`030000001<C4`0C4a<0080C4a<00<00000o`00001VIVH00_l0000207mo
O`;o0000102IVIT3o`0000T0/k>c00?o000009VIV@2IVIT00P2IVIT01Ol00000Ogmo07moO`1oOgoo
000000<0IVIV00<0000004a<C01<C4`00P1<C4`00`000000<c<c03<c<`0203<c<`030000000I6AT0
6ATI00@06ATI3`000004ooooo`0300000?oooooooooo00oooooo1000000Rooooo`;oZ7fV00?o[WbL
okJC/oniR:000oniR:02okR3VPCoaI2N00Ko`8VJomNVY?oGYZCoejJTom7ZQOo`bJTEojVmj0?oZ;cX
00?oYkcXojJlj?nT^^T00_nT^^T2oj6hj@03oi^ejonI]^coSk?_00;oSk?_0_n1[_82ofZWm@08odNL
m?lKNNGo05OBo`0[[Ol:>[[o022[o`l/Zolj@Zl2oc4hZ@04odU2Yom9@:CoFd^Voea:X`;oHDbR00Co
JU:SofiCX_m^Dj;oMERR0omoGj@2oh]YYP?oVGJY0on[QZh00onnVK;oj<fkomoXO`0>ojVmj0cooooo
00<00000ooooooooool03oooool00`00003oooooooooo`0=ooooo`002Oooool01000003ooooooooo
oooooomF000000H06ATI00<0000003<c<`0c<c<00P0c<c<010000000C4a<04a<C01<C4`200000080
IVIV00?o000007moO`1oOgl00_l0000309VIV@?o0000302c/k<00ol00000VIVI09VIV@0209VIV@05
o`00001oOgl0Ogmo07moOol000000`1VIVH00`000000C4a<04a<C00204a<C0050000000c<c<0<c<c
03<c<`0000001`0I6AT?000000Cooooo00<00000ooooooooool03oooool00`00003o0000ooooo`0T
ooooo`03obNGk_nfTk?o]Y>c00Co^HRP00?o^8>JolbOZ?o5T9h00oo5T9h4omNVY003om7ZQOnY_NSo
ZKgX01GoZKgX0onX_>P2ojJlj003ojBjjOnS^^WoXk[Y00;oWkW[0_nI]^`00on?/nooT;Oaoi2gl@02
oh>em@;oKk;i00OoCjcio`n5i?l?QNCo02^]o`Xj^_l08:_o3bb[00;o<CRY00?oBD:WodU0Y?m9@:@0
0_mLBZ<2of5<XP;oKU>R00CoMERRogmOY?moGjCoOenT0_n;JJH3oiUfZ@?oZhJ^00?ock6konS=^onY
_NP03?nY_NP?ooooo`0300000?oooooooooo00oooooo00<00000ooooooooool03?ooool000Wooooo
00@00000ooooooooooooooooE@00000601TI6@030000000c<c<0<c<c0080<c<c00D0000004a<C01<
C4`0C4a<0000000206IVIP;o00000P1oOgl01?l00000VIVI09VIV@2IVIT2o`0000@0/k>c1ol00005
0;>c/`03o`00002IVIT0VIVI0080VIVI00Co000007moO`1oOgoo00000`1VIVH01@000000C4a<04a<
C01<C4`0000000@0<c<c00<0000001TI6@0I6AT0100I6AT@000000Cooooo00<00000ooooooooool0
4Oooool00ol0003oooooooooo`0Rooooo`04obNGk_nfTk?o]Y>cokJC/`?o^HRP00?o^8>JolbOZ?o<
WjP00oo5T9h3omNVY003om7ZQOnY_NSoZKgX01OoZKgX00?oZ;cXojNlj?nW_>P00_nV^nT00onS^^Wo
Xk_Zoj>kjP02oinjk0;oVKS^00?oT;Oaoi>kl_nC^o800_n9_?L2og^mo0;oI[kn0_m7^_D2o`0PZ`05
o`l/Zola>:Wo;3:UodU2Yom9@:@00_mLBZ<2of5<XP04ofUAXom^Dj;oMERRogEHXP;oOenT0_n;JJH3
oiUfZ@?oZhJ^00?ock6koo;cYonY_NP02?nY_NPDooooo`0300000?oooooooooo00kooooo00<00000
ooooooooool03?ooool000Wooooo00@00000ooooooooooooooooE000000501TI6@8000000`0c<c<2
00000080C4a<00<00000o`00001VIVH00_l0000207moO`;o00000P2IVIT2o`000080/k>c1?l00007
0<c<c0;o0000102c/k<01Ol00000VIVI09VIV@2IVIWo00000080Ogmo00Go000006IVIP1VIVH0IVIV
0000000304a<C0050000000c<c<0<c<c03<c<`0000001`0I6AT00ol0000000000000000=000000Co
oooo00<00000ooooooooool04_ooool00ol0003oooooooooo`0Rooooo`03obNGk_nfTk?o]Y>c00?o
^HRP00?o^8>JolbOZ?o<WjP00_o5T9h2ong>]003omNVY?oAjXGoZKgX01OoZKgX0onX_NP2ojNlj0?o
YKcY00?oXk_Zoj>ljonO^n`00_nO^n`2oiZkk`03oi>kl_nI_o;oVKob00;oT/;g00CoRlGkoiS8n?nH
b?SoV<Sh0_nEcO/02?l08:_o3bb[oc4hZOla>:WoBD:WodU0Y?m=@ZCoG4ZS0_mQC:82ofUAX`;oMERR
0omoGj@2oh]YYP?oVGJY00?oZhJ^olna^oo?/K/01OnY_NPJooooo`0300000?oooooooooo00gooooo
00<00000ooooooooool03?ooool000Wooooo00@00000ooooooooooooooooD`00000501TI6@030000
000c<c<0<c<c0080<c<c00<0000004a<C01<C4`00P0000000`1VIVKo0000o`00000207moO`;o0000
00D0VIVIo`000?l0003o00000;>c/`03o`0000`0c<c<00?o00000;>c/`2c/k<00P2c/k<01Ol00000
VIVI09VIV@2IVIWo00000080Ogmo00Go000006IVIP1VIVH0IVIV0000000304a<C0050000000c<c<0
<c<c03<c<`0000001P0I6ATA000000Cooooo00<00000ooooooooool04oooool00ol0003ooooooooo
o`0Qooooo`03obNGk_nfTk?o]Y>c00;o^HRP00GofMWHolbOZ?o<WjSoc9nXolF@WP03ong>]003omNV
Y?ooooooZKgX01SoZKgX0onX_NP2ojNlj0?oYKcY0_nS_>/00onO^ncoXKg]oj6mk@02oifnk`03oiVo
l_nN`O7oW/7a00?oVlCd00[oV<Shoj77lonQao?oXL[eojK6l?l08:_o3bb[oc4hZOl/<ZGoBD2T0_m=
@Z@01_mLBZ?oHDbRofUAXomYDJ?oME^VogEHXP?oOenT0_n;JJH2oiUfZ@04ok>D]oo?/K_ock6koo;c
Y`?oZKgX7?ooool00`00003oooooooooo`0=ooooo`0300000?oooooooooo00cooooo0009ooooo`04
00000?oooooooooooooooe8000001@0I6AT00`000000<c<c03<c<`0203<c<`040000001<C4`0C4a<
00000080IVIV00Go000007moO`1oOgl0Ogmoo`00000209VIV@03o`00002c/k<0/k>c00;o00001P3<
c<`5o`0000D0c<c<00Co00000;>c/`2c/k?o00000`2IVIT01?l00000Ogmo07moOol0000306IVIP05
0000001<C4`0C4a<04a<C00000000`0c<c<00`0000006ATI01TI6@0401TI6A8000001?ooool00`00
003oooooooooo`0Dooooo`;o00008_ooool2okJC/`03okV8X?oIfMSofMWH00?oc9nX00CoaI2Nong>
]?o]c[CokLjd0ooooolIojVmj0?oZ;gX0_nW_>T00onU_>WoY[gZojJmjP02ojBmj`03oj6mkOnS_^co
Xkk/00;oXKo^00CoW/7aoj?2konS`^ooXl;_0_nRa?402?nQao?oY/C_ojK4konVa_3oZ<;/o`07VOl0
7jGo;3:U0_m9@:@2ode2Y0;oHDbR00?oJE6SogEKY_meFjH00omoGj@2oh]YYP06oiUfZOncU;Oo/iBg
ok>D]oo?/K_ol_>W8?ooool00`00003oooooooooo`0<ooooo`0300000?oooooooooo00cooooo0009
ooooo`0400000?ooooooooooooooodl0000000?o00000000000I6AT0100I6AT00`000000<c<c03<c
<`0203<c<`040000001<C4`0C4a<00000080IVIV00Ko000007moO`1oOgl0Ogmoo`00002IVIT2o`00
0080/k>c00?o00000<c<c03<c<`00P3<c<`4o`0000D0i^KV00?o00000<c<c03<c<`00P3<c<`01?l0
0000/k>c0;>c/ol0000309VIV@04o`00001oOgl0Ogmoo`000080IVIV00Go000004a<C01<C4`0C4a<
o`00000303<c<`030000000I6AT06ATI00@06ATI4`000004ooooo`0300000?oooooooooo01Kooooo
00?o0000ooooooooool08oooool2omWIf0;oc9nX0_ooool00oo]c[Coooooooooo`03oooooaWoZKgX
0onX_NP2ojNmj@?oY[gZ0_nU_N/01?nS_^coYKo/ojFok?nU_n`2ojC0k@03oj?2konV`NgoY/7]00;o
Y/?^00WoY/C_ojS2k?nX`^coZ<;/ojW0j_l07jGo;3:Uob/cY_m9@:@00_m=@Z@2of5<XP03ofUAXome
FjKoME^V00?oQFV[00?oRfVVoiYk/?ncU;L00oncU;L00oo/i<Soooooooooo`0Pooooo`0300000?oo
oooooooo00_ooooo00<00000ooooooooool03?ooool000Wooooo00@00000ooooooooooooooooC`00
000601TI6@030000000c<c<0<c<c0080<c<c00Co000004a<C01<C4co00000`1VIVH01_l00000Ogmo
07moOol00000VIVIo`0000<0/k>c00Co00000<c<c03<c<`0c<c<0_l000090>KViP03o`00003<c<`0
c<c<0080c<c<00Co00000;>c/`2c/k?o00000`2IVIT00ol00000Ogmoo`00000306IVIP040000001<
C4`0C4a<000000@0<c<c00<0000001TI6@0I6AT0100I6ATC000000Cooooo00<00000ooooooooool0
5oooool00ol0003oooooooooo`0Tooooo`03olbOZ?oooooooooo00Sooooo5onY_NP6ojRmj0;oYkgY
00?oY[gZojNmjOnW_NT00_nV_^/00onU_ncoYko[ojNoj`02ojK0k003ojK1kOnX`>_oZ<3[00;oZ<7/
00SoZ<;/ojW0j_nY`>[oZL3ZojVnjOl06:;o;3:UodU0Y0;oCD:T00CoETVWof5<X_mYDJ?oJE6S0_me
FjH2ohEYZ`;oVW^`1?ncU;L00oo/i<Soooooooooo`0Qooooo`0300000?oooooooooo00[ooooo00<0
0000ooooooooool03?ooool000Wooooo00@00000ooooooooooooooooCP00000601TI6@030000000c
<c<0<c<c0080<c<c00@0000004a<C01<C4`000000`1VIVH01_l00000Ogmo07moOol00000VIVIo`00
00<0/k>c00?o00000<c<c03<c<`00_l0000;0>KViP05o`00003<c<`0c<c<0<c<c?l000000P2c/k<0
1Ol00000VIVI09VIV@2IVIWo00000080Ogmo00Co000006IVIP1VIVH000000`1<C4`01@000000<c<c
03<c<`0c<c<0000000H06ATI50000004ooooo`0300000?oooooooooo01Sooooo00?o0000oooooooo
ool0;ooooolGojVmj003ojRmj?nY_NSoZKgX00;oZ;gX0onX_NT00onW_NWoZ;kYojNnjP02ojNnjP03
ojNojonX_^[oZ;kZ00;oZ;oZ00?oZ<3[ojVojOnY_nT00_nY_nX01onY`>[oZKkYojVnjOnY_^Wo01nU
ob`bYOl[<jH00_m=@Z@2oeI9Y`;oJE6S0_meFjH2ohEYZ`?oVW^`0_ncU;L00oo/i<Soooooooooo`0R
ooooo`0300000?oooooooooo00_ooooo00<00000ooooooooool02oooool000Wooooo00@00000oooo
ooooooooooooC@00000601TI6@030000000c<c<0<c<c0080<c<c00@0000004a<C01<C4`000000`1V
IVH01_l00000Ogmo07moOol00000VIVIo`0000<0/k>c00Co00000<c<c03<c<co0000303Vi^H00ol0
0000c<c<0<c<c0020<c<c004o`00002c/k<0/k>co`000080VIVI0_l000001@1oOgoo000006IVIP1V
IVH0000000<0C4a<00@0000003<c<`0c<c<0<c<c0P00000501TI6@03o`0000000000000001800000
1?ooool00`00003oooooooooo`0Iooooo`;o0000<?oooolJojVmj0;oZ;gX0onX_NT2ojRnj@04ojNn
j_nX_^WoZ;kYojRnjPCoZKkY00?oZKoYojVnjOnY_^T00onY_^T3ojVnj003o`0HX_l[<jKo<3Z[00;o
CD:T00?oETVWofAF[?mYDJ<00_meFjH3ohEYZ`;oVW^`00?o/iBgoncTb?o/i<P09Oooool00`00003o
ooooooooo`0:ooooo`0300000?oooooooooo00_ooooo0009ooooo`0400000?oooooooooooooood/0
000000?o000001TI6@0I6AT0100I6AT01_l00000<c<c03<c<`0c<c?o000000000080C4a<00<00000
06IVIP1VIVH00_l0000207moO`04o`00002IVIT0VIVIo`000080/k>c00Go00000<c<c03<c<`0c<c<
o`00000<0>KViP05o`00003<c<`0c<c<0<c<c?l000000P2c/k<01?l00000VIVI09VIVOl0000207mo
O`04o`00001VIVH0IVIVo`0000<0C4a<00Go000003<c<`0c<c<0<c<c0000000701TI6AD000001?oo
ool00`00003oooooooooo`0Kooooo`03o`000?oooooooooo02kooooo7?nY_NP00onX_NWoZKgXojVm
j003ojRnj@SoZKkY1OnY_^P2ojVmj006o`0HX_l05ZCo:c>Voc0jZom=@ZCoETVW0_mTEZ`3ogEKYP;o
QFV[0_nJNk02olFhcBOooooo00<00000ooooooooool02Oooool00`00003oooooooooo`0;ooooo`00
2Oooool01000003ooooooooooooooom<000000H06ATI00D0000003<c<`0c<c<0<c<c0000000304a<
C0040000001VIVH0IVIVo`000080Ogmo00Co000009VIV@2IVIWo00000P2c/k<01Ol00000c<c<0<c<
c03<c<co000000`0i^KV00Go00000<c<c03<c<`0c<c<o`0000030;>c/`03o`00002IVIWo000000<0
Ogmo00?o000006IVIP0000000`1<C4`01@000000<c<c03<c<`0c<c<0000000L06ATI5P000004oooo
o`0300000?oooooooooo01cooooo00?o0000ooooooooool0;_oooolOojVmj0;oZKkX00?oZKkYojVn
j?nY_^P00_nY_^P00onY_^WoZKkXojVnj003ojVnj0?oZKgX0_ooool01?l06:;o01JToc0jZol`>Z/2
oeI9Y`04ofAF[?mjJkKoNV^fogY[]P;oQFV[00CoVW^`olFhcOo5^<goaKS=:?ooool00`00003ooooo
ooooo`08ooooo`0300000?oooooooooo00_ooooo0009ooooo`0400000?oooooooooooooood/00000
1P0I6AT01@000000<c<c03<c<`0c<c<0000000<0C4a<00@0000006IVIP1VIVKo00000P1oOgl01?l0
0000VIVI09VIVOl000020;>c/`05o`00003<c<`0c<c<0<c<c?l00000303Vi^H01Ol00000c<c<0<c<
c03<c<co000000<0/k>c00?o000009VIVOl000000P1oOgl2o`00000306IVIP000000C4a<0080C4a<
00D0000003<c<`0c<c<0<c<co`00000701TI6AL000001?ooool00`00003oooooooooo`0Mooooo`03
o`000?oooooooooo02kooooo8OnY_NP00onY_^SoZKgXojVmj002ojVmj003ojVnj?nY_NSoZKgX00?o
ZKgX1Oooool2o`0FY003oc0jZollBkSoETVW00;oI5J/0_mjJkH2oiZ;`P?oaKS=:Oooool00`00003o
ooooooooo`08ooooo`0300000?oooooooooo00_ooooo0009ooooo`0400000?ooooooooooooooodP0
000000?o00000000000I6AT0100I6AT00ol00000000003<c<`0203<c<`050000001<C4`0C4a<04a<
C00000000P1VIVH01?l00000Ogmo07moOol0000209VIV@04o`00002c/k<0/k>co`0000<0c<c<00?o
00000>KViP3Vi^H02@3Vi^H2o`000080c<c<0_l000001P2c/k?o0000o`000?l00000VIVIo`000080
Ogmo00Co000006IVIP1VIVH000000`1<C4`01@000000<c<c03<c<`0c<c<0000000H06ATI00<00000
o`00000000005P000004ooooo`0300000?oooooooooo01kooooo0_l0000_ooooobOoZKgX2oooool0
0ol`>Z_o?4^hoca;^002ofAF[0?oNV^f0_nJRl800oo5^<goooooooooo`0Yooooo`0300000?oooooo
oooo00Oooooo00<00000ooooooooool02oooool000Wooooo00@00000ooooooooooooooooB@000006
01TI6@050000000c<c<0<c<c03<c<ol000000`1<C4`010000000IVIV06IVI_l0000207moO`05o`00
002IVIT0VIVI09VIVOl000000P2c/k<00ol00000c<c<0<c<c0020<c<c003o`00003Vi^H0i^KV00L0
i^KV00Go00000<c<c03<c<`0c<c<o`0000020;>c/`05o`00002IVIT0VIVI09VIVOl000000P1oOgl0
1Ol00000IVIV06IVIP1VIVH000000080C4a<00<0000003<c<`0c<c<00P0c<c<00`0000006ATI01TI
6@0401TI6AT000001?ooool00`00003oooooooooo`0Pooooo`03o`000?oooooooooo02gooooo8_nY
_NP@ooooo`04oc0jZollBkSoEg3@oeM`d0?oNV^f00?oVX_2okcmeoooool0;?ooool00`00003ooooo
ooooo`07ooooo`0300000?oooooooooo00[ooooo0009ooooo`0400000?ooooooooooooooodP00000
1P0I6AT00`000000<c<c03<c<`0203<c<`040000001<C4`0C4a<000000<0IVIV00Co000007moO`1o
Ogoo00000P2IVIT01Ol00000/k>c0;>c/`2c/k?o000000D0c<c<00?o00000>KViP3Vi^H0103Vi^H2
o`000080c<c<0_l000020;>c/`03o`00002IVIT0VIVI00;o00000P1oOgl00ol00000IVIV06IVIP02
00000080C4a<00<0000003<c<`0c<c<00P0c<c<00`0000006ATI01TI6@0401TI6AX000001?ooool0
0`00003oooooooooo`0Qooooo`03o`000?oooooooooo02kooooo7_nY_NPCooooo`;o?4^h0_mGL=00
0omjJkKoS[_eohjkm@0_ooooo`0300000?oooooooooo00Kooooo00<00000ooooooooool02_ooool0
00Wooooo00@00000ooooooooooooooooB000000601TI6@050000000c<c<0<c<c03<c<`0000000`1<
C4`010000000IVIV06IVI_l0000207moO`05o`00002IVIT0VIVI09VIVOl000000P2c/k<00ol00000
c<c<0<c<c0050<c<c0Ko00000`3<c<`01Ol00000/k>c0;>c/`2c/k?o00000080VIVI00Go000007mo
O`1oOgl0Ogmoo`00000206IVIP050000001<C4`0C4a<04a<C00000000`0c<c<2000000H06ATI00?o
000000000000000060000004ooooo`0300000?oooooooooo02;ooooo00?o0000ooooooooool0;_oo
oolIojVmj1Wooooo0omGL=000on>^oGoooooooooo`0^ooooo`0300000?oooooooooo00Kooooo00<0
0000ooooooooool02_ooool000Wooooo00@00000ooooooooooooooooA`00000601TI6@030000000c
<c<0<c<c0080<c<c00@0000004a<C01<C4`000000`1VIVH01?l00000Ogmo07moOol0000209VIV@05
o`00002c/k<0/k>c0;>c/ol000003@3<c<`3o`0000<0/k>c00Go000009VIV@2IVIWo000007moO`03
o`00000306IVIP00003o000000<0C4a<00Go000003<c<`0c<c<0<c<c0000000601TI6Ad000001?oo
ool00`00003oooooooooo`0Sooooo`03o`000?oooooooooo02kooooo5?nY_NQBooooo`0300000?oo
oooooooo00Gooooo00<00000ooooooooool02_ooool000Wooooo00@00000ooooooooooooooooA@00
00000ol000006ATI01TI6@0401TI6@03o`00000c<c<0<c<c00<0<c<c00@0000004a<C01<C4`00000
0`1VIVH01?l00000Ogmo07moOol0000209VIV@05o`00002c/k<0/k>c0;>c/ol00000303<c<`01?l0
0000/k>c0;>c/`2c/k<3o`00000509VIVOl0003o000007moOol000000`1VIVH010000000C4a<04a<
C01<C4`2000000<0<c<c00<0000001TI6@0I6AT0100I6ATN000000Cooooo00<00000ooooooooool0
9?ooool2o`0002oooooo4?nY_NQFooooo`0300000?oooooooooo00Cooooo00<00000ooooooooool0
2_ooool000Wooooo00@00000ooooooooooooooooAP00000601TI6@030000000c<c<0<c<c0080<c<c
00@0000004a<C01<C4`000000`1VIVH01Ol00000Ogmo07moO`1oOgoo000000<0VIVI00Co00000;>c
/`2c/k<0/k>c0ol000060<c<c0?o000000@0/k>co`000?l0003o00000`2IVIT01?l00000Ogmo07mo
Ool0000306IVIP030000001<C4`0C4a<008000000`0c<c<2000000D06ATI80000004ooooo`030000
0?oooooooooo02Kooooo00?o0000ooooooooool0;Oooool=ojVmj5Sooooo00<00000ooooooooool0
1?ooool00`00003oooooooooo`0:ooooo`002Oooool01000003ooooooooooooooom5000000H06ATI
00<0000003<c<`0c<c<00P0c<c<01@000000C4a<04a<C01<C4`0000000<0IVIV00Go000007moO`1o
Ogl0Ogmoo`00000309VIV@03o`00002c/k<0/k>c00@0/k>c1_l000030;>c/`04o`00002IVIT0VIVI
09VIV@?o000000@0Ogmoo`000?l00000IVIV0P0000001?l00000C4a<00000000000403<c<`03o`00
000I6AT06ATI00@06ATI8@000004ooooo`0300000?oooooooooo02Oooooo00?o0000ooooooooool0
;Oooool8ojVmj5gooooo00<00000ooooooooool00oooool00`00003oooooooooo`0:ooooo`002Ooo
ool01000003ooooooooooooooom5000000H06ATI00<0000003<c<`0c<c<00P0c<c<01@000000C4a<
04a<C01<C4`0000000<0IVIV00Go000007moO`1oOgl0Ogmoo`00000309VIV@03o`00002c/k<0/k>c
00X0/k>c0ol00000102IVIWo0000o`000?l0000307moO`04o`00001VIVH0IVIV000000<0C4a<00<0
000003<c<`0c<c<00P0c<c<2000000L06ATI8@000004ooooo`0300000?oooooooooo02Sooooo00?o
0000ooooooooool0;Oooool3ojVmj6;ooooo00<00000ooooooooool00oooool00`00003ooooooooo
o`09ooooo`002Oooool01000003ooooooooooooooom4000000L06ATI00<0000003<c<`0c<c<00P0c
<c<01@000000C4a<04a<C01<C4`0000000<0IVIV00?o000007moO`1oOgl00P1oOgl01?l00000VIVI
09VIV@2IVIT<o`0000<0VIVI00Co000007moO`1oOgl0Ogmo0ol000000`1VIVH000000000000204a<
C0800000100c<c<00`0000006ATI01TI6@0501TI6B<000001?ooool00`00003oooooooooo`0Yoooo
o`;o0000;Oooool00ol0003oooooooooo`1Sooooo`0300000?oooooooooo00;ooooo00<00000oooo
ooooool02Oooool000Wooooo00@00000ooooooooooooooooA000000601TI6@030000000c<c<0<c<c
00<0<c<c00D0000004a<C01<C4`0C4a<0000000306IVIP03o`00001oOgl0Ogmo0080Ogmo00?o0000
09VIV@2IVIT03P2IVIT2o`000080Ogmo0_l0000306IVIP050000001<C4`0C4a<04a<C00000001@0c
<c<00`0000006ATI01TI6@0501TI6B@000001?ooool00`00003oooooooooo`0[ooooo`03o`000?oo
oooooooo02[ooooo00?o0000ooooooooool0Hoooool00`00003oooooooooo`02ooooo`0300000?oo
oooooooo00Wooooo0009ooooo`0400000?oooooooooooooood<000001`0I6AT00`000000<c<c03<c
<`0203<c<`030000001<C4`0C4a<0080C4a<00D0000006IVIP1VIVH0IVIVo`00000507moO`?o0000
2@2IVIT4o`000080Ogmo0_l0000206IVIP<0000000@0C4a<00000000003o0000100c<c<2000000D0
6ATI0P0000000ol0000000000000000R000000Cooooo00<00000ooooooooool0;?ooool00ol0003o
ooooooooo`0Yooooo`03o`000?oooooooooo06Cooooo00D00000oooooooooooooooo0000000;oooo
o`002Oooool01000003ooooooooooooooom200000003o`00000I6AT06ATI00D06ATI00<0000003<c
<`0c<c<00P0c<c<00`000000C4a<04a<C00204a<C0030000001VIVH0IVIV0080IVIV00?o000007mo
O`1oOgl01@1oOgl9o`0000<0Ogmo0ol00000101VIVH0000000000000000304a<C0030000000c<c<0
<c<c00@0<c<c00<0000001TI6@0I6AT0100I6ATX000000Cooooo00<00000ooooooooool0;Oooool0
0ol0003oooooooooo`0Xooooo`03o`000?oooooooooo06Gooooo00@00000ooooooooool000002ooo
ool000Wooooo00@00000oooooooooooooooo@`00000701TI6@030000000c<c<0<c<c00<0<c<c00<0
000004a<C01<C4`00P1<C4`00`000000IVIV06IVIP0206IVIP?o00003@1oOgl3o`0000<0IVIV00<0
000004a<C01<C4`00P1<C4`2000000D0<c<c0P00000501TI6BX000001?ooool00`00003ooooooooo
o`0^ooooo`;o0000:?ooool00ol0003oooooooooo`1Vooooo`0300000?ooool0000000_ooooo0009
ooooo`0400000?oooooooooooooood800000200I6AT00`000000<c<c03<c<`0303<c<`03o`00001<
C4`0C4a<00<0C4a<00<0000006IVIP1VIVH0101VIVH=o`0000<0IVIV0P0000001?l00000C4a<04a<
C01<C4`2000000<0<c<c0P0000000ol00000000001TI6@0401TI6B`000001?ooool00`00003ooooo
ooooo`0`ooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool0I_ooool00`00003ooooo
0000000;ooooo`002Oooool01000003ooooooooooooooom2000000P06ATI00<0000003<c<`0c<c<0
0`0c<c<00`000000C4a<04a<C00304a<C003o`000000000000000140IVIV0`00000404a<C0800000
100c<c<00`0000006ATI01TI6@0601TI6Bd000001?ooool00`00003oooooooooo`0aooooo`03o`00
0?oooooooooo02Cooooo00?o0000ooooooooool0Ioooool00`00003ooooo0000000:ooooo`002Ooo
ool01000003ooooooooooooooom2000000P06ATI00<0000003<c<`0c<c<0100c<c<00`000000C4a<
04a<C00504a<C0@000002@1VIVH4000000<0C4a<1000000403<c<`800000200I6AT^000000Cooooo
00<00000ooooooooool0<_ooool00ol0003oooooooooo`0Sooooo`03o`000?oooooooooo06Sooooo
0P00000:ooooo`002Oooool01000003ooooooooooooooom2000000T06ATI00<0000003<c<`0c<c<0
100c<c<00`000000C4a<04a<C00804a<C0T000001@1<C4`00ol00000000003<c<`0603<c<`030000
000I6AT06ATI00L06ATI;`000004ooooo`0300000?oooooooooo03?ooooo0_l0000Sooooo`03o`00
0?oooooooooo06Oooooo0_l000000`00003oooooooooo`08ooooo`002Oooool01000003ooooooooo
oooooom2000000T06ATI00<0000003<c<`0c<c<01@0c<c<300000100C4a<1@00000603<c<`800000
00?o000001TI6@0I6AT01@0I6AT200000003o`0000000000000002d000001?ooool00`00003ooooo
ooooo`0eooooo`03o`000?oooooooooo023ooooo00?o0000ooooooooool0Hoooool4o`0000gooooo
0009ooooo`0400000?oooooooooooooood8000002@0I6AT00`000000<c<c03<c<`0803<c<`<00000
2P1<C4`3000000L0<c<c1000000701TI6CD000001?ooool00`00003oooooooooo`0fooooo`03o`00
0?oooooooooo01oooooo00?o0000ooooooooool0H?ooool3o`00017ooooo0009ooooo`0400000?oo
oooooooooooood<000002@0I6AT2000000/0<c<c2P00000703<c<`<000002P0I6ATf000000Cooooo
00<00000ooooooooool0=oooool00ol0003oooooooooo`0Nooooo`03o`000?oooooooooo05cooooo
1?l0000Dooooo`002Oooool01000003ooooooooooooooom3000000/06ATI0P00000F03<c<`<00000
00?o000001TI6@0I6AT0200I6AT200000003o`0000000000000003@000001?ooool00`00003ooooo
ooooo`0hooooo`;o00007_ooool00ol0003oooooooooo`1Hooooo`Co00006?ooool000Wooooo00@0
0000oooooooooooooooo@`00000=01TI6@<00000400c<c<3000000/06ATI?0000004ooooo`030000
0?oooooooooo03[ooooo00?o0000ooooooooool06oooool00ol0003oooooooooo`1Dooooo`Co0000
7?ooool000Wooooo00@00000ooooooooooooooooA000000?01TI6@<000001P0c<c<7000000d06ATI
?@000004ooooo`0300000?oooooooooo03_ooooo00?o0000ooooooooool06_ooool00ol0003ooooo
ooooo`1Aooooo`?o00008?ooool000Wooooo00@00000ooooooooooooooooA000000B01TI6@H00000
4P0I6ATo000000Cooooo00<00000ooooooooool0??ooool00ol0003oooooooooo`0Iooooo`03o`00
0?oooooooooo04gooooo1?l0000Sooooo`002Oooool01000003ooooooooooooooom5000002D06ATI
@`000004ooooo`0300000?oooooooooo03gooooo0_l0000Iooooo`03o`000?oooooooooo04Wooooo
1?l0000Wooooo`002Oooool01000003ooooooooooooooom500000003o`00000000006ATI01h06ATI
A`000004ooooo`0300000?oooooooooo03oooooo00?o0000ooooooooool05_ooool00ol0003ooooo
ooooo`15ooooo`Co0000:oooool000Wooooo00@00000ooooooooooooooooB@00000J01TI6DX00000
1?ooool00`00003oooooooooo`10ooooo`03o`000?oooooooooo01Cooooo00?o0000ooooooooool0
@oooool3o`0002oooooo0009ooooo`0400000?oooooooooooooood`000004`0I6AU>000000Cooooo
00<00000ooooooooool0@Oooool00ol0003oooooooooo`0Cooooo`03o`000?oooooooooo03oooooo
1?l0000booooo`002Oooool01000003ooooooooooooooomC000000D06ATIE@000004ooooo`030000
0?oooooooooo04;ooooo0_l0000Cooooo`03o`000?oooooooooo03_ooooo1?l0000fooooo`002Ooo
ool01000003ooooooooooooooon]000000Cooooo00<00000ooooooooool0A?ooool00ol0003ooooo
ooooo`0@ooooo`03o`000?oooooooooo03Oooooo1?l0000jooooo`002Oooool01000003ooooooooo
oooooon]000000Cooooo00<00000ooooooooool0AOooool00ol0003oooooooooo`0?ooooo`03o`00
0?oooooooooo03?ooooo1?l0000nooooo`002Oooool01000003ooooooooooooooon]000000Cooooo
00<00000ooooooooool0A_ooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo033ooooo
0ol00012ooooo`002Oooool01000003ooooooooooooooon]000000Cooooo00<00000ooooooooool0
Aoooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo02cooooo1?l00015ooooo`002Ooo
ool01000003ooooooooooooooon]000000Cooooo00<00000ooooooooool0B?ooool2o`0000gooooo
00?o0000ooooooooool0:?ooool4o`0004Wooooo0009ooooo`0400000?ooooooooooooooojd00000
1?ooool00`00003oooooooooo`1:ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool0
9?ooool4o`0004gooooo0009ooooo`0400000?ooooooooooooooojd000001?ooool00`00003ooooo
ooooo`1;ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool08Oooool3o`00057ooooo
0009ooooo`0400000?ooooooooooooooojd000001?ooool00`00003oooooooooo`1<ooooo`03o`00
0?oooooooooo00Sooooo00?o0000ooooooooool07Oooool4o`0005Cooooo0009ooooo`0400000?oo
ooooooooooooojd000001?ooool00`00003oooooooooo`1=ooooo`;o00002?ooool00ol0003ooooo
ooooo`0Iooooo`Co0000F?ooool000Wooooo00@00000oooooooooooooooo[@000004ooooo`030000
0?oooooooooo04oooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0Eooooo`Co0000
G?ooool000Wooooo00@00000oooooooooooooooo[@000004ooooo`0300000?oooooooooo053ooooo
00?o0000ooooooooool01?ooool00ol0003oooooooooo`0Booooo`?o0000H?ooool000Wooooo00@0
0000oooooooooooooooo[@000004ooooo`0300000?oooooooooo057ooooo00?o0000ooooooooool0
0oooool00ol0003oooooooooo`0>ooooo`Co0000Hoooool000Wooooo00@00000oooooooooooooooo
[@000004ooooo`0300000?oooooooooo05;ooooo0_l00003ooooo`03o`000?oooooooooo00[ooooo
1?l0001Wooooo`002Oooool01000003ooooooooooooooon]000000Cooooo00<00000ooooooooool0
E?ooool01?l0003oooooooooool00008ooooo`Co0000Joooool000Wooooo00@00000oooooooooooo
oooo[@000004ooooo`0300000?oooooooooo05Gooooo00?o0000ooooool000001Oooool3o`0006oo
oooo0009ooooo`0400000?ooooooooooooooojd000001?ooool00`00003oooooooooo`1Fooooo`;o
000000?oooooo`000?l000000_l0001booooo`002Oooool01000003ooooooooooooooon]000000Co
oooo00<00000ooooooooool0Eoooool2o`0007Kooooo0009ooooo`0400000?ooooooooooooooojd0
00001?ooool00`00003oooooooooo`3?ooooo`002Oooool01000003ooooooooooooooon]000000Co
oooo00<00000ooooooooool0coooool000Wooooo00@00000oooooooooooooooo[@000004ooooo`03
00000?oooooooooo0<oooooo0009ooooo`0400000?ooooooooooooooojd000001?ooool00`00003o
ooooooooo`3?ooooo`002Oooool01000003ooooooooooooooon]000000Cooooo00<00000oooooooo
ool0coooool000Wooooo00@00000oooooooooooooooo[@000004ooooo`0300000?oooooooooo0<oo
oooo0009ooooo`0400000?ooooooooooooooojd000001?ooool00`00003oooooooooo`3?ooooo`00
2Oooool01000003ooooooooooooooon]000000Cooooo00<00000ooooooooool0coooool000Wooooo
00@00000oooooooooooooooo[@000004ooooo`0300000?oooooooooo0<oooooo0009ooooo`040000
0?ooooooooooooooojd000001?ooool00`00003oooooooooo`3?ooooo`002Oooool01000003ooooo
oooooooooon]000000Cooooo00<00000ooooooooool0coooool000Wooooo00@00000oooooooooooo
oooo[@000004ooooo`0300000?oooooooooo0<oooooo0009ooooo`0400000?ooooooooooooooojd0
00001?ooool00`00003oooooooooo`3?ooooo`002Oooool00`00003oooooooooo`2booooo`030000
0?oooooooooo0<oooooo0009ooooo`0300000?oooooooooo0;;ooooo00<00000ooooooooool0cooo
ool000Wooooo00<00000ooooooooool0/_ooool00`00003oooooooooo`3?ooooo`002Ooooonf0000
0=7ooooo003ooooooi7ooooo003ooooooi7ooooo003ooooooi7ooooo003ooooooi7ooooo003ooooo
oi7ooooo003ooooooi7ooooo003ooooooi7ooooo003ooooooi7ooooo003ooooooi7ooooo003ooooo
oi7ooooo003ooooooi7ooooo003ooooooi7ooooo003ooooooi7ooooo003ooooooi7ooooo003ooooo
oi7ooooo003ooooooi7ooooo003ooooooi7ooooo0009oooookH000004Ooooonf000000[ooooo0009
ooooo`0300000?oooooooooo0;;ooooo00<00000ooooooooool03oooool00`00003oooooooooo`2b
ooooo`0300000?oooooooooo00Sooooo0009ooooo`0300000?oooooooooo0;;ooooo00<00000oooo
ooooool03oooool00`00003oooooooooo`2booooo`0300000?oooooooooo00Sooooo0009ooooo`03
00000?oooooooooo0;;ooooo00<00000ooooooooool03oooool00`00003oooooooooo`2booooo`03
00000?oooooooooo00Sooooo0009ooooo`0300000?oooooooooo0;;ooooo00<00000ooooooooool0
3oooool00`00003oooooooooo`2booooo`0300000?oooooooooo00Sooooo0009ooooo`0300000?oo
oooooooo0;;ooooo00<00000ooooooooool03oooool00`00003oooooooooo`2booooo`0300000?oo
oooooooo00Sooooo0009ooooo`0300000?oooooooooo0;;ooooo00<00000ooooooooool03oooool0
0`00003oooooooooo`2booooo`0300000?oooooooooo00Sooooo0009ooooo`0300000?oooooooooo
0;;ooooo00<00000ooooooooool03oooool00`00003oooooooooo`2booooo`0300000?oooooooooo
00Sooooo0009ooooo`0300000?oooooooooo0;;ooooo00<00000ooooooooool03oooool00`00003o
ooooooooo`2booooo`0300000?oooooooooo00Sooooo0009ooooo`0300000?oooooooooo0;;ooooo
00<00000ooooooooool03oooool00`00003oooooooooo`2booooo`0300000?oooooooooo00Sooooo
0009ooooo`0300000?oooooooooo0;;ooooo00<00000ooooooooool03oooool00`00003ooooooooo
o`2booooo`0300000?oooooooooo00Sooooo0009ooooo`0300000?oooooooooo0;;ooooo00<00000
ooooooooool03oooool00`00003oooooooooo`2booooo`0300000?oooooooooo00Sooooo0009oooo
o`0300000?oooooooooo0;;ooooo00<00000ooooooooool03oooool00`00003oooooooooo`2boooo
o`0300000?oooooooooo00Sooooo0009ooooo`0300000?oooooooooo0;;ooooo00<00000oooooooo
ool03oooool00`00003oooooooooo`2booooo`0300000?oooooooooo00Sooooo0009ooooo`030000
0?oooooooooo0;;ooooo00<00000ooooooooool03oooool00`00003oooooooooo`2booooo`030000
0?oooooooooo00Sooooo0009ooooo`0300000?oooooooooo0;;ooooo00<00000ooooooooool03ooo
ool00`00003oooooooooo`2booooo`0300000?oooooooooo00Sooooo0009ooooo`0300000?oooooo
oooo0;;ooooo00<00000ooooooooool03oooool00`00003oooooooooo`2booooo`0300000?oooooo
oooo00Sooooo0009ooooo`0300000?oooooooooo0;;ooooo00<00000ooooooooool03oooool00`00
003oooooooooo`2booooo`0300000?oooooooooo00Sooooo0009ooooo`0300000?oooooooooo0;;o
oooo00<00000ooooooooool03oooool00`00003oooooooooo`2booooo`0300000?oooooooooo00So
oooo0009ooooo`0300000?oooooooooo0;;ooooo00<00000ooooooooool03oooool00`00003ooooo
ooooo`2booooo`0300000?oooooooooo00Sooooo0009ooooo`0300000?oooooooooo0;;ooooo00<0
0000ooooooooool03oooool00`00003oooooooooo`2booooo`0300000?oooooooooo00Sooooo0009
ooooo`0300000?oooooooooo0;;ooooo00<00000ooooooooool03oooool00`00003oooooooooo`2b
ooooo`0300000?oooooooooo00Sooooo0009ooooo`0300000?oooooooooo0;;ooooo00<00000oooo
ooooool03oooool00`00003oooooooooo`2booooo`0300000?oooooooooo00Sooooo0009ooooo`03
00000?oooooooooo00?ooooo0P3oO`0;ooooo`80ogl0X?ooool00`00003oooooooooo`0?ooooo`03
00000?oooooooooo00?ooooo0P3oO`0;ooooo`80ogl0X?ooool00`00003oooooooooo`08ooooo`00
2Oooool00`00003oooooooooo`02ooooo`<0ogl02oooool20?mo00cooooo0P3oO`2Booooo`030000
0?oooooooooo00oooooo00<00000ooooooooool00_ooool30?mo00_ooooo0P3oO`0<ooooo`80ogl0
T_ooool00`00003oooooooooo`08ooooo`002Oooool00`00003oooooooooo`02ooooo`80ogl06_oo
ool20?mo09;ooooo00<00000ooooooooool03oooool00`00003oooooooooo`02ooooo`80ogl06_oo
ool20?mo09;ooooo00<00000ooooooooool02?ooool000Wooooo00<00000ooooooooool0/_ooool0
0`00003oooooooooo`0?ooooo`0300000?oooooooooo0;;ooooo00<00000ooooooooool02?ooool0
00Wooooo00<00000ooooooooool0/_ooool00`00003oooooooooo`0?ooooo`0300000?oooooooooo
0;;ooooo00<00000ooooooooool02?ooool000Wooooo00<00000ooooooooool0/_ooool00`00003o
ooooooooo`0?ooooo`0300000?oooooooooo0;;ooooo00<00000ooooooooool02?ooool000Wooooo
00<00000ooooooooool0/_ooool00`00003oooooooooo`0?ooooo`0300000?oooooooooo0;;ooooo
00<00000ooooooooool02?ooool000Wooooo00<00000ooooooooool0/_ooool00`00003ooooooooo
o`0?ooooo`0300000?oooooooooo0;;ooooo00<00000ooooooooool02?ooool000Wooooo00<00000
ooooooooool06Oooool80000oi7ooooo00<00000ooooooooool03oooool00`00003oooooooooo`2b
ooooo`0300000?oooooooooo00Sooooo0009ooooo`0300000?oooooooooo01Sooooo00<0003ooooo
ooooool01_ooool30000ohkooooo00<00000ooooooooool03oooool00`00003oooooooooo`2boooo
o`0300000?oooooooooo00Sooooo0009ooooo`0300000?oooooooooo01Oooooo00<0003ooooooooo
ool02_ooool30000oh_ooooo00<00000ooooooooool03oooool00`00003oooooooooo`2booooo`03
00000?oooooooooo00Sooooo0009ooooo`0300000?oooooooooo01Kooooo00<0003o0?mo0?ooool0
1?ooool20?mo00Sooooo00?o003oooooooooool0R?ooool00`00003oooooooooo`0?ooooo`030000
0?oooooooooo01Kooooo0P3oO`05ooooo`80ogl0Toooool00`00003oooooooooo`08ooooo`002Ooo
ool00`00003oooooooooo`0Fooooo`030000o`3oO`3ooooo00Cooooo0P3oO`09ooooo`80003oR?oo
ool00`00003oooooooooo`0?ooooo`0300000?oooooooooo01Kooooo0P3oO`05ooooo`80ogl0Tooo
ool00`00003oooooooooo`08ooooo`002Oooool00`00003oooooooooo`0Gooooo`030000oooooooo
oooo013ooooo0`000?n5ooooo`0300000?oooooooooo00oooooo00<00000ooooooooool0/_ooool0
0`00003oooooooooo`08ooooo`002Oooool00`00003oooooooooo`0Gooooo`030000oooooooooooo
01?ooooo00<0003oooooooooool0P_ooool00`00003oooooooooo`0?ooooo`0300000?oooooooooo
0;;ooooo00<00000ooooooooool02?ooool000Wooooo00<00000ooooooooool05oooool00`000?oo
ooooooooo`02ooooo`80ogl01_ooool20?mo00Sooooo00<0003oooooooooool00P3oO`03ooooo`80
ogl0N_ooool00`00003oooooooooo`0?ooooo`0300000?oooooooooo01cooooo0P3oO`06ooooo`80
ogl02oooool20?mo00?ooooo0P3oO`1jooooo`0300000?oooooooooo00Sooooo0009ooooo`030000
0?oooooooooo01Sooooo00@0003ooooooooooooooooo0P3oO`06ooooo`80ogl02Oooool30000o`04
0?mo0?ooooooooooooooo`80ogl0N_ooool00`00003oooooooooo`0?ooooo`0300000?oooooooooo
01cooooo0P3oO`06ooooo`80ogl02oooool20?mo00?ooooo0P3oO`1jooooo`0300000?oooooooooo
00Sooooo0009ooooo`0300000?oooooooooo01Sooooo00<0003oooooooooool05oooool20000o`?o
oooo0P3oO`1iooooo`0300000?oooooooooo00oooooo00<00000ooooooooool0=oooool20?mo07Wo
oooo00<00000ooooooooool02?ooool000Wooooo00<00000ooooooooool06Oooool00`000?oooooo
ooooo`0Gooooo`040?mo00000?ooooooooooo`80ogl0NOooool00`00003oooooooooo`0?ooooo`03
00000?oooooooooo03?ooooo0P3oO`02ooooo`80ogl0NOooool00`00003oooooooooo`08ooooo`00
2Oooool00`00003oooooooooo`0Jooooo`80003o3?ooool3000000Sooooo0P3oO`000`000?oooooo
ooooo`1jooooo`0300000?oooooooooo00oooooo00<00000ooooooooool0<oooool20?mo07gooooo
00<00000ooooooooool02?ooool000Wooooo00<00000ooooooooool07?ooool00`000?oooooooooo
o`02ooooo`80ogl01?ooool5000000[ooooo00<0003oooooooooool0NOooool00`00003ooooooooo
o`0?ooooo`0300000?oooooooooo027ooooo0P3oO`2?ooooo`0300000?oooooooooo00Sooooo0009
ooooo`0300000?oooooooooo01[ooooo0P3oO`000oooool0003oooooo`02ooooo`80ogl01?ooool5
000000[ooooo00<0003oooooooooool0NOooool00`00003oooooooooo`0?ooooo`0300000?oooooo
oooo01[ooooo0P3oO`05ooooo`80ogl0Soooool00`00003oooooooooo`08ooooo`002Oooool00`00
003oooooooooo`0Jooooo`80ogl00_ooool00`000?ooooooooooo`06ooooo`D000001_ooool20?mo
00?ooooo00<0003oooooooooool01?ooool20?mo07;ooooo00<00000ooooooooool03oooool00`00
003oooooooooo`0Jooooo`80ogl05_ooool20?mo00[ooooo0P3oO`1booooo`0300000?oooooooooo
00Sooooo0009ooooo`0300000?oooooooooo01oooooo0P000?l7ooooo`<000001oooool20?mo00Co
oooo00<0003oooooooooool00oooool20?mo07;ooooo00<00000ooooooooool03oooool00`00003o
ooooooooo`0booooo`80ogl02_ooool20?mo07;ooooo00<00000ooooooooool02?ooool000Wooooo
00<00000ooooooooool08Oooool00`000?ooooooooooo`0Eooooo`030000oooooooooooo07Kooooo
00<00000ooooooooool03oooool00`00003oooooooooo`2booooo`0300000?oooooooooo00Sooooo
0009ooooo`0300000?oooooooooo02;ooooo00<0003oooooooooool05Oooool00`000?oooooooooo
o`1eooooo`0300000?oooooooooo00oooooo00<00000ooooooooool0/_ooool00`00003ooooooooo
o`08ooooo`002Oooool00`00003oooooooooo`0Sooooo`030000oooooooooooo01Cooooo00<0003o
ooooooooool0MOooool00`00003oooooooooo`0?ooooo`0300000?oooooooooo0;;ooooo00<00000
ooooooooool02?ooool000Wooooo00<00000ooooooooool08oooool00`3oO`00003o0000o`020?mo
01?ooooo00<0003oooooooooool0M?ooool00`00003oooooooooo`0?ooooo`0300000?oooooooooo
02?ooooo0P3oO`000oooool0ogl00?mo002:ooooo`0300000?oooooooooo00Sooooo0009ooooo`03
00000?oooooooooo02?ooooo0`3oO`020000oa?ooooo00<0003oooooooooool0M?ooool00`00003o
ooooooooo`0?ooooo`0300000?oooooooooo02?ooooo1@3oO`2:ooooo`0300000?oooooooooo00So
oooo0009ooooo`0300000?oooooooooo02Gooooo0P3oO`000oooool0003oooooo`0Aooooo`030000
o`3oO`3ooooo07Cooooo00<00000ooooooooool03oooool00`00003oooooooooo`0Uooooo`80ogl0
5?ooool20?mo07Gooooo00<00000ooooooooool02?ooool000Wooooo00<00000ooooooooool0:Ooo
ool00ol00?l0003o0000o`0?ooooo`03o`00o`3oO`3ooooo07Cooooo00<00000ooooooooool03ooo
ool00`00003oooooooooo`0kooooo`80ogl0MOooool00`00003oooooooooo`08ooooo`002Oooool0
0`00003oooooooooo`0/ooooo`<0003o2oooool20000ogKooooo00<00000ooooooooool03oooool0
0`00003oooooooooo`2booooo`0300000?oooooooooo00Sooooo0009ooooo`0300000?oooooooooo
02oooooo0`000?l6ooooo`80003oN?ooool00`00003oooooooooo`0?ooooo`0300000?oooooooooo
0;;ooooo00<00000ooooooooool02?ooool000Wooooo00<00000ooooooooool07_ooool20?mo01;o
oooo1P000?mjooooo`0300000?oooooooooo00oooooo00<00000ooooooooool07_ooool20?mo09;o
oooo00<00000ooooooooool02?ooool000Wooooo00<00000ooooooooool07_ooool20?mo09;ooooo
00<00000ooooooooool03oooool00`00003oooooooooo`0Nooooo`80ogl0T_ooool00`00003ooooo
ooooo`08ooooo`002Oooool00`00003oooooooooo`2booooo`0300000?oooooooooo00oooooo00<0
0000ooooooooool0/_ooool00`00003oooooooooo`08ooooo`002Oooool00`00003oooooooooo`2b
ooooo`0300000?oooooooooo00oooooo00<00000ooooooooool0/_ooool00`00003oooooooooo`08
ooooo`002Oooool00`00003oooooooooo`2booooo`0300000?oooooooooo00oooooo00<00000oooo
ooooool0/_ooool00`00003oooooooooo`08ooooo`002Oooool00`00003oooooooooo`2booooo`03
00000?oooooooooo00oooooo00<00000ooooooooool0/_ooool00`00003oooooooooo`08ooooo`00
2Oooool00`00003oooooooooo`1>ooooo`80ogl0H_ooool00`00003oooooooooo`0?ooooo`030000
0?oooooooooo04kooooo0P3oO`1Rooooo`0300000?oooooooooo00Sooooo0009ooooo`0300000?oo
oooooooo03Cooooo0P3oO`0Hooooo`80ogl0H_ooool00`00003oooooooooo`0?ooooo`0300000?oo
oooooooo03Cooooo0P3oO`0Hooooo`80ogl0H_ooool00`00003oooooooooo`08ooooo`002Oooool0
0`00003oooooooooo`0dooooo`80ogl0O?ooool00`00003oooooooooo`0?ooooo`0300000?oooooo
oooo03Cooooo0P3oO`1looooo`0300000?oooooooooo00Sooooo0009ooooo`0300000?oooooooooo
0;;ooooo00<00000ooooooooool03oooool00`00003oooooooooo`2booooo`0300000?oooooooooo
00Sooooo0009ooooo`0300000?oooooooooo03gooooo0P3oO`02ooooo`80ogl0Koooool00`00003o
ooooooooo`0?ooooo`0300000?oooooooooo03gooooo0P3oO`02ooooo`80ogl0Koooool00`00003o
ooooooooo`08ooooo`002Oooool00`00003oooooooooo`0mooooo`80ogl00_ooool20?mo06oooooo
00<00000ooooooooool03oooool00`00003oooooooooo`0mooooo`80ogl00_ooool20?mo06oooooo
00<00000ooooooooool02?ooool000Wooooo00<00000ooooooooool0/_ooool00`00003ooooooooo
o`0?ooooo`0300000?oooooooooo0;;ooooo00<00000ooooooooool02?ooool000Wooooo00<00000
ooooooooool0/_ooool00`00003oooooooooo`0?ooooo`0300000?oooooooooo0;;ooooo00<00000
ooooooooool02?ooool000Wooooo00<00000ooooooooool0/_ooool00`00003oooooooooo`0?oooo
o`0300000?oooooooooo0;;ooooo00<00000ooooooooool02?ooool000Wooooo00<00000oooooooo
ool0/_ooool00`00003oooooooooo`0?ooooo`0300000?oooooooooo0;;ooooo00<00000oooooooo
ool02?ooool000Wooooo00<00000ooooooooool0/_ooool00`00003oooooooooo`0?ooooo`030000
0?oooooooooo0;;ooooo00<00000ooooooooool02?ooool000Wooooo00<00000ooooooooool0/_oo
ool00`00003oooooooooo`0?ooooo`0300000?oooooooooo0;;ooooo00<00000ooooooooool02?oo
ool000Wooooo00<00000ooooooooool0/_ooool00`00003oooooooooo`0?ooooo`0300000?oooooo
oooo0;;ooooo00<00000ooooooooool02?ooool000Wooooo00<00000ooooooooool0/_ooool00`00
003oooooooooo`0?ooooo`0300000?oooooooooo0;;ooooo00<00000ooooooooool02?ooool000Wo
oooo00<00000ooooooooool0/_ooool00`00003oooooooooo`0?ooooo`0300000?oooooooooo0;;o
oooo00<00000ooooooooool02?ooool000Wooooo00<00000ooooooooool0/_ooool00`00003ooooo
ooooo`0?ooooo`0300000?oooooooooo0;;ooooo00<00000ooooooooool02?ooool000Wooooo00<0
0000ooooooooool0/_ooool00`00003oooooooooo`0?ooooo`0300000?oooooooooo0;;ooooo00<0
0000ooooooooool02?ooool000Wooooo00<00000ooooooooool0/_ooool00`00003oooooooooo`0?
ooooo`0300000?oooooooooo0;;ooooo00<00000ooooooooool02?ooool000Wooooo00<00000oooo
ooooool0/_ooool00`00003oooooooooo`0?ooooo`0300000?oooooooooo0;;ooooo00<00000oooo
ooooool02?ooool000Wooooo00<00000ooooooooool0/_ooool00`00003oooooooooo`0?ooooo`03
00000?oooooooooo0;;ooooo00<00000ooooooooool02?ooool000Wooooo00<00000ooooooooool0
/_ooool00`00003oooooooooo`0?ooooo`0300000?oooooooooo0;;ooooo00<00000ooooooooool0
2?ooool000Wooooo00<00000ooooooooool0/_ooool00`00003oooooooooo`0?ooooo`0300000?oo
oooooooo0;;ooooo00<00000ooooooooool02?ooool000Wooooo00<00000ooooooooool0/_ooool0
0`00003oooooooooo`0?ooooo`0300000?oooooooooo0;;ooooo00<00000ooooooooool02?ooool0
00Wooooo00<00000ooooooooool0/_ooool00`00003oooooooooo`0?ooooo`0300000?oooooooooo
0;;ooooo00<00000ooooooooool02?ooool000Wooooo00<00000ooooooooool0/_ooool00`00003o
ooooooooo`0?ooooo`0300000?oooooooooo0;;ooooo00<00000ooooooooool02?ooool000Wooooo
00<00000ooooooooool0/_ooool00`00003oooooooooo`0?ooooo`0300000?oooooooooo0;;ooooo
00<00000ooooooooool02?ooool000Wooooo00<00000ooooooooool0/_ooool00`00003ooooooooo
o`0?ooooo`0300000?oooooooooo0;;ooooo00<00000ooooooooool02?ooool000Wooooo00<00000
ooooooooool0X_ooool20?mo00kooooo00<00000ooooooooool03oooool00`00003oooooooooo`2R
ooooo`80ogl03_ooool00`00003oooooooooo`08ooooo`002Oooool00`00003oooooooooo`2Roooo
o`80ogl03_ooool00`00003oooooooooo`0?ooooo`0300000?oooooooooo0:;ooooo0P3oO`0>oooo
o`0300000?oooooooooo00Sooooo0009ooooo`0300000?oooooooooo0;;ooooo00<00000oooooooo
ool03oooool00`00003oooooooooo`2booooo`0300000?oooooooooo00Sooooo0009ooooo`030000
0?oooooooooo0;;ooooo00<00000ooooooooool03oooool00`00003oooooooooo`2booooo`030000
0?oooooooooo00Sooooo0009ooooo`0300000?oooooooooo0;;ooooo00<00000ooooooooool03ooo
ool00`00003oooooooooo`2booooo`0300000?oooooooooo00Sooooo0009ooooo`0300000?oooooo
oooo0;;ooooo00<00000ooooooooool03oooool00`00003oooooooooo`2booooo`0300000?oooooo
oooo00Sooooo0009ooooo`0300000?oooooooooo0;;ooooo00<00000ooooooooool03oooool00`00
003oooooooooo`2booooo`0300000?oooooooooo00Sooooo0009ooooo`0300000?oooooooooo0;;o
oooo00<00000ooooooooool03oooool00`00003oooooooooo`2booooo`0300000?oooooooooo00So
oooo0009ooooo`0300000?oooooooooo0;;ooooo00<00000ooooooooool03oooool00`00003ooooo
ooooo`2booooo`0300000?oooooooooo00Sooooo0009ooooo`0300000?oooooooooo077ooooo0P3o
O`0oooooo`0300000?oooooooooo00oooooo00<00000ooooooooool0LOooool20?mo03oooooo00<0
0000ooooooooool02?ooool000Wooooo00<00000ooooooooool0LOooool20?mo03oooooo00<00000
ooooooooool03oooool00`00003oooooooooo`1aooooo`80ogl0?oooool00`00003oooooooooo`08
ooooo`002Oooool00`00003oooooooooo`2Cooooo`80ogl07Oooool00`00003oooooooooo`0?oooo
o`0300000?oooooooooo09?ooooo0P3oO`0Mooooo`0300000?oooooooooo00Sooooo0009ooooo`03
00000?oooooooooo08oooooo0P3oO`02ooooo`80ogl07Oooool00`00003oooooooooo`0?ooooo`03
00000?oooooooooo08oooooo0P3oO`02ooooo`80ogl07Oooool00`00003oooooooooo`08ooooo`00
2Oooool00`00003oooooooooo`1jooooo`030?mo00000?l0003o00L0003o2oooool20?mo027ooooo
00<00000ooooooooool03oooool00`00003oooooooooo`1jooooo`80ogl04oooool20?mo027ooooo
00<00000ooooooooool02?ooool000Wooooo00<00000ooooooooool0M_ooool50000o`030?mo0?oo
oooooooo00Kooooo0`000?l[ooooo`0300000?oooooooooo00oooooo00<00000ooooooooool0N_oo
ool20?mo03Kooooo00<00000ooooooooool02?ooool000Wooooo00<00000ooooooooool0M?ooool0
0ol00?l0003oooooo`0@ooooo`03o`00oooooooooooo00;ooooo0P3oO`0Tooooo`0300000?oooooo
oooo00oooooo00<00000ooooooooool0M?ooool20?mo01Kooooo0P3oO`0Tooooo`0300000?oooooo
oooo00Sooooo0009ooooo`0300000?oooooooooo077ooooo0P000?l00ol00?l0ogl00?mo000Aoooo
o`030000oooooooooooo00;ooooo0P3oO`0Tooooo`0300000?oooooooooo00oooooo00<00000oooo
ooooool0M?ooool20?mo01Kooooo0P3oO`0Tooooo`0300000?oooooooooo00Sooooo0009ooooo`03
00000?oooooooooo06kooooo0`000?l00`3oO`3oooooooooo`0=ooooo`80ogl01?ooool00`000?oo
ooooooooo`06ooooo`80ogl08?ooool00`00003oooooooooo`0?ooooo`0300000?oooooooooo073o
oooo0P3oO`0?ooooo`80ogl03Oooool20?mo023ooooo00<00000ooooooooool02?ooool000Wooooo
00<00000ooooooooool0K?ooool20000o`;ooooo0P3oO`04ooooo`80ogl02Oooool20?mo00Cooooo
00<0003oooooooooool01_ooool20?mo023ooooo00<00000ooooooooool03oooool00`00003ooooo
ooooo`1`ooooo`80ogl01?ooool20?mo00Wooooo0P3oO`0=ooooo`80ogl08?ooool00`00003ooooo
ooooo`08ooooo`002Oooool00`00003oooooooooo`1Fooooo`80ogl04oooool00`000?oooooooooo
o`02ooooo`80ogl01?ooool20?mo013ooooo00<0003oooooooooool09oooool00`00003ooooooooo
o`0?ooooo`0300000?oooooooooo05Kooooo0P3oO`0Hooooo`80ogl01?ooool20?mo03[ooooo00<0
0000ooooooooool02?ooool000Wooooo00<00000ooooooooool0E_ooool20?mo017ooooo0P000?l5
ooooo`80ogl05_ooool00`000?ooooooooooo`0Wooooo`0300000?oooooooooo00oooooo00<00000
ooooooooool0E_ooool20?mo01Sooooo0P3oO`10ooooo`0300000?oooooooooo00Sooooo0009oooo
o`0300000?oooooooooo06Sooooo00<0003oooooooooool07Oooool00`000?ooooooooooo`0Woooo
o`0300000?oooooooooo00oooooo00<00000ooooooooool0/_ooool00`00003oooooooooo`08oooo
o`002Oooool00`00003oooooooooo`1Mooooo`80ogl02?ooool00`000?l0ogl00?mo000Iooooo`80
ogl00oooool00`000?ooooooooooo`0Wooooo`0300000?oooooooooo00oooooo00<00000oooooooo
ool0GOooool20?mo00Wooooo0P3oO`0Iooooo`80ogl0;Oooool00`00003oooooooooo`08ooooo`00
2Oooool00`00003oooooooooo`1Mooooo`80ogl01_ooool20000o`03ooooo`3oO`00ogl001Wooooo
0P3oO`02ooooo`030000oooooooooooo02Sooooo00<00000ooooooooool03oooool00`00003ooooo
ooooo`1Mooooo`80ogl02Oooool20?mo01Wooooo0P3oO`0]ooooo`0300000?oooooooooo00Sooooo
0009ooooo`0300000?oooooooooo06Cooooo00<0003oooooooooool08?ooool00ol00?oooooooooo
o`0Xooooo`0300000?oooooooooo00oooooo00<00000ooooooooool0/_ooool00`00003ooooooooo
o`08ooooo`002Oooool00`00003oooooooooo`1Sooooo`030000oooooooooooo023ooooo00<0003o
ooooooooool02_ooool20?mo01gooooo00<00000ooooooooool03oooool00`00003oooooooooo`2C
ooooo`80ogl07Oooool00`00003oooooooooo`08ooooo`002Oooool00`00003oooooooooo`1Roooo
o`030000oooooooooooo00cooooo0`00000Booooo`030000o`3oO`3ooooo00[ooooo0P3oO`0Moooo
o`0300000?oooooooooo00oooooo00<00000ooooooooool0Q_ooool20?mo00_ooooo0P3oO`0Moooo
o`0300000?oooooooooo00Sooooo0009ooooo`0300000?oooooooooo067ooooo00<0003ooooooooo
ool03?ooool50000013ooooo00<0003o0?mo003oO`00:_ooool00`00003oooooooooo`0?ooooo`03
00000?oooooooooo07;ooooo0P3oO`0Booooo`80ogl0:_ooool00`00003oooooooooo`08ooooo`00
2Oooool00`00003oooooooooo`1Qooooo`030000oooooooooooo00cooooo1@00000?ooooo`030000
oooooooooooo02_ooooo00<00000ooooooooool03oooool00`00003oooooooooo`1booooo`80ogl0
?_ooool00`00003oooooooooo`08ooooo`002Oooool00`00003oooooooooo`1Pooooo`030000oooo
oooooooo00Kooooo0P3oO`05ooooo`D000003_ooool00`000?l0ogl00?mo000/ooooo`0300000?oo
oooooooo00oooooo00<00000ooooooooool0JOooool20?mo00Gooooo0P3oO`0Booooo`80ogl0;?oo
ool00`00003oooooooooo`08ooooo`002Oooool00`00003oooooooooo`1Oooooo`030000oooooooo
oooo00Gooooo103oO`05ooooo`040?mo000000000000000000cooooo00@0ogl00000o`000?oooooo
0P3oO`0/ooooo`0300000?oooooooooo00oooooo00<00000ooooooooool0Ioooool40?mo00Gooooo
0P3oO`0>ooooo`80ogl00_ooool20?mo02cooooo00<00000ooooooooool02?ooool000Wooooo00<0
0000ooooooooool0Goooool00`000?ooooooooooo`05ooooo`80ogl05oooool00`000?l0ogl0oooo
o`0_ooooo`0300000?oooooooooo00oooooo00<00000ooooooooool0Ioooool20?mo01Oooooo0P3o
O`0`ooooo`0300000?oooooooooo00Sooooo0009ooooo`0300000?oooooooooo04Wooooo0P3oO`0C
ooooo`030000oooooooooooo01kooooo00<0003oooooooooool0<?ooool00`00003oooooooooo`0?
ooooo`0300000?oooooooooo04Wooooo0P3oO`1Wooooo`0300000?oooooooooo00Sooooo0009oooo
o`0300000?oooooooooo04Wooooo0P3oO`07ooooo`80ogl02_ooool00`000?ooooooooooo`0=oooo
o`80ogl03_ooool00`000?ooooooooooo`0aooooo`0300000?oooooooooo00oooooo00<00000oooo
ooooool0BOooool20?mo00Oooooo0P3oO`0Jooooo`80ogl0@_ooool00`00003oooooooooo`08oooo
o`002Oooool00`00003oooooooooo`1Booooo`80ogl02Oooool00`000?ooooooooooo`0>ooooo`80
ogl02_ooool40000ocCooooo00<00000ooooooooool03oooool00`00003oooooooooo`1Booooo`80
ogl06_ooool20?mo04;ooooo00<00000ooooooooool02?ooool000Wooooo00<00000ooooooooool0
GOooool00`000?ooooooooooo`09ooooo`80ogl03_ooool00`000?ooooooooooo`0fooooo`030000
0?oooooooooo00oooooo00<00000ooooooooool0JOooool20?mo04Oooooo00<00000ooooooooool0
2?ooool000Wooooo00<00000ooooooooool0GOooool00`000?ooooooooooo`09ooooo`80ogl03?oo
ool20000ocWooooo00<00000ooooooooool03oooool00`00003oooooooooo`1Yooooo`80ogl0Aooo
ool00`00003oooooooooo`08ooooo`002Oooool00`00003oooooooooo`1Mooooo`030000oooooooo
oooo01Kooooo00<0003oooooooooool0>Oooool00`00003oooooooooo`0?ooooo`0300000?oooooo
oooo0;;ooooo00<00000ooooooooool02?ooool000Wooooo00<00000ooooooooool0GOooool00`00
0?ooooooooooo`0Eooooo`030000oooooooooooo03[ooooo00<00000ooooooooool03oooool00`00
003oooooooooo`2booooo`0300000?oooooooooo00Sooooo0009ooooo`0300000?oooooooooo05go
oooo0P000?lBooooo`<0003o00?o003oooooooooool0>oooool00`00003oooooooooo`0?ooooo`03
00000?oooooooooo0;;ooooo00<00000ooooooooool02?ooool000Wooooo00<00000ooooooooool0
D_ooool20?mo00_ooooo00<0003oooooooooool03?ooool30000od7ooooo00<00000ooooooooool0
3oooool00`00003oooooooooo`1Booooo`80ogl0G_ooool00`00003oooooooooo`08ooooo`002Ooo
ool00`00003oooooooooo`1Booooo`80ogl03?ooool00`000?ooooooooooo`08ooooo`<0003oA?oo
ool00`00003oooooooooo`0?ooooo`0300000?oooooooooo05;ooooo0P3oO`1Nooooo`0300000?oo
oooooooo00Sooooo0009ooooo`0300000?oooooooooo067ooooo2P000?l4ooooo`80ogl0@Oooool0
0`00003oooooooooo`0?ooooo`0300000?oooooooooo06oooooo0P3oO`11ooooo`0300000?oooooo
oooo00Sooooo0009ooooo`0300000?oooooooooo06oooooo0P3oO`11ooooo`0300000?oooooooooo
00oooooo00<00000ooooooooool0Koooool20?mo047ooooo00<00000ooooooooool02?ooool000Wo
oooo00<00000ooooooooool0/_ooool00`00003oooooooooo`0?ooooo`0300000?oooooooooo0;;o
oooo00<00000ooooooooool02?ooool000Wooooo00<00000ooooooooool0/_ooool00`00003ooooo
ooooo`0?ooooo`0300000?oooooooooo0;;ooooo00<00000ooooooooool02?ooool000Wooooo00<0
0000ooooooooool0COooool20?mo06?ooooo00<00000ooooooooool03oooool00`00003ooooooooo
o`1=ooooo`80ogl0Hoooool00`00003oooooooooo`08ooooo`002Oooool00`00003oooooooooo`1=
ooooo`80ogl05?ooool20?mo04gooooo00<00000ooooooooool03oooool00`00003oooooooooo`1=
ooooo`80ogl05?ooool20?mo04gooooo00<00000ooooooooool02?ooool000Wooooo00<00000oooo
ooooool0Hoooool20?mo04gooooo00<00000ooooooooool03oooool00`00003oooooooooo`1Soooo
o`80ogl0COooool00`00003oooooooooo`08ooooo`002Oooool00`00003oooooooooo`1Iooooo`80
ogl0Eoooool00`00003oooooooooo`0?ooooo`0300000?oooooooooo05Wooooo0P3oO`1Gooooo`03
00000?oooooooooo00Sooooo0009ooooo`0300000?oooooooooo05Wooooo0P3oO`1Gooooo`030000
0?oooooooooo00oooooo00<00000ooooooooool0FOooool20?mo05Oooooo00<00000ooooooooool0
2?ooool000Wooooo00<00000ooooooooool0LOooool20?mo03oooooo00<00000ooooooooool03ooo
ool00`00003oooooooooo`1aooooo`80ogl0?oooool00`00003oooooooooo`08ooooo`002Oooool0
0`00003oooooooooo`1aooooo`80ogl0?oooool00`00003oooooooooo`0?ooooo`0300000?oooooo
oooo077ooooo0P3oO`0oooooo`0300000?oooooooooo00Sooooo0009ooooo`0300000?oooooooooo
0;;ooooo00<00000ooooooooool03oooool00`00003oooooooooo`2booooo`0300000?oooooooooo
00Sooooo0009ooooo`0300000?oooooooooo0;;ooooo00<00000ooooooooool03oooool00`00003o
ooooooooo`2booooo`0300000?oooooooooo00Sooooo0009ooooo`0300000?oooooooooo0;;ooooo
00<00000ooooooooool03oooool00`00003oooooooooo`2booooo`0300000?oooooooooo00Sooooo
0009ooooo`0300000?oooooooooo0;;ooooo00<00000ooooooooool03oooool00`00003ooooooooo
o`2booooo`0300000?oooooooooo00Sooooo0009ooooo`0300000?oooooooooo0;;ooooo00<00000
ooooooooool03oooool00`00003oooooooooo`2booooo`0300000?oooooooooo00Sooooo0009oooo
o`0300000?oooooooooo0;;ooooo00<00000ooooooooool03oooool00`00003oooooooooo`2boooo
o`0300000?oooooooooo00Sooooo0009ooooo`0300000?oooooooooo0;;ooooo00<00000oooooooo
ool03oooool00`00003oooooooooo`2booooo`0300000?oooooooooo00Sooooo0009ooooo`030000
0?oooooooooo0;;ooooo00<00000ooooooooool03oooool00`00003oooooooooo`2booooo`030000
0?oooooooooo00Sooooo0009ooooo`0300000?oooooooooo0;;ooooo00<00000ooooooooool03ooo
ool00`00003oooooooooo`2booooo`0300000?oooooooooo00Sooooo0009ooooo`0300000?oooooo
oooo0;;ooooo00<00000ooooooooool03oooool00`00003oooooooooo`2booooo`0300000?oooooo
oooo00Sooooo0009ooooo`0300000?oooooooooo0;;ooooo00<00000ooooooooool03oooool00`00
003oooooooooo`2booooo`0300000?oooooooooo00Sooooo0009ooooo`0300000?oooooooooo0;;o
oooo00<00000ooooooooool03oooool00`00003oooooooooo`2booooo`0300000?oooooooooo00So
oooo0009ooooo`0300000?oooooooooo0;;ooooo00<00000ooooooooool03oooool00`00003ooooo
ooooo`2booooo`0300000?oooooooooo00Sooooo0009ooooo`0300000?oooooooooo0;;ooooo00<0
0000ooooooooool03oooool00`00003oooooooooo`2booooo`0300000?oooooooooo00Sooooo0009
ooooo`0300000?oooooooooo0;;ooooo00<00000ooooooooool03oooool00`00003oooooooooo`2b
ooooo`0300000?oooooooooo00Sooooo0009ooooo`0300000?oooooooooo0;;ooooo00<00000oooo
ooooool03oooool00`00003oooooooooo`2booooo`0300000?oooooooooo00Sooooo0009ooooo`03
00000?oooooooooo0;;ooooo00<00000ooooooooool03oooool00`00003oooooooooo`2booooo`03
00000?oooooooooo00Sooooo0009ooooo`0300000?oooooooooo0;;ooooo00<00000ooooooooool0
3oooool00`00003oooooooooo`2booooo`0300000?oooooooooo00Sooooo0009ooooo`0300000?oo
oooooooo0;;ooooo00<00000ooooooooool03oooool00`00003oooooooooo`2booooo`0300000?oo
oooooooo00Sooooo0009ooooo`0300000?oooooooooo0;;ooooo00<00000ooooooooool03oooool0
0`00003oooooooooo`2booooo`0300000?oooooooooo00Sooooo0009ooooo`0300000?oooooooooo
0;;ooooo00<00000ooooooooool03oooool00`00003oooooooooo`2booooo`0300000?oooooooooo
00Sooooo0009ooooo`0300000?oooooooooo0;;ooooo00<00000ooooooooool03oooool00`00003o
ooooooooo`2booooo`0300000?oooooooooo00Sooooo0009ooooo`0300000?oooooooooo0;;ooooo
00<00000ooooooooool03oooool00`00003oooooooooo`2booooo`0300000?oooooooooo00Sooooo
0009ooooo`0300000?oooooooooo0;;ooooo00<00000ooooooooool03oooool00`00003ooooooooo
o`2booooo`0300000?oooooooooo00Sooooo0009ooooo`0300000?oooooooooo05Sooooo0P3oO`1H
ooooo`0300000?oooooooooo00oooooo00<00000ooooooooool0F?ooool20?mo05Sooooo00<00000
ooooooooool02?ooool000Wooooo00<00000ooooooooool0F?ooool20?mo05Sooooo00<00000oooo
ooooool03oooool00`00003oooooooooo`1Hooooo`80ogl0F?ooool00`00003oooooooooo`08oooo
o`002Oooool00`00003oooooooooo`2booooo`0300000?oooooooooo00oooooo00<00000oooooooo
ool0/_ooool00`00003oooooooooo`08ooooo`002Oooool00`00003oooooooooo`2booooo`030000
0?oooooooooo00oooooo00<00000ooooooooool0/_ooool00`00003oooooooooo`08ooooo`002Ooo
ool00`00003oooooooooo`2booooo`0300000?oooooooooo00oooooo00<00000ooooooooool0/_oo
ool00`00003oooooooooo`08ooooo`002Oooool00`00003oooooooooo`2booooo`0300000?oooooo
oooo00oooooo00<00000ooooooooool0/_ooool00`00003oooooooooo`08ooooo`002Oooool00`00
003oooooooooo`2booooo`0300000?oooooooooo00oooooo00<00000ooooooooool0/_ooool00`00
003oooooooooo`08ooooo`002Oooool00`00003oooooooooo`2booooo`0300000?oooooooooo00oo
oooo00<00000ooooooooool0/_ooool00`00003oooooooooo`08ooooo`002Oooool00`00003ooooo
ooooo`2booooo`0300000?oooooooooo00oooooo00<00000ooooooooool0/_ooool00`00003ooooo
ooooo`08ooooo`002Oooool00`00003oooooooooo`2booooo`0300000?oooooooooo00oooooo00<0
0000ooooooooool0/_ooool00`00003oooooooooo`08ooooo`002Oooool00`00003oooooooooo`2b
ooooo`0300000?oooooooooo00oooooo00<00000ooooooooool0/_ooool00`00003oooooooooo`08
ooooo`002Oooool00`00003oooooooooo`2booooo`0300000?oooooooooo00oooooo00<00000oooo
ooooool0/_ooool00`00003oooooooooo`08ooooo`002Oooool00`00003oooooooooo`2booooo`03
00000?oooooooooo00oooooo00<00000ooooooooool0/_ooool00`00003oooooooooo`08ooooo`00
2Oooool00`00003oooooooooo`2booooo`0300000?oooooooooo00oooooo00<00000ooooooooool0
/_ooool00`00003oooooooooo`08ooooo`002Oooool00`00003oooooooooo`2booooo`0300000?oo
oooooooo00oooooo00<00000ooooooooool0/_ooool00`00003oooooooooo`08ooooo`002Ooooonf
0000017ooooo]P00000:ooooo`00oooooonAooooo`00oooooonAooooo`00oooooonAooooo`00oooo
oonAooooo`00oooooonAooooo`00oooooonAooooo`00oooooonAooooo`00oooooonAooooo`00oooo
oonAooooo`00\
\>"],
  ImageRangeCache->{{{0, 399}, {399, 0}} -> {-0.0500105, -0.0500105, \
0.00526322, 0.00526322}, {{9.5, 190.438}, {389.5, 208.5}} -> {-1.15081, \
-1.15117, 0.0115117, 0.0115117}, {{208.5, 389.438}, {389.5, 208.5}} -> \
{-1.09771, -0.0754011, 0.0052648, 0.0052648}, {{9.5, 190.438}, {190.438, \
9.5}} -> {-1.11761, -3.34306, 0.0111796, 0.0111796}, {{208.5, 389.438}, \
{190.438, 9.5}} -> {-3.34236, -3.34306, 0.0111796, 0.0111796}}]
}, Closed]]
}, Open  ]]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["A closer look: part #1(a)", "Section"],

Cell[CellGroupData[{

Cell["Setup", "Subsection"],

Cell[CellGroupData[{

Cell["Which model to examine", "Subsubsection"],

Cell[BoxData[
    \(\(tstModel\  = \ em2[\([1]\)];\)\)], "Input",
  CellFrame->True,
  Background->GrayLevel[0.849989]]
}, Closed]],

Cell[CellGroupData[{

Cell["Sample data point", "Subsubsection",
  CellFrame->False],

Cell[BoxData[
    \(\(xtst\  = \ xd[\([1]\)];\)\)], "Input",
  CellFrame->True,
  Background->GrayLevel[0.849989]]
}, Closed]],

Cell[CellGroupData[{

Cell["Generate graphic for selected mode", "Subsubsection"],

Cell[BoxData[{
    \(\(gmodel\  = \ 
        PlotMeansTwo[tstModel, \ pr, \ colors, \ 
          nS];\)\), "\[IndentingNewLine]", 
    \(\(gbase = Show[gdata, gmodel, \ nS];\)\)}], "Input"]
}, Closed]]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  "Plot ",
  Cell[BoxData[
      \(TraditionalForm\`P(\[Omega]\_i | \[Theta], x\_j)\)]],
  " for sample point"
}], "Subsection"],

Cell[CellGroupData[{

Cell["Sample data point highlighted", "Subsubsection"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(\(\ \)\(PlotExampleOne[xtst, initialModel, colors, gbase, 1, 
        yS];\)\)\)], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.49505 0.5 0.49505 [
[ 0 0 -0.125 0 ]
[ 0 0 -0.125 0 ]
[ 0 1 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
0 0 m
1 0 L
s
0 0 m
0 1 L
s
0 1 m
1 1 L
s
1 0 m
1 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
1 .5 0 r
.015 w
.03175 .1355 Mdot
.03435 .12523 Mdot
.11137 .12765 Mdot
.14107 .18841 Mdot
.16218 .24538 Mdot
.17294 .21053 Mdot
.18267 .18577 Mdot
.18434 .1304 Mdot
.18553 .30956 Mdot
.20401 .239 Mdot
.21247 .27571 Mdot
.21687 .20845 Mdot
.22376 .2799 Mdot
.22832 .27485 Mdot
.29063 .20974 Mdot
.29686 .25079 Mdot
.30487 .22936 Mdot
.30683 .34623 Mdot
.32055 .20902 Mdot
.32574 .21979 Mdot
.34472 .28521 Mdot
.35998 .36393 Mdot
.36335 .24976 Mdot
.3794 .36608 Mdot
.42386 .66992 Mdot
.44391 .74519 Mdot
.45059 .34198 Mdot
.47208 .67586 Mdot
.47436 .71381 Mdot
.49778 .59825 Mdot
.50874 .91643 Mdot
.51516 .76219 Mdot
.53655 .61374 Mdot
.56563 .75219 Mdot
.59189 .65665 Mdot
.59581 .61604 Mdot
.59923 .6556 Mdot
.60292 .68499 Mdot
.62656 .67779 Mdot
.63555 .72451 Mdot
.63919 .652 Mdot
.64169 .6004 Mdot
.64246 .58611 Mdot
.64496 .54267 Mdot
.64608 .77288 Mdot
.65077 .64308 Mdot
.66065 .57816 Mdot
.67474 .59169 Mdot
.69296 .563 Mdot
.72815 .65902 Mdot
.73169 .58879 Mdot
.74669 .61318 Mdot
.74821 .65474 Mdot
.75963 .63781 Mdot
.79673 .57809 Mdot
.80925 .55852 Mdot
.81525 .58444 Mdot
.83417 .62985 Mdot
.83598 .55526 Mdot
.91595 .49319 Mdot
1 0 0 r
.005 w
.00495 .28842 m
.00628 .29156 L
.01857 .31761 L
.03101 .33781 L
.03525 .34367 L
.05706 .36884 L
.05795 .36972 L
.08312 .39115 L
.08963 .39578 L
.10917 .40763 L
.13523 .41964 L
.14074 .42183 L
.16128 .42794 L
.18734 .43294 L
.21339 .43485 L
.23945 .43375 L
.2655 .42959 L
.29156 .42219 L
.29261 .42183 L
.31761 .41124 L
.34367 .39603 L
.34405 .39578 L
.36972 .37551 L
.37582 .36972 L
.39578 .34724 L
.39849 .34367 L
.41525 .31761 L
.42183 .30485 L
.4275 .29156 L
.436 .2655 L
.44117 .23945 L
.44325 .21339 L
.44232 .18734 L
.43834 .16128 L
.43114 .13523 L
.42183 .11212 L
.42037 .10917 L
.40546 .08312 L
.39578 .06961 L
.38528 .05706 L
.36972 .04137 L
.35758 .03101 L
.34367 .02092 L
.31761 .00569 L
.3162 .00495 L
s
.00495 .12854 m
.01344 .10917 L
.02832 .08312 L
.03101 .07912 L
.04848 .05706 L
.05706 .04802 L
.07619 .03101 L
.08312 .02579 L
.10917 .00934 L
.11742 .00495 L
s
0 0 1 r
.29156 .15739 m
.31761 .14824 L
.34367 .14249 L
.36972 .13986 L
.39578 .14025 L
.42183 .14366 L
.44789 .15025 L
.47394 .16034 L
.47599 .16128 L
.5 .17443 L
.51844 .18734 L
.52606 .19355 L
.54662 .21339 L
.55211 .21962 L
.56712 .23945 L
.57817 .25755 L
.58227 .2655 L
.59322 .29156 L
.60058 .31761 L
.60422 .3392 L
.60471 .34367 L
.6058 .36972 L
.60422 .39297 L
.60387 .39578 L
.59886 .42183 L
.59054 .44789 L
.57848 .47394 L
.57817 .47453 L
.562 .5 L
.55211 .51255 L
.53968 .52606 L
.52606 .53862 L
.50853 .55211 L
.5 .55773 L
.47394 .57183 L
.45901 .57817 L
.44789 .5819 L
.42183 .5885 L
.39578 .59192 L
.36972 .59231 L
.34367 .58968 L
.31761 .58392 L
.29972 .57817 L
.29156 .57477 L
.2655 .56178 L
.25025 .55211 L
.23945 .54409 L
.21914 .52606 L
.21339 .52008 L
.19681 .5 L
Mistroke
.18734 .48608 L
.18031 .47394 L
.16827 .44789 L
.16128 .42714 L
.15996 .42183 L
.15493 .39578 L
.153 .36972 L
.15409 .34367 L
.15823 .31761 L
.16128 .3045 L
.16559 .29156 L
.17653 .2655 L
.18734 .24609 L
.19169 .23945 L
.21221 .21339 L
.21339 .21211 L
.23945 .1881 L
.24041 .18734 L
.2655 .17038 L
.28271 .16128 L
.29156 .15739 L
Mfstroke
1 0 0 r
.03 w
.21687 .20845 Mdot
0 0 1 r
.3794 .36608 Mdot
1 0 0 r
.79703 .00495 m
.79703 .19993 L
.87129 .19993 L
.87129 .00495 L
F
0 0 1 r
.89604 .00495 m
.89604 .0575 L
.9703 .0575 L
.9703 .00495 L
F
1 0 1 r
.04 w
.03175 .1355 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P000182000`400?l00000o`00003ooooooolQ
ooooo`00o`00000P0000007ooooo00000`00003oooooooooo`0Mooooo`80o`00>?ooool2ool00003
0?l00?oooooooooo0;oooooo0@000001ooooo`0000<00000ooooooooool06oooool20?l003gooooo
00<0o`00ooooooooool0Q?oooolE0?l000Sooooo5@000?l8ooooo`4000000Oooool0000300000?oo
oooooooo01[ooooo00<0o`00ooooooooool0?_ooool20?l008Cooooo5@3o0008oooooaD0003o2?oo
ool10000007ooooo00000`00003oooooooooo`0Hooooo`80o`00@oooool00`3o003oooooooooo`21
oooooaD0o`002?oooolE0000o`Sooooo0@000001ooooo`0000<00000ooooooooool05_ooool20?l0
04Kooooo00<0o`00ooooooooool0P?oooolE0?l000Sooooo5@000?l8ooooo`4000000Oooool00003
00000?oooooooooo01Gooooo00<0o`00ooooooooool0Aoooool20?l0083ooooo5@3o0008oooooaD0
003o2?ooool10000007ooooo00000`00003oooooooooo`0Dooooo`030?l00?oooooooooo04[ooooo
00<0o`00ooooooooool0OOoooolE0?l000Sooooo5@000?l8ooooo`4000000Oooool0000300000?oo
oooooooo01?ooooo00<0o`00ooooooooool0C?ooool00`3o003oooooooooo`1loooooaD0o`002?oo
oolE0000o`Sooooo0@000001ooooo`0000<00000ooooooooool04Oooool20?l0053ooooo0P3o001l
oooooaD0o`002?oooolE0000o`Sooooo0@000001ooooo`0000<00000ooooooooool04?ooool00`3o
003oooooooooo`1Booooo`80o`00N_oooolE0?l000Sooooo5@000?l8ooooo`4000000Oooool00003
00000?oooooooooo00oooooo00<0o`00ooooooooool0EOooool00`3o003oooooooooo`1goooooaD0
o`002?oooolE0000o`Sooooo0@000001ooooo`0000<00000ooooooooool03_ooool00`3o003ooooo
ooooo`1Fooooo`030?l00?oooooooooo07Oooooo5@3o0008oooooaD0003o2?ooool10000007ooooo
00000`00003oooooooooo`0=ooooo`030?l00?oooooooooo05Sooooo00<0o`00ooooooooool0M_oo
oolE0?l000Sooooo5@000?l8ooooo`4000000Oooool0000300000?oooooooooo00gooooo00<0o`00
ooooooooool0FOooool00`3o003oooooooooo`1eoooooaD0o`002?oooolE0000o`Sooooo0@000001
ooooo`0000<00000ooooooooool03?ooool00`3o003oooooooooo`1Kooooo`030?l00?oooooooooo
07Cooooo5@3o0008oooooaD0003o2?ooool10000007ooooo00000`00003oooooooooo`0;ooooo`03
0?l00?oooooooooo05gooooo00<0o`00ooooooooool0LooooolE0?l000Sooooo5@000?l8ooooo`40
00000Oooool0000300000?oooooooooo00_ooooo00<0o`00ooooooooool0GOooool00`3o003ooooo
ooooo`1coooooaD0o`009Oooool10000007ooooo00000`00003oooooooooo`0:ooooo`030?l00?oo
oooooooo05oooooo00<0o`00ooooooooool0L_oooolE0?l002Gooooo0@000001ooooo`0000<00000
ooooooooool02Oooool00`3o003oooooooooo`1Qooooo`030?l00?oooooooooo077ooooo5@3o000U
ooooo`4000000Oooool0000300000?oooooooooo00Sooooo00<0o`00ooooooooool0Hoooool00`3o
003oooooooooo`1`oooooaD0o`009Oooool10000007ooooo00000`00003oooooooooo`07ooooo`03
0?l00?oooooooooo06Gooooo00<0o`00ooooooooool0KooooolE0?l002Gooooo0@000001ooooo`00
00<00000ooooooooool01_ooool00`3o003oooooooooo`1Wooooo`030?l00?oooooooooo06kooooo
5@3o000Uooooo`4000000Oooool0000300000?oooooooooo00Gooooo00?oo`00ooooooooool0JOoo
ool00`3o003oooooooooo`1]oooooaD0o`009Oooool10000007ooooo00000`00003oooooooooo`05
ooooo`030?l00?oooooooooo06Wooooo00<0o`00ooooooooool0KOoooolE0?l002Gooooo0@000001
ooooo`0000<00000ooooooooool01?ooool00`3o003oooooooooo`1[ooooo`030?l00?oooooooooo
06cooooo5@3o000Uooooo`4000000Oooool0000300000?oooooooooo00?ooooo00<0o`00oooooooo
ool0K?ooool00`3o003oooooooooo`1/oooooaD0o`009Oooool10000007ooooo00000`00003ooooo
ooooo`03ooooo`030?l00?oooooooooo06gooooo00<0o`00ooooooooool0JooooolE0?l002Gooooo
0@000001ooooo`0000<00000ooooooooool00_ooool00`3o003oooooooooo`1^ooooo`030?l00?oo
oooooooo06_ooooo5@3o000Uooooo`4000000Oooool0000300000?oooooooooo00;ooooo00<0o`00
ooooooooool0Koooool00`3o003oooooooooo`1ZoooooaD0o`009Oooool10000007ooooo00001@00
003oooooooooooooool0o`0007;ooooo00<0o`00ooooooooool0J_oooolE0?l002Gooooo0@000001
ooooo`0000@00000ooooooooool0o`00M?ooool00`3o003oooooooooo`1YoooooaD0o`009Oooool1
0000007ooooo00001000003oooooooooo`3o001eooooo`03ool00?oooooooooo06Sooooo5@3o000U
ooooo`4000000Oooool0000300000?ooool0o`0007Kooooo00<0o`00ooooooooool0J?oooolE0?l0
02Gooooo0@000001ooooo`0000<00000ooooo`3o00001?ooool5ool0ofkooooo00<0o`00oooooooo
ool0IooooolE0?l002Gooooo0@000001ooooo`0000<00000ooooo`3o00000oooool7ool0oa;ooooo
0_ooO`1Iooooo`030?l00?oooooooooo06Oooooo5@3o000Uooooo`4000000Oooool000030000003o
003ooooo00;ooooo2Ooo0?l@ooooo`Coogl04_ooool2oomo04Cooooo00<0o`00ooooooooool0Iooo
oolE0?l002Gooooo0@000001ooooo`0000@00000oooooooooooooooo2ooo0?l?ooooo`Coogl04Ooo
ool4oomo04Cooooo00<0o`00ooooooooool0I_oooolE0?l002Gooooo0@000001ooooo`0000@00000
oooooooooooooooo2ooo0?l@ooooo`;oogl04_ooool4oomo04Cooooo00<0o`00ooooooooool0I_oo
oolE0?l002Gooooo0@000001ooooo`0000@00000oooooooooooooooo2ooo0?lUooooo`;oogl0AOoo
ool00`3o003oooooooooo`1VoooooaD0o`009Oooool10000007ooooo00001000003ooooooooooooo
ool;ool0oe7ooooo5_l00?l5ooooo`030?l00?oooooooooo06Kooooo5@3o000Uooooo`4000000Ooo
ool0000400000?ooooooooooooooo`_oo`3oC_ooool3o`00oaKooooo1_l00?l00`3o003ooooooooo
o`1UoooooaD0o`009Oooool10000007ooooo00000`00003oooooooooo`02ooooo`Woo`3oC?ooool3
o`00oaoooooo0ol00?mUoooooaD0o`009Oooool10000007ooooo00000`00003oooooooooo`03oooo
o`Ooo`3oB_ooool3o`00ob;ooooo00<0o`00ooooooooool00ol00?mRoooooaD0o`009Oooool10000
007ooooo00000`00003oooooooooo`04ooooo`Goo`3oB?ooool3o`00obGooooo00<0o`00oooooooo
ool00oooool3o`00oeoooooo5@3o000Uooooo`4000000Oooool0000300000?oooooooooo04oooooo
0P000?lYooooo`030?l00?oooooooooo00Gooooo0ol00?mLoooooaD0o`009Oooool10000007ooooo
00000`00003oooooooooo`1=ooooo`80003o:oooool00`3o003oooooooooo`08ooooo`;o003oF_oo
oolE0?l002Gooooo0@000001ooooo`0000<00000ooooooooool0B_ooool30000obgooooo00<0o`00
ooooooooool02_ooool2o`00oeSooooo5@3o000Uooooo`4000000Oooool0000300000?oooooooooo
04Sooooo0P000?l`ooooo`030?l00?oooooooooo00cooooo00?o003oooooooooool0EOoooolE0?l0
02Gooooo0@000001ooooo`0000<00000ooooooooool0Aoooool00`000?ooooooooooo`0`ooooo`03
0?l00?oooooooooo00gooooo0_l00?mEoooooaD0o`009Oooool10000007ooooo00000`00003ooooo
ooooo`15ooooo`80003o=?ooool00`3o003oooooooooo`0>ooooo`;o003oDooooolE0?l002Gooooo
0@000001ooooo`0000<00000ooooooooool0A?ooool00`000?ooooooooooo`0dooooo`030?l00?oo
oooooooo013ooooo0_l00?mAoooooaD0o`009Oooool10000007ooooo00000`00003oooooooooo`0T
ooooo`;oogl02_ooool2oomo017ooooo00<0003oooooooooool0=Oooool00`3o003oooooooooo`0B
ooooo`03o`00oooooooooooo04kooooo5@3o000Uooooo`4000000Oooool0000300000?oooooooooo
02?ooooo1?ooO`08ooooo`Coogl03oooool00`000?ooooooooooo`0fooooo`030?l00?oooooooooo
01?ooooo00?o003oooooooooool0COoooolE0?l002Gooooo0@000001ooooo`0000<00000oooooooo
ool08oooool4oomo00Sooooo1?ooO`0=ooooo`030000ool00?oooooo03Sooooo00<0o`00oooooooo
ool05?ooool00ol00?ooooooooooo`1<oooooaD0o`009Oooool10000007ooooo00000`00003ooooo
ooooo`0Tooooo`;oogl02_ooool2oomo00gooooo00<0003oooooooooool0>Oooool00`3o003ooooo
ooooo`0Eooooo`03o`00oooooooooooo04_ooooo5@3o000Uooooo`4000000Oooool0000300000?oo
oooooooo03Wooooo1?oo00000oooool0003oooooo`0kooooo`030?l00?oooooooooo01Kooooo00?o
003oooooooooool0B_oooolE0?l002Gooooo0@000001ooooo`0000<00000ooooooooool0>?ooool6
ool003gooooo00<0o`00ooooooooool05oooool00ol00?ooooooooooo`19oooooaD0o`009Oooool1
0000007ooooo00000`00003oooooooooo`0gooooo`Soo`004?ooool2oomo00Oooooo0_ooO`0Roooo
o`030?l00?oooooooooo01Oooooo00?o003oooooooooool0P_ooool10000007ooooo00000`00003o
ooooooooo`0^ooooo`;oogl01oooool8ool000oooooo1?ooO`05ooooo`Coogl08Oooool00`3o003o
ooooooooo`0Hooooo`03o`00oooooooooooo087ooooo0@000001ooooo`0000<00000ooooooooool0
;Oooool4oomo00Kooooo2?oo000?ooooo`Coogl01Oooool4oomo027ooooo00<0o`00ooooooooool0
6Oooool00ol00?ooooooooooo`20ooooo`4000000Oooool0000300000?oooooooooo02gooooo1?oo
O`06ooooo`Soo`004?ooool2oomo00Oooooo0oooO`0Qooooo`030?l00?oooooooooo01[ooooo00?o
003oooooooooool0Ooooool10000007ooooo00000`00003oooooooooo`0^ooooo`;oogl02?ooool6
ool001[ooooo1?ooO`0Pooooo`030?l00?oooooooooo01_ooooo00?o003oooooooooool0O_ooool1
0000007ooooo00000`00003oooooooooo`0hooooo`030000oooo003oo`0000;oo`006oooool4oomo
023ooooo00<0o`00ooooooooool07?ooool00ol00?ooooooooooo`1mooooo`4000000Oooool00003
00000?oooooooooo03Oooooo00<0003oooooooooool06Oooool2oomo00Cooooo0_ooO`0Qooooo`03
0?l00?oooooooooo01cooooo00?o003oooooooooool0OOooool10000007ooooo00000`00003ooooo
ooooo`0fooooo`030000oooooooooooo01Wooooo1?ooO`0Uooooo`030?l00?oooooooooo01kooooo
00?o003oooooooooool0O?ooool10000007ooooo00000`00003oooooooooo`0fooooo`030000oooo
oooooooo01Wooooo1?ooO`0Uooooo`030?l00?oooooooooo01oooooo00?o003oooooooooool0Nooo
ool10000007ooooo00000`00003oooooooooo`0eooooo`040000ooooooooogl0oomo01[ooooo0_oo
O`0Vooooo`030?l00?oooooooooo023ooooo00?o003oooooooooool0N_ooool10000007ooooo0000
0`00003oooooooooo`0dooooo`030000ooooooooogl000?oogl0@Oooool00`3o003oooooooooo`0Q
ooooo`03o`00oooooooooooo07Wooooo0@000001ooooo`0000<00000ooooooooool0:oooool2oomo
00Kooooo00<0003oooooooooool01?ooO`11ooooo`030?l00?oooooooooo027ooooo00?o003ooooo
ooooool0NOooool10000007ooooo00000`00003oooooooooo`0Zooooo`Coogl01?ooool00`000?oo
ooooooooo`02ooooo`;oogl06?ooool2oomo017ooooo0_ooO`0Eooooo`030?l00?oooooooooo02;o
oooo00?o003oooooooooool0N?ooool10000007ooooo00000`00003oooooooooo`0Zooooo`Coogl0
1?ooool00`000?ooooooooooo`0Kooooo`Coogl03oooool4oomo01Cooooo00<0o`00ooooooooool0
8oooool00ol00?ooooooooooo`1gooooo`4000000Oooool0000300000?oooooooooo02_ooooo0_oo
O`04ooooo`030000oooooooooooo01cooooo1?ooO`0?ooooo`Coogl05?ooool00`3o003ooooooooo
o`0Sooooo`03o`00oooooooooooo07Oooooo0@000001ooooo`0000<00000ooooooooool0<Oooool0
0`000?ooooooooooo`0Mooooo`;oogl04Oooool2oomo01Cooooo00<0o`00ooooooooool09Oooool0
0ol00?ooooooooooo`1fooooo`4000000Oooool0000300000?oooooooooo033ooooo00<0003ooooo
ooooool0Aoooool00`3o003oooooooooo`0Uooooo`03o`00oooooooooooo07Kooooo0@000001oooo
o`0000<00000ooooooooool0<?ooool00`000?ooooooooooo`17ooooo`030?l00?oooooooooo02Ko
oooo00?o003oooooooooool0MOooool10000007ooooo00000`00003oooooooooo`0_ooooo`030000
oooooooooooo04Sooooo00<0o`00ooooooooool09oooool00ol00?ooooooooooo`1dooooo`400000
0Oooool0000300000?oooooooooo02oooooo00<0003oooooooooool01oooool2oomo00;ooooo0_oo
O`0kooooo`030?l00?oooooooooo02Oooooo00?o003oooooooooool0M?ooool10000007ooooo0000
0`00003oooooooooo`0^ooooo`030000oooooooooooo00Oooooo2?ooO`0iooooo`030?l00?oooooo
oooo02Wooooo00?o003oooooooooool0Loooool10000007ooooo00000`00003oooooooooo`0^oooo
o`030000oooooooooooo00Oooooo2?ooO`0iooooo`030?l00?oooooooooo02Wooooo00?o003ooooo
ooooool0Loooool10000007ooooo00000`00003oooooooooo`0]ooooo`030000oooooooooooo00Wo
oooo1_ooO`0Pooooo`;oogl05oooool00`3o003oooooooooo`0[ooooo`03o`00oooooooooooo07;o
oooo0@000001ooooo`0000<00000ooooooooool0;Oooool00`000?ooooooooooo`0;ooooo`Coogl0
7oooool4oomo01Kooooo00<0o`00ooooooooool0:oooool00ol00?ooooooooooo`1booooo`400000
0Oooool0000300000?oo003ooooo02gooooo00<0003oooooooooool03?ooool2oomo023ooooo1?oo
O`0Fooooo`030?l00?oooooooooo02_ooooo00?o003oooooooooool0L_ooool10000007ooooo0000
0`000000o`00ooooo`0/ooooo`030000oooooooooooo033ooooo0_ooO`0Fooooo`030?l00?oooooo
oooo02gooooo00?o003oooooooooool0LOooool10000007ooooo00000`000000o`00ooooo`0/oooo
o`030000oooooooooooo04Sooooo00<0o`00ooooooooool0;Oooool00ol00?ooooooooooo`1aoooo
o`4000000Oooool0000300000?ooool0o`0002cooooo00<0003oooooooooool0B?ooool00`3o003o
ooooooooo`0]ooooo`03o`00oooooooooooo077ooooo0@000001ooooo`0000<00000ooooo`3o0000
:oooool00`000?ooooooooooo`18ooooo`030?l00?oooooooooo02oooooo00?o003oooooooooool0
L?ooool10000007ooooo00001000003oooooooooo`3o000Zooooo`030000oooooooooooo00?ooooo
0_ooO`13ooooo`030?l00?oooooooooo02oooooo00?o003oooooooooool0L?ooool10000007ooooo
00001000003oooooooooo`3o000Zooooo`030000oooooooooooo00;ooooo1?ooO`12ooooo`030?l0
0?oooooooooo02oooooo00?o003oooooooooool0L?ooool10000007ooooo00001@00003ooooooooo
ooooool0o`0002Wooooo00<0003oooooooooool00_ooool4oomo047ooooo00<0o`00ooooooooool0
<?ooool00ol00?ooooooooooo`1`ooooo`4000000Oooool0000500000?ooooooooooooooo`3o0000
:?ooool00`000?ooooooooooo`04ooooo`;oogl0@_ooool00`3o003oooooooooo`0aooooo`03o`00
oooooooooooo06oooooo0@000001ooooo`0000<00000ooooooooool00_ooool00`3o003ooooooooo
o`0Uooooo`030000oooooooooooo04Oooooo00<0o`00ooooooooool0<_ooool00ol00?oooooooooo
o`1_ooooo`4000000Oooool0000300000?oooooooooo00;ooooo00<0o`00ooooooooool09Oooool0
0`000?ooooooooooo`17ooooo`030?l00?oooooooooo03;ooooo00?o003oooooooooool0Koooool1
0000007ooooo00000`00003oooooooooo`03ooooo`030?l00?oooooooooo02Cooooo00<0003ooooo
ooooool0A_ooool00`3o003oooooooooo`0cooooo`03o`00oooooooooooo06oooooo0@000001oooo
o`0000<00000ooooooooool01?ooool00`3o003oooooooooo`0Sooooo`030000oooooooooooo04Go
oooo00<0o`00ooooooooool0=?ooool00ol00?ooooooooooo`1_ooooo`4000000Oooool000030000
0?oooooooooo00Gooooo00<0o`00ooooooooool08Oooool00`000?ooooooooooo`15ooooo`030?l0
0?oooooooooo03Kooooo00?o003oooooooooool0K_ooool10000007ooooo00000`00003ooooooooo
o`06ooooo`030?l00?oooooooooo023ooooo00<0003oooooooooool0AOooool00`3o003ooooooooo
o`09ooooo`;oogl0:oooool00ol00?ooooooooooo`1^ooooo`4000000Oooool0000300000?oooooo
oooo00Kooooo00<0o`00ooooooooool08?ooool00`000?ooooooooooo`14ooooo`030?l00?oooooo
oooo00Wooooo1?ooO`0Zooooo`03o`00oooooooooooo06kooooo0@000001ooooo`0000<00000oooo
ooooool01oooool00`3o003oooooooooo`0Oooooo`030000oooooooooooo02Sooooo0_ooO`0Ioooo
o`030?l00?oooooooooo00[ooooo1?ooO`0Zooooo`03o`00oooooooooooo06kooooo0@000001oooo
o`0000<00000ooooooooool01oooool00`3o003oooooooooo`0Oooooo`030000oooooooooooo02Oo
oooo1?ooO`0Gooooo`03ool00?oooooooooo00cooooo0_ooO`0[ooooo`03o`00oooooooooooo06ko
oooo0@000001ooooo`0000<00000ooooooooool02?ooool00`3o003oooooooooo`0Nooooo`030000
oooooooooooo02Oooooo1?ooO`0Gooooo`030?l00?oooooooooo03Wooooo00?o003oooooooooool0
K_ooool10000007ooooo00000`00003oooooooooo`09ooooo`030?l00?oooooooooo01gooooo00<0
003oooooooooool0:?ooool2oomo01;ooooo1?l00?l00oooool0o`00ooooo`0kooooo`03o`00oooo
oooooooo06kooooo0@000001ooooo`0000<00000ooooooooool02_ooool00`3o003oooooooooo`0L
ooooo`030000oooooooooooo03_ooooo1_l00?lmooooo`03o`00oooooooooooo06kooooo0@000001
ooooo`0000<00000ooooooooool02oooool00`3o003oooooooooo`0Kooooo`030000oooooooooooo
03Oooooo0_ooO`000ooooooo003oo`00o`06o`00occooooo00?o003oooooooooool0K_ooool10000
007ooooo00000`00003oooooooooo`0<ooooo`030?l00?oooooooooo01[ooooo00<0003ooooooooo
ool0=_ooool4oomo00So003o??ooool00ol00?ooooooooooo`1^ooooo`4000000Oooool000030000
0?oooooooooo00gooooo00?oo`00ooooooooool06Oooool00`000?ooooooooooo`0fooooo`Coogl0
2?l00?llooooo`03o`00oooooooooooo06kooooo0@000001ooooo`0000<00000ooooooooool03Ooo
ool20?l001[ooooo00<0003oooooooooool0=oooool2oomo0003ooooool00?oo003o00Ko003o??oo
ool00ol00?ooooooooooo`1^ooooo`4000000Oooool0000300000?oooooooooo00oooooo00<0o`00
ooooooooool05oooool00`000?ooooooooooo`0jooooo`030?l00?l00?oo003o00Co003o?Oooool0
0ol00?ooooooooooo`1^ooooo`4000000Oooool0000300000?oooooooooo013ooooo00<0o`00oooo
ooooool05_ooool00`000?ooooooooooo`0iooooo`030?l00?oooooooooo00Co003o?_ooool00ol0
0?ooooooooooo`1^ooooo`4000000Oooool0000300000?oooooooooo017ooooo00<0o`00oooooooo
ool05Oooool00`000?ooooooooooo`0hooooo`030?l00?oooooooooo04?ooooo00?o003ooooooooo
ool0K_ooool10000007ooooo00000`00003oooooooooo`0Booooo`030?l00?oooooooooo01Cooooo
00<0003oooooooooool0=_ooool20?l004Kooooo00?o003oooooooooool0K_ooool10000007ooooo
00000`00003oooooooooo`0Cooooo`030?l00?oooooooooo01?ooooo00<0003oooooooooool0=Ooo
ool00`3o003oooooooooo`16ooooo`03o`00oooooooooooo06kooooo0@000001ooooo`0000<00000
ooooooooool05?ooool20?l001?ooooo00<0003oooooooooool0=?ooool00`3o003oooooooooo`17
ooooo`03o`00oooooooooooo06kooooo0@000001ooooo`0000<00000ooooooooool05_ooool20?l0
017ooooo00<0003oooooooooool0<_ooool20?l004[ooooo00?o003oooooooooool0K_ooool10000
007ooooo00000`00003oooooooooo`0Hooooo`030?l00?oooooooooo00kooooo00<0003ooooooooo
ool0<Oooool00`3o003oooooooooo`1:ooooo`03o`00oooooooooooo06kooooo0@000001ooooo`00
00<00000ooooooooool06Oooool20?l000kooooo00<0003oooooooooool0;oooool20?l004gooooo
00?o003oooooooooool0K_ooool10000007ooooo00000`00003oooooooooo`0Kooooo`030?l00?oo
oooooooo00_ooooo00<0003oooooooooool0;_ooool00`3o003oooooooooo`1<ooooo`03o`00oooo
oooooooo06oooooo0@000001ooooo`0000<00000ooooooooool07?ooool20?l000_ooooo00<0003o
ooooooooool0;Oooool00`3o003oooooooooo`1=ooooo`03o`00oooooooooooo06oooooo0@000001
ooooo`0000<00000ooooooooool07_ooool30?l000Wooooo00<0003oooooooooool0:_ooool20?l0
053ooooo00?o003oooooooooool0Koooool10000007ooooo00000`00003oooooooooo`0Qooooo`80
o`001oooool00`000?ooooooooooo`0Wooooo`<0o`00D_ooool00ol00?ooooooooooo`1_ooooo`40
00000Oooool0000300000?oooooooooo02?ooooo0P3o0005ooooo`030000oooooooooooo02Gooooo
0P3o001Dooooo`03o`00oooooooooooo073ooooo0@000001ooooo`0000<00000ooooooooool09Ooo
ool40?l00003ooooo`000?oooooo02;ooooo0P3o00000ooo0000o`00ooooo`1Eooooo`03o`00oooo
oooooooo073ooooo0@000001ooooo`0000<00000ooooooooool0:Oooool20?l00003o`00o`3o0000
o`0001gooooo0`3o001Jooooo`03o`00oooooooooooo073ooooo0@000001ooooo`0000<00000oooo
ooooool0:oooool00`000?ooooooooooo`030?l001Cooooo1P3o001Mooooo`03o`00oooooooooooo
073ooooo0@000001ooooo`0000<00000ooooooooool0;?ooool00`000?ooooooooooo`02oooooa@0
o`00H_ooool00ol00?ooooooooooo`1aooooo`4000000Oooool0000300000?oooooooooo02cooooo
00<0003oooooooooool0N?ooool00ol00?ooooooooooo`1aooooo`4000000Oooool0000300000?oo
oooooooo02cooooo00<0003oooooooooool0N?ooool00ol00?ooooooooooo`1aooooo`4000000Ooo
ool0000300000?oooooooooo02gooooo00<0003oooooooooool0M_ooool00ol00?ooooooooooo`1b
ooooo`4000000Oooool0000300000?oooooooooo02gooooo00<0003oooooooooool0M_ooool00ol0
0?ooooooooooo`1booooo`4000000Oooool0000300000?oooooooooo02gooooo00<0003ooooooooo
ool0M_ooool00ol00?ooooooooooo`1booooo`4000000Oooool0000300000?oooooooooo02kooooo
00<0003oooooooooool0M?ooool00ol00?ooooooooooo`1cooooo`4000000Oooool0000300000?oo
oooooooo02kooooo00<0003oooooooooool0M?ooool00ol00?ooooooooooo`1cooooo`4000000Ooo
ool0000300000?oooooooooo02kooooo00<0003oooooooooool0M?ooool00ol00?ooooooooooo`1c
ooooo`4000000Oooool0000300000?oooooooooo02oooooo00<0003oooooooooool0L_ooool00ol0
0?ooooooooooo`1dooooo`4000000Oooool0000300000?oooooooooo02oooooo00<0003ooooooooo
ool0L_ooool00ol00?ooooooooooo`1dooooo`4000000Oooool0000300000?oooooooooo02oooooo
00<0003oooooooooool0L_ooool00ol00?ooooooooooo`1dooooo`4000000Oooool0000300000?oo
oooooooo033ooooo00<0003oooooooooool0Koooool2o`00ogOooooo0@000001ooooo`0000<00000
ooooooooool0<?ooool00`000?ooooooooooo`1_ooooo`03o`00oooooooooooo07Kooooo0@000001
ooooo`0000<00000ooooooooool0<Oooool00`000?ooooooooooo`1]ooooo`03o`00oooooooooooo
07Oooooo0@000001ooooo`0000<00000ooooooooool0<_ooool00`000?ooooooooooo`1/ooooo`03
o`00oooooooooooo07Oooooo0@000001ooooo`0000<00000ooooooooool0<_ooool00`000?oooooo
ooooo`1[ooooo`03o`00oooooooooooo063ooooo0_ooO`0Fooooo`4000000Oooool0000300000?oo
oooooooo03?ooooo00<0003oooooooooool0JOooool00ol00?ooooooooooo`1Pooooo`Coogl05Ooo
ool10000007ooooo00000`00003oooooooooo`0dooooo`030000oooooooooooo06Sooooo00?o003o
ooooooooool0H?ooool4oomo01Gooooo0@000001ooooo`0000<00000ooooooooool0=Oooool00`00
0?ooooooooooo`1Vooooo`03o`00oooooooooooo06;ooooo0_ooO`0Fooooo`4000000Oooool00003
00000?oooooooooo03Gooooo00?o003oooooooooool0I_ooool00ol00?ooooooooooo`1jooooo`40
00000Oooool0000300000?oooooooooo03Kooooo00?o003oooooooooool0I?ooool00ol00?oooooo
ooooo`1kooooo`4000000Oooool0000300000?oooooooooo03Oooooo00?o003oooooooooool0H_oo
ool00ol00?ooooooooooo`1looooo`4000000Oooool0000300000?oooooooooo03Sooooo00?o003o
ooooooooool0Goooool2o`00ogoooooo0@000001ooooo`0000<00000ooooooooool0>Oooool00ol0
0?ooooooooooo`1Mooooo`03o`00oooooooooooo07oooooo0@000001ooooo`0000<00000oooooooo
ool0>_ooool00ol00?ooooooooooo`1Kooooo`03o`00oooooooooooo083ooooo0@000001ooooo`00
00<00000ooooooooool0>oooool00ol00?ooooooooooo`1Iooooo`03o`00oooooooooooo087ooooo
0@000001ooooo`0000<00000ooooooooool0??ooool00ol00?ooooooooooo`1Gooooo`03o`00oooo
oooooooo08;ooooo0@000001ooooo`0000<00000ooooooooool0?Oooool00ol00?ooooooooooo`1E
ooooo`03o`00oooooooooooo08?ooooo0@000001ooooo`0000<00000ooooooooool0?_ooool00ol0
0?ooooooooooo`1Cooooo`03o`00oooooooooooo08Cooooo0@000001ooooo`0000<00000oooooooo
ool0?oooool00ol00?ooooooooooo`1@ooooo`;o003o8Oooool2oomo06Cooooo0@000001ooooo`00
00<00000ooooooooool0@?ooool00ol00?ooooooooooo`1>ooooo`03o`00oooooooooooo023ooooo
1?ooO`1Sooooo`4000000Oooool0000300000?oooooooooo047ooooo0_l00?m=ooooo`03o`00oooo
oooooooo027ooooo1?ooO`1Sooooo`4000000Oooool0000300000?oooooooooo04?ooooo00?o003o
ooooooooool0BOooool00ol00?ooooooooooo`0Sooooo`;oogl0=Oooool2oomo02gooooo0@000001
ooooo`0000<00000ooooooooool0A?ooool2o`00odSooooo00?o003oooooooooool0Doooool2oomo
00Gooooo1?ooO`0/ooooo`4000000Oooool0000300000?oooooooooo04Kooooo0_l00?m5ooooo`03
o`00oooooooooooo05?ooooo1?ooO`04ooooo`Coogl0;?ooool10000007ooooo00000`00003ooooo
ooooo`18ooooo`03o`00oooooooooooo043ooooo0_l00?lfooooo`;oogl07_ooool4oomo00Gooooo
0_ooO`0]ooooo`4000000Oooool0000300000?oooooooooo04Wooooo0_l00?lnooooo`;o003o=ooo
ool4oomo01kooooo0_ooO`0eooooo`4000000Oooool0000300000?oooooooooo04_ooooo0ol00?lj
ooooo`03o`00oooooooooooo03Oooooo1?ooO`1Eooooo`4000000Oooool0000300000?oooooooooo
04kooooo0_l00?lfooooo`;o003o>oooool2oomo05Kooooo0@000001ooooo`0000<00000oooooooo
ool0D?ooool3o`00oc3ooooo0ol00?lcooooo`;oogl09Oooool2oomo03Wooooo0@000001ooooo`00
00<00000ooooooooool0Doooool2o`00ob[ooooo1?l00?leooooo`Coogl08oooool4oomo03Sooooo
0@000001ooooo`0000<00000ooooooooool0EOooool3o`00ob?ooooo1?l00?leooooo`;oogl00_oo
ool4oomo02?ooooo1?ooO`03ooooo`;oogl0<oooool10000007ooooo00000`00003oooooooooo`1H
ooooo`?o003o7Oooool3o`00ocSooooo1?ooO`02ooooo`;oogl04oooool2oomo013ooooo0_ooO`03
ooooo`Coogl0<_ooool10000007ooooo00000`00003oooooooooo`1Kooooo`?o003o5?ooool6o`00
oc_ooooo1?ooO`06ooooo`;oogl03_ooool4oomo01Cooooo1?ooO`0booooo`4000000Oooool00003
00000?oooooooooo05kooooo5?l00?m2ooooo`;oogl01_ooool4oomo00gooooo1?ooO`0Eooooo`;o
ogl0<oooool10000007ooooo00000`00003oooooooooo`2;ooooo`;oogl09oooool2oomo00Kooooo
1?ooO`0>ooooo`;oogl0Boooool10000007ooooo00000`00003oooooooooo`2:ooooo`Coogl09Ooo
ool4oomo00Kooooo0_ooO`1Looooo`4000000Oooool0000300000?oooooooooo08[ooooo1?ooO`0U
ooooo`Coogl0I?ooool10000007ooooo00000`00003oooooooooo`2;ooooo`;oogl09oooool2oomo
06Gooooo0@000001ooooo`0000<00000ooooooooool0U_ooool2oomo03[ooooo0_ooO`17ooooo`40
00000Oooool0000300000?oooooooooo09Gooooo1?ooO`0>ooooo`;oogl0:?ooool4oomo04Kooooo
0@000001ooooo`0000<00000ooooooooool0UOooool4oomo00gooooo1?ooO`0Wooooo`Coogl0A_oo
ool10000007ooooo00000`00003oooooooooo`2Fooooo`;oogl03_ooool4oomo02Sooooo0_ooO`17
ooooo`4000000Oooool0000300000?oooooooooo0:Oooooo0_ooO`1booooo`4000000Oooool00003
00000?oooooooooo0>_ooooo0_ooO`0^ooooo`4000000Oooool0000300000?oooooooooo0>[ooooo
1?ooO`0]ooooo`4000000Oooool0000300000?oooooooooo0=Kooooo0_ooO`0Booooo`Coogl0;Ooo
ool10000007ooooo00000`00003oooooooooo`3Eooooo`Coogl04_ooool2oomo02kooooo0@000001
ooooo`0000<00000ooooooooool0]oooool2oomo01cooooo1?ooO`12ooooo`4000000Oooool00003
00000?oooooooooo0;Kooooo1?ooO`0Looooo`;oogl0@oooool10000007ooooo00000`00003ooooo
ooooo`2cooooo`;oogl000?ooooooomo0?ooO`000_ooO`1Qooooo`4000000Oooool0000300000?oo
oooooooo0:Sooooo0_ooO`08ooooo`Coogl000?ooooooomo0?ooO`006_ooool2oomo04Kooooo0@00
0001ooooo`0000<00000ooooooooool0Y_ooool5oomo00Oooooo1?ooO`0Gooooo`;oogl00oooool4
oomo04Gooooo0@000001ooooo`0000<00000ooooooooool0YOooool6oomo00Sooooo0_ooO`0Goooo
o`Coogl00_ooool4oomo04Gooooo0@000001ooooo`0000<00000ooooooooool0YOooool5oomo02;o
oooo1?ooO`03ooooo`;oogl0A_ooool10000007ooooo00000`00003oooooooooo`1fooooo`;oogl0
;_ooool2oomo02Gooooo0_ooO`1<ooooo`4000000Oooool0000300000?oooooooooo07Gooooo1?oo
O`2Rooooo`4000000Oooool0000300000?oooooooooo07Gooooo1?ooO`0:ooooo`;oogl0U_ooool1
0000007ooooo00000`00003oooooooooo`1fooooo`;oogl02_ooool4oomo02[ooooo0_ooO`1Yoooo
o`4000000Oooool0000300000?oooooooooo08;ooooo1?ooO`0Yooooo`Coogl0J?ooool10000007o
oooo00000`00003oooooooooo`23ooooo`;oogl09?ooool2oomo00Cooooo1?ooO`1Xooooo`400000
0Oooool0000300000?oooooooooo0:Sooooo1?ooO`04ooooo`;oogl0JOooool10000007ooooo0000
0`00003oooooooooo`2Xooooo`Coogl0Koooool10000007ooooo00000`00003oooooooooo`2Yoooo
o`;oogl0L?ooool10000007ooooo00000`00003oooooooooo`3ooooooacooooo0@000001ooooo`00
00<00000ooooooooool0oooooolLooooo`4000000Oooool0000300000?oooooooooo0?oooooo7?oo
ool10000007ooooo00000`00003oooooooooo`3ooooooacooooo0@000001ooooo`0000<00000oooo
ooooool0Q?ooool2oomo09Gooooo0@000001ooooo`0000<00000ooooooooool0Poooool4oomo09Co
oooo0@000001ooooo`0000<00000ooooooooool0Poooool4oomo09Cooooo0@000001ooooo`0000<0
0000ooooooooool0Q?ooool2oomo02cooooo0_ooO`1Wooooo`4000000Oooool0000300000?oooooo
oooo0;7ooooo1?ooO`1Vooooo`4000000Oooool0000300000?oooooooooo0;7ooooo1?ooO`1Voooo
o`4000000Oooool0000300000?oooooooooo0;;ooooo0_ooO`1Wooooo`4000000Oooool000030000
0?oooooooooo0?oooooo7?ooool10000007ooooo00000`00003oooooooooo`3ooooooacooooo0@00
0001ooooo`0000<00000ooooooooool0Noooool2oomo09kooooo0@000001ooooo`0000<00000oooo
ooooool0N_ooool4oomo09gooooo0@000001ooooo`0000<00000ooooooooool0N_ooool4oomo023o
oooo0_ooO`1kooooo`4000000Oooool0000300000?oooooooooo07_ooooo0_ooO`0Pooooo`Coogl0
N_ooool10000007ooooo00000`00003oooooooooo`2Mooooo`Coogl0N_ooool10000007ooooo0000
0`00003oooooooooo`2@ooooo`;oogl03?ooool2oomo07_ooooo0@000001ooooo`0000<00000oooo
ooooool0Soooool4oomo08Sooooo0@000001ooooo`0000<00000ooooooooool0Soooool4oomo08So
oooo0@000001ooooo`0000<00000ooooooooool0T?ooool2oomo02?ooooo0_ooO`1Tooooo`400000
0Oooool0000300000?oooooooooo0;Cooooo1?ooO`1Sooooo`4000000Oooool0000300000?oooooo
oooo0;Cooooo1?ooO`1Sooooo`4000000Oooool0000300000?oooooooooo0;Gooooo0_ooO`1Toooo
o`4000000Oooool0000300000?oooooooooo0?oooooo7?ooool10000007ooooo00000`00003ooooo
ooooo`3ooooooacooooo0@000001ooooo`0000<00000ooooooooool0oooooolLooooo`4000000Ooo
ool0000300000?oooooooooo0?oooooo7?ooool10000007ooooo00000`00003oooooooooo`3ooooo
oacooooo0@000001ooooo`0000<00000ooooooooool0oooooolLooooo`4000000Oooool000030000
0?oooooooooo0?oooooo7?ooool10000007ooooo00000`00003oooooooooo`3ooooooacooooo0@00
0001ooooo`0000<00000ooooooooool0oooooolLooooo`4000000Oooool0000300000?oooooooooo
0?oooooo7?ooool10000007ooooo00000`00003oooooooooo`3ooooooacooooo0@000001ooooo`00
00<00000ooooooooool0oooooolLooooo`4000000Oooool0000300000?oooooooooo0?oooooo7?oo
ool10000007ooooo00000`00003oooooooooo`3ooooooacooooo0@000001ooooo`0000<00000oooo
ooooool0oooooolLooooo`4000000Oooool0000300000?oooooooooo0?oooooo7?ooool10000007o
oooo00000`00003oooooooooo`3ooooooacooooo0@000001ooooo`0000<00000ooooooooool0oooo
oolLooooo`4000000Oooool0000300000?oooooooooo0?oooooo7?ooool10000007ooooo00000`00
003oooooooooo`3ooooooacooooo0@000001ooooo`0000<00000ooooooooool0oooooolLooooo`40
00000Oooool0000300000?oooooooooo0?oooooo7?ooool10000007ooooo00000`00003ooooooooo
o`3ooooooacooooo0@000001ooooo`0000<00000ooooooooool0oooooolLooooo`4000000Oooool0
000300000?oooooooooo0?oooooo7?ooool10000007ooooo00000`00003oooooooooo`3ooooooaco
oooo0@000001ooooo`0000<00000ooooooooool0oooooolLooooo`4000000Oooool0000300000?oo
oooooooo0?oooooo7?ooool10000007ooooo00000`00003oooooooooo`3ooooooacooooo0@000001
ooooo`0000<00000ooooooooool0oooooolLooooo`4000000Oooool0000300000?oooooooooo0?oo
oooo7?ooool10000007ooooo00000`00003oooooooooo`3ooooooacooooo0@000001ooooo`0000<0
0000ooooooooool0oooooolLooooo`4000000Oooool0000300000?oooooooooo0?oooooo7?ooool1
0000007ooooo00000`00003oooooooooo`3ooooooacooooo0@000001ooooo`0000<00000oooooooo
ool0oooooolLooooo`4000000Oooool0000300000?oooooooooo0?oooooo7?ooool10000007ooooo
00000`00003oooooooooo`2>ooooo`;oogl0Roooool10000007ooooo00000`00003oooooooooo`2=
ooooo`Coogl0R_ooool10000007ooooo00000`00003oooooooooo`2=ooooo`Coogl0R_ooool10000
007ooooo00000`00003oooooooooo`2>ooooo`;oogl0Roooool10000007ooooo00000`00003ooooo
ooooo`3ooooooacooooo0@000001ooooo`0000<00000ooooooooool0oooooolLooooo`4000000Ooo
ool0000300000?oooooooooo0?oooooo7?ooool10000007ooooo00000`00003oooooooooo`3ooooo
oacooooo0@000001ooooo`0000<00000ooooooooool0oooooolLooooo`4000000Oooool000030000
0?oooooooooo0?oooooo7?ooool10000007ooooo00000`00003oooooooooo`3ooooooacooooo0@00
0001ooooo`0000<00000ooooooooool0oooooolLooooo`4000000Oooool0000300000?oooooooooo
0?oooooo7?ooool10000007ooooo00000`00003oooooooooo`3ooooooacooooo0@000001ooooo`00
00<00000ooooooooool0oooooolLooooo`4000000Oooool0000300000?oooooooooo0?oooooo7?oo
ool10000007ooooo00000`00003oooooooooo`3ooooooacooooo0@000001ooooo`0000<00000oooo
ooooool0oooooolLooooo`4000000Oooool0000300000?oooooooooo0?oooooo7?ooool10000007o
oooo00000`00003oooooooooo`3ooooooacooooo0@000001ooooo`0000<00000ooooooooool0oooo
oolLooooo`4000000Oooool0000300000?oooooooooo0?oooooo7?ooool10000007ooooo00000`00
003oooooooooo`3ooooooacooooo0@000001ooooo`0000<00000ooooooooool0oooooolLooooo`40
00000Oooool0000300000?oooooooooo0?oooooo7?ooool10000007ooooo003o0000020000000Ooo
ool00001\
\>"],
  ImageRangeCache->{{{0, 287}, {287, 0}} -> {-1.01089, -1.01089, 0.00704453, \
0.00704453}}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  "Corresponding  ",
  Cell[BoxData[
      \(TraditionalForm\`E[y\_ij]\  = P(\[Omega]\_i | \[Theta], x\_j)\)]],
  " for sample point"
}], "Subsubsection"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(\(\ \)\(\(PlotExampleOne[#, initialModel, colors, gbase, 1, 
            yS] &\)\  /@ \ xd;\)\)\)], "Input"],

Cell[CellGroupData[{

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.49505 0.5 0.49505 [
[ 0 0 -0.125 0 ]
[ 0 0 -0.125 0 ]
[ 0 1 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
0 0 m
1 0 L
s
0 0 m
0 1 L
s
0 1 m
1 1 L
s
1 0 m
1 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
1 .5 0 r
.015 w
.03175 .1355 Mdot
.03435 .12523 Mdot
.11137 .12765 Mdot
.14107 .18841 Mdot
.16218 .24538 Mdot
.17294 .21053 Mdot
.18267 .18577 Mdot
.18434 .1304 Mdot
.18553 .30956 Mdot
.20401 .239 Mdot
.21247 .27571 Mdot
.21687 .20845 Mdot
.22376 .2799 Mdot
.22832 .27485 Mdot
.29063 .20974 Mdot
.29686 .25079 Mdot
.30487 .22936 Mdot
.30683 .34623 Mdot
.32055 .20902 Mdot
.32574 .21979 Mdot
.34472 .28521 Mdot
.35998 .36393 Mdot
.36335 .24976 Mdot
.3794 .36608 Mdot
.42386 .66992 Mdot
.44391 .74519 Mdot
.45059 .34198 Mdot
.47208 .67586 Mdot
.47436 .71381 Mdot
.49778 .59825 Mdot
.50874 .91643 Mdot
.51516 .76219 Mdot
.53655 .61374 Mdot
.56563 .75219 Mdot
.59189 .65665 Mdot
.59581 .61604 Mdot
.59923 .6556 Mdot
.60292 .68499 Mdot
.62656 .67779 Mdot
.63555 .72451 Mdot
.63919 .652 Mdot
.64169 .6004 Mdot
.64246 .58611 Mdot
.64496 .54267 Mdot
.64608 .77288 Mdot
.65077 .64308 Mdot
.66065 .57816 Mdot
.67474 .59169 Mdot
.69296 .563 Mdot
.72815 .65902 Mdot
.73169 .58879 Mdot
.74669 .61318 Mdot
.74821 .65474 Mdot
.75963 .63781 Mdot
.79673 .57809 Mdot
.80925 .55852 Mdot
.81525 .58444 Mdot
.83417 .62985 Mdot
.83598 .55526 Mdot
.91595 .49319 Mdot
1 0 0 r
.005 w
.00495 .28842 m
.00628 .29156 L
.01857 .31761 L
.03101 .33781 L
.03525 .34367 L
.05706 .36884 L
.05795 .36972 L
.08312 .39115 L
.08963 .39578 L
.10917 .40763 L
.13523 .41964 L
.14074 .42183 L
.16128 .42794 L
.18734 .43294 L
.21339 .43485 L
.23945 .43375 L
.2655 .42959 L
.29156 .42219 L
.29261 .42183 L
.31761 .41124 L
.34367 .39603 L
.34405 .39578 L
.36972 .37551 L
.37582 .36972 L
.39578 .34724 L
.39849 .34367 L
.41525 .31761 L
.42183 .30485 L
.4275 .29156 L
.436 .2655 L
.44117 .23945 L
.44325 .21339 L
.44232 .18734 L
.43834 .16128 L
.43114 .13523 L
.42183 .11212 L
.42037 .10917 L
.40546 .08312 L
.39578 .06961 L
.38528 .05706 L
.36972 .04137 L
.35758 .03101 L
.34367 .02092 L
.31761 .00569 L
.3162 .00495 L
s
.00495 .12854 m
.01344 .10917 L
.02832 .08312 L
.03101 .07912 L
.04848 .05706 L
.05706 .04802 L
.07619 .03101 L
.08312 .02579 L
.10917 .00934 L
.11742 .00495 L
s
0 0 1 r
.29156 .15739 m
.31761 .14824 L
.34367 .14249 L
.36972 .13986 L
.39578 .14025 L
.42183 .14366 L
.44789 .15025 L
.47394 .16034 L
.47599 .16128 L
.5 .17443 L
.51844 .18734 L
.52606 .19355 L
.54662 .21339 L
.55211 .21962 L
.56712 .23945 L
.57817 .25755 L
.58227 .2655 L
.59322 .29156 L
.60058 .31761 L
.60422 .3392 L
.60471 .34367 L
.6058 .36972 L
.60422 .39297 L
.60387 .39578 L
.59886 .42183 L
.59054 .44789 L
.57848 .47394 L
.57817 .47453 L
.562 .5 L
.55211 .51255 L
.53968 .52606 L
.52606 .53862 L
.50853 .55211 L
.5 .55773 L
.47394 .57183 L
.45901 .57817 L
.44789 .5819 L
.42183 .5885 L
.39578 .59192 L
.36972 .59231 L
.34367 .58968 L
.31761 .58392 L
.29972 .57817 L
.29156 .57477 L
.2655 .56178 L
.25025 .55211 L
.23945 .54409 L
.21914 .52606 L
.21339 .52008 L
.19681 .5 L
Mistroke
.18734 .48608 L
.18031 .47394 L
.16827 .44789 L
.16128 .42714 L
.15996 .42183 L
.15493 .39578 L
.153 .36972 L
.15409 .34367 L
.15823 .31761 L
.16128 .3045 L
.16559 .29156 L
.17653 .2655 L
.18734 .24609 L
.19169 .23945 L
.21221 .21339 L
.21339 .21211 L
.23945 .1881 L
.24041 .18734 L
.2655 .17038 L
.28271 .16128 L
.29156 .15739 L
Mfstroke
1 0 0 r
.03 w
.21687 .20845 Mdot
0 0 1 r
.3794 .36608 Mdot
1 0 0 r
.79703 .00495 m
.79703 .19993 L
.87129 .19993 L
.87129 .00495 L
F
0 0 1 r
.89604 .00495 m
.89604 .0575 L
.9703 .0575 L
.9703 .00495 L
F
1 0 1 r
.04 w
.03175 .1355 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P000182000`400?l00000o`00003ooooooolQ
ooooo`00o`00000P0000007ooooo00000`00003oooooooooo`0Mooooo`80o`00>?ooool2ool00003
0?l00?oooooooooo0;oooooo0@000001ooooo`0000<00000ooooooooool06oooool20?l003gooooo
00<0o`00ooooooooool0Q?oooolE0?l000Sooooo5@000?l8ooooo`4000000Oooool0000300000?oo
oooooooo01[ooooo00<0o`00ooooooooool0?_ooool20?l008Cooooo5@3o0008oooooaD0003o2?oo
ool10000007ooooo00000`00003oooooooooo`0Hooooo`80o`00@oooool00`3o003oooooooooo`21
oooooaD0o`002?oooolE0000o`Sooooo0@000001ooooo`0000<00000ooooooooool05_ooool20?l0
04Kooooo00<0o`00ooooooooool0P?oooolE0?l000Sooooo5@000?l8ooooo`4000000Oooool00003
00000?oooooooooo01Gooooo00<0o`00ooooooooool0Aoooool20?l0083ooooo5@3o0008oooooaD0
003o2?ooool10000007ooooo00000`00003oooooooooo`0Dooooo`030?l00?oooooooooo04[ooooo
00<0o`00ooooooooool0OOoooolE0?l000Sooooo5@000?l8ooooo`4000000Oooool0000300000?oo
oooooooo01?ooooo00<0o`00ooooooooool0C?ooool00`3o003oooooooooo`1loooooaD0o`002?oo
oolE0000o`Sooooo0@000001ooooo`0000<00000ooooooooool04Oooool20?l0053ooooo0P3o001l
oooooaD0o`002?oooolE0000o`Sooooo0@000001ooooo`0000<00000ooooooooool04?ooool00`3o
003oooooooooo`1Booooo`80o`00N_oooolE0?l000Sooooo5@000?l8ooooo`4000000Oooool00003
00000?oooooooooo00oooooo00<0o`00ooooooooool0EOooool00`3o003oooooooooo`1goooooaD0
o`002?oooolE0000o`Sooooo0@000001ooooo`0000<00000ooooooooool03_ooool00`3o003ooooo
ooooo`1Fooooo`030?l00?oooooooooo07Oooooo5@3o0008oooooaD0003o2?ooool10000007ooooo
00000`00003oooooooooo`0=ooooo`030?l00?oooooooooo05Sooooo00<0o`00ooooooooool0M_oo
oolE0?l000Sooooo5@000?l8ooooo`4000000Oooool0000300000?oooooooooo00gooooo00<0o`00
ooooooooool0FOooool00`3o003oooooooooo`1eoooooaD0o`002?oooolE0000o`Sooooo0@000001
ooooo`0000<00000ooooooooool03?ooool00`3o003oooooooooo`1Kooooo`030?l00?oooooooooo
07Cooooo5@3o0008oooooaD0003o2?ooool10000007ooooo00000`00003oooooooooo`0;ooooo`03
0?l00?oooooooooo05gooooo00<0o`00ooooooooool0LooooolE0?l000Sooooo5@000?l8ooooo`40
00000Oooool0000300000?oooooooooo00_ooooo00<0o`00ooooooooool0GOooool00`3o003ooooo
ooooo`1coooooaD0o`009Oooool10000007ooooo00000`00003oooooooooo`0:ooooo`030?l00?oo
oooooooo05oooooo00<0o`00ooooooooool0L_oooolE0?l002Gooooo0@000001ooooo`0000<00000
ooooooooool02Oooool00`3o003oooooooooo`1Qooooo`030?l00?oooooooooo077ooooo5@3o000U
ooooo`4000000Oooool0000300000?oooooooooo00Sooooo00<0o`00ooooooooool0Hoooool00`3o
003oooooooooo`1`oooooaD0o`009Oooool10000007ooooo00000`00003oooooooooo`07ooooo`03
0?l00?oooooooooo06Gooooo00<0o`00ooooooooool0KooooolE0?l002Gooooo0@000001ooooo`00
00<00000ooooooooool01_ooool00`3o003oooooooooo`1Wooooo`030?l00?oooooooooo06kooooo
5@3o000Uooooo`4000000Oooool0000300000?oooooooooo00Gooooo00?oo`00ooooooooool0JOoo
ool00`3o003oooooooooo`1]oooooaD0o`009Oooool10000007ooooo00000`00003oooooooooo`05
ooooo`030?l00?oooooooooo06Wooooo00<0o`00ooooooooool0KOoooolE0?l002Gooooo0@000001
ooooo`0000<00000ooooooooool01?ooool00`3o003oooooooooo`1[ooooo`030?l00?oooooooooo
06cooooo5@3o000Uooooo`4000000Oooool0000300000?oooooooooo00?ooooo00<0o`00oooooooo
ool0K?ooool00`3o003oooooooooo`1/oooooaD0o`009Oooool10000007ooooo00000`00003ooooo
ooooo`03ooooo`030?l00?oooooooooo06gooooo00<0o`00ooooooooool0JooooolE0?l002Gooooo
0@000001ooooo`0000<00000ooooooooool00_ooool00`3o003oooooooooo`1^ooooo`030?l00?oo
oooooooo06_ooooo5@3o000Uooooo`4000000Oooool0000300000?oooooooooo00;ooooo00<0o`00
ooooooooool0Koooool00`3o003oooooooooo`1ZoooooaD0o`009Oooool10000007ooooo00001@00
003oooooooooooooool0o`0007;ooooo00<0o`00ooooooooool0J_oooolE0?l002Gooooo0@000001
ooooo`0000@00000ooooooooool0o`00M?ooool00`3o003oooooooooo`1YoooooaD0o`009Oooool1
0000007ooooo00001000003oooooooooo`3o001eooooo`03ool00?oooooooooo06Sooooo5@3o000U
ooooo`4000000Oooool0000300000?ooool0o`0007Kooooo00<0o`00ooooooooool0J?oooolE0?l0
02Gooooo0@000001ooooo`0000<00000ooooo`3o00001?ooool5ool0ofkooooo00<0o`00oooooooo
ool0IooooolE0?l002Gooooo0@000001ooooo`0000<00000ooooo`3o00000oooool7ool0oa;ooooo
0_ooO`1Iooooo`030?l00?oooooooooo06Oooooo5@3o000Uooooo`4000000Oooool000030000003o
003ooooo00;ooooo2Ooo0?l@ooooo`Coogl04_ooool2oomo04Cooooo00<0o`00ooooooooool0Iooo
oolE0?l002Gooooo0@000001ooooo`0000@00000oooooooooooooooo2ooo0?l?ooooo`Coogl04Ooo
ool4oomo04Cooooo00<0o`00ooooooooool0I_oooolE0?l002Gooooo0@000001ooooo`0000@00000
oooooooooooooooo2ooo0?l@ooooo`;oogl04_ooool4oomo04Cooooo00<0o`00ooooooooool0I_oo
oolE0?l002Gooooo0@000001ooooo`0000@00000oooooooooooooooo2ooo0?lUooooo`;oogl0AOoo
ool00`3o003oooooooooo`1VoooooaD0o`009Oooool10000007ooooo00001000003ooooooooooooo
ool;ool0oe7ooooo5_l00?l5ooooo`030?l00?oooooooooo06Kooooo5@3o000Uooooo`4000000Ooo
ool0000400000?ooooooooooooooo`_oo`3oC_ooool3o`00oaKooooo1_l00?l00`3o003ooooooooo
o`1UoooooaD0o`009Oooool10000007ooooo00000`00003oooooooooo`02ooooo`Woo`3oC?ooool3
o`00oaoooooo0ol00?mUoooooaD0o`009Oooool10000007ooooo00000`00003oooooooooo`03oooo
o`Ooo`3oB_ooool3o`00ob;ooooo00<0o`00ooooooooool00ol00?mRoooooaD0o`009Oooool10000
007ooooo00000`00003oooooooooo`04ooooo`Goo`3oB?ooool3o`00obGooooo00<0o`00oooooooo
ool00oooool3o`00oeoooooo5@3o000Uooooo`4000000Oooool0000300000?oooooooooo04oooooo
0P000?lYooooo`030?l00?oooooooooo00Gooooo0ol00?mLoooooaD0o`009Oooool10000007ooooo
00000`00003oooooooooo`1=ooooo`80003o:oooool00`3o003oooooooooo`08ooooo`;o003oF_oo
oolE0?l002Gooooo0@000001ooooo`0000<00000ooooooooool0B_ooool30000obgooooo00<0o`00
ooooooooool02_ooool2o`00oeSooooo5@3o000Uooooo`4000000Oooool0000300000?oooooooooo
04Sooooo0P000?l`ooooo`030?l00?oooooooooo00cooooo00?o003oooooooooool0EOoooolE0?l0
02Gooooo0@000001ooooo`0000<00000ooooooooool0Aoooool00`000?ooooooooooo`0`ooooo`03
0?l00?oooooooooo00gooooo0_l00?mEoooooaD0o`009Oooool10000007ooooo00000`00003ooooo
ooooo`15ooooo`80003o=?ooool00`3o003oooooooooo`0>ooooo`;o003oDooooolE0?l002Gooooo
0@000001ooooo`0000<00000ooooooooool0A?ooool00`000?ooooooooooo`0dooooo`030?l00?oo
oooooooo013ooooo0_l00?mAoooooaD0o`009Oooool10000007ooooo00000`00003oooooooooo`0T
ooooo`;oogl02_ooool2oomo017ooooo00<0003oooooooooool0=Oooool00`3o003oooooooooo`0B
ooooo`03o`00oooooooooooo04kooooo5@3o000Uooooo`4000000Oooool0000300000?oooooooooo
02?ooooo1?ooO`08ooooo`Coogl03oooool00`000?ooooooooooo`0fooooo`030?l00?oooooooooo
01?ooooo00?o003oooooooooool0COoooolE0?l002Gooooo0@000001ooooo`0000<00000oooooooo
ool08oooool4oomo00Sooooo1?ooO`0=ooooo`030000ool00?oooooo03Sooooo00<0o`00oooooooo
ool05?ooool00ol00?ooooooooooo`1<oooooaD0o`009Oooool10000007ooooo00000`00003ooooo
ooooo`0Tooooo`;oogl02_ooool2oomo00gooooo00<0003oooooooooool0>Oooool00`3o003ooooo
ooooo`0Eooooo`03o`00oooooooooooo04_ooooo5@3o000Uooooo`4000000Oooool0000300000?oo
oooooooo03Wooooo1?oo00000oooool0003oooooo`0kooooo`030?l00?oooooooooo01Kooooo00?o
003oooooooooool0B_oooolE0?l002Gooooo0@000001ooooo`0000<00000ooooooooool0>?ooool6
ool003gooooo00<0o`00ooooooooool05oooool00ol00?ooooooooooo`19oooooaD0o`009Oooool1
0000007ooooo00000`00003oooooooooo`0gooooo`Soo`004?ooool2oomo00Oooooo0_ooO`0Roooo
o`030?l00?oooooooooo01Oooooo00?o003oooooooooool0P_ooool10000007ooooo00000`00003o
ooooooooo`0^ooooo`;oogl01oooool8ool000oooooo1?ooO`05ooooo`Coogl08Oooool00`3o003o
ooooooooo`0Hooooo`03o`00oooooooooooo087ooooo0@000001ooooo`0000<00000ooooooooool0
;Oooool4oomo00Kooooo2?oo000?ooooo`Coogl01Oooool4oomo027ooooo00<0o`00ooooooooool0
6Oooool00ol00?ooooooooooo`20ooooo`4000000Oooool0000300000?oooooooooo02gooooo1?oo
O`06ooooo`Soo`004?ooool2oomo00Oooooo0oooO`0Qooooo`030?l00?oooooooooo01[ooooo00?o
003oooooooooool0Ooooool10000007ooooo00000`00003oooooooooo`0^ooooo`;oogl02?ooool6
ool001[ooooo1?ooO`0Pooooo`030?l00?oooooooooo01_ooooo00?o003oooooooooool0O_ooool1
0000007ooooo00000`00003oooooooooo`0hooooo`030000oooo003oo`0000;oo`006oooool4oomo
023ooooo00<0o`00ooooooooool07?ooool00ol00?ooooooooooo`1mooooo`4000000Oooool00003
00000?oooooooooo03Oooooo00<0003oooooooooool06Oooool2oomo00Cooooo0_ooO`0Qooooo`03
0?l00?oooooooooo01cooooo00?o003oooooooooool0OOooool10000007ooooo00000`00003ooooo
ooooo`0fooooo`030000oooooooooooo01Wooooo1?ooO`0Uooooo`030?l00?oooooooooo01kooooo
00?o003oooooooooool0O?ooool10000007ooooo00000`00003oooooooooo`0fooooo`030000oooo
oooooooo01Wooooo1?ooO`0Uooooo`030?l00?oooooooooo01oooooo00?o003oooooooooool0Nooo
ool10000007ooooo00000`00003oooooooooo`0eooooo`040000ooooooooogl0oomo01[ooooo0_oo
O`0Vooooo`030?l00?oooooooooo023ooooo00?o003oooooooooool0N_ooool10000007ooooo0000
0`00003oooooooooo`0dooooo`030000ooooooooogl000?oogl0@Oooool00`3o003oooooooooo`0Q
ooooo`03o`00oooooooooooo07Wooooo0@000001ooooo`0000<00000ooooooooool0:oooool2oomo
00Kooooo00<0003oooooooooool01?ooO`11ooooo`030?l00?oooooooooo027ooooo00?o003ooooo
ooooool0NOooool10000007ooooo00000`00003oooooooooo`0Zooooo`Coogl01?ooool00`000?oo
ooooooooo`02ooooo`;oogl06?ooool2oomo017ooooo0_ooO`0Eooooo`030?l00?oooooooooo02;o
oooo00?o003oooooooooool0N?ooool10000007ooooo00000`00003oooooooooo`0Zooooo`Coogl0
1?ooool00`000?ooooooooooo`0Kooooo`Coogl03oooool4oomo01Cooooo00<0o`00ooooooooool0
8oooool00ol00?ooooooooooo`1gooooo`4000000Oooool0000300000?oooooooooo02_ooooo0_oo
O`04ooooo`030000oooooooooooo01cooooo1?ooO`0?ooooo`Coogl05?ooool00`3o003ooooooooo
o`0Sooooo`03o`00oooooooooooo07Oooooo0@000001ooooo`0000<00000ooooooooool0<Oooool0
0`000?ooooooooooo`0Mooooo`;oogl04Oooool2oomo01Cooooo00<0o`00ooooooooool09Oooool0
0ol00?ooooooooooo`1fooooo`4000000Oooool0000300000?oooooooooo033ooooo00<0003ooooo
ooooool0Aoooool00`3o003oooooooooo`0Uooooo`03o`00oooooooooooo07Kooooo0@000001oooo
o`0000<00000ooooooooool0<?ooool00`000?ooooooooooo`17ooooo`030?l00?oooooooooo02Ko
oooo00?o003oooooooooool0MOooool10000007ooooo00000`00003oooooooooo`0_ooooo`030000
oooooooooooo04Sooooo00<0o`00ooooooooool09oooool00ol00?ooooooooooo`1dooooo`400000
0Oooool0000300000?oooooooooo02oooooo00<0003oooooooooool01oooool2oomo00;ooooo0_oo
O`0kooooo`030?l00?oooooooooo02Oooooo00?o003oooooooooool0M?ooool10000007ooooo0000
0`00003oooooooooo`0^ooooo`030000oooooooooooo00Oooooo2?ooO`0iooooo`030?l00?oooooo
oooo02Wooooo00?o003oooooooooool0Loooool10000007ooooo00000`00003oooooooooo`0^oooo
o`030000oooooooooooo00Oooooo2?ooO`0iooooo`030?l00?oooooooooo02Wooooo00?o003ooooo
ooooool0Loooool10000007ooooo00000`00003oooooooooo`0]ooooo`030000oooooooooooo00Wo
oooo1_ooO`0Pooooo`;oogl05oooool00`3o003oooooooooo`0[ooooo`03o`00oooooooooooo07;o
oooo0@000001ooooo`0000<00000ooooooooool0;Oooool00`000?ooooooooooo`0;ooooo`Coogl0
7oooool4oomo01Kooooo00<0o`00ooooooooool0:oooool00ol00?ooooooooooo`1booooo`400000
0Oooool0000300000?oo003ooooo02gooooo00<0003oooooooooool03?ooool2oomo023ooooo1?oo
O`0Fooooo`030?l00?oooooooooo02_ooooo00?o003oooooooooool0L_ooool10000007ooooo0000
0`000000o`00ooooo`0/ooooo`030000oooooooooooo033ooooo0_ooO`0Fooooo`030?l00?oooooo
oooo02gooooo00?o003oooooooooool0LOooool10000007ooooo00000`000000o`00ooooo`0/oooo
o`030000oooooooooooo04Sooooo00<0o`00ooooooooool0;Oooool00ol00?ooooooooooo`1aoooo
o`4000000Oooool0000300000?ooool0o`0002cooooo00<0003oooooooooool0B?ooool00`3o003o
ooooooooo`0]ooooo`03o`00oooooooooooo077ooooo0@000001ooooo`0000<00000ooooo`3o0000
:oooool00`000?ooooooooooo`18ooooo`030?l00?oooooooooo02oooooo00?o003oooooooooool0
L?ooool10000007ooooo00001000003oooooooooo`3o000Zooooo`030000oooooooooooo00?ooooo
0_ooO`13ooooo`030?l00?oooooooooo02oooooo00?o003oooooooooool0L?ooool10000007ooooo
00001000003oooooooooo`3o000Zooooo`030000oooooooooooo00;ooooo1?ooO`12ooooo`030?l0
0?oooooooooo02oooooo00?o003oooooooooool0L?ooool10000007ooooo00001@00003ooooooooo
ooooool0o`0002Wooooo00<0003oooooooooool00_ooool4oomo047ooooo00<0o`00ooooooooool0
<?ooool00ol00?ooooooooooo`1`ooooo`4000000Oooool0000500000?ooooooooooooooo`3o0000
:?ooool00`000?ooooooooooo`04ooooo`;oogl0@_ooool00`3o003oooooooooo`0aooooo`03o`00
oooooooooooo06oooooo0@000001ooooo`0000<00000ooooooooool00_ooool00`3o003ooooooooo
o`0Uooooo`030000oooooooooooo04Oooooo00<0o`00ooooooooool0<_ooool00ol00?oooooooooo
o`1_ooooo`4000000Oooool0000300000?oooooooooo00;ooooo00<0o`00ooooooooool09Oooool0
0`000?ooooooooooo`17ooooo`030?l00?oooooooooo03;ooooo00?o003oooooooooool0Koooool1
0000007ooooo00000`00003oooooooooo`03ooooo`030?l00?oooooooooo02Cooooo00<0003ooooo
ooooool0A_ooool00`3o003oooooooooo`0cooooo`03o`00oooooooooooo06oooooo0@000001oooo
o`0000<00000ooooooooool01?ooool00`3o003oooooooooo`0Sooooo`030000oooooooooooo04Go
oooo00<0o`00ooooooooool0=?ooool00ol00?ooooooooooo`1_ooooo`4000000Oooool000030000
0?oooooooooo00Gooooo00<0o`00ooooooooool08Oooool00`000?ooooooooooo`15ooooo`030?l0
0?oooooooooo03Kooooo00?o003oooooooooool0K_ooool10000007ooooo00000`00003ooooooooo
o`06ooooo`030?l00?oooooooooo023ooooo00<0003oooooooooool0AOooool00`3o003ooooooooo
o`09ooooo`;oogl0:oooool00ol00?ooooooooooo`1^ooooo`4000000Oooool0000300000?oooooo
oooo00Kooooo00<0o`00ooooooooool08?ooool00`000?ooooooooooo`14ooooo`030?l00?oooooo
oooo00Wooooo1?ooO`0Zooooo`03o`00oooooooooooo06kooooo0@000001ooooo`0000<00000oooo
ooooool01oooool00`3o003oooooooooo`0Oooooo`030000oooooooooooo02Sooooo0_ooO`0Ioooo
o`030?l00?oooooooooo00[ooooo1?ooO`0Zooooo`03o`00oooooooooooo06kooooo0@000001oooo
o`0000<00000ooooooooool01oooool00`3o003oooooooooo`0Oooooo`030000oooooooooooo02Oo
oooo1?ooO`0Gooooo`03ool00?oooooooooo00cooooo0_ooO`0[ooooo`03o`00oooooooooooo06ko
oooo0@000001ooooo`0000<00000ooooooooool02?ooool00`3o003oooooooooo`0Nooooo`030000
oooooooooooo02Oooooo1?ooO`0Gooooo`030?l00?oooooooooo03Wooooo00?o003oooooooooool0
K_ooool10000007ooooo00000`00003oooooooooo`09ooooo`030?l00?oooooooooo01gooooo00<0
003oooooooooool0:?ooool2oomo01;ooooo1?l00?l00oooool0o`00ooooo`0kooooo`03o`00oooo
oooooooo06kooooo0@000001ooooo`0000<00000ooooooooool02_ooool00`3o003oooooooooo`0L
ooooo`030000oooooooooooo03_ooooo1_l00?lmooooo`03o`00oooooooooooo06kooooo0@000001
ooooo`0000<00000ooooooooool02oooool00`3o003oooooooooo`0Kooooo`030000oooooooooooo
03Oooooo0_ooO`000ooooooo003oo`00o`06o`00occooooo00?o003oooooooooool0K_ooool10000
007ooooo00000`00003oooooooooo`0<ooooo`030?l00?oooooooooo01[ooooo00<0003ooooooooo
ool0=_ooool4oomo00So003o??ooool00ol00?ooooooooooo`1^ooooo`4000000Oooool000030000
0?oooooooooo00gooooo00?oo`00ooooooooool06Oooool00`000?ooooooooooo`0fooooo`Coogl0
2?l00?llooooo`03o`00oooooooooooo06kooooo0@000001ooooo`0000<00000ooooooooool03Ooo
ool20?l001[ooooo00<0003oooooooooool0=oooool2oomo0003ooooool00?oo003o00Ko003o??oo
ool00ol00?ooooooooooo`1^ooooo`4000000Oooool0000300000?oooooooooo00oooooo00<0o`00
ooooooooool05oooool00`000?ooooooooooo`0jooooo`030?l00?l00?oo003o00Co003o?Oooool0
0ol00?ooooooooooo`1^ooooo`4000000Oooool0000300000?oooooooooo013ooooo00<0o`00oooo
ooooool05_ooool00`000?ooooooooooo`0iooooo`030?l00?oooooooooo00Co003o?_ooool00ol0
0?ooooooooooo`1^ooooo`4000000Oooool0000300000?oooooooooo017ooooo00<0o`00oooooooo
ool05Oooool00`000?ooooooooooo`0hooooo`030?l00?oooooooooo04?ooooo00?o003ooooooooo
ool0K_ooool10000007ooooo00000`00003oooooooooo`0Booooo`030?l00?oooooooooo01Cooooo
00<0003oooooooooool0=_ooool20?l004Kooooo00?o003oooooooooool0K_ooool10000007ooooo
00000`00003oooooooooo`0Cooooo`030?l00?oooooooooo01?ooooo00<0003oooooooooool0=Ooo
ool00`3o003oooooooooo`16ooooo`03o`00oooooooooooo06kooooo0@000001ooooo`0000<00000
ooooooooool05?ooool20?l001?ooooo00<0003oooooooooool0=?ooool00`3o003oooooooooo`17
ooooo`03o`00oooooooooooo06kooooo0@000001ooooo`0000<00000ooooooooool05_ooool20?l0
017ooooo00<0003oooooooooool0<_ooool20?l004[ooooo00?o003oooooooooool0K_ooool10000
007ooooo00000`00003oooooooooo`0Hooooo`030?l00?oooooooooo00kooooo00<0003ooooooooo
ool0<Oooool00`3o003oooooooooo`1:ooooo`03o`00oooooooooooo06kooooo0@000001ooooo`00
00<00000ooooooooool06Oooool20?l000kooooo00<0003oooooooooool0;oooool20?l004gooooo
00?o003oooooooooool0K_ooool10000007ooooo00000`00003oooooooooo`0Kooooo`030?l00?oo
oooooooo00_ooooo00<0003oooooooooool0;_ooool00`3o003oooooooooo`1<ooooo`03o`00oooo
oooooooo06oooooo0@000001ooooo`0000<00000ooooooooool07?ooool20?l000_ooooo00<0003o
ooooooooool0;Oooool00`3o003oooooooooo`1=ooooo`03o`00oooooooooooo06oooooo0@000001
ooooo`0000<00000ooooooooool07_ooool30?l000Wooooo00<0003oooooooooool0:_ooool20?l0
053ooooo00?o003oooooooooool0Koooool10000007ooooo00000`00003oooooooooo`0Qooooo`80
o`001oooool00`000?ooooooooooo`0Wooooo`<0o`00D_ooool00ol00?ooooooooooo`1_ooooo`40
00000Oooool0000300000?oooooooooo02?ooooo0P3o0005ooooo`030000oooooooooooo02Gooooo
0P3o001Dooooo`03o`00oooooooooooo073ooooo0@000001ooooo`0000<00000ooooooooool09Ooo
ool40?l00003ooooo`000?oooooo02;ooooo0P3o00000ooo0000o`00ooooo`1Eooooo`03o`00oooo
oooooooo073ooooo0@000001ooooo`0000<00000ooooooooool0:Oooool20?l00003o`00o`3o0000
o`0001gooooo0`3o001Jooooo`03o`00oooooooooooo073ooooo0@000001ooooo`0000<00000oooo
ooooool0:oooool00`000?ooooooooooo`030?l001Cooooo1P3o001Mooooo`03o`00oooooooooooo
073ooooo0@000001ooooo`0000<00000ooooooooool0;?ooool00`000?ooooooooooo`02oooooa@0
o`00H_ooool00ol00?ooooooooooo`1aooooo`4000000Oooool0000300000?oooooooooo02cooooo
00<0003oooooooooool0N?ooool00ol00?ooooooooooo`1aooooo`4000000Oooool0000300000?oo
oooooooo02cooooo00<0003oooooooooool0N?ooool00ol00?ooooooooooo`1aooooo`4000000Ooo
ool0000300000?oooooooooo02gooooo00<0003oooooooooool0M_ooool00ol00?ooooooooooo`1b
ooooo`4000000Oooool0000300000?oooooooooo02gooooo00<0003oooooooooool0M_ooool00ol0
0?ooooooooooo`1booooo`4000000Oooool0000300000?oooooooooo02gooooo00<0003ooooooooo
ool0M_ooool00ol00?ooooooooooo`1booooo`4000000Oooool0000300000?oooooooooo02kooooo
00<0003oooooooooool0M?ooool00ol00?ooooooooooo`1cooooo`4000000Oooool0000300000?oo
oooooooo02kooooo00<0003oooooooooool0M?ooool00ol00?ooooooooooo`1cooooo`4000000Ooo
ool0000300000?oooooooooo02kooooo00<0003oooooooooool0M?ooool00ol00?ooooooooooo`1c
ooooo`4000000Oooool0000300000?oooooooooo02oooooo00<0003oooooooooool0L_ooool00ol0
0?ooooooooooo`1dooooo`4000000Oooool0000300000?oooooooooo02oooooo00<0003ooooooooo
ool0L_ooool00ol00?ooooooooooo`1dooooo`4000000Oooool0000300000?oooooooooo02oooooo
00<0003oooooooooool0L_ooool00ol00?ooooooooooo`1dooooo`4000000Oooool0000300000?oo
oooooooo033ooooo00<0003oooooooooool0Koooool2o`00ogOooooo0@000001ooooo`0000<00000
ooooooooool0<?ooool00`000?ooooooooooo`1_ooooo`03o`00oooooooooooo07Kooooo0@000001
ooooo`0000<00000ooooooooool0<Oooool00`000?ooooooooooo`1]ooooo`03o`00oooooooooooo
07Oooooo0@000001ooooo`0000<00000ooooooooool0<_ooool00`000?ooooooooooo`1/ooooo`03
o`00oooooooooooo07Oooooo0@000001ooooo`0000<00000ooooooooool0<_ooool00`000?oooooo
ooooo`1[ooooo`03o`00oooooooooooo063ooooo0_ooO`0Fooooo`4000000Oooool0000300000?oo
oooooooo03?ooooo00<0003oooooooooool0JOooool00ol00?ooooooooooo`1Pooooo`Coogl05Ooo
ool10000007ooooo00000`00003oooooooooo`0dooooo`030000oooooooooooo06Sooooo00?o003o
ooooooooool0H?ooool4oomo01Gooooo0@000001ooooo`0000<00000ooooooooool0=Oooool00`00
0?ooooooooooo`1Vooooo`03o`00oooooooooooo06;ooooo0_ooO`0Fooooo`4000000Oooool00003
00000?oooooooooo03Gooooo00?o003oooooooooool0I_ooool00ol00?ooooooooooo`1jooooo`40
00000Oooool0000300000?oooooooooo03Kooooo00?o003oooooooooool0I?ooool00ol00?oooooo
ooooo`1kooooo`4000000Oooool0000300000?oooooooooo03Oooooo00?o003oooooooooool0H_oo
ool00ol00?ooooooooooo`1looooo`4000000Oooool0000300000?oooooooooo03Sooooo00?o003o
ooooooooool0Goooool2o`00ogoooooo0@000001ooooo`0000<00000ooooooooool0>Oooool00ol0
0?ooooooooooo`1Mooooo`03o`00oooooooooooo07oooooo0@000001ooooo`0000<00000oooooooo
ool0>_ooool00ol00?ooooooooooo`1Kooooo`03o`00oooooooooooo083ooooo0@000001ooooo`00
00<00000ooooooooool0>oooool00ol00?ooooooooooo`1Iooooo`03o`00oooooooooooo087ooooo
0@000001ooooo`0000<00000ooooooooool0??ooool00ol00?ooooooooooo`1Gooooo`03o`00oooo
oooooooo08;ooooo0@000001ooooo`0000<00000ooooooooool0?Oooool00ol00?ooooooooooo`1E
ooooo`03o`00oooooooooooo08?ooooo0@000001ooooo`0000<00000ooooooooool0?_ooool00ol0
0?ooooooooooo`1Cooooo`03o`00oooooooooooo08Cooooo0@000001ooooo`0000<00000oooooooo
ool0?oooool00ol00?ooooooooooo`1@ooooo`;o003o8Oooool2oomo06Cooooo0@000001ooooo`00
00<00000ooooooooool0@?ooool00ol00?ooooooooooo`1>ooooo`03o`00oooooooooooo023ooooo
1?ooO`1Sooooo`4000000Oooool0000300000?oooooooooo047ooooo0_l00?m=ooooo`03o`00oooo
oooooooo027ooooo1?ooO`1Sooooo`4000000Oooool0000300000?oooooooooo04?ooooo00?o003o
ooooooooool0BOooool00ol00?ooooooooooo`0Sooooo`;oogl0=Oooool2oomo02gooooo0@000001
ooooo`0000<00000ooooooooool0A?ooool2o`00odSooooo00?o003oooooooooool0Doooool2oomo
00Gooooo1?ooO`0/ooooo`4000000Oooool0000300000?oooooooooo04Kooooo0_l00?m5ooooo`03
o`00oooooooooooo05?ooooo1?ooO`04ooooo`Coogl0;?ooool10000007ooooo00000`00003ooooo
ooooo`18ooooo`03o`00oooooooooooo043ooooo0_l00?lfooooo`;oogl07_ooool4oomo00Gooooo
0_ooO`0]ooooo`4000000Oooool0000300000?oooooooooo04Wooooo0_l00?lnooooo`;o003o=ooo
ool4oomo01kooooo0_ooO`0eooooo`4000000Oooool0000300000?oooooooooo04_ooooo0ol00?lj
ooooo`03o`00oooooooooooo03Oooooo1?ooO`1Eooooo`4000000Oooool0000300000?oooooooooo
04kooooo0_l00?lfooooo`;o003o>oooool2oomo05Kooooo0@000001ooooo`0000<00000oooooooo
ool0D?ooool3o`00oc3ooooo0ol00?lcooooo`;oogl09Oooool2oomo03Wooooo0@000001ooooo`00
00<00000ooooooooool0Doooool2o`00ob[ooooo1?l00?leooooo`Coogl08oooool4oomo03Sooooo
0@000001ooooo`0000<00000ooooooooool0EOooool3o`00ob?ooooo1?l00?leooooo`;oogl00_oo
ool4oomo02?ooooo1?ooO`03ooooo`;oogl0<oooool10000007ooooo00000`00003oooooooooo`1H
ooooo`?o003o7Oooool3o`00ocSooooo1?ooO`02ooooo`;oogl04oooool2oomo013ooooo0_ooO`03
ooooo`Coogl0<_ooool10000007ooooo00000`00003oooooooooo`1Kooooo`?o003o5?ooool6o`00
oc_ooooo1?ooO`06ooooo`;oogl03_ooool4oomo01Cooooo1?ooO`0booooo`4000000Oooool00003
00000?oooooooooo05kooooo5?l00?m2ooooo`;oogl01_ooool4oomo00gooooo1?ooO`0Eooooo`;o
ogl0<oooool10000007ooooo00000`00003oooooooooo`2;ooooo`;oogl09oooool2oomo00Kooooo
1?ooO`0>ooooo`;oogl0Boooool10000007ooooo00000`00003oooooooooo`2:ooooo`Coogl09Ooo
ool4oomo00Kooooo0_ooO`1Looooo`4000000Oooool0000300000?oooooooooo08[ooooo1?ooO`0U
ooooo`Coogl0I?ooool10000007ooooo00000`00003oooooooooo`2;ooooo`;oogl09oooool2oomo
06Gooooo0@000001ooooo`0000<00000ooooooooool0U_ooool2oomo03[ooooo0_ooO`17ooooo`40
00000Oooool0000300000?oooooooooo09Gooooo1?ooO`0>ooooo`;oogl0:?ooool4oomo04Kooooo
0@000001ooooo`0000<00000ooooooooool0UOooool4oomo00gooooo1?ooO`0Wooooo`Coogl0A_oo
ool10000007ooooo00000`00003oooooooooo`2Fooooo`;oogl03_ooool4oomo02Sooooo0_ooO`17
ooooo`4000000Oooool0000300000?oooooooooo0:Oooooo0_ooO`1booooo`4000000Oooool00003
00000?oooooooooo0>_ooooo0_ooO`0^ooooo`4000000Oooool0000300000?oooooooooo0>[ooooo
1?ooO`0]ooooo`4000000Oooool0000300000?oooooooooo0=Kooooo0_ooO`0Booooo`Coogl0;Ooo
ool10000007ooooo00000`00003oooooooooo`3Eooooo`Coogl04_ooool2oomo02kooooo0@000001
ooooo`0000<00000ooooooooool0]oooool2oomo01cooooo1?ooO`12ooooo`4000000Oooool00003
00000?oooooooooo0;Kooooo1?ooO`0Looooo`;oogl0@oooool10000007ooooo00000`00003ooooo
ooooo`2cooooo`;oogl000?ooooooomo0?ooO`000_ooO`1Qooooo`4000000Oooool0000300000?oo
oooooooo0:Sooooo0_ooO`08ooooo`Coogl000?ooooooomo0?ooO`006_ooool2oomo04Kooooo0@00
0001ooooo`0000<00000ooooooooool0Y_ooool5oomo00Oooooo1?ooO`0Gooooo`;oogl00oooool4
oomo04Gooooo0@000001ooooo`0000<00000ooooooooool0YOooool6oomo00Sooooo0_ooO`0Goooo
o`Coogl00_ooool4oomo04Gooooo0@000001ooooo`0000<00000ooooooooool0YOooool5oomo02;o
oooo1?ooO`03ooooo`;oogl0A_ooool10000007ooooo00000`00003oooooooooo`1fooooo`;oogl0
;_ooool2oomo02Gooooo0_ooO`1<ooooo`4000000Oooool0000300000?oooooooooo07Gooooo1?oo
O`2Rooooo`4000000Oooool0000300000?oooooooooo07Gooooo1?ooO`0:ooooo`;oogl0U_ooool1
0000007ooooo00000`00003oooooooooo`1fooooo`;oogl02_ooool4oomo02[ooooo0_ooO`1Yoooo
o`4000000Oooool0000300000?oooooooooo08;ooooo1?ooO`0Yooooo`Coogl0J?ooool10000007o
oooo00000`00003oooooooooo`23ooooo`;oogl09?ooool2oomo00Cooooo1?ooO`1Xooooo`400000
0Oooool0000300000?oooooooooo0:Sooooo1?ooO`04ooooo`;oogl0JOooool10000007ooooo0000
0`00003oooooooooo`2Xooooo`Coogl0Koooool10000007ooooo00000`00003oooooooooo`2Yoooo
o`;oogl0L?ooool10000007ooooo00000`00003oooooooooo`3ooooooacooooo0@000001ooooo`00
00<00000ooooooooool0oooooolLooooo`4000000Oooool0000300000?oooooooooo0?oooooo7?oo
ool10000007ooooo00000`00003oooooooooo`3ooooooacooooo0@000001ooooo`0000<00000oooo
ooooool0Q?ooool2oomo09Gooooo0@000001ooooo`0000<00000ooooooooool0Poooool4oomo09Co
oooo0@000001ooooo`0000<00000ooooooooool0Poooool4oomo09Cooooo0@000001ooooo`0000<0
0000ooooooooool0Q?ooool2oomo02cooooo0_ooO`1Wooooo`4000000Oooool0000300000?oooooo
oooo0;7ooooo1?ooO`1Vooooo`4000000Oooool0000300000?oooooooooo0;7ooooo1?ooO`1Voooo
o`4000000Oooool0000300000?oooooooooo0;;ooooo0_ooO`1Wooooo`4000000Oooool000030000
0?oooooooooo0?oooooo7?ooool10000007ooooo00000`00003oooooooooo`3ooooooacooooo0@00
0001ooooo`0000<00000ooooooooool0Noooool2oomo09kooooo0@000001ooooo`0000<00000oooo
ooooool0N_ooool4oomo09gooooo0@000001ooooo`0000<00000ooooooooool0N_ooool4oomo023o
oooo0_ooO`1kooooo`4000000Oooool0000300000?oooooooooo07_ooooo0_ooO`0Pooooo`Coogl0
N_ooool10000007ooooo00000`00003oooooooooo`2Mooooo`Coogl0N_ooool10000007ooooo0000
0`00003oooooooooo`2@ooooo`;oogl03?ooool2oomo07_ooooo0@000001ooooo`0000<00000oooo
ooooool0Soooool4oomo08Sooooo0@000001ooooo`0000<00000ooooooooool0Soooool4oomo08So
oooo0@000001ooooo`0000<00000ooooooooool0T?ooool2oomo02?ooooo0_ooO`1Tooooo`400000
0Oooool0000300000?oooooooooo0;Cooooo1?ooO`1Sooooo`4000000Oooool0000300000?oooooo
oooo0;Cooooo1?ooO`1Sooooo`4000000Oooool0000300000?oooooooooo0;Gooooo0_ooO`1Toooo
o`4000000Oooool0000300000?oooooooooo0?oooooo7?ooool10000007ooooo00000`00003ooooo
ooooo`3ooooooacooooo0@000001ooooo`0000<00000ooooooooool0oooooolLooooo`4000000Ooo
ool0000300000?oooooooooo0?oooooo7?ooool10000007ooooo00000`00003oooooooooo`3ooooo
oacooooo0@000001ooooo`0000<00000ooooooooool0oooooolLooooo`4000000Oooool000030000
0?oooooooooo0?oooooo7?ooool10000007ooooo00000`00003oooooooooo`3ooooooacooooo0@00
0001ooooo`0000<00000ooooooooool0oooooolLooooo`4000000Oooool0000300000?oooooooooo
0?oooooo7?ooool10000007ooooo00000`00003oooooooooo`3ooooooacooooo0@000001ooooo`00
00<00000ooooooooool0oooooolLooooo`4000000Oooool0000300000?oooooooooo0?oooooo7?oo
ool10000007ooooo00000`00003oooooooooo`3ooooooacooooo0@000001ooooo`0000<00000oooo
ooooool0oooooolLooooo`4000000Oooool0000300000?oooooooooo0?oooooo7?ooool10000007o
oooo00000`00003oooooooooo`3ooooooacooooo0@000001ooooo`0000<00000ooooooooool0oooo
oolLooooo`4000000Oooool0000300000?oooooooooo0?oooooo7?ooool10000007ooooo00000`00
003oooooooooo`3ooooooacooooo0@000001ooooo`0000<00000ooooooooool0oooooolLooooo`40
00000Oooool0000300000?oooooooooo0?oooooo7?ooool10000007ooooo00000`00003ooooooooo
o`3ooooooacooooo0@000001ooooo`0000<00000ooooooooool0oooooolLooooo`4000000Oooool0
000300000?oooooooooo0?oooooo7?ooool10000007ooooo00000`00003oooooooooo`3ooooooaco
oooo0@000001ooooo`0000<00000ooooooooool0oooooolLooooo`4000000Oooool0000300000?oo
oooooooo0?oooooo7?ooool10000007ooooo00000`00003oooooooooo`3ooooooacooooo0@000001
ooooo`0000<00000ooooooooool0oooooolLooooo`4000000Oooool0000300000?oooooooooo0?oo
oooo7?ooool10000007ooooo00000`00003oooooooooo`3ooooooacooooo0@000001ooooo`0000<0
0000ooooooooool0oooooolLooooo`4000000Oooool0000300000?oooooooooo0?oooooo7?ooool1
0000007ooooo00000`00003oooooooooo`3ooooooacooooo0@000001ooooo`0000<00000oooooooo
ool0oooooolLooooo`4000000Oooool0000300000?oooooooooo0?oooooo7?ooool10000007ooooo
00000`00003oooooooooo`2>ooooo`;oogl0Roooool10000007ooooo00000`00003oooooooooo`2=
ooooo`Coogl0R_ooool10000007ooooo00000`00003oooooooooo`2=ooooo`Coogl0R_ooool10000
007ooooo00000`00003oooooooooo`2>ooooo`;oogl0Roooool10000007ooooo00000`00003ooooo
ooooo`3ooooooacooooo0@000001ooooo`0000<00000ooooooooool0oooooolLooooo`4000000Ooo
ool0000300000?oooooooooo0?oooooo7?ooool10000007ooooo00000`00003oooooooooo`3ooooo
oacooooo0@000001ooooo`0000<00000ooooooooool0oooooolLooooo`4000000Oooool000030000
0?oooooooooo0?oooooo7?ooool10000007ooooo00000`00003oooooooooo`3ooooooacooooo0@00
0001ooooo`0000<00000ooooooooool0oooooolLooooo`4000000Oooool0000300000?oooooooooo
0?oooooo7?ooool10000007ooooo00000`00003oooooooooo`3ooooooacooooo0@000001ooooo`00
00<00000ooooooooool0oooooolLooooo`4000000Oooool0000300000?oooooooooo0?oooooo7?oo
ool10000007ooooo00000`00003oooooooooo`3ooooooacooooo0@000001ooooo`0000<00000oooo
ooooool0oooooolLooooo`4000000Oooool0000300000?oooooooooo0?oooooo7?ooool10000007o
oooo00000`00003oooooooooo`3ooooooacooooo0@000001ooooo`0000<00000ooooooooool0oooo
oolLooooo`4000000Oooool0000300000?oooooooooo0?oooooo7?ooool10000007ooooo00000`00
003oooooooooo`3ooooooacooooo0@000001ooooo`0000<00000ooooooooool0oooooolLooooo`40
00000Oooool0000300000?oooooooooo0?oooooo7?ooool10000007ooooo003o0000020000000Ooo
ool00001\
\>"],
  ImageRangeCache->{{{0, 287}, {287, 0}} -> {-1.01089, -1.01089, 0.00704453, \
0.00704453}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.49505 0.5 0.49505 [
[ 0 0 -0.125 0 ]
[ 0 0 -0.125 0 ]
[ 0 1 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
0 0 m
1 0 L
s
0 0 m
0 1 L
s
0 1 m
1 1 L
s
1 0 m
1 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
1 .5 0 r
.015 w
.03175 .1355 Mdot
.03435 .12523 Mdot
.11137 .12765 Mdot
.14107 .18841 Mdot
.16218 .24538 Mdot
.17294 .21053 Mdot
.18267 .18577 Mdot
.18434 .1304 Mdot
.18553 .30956 Mdot
.20401 .239 Mdot
.21247 .27571 Mdot
.21687 .20845 Mdot
.22376 .2799 Mdot
.22832 .27485 Mdot
.29063 .20974 Mdot
.29686 .25079 Mdot
.30487 .22936 Mdot
.30683 .34623 Mdot
.32055 .20902 Mdot
.32574 .21979 Mdot
.34472 .28521 Mdot
.35998 .36393 Mdot
.36335 .24976 Mdot
.3794 .36608 Mdot
.42386 .66992 Mdot
.44391 .74519 Mdot
.45059 .34198 Mdot
.47208 .67586 Mdot
.47436 .71381 Mdot
.49778 .59825 Mdot
.50874 .91643 Mdot
.51516 .76219 Mdot
.53655 .61374 Mdot
.56563 .75219 Mdot
.59189 .65665 Mdot
.59581 .61604 Mdot
.59923 .6556 Mdot
.60292 .68499 Mdot
.62656 .67779 Mdot
.63555 .72451 Mdot
.63919 .652 Mdot
.64169 .6004 Mdot
.64246 .58611 Mdot
.64496 .54267 Mdot
.64608 .77288 Mdot
.65077 .64308 Mdot
.66065 .57816 Mdot
.67474 .59169 Mdot
.69296 .563 Mdot
.72815 .65902 Mdot
.73169 .58879 Mdot
.74669 .61318 Mdot
.74821 .65474 Mdot
.75963 .63781 Mdot
.79673 .57809 Mdot
.80925 .55852 Mdot
.81525 .58444 Mdot
.83417 .62985 Mdot
.83598 .55526 Mdot
.91595 .49319 Mdot
1 0 0 r
.005 w
.00495 .28842 m
.00628 .29156 L
.01857 .31761 L
.03101 .33781 L
.03525 .34367 L
.05706 .36884 L
.05795 .36972 L
.08312 .39115 L
.08963 .39578 L
.10917 .40763 L
.13523 .41964 L
.14074 .42183 L
.16128 .42794 L
.18734 .43294 L
.21339 .43485 L
.23945 .43375 L
.2655 .42959 L
.29156 .42219 L
.29261 .42183 L
.31761 .41124 L
.34367 .39603 L
.34405 .39578 L
.36972 .37551 L
.37582 .36972 L
.39578 .34724 L
.39849 .34367 L
.41525 .31761 L
.42183 .30485 L
.4275 .29156 L
.436 .2655 L
.44117 .23945 L
.44325 .21339 L
.44232 .18734 L
.43834 .16128 L
.43114 .13523 L
.42183 .11212 L
.42037 .10917 L
.40546 .08312 L
.39578 .06961 L
.38528 .05706 L
.36972 .04137 L
.35758 .03101 L
.34367 .02092 L
.31761 .00569 L
.3162 .00495 L
s
.00495 .12854 m
.01344 .10917 L
.02832 .08312 L
.03101 .07912 L
.04848 .05706 L
.05706 .04802 L
.07619 .03101 L
.08312 .02579 L
.10917 .00934 L
.11742 .00495 L
s
0 0 1 r
.29156 .15739 m
.31761 .14824 L
.34367 .14249 L
.36972 .13986 L
.39578 .14025 L
.42183 .14366 L
.44789 .15025 L
.47394 .16034 L
.47599 .16128 L
.5 .17443 L
.51844 .18734 L
.52606 .19355 L
.54662 .21339 L
.55211 .21962 L
.56712 .23945 L
.57817 .25755 L
.58227 .2655 L
.59322 .29156 L
.60058 .31761 L
.60422 .3392 L
.60471 .34367 L
.6058 .36972 L
.60422 .39297 L
.60387 .39578 L
.59886 .42183 L
.59054 .44789 L
.57848 .47394 L
.57817 .47453 L
.562 .5 L
.55211 .51255 L
.53968 .52606 L
.52606 .53862 L
.50853 .55211 L
.5 .55773 L
.47394 .57183 L
.45901 .57817 L
.44789 .5819 L
.42183 .5885 L
.39578 .59192 L
.36972 .59231 L
.34367 .58968 L
.31761 .58392 L
.29972 .57817 L
.29156 .57477 L
.2655 .56178 L
.25025 .55211 L
.23945 .54409 L
.21914 .52606 L
.21339 .52008 L
.19681 .5 L
Mistroke
.18734 .48608 L
.18031 .47394 L
.16827 .44789 L
.16128 .42714 L
.15996 .42183 L
.15493 .39578 L
.153 .36972 L
.15409 .34367 L
.15823 .31761 L
.16128 .3045 L
.16559 .29156 L
.17653 .2655 L
.18734 .24609 L
.19169 .23945 L
.21221 .21339 L
.21339 .21211 L
.23945 .1881 L
.24041 .18734 L
.2655 .17038 L
.28271 .16128 L
.29156 .15739 L
Mfstroke
1 0 0 r
.03 w
.21687 .20845 Mdot
0 0 1 r
.3794 .36608 Mdot
1 0 0 r
.79703 .00495 m
.79703 .20089 L
.87129 .20089 L
.87129 .00495 L
F
0 0 1 r
.89604 .00495 m
.89604 .05654 L
.9703 .05654 L
.9703 .00495 L
F
1 0 1 r
.04 w
.03435 .12523 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCacheValid->False],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.49505 0.5 0.49505 [
[ 0 0 -0.125 0 ]
[ 0 0 -0.125 0 ]
[ 0 1 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
0 0 m
1 0 L
s
0 0 m
0 1 L
s
0 1 m
1 1 L
s
1 0 m
1 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
1 .5 0 r
.015 w
.03175 .1355 Mdot
.03435 .12523 Mdot
.11137 .12765 Mdot
.14107 .18841 Mdot
.16218 .24538 Mdot
.17294 .21053 Mdot
.18267 .18577 Mdot
.18434 .1304 Mdot
.18553 .30956 Mdot
.20401 .239 Mdot
.21247 .27571 Mdot
.21687 .20845 Mdot
.22376 .2799 Mdot
.22832 .27485 Mdot
.29063 .20974 Mdot
.29686 .25079 Mdot
.30487 .22936 Mdot
.30683 .34623 Mdot
.32055 .20902 Mdot
.32574 .21979 Mdot
.34472 .28521 Mdot
.35998 .36393 Mdot
.36335 .24976 Mdot
.3794 .36608 Mdot
.42386 .66992 Mdot
.44391 .74519 Mdot
.45059 .34198 Mdot
.47208 .67586 Mdot
.47436 .71381 Mdot
.49778 .59825 Mdot
.50874 .91643 Mdot
.51516 .76219 Mdot
.53655 .61374 Mdot
.56563 .75219 Mdot
.59189 .65665 Mdot
.59581 .61604 Mdot
.59923 .6556 Mdot
.60292 .68499 Mdot
.62656 .67779 Mdot
.63555 .72451 Mdot
.63919 .652 Mdot
.64169 .6004 Mdot
.64246 .58611 Mdot
.64496 .54267 Mdot
.64608 .77288 Mdot
.65077 .64308 Mdot
.66065 .57816 Mdot
.67474 .59169 Mdot
.69296 .563 Mdot
.72815 .65902 Mdot
.73169 .58879 Mdot
.74669 .61318 Mdot
.74821 .65474 Mdot
.75963 .63781 Mdot
.79673 .57809 Mdot
.80925 .55852 Mdot
.81525 .58444 Mdot
.83417 .62985 Mdot
.83598 .55526 Mdot
.91595 .49319 Mdot
1 0 0 r
.005 w
.00495 .28842 m
.00628 .29156 L
.01857 .31761 L
.03101 .33781 L
.03525 .34367 L
.05706 .36884 L
.05795 .36972 L
.08312 .39115 L
.08963 .39578 L
.10917 .40763 L
.13523 .41964 L
.14074 .42183 L
.16128 .42794 L
.18734 .43294 L
.21339 .43485 L
.23945 .43375 L
.2655 .42959 L
.29156 .42219 L
.29261 .42183 L
.31761 .41124 L
.34367 .39603 L
.34405 .39578 L
.36972 .37551 L
.37582 .36972 L
.39578 .34724 L
.39849 .34367 L
.41525 .31761 L
.42183 .30485 L
.4275 .29156 L
.436 .2655 L
.44117 .23945 L
.44325 .21339 L
.44232 .18734 L
.43834 .16128 L
.43114 .13523 L
.42183 .11212 L
.42037 .10917 L
.40546 .08312 L
.39578 .06961 L
.38528 .05706 L
.36972 .04137 L
.35758 .03101 L
.34367 .02092 L
.31761 .00569 L
.3162 .00495 L
s
.00495 .12854 m
.01344 .10917 L
.02832 .08312 L
.03101 .07912 L
.04848 .05706 L
.05706 .04802 L
.07619 .03101 L
.08312 .02579 L
.10917 .00934 L
.11742 .00495 L
s
0 0 1 r
.29156 .15739 m
.31761 .14824 L
.34367 .14249 L
.36972 .13986 L
.39578 .14025 L
.42183 .14366 L
.44789 .15025 L
.47394 .16034 L
.47599 .16128 L
.5 .17443 L
.51844 .18734 L
.52606 .19355 L
.54662 .21339 L
.55211 .21962 L
.56712 .23945 L
.57817 .25755 L
.58227 .2655 L
.59322 .29156 L
.60058 .31761 L
.60422 .3392 L
.60471 .34367 L
.6058 .36972 L
.60422 .39297 L
.60387 .39578 L
.59886 .42183 L
.59054 .44789 L
.57848 .47394 L
.57817 .47453 L
.562 .5 L
.55211 .51255 L
.53968 .52606 L
.52606 .53862 L
.50853 .55211 L
.5 .55773 L
.47394 .57183 L
.45901 .57817 L
.44789 .5819 L
.42183 .5885 L
.39578 .59192 L
.36972 .59231 L
.34367 .58968 L
.31761 .58392 L
.29972 .57817 L
.29156 .57477 L
.2655 .56178 L
.25025 .55211 L
.23945 .54409 L
.21914 .52606 L
.21339 .52008 L
.19681 .5 L
Mistroke
.18734 .48608 L
.18031 .47394 L
.16827 .44789 L
.16128 .42714 L
.15996 .42183 L
.15493 .39578 L
.153 .36972 L
.15409 .34367 L
.15823 .31761 L
.16128 .3045 L
.16559 .29156 L
.17653 .2655 L
.18734 .24609 L
.19169 .23945 L
.21221 .21339 L
.21339 .21211 L
.23945 .1881 L
.24041 .18734 L
.2655 .17038 L
.28271 .16128 L
.29156 .15739 L
Mfstroke
1 0 0 r
.03 w
.21687 .20845 Mdot
0 0 1 r
.3794 .36608 Mdot
1 0 0 r
.79703 .00495 m
.79703 .18986 L
.87129 .18986 L
.87129 .00495 L
F
0 0 1 r
.89604 .00495 m
.89604 .06756 L
.9703 .06756 L
.9703 .00495 L
F
1 0 1 r
.04 w
.11137 .12765 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCacheValid->False],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.49505 0.5 0.49505 [
[ 0 0 -0.125 0 ]
[ 0 0 -0.125 0 ]
[ 0 1 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
0 0 m
1 0 L
s
0 0 m
0 1 L
s
0 1 m
1 1 L
s
1 0 m
1 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
1 .5 0 r
.015 w
.03175 .1355 Mdot
.03435 .12523 Mdot
.11137 .12765 Mdot
.14107 .18841 Mdot
.16218 .24538 Mdot
.17294 .21053 Mdot
.18267 .18577 Mdot
.18434 .1304 Mdot
.18553 .30956 Mdot
.20401 .239 Mdot
.21247 .27571 Mdot
.21687 .20845 Mdot
.22376 .2799 Mdot
.22832 .27485 Mdot
.29063 .20974 Mdot
.29686 .25079 Mdot
.30487 .22936 Mdot
.30683 .34623 Mdot
.32055 .20902 Mdot
.32574 .21979 Mdot
.34472 .28521 Mdot
.35998 .36393 Mdot
.36335 .24976 Mdot
.3794 .36608 Mdot
.42386 .66992 Mdot
.44391 .74519 Mdot
.45059 .34198 Mdot
.47208 .67586 Mdot
.47436 .71381 Mdot
.49778 .59825 Mdot
.50874 .91643 Mdot
.51516 .76219 Mdot
.53655 .61374 Mdot
.56563 .75219 Mdot
.59189 .65665 Mdot
.59581 .61604 Mdot
.59923 .6556 Mdot
.60292 .68499 Mdot
.62656 .67779 Mdot
.63555 .72451 Mdot
.63919 .652 Mdot
.64169 .6004 Mdot
.64246 .58611 Mdot
.64496 .54267 Mdot
.64608 .77288 Mdot
.65077 .64308 Mdot
.66065 .57816 Mdot
.67474 .59169 Mdot
.69296 .563 Mdot
.72815 .65902 Mdot
.73169 .58879 Mdot
.74669 .61318 Mdot
.74821 .65474 Mdot
.75963 .63781 Mdot
.79673 .57809 Mdot
.80925 .55852 Mdot
.81525 .58444 Mdot
.83417 .62985 Mdot
.83598 .55526 Mdot
.91595 .49319 Mdot
1 0 0 r
.005 w
.00495 .28842 m
.00628 .29156 L
.01857 .31761 L
.03101 .33781 L
.03525 .34367 L
.05706 .36884 L
.05795 .36972 L
.08312 .39115 L
.08963 .39578 L
.10917 .40763 L
.13523 .41964 L
.14074 .42183 L
.16128 .42794 L
.18734 .43294 L
.21339 .43485 L
.23945 .43375 L
.2655 .42959 L
.29156 .42219 L
.29261 .42183 L
.31761 .41124 L
.34367 .39603 L
.34405 .39578 L
.36972 .37551 L
.37582 .36972 L
.39578 .34724 L
.39849 .34367 L
.41525 .31761 L
.42183 .30485 L
.4275 .29156 L
.436 .2655 L
.44117 .23945 L
.44325 .21339 L
.44232 .18734 L
.43834 .16128 L
.43114 .13523 L
.42183 .11212 L
.42037 .10917 L
.40546 .08312 L
.39578 .06961 L
.38528 .05706 L
.36972 .04137 L
.35758 .03101 L
.34367 .02092 L
.31761 .00569 L
.3162 .00495 L
s
.00495 .12854 m
.01344 .10917 L
.02832 .08312 L
.03101 .07912 L
.04848 .05706 L
.05706 .04802 L
.07619 .03101 L
.08312 .02579 L
.10917 .00934 L
.11742 .00495 L
s
0 0 1 r
.29156 .15739 m
.31761 .14824 L
.34367 .14249 L
.36972 .13986 L
.39578 .14025 L
.42183 .14366 L
.44789 .15025 L
.47394 .16034 L
.47599 .16128 L
.5 .17443 L
.51844 .18734 L
.52606 .19355 L
.54662 .21339 L
.55211 .21962 L
.56712 .23945 L
.57817 .25755 L
.58227 .2655 L
.59322 .29156 L
.60058 .31761 L
.60422 .3392 L
.60471 .34367 L
.6058 .36972 L
.60422 .39297 L
.60387 .39578 L
.59886 .42183 L
.59054 .44789 L
.57848 .47394 L
.57817 .47453 L
.562 .5 L
.55211 .51255 L
.53968 .52606 L
.52606 .53862 L
.50853 .55211 L
.5 .55773 L
.47394 .57183 L
.45901 .57817 L
.44789 .5819 L
.42183 .5885 L
.39578 .59192 L
.36972 .59231 L
.34367 .58968 L
.31761 .58392 L
.29972 .57817 L
.29156 .57477 L
.2655 .56178 L
.25025 .55211 L
.23945 .54409 L
.21914 .52606 L
.21339 .52008 L
.19681 .5 L
Mistroke
.18734 .48608 L
.18031 .47394 L
.16827 .44789 L
.16128 .42714 L
.15996 .42183 L
.15493 .39578 L
.153 .36972 L
.15409 .34367 L
.15823 .31761 L
.16128 .3045 L
.16559 .29156 L
.17653 .2655 L
.18734 .24609 L
.19169 .23945 L
.21221 .21339 L
.21339 .21211 L
.23945 .1881 L
.24041 .18734 L
.2655 .17038 L
.28271 .16128 L
.29156 .15739 L
Mfstroke
1 0 0 r
.03 w
.21687 .20845 Mdot
0 0 1 r
.3794 .36608 Mdot
1 0 0 r
.79703 .00495 m
.79703 .17584 L
.87129 .17584 L
.87129 .00495 L
F
0 0 1 r
.89604 .00495 m
.89604 .08159 L
.9703 .08159 L
.9703 .00495 L
F
1 0 1 r
.04 w
.14107 .18841 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCacheValid->False],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.49505 0.5 0.49505 [
[ 0 0 -0.125 0 ]
[ 0 0 -0.125 0 ]
[ 0 1 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
0 0 m
1 0 L
s
0 0 m
0 1 L
s
0 1 m
1 1 L
s
1 0 m
1 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
1 .5 0 r
.015 w
.03175 .1355 Mdot
.03435 .12523 Mdot
.11137 .12765 Mdot
.14107 .18841 Mdot
.16218 .24538 Mdot
.17294 .21053 Mdot
.18267 .18577 Mdot
.18434 .1304 Mdot
.18553 .30956 Mdot
.20401 .239 Mdot
.21247 .27571 Mdot
.21687 .20845 Mdot
.22376 .2799 Mdot
.22832 .27485 Mdot
.29063 .20974 Mdot
.29686 .25079 Mdot
.30487 .22936 Mdot
.30683 .34623 Mdot
.32055 .20902 Mdot
.32574 .21979 Mdot
.34472 .28521 Mdot
.35998 .36393 Mdot
.36335 .24976 Mdot
.3794 .36608 Mdot
.42386 .66992 Mdot
.44391 .74519 Mdot
.45059 .34198 Mdot
.47208 .67586 Mdot
.47436 .71381 Mdot
.49778 .59825 Mdot
.50874 .91643 Mdot
.51516 .76219 Mdot
.53655 .61374 Mdot
.56563 .75219 Mdot
.59189 .65665 Mdot
.59581 .61604 Mdot
.59923 .6556 Mdot
.60292 .68499 Mdot
.62656 .67779 Mdot
.63555 .72451 Mdot
.63919 .652 Mdot
.64169 .6004 Mdot
.64246 .58611 Mdot
.64496 .54267 Mdot
.64608 .77288 Mdot
.65077 .64308 Mdot
.66065 .57816 Mdot
.67474 .59169 Mdot
.69296 .563 Mdot
.72815 .65902 Mdot
.73169 .58879 Mdot
.74669 .61318 Mdot
.74821 .65474 Mdot
.75963 .63781 Mdot
.79673 .57809 Mdot
.80925 .55852 Mdot
.81525 .58444 Mdot
.83417 .62985 Mdot
.83598 .55526 Mdot
.91595 .49319 Mdot
1 0 0 r
.005 w
.00495 .28842 m
.00628 .29156 L
.01857 .31761 L
.03101 .33781 L
.03525 .34367 L
.05706 .36884 L
.05795 .36972 L
.08312 .39115 L
.08963 .39578 L
.10917 .40763 L
.13523 .41964 L
.14074 .42183 L
.16128 .42794 L
.18734 .43294 L
.21339 .43485 L
.23945 .43375 L
.2655 .42959 L
.29156 .42219 L
.29261 .42183 L
.31761 .41124 L
.34367 .39603 L
.34405 .39578 L
.36972 .37551 L
.37582 .36972 L
.39578 .34724 L
.39849 .34367 L
.41525 .31761 L
.42183 .30485 L
.4275 .29156 L
.436 .2655 L
.44117 .23945 L
.44325 .21339 L
.44232 .18734 L
.43834 .16128 L
.43114 .13523 L
.42183 .11212 L
.42037 .10917 L
.40546 .08312 L
.39578 .06961 L
.38528 .05706 L
.36972 .04137 L
.35758 .03101 L
.34367 .02092 L
.31761 .00569 L
.3162 .00495 L
s
.00495 .12854 m
.01344 .10917 L
.02832 .08312 L
.03101 .07912 L
.04848 .05706 L
.05706 .04802 L
.07619 .03101 L
.08312 .02579 L
.10917 .00934 L
.11742 .00495 L
s
0 0 1 r
.29156 .15739 m
.31761 .14824 L
.34367 .14249 L
.36972 .13986 L
.39578 .14025 L
.42183 .14366 L
.44789 .15025 L
.47394 .16034 L
.47599 .16128 L
.5 .17443 L
.51844 .18734 L
.52606 .19355 L
.54662 .21339 L
.55211 .21962 L
.56712 .23945 L
.57817 .25755 L
.58227 .2655 L
.59322 .29156 L
.60058 .31761 L
.60422 .3392 L
.60471 .34367 L
.6058 .36972 L
.60422 .39297 L
.60387 .39578 L
.59886 .42183 L
.59054 .44789 L
.57848 .47394 L
.57817 .47453 L
.562 .5 L
.55211 .51255 L
.53968 .52606 L
.52606 .53862 L
.50853 .55211 L
.5 .55773 L
.47394 .57183 L
.45901 .57817 L
.44789 .5819 L
.42183 .5885 L
.39578 .59192 L
.36972 .59231 L
.34367 .58968 L
.31761 .58392 L
.29972 .57817 L
.29156 .57477 L
.2655 .56178 L
.25025 .55211 L
.23945 .54409 L
.21914 .52606 L
.21339 .52008 L
.19681 .5 L
Mistroke
.18734 .48608 L
.18031 .47394 L
.16827 .44789 L
.16128 .42714 L
.15996 .42183 L
.15493 .39578 L
.153 .36972 L
.15409 .34367 L
.15823 .31761 L
.16128 .3045 L
.16559 .29156 L
.17653 .2655 L
.18734 .24609 L
.19169 .23945 L
.21221 .21339 L
.21339 .21211 L
.23945 .1881 L
.24041 .18734 L
.2655 .17038 L
.28271 .16128 L
.29156 .15739 L
Mfstroke
1 0 0 r
.03 w
.21687 .20845 Mdot
0 0 1 r
.3794 .36608 Mdot
1 0 0 r
.79703 .00495 m
.79703 .16248 L
.87129 .16248 L
.87129 .00495 L
F
0 0 1 r
.89604 .00495 m
.89604 .09495 L
.9703 .09495 L
.9703 .00495 L
F
1 0 1 r
.04 w
.16218 .24538 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCacheValid->False],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.49505 0.5 0.49505 [
[ 0 0 -0.125 0 ]
[ 0 0 -0.125 0 ]
[ 0 1 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
0 0 m
1 0 L
s
0 0 m
0 1 L
s
0 1 m
1 1 L
s
1 0 m
1 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
1 .5 0 r
.015 w
.03175 .1355 Mdot
.03435 .12523 Mdot
.11137 .12765 Mdot
.14107 .18841 Mdot
.16218 .24538 Mdot
.17294 .21053 Mdot
.18267 .18577 Mdot
.18434 .1304 Mdot
.18553 .30956 Mdot
.20401 .239 Mdot
.21247 .27571 Mdot
.21687 .20845 Mdot
.22376 .2799 Mdot
.22832 .27485 Mdot
.29063 .20974 Mdot
.29686 .25079 Mdot
.30487 .22936 Mdot
.30683 .34623 Mdot
.32055 .20902 Mdot
.32574 .21979 Mdot
.34472 .28521 Mdot
.35998 .36393 Mdot
.36335 .24976 Mdot
.3794 .36608 Mdot
.42386 .66992 Mdot
.44391 .74519 Mdot
.45059 .34198 Mdot
.47208 .67586 Mdot
.47436 .71381 Mdot
.49778 .59825 Mdot
.50874 .91643 Mdot
.51516 .76219 Mdot
.53655 .61374 Mdot
.56563 .75219 Mdot
.59189 .65665 Mdot
.59581 .61604 Mdot
.59923 .6556 Mdot
.60292 .68499 Mdot
.62656 .67779 Mdot
.63555 .72451 Mdot
.63919 .652 Mdot
.64169 .6004 Mdot
.64246 .58611 Mdot
.64496 .54267 Mdot
.64608 .77288 Mdot
.65077 .64308 Mdot
.66065 .57816 Mdot
.67474 .59169 Mdot
.69296 .563 Mdot
.72815 .65902 Mdot
.73169 .58879 Mdot
.74669 .61318 Mdot
.74821 .65474 Mdot
.75963 .63781 Mdot
.79673 .57809 Mdot
.80925 .55852 Mdot
.81525 .58444 Mdot
.83417 .62985 Mdot
.83598 .55526 Mdot
.91595 .49319 Mdot
1 0 0 r
.005 w
.00495 .28842 m
.00628 .29156 L
.01857 .31761 L
.03101 .33781 L
.03525 .34367 L
.05706 .36884 L
.05795 .36972 L
.08312 .39115 L
.08963 .39578 L
.10917 .40763 L
.13523 .41964 L
.14074 .42183 L
.16128 .42794 L
.18734 .43294 L
.21339 .43485 L
.23945 .43375 L
.2655 .42959 L
.29156 .42219 L
.29261 .42183 L
.31761 .41124 L
.34367 .39603 L
.34405 .39578 L
.36972 .37551 L
.37582 .36972 L
.39578 .34724 L
.39849 .34367 L
.41525 .31761 L
.42183 .30485 L
.4275 .29156 L
.436 .2655 L
.44117 .23945 L
.44325 .21339 L
.44232 .18734 L
.43834 .16128 L
.43114 .13523 L
.42183 .11212 L
.42037 .10917 L
.40546 .08312 L
.39578 .06961 L
.38528 .05706 L
.36972 .04137 L
.35758 .03101 L
.34367 .02092 L
.31761 .00569 L
.3162 .00495 L
s
.00495 .12854 m
.01344 .10917 L
.02832 .08312 L
.03101 .07912 L
.04848 .05706 L
.05706 .04802 L
.07619 .03101 L
.08312 .02579 L
.10917 .00934 L
.11742 .00495 L
s
0 0 1 r
.29156 .15739 m
.31761 .14824 L
.34367 .14249 L
.36972 .13986 L
.39578 .14025 L
.42183 .14366 L
.44789 .15025 L
.47394 .16034 L
.47599 .16128 L
.5 .17443 L
.51844 .18734 L
.52606 .19355 L
.54662 .21339 L
.55211 .21962 L
.56712 .23945 L
.57817 .25755 L
.58227 .2655 L
.59322 .29156 L
.60058 .31761 L
.60422 .3392 L
.60471 .34367 L
.6058 .36972 L
.60422 .39297 L
.60387 .39578 L
.59886 .42183 L
.59054 .44789 L
.57848 .47394 L
.57817 .47453 L
.562 .5 L
.55211 .51255 L
.53968 .52606 L
.52606 .53862 L
.50853 .55211 L
.5 .55773 L
.47394 .57183 L
.45901 .57817 L
.44789 .5819 L
.42183 .5885 L
.39578 .59192 L
.36972 .59231 L
.34367 .58968 L
.31761 .58392 L
.29972 .57817 L
.29156 .57477 L
.2655 .56178 L
.25025 .55211 L
.23945 .54409 L
.21914 .52606 L
.21339 .52008 L
.19681 .5 L
Mistroke
.18734 .48608 L
.18031 .47394 L
.16827 .44789 L
.16128 .42714 L
.15996 .42183 L
.15493 .39578 L
.153 .36972 L
.15409 .34367 L
.15823 .31761 L
.16128 .3045 L
.16559 .29156 L
.17653 .2655 L
.18734 .24609 L
.19169 .23945 L
.21221 .21339 L
.21339 .21211 L
.23945 .1881 L
.24041 .18734 L
.2655 .17038 L
.28271 .16128 L
.29156 .15739 L
Mfstroke
1 0 0 r
.03 w
.21687 .20845 Mdot
0 0 1 r
.3794 .36608 Mdot
1 0 0 r
.79703 .00495 m
.79703 .16662 L
.87129 .16662 L
.87129 .00495 L
F
0 0 1 r
.89604 .00495 m
.89604 .09081 L
.9703 .09081 L
.9703 .00495 L
F
1 0 1 r
.04 w
.17294 .21053 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCacheValid->False],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.49505 0.5 0.49505 [
[ 0 0 -0.125 0 ]
[ 0 0 -0.125 0 ]
[ 0 1 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
0 0 m
1 0 L
s
0 0 m
0 1 L
s
0 1 m
1 1 L
s
1 0 m
1 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
1 .5 0 r
.015 w
.03175 .1355 Mdot
.03435 .12523 Mdot
.11137 .12765 Mdot
.14107 .18841 Mdot
.16218 .24538 Mdot
.17294 .21053 Mdot
.18267 .18577 Mdot
.18434 .1304 Mdot
.18553 .30956 Mdot
.20401 .239 Mdot
.21247 .27571 Mdot
.21687 .20845 Mdot
.22376 .2799 Mdot
.22832 .27485 Mdot
.29063 .20974 Mdot
.29686 .25079 Mdot
.30487 .22936 Mdot
.30683 .34623 Mdot
.32055 .20902 Mdot
.32574 .21979 Mdot
.34472 .28521 Mdot
.35998 .36393 Mdot
.36335 .24976 Mdot
.3794 .36608 Mdot
.42386 .66992 Mdot
.44391 .74519 Mdot
.45059 .34198 Mdot
.47208 .67586 Mdot
.47436 .71381 Mdot
.49778 .59825 Mdot
.50874 .91643 Mdot
.51516 .76219 Mdot
.53655 .61374 Mdot
.56563 .75219 Mdot
.59189 .65665 Mdot
.59581 .61604 Mdot
.59923 .6556 Mdot
.60292 .68499 Mdot
.62656 .67779 Mdot
.63555 .72451 Mdot
.63919 .652 Mdot
.64169 .6004 Mdot
.64246 .58611 Mdot
.64496 .54267 Mdot
.64608 .77288 Mdot
.65077 .64308 Mdot
.66065 .57816 Mdot
.67474 .59169 Mdot
.69296 .563 Mdot
.72815 .65902 Mdot
.73169 .58879 Mdot
.74669 .61318 Mdot
.74821 .65474 Mdot
.75963 .63781 Mdot
.79673 .57809 Mdot
.80925 .55852 Mdot
.81525 .58444 Mdot
.83417 .62985 Mdot
.83598 .55526 Mdot
.91595 .49319 Mdot
1 0 0 r
.005 w
.00495 .28842 m
.00628 .29156 L
.01857 .31761 L
.03101 .33781 L
.03525 .34367 L
.05706 .36884 L
.05795 .36972 L
.08312 .39115 L
.08963 .39578 L
.10917 .40763 L
.13523 .41964 L
.14074 .42183 L
.16128 .42794 L
.18734 .43294 L
.21339 .43485 L
.23945 .43375 L
.2655 .42959 L
.29156 .42219 L
.29261 .42183 L
.31761 .41124 L
.34367 .39603 L
.34405 .39578 L
.36972 .37551 L
.37582 .36972 L
.39578 .34724 L
.39849 .34367 L
.41525 .31761 L
.42183 .30485 L
.4275 .29156 L
.436 .2655 L
.44117 .23945 L
.44325 .21339 L
.44232 .18734 L
.43834 .16128 L
.43114 .13523 L
.42183 .11212 L
.42037 .10917 L
.40546 .08312 L
.39578 .06961 L
.38528 .05706 L
.36972 .04137 L
.35758 .03101 L
.34367 .02092 L
.31761 .00569 L
.3162 .00495 L
s
.00495 .12854 m
.01344 .10917 L
.02832 .08312 L
.03101 .07912 L
.04848 .05706 L
.05706 .04802 L
.07619 .03101 L
.08312 .02579 L
.10917 .00934 L
.11742 .00495 L
s
0 0 1 r
.29156 .15739 m
.31761 .14824 L
.34367 .14249 L
.36972 .13986 L
.39578 .14025 L
.42183 .14366 L
.44789 .15025 L
.47394 .16034 L
.47599 .16128 L
.5 .17443 L
.51844 .18734 L
.52606 .19355 L
.54662 .21339 L
.55211 .21962 L
.56712 .23945 L
.57817 .25755 L
.58227 .2655 L
.59322 .29156 L
.60058 .31761 L
.60422 .3392 L
.60471 .34367 L
.6058 .36972 L
.60422 .39297 L
.60387 .39578 L
.59886 .42183 L
.59054 .44789 L
.57848 .47394 L
.57817 .47453 L
.562 .5 L
.55211 .51255 L
.53968 .52606 L
.52606 .53862 L
.50853 .55211 L
.5 .55773 L
.47394 .57183 L
.45901 .57817 L
.44789 .5819 L
.42183 .5885 L
.39578 .59192 L
.36972 .59231 L
.34367 .58968 L
.31761 .58392 L
.29972 .57817 L
.29156 .57477 L
.2655 .56178 L
.25025 .55211 L
.23945 .54409 L
.21914 .52606 L
.21339 .52008 L
.19681 .5 L
Mistroke
.18734 .48608 L
.18031 .47394 L
.16827 .44789 L
.16128 .42714 L
.15996 .42183 L
.15493 .39578 L
.153 .36972 L
.15409 .34367 L
.15823 .31761 L
.16128 .3045 L
.16559 .29156 L
.17653 .2655 L
.18734 .24609 L
.19169 .23945 L
.21221 .21339 L
.21339 .21211 L
.23945 .1881 L
.24041 .18734 L
.2655 .17038 L
.28271 .16128 L
.29156 .15739 L
Mfstroke
1 0 0 r
.03 w
.21687 .20845 Mdot
0 0 1 r
.3794 .36608 Mdot
1 0 0 r
.79703 .00495 m
.79703 .16914 L
.87129 .16914 L
.87129 .00495 L
F
0 0 1 r
.89604 .00495 m
.89604 .08828 L
.9703 .08828 L
.9703 .00495 L
F
1 0 1 r
.04 w
.18267 .18577 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCacheValid->False],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.49505 0.5 0.49505 [
[ 0 0 -0.125 0 ]
[ 0 0 -0.125 0 ]
[ 0 1 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
0 0 m
1 0 L
s
0 0 m
0 1 L
s
0 1 m
1 1 L
s
1 0 m
1 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
1 .5 0 r
.015 w
.03175 .1355 Mdot
.03435 .12523 Mdot
.11137 .12765 Mdot
.14107 .18841 Mdot
.16218 .24538 Mdot
.17294 .21053 Mdot
.18267 .18577 Mdot
.18434 .1304 Mdot
.18553 .30956 Mdot
.20401 .239 Mdot
.21247 .27571 Mdot
.21687 .20845 Mdot
.22376 .2799 Mdot
.22832 .27485 Mdot
.29063 .20974 Mdot
.29686 .25079 Mdot
.30487 .22936 Mdot
.30683 .34623 Mdot
.32055 .20902 Mdot
.32574 .21979 Mdot
.34472 .28521 Mdot
.35998 .36393 Mdot
.36335 .24976 Mdot
.3794 .36608 Mdot
.42386 .66992 Mdot
.44391 .74519 Mdot
.45059 .34198 Mdot
.47208 .67586 Mdot
.47436 .71381 Mdot
.49778 .59825 Mdot
.50874 .91643 Mdot
.51516 .76219 Mdot
.53655 .61374 Mdot
.56563 .75219 Mdot
.59189 .65665 Mdot
.59581 .61604 Mdot
.59923 .6556 Mdot
.60292 .68499 Mdot
.62656 .67779 Mdot
.63555 .72451 Mdot
.63919 .652 Mdot
.64169 .6004 Mdot
.64246 .58611 Mdot
.64496 .54267 Mdot
.64608 .77288 Mdot
.65077 .64308 Mdot
.66065 .57816 Mdot
.67474 .59169 Mdot
.69296 .563 Mdot
.72815 .65902 Mdot
.73169 .58879 Mdot
.74669 .61318 Mdot
.74821 .65474 Mdot
.75963 .63781 Mdot
.79673 .57809 Mdot
.80925 .55852 Mdot
.81525 .58444 Mdot
.83417 .62985 Mdot
.83598 .55526 Mdot
.91595 .49319 Mdot
1 0 0 r
.005 w
.00495 .28842 m
.00628 .29156 L
.01857 .31761 L
.03101 .33781 L
.03525 .34367 L
.05706 .36884 L
.05795 .36972 L
.08312 .39115 L
.08963 .39578 L
.10917 .40763 L
.13523 .41964 L
.14074 .42183 L
.16128 .42794 L
.18734 .43294 L
.21339 .43485 L
.23945 .43375 L
.2655 .42959 L
.29156 .42219 L
.29261 .42183 L
.31761 .41124 L
.34367 .39603 L
.34405 .39578 L
.36972 .37551 L
.37582 .36972 L
.39578 .34724 L
.39849 .34367 L
.41525 .31761 L
.42183 .30485 L
.4275 .29156 L
.436 .2655 L
.44117 .23945 L
.44325 .21339 L
.44232 .18734 L
.43834 .16128 L
.43114 .13523 L
.42183 .11212 L
.42037 .10917 L
.40546 .08312 L
.39578 .06961 L
.38528 .05706 L
.36972 .04137 L
.35758 .03101 L
.34367 .02092 L
.31761 .00569 L
.3162 .00495 L
s
.00495 .12854 m
.01344 .10917 L
.02832 .08312 L
.03101 .07912 L
.04848 .05706 L
.05706 .04802 L
.07619 .03101 L
.08312 .02579 L
.10917 .00934 L
.11742 .00495 L
s
0 0 1 r
.29156 .15739 m
.31761 .14824 L
.34367 .14249 L
.36972 .13986 L
.39578 .14025 L
.42183 .14366 L
.44789 .15025 L
.47394 .16034 L
.47599 .16128 L
.5 .17443 L
.51844 .18734 L
.52606 .19355 L
.54662 .21339 L
.55211 .21962 L
.56712 .23945 L
.57817 .25755 L
.58227 .2655 L
.59322 .29156 L
.60058 .31761 L
.60422 .3392 L
.60471 .34367 L
.6058 .36972 L
.60422 .39297 L
.60387 .39578 L
.59886 .42183 L
.59054 .44789 L
.57848 .47394 L
.57817 .47453 L
.562 .5 L
.55211 .51255 L
.53968 .52606 L
.52606 .53862 L
.50853 .55211 L
.5 .55773 L
.47394 .57183 L
.45901 .57817 L
.44789 .5819 L
.42183 .5885 L
.39578 .59192 L
.36972 .59231 L
.34367 .58968 L
.31761 .58392 L
.29972 .57817 L
.29156 .57477 L
.2655 .56178 L
.25025 .55211 L
.23945 .54409 L
.21914 .52606 L
.21339 .52008 L
.19681 .5 L
Mistroke
.18734 .48608 L
.18031 .47394 L
.16827 .44789 L
.16128 .42714 L
.15996 .42183 L
.15493 .39578 L
.153 .36972 L
.15409 .34367 L
.15823 .31761 L
.16128 .3045 L
.16559 .29156 L
.17653 .2655 L
.18734 .24609 L
.19169 .23945 L
.21221 .21339 L
.21339 .21211 L
.23945 .1881 L
.24041 .18734 L
.2655 .17038 L
.28271 .16128 L
.29156 .15739 L
Mfstroke
1 0 0 r
.03 w
.21687 .20845 Mdot
0 0 1 r
.3794 .36608 Mdot
1 0 0 r
.79703 .00495 m
.79703 .178 L
.87129 .178 L
.87129 .00495 L
F
0 0 1 r
.89604 .00495 m
.89604 .07943 L
.9703 .07943 L
.9703 .00495 L
F
1 0 1 r
.04 w
.18434 .1304 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCacheValid->False],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.49505 0.5 0.49505 [
[ 0 0 -0.125 0 ]
[ 0 0 -0.125 0 ]
[ 0 1 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
0 0 m
1 0 L
s
0 0 m
0 1 L
s
0 1 m
1 1 L
s
1 0 m
1 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
1 .5 0 r
.015 w
.03175 .1355 Mdot
.03435 .12523 Mdot
.11137 .12765 Mdot
.14107 .18841 Mdot
.16218 .24538 Mdot
.17294 .21053 Mdot
.18267 .18577 Mdot
.18434 .1304 Mdot
.18553 .30956 Mdot
.20401 .239 Mdot
.21247 .27571 Mdot
.21687 .20845 Mdot
.22376 .2799 Mdot
.22832 .27485 Mdot
.29063 .20974 Mdot
.29686 .25079 Mdot
.30487 .22936 Mdot
.30683 .34623 Mdot
.32055 .20902 Mdot
.32574 .21979 Mdot
.34472 .28521 Mdot
.35998 .36393 Mdot
.36335 .24976 Mdot
.3794 .36608 Mdot
.42386 .66992 Mdot
.44391 .74519 Mdot
.45059 .34198 Mdot
.47208 .67586 Mdot
.47436 .71381 Mdot
.49778 .59825 Mdot
.50874 .91643 Mdot
.51516 .76219 Mdot
.53655 .61374 Mdot
.56563 .75219 Mdot
.59189 .65665 Mdot
.59581 .61604 Mdot
.59923 .6556 Mdot
.60292 .68499 Mdot
.62656 .67779 Mdot
.63555 .72451 Mdot
.63919 .652 Mdot
.64169 .6004 Mdot
.64246 .58611 Mdot
.64496 .54267 Mdot
.64608 .77288 Mdot
.65077 .64308 Mdot
.66065 .57816 Mdot
.67474 .59169 Mdot
.69296 .563 Mdot
.72815 .65902 Mdot
.73169 .58879 Mdot
.74669 .61318 Mdot
.74821 .65474 Mdot
.75963 .63781 Mdot
.79673 .57809 Mdot
.80925 .55852 Mdot
.81525 .58444 Mdot
.83417 .62985 Mdot
.83598 .55526 Mdot
.91595 .49319 Mdot
1 0 0 r
.005 w
.00495 .28842 m
.00628 .29156 L
.01857 .31761 L
.03101 .33781 L
.03525 .34367 L
.05706 .36884 L
.05795 .36972 L
.08312 .39115 L
.08963 .39578 L
.10917 .40763 L
.13523 .41964 L
.14074 .42183 L
.16128 .42794 L
.18734 .43294 L
.21339 .43485 L
.23945 .43375 L
.2655 .42959 L
.29156 .42219 L
.29261 .42183 L
.31761 .41124 L
.34367 .39603 L
.34405 .39578 L
.36972 .37551 L
.37582 .36972 L
.39578 .34724 L
.39849 .34367 L
.41525 .31761 L
.42183 .30485 L
.4275 .29156 L
.436 .2655 L
.44117 .23945 L
.44325 .21339 L
.44232 .18734 L
.43834 .16128 L
.43114 .13523 L
.42183 .11212 L
.42037 .10917 L
.40546 .08312 L
.39578 .06961 L
.38528 .05706 L
.36972 .04137 L
.35758 .03101 L
.34367 .02092 L
.31761 .00569 L
.3162 .00495 L
s
.00495 .12854 m
.01344 .10917 L
.02832 .08312 L
.03101 .07912 L
.04848 .05706 L
.05706 .04802 L
.07619 .03101 L
.08312 .02579 L
.10917 .00934 L
.11742 .00495 L
s
0 0 1 r
.29156 .15739 m
.31761 .14824 L
.34367 .14249 L
.36972 .13986 L
.39578 .14025 L
.42183 .14366 L
.44789 .15025 L
.47394 .16034 L
.47599 .16128 L
.5 .17443 L
.51844 .18734 L
.52606 .19355 L
.54662 .21339 L
.55211 .21962 L
.56712 .23945 L
.57817 .25755 L
.58227 .2655 L
.59322 .29156 L
.60058 .31761 L
.60422 .3392 L
.60471 .34367 L
.6058 .36972 L
.60422 .39297 L
.60387 .39578 L
.59886 .42183 L
.59054 .44789 L
.57848 .47394 L
.57817 .47453 L
.562 .5 L
.55211 .51255 L
.53968 .52606 L
.52606 .53862 L
.50853 .55211 L
.5 .55773 L
.47394 .57183 L
.45901 .57817 L
.44789 .5819 L
.42183 .5885 L
.39578 .59192 L
.36972 .59231 L
.34367 .58968 L
.31761 .58392 L
.29972 .57817 L
.29156 .57477 L
.2655 .56178 L
.25025 .55211 L
.23945 .54409 L
.21914 .52606 L
.21339 .52008 L
.19681 .5 L
Mistroke
.18734 .48608 L
.18031 .47394 L
.16827 .44789 L
.16128 .42714 L
.15996 .42183 L
.15493 .39578 L
.153 .36972 L
.15409 .34367 L
.15823 .31761 L
.16128 .3045 L
.16559 .29156 L
.17653 .2655 L
.18734 .24609 L
.19169 .23945 L
.21221 .21339 L
.21339 .21211 L
.23945 .1881 L
.24041 .18734 L
.2655 .17038 L
.28271 .16128 L
.29156 .15739 L
Mfstroke
1 0 0 r
.03 w
.21687 .20845 Mdot
0 0 1 r
.3794 .36608 Mdot
1 0 0 r
.79703 .00495 m
.79703 .14644 L
.87129 .14644 L
.87129 .00495 L
F
0 0 1 r
.89604 .00495 m
.89604 .11099 L
.9703 .11099 L
.9703 .00495 L
F
1 0 1 r
.04 w
.18553 .30956 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCacheValid->False],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.49505 0.5 0.49505 [
[ 0 0 -0.125 0 ]
[ 0 0 -0.125 0 ]
[ 0 1 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
0 0 m
1 0 L
s
0 0 m
0 1 L
s
0 1 m
1 1 L
s
1 0 m
1 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
1 .5 0 r
.015 w
.03175 .1355 Mdot
.03435 .12523 Mdot
.11137 .12765 Mdot
.14107 .18841 Mdot
.16218 .24538 Mdot
.17294 .21053 Mdot
.18267 .18577 Mdot
.18434 .1304 Mdot
.18553 .30956 Mdot
.20401 .239 Mdot
.21247 .27571 Mdot
.21687 .20845 Mdot
.22376 .2799 Mdot
.22832 .27485 Mdot
.29063 .20974 Mdot
.29686 .25079 Mdot
.30487 .22936 Mdot
.30683 .34623 Mdot
.32055 .20902 Mdot
.32574 .21979 Mdot
.34472 .28521 Mdot
.35998 .36393 Mdot
.36335 .24976 Mdot
.3794 .36608 Mdot
.42386 .66992 Mdot
.44391 .74519 Mdot
.45059 .34198 Mdot
.47208 .67586 Mdot
.47436 .71381 Mdot
.49778 .59825 Mdot
.50874 .91643 Mdot
.51516 .76219 Mdot
.53655 .61374 Mdot
.56563 .75219 Mdot
.59189 .65665 Mdot
.59581 .61604 Mdot
.59923 .6556 Mdot
.60292 .68499 Mdot
.62656 .67779 Mdot
.63555 .72451 Mdot
.63919 .652 Mdot
.64169 .6004 Mdot
.64246 .58611 Mdot
.64496 .54267 Mdot
.64608 .77288 Mdot
.65077 .64308 Mdot
.66065 .57816 Mdot
.67474 .59169 Mdot
.69296 .563 Mdot
.72815 .65902 Mdot
.73169 .58879 Mdot
.74669 .61318 Mdot
.74821 .65474 Mdot
.75963 .63781 Mdot
.79673 .57809 Mdot
.80925 .55852 Mdot
.81525 .58444 Mdot
.83417 .62985 Mdot
.83598 .55526 Mdot
.91595 .49319 Mdot
1 0 0 r
.005 w
.00495 .28842 m
.00628 .29156 L
.01857 .31761 L
.03101 .33781 L
.03525 .34367 L
.05706 .36884 L
.05795 .36972 L
.08312 .39115 L
.08963 .39578 L
.10917 .40763 L
.13523 .41964 L
.14074 .42183 L
.16128 .42794 L
.18734 .43294 L
.21339 .43485 L
.23945 .43375 L
.2655 .42959 L
.29156 .42219 L
.29261 .42183 L
.31761 .41124 L
.34367 .39603 L
.34405 .39578 L
.36972 .37551 L
.37582 .36972 L
.39578 .34724 L
.39849 .34367 L
.41525 .31761 L
.42183 .30485 L
.4275 .29156 L
.436 .2655 L
.44117 .23945 L
.44325 .21339 L
.44232 .18734 L
.43834 .16128 L
.43114 .13523 L
.42183 .11212 L
.42037 .10917 L
.40546 .08312 L
.39578 .06961 L
.38528 .05706 L
.36972 .04137 L
.35758 .03101 L
.34367 .02092 L
.31761 .00569 L
.3162 .00495 L
s
.00495 .12854 m
.01344 .10917 L
.02832 .08312 L
.03101 .07912 L
.04848 .05706 L
.05706 .04802 L
.07619 .03101 L
.08312 .02579 L
.10917 .00934 L
.11742 .00495 L
s
0 0 1 r
.29156 .15739 m
.31761 .14824 L
.34367 .14249 L
.36972 .13986 L
.39578 .14025 L
.42183 .14366 L
.44789 .15025 L
.47394 .16034 L
.47599 .16128 L
.5 .17443 L
.51844 .18734 L
.52606 .19355 L
.54662 .21339 L
.55211 .21962 L
.56712 .23945 L
.57817 .25755 L
.58227 .2655 L
.59322 .29156 L
.60058 .31761 L
.60422 .3392 L
.60471 .34367 L
.6058 .36972 L
.60422 .39297 L
.60387 .39578 L
.59886 .42183 L
.59054 .44789 L
.57848 .47394 L
.57817 .47453 L
.562 .5 L
.55211 .51255 L
.53968 .52606 L
.52606 .53862 L
.50853 .55211 L
.5 .55773 L
.47394 .57183 L
.45901 .57817 L
.44789 .5819 L
.42183 .5885 L
.39578 .59192 L
.36972 .59231 L
.34367 .58968 L
.31761 .58392 L
.29972 .57817 L
.29156 .57477 L
.2655 .56178 L
.25025 .55211 L
.23945 .54409 L
.21914 .52606 L
.21339 .52008 L
.19681 .5 L
Mistroke
.18734 .48608 L
.18031 .47394 L
.16827 .44789 L
.16128 .42714 L
.15996 .42183 L
.15493 .39578 L
.153 .36972 L
.15409 .34367 L
.15823 .31761 L
.16128 .3045 L
.16559 .29156 L
.17653 .2655 L
.18734 .24609 L
.19169 .23945 L
.21221 .21339 L
.21339 .21211 L
.23945 .1881 L
.24041 .18734 L
.2655 .17038 L
.28271 .16128 L
.29156 .15739 L
Mfstroke
1 0 0 r
.03 w
.21687 .20845 Mdot
0 0 1 r
.3794 .36608 Mdot
1 0 0 r
.79703 .00495 m
.79703 .15591 L
.87129 .15591 L
.87129 .00495 L
F
0 0 1 r
.89604 .00495 m
.89604 .10151 L
.9703 .10151 L
.9703 .00495 L
F
1 0 1 r
.04 w
.20401 .239 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCacheValid->False],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.49505 0.5 0.49505 [
[ 0 0 -0.125 0 ]
[ 0 0 -0.125 0 ]
[ 0 1 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
0 0 m
1 0 L
s
0 0 m
0 1 L
s
0 1 m
1 1 L
s
1 0 m
1 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
1 .5 0 r
.015 w
.03175 .1355 Mdot
.03435 .12523 Mdot
.11137 .12765 Mdot
.14107 .18841 Mdot
.16218 .24538 Mdot
.17294 .21053 Mdot
.18267 .18577 Mdot
.18434 .1304 Mdot
.18553 .30956 Mdot
.20401 .239 Mdot
.21247 .27571 Mdot
.21687 .20845 Mdot
.22376 .2799 Mdot
.22832 .27485 Mdot
.29063 .20974 Mdot
.29686 .25079 Mdot
.30487 .22936 Mdot
.30683 .34623 Mdot
.32055 .20902 Mdot
.32574 .21979 Mdot
.34472 .28521 Mdot
.35998 .36393 Mdot
.36335 .24976 Mdot
.3794 .36608 Mdot
.42386 .66992 Mdot
.44391 .74519 Mdot
.45059 .34198 Mdot
.47208 .67586 Mdot
.47436 .71381 Mdot
.49778 .59825 Mdot
.50874 .91643 Mdot
.51516 .76219 Mdot
.53655 .61374 Mdot
.56563 .75219 Mdot
.59189 .65665 Mdot
.59581 .61604 Mdot
.59923 .6556 Mdot
.60292 .68499 Mdot
.62656 .67779 Mdot
.63555 .72451 Mdot
.63919 .652 Mdot
.64169 .6004 Mdot
.64246 .58611 Mdot
.64496 .54267 Mdot
.64608 .77288 Mdot
.65077 .64308 Mdot
.66065 .57816 Mdot
.67474 .59169 Mdot
.69296 .563 Mdot
.72815 .65902 Mdot
.73169 .58879 Mdot
.74669 .61318 Mdot
.74821 .65474 Mdot
.75963 .63781 Mdot
.79673 .57809 Mdot
.80925 .55852 Mdot
.81525 .58444 Mdot
.83417 .62985 Mdot
.83598 .55526 Mdot
.91595 .49319 Mdot
1 0 0 r
.005 w
.00495 .28842 m
.00628 .29156 L
.01857 .31761 L
.03101 .33781 L
.03525 .34367 L
.05706 .36884 L
.05795 .36972 L
.08312 .39115 L
.08963 .39578 L
.10917 .40763 L
.13523 .41964 L
.14074 .42183 L
.16128 .42794 L
.18734 .43294 L
.21339 .43485 L
.23945 .43375 L
.2655 .42959 L
.29156 .42219 L
.29261 .42183 L
.31761 .41124 L
.34367 .39603 L
.34405 .39578 L
.36972 .37551 L
.37582 .36972 L
.39578 .34724 L
.39849 .34367 L
.41525 .31761 L
.42183 .30485 L
.4275 .29156 L
.436 .2655 L
.44117 .23945 L
.44325 .21339 L
.44232 .18734 L
.43834 .16128 L
.43114 .13523 L
.42183 .11212 L
.42037 .10917 L
.40546 .08312 L
.39578 .06961 L
.38528 .05706 L
.36972 .04137 L
.35758 .03101 L
.34367 .02092 L
.31761 .00569 L
.3162 .00495 L
s
.00495 .12854 m
.01344 .10917 L
.02832 .08312 L
.03101 .07912 L
.04848 .05706 L
.05706 .04802 L
.07619 .03101 L
.08312 .02579 L
.10917 .00934 L
.11742 .00495 L
s
0 0 1 r
.29156 .15739 m
.31761 .14824 L
.34367 .14249 L
.36972 .13986 L
.39578 .14025 L
.42183 .14366 L
.44789 .15025 L
.47394 .16034 L
.47599 .16128 L
.5 .17443 L
.51844 .18734 L
.52606 .19355 L
.54662 .21339 L
.55211 .21962 L
.56712 .23945 L
.57817 .25755 L
.58227 .2655 L
.59322 .29156 L
.60058 .31761 L
.60422 .3392 L
.60471 .34367 L
.6058 .36972 L
.60422 .39297 L
.60387 .39578 L
.59886 .42183 L
.59054 .44789 L
.57848 .47394 L
.57817 .47453 L
.562 .5 L
.55211 .51255 L
.53968 .52606 L
.52606 .53862 L
.50853 .55211 L
.5 .55773 L
.47394 .57183 L
.45901 .57817 L
.44789 .5819 L
.42183 .5885 L
.39578 .59192 L
.36972 .59231 L
.34367 .58968 L
.31761 .58392 L
.29972 .57817 L
.29156 .57477 L
.2655 .56178 L
.25025 .55211 L
.23945 .54409 L
.21914 .52606 L
.21339 .52008 L
.19681 .5 L
Mistroke
.18734 .48608 L
.18031 .47394 L
.16827 .44789 L
.16128 .42714 L
.15996 .42183 L
.15493 .39578 L
.153 .36972 L
.15409 .34367 L
.15823 .31761 L
.16128 .3045 L
.16559 .29156 L
.17653 .2655 L
.18734 .24609 L
.19169 .23945 L
.21221 .21339 L
.21339 .21211 L
.23945 .1881 L
.24041 .18734 L
.2655 .17038 L
.28271 .16128 L
.29156 .15739 L
Mfstroke
1 0 0 r
.03 w
.21687 .20845 Mdot
0 0 1 r
.3794 .36608 Mdot
1 0 0 r
.79703 .00495 m
.79703 .14757 L
.87129 .14757 L
.87129 .00495 L
F
0 0 1 r
.89604 .00495 m
.89604 .10986 L
.9703 .10986 L
.9703 .00495 L
F
1 0 1 r
.04 w
.21247 .27571 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCacheValid->False],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.49505 0.5 0.49505 [
[ 0 0 -0.125 0 ]
[ 0 0 -0.125 0 ]
[ 0 1 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
0 0 m
1 0 L
s
0 0 m
0 1 L
s
0 1 m
1 1 L
s
1 0 m
1 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
1 .5 0 r
.015 w
.03175 .1355 Mdot
.03435 .12523 Mdot
.11137 .12765 Mdot
.14107 .18841 Mdot
.16218 .24538 Mdot
.17294 .21053 Mdot
.18267 .18577 Mdot
.18434 .1304 Mdot
.18553 .30956 Mdot
.20401 .239 Mdot
.21247 .27571 Mdot
.21687 .20845 Mdot
.22376 .2799 Mdot
.22832 .27485 Mdot
.29063 .20974 Mdot
.29686 .25079 Mdot
.30487 .22936 Mdot
.30683 .34623 Mdot
.32055 .20902 Mdot
.32574 .21979 Mdot
.34472 .28521 Mdot
.35998 .36393 Mdot
.36335 .24976 Mdot
.3794 .36608 Mdot
.42386 .66992 Mdot
.44391 .74519 Mdot
.45059 .34198 Mdot
.47208 .67586 Mdot
.47436 .71381 Mdot
.49778 .59825 Mdot
.50874 .91643 Mdot
.51516 .76219 Mdot
.53655 .61374 Mdot
.56563 .75219 Mdot
.59189 .65665 Mdot
.59581 .61604 Mdot
.59923 .6556 Mdot
.60292 .68499 Mdot
.62656 .67779 Mdot
.63555 .72451 Mdot
.63919 .652 Mdot
.64169 .6004 Mdot
.64246 .58611 Mdot
.64496 .54267 Mdot
.64608 .77288 Mdot
.65077 .64308 Mdot
.66065 .57816 Mdot
.67474 .59169 Mdot
.69296 .563 Mdot
.72815 .65902 Mdot
.73169 .58879 Mdot
.74669 .61318 Mdot
.74821 .65474 Mdot
.75963 .63781 Mdot
.79673 .57809 Mdot
.80925 .55852 Mdot
.81525 .58444 Mdot
.83417 .62985 Mdot
.83598 .55526 Mdot
.91595 .49319 Mdot
1 0 0 r
.005 w
.00495 .28842 m
.00628 .29156 L
.01857 .31761 L
.03101 .33781 L
.03525 .34367 L
.05706 .36884 L
.05795 .36972 L
.08312 .39115 L
.08963 .39578 L
.10917 .40763 L
.13523 .41964 L
.14074 .42183 L
.16128 .42794 L
.18734 .43294 L
.21339 .43485 L
.23945 .43375 L
.2655 .42959 L
.29156 .42219 L
.29261 .42183 L
.31761 .41124 L
.34367 .39603 L
.34405 .39578 L
.36972 .37551 L
.37582 .36972 L
.39578 .34724 L
.39849 .34367 L
.41525 .31761 L
.42183 .30485 L
.4275 .29156 L
.436 .2655 L
.44117 .23945 L
.44325 .21339 L
.44232 .18734 L
.43834 .16128 L
.43114 .13523 L
.42183 .11212 L
.42037 .10917 L
.40546 .08312 L
.39578 .06961 L
.38528 .05706 L
.36972 .04137 L
.35758 .03101 L
.34367 .02092 L
.31761 .00569 L
.3162 .00495 L
s
.00495 .12854 m
.01344 .10917 L
.02832 .08312 L
.03101 .07912 L
.04848 .05706 L
.05706 .04802 L
.07619 .03101 L
.08312 .02579 L
.10917 .00934 L
.11742 .00495 L
s
0 0 1 r
.29156 .15739 m
.31761 .14824 L
.34367 .14249 L
.36972 .13986 L
.39578 .14025 L
.42183 .14366 L
.44789 .15025 L
.47394 .16034 L
.47599 .16128 L
.5 .17443 L
.51844 .18734 L
.52606 .19355 L
.54662 .21339 L
.55211 .21962 L
.56712 .23945 L
.57817 .25755 L
.58227 .2655 L
.59322 .29156 L
.60058 .31761 L
.60422 .3392 L
.60471 .34367 L
.6058 .36972 L
.60422 .39297 L
.60387 .39578 L
.59886 .42183 L
.59054 .44789 L
.57848 .47394 L
.57817 .47453 L
.562 .5 L
.55211 .51255 L
.53968 .52606 L
.52606 .53862 L
.50853 .55211 L
.5 .55773 L
.47394 .57183 L
.45901 .57817 L
.44789 .5819 L
.42183 .5885 L
.39578 .59192 L
.36972 .59231 L
.34367 .58968 L
.31761 .58392 L
.29972 .57817 L
.29156 .57477 L
.2655 .56178 L
.25025 .55211 L
.23945 .54409 L
.21914 .52606 L
.21339 .52008 L
.19681 .5 L
Mistroke
.18734 .48608 L
.18031 .47394 L
.16827 .44789 L
.16128 .42714 L
.15996 .42183 L
.15493 .39578 L
.153 .36972 L
.15409 .34367 L
.15823 .31761 L
.16128 .3045 L
.16559 .29156 L
.17653 .2655 L
.18734 .24609 L
.19169 .23945 L
.21221 .21339 L
.21339 .21211 L
.23945 .1881 L
.24041 .18734 L
.2655 .17038 L
.28271 .16128 L
.29156 .15739 L
Mfstroke
1 0 0 r
.03 w
.21687 .20845 Mdot
0 0 1 r
.3794 .36608 Mdot
1 0 0 r
.79703 .00495 m
.79703 .15902 L
.87129 .15902 L
.87129 .00495 L
F
0 0 1 r
.89604 .00495 m
.89604 .0984 L
.9703 .0984 L
.9703 .00495 L
F
1 0 1 r
.04 w
.21687 .20845 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCacheValid->False],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.49505 0.5 0.49505 [
[ 0 0 -0.125 0 ]
[ 0 0 -0.125 0 ]
[ 0 1 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
0 0 m
1 0 L
s
0 0 m
0 1 L
s
0 1 m
1 1 L
s
1 0 m
1 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
1 .5 0 r
.015 w
.03175 .1355 Mdot
.03435 .12523 Mdot
.11137 .12765 Mdot
.14107 .18841 Mdot
.16218 .24538 Mdot
.17294 .21053 Mdot
.18267 .18577 Mdot
.18434 .1304 Mdot
.18553 .30956 Mdot
.20401 .239 Mdot
.21247 .27571 Mdot
.21687 .20845 Mdot
.22376 .2799 Mdot
.22832 .27485 Mdot
.29063 .20974 Mdot
.29686 .25079 Mdot
.30487 .22936 Mdot
.30683 .34623 Mdot
.32055 .20902 Mdot
.32574 .21979 Mdot
.34472 .28521 Mdot
.35998 .36393 Mdot
.36335 .24976 Mdot
.3794 .36608 Mdot
.42386 .66992 Mdot
.44391 .74519 Mdot
.45059 .34198 Mdot
.47208 .67586 Mdot
.47436 .71381 Mdot
.49778 .59825 Mdot
.50874 .91643 Mdot
.51516 .76219 Mdot
.53655 .61374 Mdot
.56563 .75219 Mdot
.59189 .65665 Mdot
.59581 .61604 Mdot
.59923 .6556 Mdot
.60292 .68499 Mdot
.62656 .67779 Mdot
.63555 .72451 Mdot
.63919 .652 Mdot
.64169 .6004 Mdot
.64246 .58611 Mdot
.64496 .54267 Mdot
.64608 .77288 Mdot
.65077 .64308 Mdot
.66065 .57816 Mdot
.67474 .59169 Mdot
.69296 .563 Mdot
.72815 .65902 Mdot
.73169 .58879 Mdot
.74669 .61318 Mdot
.74821 .65474 Mdot
.75963 .63781 Mdot
.79673 .57809 Mdot
.80925 .55852 Mdot
.81525 .58444 Mdot
.83417 .62985 Mdot
.83598 .55526 Mdot
.91595 .49319 Mdot
1 0 0 r
.005 w
.00495 .28842 m
.00628 .29156 L
.01857 .31761 L
.03101 .33781 L
.03525 .34367 L
.05706 .36884 L
.05795 .36972 L
.08312 .39115 L
.08963 .39578 L
.10917 .40763 L
.13523 .41964 L
.14074 .42183 L
.16128 .42794 L
.18734 .43294 L
.21339 .43485 L
.23945 .43375 L
.2655 .42959 L
.29156 .42219 L
.29261 .42183 L
.31761 .41124 L
.34367 .39603 L
.34405 .39578 L
.36972 .37551 L
.37582 .36972 L
.39578 .34724 L
.39849 .34367 L
.41525 .31761 L
.42183 .30485 L
.4275 .29156 L
.436 .2655 L
.44117 .23945 L
.44325 .21339 L
.44232 .18734 L
.43834 .16128 L
.43114 .13523 L
.42183 .11212 L
.42037 .10917 L
.40546 .08312 L
.39578 .06961 L
.38528 .05706 L
.36972 .04137 L
.35758 .03101 L
.34367 .02092 L
.31761 .00569 L
.3162 .00495 L
s
.00495 .12854 m
.01344 .10917 L
.02832 .08312 L
.03101 .07912 L
.04848 .05706 L
.05706 .04802 L
.07619 .03101 L
.08312 .02579 L
.10917 .00934 L
.11742 .00495 L
s
0 0 1 r
.29156 .15739 m
.31761 .14824 L
.34367 .14249 L
.36972 .13986 L
.39578 .14025 L
.42183 .14366 L
.44789 .15025 L
.47394 .16034 L
.47599 .16128 L
.5 .17443 L
.51844 .18734 L
.52606 .19355 L
.54662 .21339 L
.55211 .21962 L
.56712 .23945 L
.57817 .25755 L
.58227 .2655 L
.59322 .29156 L
.60058 .31761 L
.60422 .3392 L
.60471 .34367 L
.6058 .36972 L
.60422 .39297 L
.60387 .39578 L
.59886 .42183 L
.59054 .44789 L
.57848 .47394 L
.57817 .47453 L
.562 .5 L
.55211 .51255 L
.53968 .52606 L
.52606 .53862 L
.50853 .55211 L
.5 .55773 L
.47394 .57183 L
.45901 .57817 L
.44789 .5819 L
.42183 .5885 L
.39578 .59192 L
.36972 .59231 L
.34367 .58968 L
.31761 .58392 L
.29972 .57817 L
.29156 .57477 L
.2655 .56178 L
.25025 .55211 L
.23945 .54409 L
.21914 .52606 L
.21339 .52008 L
.19681 .5 L
Mistroke
.18734 .48608 L
.18031 .47394 L
.16827 .44789 L
.16128 .42714 L
.15996 .42183 L
.15493 .39578 L
.153 .36972 L
.15409 .34367 L
.15823 .31761 L
.16128 .3045 L
.16559 .29156 L
.17653 .2655 L
.18734 .24609 L
.19169 .23945 L
.21221 .21339 L
.21339 .21211 L
.23945 .1881 L
.24041 .18734 L
.2655 .17038 L
.28271 .16128 L
.29156 .15739 L
Mfstroke
1 0 0 r
.03 w
.21687 .20845 Mdot
0 0 1 r
.3794 .36608 Mdot
1 0 0 r
.79703 .00495 m
.79703 .14462 L
.87129 .14462 L
.87129 .00495 L
F
0 0 1 r
.89604 .00495 m
.89604 .11281 L
.9703 .11281 L
.9703 .00495 L
F
1 0 1 r
.04 w
.22376 .2799 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCacheValid->False],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.49505 0.5 0.49505 [
[ 0 0 -0.125 0 ]
[ 0 0 -0.125 0 ]
[ 0 1 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
0 0 m
1 0 L
s
0 0 m
0 1 L
s
0 1 m
1 1 L
s
1 0 m
1 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
1 .5 0 r
.015 w
.03175 .1355 Mdot
.03435 .12523 Mdot
.11137 .12765 Mdot
.14107 .18841 Mdot
.16218 .24538 Mdot
.17294 .21053 Mdot
.18267 .18577 Mdot
.18434 .1304 Mdot
.18553 .30956 Mdot
.20401 .239 Mdot
.21247 .27571 Mdot
.21687 .20845 Mdot
.22376 .2799 Mdot
.22832 .27485 Mdot
.29063 .20974 Mdot
.29686 .25079 Mdot
.30487 .22936 Mdot
.30683 .34623 Mdot
.32055 .20902 Mdot
.32574 .21979 Mdot
.34472 .28521 Mdot
.35998 .36393 Mdot
.36335 .24976 Mdot
.3794 .36608 Mdot
.42386 .66992 Mdot
.44391 .74519 Mdot
.45059 .34198 Mdot
.47208 .67586 Mdot
.47436 .71381 Mdot
.49778 .59825 Mdot
.50874 .91643 Mdot
.51516 .76219 Mdot
.53655 .61374 Mdot
.56563 .75219 Mdot
.59189 .65665 Mdot
.59581 .61604 Mdot
.59923 .6556 Mdot
.60292 .68499 Mdot
.62656 .67779 Mdot
.63555 .72451 Mdot
.63919 .652 Mdot
.64169 .6004 Mdot
.64246 .58611 Mdot
.64496 .54267 Mdot
.64608 .77288 Mdot
.65077 .64308 Mdot
.66065 .57816 Mdot
.67474 .59169 Mdot
.69296 .563 Mdot
.72815 .65902 Mdot
.73169 .58879 Mdot
.74669 .61318 Mdot
.74821 .65474 Mdot
.75963 .63781 Mdot
.79673 .57809 Mdot
.80925 .55852 Mdot
.81525 .58444 Mdot
.83417 .62985 Mdot
.83598 .55526 Mdot
.91595 .49319 Mdot
1 0 0 r
.005 w
.00495 .28842 m
.00628 .29156 L
.01857 .31761 L
.03101 .33781 L
.03525 .34367 L
.05706 .36884 L
.05795 .36972 L
.08312 .39115 L
.08963 .39578 L
.10917 .40763 L
.13523 .41964 L
.14074 .42183 L
.16128 .42794 L
.18734 .43294 L
.21339 .43485 L
.23945 .43375 L
.2655 .42959 L
.29156 .42219 L
.29261 .42183 L
.31761 .41124 L
.34367 .39603 L
.34405 .39578 L
.36972 .37551 L
.37582 .36972 L
.39578 .34724 L
.39849 .34367 L
.41525 .31761 L
.42183 .30485 L
.4275 .29156 L
.436 .2655 L
.44117 .23945 L
.44325 .21339 L
.44232 .18734 L
.43834 .16128 L
.43114 .13523 L
.42183 .11212 L
.42037 .10917 L
.40546 .08312 L
.39578 .06961 L
.38528 .05706 L
.36972 .04137 L
.35758 .03101 L
.34367 .02092 L
.31761 .00569 L
.3162 .00495 L
s
.00495 .12854 m
.01344 .10917 L
.02832 .08312 L
.03101 .07912 L
.04848 .05706 L
.05706 .04802 L
.07619 .03101 L
.08312 .02579 L
.10917 .00934 L
.11742 .00495 L
s
0 0 1 r
.29156 .15739 m
.31761 .14824 L
.34367 .14249 L
.36972 .13986 L
.39578 .14025 L
.42183 .14366 L
.44789 .15025 L
.47394 .16034 L
.47599 .16128 L
.5 .17443 L
.51844 .18734 L
.52606 .19355 L
.54662 .21339 L
.55211 .21962 L
.56712 .23945 L
.57817 .25755 L
.58227 .2655 L
.59322 .29156 L
.60058 .31761 L
.60422 .3392 L
.60471 .34367 L
.6058 .36972 L
.60422 .39297 L
.60387 .39578 L
.59886 .42183 L
.59054 .44789 L
.57848 .47394 L
.57817 .47453 L
.562 .5 L
.55211 .51255 L
.53968 .52606 L
.52606 .53862 L
.50853 .55211 L
.5 .55773 L
.47394 .57183 L
.45901 .57817 L
.44789 .5819 L
.42183 .5885 L
.39578 .59192 L
.36972 .59231 L
.34367 .58968 L
.31761 .58392 L
.29972 .57817 L
.29156 .57477 L
.2655 .56178 L
.25025 .55211 L
.23945 .54409 L
.21914 .52606 L
.21339 .52008 L
.19681 .5 L
Mistroke
.18734 .48608 L
.18031 .47394 L
.16827 .44789 L
.16128 .42714 L
.15996 .42183 L
.15493 .39578 L
.153 .36972 L
.15409 .34367 L
.15823 .31761 L
.16128 .3045 L
.16559 .29156 L
.17653 .2655 L
.18734 .24609 L
.19169 .23945 L
.21221 .21339 L
.21339 .21211 L
.23945 .1881 L
.24041 .18734 L
.2655 .17038 L
.28271 .16128 L
.29156 .15739 L
Mfstroke
1 0 0 r
.03 w
.21687 .20845 Mdot
0 0 1 r
.3794 .36608 Mdot
1 0 0 r
.79703 .00495 m
.79703 .14468 L
.87129 .14468 L
.87129 .00495 L
F
0 0 1 r
.89604 .00495 m
.89604 .11274 L
.9703 .11274 L
.9703 .00495 L
F
1 0 1 r
.04 w
.22832 .27485 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCacheValid->False],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.49505 0.5 0.49505 [
[ 0 0 -0.125 0 ]
[ 0 0 -0.125 0 ]
[ 0 1 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
0 0 m
1 0 L
s
0 0 m
0 1 L
s
0 1 m
1 1 L
s
1 0 m
1 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
1 .5 0 r
.015 w
.03175 .1355 Mdot
.03435 .12523 Mdot
.11137 .12765 Mdot
.14107 .18841 Mdot
.16218 .24538 Mdot
.17294 .21053 Mdot
.18267 .18577 Mdot
.18434 .1304 Mdot
.18553 .30956 Mdot
.20401 .239 Mdot
.21247 .27571 Mdot
.21687 .20845 Mdot
.22376 .2799 Mdot
.22832 .27485 Mdot
.29063 .20974 Mdot
.29686 .25079 Mdot
.30487 .22936 Mdot
.30683 .34623 Mdot
.32055 .20902 Mdot
.32574 .21979 Mdot
.34472 .28521 Mdot
.35998 .36393 Mdot
.36335 .24976 Mdot
.3794 .36608 Mdot
.42386 .66992 Mdot
.44391 .74519 Mdot
.45059 .34198 Mdot
.47208 .67586 Mdot
.47436 .71381 Mdot
.49778 .59825 Mdot
.50874 .91643 Mdot
.51516 .76219 Mdot
.53655 .61374 Mdot
.56563 .75219 Mdot
.59189 .65665 Mdot
.59581 .61604 Mdot
.59923 .6556 Mdot
.60292 .68499 Mdot
.62656 .67779 Mdot
.63555 .72451 Mdot
.63919 .652 Mdot
.64169 .6004 Mdot
.64246 .58611 Mdot
.64496 .54267 Mdot
.64608 .77288 Mdot
.65077 .64308 Mdot
.66065 .57816 Mdot
.67474 .59169 Mdot
.69296 .563 Mdot
.72815 .65902 Mdot
.73169 .58879 Mdot
.74669 .61318 Mdot
.74821 .65474 Mdot
.75963 .63781 Mdot
.79673 .57809 Mdot
.80925 .55852 Mdot
.81525 .58444 Mdot
.83417 .62985 Mdot
.83598 .55526 Mdot
.91595 .49319 Mdot
1 0 0 r
.005 w
.00495 .28842 m
.00628 .29156 L
.01857 .31761 L
.03101 .33781 L
.03525 .34367 L
.05706 .36884 L
.05795 .36972 L
.08312 .39115 L
.08963 .39578 L
.10917 .40763 L
.13523 .41964 L
.14074 .42183 L
.16128 .42794 L
.18734 .43294 L
.21339 .43485 L
.23945 .43375 L
.2655 .42959 L
.29156 .42219 L
.29261 .42183 L
.31761 .41124 L
.34367 .39603 L
.34405 .39578 L
.36972 .37551 L
.37582 .36972 L
.39578 .34724 L
.39849 .34367 L
.41525 .31761 L
.42183 .30485 L
.4275 .29156 L
.436 .2655 L
.44117 .23945 L
.44325 .21339 L
.44232 .18734 L
.43834 .16128 L
.43114 .13523 L
.42183 .11212 L
.42037 .10917 L
.40546 .08312 L
.39578 .06961 L
.38528 .05706 L
.36972 .04137 L
.35758 .03101 L
.34367 .02092 L
.31761 .00569 L
.3162 .00495 L
s
.00495 .12854 m
.01344 .10917 L
.02832 .08312 L
.03101 .07912 L
.04848 .05706 L
.05706 .04802 L
.07619 .03101 L
.08312 .02579 L
.10917 .00934 L
.11742 .00495 L
s
0 0 1 r
.29156 .15739 m
.31761 .14824 L
.34367 .14249 L
.36972 .13986 L
.39578 .14025 L
.42183 .14366 L
.44789 .15025 L
.47394 .16034 L
.47599 .16128 L
.5 .17443 L
.51844 .18734 L
.52606 .19355 L
.54662 .21339 L
.55211 .21962 L
.56712 .23945 L
.57817 .25755 L
.58227 .2655 L
.59322 .29156 L
.60058 .31761 L
.60422 .3392 L
.60471 .34367 L
.6058 .36972 L
.60422 .39297 L
.60387 .39578 L
.59886 .42183 L
.59054 .44789 L
.57848 .47394 L
.57817 .47453 L
.562 .5 L
.55211 .51255 L
.53968 .52606 L
.52606 .53862 L
.50853 .55211 L
.5 .55773 L
.47394 .57183 L
.45901 .57817 L
.44789 .5819 L
.42183 .5885 L
.39578 .59192 L
.36972 .59231 L
.34367 .58968 L
.31761 .58392 L
.29972 .57817 L
.29156 .57477 L
.2655 .56178 L
.25025 .55211 L
.23945 .54409 L
.21914 .52606 L
.21339 .52008 L
.19681 .5 L
Mistroke
.18734 .48608 L
.18031 .47394 L
.16827 .44789 L
.16128 .42714 L
.15996 .42183 L
.15493 .39578 L
.153 .36972 L
.15409 .34367 L
.15823 .31761 L
.16128 .3045 L
.16559 .29156 L
.17653 .2655 L
.18734 .24609 L
.19169 .23945 L
.21221 .21339 L
.21339 .21211 L
.23945 .1881 L
.24041 .18734 L
.2655 .17038 L
.28271 .16128 L
.29156 .15739 L
Mfstroke
1 0 0 r
.03 w
.21687 .20845 Mdot
0 0 1 r
.3794 .36608 Mdot
1 0 0 r
.79703 .00495 m
.79703 .14485 L
.87129 .14485 L
.87129 .00495 L
F
0 0 1 r
.89604 .00495 m
.89604 .11258 L
.9703 .11258 L
.9703 .00495 L
F
1 0 1 r
.04 w
.29063 .20974 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCacheValid->False],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.49505 0.5 0.49505 [
[ 0 0 -0.125 0 ]
[ 0 0 -0.125 0 ]
[ 0 1 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
0 0 m
1 0 L
s
0 0 m
0 1 L
s
0 1 m
1 1 L
s
1 0 m
1 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
1 .5 0 r
.015 w
.03175 .1355 Mdot
.03435 .12523 Mdot
.11137 .12765 Mdot
.14107 .18841 Mdot
.16218 .24538 Mdot
.17294 .21053 Mdot
.18267 .18577 Mdot
.18434 .1304 Mdot
.18553 .30956 Mdot
.20401 .239 Mdot
.21247 .27571 Mdot
.21687 .20845 Mdot
.22376 .2799 Mdot
.22832 .27485 Mdot
.29063 .20974 Mdot
.29686 .25079 Mdot
.30487 .22936 Mdot
.30683 .34623 Mdot
.32055 .20902 Mdot
.32574 .21979 Mdot
.34472 .28521 Mdot
.35998 .36393 Mdot
.36335 .24976 Mdot
.3794 .36608 Mdot
.42386 .66992 Mdot
.44391 .74519 Mdot
.45059 .34198 Mdot
.47208 .67586 Mdot
.47436 .71381 Mdot
.49778 .59825 Mdot
.50874 .91643 Mdot
.51516 .76219 Mdot
.53655 .61374 Mdot
.56563 .75219 Mdot
.59189 .65665 Mdot
.59581 .61604 Mdot
.59923 .6556 Mdot
.60292 .68499 Mdot
.62656 .67779 Mdot
.63555 .72451 Mdot
.63919 .652 Mdot
.64169 .6004 Mdot
.64246 .58611 Mdot
.64496 .54267 Mdot
.64608 .77288 Mdot
.65077 .64308 Mdot
.66065 .57816 Mdot
.67474 .59169 Mdot
.69296 .563 Mdot
.72815 .65902 Mdot
.73169 .58879 Mdot
.74669 .61318 Mdot
.74821 .65474 Mdot
.75963 .63781 Mdot
.79673 .57809 Mdot
.80925 .55852 Mdot
.81525 .58444 Mdot
.83417 .62985 Mdot
.83598 .55526 Mdot
.91595 .49319 Mdot
1 0 0 r
.005 w
.00495 .28842 m
.00628 .29156 L
.01857 .31761 L
.03101 .33781 L
.03525 .34367 L
.05706 .36884 L
.05795 .36972 L
.08312 .39115 L
.08963 .39578 L
.10917 .40763 L
.13523 .41964 L
.14074 .42183 L
.16128 .42794 L
.18734 .43294 L
.21339 .43485 L
.23945 .43375 L
.2655 .42959 L
.29156 .42219 L
.29261 .42183 L
.31761 .41124 L
.34367 .39603 L
.34405 .39578 L
.36972 .37551 L
.37582 .36972 L
.39578 .34724 L
.39849 .34367 L
.41525 .31761 L
.42183 .30485 L
.4275 .29156 L
.436 .2655 L
.44117 .23945 L
.44325 .21339 L
.44232 .18734 L
.43834 .16128 L
.43114 .13523 L
.42183 .11212 L
.42037 .10917 L
.40546 .08312 L
.39578 .06961 L
.38528 .05706 L
.36972 .04137 L
.35758 .03101 L
.34367 .02092 L
.31761 .00569 L
.3162 .00495 L
s
.00495 .12854 m
.01344 .10917 L
.02832 .08312 L
.03101 .07912 L
.04848 .05706 L
.05706 .04802 L
.07619 .03101 L
.08312 .02579 L
.10917 .00934 L
.11742 .00495 L
s
0 0 1 r
.29156 .15739 m
.31761 .14824 L
.34367 .14249 L
.36972 .13986 L
.39578 .14025 L
.42183 .14366 L
.44789 .15025 L
.47394 .16034 L
.47599 .16128 L
.5 .17443 L
.51844 .18734 L
.52606 .19355 L
.54662 .21339 L
.55211 .21962 L
.56712 .23945 L
.57817 .25755 L
.58227 .2655 L
.59322 .29156 L
.60058 .31761 L
.60422 .3392 L
.60471 .34367 L
.6058 .36972 L
.60422 .39297 L
.60387 .39578 L
.59886 .42183 L
.59054 .44789 L
.57848 .47394 L
.57817 .47453 L
.562 .5 L
.55211 .51255 L
.53968 .52606 L
.52606 .53862 L
.50853 .55211 L
.5 .55773 L
.47394 .57183 L
.45901 .57817 L
.44789 .5819 L
.42183 .5885 L
.39578 .59192 L
.36972 .59231 L
.34367 .58968 L
.31761 .58392 L
.29972 .57817 L
.29156 .57477 L
.2655 .56178 L
.25025 .55211 L
.23945 .54409 L
.21914 .52606 L
.21339 .52008 L
.19681 .5 L
Mistroke
.18734 .48608 L
.18031 .47394 L
.16827 .44789 L
.16128 .42714 L
.15996 .42183 L
.15493 .39578 L
.153 .36972 L
.15409 .34367 L
.15823 .31761 L
.16128 .3045 L
.16559 .29156 L
.17653 .2655 L
.18734 .24609 L
.19169 .23945 L
.21221 .21339 L
.21339 .21211 L
.23945 .1881 L
.24041 .18734 L
.2655 .17038 L
.28271 .16128 L
.29156 .15739 L
Mfstroke
1 0 0 r
.03 w
.21687 .20845 Mdot
0 0 1 r
.3794 .36608 Mdot
1 0 0 r
.79703 .00495 m
.79703 .13589 L
.87129 .13589 L
.87129 .00495 L
F
0 0 1 r
.89604 .00495 m
.89604 .12153 L
.9703 .12153 L
.9703 .00495 L
F
1 0 1 r
.04 w
.29686 .25079 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCacheValid->False],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.49505 0.5 0.49505 [
[ 0 0 -0.125 0 ]
[ 0 0 -0.125 0 ]
[ 0 1 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
0 0 m
1 0 L
s
0 0 m
0 1 L
s
0 1 m
1 1 L
s
1 0 m
1 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
1 .5 0 r
.015 w
.03175 .1355 Mdot
.03435 .12523 Mdot
.11137 .12765 Mdot
.14107 .18841 Mdot
.16218 .24538 Mdot
.17294 .21053 Mdot
.18267 .18577 Mdot
.18434 .1304 Mdot
.18553 .30956 Mdot
.20401 .239 Mdot
.21247 .27571 Mdot
.21687 .20845 Mdot
.22376 .2799 Mdot
.22832 .27485 Mdot
.29063 .20974 Mdot
.29686 .25079 Mdot
.30487 .22936 Mdot
.30683 .34623 Mdot
.32055 .20902 Mdot
.32574 .21979 Mdot
.34472 .28521 Mdot
.35998 .36393 Mdot
.36335 .24976 Mdot
.3794 .36608 Mdot
.42386 .66992 Mdot
.44391 .74519 Mdot
.45059 .34198 Mdot
.47208 .67586 Mdot
.47436 .71381 Mdot
.49778 .59825 Mdot
.50874 .91643 Mdot
.51516 .76219 Mdot
.53655 .61374 Mdot
.56563 .75219 Mdot
.59189 .65665 Mdot
.59581 .61604 Mdot
.59923 .6556 Mdot
.60292 .68499 Mdot
.62656 .67779 Mdot
.63555 .72451 Mdot
.63919 .652 Mdot
.64169 .6004 Mdot
.64246 .58611 Mdot
.64496 .54267 Mdot
.64608 .77288 Mdot
.65077 .64308 Mdot
.66065 .57816 Mdot
.67474 .59169 Mdot
.69296 .563 Mdot
.72815 .65902 Mdot
.73169 .58879 Mdot
.74669 .61318 Mdot
.74821 .65474 Mdot
.75963 .63781 Mdot
.79673 .57809 Mdot
.80925 .55852 Mdot
.81525 .58444 Mdot
.83417 .62985 Mdot
.83598 .55526 Mdot
.91595 .49319 Mdot
1 0 0 r
.005 w
.00495 .28842 m
.00628 .29156 L
.01857 .31761 L
.03101 .33781 L
.03525 .34367 L
.05706 .36884 L
.05795 .36972 L
.08312 .39115 L
.08963 .39578 L
.10917 .40763 L
.13523 .41964 L
.14074 .42183 L
.16128 .42794 L
.18734 .43294 L
.21339 .43485 L
.23945 .43375 L
.2655 .42959 L
.29156 .42219 L
.29261 .42183 L
.31761 .41124 L
.34367 .39603 L
.34405 .39578 L
.36972 .37551 L
.37582 .36972 L
.39578 .34724 L
.39849 .34367 L
.41525 .31761 L
.42183 .30485 L
.4275 .29156 L
.436 .2655 L
.44117 .23945 L
.44325 .21339 L
.44232 .18734 L
.43834 .16128 L
.43114 .13523 L
.42183 .11212 L
.42037 .10917 L
.40546 .08312 L
.39578 .06961 L
.38528 .05706 L
.36972 .04137 L
.35758 .03101 L
.34367 .02092 L
.31761 .00569 L
.3162 .00495 L
s
.00495 .12854 m
.01344 .10917 L
.02832 .08312 L
.03101 .07912 L
.04848 .05706 L
.05706 .04802 L
.07619 .03101 L
.08312 .02579 L
.10917 .00934 L
.11742 .00495 L
s
0 0 1 r
.29156 .15739 m
.31761 .14824 L
.34367 .14249 L
.36972 .13986 L
.39578 .14025 L
.42183 .14366 L
.44789 .15025 L
.47394 .16034 L
.47599 .16128 L
.5 .17443 L
.51844 .18734 L
.52606 .19355 L
.54662 .21339 L
.55211 .21962 L
.56712 .23945 L
.57817 .25755 L
.58227 .2655 L
.59322 .29156 L
.60058 .31761 L
.60422 .3392 L
.60471 .34367 L
.6058 .36972 L
.60422 .39297 L
.60387 .39578 L
.59886 .42183 L
.59054 .44789 L
.57848 .47394 L
.57817 .47453 L
.562 .5 L
.55211 .51255 L
.53968 .52606 L
.52606 .53862 L
.50853 .55211 L
.5 .55773 L
.47394 .57183 L
.45901 .57817 L
.44789 .5819 L
.42183 .5885 L
.39578 .59192 L
.36972 .59231 L
.34367 .58968 L
.31761 .58392 L
.29972 .57817 L
.29156 .57477 L
.2655 .56178 L
.25025 .55211 L
.23945 .54409 L
.21914 .52606 L
.21339 .52008 L
.19681 .5 L
Mistroke
.18734 .48608 L
.18031 .47394 L
.16827 .44789 L
.16128 .42714 L
.15996 .42183 L
.15493 .39578 L
.153 .36972 L
.15409 .34367 L
.15823 .31761 L
.16128 .3045 L
.16559 .29156 L
.17653 .2655 L
.18734 .24609 L
.19169 .23945 L
.21221 .21339 L
.21339 .21211 L
.23945 .1881 L
.24041 .18734 L
.2655 .17038 L
.28271 .16128 L
.29156 .15739 L
Mfstroke
1 0 0 r
.03 w
.21687 .20845 Mdot
0 0 1 r
.3794 .36608 Mdot
1 0 0 r
.79703 .00495 m
.79703 .13839 L
.87129 .13839 L
.87129 .00495 L
F
0 0 1 r
.89604 .00495 m
.89604 .11903 L
.9703 .11903 L
.9703 .00495 L
F
1 0 1 r
.04 w
.30487 .22936 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCacheValid->False],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.49505 0.5 0.49505 [
[ 0 0 -0.125 0 ]
[ 0 0 -0.125 0 ]
[ 0 1 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
0 0 m
1 0 L
s
0 0 m
0 1 L
s
0 1 m
1 1 L
s
1 0 m
1 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
1 .5 0 r
.015 w
.03175 .1355 Mdot
.03435 .12523 Mdot
.11137 .12765 Mdot
.14107 .18841 Mdot
.16218 .24538 Mdot
.17294 .21053 Mdot
.18267 .18577 Mdot
.18434 .1304 Mdot
.18553 .30956 Mdot
.20401 .239 Mdot
.21247 .27571 Mdot
.21687 .20845 Mdot
.22376 .2799 Mdot
.22832 .27485 Mdot
.29063 .20974 Mdot
.29686 .25079 Mdot
.30487 .22936 Mdot
.30683 .34623 Mdot
.32055 .20902 Mdot
.32574 .21979 Mdot
.34472 .28521 Mdot
.35998 .36393 Mdot
.36335 .24976 Mdot
.3794 .36608 Mdot
.42386 .66992 Mdot
.44391 .74519 Mdot
.45059 .34198 Mdot
.47208 .67586 Mdot
.47436 .71381 Mdot
.49778 .59825 Mdot
.50874 .91643 Mdot
.51516 .76219 Mdot
.53655 .61374 Mdot
.56563 .75219 Mdot
.59189 .65665 Mdot
.59581 .61604 Mdot
.59923 .6556 Mdot
.60292 .68499 Mdot
.62656 .67779 Mdot
.63555 .72451 Mdot
.63919 .652 Mdot
.64169 .6004 Mdot
.64246 .58611 Mdot
.64496 .54267 Mdot
.64608 .77288 Mdot
.65077 .64308 Mdot
.66065 .57816 Mdot
.67474 .59169 Mdot
.69296 .563 Mdot
.72815 .65902 Mdot
.73169 .58879 Mdot
.74669 .61318 Mdot
.74821 .65474 Mdot
.75963 .63781 Mdot
.79673 .57809 Mdot
.80925 .55852 Mdot
.81525 .58444 Mdot
.83417 .62985 Mdot
.83598 .55526 Mdot
.91595 .49319 Mdot
1 0 0 r
.005 w
.00495 .28842 m
.00628 .29156 L
.01857 .31761 L
.03101 .33781 L
.03525 .34367 L
.05706 .36884 L
.05795 .36972 L
.08312 .39115 L
.08963 .39578 L
.10917 .40763 L
.13523 .41964 L
.14074 .42183 L
.16128 .42794 L
.18734 .43294 L
.21339 .43485 L
.23945 .43375 L
.2655 .42959 L
.29156 .42219 L
.29261 .42183 L
.31761 .41124 L
.34367 .39603 L
.34405 .39578 L
.36972 .37551 L
.37582 .36972 L
.39578 .34724 L
.39849 .34367 L
.41525 .31761 L
.42183 .30485 L
.4275 .29156 L
.436 .2655 L
.44117 .23945 L
.44325 .21339 L
.44232 .18734 L
.43834 .16128 L
.43114 .13523 L
.42183 .11212 L
.42037 .10917 L
.40546 .08312 L
.39578 .06961 L
.38528 .05706 L
.36972 .04137 L
.35758 .03101 L
.34367 .02092 L
.31761 .00569 L
.3162 .00495 L
s
.00495 .12854 m
.01344 .10917 L
.02832 .08312 L
.03101 .07912 L
.04848 .05706 L
.05706 .04802 L
.07619 .03101 L
.08312 .02579 L
.10917 .00934 L
.11742 .00495 L
s
0 0 1 r
.29156 .15739 m
.31761 .14824 L
.34367 .14249 L
.36972 .13986 L
.39578 .14025 L
.42183 .14366 L
.44789 .15025 L
.47394 .16034 L
.47599 .16128 L
.5 .17443 L
.51844 .18734 L
.52606 .19355 L
.54662 .21339 L
.55211 .21962 L
.56712 .23945 L
.57817 .25755 L
.58227 .2655 L
.59322 .29156 L
.60058 .31761 L
.60422 .3392 L
.60471 .34367 L
.6058 .36972 L
.60422 .39297 L
.60387 .39578 L
.59886 .42183 L
.59054 .44789 L
.57848 .47394 L
.57817 .47453 L
.562 .5 L
.55211 .51255 L
.53968 .52606 L
.52606 .53862 L
.50853 .55211 L
.5 .55773 L
.47394 .57183 L
.45901 .57817 L
.44789 .5819 L
.42183 .5885 L
.39578 .59192 L
.36972 .59231 L
.34367 .58968 L
.31761 .58392 L
.29972 .57817 L
.29156 .57477 L
.2655 .56178 L
.25025 .55211 L
.23945 .54409 L
.21914 .52606 L
.21339 .52008 L
.19681 .5 L
Mistroke
.18734 .48608 L
.18031 .47394 L
.16827 .44789 L
.16128 .42714 L
.15996 .42183 L
.15493 .39578 L
.153 .36972 L
.15409 .34367 L
.15823 .31761 L
.16128 .3045 L
.16559 .29156 L
.17653 .2655 L
.18734 .24609 L
.19169 .23945 L
.21221 .21339 L
.21339 .21211 L
.23945 .1881 L
.24041 .18734 L
.2655 .17038 L
.28271 .16128 L
.29156 .15739 L
Mfstroke
1 0 0 r
.03 w
.21687 .20845 Mdot
0 0 1 r
.3794 .36608 Mdot
1 0 0 r
.79703 .00495 m
.79703 .11583 L
.87129 .11583 L
.87129 .00495 L
F
0 0 1 r
.89604 .00495 m
.89604 .14159 L
.9703 .14159 L
.9703 .00495 L
F
1 0 1 r
.04 w
.30683 .34623 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCacheValid->False],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.49505 0.5 0.49505 [
[ 0 0 -0.125 0 ]
[ 0 0 -0.125 0 ]
[ 0 1 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
0 0 m
1 0 L
s
0 0 m
0 1 L
s
0 1 m
1 1 L
s
1 0 m
1 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
1 .5 0 r
.015 w
.03175 .1355 Mdot
.03435 .12523 Mdot
.11137 .12765 Mdot
.14107 .18841 Mdot
.16218 .24538 Mdot
.17294 .21053 Mdot
.18267 .18577 Mdot
.18434 .1304 Mdot
.18553 .30956 Mdot
.20401 .239 Mdot
.21247 .27571 Mdot
.21687 .20845 Mdot
.22376 .2799 Mdot
.22832 .27485 Mdot
.29063 .20974 Mdot
.29686 .25079 Mdot
.30487 .22936 Mdot
.30683 .34623 Mdot
.32055 .20902 Mdot
.32574 .21979 Mdot
.34472 .28521 Mdot
.35998 .36393 Mdot
.36335 .24976 Mdot
.3794 .36608 Mdot
.42386 .66992 Mdot
.44391 .74519 Mdot
.45059 .34198 Mdot
.47208 .67586 Mdot
.47436 .71381 Mdot
.49778 .59825 Mdot
.50874 .91643 Mdot
.51516 .76219 Mdot
.53655 .61374 Mdot
.56563 .75219 Mdot
.59189 .65665 Mdot
.59581 .61604 Mdot
.59923 .6556 Mdot
.60292 .68499 Mdot
.62656 .67779 Mdot
.63555 .72451 Mdot
.63919 .652 Mdot
.64169 .6004 Mdot
.64246 .58611 Mdot
.64496 .54267 Mdot
.64608 .77288 Mdot
.65077 .64308 Mdot
.66065 .57816 Mdot
.67474 .59169 Mdot
.69296 .563 Mdot
.72815 .65902 Mdot
.73169 .58879 Mdot
.74669 .61318 Mdot
.74821 .65474 Mdot
.75963 .63781 Mdot
.79673 .57809 Mdot
.80925 .55852 Mdot
.81525 .58444 Mdot
.83417 .62985 Mdot
.83598 .55526 Mdot
.91595 .49319 Mdot
1 0 0 r
.005 w
.00495 .28842 m
.00628 .29156 L
.01857 .31761 L
.03101 .33781 L
.03525 .34367 L
.05706 .36884 L
.05795 .36972 L
.08312 .39115 L
.08963 .39578 L
.10917 .40763 L
.13523 .41964 L
.14074 .42183 L
.16128 .42794 L
.18734 .43294 L
.21339 .43485 L
.23945 .43375 L
.2655 .42959 L
.29156 .42219 L
.29261 .42183 L
.31761 .41124 L
.34367 .39603 L
.34405 .39578 L
.36972 .37551 L
.37582 .36972 L
.39578 .34724 L
.39849 .34367 L
.41525 .31761 L
.42183 .30485 L
.4275 .29156 L
.436 .2655 L
.44117 .23945 L
.44325 .21339 L
.44232 .18734 L
.43834 .16128 L
.43114 .13523 L
.42183 .11212 L
.42037 .10917 L
.40546 .08312 L
.39578 .06961 L
.38528 .05706 L
.36972 .04137 L
.35758 .03101 L
.34367 .02092 L
.31761 .00569 L
.3162 .00495 L
s
.00495 .12854 m
.01344 .10917 L
.02832 .08312 L
.03101 .07912 L
.04848 .05706 L
.05706 .04802 L
.07619 .03101 L
.08312 .02579 L
.10917 .00934 L
.11742 .00495 L
s
0 0 1 r
.29156 .15739 m
.31761 .14824 L
.34367 .14249 L
.36972 .13986 L
.39578 .14025 L
.42183 .14366 L
.44789 .15025 L
.47394 .16034 L
.47599 .16128 L
.5 .17443 L
.51844 .18734 L
.52606 .19355 L
.54662 .21339 L
.55211 .21962 L
.56712 .23945 L
.57817 .25755 L
.58227 .2655 L
.59322 .29156 L
.60058 .31761 L
.60422 .3392 L
.60471 .34367 L
.6058 .36972 L
.60422 .39297 L
.60387 .39578 L
.59886 .42183 L
.59054 .44789 L
.57848 .47394 L
.57817 .47453 L
.562 .5 L
.55211 .51255 L
.53968 .52606 L
.52606 .53862 L
.50853 .55211 L
.5 .55773 L
.47394 .57183 L
.45901 .57817 L
.44789 .5819 L
.42183 .5885 L
.39578 .59192 L
.36972 .59231 L
.34367 .58968 L
.31761 .58392 L
.29972 .57817 L
.29156 .57477 L
.2655 .56178 L
.25025 .55211 L
.23945 .54409 L
.21914 .52606 L
.21339 .52008 L
.19681 .5 L
Mistroke
.18734 .48608 L
.18031 .47394 L
.16827 .44789 L
.16128 .42714 L
.15996 .42183 L
.15493 .39578 L
.153 .36972 L
.15409 .34367 L
.15823 .31761 L
.16128 .3045 L
.16559 .29156 L
.17653 .2655 L
.18734 .24609 L
.19169 .23945 L
.21221 .21339 L
.21339 .21211 L
.23945 .1881 L
.24041 .18734 L
.2655 .17038 L
.28271 .16128 L
.29156 .15739 L
Mfstroke
1 0 0 r
.03 w
.21687 .20845 Mdot
0 0 1 r
.3794 .36608 Mdot
1 0 0 r
.79703 .00495 m
.79703 .13918 L
.87129 .13918 L
.87129 .00495 L
F
0 0 1 r
.89604 .00495 m
.89604 .11825 L
.9703 .11825 L
.9703 .00495 L
F
1 0 1 r
.04 w
.32055 .20902 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCacheValid->False],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.49505 0.5 0.49505 [
[ 0 0 -0.125 0 ]
[ 0 0 -0.125 0 ]
[ 0 1 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
0 0 m
1 0 L
s
0 0 m
0 1 L
s
0 1 m
1 1 L
s
1 0 m
1 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
1 .5 0 r
.015 w
.03175 .1355 Mdot
.03435 .12523 Mdot
.11137 .12765 Mdot
.14107 .18841 Mdot
.16218 .24538 Mdot
.17294 .21053 Mdot
.18267 .18577 Mdot
.18434 .1304 Mdot
.18553 .30956 Mdot
.20401 .239 Mdot
.21247 .27571 Mdot
.21687 .20845 Mdot
.22376 .2799 Mdot
.22832 .27485 Mdot
.29063 .20974 Mdot
.29686 .25079 Mdot
.30487 .22936 Mdot
.30683 .34623 Mdot
.32055 .20902 Mdot
.32574 .21979 Mdot
.34472 .28521 Mdot
.35998 .36393 Mdot
.36335 .24976 Mdot
.3794 .36608 Mdot
.42386 .66992 Mdot
.44391 .74519 Mdot
.45059 .34198 Mdot
.47208 .67586 Mdot
.47436 .71381 Mdot
.49778 .59825 Mdot
.50874 .91643 Mdot
.51516 .76219 Mdot
.53655 .61374 Mdot
.56563 .75219 Mdot
.59189 .65665 Mdot
.59581 .61604 Mdot
.59923 .6556 Mdot
.60292 .68499 Mdot
.62656 .67779 Mdot
.63555 .72451 Mdot
.63919 .652 Mdot
.64169 .6004 Mdot
.64246 .58611 Mdot
.64496 .54267 Mdot
.64608 .77288 Mdot
.65077 .64308 Mdot
.66065 .57816 Mdot
.67474 .59169 Mdot
.69296 .563 Mdot
.72815 .65902 Mdot
.73169 .58879 Mdot
.74669 .61318 Mdot
.74821 .65474 Mdot
.75963 .63781 Mdot
.79673 .57809 Mdot
.80925 .55852 Mdot
.81525 .58444 Mdot
.83417 .62985 Mdot
.83598 .55526 Mdot
.91595 .49319 Mdot
1 0 0 r
.005 w
.00495 .28842 m
.00628 .29156 L
.01857 .31761 L
.03101 .33781 L
.03525 .34367 L
.05706 .36884 L
.05795 .36972 L
.08312 .39115 L
.08963 .39578 L
.10917 .40763 L
.13523 .41964 L
.14074 .42183 L
.16128 .42794 L
.18734 .43294 L
.21339 .43485 L
.23945 .43375 L
.2655 .42959 L
.29156 .42219 L
.29261 .42183 L
.31761 .41124 L
.34367 .39603 L
.34405 .39578 L
.36972 .37551 L
.37582 .36972 L
.39578 .34724 L
.39849 .34367 L
.41525 .31761 L
.42183 .30485 L
.4275 .29156 L
.436 .2655 L
.44117 .23945 L
.44325 .21339 L
.44232 .18734 L
.43834 .16128 L
.43114 .13523 L
.42183 .11212 L
.42037 .10917 L
.40546 .08312 L
.39578 .06961 L
.38528 .05706 L
.36972 .04137 L
.35758 .03101 L
.34367 .02092 L
.31761 .00569 L
.3162 .00495 L
s
.00495 .12854 m
.01344 .10917 L
.02832 .08312 L
.03101 .07912 L
.04848 .05706 L
.05706 .04802 L
.07619 .03101 L
.08312 .02579 L
.10917 .00934 L
.11742 .00495 L
s
0 0 1 r
.29156 .15739 m
.31761 .14824 L
.34367 .14249 L
.36972 .13986 L
.39578 .14025 L
.42183 .14366 L
.44789 .15025 L
.47394 .16034 L
.47599 .16128 L
.5 .17443 L
.51844 .18734 L
.52606 .19355 L
.54662 .21339 L
.55211 .21962 L
.56712 .23945 L
.57817 .25755 L
.58227 .2655 L
.59322 .29156 L
.60058 .31761 L
.60422 .3392 L
.60471 .34367 L
.6058 .36972 L
.60422 .39297 L
.60387 .39578 L
.59886 .42183 L
.59054 .44789 L
.57848 .47394 L
.57817 .47453 L
.562 .5 L
.55211 .51255 L
.53968 .52606 L
.52606 .53862 L
.50853 .55211 L
.5 .55773 L
.47394 .57183 L
.45901 .57817 L
.44789 .5819 L
.42183 .5885 L
.39578 .59192 L
.36972 .59231 L
.34367 .58968 L
.31761 .58392 L
.29972 .57817 L
.29156 .57477 L
.2655 .56178 L
.25025 .55211 L
.23945 .54409 L
.21914 .52606 L
.21339 .52008 L
.19681 .5 L
Mistroke
.18734 .48608 L
.18031 .47394 L
.16827 .44789 L
.16128 .42714 L
.15996 .42183 L
.15493 .39578 L
.153 .36972 L
.15409 .34367 L
.15823 .31761 L
.16128 .3045 L
.16559 .29156 L
.17653 .2655 L
.18734 .24609 L
.19169 .23945 L
.21221 .21339 L
.21339 .21211 L
.23945 .1881 L
.24041 .18734 L
.2655 .17038 L
.28271 .16128 L
.29156 .15739 L
Mfstroke
1 0 0 r
.03 w
.21687 .20845 Mdot
0 0 1 r
.3794 .36608 Mdot
1 0 0 r
.79703 .00495 m
.79703 .13613 L
.87129 .13613 L
.87129 .00495 L
F
0 0 1 r
.89604 .00495 m
.89604 .1213 L
.9703 .1213 L
.9703 .00495 L
F
1 0 1 r
.04 w
.32574 .21979 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCacheValid->False],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.49505 0.5 0.49505 [
[ 0 0 -0.125 0 ]
[ 0 0 -0.125 0 ]
[ 0 1 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
0 0 m
1 0 L
s
0 0 m
0 1 L
s
0 1 m
1 1 L
s
1 0 m
1 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
1 .5 0 r
.015 w
.03175 .1355 Mdot
.03435 .12523 Mdot
.11137 .12765 Mdot
.14107 .18841 Mdot
.16218 .24538 Mdot
.17294 .21053 Mdot
.18267 .18577 Mdot
.18434 .1304 Mdot
.18553 .30956 Mdot
.20401 .239 Mdot
.21247 .27571 Mdot
.21687 .20845 Mdot
.22376 .2799 Mdot
.22832 .27485 Mdot
.29063 .20974 Mdot
.29686 .25079 Mdot
.30487 .22936 Mdot
.30683 .34623 Mdot
.32055 .20902 Mdot
.32574 .21979 Mdot
.34472 .28521 Mdot
.35998 .36393 Mdot
.36335 .24976 Mdot
.3794 .36608 Mdot
.42386 .66992 Mdot
.44391 .74519 Mdot
.45059 .34198 Mdot
.47208 .67586 Mdot
.47436 .71381 Mdot
.49778 .59825 Mdot
.50874 .91643 Mdot
.51516 .76219 Mdot
.53655 .61374 Mdot
.56563 .75219 Mdot
.59189 .65665 Mdot
.59581 .61604 Mdot
.59923 .6556 Mdot
.60292 .68499 Mdot
.62656 .67779 Mdot
.63555 .72451 Mdot
.63919 .652 Mdot
.64169 .6004 Mdot
.64246 .58611 Mdot
.64496 .54267 Mdot
.64608 .77288 Mdot
.65077 .64308 Mdot
.66065 .57816 Mdot
.67474 .59169 Mdot
.69296 .563 Mdot
.72815 .65902 Mdot
.73169 .58879 Mdot
.74669 .61318 Mdot
.74821 .65474 Mdot
.75963 .63781 Mdot
.79673 .57809 Mdot
.80925 .55852 Mdot
.81525 .58444 Mdot
.83417 .62985 Mdot
.83598 .55526 Mdot
.91595 .49319 Mdot
1 0 0 r
.005 w
.00495 .28842 m
.00628 .29156 L
.01857 .31761 L
.03101 .33781 L
.03525 .34367 L
.05706 .36884 L
.05795 .36972 L
.08312 .39115 L
.08963 .39578 L
.10917 .40763 L
.13523 .41964 L
.14074 .42183 L
.16128 .42794 L
.18734 .43294 L
.21339 .43485 L
.23945 .43375 L
.2655 .42959 L
.29156 .42219 L
.29261 .42183 L
.31761 .41124 L
.34367 .39603 L
.34405 .39578 L
.36972 .37551 L
.37582 .36972 L
.39578 .34724 L
.39849 .34367 L
.41525 .31761 L
.42183 .30485 L
.4275 .29156 L
.436 .2655 L
.44117 .23945 L
.44325 .21339 L
.44232 .18734 L
.43834 .16128 L
.43114 .13523 L
.42183 .11212 L
.42037 .10917 L
.40546 .08312 L
.39578 .06961 L
.38528 .05706 L
.36972 .04137 L
.35758 .03101 L
.34367 .02092 L
.31761 .00569 L
.3162 .00495 L
s
.00495 .12854 m
.01344 .10917 L
.02832 .08312 L
.03101 .07912 L
.04848 .05706 L
.05706 .04802 L
.07619 .03101 L
.08312 .02579 L
.10917 .00934 L
.11742 .00495 L
s
0 0 1 r
.29156 .15739 m
.31761 .14824 L
.34367 .14249 L
.36972 .13986 L
.39578 .14025 L
.42183 .14366 L
.44789 .15025 L
.47394 .16034 L
.47599 .16128 L
.5 .17443 L
.51844 .18734 L
.52606 .19355 L
.54662 .21339 L
.55211 .21962 L
.56712 .23945 L
.57817 .25755 L
.58227 .2655 L
.59322 .29156 L
.60058 .31761 L
.60422 .3392 L
.60471 .34367 L
.6058 .36972 L
.60422 .39297 L
.60387 .39578 L
.59886 .42183 L
.59054 .44789 L
.57848 .47394 L
.57817 .47453 L
.562 .5 L
.55211 .51255 L
.53968 .52606 L
.52606 .53862 L
.50853 .55211 L
.5 .55773 L
.47394 .57183 L
.45901 .57817 L
.44789 .5819 L
.42183 .5885 L
.39578 .59192 L
.36972 .59231 L
.34367 .58968 L
.31761 .58392 L
.29972 .57817 L
.29156 .57477 L
.2655 .56178 L
.25025 .55211 L
.23945 .54409 L
.21914 .52606 L
.21339 .52008 L
.19681 .5 L
Mistroke
.18734 .48608 L
.18031 .47394 L
.16827 .44789 L
.16128 .42714 L
.15996 .42183 L
.15493 .39578 L
.153 .36972 L
.15409 .34367 L
.15823 .31761 L
.16128 .3045 L
.16559 .29156 L
.17653 .2655 L
.18734 .24609 L
.19169 .23945 L
.21221 .21339 L
.21339 .21211 L
.23945 .1881 L
.24041 .18734 L
.2655 .17038 L
.28271 .16128 L
.29156 .15739 L
Mfstroke
1 0 0 r
.03 w
.21687 .20845 Mdot
0 0 1 r
.3794 .36608 Mdot
1 0 0 r
.79703 .00495 m
.79703 .11998 L
.87129 .11998 L
.87129 .00495 L
F
0 0 1 r
.89604 .00495 m
.89604 .13745 L
.9703 .13745 L
.9703 .00495 L
F
1 0 1 r
.04 w
.34472 .28521 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCacheValid->False],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.49505 0.5 0.49505 [
[ 0 0 -0.125 0 ]
[ 0 0 -0.125 0 ]
[ 0 1 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
0 0 m
1 0 L
s
0 0 m
0 1 L
s
0 1 m
1 1 L
s
1 0 m
1 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
1 .5 0 r
.015 w
.03175 .1355 Mdot
.03435 .12523 Mdot
.11137 .12765 Mdot
.14107 .18841 Mdot
.16218 .24538 Mdot
.17294 .21053 Mdot
.18267 .18577 Mdot
.18434 .1304 Mdot
.18553 .30956 Mdot
.20401 .239 Mdot
.21247 .27571 Mdot
.21687 .20845 Mdot
.22376 .2799 Mdot
.22832 .27485 Mdot
.29063 .20974 Mdot
.29686 .25079 Mdot
.30487 .22936 Mdot
.30683 .34623 Mdot
.32055 .20902 Mdot
.32574 .21979 Mdot
.34472 .28521 Mdot
.35998 .36393 Mdot
.36335 .24976 Mdot
.3794 .36608 Mdot
.42386 .66992 Mdot
.44391 .74519 Mdot
.45059 .34198 Mdot
.47208 .67586 Mdot
.47436 .71381 Mdot
.49778 .59825 Mdot
.50874 .91643 Mdot
.51516 .76219 Mdot
.53655 .61374 Mdot
.56563 .75219 Mdot
.59189 .65665 Mdot
.59581 .61604 Mdot
.59923 .6556 Mdot
.60292 .68499 Mdot
.62656 .67779 Mdot
.63555 .72451 Mdot
.63919 .652 Mdot
.64169 .6004 Mdot
.64246 .58611 Mdot
.64496 .54267 Mdot
.64608 .77288 Mdot
.65077 .64308 Mdot
.66065 .57816 Mdot
.67474 .59169 Mdot
.69296 .563 Mdot
.72815 .65902 Mdot
.73169 .58879 Mdot
.74669 .61318 Mdot
.74821 .65474 Mdot
.75963 .63781 Mdot
.79673 .57809 Mdot
.80925 .55852 Mdot
.81525 .58444 Mdot
.83417 .62985 Mdot
.83598 .55526 Mdot
.91595 .49319 Mdot
1 0 0 r
.005 w
.00495 .28842 m
.00628 .29156 L
.01857 .31761 L
.03101 .33781 L
.03525 .34367 L
.05706 .36884 L
.05795 .36972 L
.08312 .39115 L
.08963 .39578 L
.10917 .40763 L
.13523 .41964 L
.14074 .42183 L
.16128 .42794 L
.18734 .43294 L
.21339 .43485 L
.23945 .43375 L
.2655 .42959 L
.29156 .42219 L
.29261 .42183 L
.31761 .41124 L
.34367 .39603 L
.34405 .39578 L
.36972 .37551 L
.37582 .36972 L
.39578 .34724 L
.39849 .34367 L
.41525 .31761 L
.42183 .30485 L
.4275 .29156 L
.436 .2655 L
.44117 .23945 L
.44325 .21339 L
.44232 .18734 L
.43834 .16128 L
.43114 .13523 L
.42183 .11212 L
.42037 .10917 L
.40546 .08312 L
.39578 .06961 L
.38528 .05706 L
.36972 .04137 L
.35758 .03101 L
.34367 .02092 L
.31761 .00569 L
.3162 .00495 L
s
.00495 .12854 m
.01344 .10917 L
.02832 .08312 L
.03101 .07912 L
.04848 .05706 L
.05706 .04802 L
.07619 .03101 L
.08312 .02579 L
.10917 .00934 L
.11742 .00495 L
s
0 0 1 r
.29156 .15739 m
.31761 .14824 L
.34367 .14249 L
.36972 .13986 L
.39578 .14025 L
.42183 .14366 L
.44789 .15025 L
.47394 .16034 L
.47599 .16128 L
.5 .17443 L
.51844 .18734 L
.52606 .19355 L
.54662 .21339 L
.55211 .21962 L
.56712 .23945 L
.57817 .25755 L
.58227 .2655 L
.59322 .29156 L
.60058 .31761 L
.60422 .3392 L
.60471 .34367 L
.6058 .36972 L
.60422 .39297 L
.60387 .39578 L
.59886 .42183 L
.59054 .44789 L
.57848 .47394 L
.57817 .47453 L
.562 .5 L
.55211 .51255 L
.53968 .52606 L
.52606 .53862 L
.50853 .55211 L
.5 .55773 L
.47394 .57183 L
.45901 .57817 L
.44789 .5819 L
.42183 .5885 L
.39578 .59192 L
.36972 .59231 L
.34367 .58968 L
.31761 .58392 L
.29972 .57817 L
.29156 .57477 L
.2655 .56178 L
.25025 .55211 L
.23945 .54409 L
.21914 .52606 L
.21339 .52008 L
.19681 .5 L
Mistroke
.18734 .48608 L
.18031 .47394 L
.16827 .44789 L
.16128 .42714 L
.15996 .42183 L
.15493 .39578 L
.153 .36972 L
.15409 .34367 L
.15823 .31761 L
.16128 .3045 L
.16559 .29156 L
.17653 .2655 L
.18734 .24609 L
.19169 .23945 L
.21221 .21339 L
.21339 .21211 L
.23945 .1881 L
.24041 .18734 L
.2655 .17038 L
.28271 .16128 L
.29156 .15739 L
Mfstroke
1 0 0 r
.03 w
.21687 .20845 Mdot
0 0 1 r
.3794 .36608 Mdot
1 0 0 r
.79703 .00495 m
.79703 .1024 L
.87129 .1024 L
.87129 .00495 L
F
0 0 1 r
.89604 .00495 m
.89604 .15503 L
.9703 .15503 L
.9703 .00495 L
F
1 0 1 r
.04 w
.35998 .36393 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCacheValid->False],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.49505 0.5 0.49505 [
[ 0 0 -0.125 0 ]
[ 0 0 -0.125 0 ]
[ 0 1 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
0 0 m
1 0 L
s
0 0 m
0 1 L
s
0 1 m
1 1 L
s
1 0 m
1 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
1 .5 0 r
.015 w
.03175 .1355 Mdot
.03435 .12523 Mdot
.11137 .12765 Mdot
.14107 .18841 Mdot
.16218 .24538 Mdot
.17294 .21053 Mdot
.18267 .18577 Mdot
.18434 .1304 Mdot
.18553 .30956 Mdot
.20401 .239 Mdot
.21247 .27571 Mdot
.21687 .20845 Mdot
.22376 .2799 Mdot
.22832 .27485 Mdot
.29063 .20974 Mdot
.29686 .25079 Mdot
.30487 .22936 Mdot
.30683 .34623 Mdot
.32055 .20902 Mdot
.32574 .21979 Mdot
.34472 .28521 Mdot
.35998 .36393 Mdot
.36335 .24976 Mdot
.3794 .36608 Mdot
.42386 .66992 Mdot
.44391 .74519 Mdot
.45059 .34198 Mdot
.47208 .67586 Mdot
.47436 .71381 Mdot
.49778 .59825 Mdot
.50874 .91643 Mdot
.51516 .76219 Mdot
.53655 .61374 Mdot
.56563 .75219 Mdot
.59189 .65665 Mdot
.59581 .61604 Mdot
.59923 .6556 Mdot
.60292 .68499 Mdot
.62656 .67779 Mdot
.63555 .72451 Mdot
.63919 .652 Mdot
.64169 .6004 Mdot
.64246 .58611 Mdot
.64496 .54267 Mdot
.64608 .77288 Mdot
.65077 .64308 Mdot
.66065 .57816 Mdot
.67474 .59169 Mdot
.69296 .563 Mdot
.72815 .65902 Mdot
.73169 .58879 Mdot
.74669 .61318 Mdot
.74821 .65474 Mdot
.75963 .63781 Mdot
.79673 .57809 Mdot
.80925 .55852 Mdot
.81525 .58444 Mdot
.83417 .62985 Mdot
.83598 .55526 Mdot
.91595 .49319 Mdot
1 0 0 r
.005 w
.00495 .28842 m
.00628 .29156 L
.01857 .31761 L
.03101 .33781 L
.03525 .34367 L
.05706 .36884 L
.05795 .36972 L
.08312 .39115 L
.08963 .39578 L
.10917 .40763 L
.13523 .41964 L
.14074 .42183 L
.16128 .42794 L
.18734 .43294 L
.21339 .43485 L
.23945 .43375 L
.2655 .42959 L
.29156 .42219 L
.29261 .42183 L
.31761 .41124 L
.34367 .39603 L
.34405 .39578 L
.36972 .37551 L
.37582 .36972 L
.39578 .34724 L
.39849 .34367 L
.41525 .31761 L
.42183 .30485 L
.4275 .29156 L
.436 .2655 L
.44117 .23945 L
.44325 .21339 L
.44232 .18734 L
.43834 .16128 L
.43114 .13523 L
.42183 .11212 L
.42037 .10917 L
.40546 .08312 L
.39578 .06961 L
.38528 .05706 L
.36972 .04137 L
.35758 .03101 L
.34367 .02092 L
.31761 .00569 L
.3162 .00495 L
s
.00495 .12854 m
.01344 .10917 L
.02832 .08312 L
.03101 .07912 L
.04848 .05706 L
.05706 .04802 L
.07619 .03101 L
.08312 .02579 L
.10917 .00934 L
.11742 .00495 L
s
0 0 1 r
.29156 .15739 m
.31761 .14824 L
.34367 .14249 L
.36972 .13986 L
.39578 .14025 L
.42183 .14366 L
.44789 .15025 L
.47394 .16034 L
.47599 .16128 L
.5 .17443 L
.51844 .18734 L
.52606 .19355 L
.54662 .21339 L
.55211 .21962 L
.56712 .23945 L
.57817 .25755 L
.58227 .2655 L
.59322 .29156 L
.60058 .31761 L
.60422 .3392 L
.60471 .34367 L
.6058 .36972 L
.60422 .39297 L
.60387 .39578 L
.59886 .42183 L
.59054 .44789 L
.57848 .47394 L
.57817 .47453 L
.562 .5 L
.55211 .51255 L
.53968 .52606 L
.52606 .53862 L
.50853 .55211 L
.5 .55773 L
.47394 .57183 L
.45901 .57817 L
.44789 .5819 L
.42183 .5885 L
.39578 .59192 L
.36972 .59231 L
.34367 .58968 L
.31761 .58392 L
.29972 .57817 L
.29156 .57477 L
.2655 .56178 L
.25025 .55211 L
.23945 .54409 L
.21914 .52606 L
.21339 .52008 L
.19681 .5 L
Mistroke
.18734 .48608 L
.18031 .47394 L
.16827 .44789 L
.16128 .42714 L
.15996 .42183 L
.15493 .39578 L
.153 .36972 L
.15409 .34367 L
.15823 .31761 L
.16128 .3045 L
.16559 .29156 L
.17653 .2655 L
.18734 .24609 L
.19169 .23945 L
.21221 .21339 L
.21339 .21211 L
.23945 .1881 L
.24041 .18734 L
.2655 .17038 L
.28271 .16128 L
.29156 .15739 L
Mfstroke
1 0 0 r
.03 w
.21687 .20845 Mdot
0 0 1 r
.3794 .36608 Mdot
1 0 0 r
.79703 .00495 m
.79703 .12306 L
.87129 .12306 L
.87129 .00495 L
F
0 0 1 r
.89604 .00495 m
.89604 .13437 L
.9703 .13437 L
.9703 .00495 L
F
1 0 1 r
.04 w
.36335 .24976 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCacheValid->False],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.49505 0.5 0.49505 [
[ 0 0 -0.125 0 ]
[ 0 0 -0.125 0 ]
[ 0 1 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
0 0 m
1 0 L
s
0 0 m
0 1 L
s
0 1 m
1 1 L
s
1 0 m
1 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
1 .5 0 r
.015 w
.03175 .1355 Mdot
.03435 .12523 Mdot
.11137 .12765 Mdot
.14107 .18841 Mdot
.16218 .24538 Mdot
.17294 .21053 Mdot
.18267 .18577 Mdot
.18434 .1304 Mdot
.18553 .30956 Mdot
.20401 .239 Mdot
.21247 .27571 Mdot
.21687 .20845 Mdot
.22376 .2799 Mdot
.22832 .27485 Mdot
.29063 .20974 Mdot
.29686 .25079 Mdot
.30487 .22936 Mdot
.30683 .34623 Mdot
.32055 .20902 Mdot
.32574 .21979 Mdot
.34472 .28521 Mdot
.35998 .36393 Mdot
.36335 .24976 Mdot
.3794 .36608 Mdot
.42386 .66992 Mdot
.44391 .74519 Mdot
.45059 .34198 Mdot
.47208 .67586 Mdot
.47436 .71381 Mdot
.49778 .59825 Mdot
.50874 .91643 Mdot
.51516 .76219 Mdot
.53655 .61374 Mdot
.56563 .75219 Mdot
.59189 .65665 Mdot
.59581 .61604 Mdot
.59923 .6556 Mdot
.60292 .68499 Mdot
.62656 .67779 Mdot
.63555 .72451 Mdot
.63919 .652 Mdot
.64169 .6004 Mdot
.64246 .58611 Mdot
.64496 .54267 Mdot
.64608 .77288 Mdot
.65077 .64308 Mdot
.66065 .57816 Mdot
.67474 .59169 Mdot
.69296 .563 Mdot
.72815 .65902 Mdot
.73169 .58879 Mdot
.74669 .61318 Mdot
.74821 .65474 Mdot
.75963 .63781 Mdot
.79673 .57809 Mdot
.80925 .55852 Mdot
.81525 .58444 Mdot
.83417 .62985 Mdot
.83598 .55526 Mdot
.91595 .49319 Mdot
1 0 0 r
.005 w
.00495 .28842 m
.00628 .29156 L
.01857 .31761 L
.03101 .33781 L
.03525 .34367 L
.05706 .36884 L
.05795 .36972 L
.08312 .39115 L
.08963 .39578 L
.10917 .40763 L
.13523 .41964 L
.14074 .42183 L
.16128 .42794 L
.18734 .43294 L
.21339 .43485 L
.23945 .43375 L
.2655 .42959 L
.29156 .42219 L
.29261 .42183 L
.31761 .41124 L
.34367 .39603 L
.34405 .39578 L
.36972 .37551 L
.37582 .36972 L
.39578 .34724 L
.39849 .34367 L
.41525 .31761 L
.42183 .30485 L
.4275 .29156 L
.436 .2655 L
.44117 .23945 L
.44325 .21339 L
.44232 .18734 L
.43834 .16128 L
.43114 .13523 L
.42183 .11212 L
.42037 .10917 L
.40546 .08312 L
.39578 .06961 L
.38528 .05706 L
.36972 .04137 L
.35758 .03101 L
.34367 .02092 L
.31761 .00569 L
.3162 .00495 L
s
.00495 .12854 m
.01344 .10917 L
.02832 .08312 L
.03101 .07912 L
.04848 .05706 L
.05706 .04802 L
.07619 .03101 L
.08312 .02579 L
.10917 .00934 L
.11742 .00495 L
s
0 0 1 r
.29156 .15739 m
.31761 .14824 L
.34367 .14249 L
.36972 .13986 L
.39578 .14025 L
.42183 .14366 L
.44789 .15025 L
.47394 .16034 L
.47599 .16128 L
.5 .17443 L
.51844 .18734 L
.52606 .19355 L
.54662 .21339 L
.55211 .21962 L
.56712 .23945 L
.57817 .25755 L
.58227 .2655 L
.59322 .29156 L
.60058 .31761 L
.60422 .3392 L
.60471 .34367 L
.6058 .36972 L
.60422 .39297 L
.60387 .39578 L
.59886 .42183 L
.59054 .44789 L
.57848 .47394 L
.57817 .47453 L
.562 .5 L
.55211 .51255 L
.53968 .52606 L
.52606 .53862 L
.50853 .55211 L
.5 .55773 L
.47394 .57183 L
.45901 .57817 L
.44789 .5819 L
.42183 .5885 L
.39578 .59192 L
.36972 .59231 L
.34367 .58968 L
.31761 .58392 L
.29972 .57817 L
.29156 .57477 L
.2655 .56178 L
.25025 .55211 L
.23945 .54409 L
.21914 .52606 L
.21339 .52008 L
.19681 .5 L
Mistroke
.18734 .48608 L
.18031 .47394 L
.16827 .44789 L
.16128 .42714 L
.15996 .42183 L
.15493 .39578 L
.153 .36972 L
.15409 .34367 L
.15823 .31761 L
.16128 .3045 L
.16559 .29156 L
.17653 .2655 L
.18734 .24609 L
.19169 .23945 L
.21221 .21339 L
.21339 .21211 L
.23945 .1881 L
.24041 .18734 L
.2655 .17038 L
.28271 .16128 L
.29156 .15739 L
Mfstroke
1 0 0 r
.03 w
.21687 .20845 Mdot
0 0 1 r
.3794 .36608 Mdot
1 0 0 r
.79703 .00495 m
.79703 .0984 L
.87129 .0984 L
.87129 .00495 L
F
0 0 1 r
.89604 .00495 m
.89604 .15902 L
.9703 .15902 L
.9703 .00495 L
F
1 0 1 r
.04 w
.3794 .36608 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCacheValid->False],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.49505 0.5 0.49505 [
[ 0 0 -0.125 0 ]
[ 0 0 -0.125 0 ]
[ 0 1 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
0 0 m
1 0 L
s
0 0 m
0 1 L
s
0 1 m
1 1 L
s
1 0 m
1 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
1 .5 0 r
.015 w
.03175 .1355 Mdot
.03435 .12523 Mdot
.11137 .12765 Mdot
.14107 .18841 Mdot
.16218 .24538 Mdot
.17294 .21053 Mdot
.18267 .18577 Mdot
.18434 .1304 Mdot
.18553 .30956 Mdot
.20401 .239 Mdot
.21247 .27571 Mdot
.21687 .20845 Mdot
.22376 .2799 Mdot
.22832 .27485 Mdot
.29063 .20974 Mdot
.29686 .25079 Mdot
.30487 .22936 Mdot
.30683 .34623 Mdot
.32055 .20902 Mdot
.32574 .21979 Mdot
.34472 .28521 Mdot
.35998 .36393 Mdot
.36335 .24976 Mdot
.3794 .36608 Mdot
.42386 .66992 Mdot
.44391 .74519 Mdot
.45059 .34198 Mdot
.47208 .67586 Mdot
.47436 .71381 Mdot
.49778 .59825 Mdot
.50874 .91643 Mdot
.51516 .76219 Mdot
.53655 .61374 Mdot
.56563 .75219 Mdot
.59189 .65665 Mdot
.59581 .61604 Mdot
.59923 .6556 Mdot
.60292 .68499 Mdot
.62656 .67779 Mdot
.63555 .72451 Mdot
.63919 .652 Mdot
.64169 .6004 Mdot
.64246 .58611 Mdot
.64496 .54267 Mdot
.64608 .77288 Mdot
.65077 .64308 Mdot
.66065 .57816 Mdot
.67474 .59169 Mdot
.69296 .563 Mdot
.72815 .65902 Mdot
.73169 .58879 Mdot
.74669 .61318 Mdot
.74821 .65474 Mdot
.75963 .63781 Mdot
.79673 .57809 Mdot
.80925 .55852 Mdot
.81525 .58444 Mdot
.83417 .62985 Mdot
.83598 .55526 Mdot
.91595 .49319 Mdot
1 0 0 r
.005 w
.00495 .28842 m
.00628 .29156 L
.01857 .31761 L
.03101 .33781 L
.03525 .34367 L
.05706 .36884 L
.05795 .36972 L
.08312 .39115 L
.08963 .39578 L
.10917 .40763 L
.13523 .41964 L
.14074 .42183 L
.16128 .42794 L
.18734 .43294 L
.21339 .43485 L
.23945 .43375 L
.2655 .42959 L
.29156 .42219 L
.29261 .42183 L
.31761 .41124 L
.34367 .39603 L
.34405 .39578 L
.36972 .37551 L
.37582 .36972 L
.39578 .34724 L
.39849 .34367 L
.41525 .31761 L
.42183 .30485 L
.4275 .29156 L
.436 .2655 L
.44117 .23945 L
.44325 .21339 L
.44232 .18734 L
.43834 .16128 L
.43114 .13523 L
.42183 .11212 L
.42037 .10917 L
.40546 .08312 L
.39578 .06961 L
.38528 .05706 L
.36972 .04137 L
.35758 .03101 L
.34367 .02092 L
.31761 .00569 L
.3162 .00495 L
s
.00495 .12854 m
.01344 .10917 L
.02832 .08312 L
.03101 .07912 L
.04848 .05706 L
.05706 .04802 L
.07619 .03101 L
.08312 .02579 L
.10917 .00934 L
.11742 .00495 L
s
0 0 1 r
.29156 .15739 m
.31761 .14824 L
.34367 .14249 L
.36972 .13986 L
.39578 .14025 L
.42183 .14366 L
.44789 .15025 L
.47394 .16034 L
.47599 .16128 L
.5 .17443 L
.51844 .18734 L
.52606 .19355 L
.54662 .21339 L
.55211 .21962 L
.56712 .23945 L
.57817 .25755 L
.58227 .2655 L
.59322 .29156 L
.60058 .31761 L
.60422 .3392 L
.60471 .34367 L
.6058 .36972 L
.60422 .39297 L
.60387 .39578 L
.59886 .42183 L
.59054 .44789 L
.57848 .47394 L
.57817 .47453 L
.562 .5 L
.55211 .51255 L
.53968 .52606 L
.52606 .53862 L
.50853 .55211 L
.5 .55773 L
.47394 .57183 L
.45901 .57817 L
.44789 .5819 L
.42183 .5885 L
.39578 .59192 L
.36972 .59231 L
.34367 .58968 L
.31761 .58392 L
.29972 .57817 L
.29156 .57477 L
.2655 .56178 L
.25025 .55211 L
.23945 .54409 L
.21914 .52606 L
.21339 .52008 L
.19681 .5 L
Mistroke
.18734 .48608 L
.18031 .47394 L
.16827 .44789 L
.16128 .42714 L
.15996 .42183 L
.15493 .39578 L
.153 .36972 L
.15409 .34367 L
.15823 .31761 L
.16128 .3045 L
.16559 .29156 L
.17653 .2655 L
.18734 .24609 L
.19169 .23945 L
.21221 .21339 L
.21339 .21211 L
.23945 .1881 L
.24041 .18734 L
.2655 .17038 L
.28271 .16128 L
.29156 .15739 L
Mfstroke
1 0 0 r
.03 w
.21687 .20845 Mdot
0 0 1 r
.3794 .36608 Mdot
1 0 0 r
.79703 .00495 m
.79703 .04739 L
.87129 .04739 L
.87129 .00495 L
F
0 0 1 r
.89604 .00495 m
.89604 .21003 L
.9703 .21003 L
.9703 .00495 L
F
1 0 1 r
.04 w
.42386 .66992 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCacheValid->False],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.49505 0.5 0.49505 [
[ 0 0 -0.125 0 ]
[ 0 0 -0.125 0 ]
[ 0 1 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
0 0 m
1 0 L
s
0 0 m
0 1 L
s
0 1 m
1 1 L
s
1 0 m
1 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
1 .5 0 r
.015 w
.03175 .1355 Mdot
.03435 .12523 Mdot
.11137 .12765 Mdot
.14107 .18841 Mdot
.16218 .24538 Mdot
.17294 .21053 Mdot
.18267 .18577 Mdot
.18434 .1304 Mdot
.18553 .30956 Mdot
.20401 .239 Mdot
.21247 .27571 Mdot
.21687 .20845 Mdot
.22376 .2799 Mdot
.22832 .27485 Mdot
.29063 .20974 Mdot
.29686 .25079 Mdot
.30487 .22936 Mdot
.30683 .34623 Mdot
.32055 .20902 Mdot
.32574 .21979 Mdot
.34472 .28521 Mdot
.35998 .36393 Mdot
.36335 .24976 Mdot
.3794 .36608 Mdot
.42386 .66992 Mdot
.44391 .74519 Mdot
.45059 .34198 Mdot
.47208 .67586 Mdot
.47436 .71381 Mdot
.49778 .59825 Mdot
.50874 .91643 Mdot
.51516 .76219 Mdot
.53655 .61374 Mdot
.56563 .75219 Mdot
.59189 .65665 Mdot
.59581 .61604 Mdot
.59923 .6556 Mdot
.60292 .68499 Mdot
.62656 .67779 Mdot
.63555 .72451 Mdot
.63919 .652 Mdot
.64169 .6004 Mdot
.64246 .58611 Mdot
.64496 .54267 Mdot
.64608 .77288 Mdot
.65077 .64308 Mdot
.66065 .57816 Mdot
.67474 .59169 Mdot
.69296 .563 Mdot
.72815 .65902 Mdot
.73169 .58879 Mdot
.74669 .61318 Mdot
.74821 .65474 Mdot
.75963 .63781 Mdot
.79673 .57809 Mdot
.80925 .55852 Mdot
.81525 .58444 Mdot
.83417 .62985 Mdot
.83598 .55526 Mdot
.91595 .49319 Mdot
1 0 0 r
.005 w
.00495 .28842 m
.00628 .29156 L
.01857 .31761 L
.03101 .33781 L
.03525 .34367 L
.05706 .36884 L
.05795 .36972 L
.08312 .39115 L
.08963 .39578 L
.10917 .40763 L
.13523 .41964 L
.14074 .42183 L
.16128 .42794 L
.18734 .43294 L
.21339 .43485 L
.23945 .43375 L
.2655 .42959 L
.29156 .42219 L
.29261 .42183 L
.31761 .41124 L
.34367 .39603 L
.34405 .39578 L
.36972 .37551 L
.37582 .36972 L
.39578 .34724 L
.39849 .34367 L
.41525 .31761 L
.42183 .30485 L
.4275 .29156 L
.436 .2655 L
.44117 .23945 L
.44325 .21339 L
.44232 .18734 L
.43834 .16128 L
.43114 .13523 L
.42183 .11212 L
.42037 .10917 L
.40546 .08312 L
.39578 .06961 L
.38528 .05706 L
.36972 .04137 L
.35758 .03101 L
.34367 .02092 L
.31761 .00569 L
.3162 .00495 L
s
.00495 .12854 m
.01344 .10917 L
.02832 .08312 L
.03101 .07912 L
.04848 .05706 L
.05706 .04802 L
.07619 .03101 L
.08312 .02579 L
.10917 .00934 L
.11742 .00495 L
s
0 0 1 r
.29156 .15739 m
.31761 .14824 L
.34367 .14249 L
.36972 .13986 L
.39578 .14025 L
.42183 .14366 L
.44789 .15025 L
.47394 .16034 L
.47599 .16128 L
.5 .17443 L
.51844 .18734 L
.52606 .19355 L
.54662 .21339 L
.55211 .21962 L
.56712 .23945 L
.57817 .25755 L
.58227 .2655 L
.59322 .29156 L
.60058 .31761 L
.60422 .3392 L
.60471 .34367 L
.6058 .36972 L
.60422 .39297 L
.60387 .39578 L
.59886 .42183 L
.59054 .44789 L
.57848 .47394 L
.57817 .47453 L
.562 .5 L
.55211 .51255 L
.53968 .52606 L
.52606 .53862 L
.50853 .55211 L
.5 .55773 L
.47394 .57183 L
.45901 .57817 L
.44789 .5819 L
.42183 .5885 L
.39578 .59192 L
.36972 .59231 L
.34367 .58968 L
.31761 .58392 L
.29972 .57817 L
.29156 .57477 L
.2655 .56178 L
.25025 .55211 L
.23945 .54409 L
.21914 .52606 L
.21339 .52008 L
.19681 .5 L
Mistroke
.18734 .48608 L
.18031 .47394 L
.16827 .44789 L
.16128 .42714 L
.15996 .42183 L
.15493 .39578 L
.153 .36972 L
.15409 .34367 L
.15823 .31761 L
.16128 .3045 L
.16559 .29156 L
.17653 .2655 L
.18734 .24609 L
.19169 .23945 L
.21221 .21339 L
.21339 .21211 L
.23945 .1881 L
.24041 .18734 L
.2655 .17038 L
.28271 .16128 L
.29156 .15739 L
Mfstroke
1 0 0 r
.03 w
.21687 .20845 Mdot
0 0 1 r
.3794 .36608 Mdot
1 0 0 r
.79703 .00495 m
.79703 .038 L
.87129 .038 L
.87129 .00495 L
F
0 0 1 r
.89604 .00495 m
.89604 .21943 L
.9703 .21943 L
.9703 .00495 L
F
1 0 1 r
.04 w
.44391 .74519 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCacheValid->False],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.49505 0.5 0.49505 [
[ 0 0 -0.125 0 ]
[ 0 0 -0.125 0 ]
[ 0 1 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
0 0 m
1 0 L
s
0 0 m
0 1 L
s
0 1 m
1 1 L
s
1 0 m
1 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
1 .5 0 r
.015 w
.03175 .1355 Mdot
.03435 .12523 Mdot
.11137 .12765 Mdot
.14107 .18841 Mdot
.16218 .24538 Mdot
.17294 .21053 Mdot
.18267 .18577 Mdot
.18434 .1304 Mdot
.18553 .30956 Mdot
.20401 .239 Mdot
.21247 .27571 Mdot
.21687 .20845 Mdot
.22376 .2799 Mdot
.22832 .27485 Mdot
.29063 .20974 Mdot
.29686 .25079 Mdot
.30487 .22936 Mdot
.30683 .34623 Mdot
.32055 .20902 Mdot
.32574 .21979 Mdot
.34472 .28521 Mdot
.35998 .36393 Mdot
.36335 .24976 Mdot
.3794 .36608 Mdot
.42386 .66992 Mdot
.44391 .74519 Mdot
.45059 .34198 Mdot
.47208 .67586 Mdot
.47436 .71381 Mdot
.49778 .59825 Mdot
.50874 .91643 Mdot
.51516 .76219 Mdot
.53655 .61374 Mdot
.56563 .75219 Mdot
.59189 .65665 Mdot
.59581 .61604 Mdot
.59923 .6556 Mdot
.60292 .68499 Mdot
.62656 .67779 Mdot
.63555 .72451 Mdot
.63919 .652 Mdot
.64169 .6004 Mdot
.64246 .58611 Mdot
.64496 .54267 Mdot
.64608 .77288 Mdot
.65077 .64308 Mdot
.66065 .57816 Mdot
.67474 .59169 Mdot
.69296 .563 Mdot
.72815 .65902 Mdot
.73169 .58879 Mdot
.74669 .61318 Mdot
.74821 .65474 Mdot
.75963 .63781 Mdot
.79673 .57809 Mdot
.80925 .55852 Mdot
.81525 .58444 Mdot
.83417 .62985 Mdot
.83598 .55526 Mdot
.91595 .49319 Mdot
1 0 0 r
.005 w
.00495 .28842 m
.00628 .29156 L
.01857 .31761 L
.03101 .33781 L
.03525 .34367 L
.05706 .36884 L
.05795 .36972 L
.08312 .39115 L
.08963 .39578 L
.10917 .40763 L
.13523 .41964 L
.14074 .42183 L
.16128 .42794 L
.18734 .43294 L
.21339 .43485 L
.23945 .43375 L
.2655 .42959 L
.29156 .42219 L
.29261 .42183 L
.31761 .41124 L
.34367 .39603 L
.34405 .39578 L
.36972 .37551 L
.37582 .36972 L
.39578 .34724 L
.39849 .34367 L
.41525 .31761 L
.42183 .30485 L
.4275 .29156 L
.436 .2655 L
.44117 .23945 L
.44325 .21339 L
.44232 .18734 L
.43834 .16128 L
.43114 .13523 L
.42183 .11212 L
.42037 .10917 L
.40546 .08312 L
.39578 .06961 L
.38528 .05706 L
.36972 .04137 L
.35758 .03101 L
.34367 .02092 L
.31761 .00569 L
.3162 .00495 L
s
.00495 .12854 m
.01344 .10917 L
.02832 .08312 L
.03101 .07912 L
.04848 .05706 L
.05706 .04802 L
.07619 .03101 L
.08312 .02579 L
.10917 .00934 L
.11742 .00495 L
s
0 0 1 r
.29156 .15739 m
.31761 .14824 L
.34367 .14249 L
.36972 .13986 L
.39578 .14025 L
.42183 .14366 L
.44789 .15025 L
.47394 .16034 L
.47599 .16128 L
.5 .17443 L
.51844 .18734 L
.52606 .19355 L
.54662 .21339 L
.55211 .21962 L
.56712 .23945 L
.57817 .25755 L
.58227 .2655 L
.59322 .29156 L
.60058 .31761 L
.60422 .3392 L
.60471 .34367 L
.6058 .36972 L
.60422 .39297 L
.60387 .39578 L
.59886 .42183 L
.59054 .44789 L
.57848 .47394 L
.57817 .47453 L
.562 .5 L
.55211 .51255 L
.53968 .52606 L
.52606 .53862 L
.50853 .55211 L
.5 .55773 L
.47394 .57183 L
.45901 .57817 L
.44789 .5819 L
.42183 .5885 L
.39578 .59192 L
.36972 .59231 L
.34367 .58968 L
.31761 .58392 L
.29972 .57817 L
.29156 .57477 L
.2655 .56178 L
.25025 .55211 L
.23945 .54409 L
.21914 .52606 L
.21339 .52008 L
.19681 .5 L
Mistroke
.18734 .48608 L
.18031 .47394 L
.16827 .44789 L
.16128 .42714 L
.15996 .42183 L
.15493 .39578 L
.153 .36972 L
.15409 .34367 L
.15823 .31761 L
.16128 .3045 L
.16559 .29156 L
.17653 .2655 L
.18734 .24609 L
.19169 .23945 L
.21221 .21339 L
.21339 .21211 L
.23945 .1881 L
.24041 .18734 L
.2655 .17038 L
.28271 .16128 L
.29156 .15739 L
Mfstroke
1 0 0 r
.03 w
.21687 .20845 Mdot
0 0 1 r
.3794 .36608 Mdot
1 0 0 r
.79703 .00495 m
.79703 .08976 L
.87129 .08976 L
.87129 .00495 L
F
0 0 1 r
.89604 .00495 m
.89604 .16767 L
.9703 .16767 L
.9703 .00495 L
F
1 0 1 r
.04 w
.45059 .34198 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCacheValid->False],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.49505 0.5 0.49505 [
[ 0 0 -0.125 0 ]
[ 0 0 -0.125 0 ]
[ 0 1 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
0 0 m
1 0 L
s
0 0 m
0 1 L
s
0 1 m
1 1 L
s
1 0 m
1 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
1 .5 0 r
.015 w
.03175 .1355 Mdot
.03435 .12523 Mdot
.11137 .12765 Mdot
.14107 .18841 Mdot
.16218 .24538 Mdot
.17294 .21053 Mdot
.18267 .18577 Mdot
.18434 .1304 Mdot
.18553 .30956 Mdot
.20401 .239 Mdot
.21247 .27571 Mdot
.21687 .20845 Mdot
.22376 .2799 Mdot
.22832 .27485 Mdot
.29063 .20974 Mdot
.29686 .25079 Mdot
.30487 .22936 Mdot
.30683 .34623 Mdot
.32055 .20902 Mdot
.32574 .21979 Mdot
.34472 .28521 Mdot
.35998 .36393 Mdot
.36335 .24976 Mdot
.3794 .36608 Mdot
.42386 .66992 Mdot
.44391 .74519 Mdot
.45059 .34198 Mdot
.47208 .67586 Mdot
.47436 .71381 Mdot
.49778 .59825 Mdot
.50874 .91643 Mdot
.51516 .76219 Mdot
.53655 .61374 Mdot
.56563 .75219 Mdot
.59189 .65665 Mdot
.59581 .61604 Mdot
.59923 .6556 Mdot
.60292 .68499 Mdot
.62656 .67779 Mdot
.63555 .72451 Mdot
.63919 .652 Mdot
.64169 .6004 Mdot
.64246 .58611 Mdot
.64496 .54267 Mdot
.64608 .77288 Mdot
.65077 .64308 Mdot
.66065 .57816 Mdot
.67474 .59169 Mdot
.69296 .563 Mdot
.72815 .65902 Mdot
.73169 .58879 Mdot
.74669 .61318 Mdot
.74821 .65474 Mdot
.75963 .63781 Mdot
.79673 .57809 Mdot
.80925 .55852 Mdot
.81525 .58444 Mdot
.83417 .62985 Mdot
.83598 .55526 Mdot
.91595 .49319 Mdot
1 0 0 r
.005 w
.00495 .28842 m
.00628 .29156 L
.01857 .31761 L
.03101 .33781 L
.03525 .34367 L
.05706 .36884 L
.05795 .36972 L
.08312 .39115 L
.08963 .39578 L
.10917 .40763 L
.13523 .41964 L
.14074 .42183 L
.16128 .42794 L
.18734 .43294 L
.21339 .43485 L
.23945 .43375 L
.2655 .42959 L
.29156 .42219 L
.29261 .42183 L
.31761 .41124 L
.34367 .39603 L
.34405 .39578 L
.36972 .37551 L
.37582 .36972 L
.39578 .34724 L
.39849 .34367 L
.41525 .31761 L
.42183 .30485 L
.4275 .29156 L
.436 .2655 L
.44117 .23945 L
.44325 .21339 L
.44232 .18734 L
.43834 .16128 L
.43114 .13523 L
.42183 .11212 L
.42037 .10917 L
.40546 .08312 L
.39578 .06961 L
.38528 .05706 L
.36972 .04137 L
.35758 .03101 L
.34367 .02092 L
.31761 .00569 L
.3162 .00495 L
s
.00495 .12854 m
.01344 .10917 L
.02832 .08312 L
.03101 .07912 L
.04848 .05706 L
.05706 .04802 L
.07619 .03101 L
.08312 .02579 L
.10917 .00934 L
.11742 .00495 L
s
0 0 1 r
.29156 .15739 m
.31761 .14824 L
.34367 .14249 L
.36972 .13986 L
.39578 .14025 L
.42183 .14366 L
.44789 .15025 L
.47394 .16034 L
.47599 .16128 L
.5 .17443 L
.51844 .18734 L
.52606 .19355 L
.54662 .21339 L
.55211 .21962 L
.56712 .23945 L
.57817 .25755 L
.58227 .2655 L
.59322 .29156 L
.60058 .31761 L
.60422 .3392 L
.60471 .34367 L
.6058 .36972 L
.60422 .39297 L
.60387 .39578 L
.59886 .42183 L
.59054 .44789 L
.57848 .47394 L
.57817 .47453 L
.562 .5 L
.55211 .51255 L
.53968 .52606 L
.52606 .53862 L
.50853 .55211 L
.5 .55773 L
.47394 .57183 L
.45901 .57817 L
.44789 .5819 L
.42183 .5885 L
.39578 .59192 L
.36972 .59231 L
.34367 .58968 L
.31761 .58392 L
.29972 .57817 L
.29156 .57477 L
.2655 .56178 L
.25025 .55211 L
.23945 .54409 L
.21914 .52606 L
.21339 .52008 L
.19681 .5 L
Mistroke
.18734 .48608 L
.18031 .47394 L
.16827 .44789 L
.16128 .42714 L
.15996 .42183 L
.15493 .39578 L
.153 .36972 L
.15409 .34367 L
.15823 .31761 L
.16128 .3045 L
.16559 .29156 L
.17653 .2655 L
.18734 .24609 L
.19169 .23945 L
.21221 .21339 L
.21339 .21211 L
.23945 .1881 L
.24041 .18734 L
.2655 .17038 L
.28271 .16128 L
.29156 .15739 L
Mfstroke
1 0 0 r
.03 w
.21687 .20845 Mdot
0 0 1 r
.3794 .36608 Mdot
1 0 0 r
.79703 .00495 m
.79703 .04171 L
.87129 .04171 L
.87129 .00495 L
F
0 0 1 r
.89604 .00495 m
.89604 .21572 L
.9703 .21572 L
.9703 .00495 L
F
1 0 1 r
.04 w
.47208 .67586 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCacheValid->False],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.49505 0.5 0.49505 [
[ 0 0 -0.125 0 ]
[ 0 0 -0.125 0 ]
[ 0 1 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
0 0 m
1 0 L
s
0 0 m
0 1 L
s
0 1 m
1 1 L
s
1 0 m
1 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
1 .5 0 r
.015 w
.03175 .1355 Mdot
.03435 .12523 Mdot
.11137 .12765 Mdot
.14107 .18841 Mdot
.16218 .24538 Mdot
.17294 .21053 Mdot
.18267 .18577 Mdot
.18434 .1304 Mdot
.18553 .30956 Mdot
.20401 .239 Mdot
.21247 .27571 Mdot
.21687 .20845 Mdot
.22376 .2799 Mdot
.22832 .27485 Mdot
.29063 .20974 Mdot
.29686 .25079 Mdot
.30487 .22936 Mdot
.30683 .34623 Mdot
.32055 .20902 Mdot
.32574 .21979 Mdot
.34472 .28521 Mdot
.35998 .36393 Mdot
.36335 .24976 Mdot
.3794 .36608 Mdot
.42386 .66992 Mdot
.44391 .74519 Mdot
.45059 .34198 Mdot
.47208 .67586 Mdot
.47436 .71381 Mdot
.49778 .59825 Mdot
.50874 .91643 Mdot
.51516 .76219 Mdot
.53655 .61374 Mdot
.56563 .75219 Mdot
.59189 .65665 Mdot
.59581 .61604 Mdot
.59923 .6556 Mdot
.60292 .68499 Mdot
.62656 .67779 Mdot
.63555 .72451 Mdot
.63919 .652 Mdot
.64169 .6004 Mdot
.64246 .58611 Mdot
.64496 .54267 Mdot
.64608 .77288 Mdot
.65077 .64308 Mdot
.66065 .57816 Mdot
.67474 .59169 Mdot
.69296 .563 Mdot
.72815 .65902 Mdot
.73169 .58879 Mdot
.74669 .61318 Mdot
.74821 .65474 Mdot
.75963 .63781 Mdot
.79673 .57809 Mdot
.80925 .55852 Mdot
.81525 .58444 Mdot
.83417 .62985 Mdot
.83598 .55526 Mdot
.91595 .49319 Mdot
1 0 0 r
.005 w
.00495 .28842 m
.00628 .29156 L
.01857 .31761 L
.03101 .33781 L
.03525 .34367 L
.05706 .36884 L
.05795 .36972 L
.08312 .39115 L
.08963 .39578 L
.10917 .40763 L
.13523 .41964 L
.14074 .42183 L
.16128 .42794 L
.18734 .43294 L
.21339 .43485 L
.23945 .43375 L
.2655 .42959 L
.29156 .42219 L
.29261 .42183 L
.31761 .41124 L
.34367 .39603 L
.34405 .39578 L
.36972 .37551 L
.37582 .36972 L
.39578 .34724 L
.39849 .34367 L
.41525 .31761 L
.42183 .30485 L
.4275 .29156 L
.436 .2655 L
.44117 .23945 L
.44325 .21339 L
.44232 .18734 L
.43834 .16128 L
.43114 .13523 L
.42183 .11212 L
.42037 .10917 L
.40546 .08312 L
.39578 .06961 L
.38528 .05706 L
.36972 .04137 L
.35758 .03101 L
.34367 .02092 L
.31761 .00569 L
.3162 .00495 L
s
.00495 .12854 m
.01344 .10917 L
.02832 .08312 L
.03101 .07912 L
.04848 .05706 L
.05706 .04802 L
.07619 .03101 L
.08312 .02579 L
.10917 .00934 L
.11742 .00495 L
s
0 0 1 r
.29156 .15739 m
.31761 .14824 L
.34367 .14249 L
.36972 .13986 L
.39578 .14025 L
.42183 .14366 L
.44789 .15025 L
.47394 .16034 L
.47599 .16128 L
.5 .17443 L
.51844 .18734 L
.52606 .19355 L
.54662 .21339 L
.55211 .21962 L
.56712 .23945 L
.57817 .25755 L
.58227 .2655 L
.59322 .29156 L
.60058 .31761 L
.60422 .3392 L
.60471 .34367 L
.6058 .36972 L
.60422 .39297 L
.60387 .39578 L
.59886 .42183 L
.59054 .44789 L
.57848 .47394 L
.57817 .47453 L
.562 .5 L
.55211 .51255 L
.53968 .52606 L
.52606 .53862 L
.50853 .55211 L
.5 .55773 L
.47394 .57183 L
.45901 .57817 L
.44789 .5819 L
.42183 .5885 L
.39578 .59192 L
.36972 .59231 L
.34367 .58968 L
.31761 .58392 L
.29972 .57817 L
.29156 .57477 L
.2655 .56178 L
.25025 .55211 L
.23945 .54409 L
.21914 .52606 L
.21339 .52008 L
.19681 .5 L
Mistroke
.18734 .48608 L
.18031 .47394 L
.16827 .44789 L
.16128 .42714 L
.15996 .42183 L
.15493 .39578 L
.153 .36972 L
.15409 .34367 L
.15823 .31761 L
.16128 .3045 L
.16559 .29156 L
.17653 .2655 L
.18734 .24609 L
.19169 .23945 L
.21221 .21339 L
.21339 .21211 L
.23945 .1881 L
.24041 .18734 L
.2655 .17038 L
.28271 .16128 L
.29156 .15739 L
Mfstroke
1 0 0 r
.03 w
.21687 .20845 Mdot
0 0 1 r
.3794 .36608 Mdot
1 0 0 r
.79703 .00495 m
.79703 .038 L
.87129 .038 L
.87129 .00495 L
F
0 0 1 r
.89604 .00495 m
.89604 .21943 L
.9703 .21943 L
.9703 .00495 L
F
1 0 1 r
.04 w
.47436 .71381 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCacheValid->False],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.49505 0.5 0.49505 [
[ 0 0 -0.125 0 ]
[ 0 0 -0.125 0 ]
[ 0 1 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
0 0 m
1 0 L
s
0 0 m
0 1 L
s
0 1 m
1 1 L
s
1 0 m
1 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
1 .5 0 r
.015 w
.03175 .1355 Mdot
.03435 .12523 Mdot
.11137 .12765 Mdot
.14107 .18841 Mdot
.16218 .24538 Mdot
.17294 .21053 Mdot
.18267 .18577 Mdot
.18434 .1304 Mdot
.18553 .30956 Mdot
.20401 .239 Mdot
.21247 .27571 Mdot
.21687 .20845 Mdot
.22376 .2799 Mdot
.22832 .27485 Mdot
.29063 .20974 Mdot
.29686 .25079 Mdot
.30487 .22936 Mdot
.30683 .34623 Mdot
.32055 .20902 Mdot
.32574 .21979 Mdot
.34472 .28521 Mdot
.35998 .36393 Mdot
.36335 .24976 Mdot
.3794 .36608 Mdot
.42386 .66992 Mdot
.44391 .74519 Mdot
.45059 .34198 Mdot
.47208 .67586 Mdot
.47436 .71381 Mdot
.49778 .59825 Mdot
.50874 .91643 Mdot
.51516 .76219 Mdot
.53655 .61374 Mdot
.56563 .75219 Mdot
.59189 .65665 Mdot
.59581 .61604 Mdot
.59923 .6556 Mdot
.60292 .68499 Mdot
.62656 .67779 Mdot
.63555 .72451 Mdot
.63919 .652 Mdot
.64169 .6004 Mdot
.64246 .58611 Mdot
.64496 .54267 Mdot
.64608 .77288 Mdot
.65077 .64308 Mdot
.66065 .57816 Mdot
.67474 .59169 Mdot
.69296 .563 Mdot
.72815 .65902 Mdot
.73169 .58879 Mdot
.74669 .61318 Mdot
.74821 .65474 Mdot
.75963 .63781 Mdot
.79673 .57809 Mdot
.80925 .55852 Mdot
.81525 .58444 Mdot
.83417 .62985 Mdot
.83598 .55526 Mdot
.91595 .49319 Mdot
1 0 0 r
.005 w
.00495 .28842 m
.00628 .29156 L
.01857 .31761 L
.03101 .33781 L
.03525 .34367 L
.05706 .36884 L
.05795 .36972 L
.08312 .39115 L
.08963 .39578 L
.10917 .40763 L
.13523 .41964 L
.14074 .42183 L
.16128 .42794 L
.18734 .43294 L
.21339 .43485 L
.23945 .43375 L
.2655 .42959 L
.29156 .42219 L
.29261 .42183 L
.31761 .41124 L
.34367 .39603 L
.34405 .39578 L
.36972 .37551 L
.37582 .36972 L
.39578 .34724 L
.39849 .34367 L
.41525 .31761 L
.42183 .30485 L
.4275 .29156 L
.436 .2655 L
.44117 .23945 L
.44325 .21339 L
.44232 .18734 L
.43834 .16128 L
.43114 .13523 L
.42183 .11212 L
.42037 .10917 L
.40546 .08312 L
.39578 .06961 L
.38528 .05706 L
.36972 .04137 L
.35758 .03101 L
.34367 .02092 L
.31761 .00569 L
.3162 .00495 L
s
.00495 .12854 m
.01344 .10917 L
.02832 .08312 L
.03101 .07912 L
.04848 .05706 L
.05706 .04802 L
.07619 .03101 L
.08312 .02579 L
.10917 .00934 L
.11742 .00495 L
s
0 0 1 r
.29156 .15739 m
.31761 .14824 L
.34367 .14249 L
.36972 .13986 L
.39578 .14025 L
.42183 .14366 L
.44789 .15025 L
.47394 .16034 L
.47599 .16128 L
.5 .17443 L
.51844 .18734 L
.52606 .19355 L
.54662 .21339 L
.55211 .21962 L
.56712 .23945 L
.57817 .25755 L
.58227 .2655 L
.59322 .29156 L
.60058 .31761 L
.60422 .3392 L
.60471 .34367 L
.6058 .36972 L
.60422 .39297 L
.60387 .39578 L
.59886 .42183 L
.59054 .44789 L
.57848 .47394 L
.57817 .47453 L
.562 .5 L
.55211 .51255 L
.53968 .52606 L
.52606 .53862 L
.50853 .55211 L
.5 .55773 L
.47394 .57183 L
.45901 .57817 L
.44789 .5819 L
.42183 .5885 L
.39578 .59192 L
.36972 .59231 L
.34367 .58968 L
.31761 .58392 L
.29972 .57817 L
.29156 .57477 L
.2655 .56178 L
.25025 .55211 L
.23945 .54409 L
.21914 .52606 L
.21339 .52008 L
.19681 .5 L
Mistroke
.18734 .48608 L
.18031 .47394 L
.16827 .44789 L
.16128 .42714 L
.15996 .42183 L
.15493 .39578 L
.153 .36972 L
.15409 .34367 L
.15823 .31761 L
.16128 .3045 L
.16559 .29156 L
.17653 .2655 L
.18734 .24609 L
.19169 .23945 L
.21221 .21339 L
.21339 .21211 L
.23945 .1881 L
.24041 .18734 L
.2655 .17038 L
.28271 .16128 L
.29156 .15739 L
Mfstroke
1 0 0 r
.03 w
.21687 .20845 Mdot
0 0 1 r
.3794 .36608 Mdot
1 0 0 r
.79703 .00495 m
.79703 .04691 L
.87129 .04691 L
.87129 .00495 L
F
0 0 1 r
.89604 .00495 m
.89604 .21052 L
.9703 .21052 L
.9703 .00495 L
F
1 0 1 r
.04 w
.49778 .59825 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCacheValid->False],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.49505 0.5 0.49505 [
[ 0 0 -0.125 0 ]
[ 0 0 -0.125 0 ]
[ 0 1 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
0 0 m
1 0 L
s
0 0 m
0 1 L
s
0 1 m
1 1 L
s
1 0 m
1 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
1 .5 0 r
.015 w
.03175 .1355 Mdot
.03435 .12523 Mdot
.11137 .12765 Mdot
.14107 .18841 Mdot
.16218 .24538 Mdot
.17294 .21053 Mdot
.18267 .18577 Mdot
.18434 .1304 Mdot
.18553 .30956 Mdot
.20401 .239 Mdot
.21247 .27571 Mdot
.21687 .20845 Mdot
.22376 .2799 Mdot
.22832 .27485 Mdot
.29063 .20974 Mdot
.29686 .25079 Mdot
.30487 .22936 Mdot
.30683 .34623 Mdot
.32055 .20902 Mdot
.32574 .21979 Mdot
.34472 .28521 Mdot
.35998 .36393 Mdot
.36335 .24976 Mdot
.3794 .36608 Mdot
.42386 .66992 Mdot
.44391 .74519 Mdot
.45059 .34198 Mdot
.47208 .67586 Mdot
.47436 .71381 Mdot
.49778 .59825 Mdot
.50874 .91643 Mdot
.51516 .76219 Mdot
.53655 .61374 Mdot
.56563 .75219 Mdot
.59189 .65665 Mdot
.59581 .61604 Mdot
.59923 .6556 Mdot
.60292 .68499 Mdot
.62656 .67779 Mdot
.63555 .72451 Mdot
.63919 .652 Mdot
.64169 .6004 Mdot
.64246 .58611 Mdot
.64496 .54267 Mdot
.64608 .77288 Mdot
.65077 .64308 Mdot
.66065 .57816 Mdot
.67474 .59169 Mdot
.69296 .563 Mdot
.72815 .65902 Mdot
.73169 .58879 Mdot
.74669 .61318 Mdot
.74821 .65474 Mdot
.75963 .63781 Mdot
.79673 .57809 Mdot
.80925 .55852 Mdot
.81525 .58444 Mdot
.83417 .62985 Mdot
.83598 .55526 Mdot
.91595 .49319 Mdot
1 0 0 r
.005 w
.00495 .28842 m
.00628 .29156 L
.01857 .31761 L
.03101 .33781 L
.03525 .34367 L
.05706 .36884 L
.05795 .36972 L
.08312 .39115 L
.08963 .39578 L
.10917 .40763 L
.13523 .41964 L
.14074 .42183 L
.16128 .42794 L
.18734 .43294 L
.21339 .43485 L
.23945 .43375 L
.2655 .42959 L
.29156 .42219 L
.29261 .42183 L
.31761 .41124 L
.34367 .39603 L
.34405 .39578 L
.36972 .37551 L
.37582 .36972 L
.39578 .34724 L
.39849 .34367 L
.41525 .31761 L
.42183 .30485 L
.4275 .29156 L
.436 .2655 L
.44117 .23945 L
.44325 .21339 L
.44232 .18734 L
.43834 .16128 L
.43114 .13523 L
.42183 .11212 L
.42037 .10917 L
.40546 .08312 L
.39578 .06961 L
.38528 .05706 L
.36972 .04137 L
.35758 .03101 L
.34367 .02092 L
.31761 .00569 L
.3162 .00495 L
s
.00495 .12854 m
.01344 .10917 L
.02832 .08312 L
.03101 .07912 L
.04848 .05706 L
.05706 .04802 L
.07619 .03101 L
.08312 .02579 L
.10917 .00934 L
.11742 .00495 L
s
0 0 1 r
.29156 .15739 m
.31761 .14824 L
.34367 .14249 L
.36972 .13986 L
.39578 .14025 L
.42183 .14366 L
.44789 .15025 L
.47394 .16034 L
.47599 .16128 L
.5 .17443 L
.51844 .18734 L
.52606 .19355 L
.54662 .21339 L
.55211 .21962 L
.56712 .23945 L
.57817 .25755 L
.58227 .2655 L
.59322 .29156 L
.60058 .31761 L
.60422 .3392 L
.60471 .34367 L
.6058 .36972 L
.60422 .39297 L
.60387 .39578 L
.59886 .42183 L
.59054 .44789 L
.57848 .47394 L
.57817 .47453 L
.562 .5 L
.55211 .51255 L
.53968 .52606 L
.52606 .53862 L
.50853 .55211 L
.5 .55773 L
.47394 .57183 L
.45901 .57817 L
.44789 .5819 L
.42183 .5885 L
.39578 .59192 L
.36972 .59231 L
.34367 .58968 L
.31761 .58392 L
.29972 .57817 L
.29156 .57477 L
.2655 .56178 L
.25025 .55211 L
.23945 .54409 L
.21914 .52606 L
.21339 .52008 L
.19681 .5 L
Mistroke
.18734 .48608 L
.18031 .47394 L
.16827 .44789 L
.16128 .42714 L
.15996 .42183 L
.15493 .39578 L
.153 .36972 L
.15409 .34367 L
.15823 .31761 L
.16128 .3045 L
.16559 .29156 L
.17653 .2655 L
.18734 .24609 L
.19169 .23945 L
.21221 .21339 L
.21339 .21211 L
.23945 .1881 L
.24041 .18734 L
.2655 .17038 L
.28271 .16128 L
.29156 .15739 L
Mfstroke
1 0 0 r
.03 w
.21687 .20845 Mdot
0 0 1 r
.3794 .36608 Mdot
1 0 0 r
.79703 .00495 m
.79703 .02203 L
.87129 .02203 L
.87129 .00495 L
F
0 0 1 r
.89604 .00495 m
.89604 .2354 L
.9703 .2354 L
.9703 .00495 L
F
1 0 1 r
.04 w
.50874 .91643 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCacheValid->False],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.49505 0.5 0.49505 [
[ 0 0 -0.125 0 ]
[ 0 0 -0.125 0 ]
[ 0 1 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
0 0 m
1 0 L
s
0 0 m
0 1 L
s
0 1 m
1 1 L
s
1 0 m
1 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
1 .5 0 r
.015 w
.03175 .1355 Mdot
.03435 .12523 Mdot
.11137 .12765 Mdot
.14107 .18841 Mdot
.16218 .24538 Mdot
.17294 .21053 Mdot
.18267 .18577 Mdot
.18434 .1304 Mdot
.18553 .30956 Mdot
.20401 .239 Mdot
.21247 .27571 Mdot
.21687 .20845 Mdot
.22376 .2799 Mdot
.22832 .27485 Mdot
.29063 .20974 Mdot
.29686 .25079 Mdot
.30487 .22936 Mdot
.30683 .34623 Mdot
.32055 .20902 Mdot
.32574 .21979 Mdot
.34472 .28521 Mdot
.35998 .36393 Mdot
.36335 .24976 Mdot
.3794 .36608 Mdot
.42386 .66992 Mdot
.44391 .74519 Mdot
.45059 .34198 Mdot
.47208 .67586 Mdot
.47436 .71381 Mdot
.49778 .59825 Mdot
.50874 .91643 Mdot
.51516 .76219 Mdot
.53655 .61374 Mdot
.56563 .75219 Mdot
.59189 .65665 Mdot
.59581 .61604 Mdot
.59923 .6556 Mdot
.60292 .68499 Mdot
.62656 .67779 Mdot
.63555 .72451 Mdot
.63919 .652 Mdot
.64169 .6004 Mdot
.64246 .58611 Mdot
.64496 .54267 Mdot
.64608 .77288 Mdot
.65077 .64308 Mdot
.66065 .57816 Mdot
.67474 .59169 Mdot
.69296 .563 Mdot
.72815 .65902 Mdot
.73169 .58879 Mdot
.74669 .61318 Mdot
.74821 .65474 Mdot
.75963 .63781 Mdot
.79673 .57809 Mdot
.80925 .55852 Mdot
.81525 .58444 Mdot
.83417 .62985 Mdot
.83598 .55526 Mdot
.91595 .49319 Mdot
1 0 0 r
.005 w
.00495 .28842 m
.00628 .29156 L
.01857 .31761 L
.03101 .33781 L
.03525 .34367 L
.05706 .36884 L
.05795 .36972 L
.08312 .39115 L
.08963 .39578 L
.10917 .40763 L
.13523 .41964 L
.14074 .42183 L
.16128 .42794 L
.18734 .43294 L
.21339 .43485 L
.23945 .43375 L
.2655 .42959 L
.29156 .42219 L
.29261 .42183 L
.31761 .41124 L
.34367 .39603 L
.34405 .39578 L
.36972 .37551 L
.37582 .36972 L
.39578 .34724 L
.39849 .34367 L
.41525 .31761 L
.42183 .30485 L
.4275 .29156 L
.436 .2655 L
.44117 .23945 L
.44325 .21339 L
.44232 .18734 L
.43834 .16128 L
.43114 .13523 L
.42183 .11212 L
.42037 .10917 L
.40546 .08312 L
.39578 .06961 L
.38528 .05706 L
.36972 .04137 L
.35758 .03101 L
.34367 .02092 L
.31761 .00569 L
.3162 .00495 L
s
.00495 .12854 m
.01344 .10917 L
.02832 .08312 L
.03101 .07912 L
.04848 .05706 L
.05706 .04802 L
.07619 .03101 L
.08312 .02579 L
.10917 .00934 L
.11742 .00495 L
s
0 0 1 r
.29156 .15739 m
.31761 .14824 L
.34367 .14249 L
.36972 .13986 L
.39578 .14025 L
.42183 .14366 L
.44789 .15025 L
.47394 .16034 L
.47599 .16128 L
.5 .17443 L
.51844 .18734 L
.52606 .19355 L
.54662 .21339 L
.55211 .21962 L
.56712 .23945 L
.57817 .25755 L
.58227 .2655 L
.59322 .29156 L
.60058 .31761 L
.60422 .3392 L
.60471 .34367 L
.6058 .36972 L
.60422 .39297 L
.60387 .39578 L
.59886 .42183 L
.59054 .44789 L
.57848 .47394 L
.57817 .47453 L
.562 .5 L
.55211 .51255 L
.53968 .52606 L
.52606 .53862 L
.50853 .55211 L
.5 .55773 L
.47394 .57183 L
.45901 .57817 L
.44789 .5819 L
.42183 .5885 L
.39578 .59192 L
.36972 .59231 L
.34367 .58968 L
.31761 .58392 L
.29972 .57817 L
.29156 .57477 L
.2655 .56178 L
.25025 .55211 L
.23945 .54409 L
.21914 .52606 L
.21339 .52008 L
.19681 .5 L
Mistroke
.18734 .48608 L
.18031 .47394 L
.16827 .44789 L
.16128 .42714 L
.15996 .42183 L
.15493 .39578 L
.153 .36972 L
.15409 .34367 L
.15823 .31761 L
.16128 .3045 L
.16559 .29156 L
.17653 .2655 L
.18734 .24609 L
.19169 .23945 L
.21221 .21339 L
.21339 .21211 L
.23945 .1881 L
.24041 .18734 L
.2655 .17038 L
.28271 .16128 L
.29156 .15739 L
Mfstroke
1 0 0 r
.03 w
.21687 .20845 Mdot
0 0 1 r
.3794 .36608 Mdot
1 0 0 r
.79703 .00495 m
.79703 .03081 L
.87129 .03081 L
.87129 .00495 L
F
0 0 1 r
.89604 .00495 m
.89604 .22661 L
.9703 .22661 L
.9703 .00495 L
F
1 0 1 r
.04 w
.51516 .76219 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCacheValid->False],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.49505 0.5 0.49505 [
[ 0 0 -0.125 0 ]
[ 0 0 -0.125 0 ]
[ 0 1 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
0 0 m
1 0 L
s
0 0 m
0 1 L
s
0 1 m
1 1 L
s
1 0 m
1 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
1 .5 0 r
.015 w
.03175 .1355 Mdot
.03435 .12523 Mdot
.11137 .12765 Mdot
.14107 .18841 Mdot
.16218 .24538 Mdot
.17294 .21053 Mdot
.18267 .18577 Mdot
.18434 .1304 Mdot
.18553 .30956 Mdot
.20401 .239 Mdot
.21247 .27571 Mdot
.21687 .20845 Mdot
.22376 .2799 Mdot
.22832 .27485 Mdot
.29063 .20974 Mdot
.29686 .25079 Mdot
.30487 .22936 Mdot
.30683 .34623 Mdot
.32055 .20902 Mdot
.32574 .21979 Mdot
.34472 .28521 Mdot
.35998 .36393 Mdot
.36335 .24976 Mdot
.3794 .36608 Mdot
.42386 .66992 Mdot
.44391 .74519 Mdot
.45059 .34198 Mdot
.47208 .67586 Mdot
.47436 .71381 Mdot
.49778 .59825 Mdot
.50874 .91643 Mdot
.51516 .76219 Mdot
.53655 .61374 Mdot
.56563 .75219 Mdot
.59189 .65665 Mdot
.59581 .61604 Mdot
.59923 .6556 Mdot
.60292 .68499 Mdot
.62656 .67779 Mdot
.63555 .72451 Mdot
.63919 .652 Mdot
.64169 .6004 Mdot
.64246 .58611 Mdot
.64496 .54267 Mdot
.64608 .77288 Mdot
.65077 .64308 Mdot
.66065 .57816 Mdot
.67474 .59169 Mdot
.69296 .563 Mdot
.72815 .65902 Mdot
.73169 .58879 Mdot
.74669 .61318 Mdot
.74821 .65474 Mdot
.75963 .63781 Mdot
.79673 .57809 Mdot
.80925 .55852 Mdot
.81525 .58444 Mdot
.83417 .62985 Mdot
.83598 .55526 Mdot
.91595 .49319 Mdot
1 0 0 r
.005 w
.00495 .28842 m
.00628 .29156 L
.01857 .31761 L
.03101 .33781 L
.03525 .34367 L
.05706 .36884 L
.05795 .36972 L
.08312 .39115 L
.08963 .39578 L
.10917 .40763 L
.13523 .41964 L
.14074 .42183 L
.16128 .42794 L
.18734 .43294 L
.21339 .43485 L
.23945 .43375 L
.2655 .42959 L
.29156 .42219 L
.29261 .42183 L
.31761 .41124 L
.34367 .39603 L
.34405 .39578 L
.36972 .37551 L
.37582 .36972 L
.39578 .34724 L
.39849 .34367 L
.41525 .31761 L
.42183 .30485 L
.4275 .29156 L
.436 .2655 L
.44117 .23945 L
.44325 .21339 L
.44232 .18734 L
.43834 .16128 L
.43114 .13523 L
.42183 .11212 L
.42037 .10917 L
.40546 .08312 L
.39578 .06961 L
.38528 .05706 L
.36972 .04137 L
.35758 .03101 L
.34367 .02092 L
.31761 .00569 L
.3162 .00495 L
s
.00495 .12854 m
.01344 .10917 L
.02832 .08312 L
.03101 .07912 L
.04848 .05706 L
.05706 .04802 L
.07619 .03101 L
.08312 .02579 L
.10917 .00934 L
.11742 .00495 L
s
0 0 1 r
.29156 .15739 m
.31761 .14824 L
.34367 .14249 L
.36972 .13986 L
.39578 .14025 L
.42183 .14366 L
.44789 .15025 L
.47394 .16034 L
.47599 .16128 L
.5 .17443 L
.51844 .18734 L
.52606 .19355 L
.54662 .21339 L
.55211 .21962 L
.56712 .23945 L
.57817 .25755 L
.58227 .2655 L
.59322 .29156 L
.60058 .31761 L
.60422 .3392 L
.60471 .34367 L
.6058 .36972 L
.60422 .39297 L
.60387 .39578 L
.59886 .42183 L
.59054 .44789 L
.57848 .47394 L
.57817 .47453 L
.562 .5 L
.55211 .51255 L
.53968 .52606 L
.52606 .53862 L
.50853 .55211 L
.5 .55773 L
.47394 .57183 L
.45901 .57817 L
.44789 .5819 L
.42183 .5885 L
.39578 .59192 L
.36972 .59231 L
.34367 .58968 L
.31761 .58392 L
.29972 .57817 L
.29156 .57477 L
.2655 .56178 L
.25025 .55211 L
.23945 .54409 L
.21914 .52606 L
.21339 .52008 L
.19681 .5 L
Mistroke
.18734 .48608 L
.18031 .47394 L
.16827 .44789 L
.16128 .42714 L
.15996 .42183 L
.15493 .39578 L
.153 .36972 L
.15409 .34367 L
.15823 .31761 L
.16128 .3045 L
.16559 .29156 L
.17653 .2655 L
.18734 .24609 L
.19169 .23945 L
.21221 .21339 L
.21339 .21211 L
.23945 .1881 L
.24041 .18734 L
.2655 .17038 L
.28271 .16128 L
.29156 .15739 L
Mfstroke
1 0 0 r
.03 w
.21687 .20845 Mdot
0 0 1 r
.3794 .36608 Mdot
1 0 0 r
.79703 .00495 m
.79703 .04129 L
.87129 .04129 L
.87129 .00495 L
F
0 0 1 r
.89604 .00495 m
.89604 .21613 L
.9703 .21613 L
.9703 .00495 L
F
1 0 1 r
.04 w
.53655 .61374 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCacheValid->False],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.49505 0.5 0.49505 [
[ 0 0 -0.125 0 ]
[ 0 0 -0.125 0 ]
[ 0 1 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
0 0 m
1 0 L
s
0 0 m
0 1 L
s
0 1 m
1 1 L
s
1 0 m
1 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
1 .5 0 r
.015 w
.03175 .1355 Mdot
.03435 .12523 Mdot
.11137 .12765 Mdot
.14107 .18841 Mdot
.16218 .24538 Mdot
.17294 .21053 Mdot
.18267 .18577 Mdot
.18434 .1304 Mdot
.18553 .30956 Mdot
.20401 .239 Mdot
.21247 .27571 Mdot
.21687 .20845 Mdot
.22376 .2799 Mdot
.22832 .27485 Mdot
.29063 .20974 Mdot
.29686 .25079 Mdot
.30487 .22936 Mdot
.30683 .34623 Mdot
.32055 .20902 Mdot
.32574 .21979 Mdot
.34472 .28521 Mdot
.35998 .36393 Mdot
.36335 .24976 Mdot
.3794 .36608 Mdot
.42386 .66992 Mdot
.44391 .74519 Mdot
.45059 .34198 Mdot
.47208 .67586 Mdot
.47436 .71381 Mdot
.49778 .59825 Mdot
.50874 .91643 Mdot
.51516 .76219 Mdot
.53655 .61374 Mdot
.56563 .75219 Mdot
.59189 .65665 Mdot
.59581 .61604 Mdot
.59923 .6556 Mdot
.60292 .68499 Mdot
.62656 .67779 Mdot
.63555 .72451 Mdot
.63919 .652 Mdot
.64169 .6004 Mdot
.64246 .58611 Mdot
.64496 .54267 Mdot
.64608 .77288 Mdot
.65077 .64308 Mdot
.66065 .57816 Mdot
.67474 .59169 Mdot
.69296 .563 Mdot
.72815 .65902 Mdot
.73169 .58879 Mdot
.74669 .61318 Mdot
.74821 .65474 Mdot
.75963 .63781 Mdot
.79673 .57809 Mdot
.80925 .55852 Mdot
.81525 .58444 Mdot
.83417 .62985 Mdot
.83598 .55526 Mdot
.91595 .49319 Mdot
1 0 0 r
.005 w
.00495 .28842 m
.00628 .29156 L
.01857 .31761 L
.03101 .33781 L
.03525 .34367 L
.05706 .36884 L
.05795 .36972 L
.08312 .39115 L
.08963 .39578 L
.10917 .40763 L
.13523 .41964 L
.14074 .42183 L
.16128 .42794 L
.18734 .43294 L
.21339 .43485 L
.23945 .43375 L
.2655 .42959 L
.29156 .42219 L
.29261 .42183 L
.31761 .41124 L
.34367 .39603 L
.34405 .39578 L
.36972 .37551 L
.37582 .36972 L
.39578 .34724 L
.39849 .34367 L
.41525 .31761 L
.42183 .30485 L
.4275 .29156 L
.436 .2655 L
.44117 .23945 L
.44325 .21339 L
.44232 .18734 L
.43834 .16128 L
.43114 .13523 L
.42183 .11212 L
.42037 .10917 L
.40546 .08312 L
.39578 .06961 L
.38528 .05706 L
.36972 .04137 L
.35758 .03101 L
.34367 .02092 L
.31761 .00569 L
.3162 .00495 L
s
.00495 .12854 m
.01344 .10917 L
.02832 .08312 L
.03101 .07912 L
.04848 .05706 L
.05706 .04802 L
.07619 .03101 L
.08312 .02579 L
.10917 .00934 L
.11742 .00495 L
s
0 0 1 r
.29156 .15739 m
.31761 .14824 L
.34367 .14249 L
.36972 .13986 L
.39578 .14025 L
.42183 .14366 L
.44789 .15025 L
.47394 .16034 L
.47599 .16128 L
.5 .17443 L
.51844 .18734 L
.52606 .19355 L
.54662 .21339 L
.55211 .21962 L
.56712 .23945 L
.57817 .25755 L
.58227 .2655 L
.59322 .29156 L
.60058 .31761 L
.60422 .3392 L
.60471 .34367 L
.6058 .36972 L
.60422 .39297 L
.60387 .39578 L
.59886 .42183 L
.59054 .44789 L
.57848 .47394 L
.57817 .47453 L
.562 .5 L
.55211 .51255 L
.53968 .52606 L
.52606 .53862 L
.50853 .55211 L
.5 .55773 L
.47394 .57183 L
.45901 .57817 L
.44789 .5819 L
.42183 .5885 L
.39578 .59192 L
.36972 .59231 L
.34367 .58968 L
.31761 .58392 L
.29972 .57817 L
.29156 .57477 L
.2655 .56178 L
.25025 .55211 L
.23945 .54409 L
.21914 .52606 L
.21339 .52008 L
.19681 .5 L
Mistroke
.18734 .48608 L
.18031 .47394 L
.16827 .44789 L
.16128 .42714 L
.15996 .42183 L
.15493 .39578 L
.153 .36972 L
.15409 .34367 L
.15823 .31761 L
.16128 .3045 L
.16559 .29156 L
.17653 .2655 L
.18734 .24609 L
.19169 .23945 L
.21221 .21339 L
.21339 .21211 L
.23945 .1881 L
.24041 .18734 L
.2655 .17038 L
.28271 .16128 L
.29156 .15739 L
Mfstroke
1 0 0 r
.03 w
.21687 .20845 Mdot
0 0 1 r
.3794 .36608 Mdot
1 0 0 r
.79703 .00495 m
.79703 .02797 L
.87129 .02797 L
.87129 .00495 L
F
0 0 1 r
.89604 .00495 m
.89604 .22946 L
.9703 .22946 L
.9703 .00495 L
F
1 0 1 r
.04 w
.56563 .75219 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCacheValid->False],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.49505 0.5 0.49505 [
[ 0 0 -0.125 0 ]
[ 0 0 -0.125 0 ]
[ 0 1 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
0 0 m
1 0 L
s
0 0 m
0 1 L
s
0 1 m
1 1 L
s
1 0 m
1 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
1 .5 0 r
.015 w
.03175 .1355 Mdot
.03435 .12523 Mdot
.11137 .12765 Mdot
.14107 .18841 Mdot
.16218 .24538 Mdot
.17294 .21053 Mdot
.18267 .18577 Mdot
.18434 .1304 Mdot
.18553 .30956 Mdot
.20401 .239 Mdot
.21247 .27571 Mdot
.21687 .20845 Mdot
.22376 .2799 Mdot
.22832 .27485 Mdot
.29063 .20974 Mdot
.29686 .25079 Mdot
.30487 .22936 Mdot
.30683 .34623 Mdot
.32055 .20902 Mdot
.32574 .21979 Mdot
.34472 .28521 Mdot
.35998 .36393 Mdot
.36335 .24976 Mdot
.3794 .36608 Mdot
.42386 .66992 Mdot
.44391 .74519 Mdot
.45059 .34198 Mdot
.47208 .67586 Mdot
.47436 .71381 Mdot
.49778 .59825 Mdot
.50874 .91643 Mdot
.51516 .76219 Mdot
.53655 .61374 Mdot
.56563 .75219 Mdot
.59189 .65665 Mdot
.59581 .61604 Mdot
.59923 .6556 Mdot
.60292 .68499 Mdot
.62656 .67779 Mdot
.63555 .72451 Mdot
.63919 .652 Mdot
.64169 .6004 Mdot
.64246 .58611 Mdot
.64496 .54267 Mdot
.64608 .77288 Mdot
.65077 .64308 Mdot
.66065 .57816 Mdot
.67474 .59169 Mdot
.69296 .563 Mdot
.72815 .65902 Mdot
.73169 .58879 Mdot
.74669 .61318 Mdot
.74821 .65474 Mdot
.75963 .63781 Mdot
.79673 .57809 Mdot
.80925 .55852 Mdot
.81525 .58444 Mdot
.83417 .62985 Mdot
.83598 .55526 Mdot
.91595 .49319 Mdot
1 0 0 r
.005 w
.00495 .28842 m
.00628 .29156 L
.01857 .31761 L
.03101 .33781 L
.03525 .34367 L
.05706 .36884 L
.05795 .36972 L
.08312 .39115 L
.08963 .39578 L
.10917 .40763 L
.13523 .41964 L
.14074 .42183 L
.16128 .42794 L
.18734 .43294 L
.21339 .43485 L
.23945 .43375 L
.2655 .42959 L
.29156 .42219 L
.29261 .42183 L
.31761 .41124 L
.34367 .39603 L
.34405 .39578 L
.36972 .37551 L
.37582 .36972 L
.39578 .34724 L
.39849 .34367 L
.41525 .31761 L
.42183 .30485 L
.4275 .29156 L
.436 .2655 L
.44117 .23945 L
.44325 .21339 L
.44232 .18734 L
.43834 .16128 L
.43114 .13523 L
.42183 .11212 L
.42037 .10917 L
.40546 .08312 L
.39578 .06961 L
.38528 .05706 L
.36972 .04137 L
.35758 .03101 L
.34367 .02092 L
.31761 .00569 L
.3162 .00495 L
s
.00495 .12854 m
.01344 .10917 L
.02832 .08312 L
.03101 .07912 L
.04848 .05706 L
.05706 .04802 L
.07619 .03101 L
.08312 .02579 L
.10917 .00934 L
.11742 .00495 L
s
0 0 1 r
.29156 .15739 m
.31761 .14824 L
.34367 .14249 L
.36972 .13986 L
.39578 .14025 L
.42183 .14366 L
.44789 .15025 L
.47394 .16034 L
.47599 .16128 L
.5 .17443 L
.51844 .18734 L
.52606 .19355 L
.54662 .21339 L
.55211 .21962 L
.56712 .23945 L
.57817 .25755 L
.58227 .2655 L
.59322 .29156 L
.60058 .31761 L
.60422 .3392 L
.60471 .34367 L
.6058 .36972 L
.60422 .39297 L
.60387 .39578 L
.59886 .42183 L
.59054 .44789 L
.57848 .47394 L
.57817 .47453 L
.562 .5 L
.55211 .51255 L
.53968 .52606 L
.52606 .53862 L
.50853 .55211 L
.5 .55773 L
.47394 .57183 L
.45901 .57817 L
.44789 .5819 L
.42183 .5885 L
.39578 .59192 L
.36972 .59231 L
.34367 .58968 L
.31761 .58392 L
.29972 .57817 L
.29156 .57477 L
.2655 .56178 L
.25025 .55211 L
.23945 .54409 L
.21914 .52606 L
.21339 .52008 L
.19681 .5 L
Mistroke
.18734 .48608 L
.18031 .47394 L
.16827 .44789 L
.16128 .42714 L
.15996 .42183 L
.15493 .39578 L
.153 .36972 L
.15409 .34367 L
.15823 .31761 L
.16128 .3045 L
.16559 .29156 L
.17653 .2655 L
.18734 .24609 L
.19169 .23945 L
.21221 .21339 L
.21339 .21211 L
.23945 .1881 L
.24041 .18734 L
.2655 .17038 L
.28271 .16128 L
.29156 .15739 L
Mfstroke
1 0 0 r
.03 w
.21687 .20845 Mdot
0 0 1 r
.3794 .36608 Mdot
1 0 0 r
.79703 .00495 m
.79703 .03276 L
.87129 .03276 L
.87129 .00495 L
F
0 0 1 r
.89604 .00495 m
.89604 .22467 L
.9703 .22467 L
.9703 .00495 L
F
1 0 1 r
.04 w
.59189 .65665 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCacheValid->False],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.49505 0.5 0.49505 [
[ 0 0 -0.125 0 ]
[ 0 0 -0.125 0 ]
[ 0 1 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
0 0 m
1 0 L
s
0 0 m
0 1 L
s
0 1 m
1 1 L
s
1 0 m
1 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
1 .5 0 r
.015 w
.03175 .1355 Mdot
.03435 .12523 Mdot
.11137 .12765 Mdot
.14107 .18841 Mdot
.16218 .24538 Mdot
.17294 .21053 Mdot
.18267 .18577 Mdot
.18434 .1304 Mdot
.18553 .30956 Mdot
.20401 .239 Mdot
.21247 .27571 Mdot
.21687 .20845 Mdot
.22376 .2799 Mdot
.22832 .27485 Mdot
.29063 .20974 Mdot
.29686 .25079 Mdot
.30487 .22936 Mdot
.30683 .34623 Mdot
.32055 .20902 Mdot
.32574 .21979 Mdot
.34472 .28521 Mdot
.35998 .36393 Mdot
.36335 .24976 Mdot
.3794 .36608 Mdot
.42386 .66992 Mdot
.44391 .74519 Mdot
.45059 .34198 Mdot
.47208 .67586 Mdot
.47436 .71381 Mdot
.49778 .59825 Mdot
.50874 .91643 Mdot
.51516 .76219 Mdot
.53655 .61374 Mdot
.56563 .75219 Mdot
.59189 .65665 Mdot
.59581 .61604 Mdot
.59923 .6556 Mdot
.60292 .68499 Mdot
.62656 .67779 Mdot
.63555 .72451 Mdot
.63919 .652 Mdot
.64169 .6004 Mdot
.64246 .58611 Mdot
.64496 .54267 Mdot
.64608 .77288 Mdot
.65077 .64308 Mdot
.66065 .57816 Mdot
.67474 .59169 Mdot
.69296 .563 Mdot
.72815 .65902 Mdot
.73169 .58879 Mdot
.74669 .61318 Mdot
.74821 .65474 Mdot
.75963 .63781 Mdot
.79673 .57809 Mdot
.80925 .55852 Mdot
.81525 .58444 Mdot
.83417 .62985 Mdot
.83598 .55526 Mdot
.91595 .49319 Mdot
1 0 0 r
.005 w
.00495 .28842 m
.00628 .29156 L
.01857 .31761 L
.03101 .33781 L
.03525 .34367 L
.05706 .36884 L
.05795 .36972 L
.08312 .39115 L
.08963 .39578 L
.10917 .40763 L
.13523 .41964 L
.14074 .42183 L
.16128 .42794 L
.18734 .43294 L
.21339 .43485 L
.23945 .43375 L
.2655 .42959 L
.29156 .42219 L
.29261 .42183 L
.31761 .41124 L
.34367 .39603 L
.34405 .39578 L
.36972 .37551 L
.37582 .36972 L
.39578 .34724 L
.39849 .34367 L
.41525 .31761 L
.42183 .30485 L
.4275 .29156 L
.436 .2655 L
.44117 .23945 L
.44325 .21339 L
.44232 .18734 L
.43834 .16128 L
.43114 .13523 L
.42183 .11212 L
.42037 .10917 L
.40546 .08312 L
.39578 .06961 L
.38528 .05706 L
.36972 .04137 L
.35758 .03101 L
.34367 .02092 L
.31761 .00569 L
.3162 .00495 L
s
.00495 .12854 m
.01344 .10917 L
.02832 .08312 L
.03101 .07912 L
.04848 .05706 L
.05706 .04802 L
.07619 .03101 L
.08312 .02579 L
.10917 .00934 L
.11742 .00495 L
s
0 0 1 r
.29156 .15739 m
.31761 .14824 L
.34367 .14249 L
.36972 .13986 L
.39578 .14025 L
.42183 .14366 L
.44789 .15025 L
.47394 .16034 L
.47599 .16128 L
.5 .17443 L
.51844 .18734 L
.52606 .19355 L
.54662 .21339 L
.55211 .21962 L
.56712 .23945 L
.57817 .25755 L
.58227 .2655 L
.59322 .29156 L
.60058 .31761 L
.60422 .3392 L
.60471 .34367 L
.6058 .36972 L
.60422 .39297 L
.60387 .39578 L
.59886 .42183 L
.59054 .44789 L
.57848 .47394 L
.57817 .47453 L
.562 .5 L
.55211 .51255 L
.53968 .52606 L
.52606 .53862 L
.50853 .55211 L
.5 .55773 L
.47394 .57183 L
.45901 .57817 L
.44789 .5819 L
.42183 .5885 L
.39578 .59192 L
.36972 .59231 L
.34367 .58968 L
.31761 .58392 L
.29972 .57817 L
.29156 .57477 L
.2655 .56178 L
.25025 .55211 L
.23945 .54409 L
.21914 .52606 L
.21339 .52008 L
.19681 .5 L
Mistroke
.18734 .48608 L
.18031 .47394 L
.16827 .44789 L
.16128 .42714 L
.15996 .42183 L
.15493 .39578 L
.153 .36972 L
.15409 .34367 L
.15823 .31761 L
.16128 .3045 L
.16559 .29156 L
.17653 .2655 L
.18734 .24609 L
.19169 .23945 L
.21221 .21339 L
.21339 .21211 L
.23945 .1881 L
.24041 .18734 L
.2655 .17038 L
.28271 .16128 L
.29156 .15739 L
Mfstroke
1 0 0 r
.03 w
.21687 .20845 Mdot
0 0 1 r
.3794 .36608 Mdot
1 0 0 r
.79703 .00495 m
.79703 .03565 L
.87129 .03565 L
.87129 .00495 L
F
0 0 1 r
.89604 .00495 m
.89604 .22177 L
.9703 .22177 L
.9703 .00495 L
F
1 0 1 r
.04 w
.59581 .61604 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCacheValid->False],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.49505 0.5 0.49505 [
[ 0 0 -0.125 0 ]
[ 0 0 -0.125 0 ]
[ 0 1 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
0 0 m
1 0 L
s
0 0 m
0 1 L
s
0 1 m
1 1 L
s
1 0 m
1 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
1 .5 0 r
.015 w
.03175 .1355 Mdot
.03435 .12523 Mdot
.11137 .12765 Mdot
.14107 .18841 Mdot
.16218 .24538 Mdot
.17294 .21053 Mdot
.18267 .18577 Mdot
.18434 .1304 Mdot
.18553 .30956 Mdot
.20401 .239 Mdot
.21247 .27571 Mdot
.21687 .20845 Mdot
.22376 .2799 Mdot
.22832 .27485 Mdot
.29063 .20974 Mdot
.29686 .25079 Mdot
.30487 .22936 Mdot
.30683 .34623 Mdot
.32055 .20902 Mdot
.32574 .21979 Mdot
.34472 .28521 Mdot
.35998 .36393 Mdot
.36335 .24976 Mdot
.3794 .36608 Mdot
.42386 .66992 Mdot
.44391 .74519 Mdot
.45059 .34198 Mdot
.47208 .67586 Mdot
.47436 .71381 Mdot
.49778 .59825 Mdot
.50874 .91643 Mdot
.51516 .76219 Mdot
.53655 .61374 Mdot
.56563 .75219 Mdot
.59189 .65665 Mdot
.59581 .61604 Mdot
.59923 .6556 Mdot
.60292 .68499 Mdot
.62656 .67779 Mdot
.63555 .72451 Mdot
.63919 .652 Mdot
.64169 .6004 Mdot
.64246 .58611 Mdot
.64496 .54267 Mdot
.64608 .77288 Mdot
.65077 .64308 Mdot
.66065 .57816 Mdot
.67474 .59169 Mdot
.69296 .563 Mdot
.72815 .65902 Mdot
.73169 .58879 Mdot
.74669 .61318 Mdot
.74821 .65474 Mdot
.75963 .63781 Mdot
.79673 .57809 Mdot
.80925 .55852 Mdot
.81525 .58444 Mdot
.83417 .62985 Mdot
.83598 .55526 Mdot
.91595 .49319 Mdot
1 0 0 r
.005 w
.00495 .28842 m
.00628 .29156 L
.01857 .31761 L
.03101 .33781 L
.03525 .34367 L
.05706 .36884 L
.05795 .36972 L
.08312 .39115 L
.08963 .39578 L
.10917 .40763 L
.13523 .41964 L
.14074 .42183 L
.16128 .42794 L
.18734 .43294 L
.21339 .43485 L
.23945 .43375 L
.2655 .42959 L
.29156 .42219 L
.29261 .42183 L
.31761 .41124 L
.34367 .39603 L
.34405 .39578 L
.36972 .37551 L
.37582 .36972 L
.39578 .34724 L
.39849 .34367 L
.41525 .31761 L
.42183 .30485 L
.4275 .29156 L
.436 .2655 L
.44117 .23945 L
.44325 .21339 L
.44232 .18734 L
.43834 .16128 L
.43114 .13523 L
.42183 .11212 L
.42037 .10917 L
.40546 .08312 L
.39578 .06961 L
.38528 .05706 L
.36972 .04137 L
.35758 .03101 L
.34367 .02092 L
.31761 .00569 L
.3162 .00495 L
s
.00495 .12854 m
.01344 .10917 L
.02832 .08312 L
.03101 .07912 L
.04848 .05706 L
.05706 .04802 L
.07619 .03101 L
.08312 .02579 L
.10917 .00934 L
.11742 .00495 L
s
0 0 1 r
.29156 .15739 m
.31761 .14824 L
.34367 .14249 L
.36972 .13986 L
.39578 .14025 L
.42183 .14366 L
.44789 .15025 L
.47394 .16034 L
.47599 .16128 L
.5 .17443 L
.51844 .18734 L
.52606 .19355 L
.54662 .21339 L
.55211 .21962 L
.56712 .23945 L
.57817 .25755 L
.58227 .2655 L
.59322 .29156 L
.60058 .31761 L
.60422 .3392 L
.60471 .34367 L
.6058 .36972 L
.60422 .39297 L
.60387 .39578 L
.59886 .42183 L
.59054 .44789 L
.57848 .47394 L
.57817 .47453 L
.562 .5 L
.55211 .51255 L
.53968 .52606 L
.52606 .53862 L
.50853 .55211 L
.5 .55773 L
.47394 .57183 L
.45901 .57817 L
.44789 .5819 L
.42183 .5885 L
.39578 .59192 L
.36972 .59231 L
.34367 .58968 L
.31761 .58392 L
.29972 .57817 L
.29156 .57477 L
.2655 .56178 L
.25025 .55211 L
.23945 .54409 L
.21914 .52606 L
.21339 .52008 L
.19681 .5 L
Mistroke
.18734 .48608 L
.18031 .47394 L
.16827 .44789 L
.16128 .42714 L
.15996 .42183 L
.15493 .39578 L
.153 .36972 L
.15409 .34367 L
.15823 .31761 L
.16128 .3045 L
.16559 .29156 L
.17653 .2655 L
.18734 .24609 L
.19169 .23945 L
.21221 .21339 L
.21339 .21211 L
.23945 .1881 L
.24041 .18734 L
.2655 .17038 L
.28271 .16128 L
.29156 .15739 L
Mfstroke
1 0 0 r
.03 w
.21687 .20845 Mdot
0 0 1 r
.3794 .36608 Mdot
1 0 0 r
.79703 .00495 m
.79703 .03227 L
.87129 .03227 L
.87129 .00495 L
F
0 0 1 r
.89604 .00495 m
.89604 .22516 L
.9703 .22516 L
.9703 .00495 L
F
1 0 1 r
.04 w
.59923 .6556 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCacheValid->False],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.49505 0.5 0.49505 [
[ 0 0 -0.125 0 ]
[ 0 0 -0.125 0 ]
[ 0 1 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
0 0 m
1 0 L
s
0 0 m
0 1 L
s
0 1 m
1 1 L
s
1 0 m
1 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
1 .5 0 r
.015 w
.03175 .1355 Mdot
.03435 .12523 Mdot
.11137 .12765 Mdot
.14107 .18841 Mdot
.16218 .24538 Mdot
.17294 .21053 Mdot
.18267 .18577 Mdot
.18434 .1304 Mdot
.18553 .30956 Mdot
.20401 .239 Mdot
.21247 .27571 Mdot
.21687 .20845 Mdot
.22376 .2799 Mdot
.22832 .27485 Mdot
.29063 .20974 Mdot
.29686 .25079 Mdot
.30487 .22936 Mdot
.30683 .34623 Mdot
.32055 .20902 Mdot
.32574 .21979 Mdot
.34472 .28521 Mdot
.35998 .36393 Mdot
.36335 .24976 Mdot
.3794 .36608 Mdot
.42386 .66992 Mdot
.44391 .74519 Mdot
.45059 .34198 Mdot
.47208 .67586 Mdot
.47436 .71381 Mdot
.49778 .59825 Mdot
.50874 .91643 Mdot
.51516 .76219 Mdot
.53655 .61374 Mdot
.56563 .75219 Mdot
.59189 .65665 Mdot
.59581 .61604 Mdot
.59923 .6556 Mdot
.60292 .68499 Mdot
.62656 .67779 Mdot
.63555 .72451 Mdot
.63919 .652 Mdot
.64169 .6004 Mdot
.64246 .58611 Mdot
.64496 .54267 Mdot
.64608 .77288 Mdot
.65077 .64308 Mdot
.66065 .57816 Mdot
.67474 .59169 Mdot
.69296 .563 Mdot
.72815 .65902 Mdot
.73169 .58879 Mdot
.74669 .61318 Mdot
.74821 .65474 Mdot
.75963 .63781 Mdot
.79673 .57809 Mdot
.80925 .55852 Mdot
.81525 .58444 Mdot
.83417 .62985 Mdot
.83598 .55526 Mdot
.91595 .49319 Mdot
1 0 0 r
.005 w
.00495 .28842 m
.00628 .29156 L
.01857 .31761 L
.03101 .33781 L
.03525 .34367 L
.05706 .36884 L
.05795 .36972 L
.08312 .39115 L
.08963 .39578 L
.10917 .40763 L
.13523 .41964 L
.14074 .42183 L
.16128 .42794 L
.18734 .43294 L
.21339 .43485 L
.23945 .43375 L
.2655 .42959 L
.29156 .42219 L
.29261 .42183 L
.31761 .41124 L
.34367 .39603 L
.34405 .39578 L
.36972 .37551 L
.37582 .36972 L
.39578 .34724 L
.39849 .34367 L
.41525 .31761 L
.42183 .30485 L
.4275 .29156 L
.436 .2655 L
.44117 .23945 L
.44325 .21339 L
.44232 .18734 L
.43834 .16128 L
.43114 .13523 L
.42183 .11212 L
.42037 .10917 L
.40546 .08312 L
.39578 .06961 L
.38528 .05706 L
.36972 .04137 L
.35758 .03101 L
.34367 .02092 L
.31761 .00569 L
.3162 .00495 L
s
.00495 .12854 m
.01344 .10917 L
.02832 .08312 L
.03101 .07912 L
.04848 .05706 L
.05706 .04802 L
.07619 .03101 L
.08312 .02579 L
.10917 .00934 L
.11742 .00495 L
s
0 0 1 r
.29156 .15739 m
.31761 .14824 L
.34367 .14249 L
.36972 .13986 L
.39578 .14025 L
.42183 .14366 L
.44789 .15025 L
.47394 .16034 L
.47599 .16128 L
.5 .17443 L
.51844 .18734 L
.52606 .19355 L
.54662 .21339 L
.55211 .21962 L
.56712 .23945 L
.57817 .25755 L
.58227 .2655 L
.59322 .29156 L
.60058 .31761 L
.60422 .3392 L
.60471 .34367 L
.6058 .36972 L
.60422 .39297 L
.60387 .39578 L
.59886 .42183 L
.59054 .44789 L
.57848 .47394 L
.57817 .47453 L
.562 .5 L
.55211 .51255 L
.53968 .52606 L
.52606 .53862 L
.50853 .55211 L
.5 .55773 L
.47394 .57183 L
.45901 .57817 L
.44789 .5819 L
.42183 .5885 L
.39578 .59192 L
.36972 .59231 L
.34367 .58968 L
.31761 .58392 L
.29972 .57817 L
.29156 .57477 L
.2655 .56178 L
.25025 .55211 L
.23945 .54409 L
.21914 .52606 L
.21339 .52008 L
.19681 .5 L
Mistroke
.18734 .48608 L
.18031 .47394 L
.16827 .44789 L
.16128 .42714 L
.15996 .42183 L
.15493 .39578 L
.153 .36972 L
.15409 .34367 L
.15823 .31761 L
.16128 .3045 L
.16559 .29156 L
.17653 .2655 L
.18734 .24609 L
.19169 .23945 L
.21221 .21339 L
.21339 .21211 L
.23945 .1881 L
.24041 .18734 L
.2655 .17038 L
.28271 .16128 L
.29156 .15739 L
Mfstroke
1 0 0 r
.03 w
.21687 .20845 Mdot
0 0 1 r
.3794 .36608 Mdot
1 0 0 r
.79703 .00495 m
.79703 .02988 L
.87129 .02988 L
.87129 .00495 L
F
0 0 1 r
.89604 .00495 m
.89604 .22754 L
.9703 .22754 L
.9703 .00495 L
F
1 0 1 r
.04 w
.60292 .68499 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCacheValid->False],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.49505 0.5 0.49505 [
[ 0 0 -0.125 0 ]
[ 0 0 -0.125 0 ]
[ 0 1 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
0 0 m
1 0 L
s
0 0 m
0 1 L
s
0 1 m
1 1 L
s
1 0 m
1 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
1 .5 0 r
.015 w
.03175 .1355 Mdot
.03435 .12523 Mdot
.11137 .12765 Mdot
.14107 .18841 Mdot
.16218 .24538 Mdot
.17294 .21053 Mdot
.18267 .18577 Mdot
.18434 .1304 Mdot
.18553 .30956 Mdot
.20401 .239 Mdot
.21247 .27571 Mdot
.21687 .20845 Mdot
.22376 .2799 Mdot
.22832 .27485 Mdot
.29063 .20974 Mdot
.29686 .25079 Mdot
.30487 .22936 Mdot
.30683 .34623 Mdot
.32055 .20902 Mdot
.32574 .21979 Mdot
.34472 .28521 Mdot
.35998 .36393 Mdot
.36335 .24976 Mdot
.3794 .36608 Mdot
.42386 .66992 Mdot
.44391 .74519 Mdot
.45059 .34198 Mdot
.47208 .67586 Mdot
.47436 .71381 Mdot
.49778 .59825 Mdot
.50874 .91643 Mdot
.51516 .76219 Mdot
.53655 .61374 Mdot
.56563 .75219 Mdot
.59189 .65665 Mdot
.59581 .61604 Mdot
.59923 .6556 Mdot
.60292 .68499 Mdot
.62656 .67779 Mdot
.63555 .72451 Mdot
.63919 .652 Mdot
.64169 .6004 Mdot
.64246 .58611 Mdot
.64496 .54267 Mdot
.64608 .77288 Mdot
.65077 .64308 Mdot
.66065 .57816 Mdot
.67474 .59169 Mdot
.69296 .563 Mdot
.72815 .65902 Mdot
.73169 .58879 Mdot
.74669 .61318 Mdot
.74821 .65474 Mdot
.75963 .63781 Mdot
.79673 .57809 Mdot
.80925 .55852 Mdot
.81525 .58444 Mdot
.83417 .62985 Mdot
.83598 .55526 Mdot
.91595 .49319 Mdot
1 0 0 r
.005 w
.00495 .28842 m
.00628 .29156 L
.01857 .31761 L
.03101 .33781 L
.03525 .34367 L
.05706 .36884 L
.05795 .36972 L
.08312 .39115 L
.08963 .39578 L
.10917 .40763 L
.13523 .41964 L
.14074 .42183 L
.16128 .42794 L
.18734 .43294 L
.21339 .43485 L
.23945 .43375 L
.2655 .42959 L
.29156 .42219 L
.29261 .42183 L
.31761 .41124 L
.34367 .39603 L
.34405 .39578 L
.36972 .37551 L
.37582 .36972 L
.39578 .34724 L
.39849 .34367 L
.41525 .31761 L
.42183 .30485 L
.4275 .29156 L
.436 .2655 L
.44117 .23945 L
.44325 .21339 L
.44232 .18734 L
.43834 .16128 L
.43114 .13523 L
.42183 .11212 L
.42037 .10917 L
.40546 .08312 L
.39578 .06961 L
.38528 .05706 L
.36972 .04137 L
.35758 .03101 L
.34367 .02092 L
.31761 .00569 L
.3162 .00495 L
s
.00495 .12854 m
.01344 .10917 L
.02832 .08312 L
.03101 .07912 L
.04848 .05706 L
.05706 .04802 L
.07619 .03101 L
.08312 .02579 L
.10917 .00934 L
.11742 .00495 L
s
0 0 1 r
.29156 .15739 m
.31761 .14824 L
.34367 .14249 L
.36972 .13986 L
.39578 .14025 L
.42183 .14366 L
.44789 .15025 L
.47394 .16034 L
.47599 .16128 L
.5 .17443 L
.51844 .18734 L
.52606 .19355 L
.54662 .21339 L
.55211 .21962 L
.56712 .23945 L
.57817 .25755 L
.58227 .2655 L
.59322 .29156 L
.60058 .31761 L
.60422 .3392 L
.60471 .34367 L
.6058 .36972 L
.60422 .39297 L
.60387 .39578 L
.59886 .42183 L
.59054 .44789 L
.57848 .47394 L
.57817 .47453 L
.562 .5 L
.55211 .51255 L
.53968 .52606 L
.52606 .53862 L
.50853 .55211 L
.5 .55773 L
.47394 .57183 L
.45901 .57817 L
.44789 .5819 L
.42183 .5885 L
.39578 .59192 L
.36972 .59231 L
.34367 .58968 L
.31761 .58392 L
.29972 .57817 L
.29156 .57477 L
.2655 .56178 L
.25025 .55211 L
.23945 .54409 L
.21914 .52606 L
.21339 .52008 L
.19681 .5 L
Mistroke
.18734 .48608 L
.18031 .47394 L
.16827 .44789 L
.16128 .42714 L
.15996 .42183 L
.15493 .39578 L
.153 .36972 L
.15409 .34367 L
.15823 .31761 L
.16128 .3045 L
.16559 .29156 L
.17653 .2655 L
.18734 .24609 L
.19169 .23945 L
.21221 .21339 L
.21339 .21211 L
.23945 .1881 L
.24041 .18734 L
.2655 .17038 L
.28271 .16128 L
.29156 .15739 L
Mfstroke
1 0 0 r
.03 w
.21687 .20845 Mdot
0 0 1 r
.3794 .36608 Mdot
1 0 0 r
.79703 .00495 m
.79703 .02872 L
.87129 .02872 L
.87129 .00495 L
F
0 0 1 r
.89604 .00495 m
.89604 .2287 L
.9703 .2287 L
.9703 .00495 L
F
1 0 1 r
.04 w
.62656 .67779 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCacheValid->False],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.49505 0.5 0.49505 [
[ 0 0 -0.125 0 ]
[ 0 0 -0.125 0 ]
[ 0 1 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
0 0 m
1 0 L
s
0 0 m
0 1 L
s
0 1 m
1 1 L
s
1 0 m
1 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
1 .5 0 r
.015 w
.03175 .1355 Mdot
.03435 .12523 Mdot
.11137 .12765 Mdot
.14107 .18841 Mdot
.16218 .24538 Mdot
.17294 .21053 Mdot
.18267 .18577 Mdot
.18434 .1304 Mdot
.18553 .30956 Mdot
.20401 .239 Mdot
.21247 .27571 Mdot
.21687 .20845 Mdot
.22376 .2799 Mdot
.22832 .27485 Mdot
.29063 .20974 Mdot
.29686 .25079 Mdot
.30487 .22936 Mdot
.30683 .34623 Mdot
.32055 .20902 Mdot
.32574 .21979 Mdot
.34472 .28521 Mdot
.35998 .36393 Mdot
.36335 .24976 Mdot
.3794 .36608 Mdot
.42386 .66992 Mdot
.44391 .74519 Mdot
.45059 .34198 Mdot
.47208 .67586 Mdot
.47436 .71381 Mdot
.49778 .59825 Mdot
.50874 .91643 Mdot
.51516 .76219 Mdot
.53655 .61374 Mdot
.56563 .75219 Mdot
.59189 .65665 Mdot
.59581 .61604 Mdot
.59923 .6556 Mdot
.60292 .68499 Mdot
.62656 .67779 Mdot
.63555 .72451 Mdot
.63919 .652 Mdot
.64169 .6004 Mdot
.64246 .58611 Mdot
.64496 .54267 Mdot
.64608 .77288 Mdot
.65077 .64308 Mdot
.66065 .57816 Mdot
.67474 .59169 Mdot
.69296 .563 Mdot
.72815 .65902 Mdot
.73169 .58879 Mdot
.74669 .61318 Mdot
.74821 .65474 Mdot
.75963 .63781 Mdot
.79673 .57809 Mdot
.80925 .55852 Mdot
.81525 .58444 Mdot
.83417 .62985 Mdot
.83598 .55526 Mdot
.91595 .49319 Mdot
1 0 0 r
.005 w
.00495 .28842 m
.00628 .29156 L
.01857 .31761 L
.03101 .33781 L
.03525 .34367 L
.05706 .36884 L
.05795 .36972 L
.08312 .39115 L
.08963 .39578 L
.10917 .40763 L
.13523 .41964 L
.14074 .42183 L
.16128 .42794 L
.18734 .43294 L
.21339 .43485 L
.23945 .43375 L
.2655 .42959 L
.29156 .42219 L
.29261 .42183 L
.31761 .41124 L
.34367 .39603 L
.34405 .39578 L
.36972 .37551 L
.37582 .36972 L
.39578 .34724 L
.39849 .34367 L
.41525 .31761 L
.42183 .30485 L
.4275 .29156 L
.436 .2655 L
.44117 .23945 L
.44325 .21339 L
.44232 .18734 L
.43834 .16128 L
.43114 .13523 L
.42183 .11212 L
.42037 .10917 L
.40546 .08312 L
.39578 .06961 L
.38528 .05706 L
.36972 .04137 L
.35758 .03101 L
.34367 .02092 L
.31761 .00569 L
.3162 .00495 L
s
.00495 .12854 m
.01344 .10917 L
.02832 .08312 L
.03101 .07912 L
.04848 .05706 L
.05706 .04802 L
.07619 .03101 L
.08312 .02579 L
.10917 .00934 L
.11742 .00495 L
s
0 0 1 r
.29156 .15739 m
.31761 .14824 L
.34367 .14249 L
.36972 .13986 L
.39578 .14025 L
.42183 .14366 L
.44789 .15025 L
.47394 .16034 L
.47599 .16128 L
.5 .17443 L
.51844 .18734 L
.52606 .19355 L
.54662 .21339 L
.55211 .21962 L
.56712 .23945 L
.57817 .25755 L
.58227 .2655 L
.59322 .29156 L
.60058 .31761 L
.60422 .3392 L
.60471 .34367 L
.6058 .36972 L
.60422 .39297 L
.60387 .39578 L
.59886 .42183 L
.59054 .44789 L
.57848 .47394 L
.57817 .47453 L
.562 .5 L
.55211 .51255 L
.53968 .52606 L
.52606 .53862 L
.50853 .55211 L
.5 .55773 L
.47394 .57183 L
.45901 .57817 L
.44789 .5819 L
.42183 .5885 L
.39578 .59192 L
.36972 .59231 L
.34367 .58968 L
.31761 .58392 L
.29972 .57817 L
.29156 .57477 L
.2655 .56178 L
.25025 .55211 L
.23945 .54409 L
.21914 .52606 L
.21339 .52008 L
.19681 .5 L
Mistroke
.18734 .48608 L
.18031 .47394 L
.16827 .44789 L
.16128 .42714 L
.15996 .42183 L
.15493 .39578 L
.153 .36972 L
.15409 .34367 L
.15823 .31761 L
.16128 .3045 L
.16559 .29156 L
.17653 .2655 L
.18734 .24609 L
.19169 .23945 L
.21221 .21339 L
.21339 .21211 L
.23945 .1881 L
.24041 .18734 L
.2655 .17038 L
.28271 .16128 L
.29156 .15739 L
Mfstroke
1 0 0 r
.03 w
.21687 .20845 Mdot
0 0 1 r
.3794 .36608 Mdot
1 0 0 r
.79703 .00495 m
.79703 .02527 L
.87129 .02527 L
.87129 .00495 L
F
0 0 1 r
.89604 .00495 m
.89604 .23215 L
.9703 .23215 L
.9703 .00495 L
F
1 0 1 r
.04 w
.63555 .72451 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCacheValid->False],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.49505 0.5 0.49505 [
[ 0 0 -0.125 0 ]
[ 0 0 -0.125 0 ]
[ 0 1 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
0 0 m
1 0 L
s
0 0 m
0 1 L
s
0 1 m
1 1 L
s
1 0 m
1 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
1 .5 0 r
.015 w
.03175 .1355 Mdot
.03435 .12523 Mdot
.11137 .12765 Mdot
.14107 .18841 Mdot
.16218 .24538 Mdot
.17294 .21053 Mdot
.18267 .18577 Mdot
.18434 .1304 Mdot
.18553 .30956 Mdot
.20401 .239 Mdot
.21247 .27571 Mdot
.21687 .20845 Mdot
.22376 .2799 Mdot
.22832 .27485 Mdot
.29063 .20974 Mdot
.29686 .25079 Mdot
.30487 .22936 Mdot
.30683 .34623 Mdot
.32055 .20902 Mdot
.32574 .21979 Mdot
.34472 .28521 Mdot
.35998 .36393 Mdot
.36335 .24976 Mdot
.3794 .36608 Mdot
.42386 .66992 Mdot
.44391 .74519 Mdot
.45059 .34198 Mdot
.47208 .67586 Mdot
.47436 .71381 Mdot
.49778 .59825 Mdot
.50874 .91643 Mdot
.51516 .76219 Mdot
.53655 .61374 Mdot
.56563 .75219 Mdot
.59189 .65665 Mdot
.59581 .61604 Mdot
.59923 .6556 Mdot
.60292 .68499 Mdot
.62656 .67779 Mdot
.63555 .72451 Mdot
.63919 .652 Mdot
.64169 .6004 Mdot
.64246 .58611 Mdot
.64496 .54267 Mdot
.64608 .77288 Mdot
.65077 .64308 Mdot
.66065 .57816 Mdot
.67474 .59169 Mdot
.69296 .563 Mdot
.72815 .65902 Mdot
.73169 .58879 Mdot
.74669 .61318 Mdot
.74821 .65474 Mdot
.75963 .63781 Mdot
.79673 .57809 Mdot
.80925 .55852 Mdot
.81525 .58444 Mdot
.83417 .62985 Mdot
.83598 .55526 Mdot
.91595 .49319 Mdot
1 0 0 r
.005 w
.00495 .28842 m
.00628 .29156 L
.01857 .31761 L
.03101 .33781 L
.03525 .34367 L
.05706 .36884 L
.05795 .36972 L
.08312 .39115 L
.08963 .39578 L
.10917 .40763 L
.13523 .41964 L
.14074 .42183 L
.16128 .42794 L
.18734 .43294 L
.21339 .43485 L
.23945 .43375 L
.2655 .42959 L
.29156 .42219 L
.29261 .42183 L
.31761 .41124 L
.34367 .39603 L
.34405 .39578 L
.36972 .37551 L
.37582 .36972 L
.39578 .34724 L
.39849 .34367 L
.41525 .31761 L
.42183 .30485 L
.4275 .29156 L
.436 .2655 L
.44117 .23945 L
.44325 .21339 L
.44232 .18734 L
.43834 .16128 L
.43114 .13523 L
.42183 .11212 L
.42037 .10917 L
.40546 .08312 L
.39578 .06961 L
.38528 .05706 L
.36972 .04137 L
.35758 .03101 L
.34367 .02092 L
.31761 .00569 L
.3162 .00495 L
s
.00495 .12854 m
.01344 .10917 L
.02832 .08312 L
.03101 .07912 L
.04848 .05706 L
.05706 .04802 L
.07619 .03101 L
.08312 .02579 L
.10917 .00934 L
.11742 .00495 L
s
0 0 1 r
.29156 .15739 m
.31761 .14824 L
.34367 .14249 L
.36972 .13986 L
.39578 .14025 L
.42183 .14366 L
.44789 .15025 L
.47394 .16034 L
.47599 .16128 L
.5 .17443 L
.51844 .18734 L
.52606 .19355 L
.54662 .21339 L
.55211 .21962 L
.56712 .23945 L
.57817 .25755 L
.58227 .2655 L
.59322 .29156 L
.60058 .31761 L
.60422 .3392 L
.60471 .34367 L
.6058 .36972 L
.60422 .39297 L
.60387 .39578 L
.59886 .42183 L
.59054 .44789 L
.57848 .47394 L
.57817 .47453 L
.562 .5 L
.55211 .51255 L
.53968 .52606 L
.52606 .53862 L
.50853 .55211 L
.5 .55773 L
.47394 .57183 L
.45901 .57817 L
.44789 .5819 L
.42183 .5885 L
.39578 .59192 L
.36972 .59231 L
.34367 .58968 L
.31761 .58392 L
.29972 .57817 L
.29156 .57477 L
.2655 .56178 L
.25025 .55211 L
.23945 .54409 L
.21914 .52606 L
.21339 .52008 L
.19681 .5 L
Mistroke
.18734 .48608 L
.18031 .47394 L
.16827 .44789 L
.16128 .42714 L
.15996 .42183 L
.15493 .39578 L
.153 .36972 L
.15409 .34367 L
.15823 .31761 L
.16128 .3045 L
.16559 .29156 L
.17653 .2655 L
.18734 .24609 L
.19169 .23945 L
.21221 .21339 L
.21339 .21211 L
.23945 .1881 L
.24041 .18734 L
.2655 .17038 L
.28271 .16128 L
.29156 .15739 L
Mfstroke
1 0 0 r
.03 w
.21687 .20845 Mdot
0 0 1 r
.3794 .36608 Mdot
1 0 0 r
.79703 .00495 m
.79703 .02958 L
.87129 .02958 L
.87129 .00495 L
F
0 0 1 r
.89604 .00495 m
.89604 .22785 L
.9703 .22785 L
.9703 .00495 L
F
1 0 1 r
.04 w
.63919 .652 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCacheValid->False],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.49505 0.5 0.49505 [
[ 0 0 -0.125 0 ]
[ 0 0 -0.125 0 ]
[ 0 1 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
0 0 m
1 0 L
s
0 0 m
0 1 L
s
0 1 m
1 1 L
s
1 0 m
1 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
1 .5 0 r
.015 w
.03175 .1355 Mdot
.03435 .12523 Mdot
.11137 .12765 Mdot
.14107 .18841 Mdot
.16218 .24538 Mdot
.17294 .21053 Mdot
.18267 .18577 Mdot
.18434 .1304 Mdot
.18553 .30956 Mdot
.20401 .239 Mdot
.21247 .27571 Mdot
.21687 .20845 Mdot
.22376 .2799 Mdot
.22832 .27485 Mdot
.29063 .20974 Mdot
.29686 .25079 Mdot
.30487 .22936 Mdot
.30683 .34623 Mdot
.32055 .20902 Mdot
.32574 .21979 Mdot
.34472 .28521 Mdot
.35998 .36393 Mdot
.36335 .24976 Mdot
.3794 .36608 Mdot
.42386 .66992 Mdot
.44391 .74519 Mdot
.45059 .34198 Mdot
.47208 .67586 Mdot
.47436 .71381 Mdot
.49778 .59825 Mdot
.50874 .91643 Mdot
.51516 .76219 Mdot
.53655 .61374 Mdot
.56563 .75219 Mdot
.59189 .65665 Mdot
.59581 .61604 Mdot
.59923 .6556 Mdot
.60292 .68499 Mdot
.62656 .67779 Mdot
.63555 .72451 Mdot
.63919 .652 Mdot
.64169 .6004 Mdot
.64246 .58611 Mdot
.64496 .54267 Mdot
.64608 .77288 Mdot
.65077 .64308 Mdot
.66065 .57816 Mdot
.67474 .59169 Mdot
.69296 .563 Mdot
.72815 .65902 Mdot
.73169 .58879 Mdot
.74669 .61318 Mdot
.74821 .65474 Mdot
.75963 .63781 Mdot
.79673 .57809 Mdot
.80925 .55852 Mdot
.81525 .58444 Mdot
.83417 .62985 Mdot
.83598 .55526 Mdot
.91595 .49319 Mdot
1 0 0 r
.005 w
.00495 .28842 m
.00628 .29156 L
.01857 .31761 L
.03101 .33781 L
.03525 .34367 L
.05706 .36884 L
.05795 .36972 L
.08312 .39115 L
.08963 .39578 L
.10917 .40763 L
.13523 .41964 L
.14074 .42183 L
.16128 .42794 L
.18734 .43294 L
.21339 .43485 L
.23945 .43375 L
.2655 .42959 L
.29156 .42219 L
.29261 .42183 L
.31761 .41124 L
.34367 .39603 L
.34405 .39578 L
.36972 .37551 L
.37582 .36972 L
.39578 .34724 L
.39849 .34367 L
.41525 .31761 L
.42183 .30485 L
.4275 .29156 L
.436 .2655 L
.44117 .23945 L
.44325 .21339 L
.44232 .18734 L
.43834 .16128 L
.43114 .13523 L
.42183 .11212 L
.42037 .10917 L
.40546 .08312 L
.39578 .06961 L
.38528 .05706 L
.36972 .04137 L
.35758 .03101 L
.34367 .02092 L
.31761 .00569 L
.3162 .00495 L
s
.00495 .12854 m
.01344 .10917 L
.02832 .08312 L
.03101 .07912 L
.04848 .05706 L
.05706 .04802 L
.07619 .03101 L
.08312 .02579 L
.10917 .00934 L
.11742 .00495 L
s
0 0 1 r
.29156 .15739 m
.31761 .14824 L
.34367 .14249 L
.36972 .13986 L
.39578 .14025 L
.42183 .14366 L
.44789 .15025 L
.47394 .16034 L
.47599 .16128 L
.5 .17443 L
.51844 .18734 L
.52606 .19355 L
.54662 .21339 L
.55211 .21962 L
.56712 .23945 L
.57817 .25755 L
.58227 .2655 L
.59322 .29156 L
.60058 .31761 L
.60422 .3392 L
.60471 .34367 L
.6058 .36972 L
.60422 .39297 L
.60387 .39578 L
.59886 .42183 L
.59054 .44789 L
.57848 .47394 L
.57817 .47453 L
.562 .5 L
.55211 .51255 L
.53968 .52606 L
.52606 .53862 L
.50853 .55211 L
.5 .55773 L
.47394 .57183 L
.45901 .57817 L
.44789 .5819 L
.42183 .5885 L
.39578 .59192 L
.36972 .59231 L
.34367 .58968 L
.31761 .58392 L
.29972 .57817 L
.29156 .57477 L
.2655 .56178 L
.25025 .55211 L
.23945 .54409 L
.21914 .52606 L
.21339 .52008 L
.19681 .5 L
Mistroke
.18734 .48608 L
.18031 .47394 L
.16827 .44789 L
.16128 .42714 L
.15996 .42183 L
.15493 .39578 L
.153 .36972 L
.15409 .34367 L
.15823 .31761 L
.16128 .3045 L
.16559 .29156 L
.17653 .2655 L
.18734 .24609 L
.19169 .23945 L
.21221 .21339 L
.21339 .21211 L
.23945 .1881 L
.24041 .18734 L
.2655 .17038 L
.28271 .16128 L
.29156 .15739 L
Mfstroke
1 0 0 r
.03 w
.21687 .20845 Mdot
0 0 1 r
.3794 .36608 Mdot
1 0 0 r
.79703 .00495 m
.79703 .03313 L
.87129 .03313 L
.87129 .00495 L
F
0 0 1 r
.89604 .00495 m
.89604 .2243 L
.9703 .2243 L
.9703 .00495 L
F
1 0 1 r
.04 w
.64169 .6004 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P000182000`400?l00000o`00003ooooooolQ
ooooo`00ool0000Po`00007ooooo00000ol0003oooooooooo`0Mooooo`;oo`00>?ooool3ool00<7o
oooo0Ol00001ooooo`0000?o0000ooooooooool06oooool2ool003gooooo00?oo`00ooooooooool0
Q?oooolEool000Sooooo5Ol00?l8ooooo`7o00000Oooool00003o`000?oooooooooo01[ooooo00?o
o`00ooooooooool0?_ooool2ool008Cooooo5Ooo0008oooooaGo003o2?ooool1o`00007ooooo0000
0ol0003oooooooooo`0Hooooo`;oo`00@oooool00ooo003oooooooooo`21oooooaGoo`002?oooolE
o`00o`Sooooo0Ol00001ooooo`0000?o0000ooooooooool05_ooool2ool004Kooooo00?oo`00oooo
ooooool0P?oooolEool000Sooooo5Ol00?l8ooooo`7o00000Oooool00003o`000?oooooooooo01Go
oooo00?oo`00ooooooooool0Aoooool2ool0083ooooo5Ooo0008oooooaGo003o2?ooool1o`00007o
oooo00000ol0003oooooooooo`0Dooooo`03ool00?oooooooooo04[ooooo00?oo`00ooooooooool0
OOoooolEool000Sooooo5Ol00?l8ooooo`7o00000Oooool00003o`000?oooooooooo01?ooooo00?o
o`00ooooooooool0C?ooool00ooo003oooooooooo`1loooooaGoo`002?oooolEo`00o`Sooooo0Ol0
0001ooooo`0000?o0000ooooooooool04Oooool2ool0053ooooo0_oo001loooooaGoo`002?oooolE
o`00o`Sooooo0Ol00001ooooo`0000?o0000ooooooooool04?ooool00ooo003oooooooooo`1Boooo
o`;oo`00UooooolEo`00o`Sooooo0Ol00001ooooo`0000?o0000ooooooooool03oooool00ooo003o
ooooooooo`1Eooooo`03ool00?oooooooooo09Cooooo5Ol00?l8ooooo`7o00000Oooool00003o`00
0?oooooooooo00kooooo00?oo`00ooooooooool0E_ooool00ooo003oooooooooo`2DoooooaGo003o
2?ooool1o`00007ooooo00000ol0003oooooooooo`0=ooooo`03ool00?oooooooooo05Sooooo00?o
o`00ooooooooool0TooooolEo`00o`Sooooo0Ol00001ooooo`0000?o0000ooooooooool03Oooool0
0ooo003oooooooooo`1Iooooo`03ool00?oooooooooo09;ooooo5Ol00?l8ooooo`7o00000Oooool0
0003o`000?oooooooooo00cooooo00?oo`00ooooooooool0Foooool00ooo003oooooooooo`2Aoooo
oaGo003o2?ooool1o`00007ooooo00000ol0003oooooooooo`0;ooooo`03ool00?oooooooooo05go
oooo00?oo`00ooooooooool0T?oooolEo`00o`Sooooo0Ol00001ooooo`0000?o0000ooooooooool0
2oooool00ooo003oooooooooo`1Mooooo`03ool00?oooooooooo093ooooo5Ol00?l8ooooo`7o0000
0Oooool00003o`000?oooooooooo00[ooooo00?oo`00ooooooooool0Goooool00ooo003ooooooooo
o`2?oooooaGo003o2?ooool1o`00007ooooo00000ol0003oooooooooo`09ooooo`03ool00?oooooo
oooo067ooooo00?oo`00ooooooooool0S_oooolEo`00o`Sooooo0Ol00001ooooo`0000?o0000oooo
ooooool02?ooool00ooo003oooooooooo`1Sooooo`03ool00?oooooooooo08gooooo5Ol00?l8oooo
o`7o00000Oooool00003o`000?oooooooooo00Oooooo00?oo`00ooooooooool0IOooool00ooo003o
ooooooooo`2<oooooaGo003o2?ooool1o`00007ooooo00000ol0003oooooooooo`06ooooo`03ool0
0?oooooooooo06Oooooo00?oo`00ooooooooool0RooooolEo`00o`Sooooo0Ol00001ooooo`0000?o
0000ooooooooool01Oooool00ooo003oooooooooo`1Yooooo`03ool00?oooooooooo08[ooooo5Ol0
0?l8ooooo`7o00000Oooool00003o`000?oooooooooo00Gooooo00?oo`00ooooooooool0JOooool0
0ooo003oooooooooo`2:oooooaGo003o2?ooool1o`00007ooooo00000ol0003oooooooooo`04oooo
o`03ool00?oooooooooo06_ooooo00?oo`00ooooooooool0ROoooolEo`00o`Sooooo0Ol00001oooo
o`0000?o0000ooooooooool00oooool00ooo003oooooooooo`1/ooooo`03ool00?oooooooooo08Wo
oooo5Ol00?l8ooooo`7o00000Oooool00003o`000?oooooooooo00?ooooo00?oo`00ooooooooool0
KOooool00ooo003oooooooooo`28oooooaGo003o2?ooool1o`00007ooooo00000ol0003ooooooooo
o`02ooooo`03ool00?oooooooooo06kooooo00?oo`00ooooooooool0R?oooolEo`00o`Sooooo0Ol0
0001ooooo`0000?o0000ooooooooool00_ooool00ooo003oooooooooo`1_ooooo`03ool00?oooooo
oooo08Oooooo5Ol00?l8ooooo`7o00000Oooool00005o`000?oooooooooooooooooo0000L_ooool0
0ooo003oooooooooo`27oooooaGo003o2?ooool1o`00007ooooo00001?l0003ooooooooooooo001d
ooooo`03ool00?oooooooooo08Kooooo5Ol00?l8ooooo`7o00000Oooool00004o`000?oooooooooo
ool007Gooooo00?oo`00ooooooooool0QOoooolEo`00o`Sooooo0Ol00001ooooo`0000?o0000oooo
oooo0000M_ooool00ooo003oooooooooo`25oooooaGo003o2?ooool1o`00007ooooo00000ol0003o
ooooool00006ooooo`;oogl0Koooool00ooo003oooooooooo`24oooooaGo003o2?ooool1o`00007o
oooo00000ol0003oooooool00005ooooo`Coogl04oooool2oomo05Wooooo00?oo`00ooooooooool0
Q?oooolEo`00o`Sooooo0Ol00001ooooo`0000?o0000ool00?ooool01Oooool4oomo01;ooooo1?oo
O`0Booooo`;oogl0A?ooool00ooo003oooooooooo`24oooooaGo003o2?ooool1o`00007ooooo0000
0ol0003oooooooooo`05ooooo`?oogl04oooool4oomo017ooooo1?ooO`14ooooo`03ool00?oooooo
oooo08?ooooo5Ol00?l8ooooo`7o00000Oooool00003o`000?oooooooooo00Cooooo1?ooO`0Doooo
o`;oogl04_ooool4oomo04Cooooo00?oo`00ooooooooool0PooooolEo`00o`Sooooo0Ol00001oooo
o`0000?o0000ooooooooool01?ooool4oomo02Wooooo0_ooO`15ooooo`03ool00?oooooooooo08?o
oooo5Ol00?l8ooooo`7o00000Oooool00003o`000?oooooooooo00Gooooo0_ooO`1FoooooaKo003o
1Oooool00ooo003oooooooooo`23oooooaGo003o2?ooool1o`00007ooooo00000ol0003ooooooooo
o`1Jooooo`?o003o5_ooool6o`00o`03ool00?oooooooooo08;ooooo5Ol00?l8ooooo`7o00000Ooo
ool00003o`000?oooooooooo05Oooooo0ol00?lOooooo`?o003oP_oooolEo`00o`Sooooo0Ol00001
ooooo`0000?o0000ooooooooool0E?ooool3o`00ob;ooooo00?oo`00ooooooooool00ol00?mooooo
oaGo003o2?ooool1o`00007ooooo00000ol0003oooooooooo`1Aooooo`?o003o9Oooool00ooo003o
ooooooooo`03ooooo`?o003oO?oooolEo`00o`Sooooo0Ol00001ooooo`0000?o0000ooooooooool0
Coooool20000obWooooo00?oo`00ooooooooool01Oooool3o`00ogWooooo5Ol00?l8ooooo`7o0000
0Oooool00003o`000?oooooooooo04gooooo0P000?l[ooooo`03ool00?oooooooooo00Sooooo0_l0
0?mgoooooaGo003o2?ooool1o`00007ooooo00000ol0003oooooooooo`1:ooooo`<0003o;Oooool0
0ooo003oooooooooo`0:ooooo`;o003oMOoooolEo`00o`Sooooo0Ol00001ooooo`0000?o0000oooo
ooooool0B?ooool20000oc3ooooo00?oo`00ooooooooool03?ooool00ol00?ooooooooooo`1boooo
oaGo003o2?ooool1o`00007ooooo00000ol0003oooooooooo`17ooooo`030000oooooooooooo033o
oooo00?oo`00ooooooooool03Oooool2o`00og;ooooo5Ol00?l8ooooo`7o00000Oooool00003o`00
0?oooooooooo04Gooooo0P000?ldooooo`03ool00?oooooooooo00kooooo0_l00?m`oooooaGo003o
2?ooool1o`00007ooooo00000ol0003oooooooooo`14ooooo`030000oooooooooooo03Cooooo00?o
o`00ooooooooool04?ooool2o`00ofkooooo5Ol00?l8ooooo`7o00000Oooool00003o`000?oooooo
oooo02Cooooo0_ooO`0:ooooo`;oogl04Oooool00`000?ooooooooooo`0eooooo`03ool00?oooooo
oooo01;ooooo00?o003oooooooooool0JooooolEo`00o`Sooooo0Ol00001ooooo`0000?o0000oooo
ooooool08oooool4oomo00Sooooo1?ooO`0?ooooo`030000oooooooooooo03Kooooo00?oo`00oooo
ooooool04oooool00ol00?ooooooooooo`1ZoooooaGo003o2?ooool1o`00007ooooo00000ol0003o
ooooooooo`0Sooooo`Coogl02?ooool4oomo00gooooo00<0003oo`00ooooool0>?ooool00ooo003o
ooooooooo`0Dooooo`03o`00oooooooooooo06Wooooo5Ol00?l8ooooo`7o00000Oooool00003o`00
0?oooooooooo02Cooooo0_ooO`0:ooooo`;oogl03Oooool00`000?ooooooooooo`0iooooo`03ool0
0?oooooooooo01Gooooo00?o003oooooooooool0J?oooolEo`00o`Sooooo0Ol00001ooooo`0000?o
0000ooooooooool0>Oooool4ool00003ooooo`000?oooooo03_ooooo00?oo`00ooooooooool05_oo
ool00ol00?ooooooooooo`1WoooooaGo003o2?ooool1o`00007ooooo00000ol0003oooooooooo`0h
ooooo`Koo`00?Oooool00ooo003oooooooooo`0Gooooo`03o`00oooooooooooo06Kooooo5Ol00?l8
ooooo`7o00000Oooool00003o`000?oooooooooo03Oooooo2?oo000@ooooo`;oogl01oooool2oomo
02;ooooo00?oo`00ooooooooool05oooool00ol00?ooooooooooo`1UoooooaGo003o2?ooool1o`00
007ooooo00000ol0003oooooooooo`0^ooooo`;oogl01oooool8ool000oooooo1?ooO`05ooooo`Co
ogl08Oooool00ooo003oooooooooo`0Hooooo`03o`00oooooooooooo06Cooooo5Ol00?l8ooooo`7o
00000Oooool00003o`000?oooooooooo02gooooo1?ooO`06ooooo`Soo`003oooool4oomo00Gooooo
1?ooO`0Qooooo`03ool00?oooooooooo01Wooooo00?o003oooooooooool0HooooolEo`00o`Sooooo
0Ol00001ooooo`0000?o0000ooooooooool0;Oooool4oomo00Kooooo2?oo000@ooooo`;oogl01ooo
ool3oomo027ooooo00?oo`00ooooooooool06_ooool00ol00?ooooooooooo`1RoooooaGo003o2?oo
ool1o`00007ooooo00000ol0003oooooooooo`0^ooooo`;oogl02?ooool6ool001[ooooo1?ooO`0P
ooooo`03ool00?oooooooooo01_ooooo00?o003oooooooooool0HOoooolEo`00o`Sooooo0Ol00001
ooooo`0000?o0000ooooooooool0>?ooool00`000?ooo`00ool00002ool001_ooooo1?ooO`0Poooo
o`03ool00?oooooooooo01cooooo00?o003oooooooooool0H?oooolEo`00o`Sooooo0Ol00001oooo
o`0000?o0000ooooooooool0=oooool00`000?ooooooooooo`0Iooooo`;oogl01?ooool2oomo027o
oooo00?oo`00ooooooooool07?ooool00ol00?ooooooooooo`1PoooooaGo003o2?ooool1o`00007o
oooo00000ol0003oooooooooo`0fooooo`030000oooooooooooo01Wooooo1?ooO`0Uooooo`03ool0
0?oooooooooo01kooooo00?o003oooooooooool0O?ooool1o`00007ooooo00000ol0003ooooooooo
o`0fooooo`030000oooooooooooo01Wooooo1?ooO`0Uooooo`03ool00?oooooooooo01oooooo00?o
003oooooooooool0Noooool1o`00007ooooo00000ol0003oooooooooo`0eooooo`040000oooooooo
ogl0oomo01[ooooo0_ooO`0Vooooo`03ool00?oooooooooo023ooooo00?o003oooooooooool0N_oo
ool1o`00007ooooo00000ol0003oooooooooo`0dooooo`030000ooooooooogl000?oogl0@Oooool0
0ooo003oooooooooo`0Qooooo`03o`00oooooooooooo07Wooooo0Ol00001ooooo`0000?o0000oooo
ooooool0:oooool2oomo00Kooooo00<0003oooooooooool01?ooO`11ooooo`03ool00?oooooooooo
027ooooo00?o003oooooooooool0NOooool1o`00007ooooo00000ol0003oooooooooo`0Zooooo`Co
ogl01?ooool00`000?ooooooooooo`02ooooo`;oogl06?ooool2oomo017ooooo0_ooO`0Eooooo`03
ool00?oooooooooo02;ooooo00?o003oooooooooool0N?ooool1o`00007ooooo00000ol0003ooooo
ooooo`0Zooooo`Coogl01?ooool00`000?ooooooooooo`0Kooooo`Coogl03oooool4oomo01Cooooo
00?oo`00ooooooooool08oooool00ol00?ooooooooooo`1gooooo`7o00000Oooool00003o`000?oo
oooooooo02_ooooo0_ooO`04ooooo`030000oooooooooooo01cooooo1?ooO`0?ooooo`Coogl05?oo
ool00ooo003oooooooooo`0Sooooo`03o`00oooooooooooo07Oooooo0Ol00001ooooo`0000?o0000
ooooooooool0<Oooool00`000?ooooooooooo`0Mooooo`;oogl04Oooool2oomo01Cooooo00?oo`00
ooooooooool09Oooool00ol00?ooooooooooo`1fooooo`7o00000Oooool00003o`000?oooooooooo
033ooooo00<0003oooooooooool0Aoooool00ooo003oooooooooo`0Uooooo`03o`00oooooooooooo
07Kooooo0Ol00001ooooo`0000?o0000ooooooooool0<?ooool00`000?ooooooooooo`17ooooo`03
ool00?oooooooooo02Kooooo00?o003oooooooooool0MOooool1o`00007ooooo00000ol0003ooooo
ooooo`0_ooooo`030000oooooooooooo04Sooooo00?oo`00ooooooooool09oooool00ol00?oooooo
ooooo`1dooooo`7o00000Oooool00003o`000?oooooooooo02oooooo00<0003oooooooooool01ooo
ool2oomo00;ooooo0_ooO`0kooooo`03ool00?oooooooooo02Oooooo00?o003oooooooooool0M?oo
ool1o`00007ooooo00000ol0003oooooooooo`0^ooooo`030000oooooooooooo00Oooooo2?ooO`0i
ooooo`03ool00?oooooooooo02Wooooo00?o003oooooooooool0Loooool1o`00007ooooo00000ol0
003oooooooooo`0^ooooo`030000oooooooooooo00Oooooo2?ooO`0iooooo`03ool00?oooooooooo
02Wooooo00?o003oooooooooool0Loooool1o`00007ooooo00000ol0003oooooooooo`0]ooooo`03
0000oooooooooooo00Wooooo1_ooO`0Pooooo`;oogl05oooool00ooo003oooooooooo`0[ooooo`03
o`00oooooooooooo07;ooooo0Ol00001ooooo`0000?o0000ooooooooool0;Oooool00`000?oooooo
ooooo`0;ooooo`Coogl07oooool4oomo01Kooooo00?oo`00ooooooooool0:oooool00ol00?oooooo
ooooo`1booooo`7o00000Oooool00003o`000?oo003ooooo02gooooo00<0003oooooooooool03?oo
ool2oomo023ooooo1?ooO`0Fooooo`03ool00?oooooooooo02_ooooo00?o003oooooooooool0L_oo
ool1o`00007ooooo00000ol0003oo`00ooooo`0/ooooo`030000oooooooooooo033ooooo0_ooO`0F
ooooo`03ool00?oooooooooo02gooooo00?o003oooooooooool0LOooool1o`00007ooooo00000ol0
003oo`00ooooo`0/ooooo`030000oooooooooooo04Sooooo00?oo`00ooooooooool0;Oooool00ol0
0?ooooooooooo`1aooooo`7o00000Oooool00003o`000?ooooooo`0002cooooo00<0003ooooooooo
ool0B?ooool00ooo003oooooooooo`0]ooooo`03o`00oooooooooooo077ooooo0Ol00001ooooo`00
00?o0000oooooooo0000:oooool00`000?ooooooooooo`18ooooo`03ool00?oooooooooo02oooooo
00?o003oooooooooool0L?ooool1o`00007ooooo00001?l0003ooooooooooooo000Zooooo`030000
oooooooooooo00?ooooo0_ooO`13ooooo`03ool00?oooooooooo02oooooo00?o003oooooooooool0
L?ooool1o`00007ooooo00001?l0003ooooooooooooo000Zooooo`030000oooooooooooo00;ooooo
1?ooO`12ooooo`03ool00?oooooooooo02oooooo00?o003oooooooooool0L?ooool1o`00007ooooo
00001Ol0003oooooooooooooooooo`0002Wooooo00<0003oooooooooool00_ooool4oomo047ooooo
00?oo`00ooooooooool0<?ooool00ol00?ooooooooooo`1`ooooo`7o00000Oooool00005o`000?oo
oooooooooooooooo0000:?ooool00`000?ooooooooooo`04ooooo`;oogl0@_ooool00ooo003ooooo
ooooo`0aooooo`03o`00oooooooooooo06oooooo0Ol00001ooooo`0000?o0000ooooooooool00_oo
ool00ooo003oooooooooo`0Uooooo`030000oooooooooooo04Oooooo00?oo`00ooooooooool0<_oo
ool00ol00?ooooooooooo`1_ooooo`7o00000Oooool00003o`000?oooooooooo00;ooooo00?oo`00
ooooooooool09Oooool00`000?ooooooooooo`17ooooo`03ool00?oooooooooo03;ooooo00?o003o
ooooooooool0Koooool1o`00007ooooo00000ol0003oooooooooo`03ooooo`03ool00?oooooooooo
02Cooooo00<0003oooooooooool0A_ooool00ooo003oooooooooo`0cooooo`03o`00oooooooooooo
06oooooo0Ol00001ooooo`0000?o0000ooooooooool01?ooool00ooo003oooooooooo`0Sooooo`03
0000oooooooooooo04Gooooo00?oo`00ooooooooool0=?ooool00ol00?ooooooooooo`1_ooooo`7o
00000Oooool00003o`000?oooooooooo00Gooooo00?oo`00ooooooooool08Oooool00`000?oooooo
ooooo`15ooooo`03ool00?oooooooooo03Kooooo00?o003oooooooooool0K_ooool1o`00007ooooo
00000ol0003oooooooooo`06ooooo`03ool00?oooooooooo023ooooo00<0003oooooooooool0AOoo
ool00ooo003oooooooooo`09ooooo`;oogl0:oooool00ol00?ooooooooooo`1^ooooo`7o00000Ooo
ool00003o`000?oooooooooo00Kooooo00?oo`00ooooooooool08?ooool00`000?ooooooooooo`14
ooooo`03ool00?oooooooooo00Wooooo1?ooO`0Zooooo`03o`00oooooooooooo06kooooo0Ol00001
ooooo`0000?o0000ooooooooool01oooool00ooo003oooooooooo`0Oooooo`030000oooooooooooo
02Sooooo0_ooO`0Iooooo`03ool00?oooooooooo00[ooooo1?ooO`0Zooooo`03o`00oooooooooooo
06kooooo0Ol00001ooooo`0000?o0000ooooooooool01oooool00ooo003oooooooooo`0Oooooo`03
0000oooooooooooo02Oooooo1?ooO`0Gooooo`03ool00?oooooooooo00cooooo0_ooO`0[ooooo`03
o`00oooooooooooo06kooooo0Ol00001ooooo`0000?o0000ooooooooool02?ooool00ooo003ooooo
ooooo`0Nooooo`030000oooooooooooo02Oooooo1?ooO`0Gooooo`03ool00?oooooooooo03Wooooo
00?o003oooooooooool0K_ooool1o`00007ooooo00000ol0003oooooooooo`09ooooo`03ool00?oo
oooooooo01gooooo00<0003oooooooooool0:?ooool2oomo01;ooooo1?l00?l00oooooooo`00oooo
o`0kooooo`03o`00oooooooooooo06kooooo0Ol00001ooooo`0000?o0000ooooooooool02_ooool0
0ooo003oooooooooo`0Looooo`030000oooooooooooo03_ooooo1_l00?lmooooo`03o`00oooooooo
oooo06kooooo0Ol00001ooooo`0000?o0000ooooooooool02oooool00ooo003oooooooooo`0Koooo
o`030000oooooooooooo03Oooooo0_ooO`000ooooooo003oo`00o`06o`00occooooo00?o003ooooo
ooooool0K_ooool1o`00007ooooo00000ol0003oooooooooo`0<ooooo`03ool00?oooooooooo01[o
oooo00<0003oooooooooool0=_ooool4oomo00So003o??ooool00ol00?ooooooooooo`1^ooooo`7o
00000Oooool00003o`000?oooooooooo00gooooo00?oo`00ooooooooool06Oooool00`000?oooooo
ooooo`0fooooo`Coogl02?l00?llooooo`03o`00oooooooooooo06kooooo0Ol00001ooooo`0000?o
0000ooooooooool03Oooool2ool001[ooooo00<0003oooooooooool0=oooool2oomo0003ooooool0
0?oo003o00Ko003o??ooool00ol00?ooooooooooo`1^ooooo`7o00000Oooool00003o`000?oooooo
oooo00oooooo00?oo`00ooooooooool05oooool00`000?ooooooooooo`0jooooo`03ool00?l00?oo
003o00Co003o?Oooool00ol00?ooooooooooo`1^ooooo`7o00000Oooool00003o`000?oooooooooo
013ooooo00?oo`00ooooooooool05_ooool00`000?ooooooooooo`0iooooo`03ool00?oooooooooo
00Co003o?_ooool00ol00?ooooooooooo`1^ooooo`7o00000Oooool00003o`000?oooooooooo017o
oooo00?oo`00ooooooooool05Oooool00`000?ooooooooooo`0hooooo`03ool00?oooooooooo04?o
oooo00?o003oooooooooool0K_ooool1o`00007ooooo00000ol0003oooooooooo`0Booooo`03ool0
0?oooooooooo01Cooooo00<0003oooooooooool0=_ooool2ool004Kooooo00?o003oooooooooool0
K_ooool1o`00007ooooo00000ol0003oooooooooo`0Cooooo`03ool00?oooooooooo01?ooooo00<0
003oooooooooool0=Oooool00ooo003oooooooooo`16ooooo`03o`00oooooooooooo06kooooo0Ol0
0001ooooo`0000?o0000ooooooooool05?ooool2ool001?ooooo00<0003oooooooooool0=?ooool0
0ooo003oooooooooo`17ooooo`03o`00oooooooooooo06kooooo0Ol00001ooooo`0000?o0000oooo
ooooool05_ooool2ool0017ooooo00<0003oooooooooool0<_ooool2ool004[ooooo00?o003ooooo
ooooool0K_ooool1o`00007ooooo00000ol0003oooooooooo`0Hooooo`03ool00?oooooooooo00ko
oooo00<0003oooooooooool0<Oooool00ooo003oooooooooo`1:ooooo`03o`00oooooooooooo06ko
oooo0Ol00001ooooo`0000?o0000ooooooooool06Oooool2ool000kooooo00<0003oooooooooool0
;oooool2ool004gooooo00?o003oooooooooool0K_ooool1o`00007ooooo00000ol0003ooooooooo
o`0Kooooo`03ool00?oooooooooo00_ooooo00<0003oooooooooool0;_ooool00ooo003ooooooooo
o`1<ooooo`03o`00oooooooooooo06oooooo0Ol00001ooooo`0000?o0000ooooooooool07?ooool2
ool000_ooooo00<0003oooooooooool0;Oooool00ooo003oooooooooo`1=ooooo`03o`00oooooooo
oooo06oooooo0Ol00001ooooo`0000?o0000ooooooooool07_ooool3ool000Wooooo00<0003ooooo
ooooool0:_ooool2ool0053ooooo00?o003oooooooooool0Koooool1o`00007ooooo00000ol0003o
ooooooooo`0Qooooo`;oo`001oooool00`000?ooooooooooo`0Wooooo`?oo`00D_ooool00ol00?oo
ooooooooo`1_ooooo`7o00000Oooool00003o`000?oooooooooo02?ooooo0_oo0005ooooo`030000
oooooooooooo02Gooooo0_oo001Dooooo`03o`00oooooooooooo073ooooo0Ol00001ooooo`0000?o
0000ooooooooool09Oooool4ool00003ooooo`000?oooooo02;ooooo1?oo001Fooooo`03o`00oooo
oooooooo073ooooo0Ol00001ooooo`0000?o0000ooooooooool0:Oooool2ool00003o`00oooo003o
o`0001gooooo0ooo001Jooooo`03o`00oooooooooooo073ooooo0Ol00001ooooo`0000?o0000oooo
ooooool0:oooool00`000?ooooooooooo`03ool001Cooooo1_oo001Mooooo`03o`00oooooooooooo
073ooooo0Ol00001ooooo`0000?o0000ooooooooool0;?ooool00`000?ooooooooooo`02oooooaCo
o`00H_ooool00ol00?ooooooooooo`1aooooo`7o00000Oooool00003o`000?oooooooooo02cooooo
00<0003oooooooooool0N?ooool00ol00?ooooooooooo`1aooooo`7o00000Oooool00003o`000?oo
oooooooo02cooooo00<0003oooooooooool0N?ooool00ol00?ooooooooooo`1aooooo`7o00000Ooo
ool00003o`000?oooooooooo02gooooo00<0003oooooooooool0M_ooool00ol00?ooooooooooo`1b
ooooo`7o00000Oooool00003o`000?oooooooooo02gooooo00<0003oooooooooool0M_ooool00ol0
0?ooooooooooo`1booooo`7o00000Oooool00003o`000?oooooooooo02gooooo00<0003ooooooooo
ool0M_ooool00ol00?ooooooooooo`1booooo`7o00000Oooool00003o`000?oooooooooo02kooooo
00<0003oooooooooool0M?ooool00ol00?ooooooooooo`1cooooo`7o00000Oooool00003o`000?oo
oooooooo02kooooo00<0003oooooooooool0M?ooool00ol00?ooooooooooo`1cooooo`7o00000Ooo
ool00003o`000?oooooooooo02kooooo00<0003oooooooooool0M?ooool00ol00?ooooooooooo`1c
ooooo`7o00000Oooool00003o`000?oooooooooo02oooooo00<0003oooooooooool0L_ooool00ol0
0?ooooooooooo`1dooooo`7o00000Oooool00003o`000?oooooooooo02oooooo00<0003ooooooooo
ool0L_ooool00ol00?ooooooooooo`1dooooo`7o00000Oooool00003o`000?oooooooooo02oooooo
00<0003oooooooooool0L_ooool00ol00?ooooooooooo`1dooooo`7o00000Oooool00003o`000?oo
oooooooo033ooooo00<0003oooooooooool0Koooool2o`00ogOooooo0Ol00001ooooo`0000?o0000
ooooooooool0<?ooool00`000?ooooooooooo`1_ooooo`03o`00oooooooooooo07Kooooo0Ol00001
ooooo`0000?o0000ooooooooool0<Oooool00`000?ooooooooooo`1]ooooo`03o`00oooooooooooo
07Oooooo0Ol00001ooooo`0000?o0000ooooooooool0<_ooool00`000?ooooooooooo`1/ooooo`03
o`00oooooooooooo07Oooooo0Ol00001ooooo`0000?o0000ooooooooool0<_ooool00`000?oooooo
ooooo`1[ooooo`03o`00oooooooooooo063ooooo0_ooO`0Fooooo`7o00000Oooool00003o`000?oo
oooooooo03?ooooo00<0003oooooooooool0JOooool00ol00?ooooooooooo`1Pooooo`Coogl05Ooo
ool1o`00007ooooo00000ol0003oooooooooo`0dooooo`030000oooooooooooo06Sooooo00?o003o
ooooooooool0H?ooool4oomo01Gooooo0Ol00001ooooo`0000?o0000ooooooooool0=Oooool00`00
0?ooooooooooo`1Vooooo`03o`00oooooooooooo06;ooooo0_ooO`0Fooooo`7o00000Oooool00003
o`000?oooooooooo03Gooooo00?o003oooooooooool0I_ooool00ol00?ooooooooooo`1jooooo`7o
00000Oooool00003o`000?oooooooooo03Kooooo00?o003oooooooooool0I?ooool00ol00?oooooo
ooooo`1kooooo`7o00000Oooool00003o`000?oooooooooo03Oooooo00?o003oooooooooool0H_oo
ool00ol00?ooooooooooo`1looooo`7o00000Oooool00003o`000?oooooooooo03Sooooo00?o003o
ooooooooool0Goooool2o`00ogoooooo0Ol00001ooooo`0000?o0000ooooooooool0>Oooool00ol0
0?ooooooooooo`1Mooooo`03o`00oooooooooooo07oooooo0Ol00001ooooo`0000?o0000oooooooo
ool0>_ooool00ol00?ooooooooooo`1Kooooo`03o`00oooooooooooo083ooooo0Ol00001ooooo`00
00?o0000ooooooooool0>oooool00ol00?ooooooooooo`1Iooooo`03o`00oooooooooooo087ooooo
0Ol00001ooooo`0000?o0000ooooooooool0??ooool00ol00?ooooooooooo`1Gooooo`03o`00oooo
oooooooo08;ooooo0Ol00001ooooo`0000?o0000ooooooooool0?Oooool00ol00?ooooooooooo`1E
ooooo`03o`00oooooooooooo08?ooooo0Ol00001ooooo`0000?o0000ooooooooool0?_ooool00ol0
0?ooooooooooo`1Cooooo`03o`00oooooooooooo08Cooooo0Ol00001ooooo`0000?o0000oooooooo
ool0?oooool00ol00?ooooooooooo`1@ooooo`;o003o8Oooool2oomo06Cooooo0Ol00001ooooo`00
00?o0000ooooooooool0@?ooool00ol00?ooooooooooo`1>ooooo`03o`00oooooooooooo023ooooo
1?ooO`1Sooooo`7o00000Oooool00003o`000?oooooooooo047ooooo0_l00?m=ooooo`03o`00oooo
oooooooo027ooooo1?ooO`1Sooooo`7o00000Oooool00003o`000?oooooooooo04?ooooo00?o003o
ooooooooool0BOooool00ol00?ooooooooooo`0Sooooo`;oogl0=Oooool2oomo02gooooo0Ol00001
ooooo`0000?o0000ooooooooool0A?ooool2o`00odSooooo00?o003oooooooooool0Doooool2oomo
00Gooooo1?ooO`0/ooooo`7o00000Oooool00003o`000?oooooooooo04Kooooo0_l00?m5ooooo`03
o`00oooooooooooo05?ooooo1?ooO`04ooooo`Coogl0;?ooool1o`00007ooooo00000ol0003ooooo
ooooo`18ooooo`03o`00oooooooooooo043ooooo0_l00?lfooooo`;oogl07_ooool4oomo00Gooooo
0_ooO`0]ooooo`7o00000Oooool00003o`000?oooooooooo04Wooooo0_l00?lnooooo`;o003o=ooo
ool4oomo01kooooo0_ooO`0eooooo`7o00000Oooool00003o`000?oooooooooo04_ooooo0ol00?lj
ooooo`03o`00oooooooooooo03Oooooo1?ooO`1Eooooo`7o00000Oooool00003o`000?oooooooooo
04kooooo0_l00?lfooooo`;o003o>oooool2oomo05Kooooo0Ol00001ooooo`0000?o0000oooooooo
ool0D?ooool3o`00oc3ooooo0ol00?lcooooo`;oogl09Oooool2oomo03Wooooo0Ol00001ooooo`00
00?o0000ooooooooool0Doooool2o`00ob[ooooo1?l00?leooooo`Coogl08oooool4oomo03Sooooo
0Ol00001ooooo`0000?o0000ooooooooool0EOooool3o`00ob?ooooo1?l00?leooooo`;oogl00_oo
ool4oomo02?ooooo1?ooO`03ooooo`;oogl0<oooool1o`00007ooooo00000ol0003oooooooooo`1H
ooooo`?o003o7Oooool3o`00ocOooooo1Ooo0?l2ooooo`;oogl04oooool2oomo013ooooo0_ooO`03
ooooo`Coogl0<_ooool1o`00007ooooo00000ol0003oooooooooo`1Kooooo`?o003o5?ooool6o`00
ocWooooo1ooo0?l5ooooo`;oogl03_ooool4oomo01Cooooo1?ooO`0booooo`7o00000Oooool00003
o`000?oooooooooo05kooooo5?l00?lnooooo`Woo`3o0oooool4oomo00gooooo1?ooO`0Eooooo`;o
ogl0<oooool1o`00007ooooo00000ol0003oooooooooo`2;ooooo`;oogl08_ooool;ool0o`;ooooo
1?ooO`0>ooooo`;oogl0Boooool1o`00007ooooo00000ol0003oooooooooo`2:ooooo`Coogl08Ooo
ool;ool0o`?ooooo0_ooO`1Looooo`7o00000Oooool00003o`000?oooooooooo08[ooooo1?ooO`0Q
ooooo`_oo`3oHOooool1o`00007ooooo00000ol0003oooooooooo`2;ooooo`;oogl08_ooool;ool0
of7ooooo0Ol00001ooooo`0000?o0000ooooooooool0U_ooool2oomo01Oooooo2ooo0?lHooooo`;o
ogl0Aoooool1o`00007ooooo00000ol0003oooooooooo`2Eooooo`Coogl03_ooool2oomo00Oooooo
2Ooo0?lHooooo`Coogl0A_ooool1o`00007ooooo00000ol0003oooooooooo`2Eooooo`Coogl03Ooo
ool4oomo00Oooooo1ooo0?lIooooo`Coogl0A_ooool1o`00007ooooo00000ol0003oooooooooo`2F
ooooo`;oogl03_ooool4oomo00Sooooo1Ooo0?lKooooo`;oogl0Aoooool1o`00007ooooo00000ol0
003oooooooooo`2Wooooo`;oogl0L_ooool1o`00007ooooo00000ol0003oooooooooo`3[ooooo`;o
ogl0;_ooool1o`00007ooooo00000ol0003oooooooooo`3Zooooo`Coogl0;Oooool1o`00007ooooo
00000ol0003oooooooooo`3Fooooo`;oogl04_ooool4oomo02gooooo0Ol00001ooooo`0000?o0000
ooooooooool0eOooool4oomo01;ooooo0_ooO`0^ooooo`7o00000Oooool00003o`000?oooooooooo
0;Oooooo0_ooO`0Looooo`Coogl0@_ooool1o`00007ooooo00000ol0003oooooooooo`2fooooo`Co
ogl07?ooool2oomo04?ooooo0Ol00001ooooo`0000?o0000ooooooooool0/oooool2oomo0003oooo
ooooO`3oogl000;oogl0HOooool1o`00007ooooo00000ol0003oooooooooo`2Xooooo`;oogl02?oo
ool4oomo0003ooooooooO`3oogl001[ooooo0_ooO`16ooooo`7o00000Oooool00003o`000?oooooo
oooo0:Kooooo1OooO`07ooooo`Coogl05oooool2oomo00?ooooo1?ooO`15ooooo`7o00000Oooool0
0003o`000?oooooooooo0:Gooooo1_ooO`08ooooo`;oogl05oooool4oomo00;ooooo1?ooO`15oooo
o`7o00000Oooool00003o`000?oooooooooo0:Gooooo1OooO`0Rooooo`Coogl00oooool2oomo04Ko
oooo0Ol00001ooooo`0000?o0000ooooooooool0M_ooool2oomo02kooooo0_ooO`0Uooooo`;oogl0
C?ooool1o`00007ooooo00000ol0003oooooooooo`1eooooo`Coogl0X_ooool1o`00007ooooo0000
0ol0003oooooooooo`1eooooo`Coogl02_ooool2oomo09Kooooo0Ol00001ooooo`0000?o0000oooo
ooooool0M_ooool2oomo00[ooooo1?ooO`0Zooooo`;oogl0JOooool1o`00007ooooo00000ol0003o
ooooooooo`22ooooo`Coogl0:Oooool4oomo06Sooooo0Ol00001ooooo`0000?o0000ooooooooool0
Poooool2oomo02Cooooo0_ooO`04ooooo`Coogl0J?ooool1o`00007ooooo00000ol0003ooooooooo
o`2Xooooo`Coogl01?ooool2oomo06Wooooo0Ol00001ooooo`0000?o0000ooooooooool0Z?ooool4
oomo06oooooo0Ol00001ooooo`0000?o0000ooooooooool0ZOooool2oomo073ooooo0Ol00001oooo
o`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo
7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000
ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo08Cooooo0_ooO`2Eoooo
o`7o00000Oooool00003o`000?oooooooooo08?ooooo1?ooO`2Dooooo`7o00000Oooool00003o`00
0?oooooooooo08?ooooo1?ooO`2Dooooo`7o00000Oooool00003o`000?oooooooooo08Cooooo0_oo
O`0/ooooo`;oogl0Ioooool1o`00007ooooo00000ol0003oooooooooo`2aooooo`Coogl0I_ooool1
o`00007ooooo00000ol0003oooooooooo`2aooooo`Coogl0I_ooool1o`00007ooooo00000ol0003o
ooooooooo`2booooo`;oogl0Ioooool1o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo
0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oooooo
oooo07_ooooo0_ooO`2Nooooo`7o00000Oooool00003o`000?oooooooooo07[ooooo1?ooO`2Moooo
o`7o00000Oooool00003o`000?oooooooooo07[ooooo1?ooO`0Pooooo`;oogl0Noooool1o`00007o
oooo00000ol0003oooooooooo`1kooooo`;oogl08?ooool4oomo07[ooooo0Ol00001ooooo`0000?o
0000ooooooooool0WOooool4oomo07[ooooo0Ol00001ooooo`0000?o0000ooooooooool0T?ooool2
oomo00cooooo0_ooO`1kooooo`7o00000Oooool00003o`000?oooooooooo08oooooo1?ooO`28oooo
o`7o00000Oooool00003o`000?oooooooooo08oooooo1?ooO`28ooooo`7o00000Oooool00003o`00
0?oooooooooo093ooooo0_ooO`0Sooooo`;oogl0I?ooool1o`00007ooooo00000ol0003ooooooooo
o`2dooooo`Coogl0Hoooool1o`00007ooooo00000ol0003oooooooooo`2dooooo`Coogl0Hoooool1
o`00007ooooo00000ol0003oooooooooo`2eooooo`;oogl0I?ooool1o`00007ooooo00000ol0003o
ooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o0000
0Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3o
oooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003
o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo
0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oooooo
oooo0?oooooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001oooo
o`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo
7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000
ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00
007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0
oooooolLooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo0000
0ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLoooo
o`7o00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003ooooo
ooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Ooo
ool00003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooo
oacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`00
0?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol0
0001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo
0?oooooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`00
00?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?oo
ool1o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000oooo
ooooool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007o
oooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0S_oo
ool2oomo08_ooooo0Ol00001ooooo`0000?o0000ooooooooool0SOooool4oomo08[ooooo0Ol00001
ooooo`0000?o0000ooooooooool0SOooool4oomo08[ooooo0Ol00001ooooo`0000?o0000oooooooo
ool0S_ooool2oomo08_ooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o0000
0Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3o
oooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003
o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo
0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oooooo
oooo0?oooooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001oooo
o`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo
7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000
ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00
007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0
oooooolLooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo0000
0ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLoooo
o`7o00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003ooooo
ooooo`3ooooooacooooo0Ol00001ooooo`00ool0000Po`00007ooooo0000\
\>"],
  ImageRangeCache->{{{0, 287}, {287, 0}} -> {-1.01089, -1.01089, 0.00704453, \
0.00704453}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.49505 0.5 0.49505 [
[ 0 0 -0.125 0 ]
[ 0 0 -0.125 0 ]
[ 0 1 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
0 0 m
1 0 L
s
0 0 m
0 1 L
s
0 1 m
1 1 L
s
1 0 m
1 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
1 .5 0 r
.015 w
.03175 .1355 Mdot
.03435 .12523 Mdot
.11137 .12765 Mdot
.14107 .18841 Mdot
.16218 .24538 Mdot
.17294 .21053 Mdot
.18267 .18577 Mdot
.18434 .1304 Mdot
.18553 .30956 Mdot
.20401 .239 Mdot
.21247 .27571 Mdot
.21687 .20845 Mdot
.22376 .2799 Mdot
.22832 .27485 Mdot
.29063 .20974 Mdot
.29686 .25079 Mdot
.30487 .22936 Mdot
.30683 .34623 Mdot
.32055 .20902 Mdot
.32574 .21979 Mdot
.34472 .28521 Mdot
.35998 .36393 Mdot
.36335 .24976 Mdot
.3794 .36608 Mdot
.42386 .66992 Mdot
.44391 .74519 Mdot
.45059 .34198 Mdot
.47208 .67586 Mdot
.47436 .71381 Mdot
.49778 .59825 Mdot
.50874 .91643 Mdot
.51516 .76219 Mdot
.53655 .61374 Mdot
.56563 .75219 Mdot
.59189 .65665 Mdot
.59581 .61604 Mdot
.59923 .6556 Mdot
.60292 .68499 Mdot
.62656 .67779 Mdot
.63555 .72451 Mdot
.63919 .652 Mdot
.64169 .6004 Mdot
.64246 .58611 Mdot
.64496 .54267 Mdot
.64608 .77288 Mdot
.65077 .64308 Mdot
.66065 .57816 Mdot
.67474 .59169 Mdot
.69296 .563 Mdot
.72815 .65902 Mdot
.73169 .58879 Mdot
.74669 .61318 Mdot
.74821 .65474 Mdot
.75963 .63781 Mdot
.79673 .57809 Mdot
.80925 .55852 Mdot
.81525 .58444 Mdot
.83417 .62985 Mdot
.83598 .55526 Mdot
.91595 .49319 Mdot
1 0 0 r
.005 w
.00495 .28842 m
.00628 .29156 L
.01857 .31761 L
.03101 .33781 L
.03525 .34367 L
.05706 .36884 L
.05795 .36972 L
.08312 .39115 L
.08963 .39578 L
.10917 .40763 L
.13523 .41964 L
.14074 .42183 L
.16128 .42794 L
.18734 .43294 L
.21339 .43485 L
.23945 .43375 L
.2655 .42959 L
.29156 .42219 L
.29261 .42183 L
.31761 .41124 L
.34367 .39603 L
.34405 .39578 L
.36972 .37551 L
.37582 .36972 L
.39578 .34724 L
.39849 .34367 L
.41525 .31761 L
.42183 .30485 L
.4275 .29156 L
.436 .2655 L
.44117 .23945 L
.44325 .21339 L
.44232 .18734 L
.43834 .16128 L
.43114 .13523 L
.42183 .11212 L
.42037 .10917 L
.40546 .08312 L
.39578 .06961 L
.38528 .05706 L
.36972 .04137 L
.35758 .03101 L
.34367 .02092 L
.31761 .00569 L
.3162 .00495 L
s
.00495 .12854 m
.01344 .10917 L
.02832 .08312 L
.03101 .07912 L
.04848 .05706 L
.05706 .04802 L
.07619 .03101 L
.08312 .02579 L
.10917 .00934 L
.11742 .00495 L
s
0 0 1 r
.29156 .15739 m
.31761 .14824 L
.34367 .14249 L
.36972 .13986 L
.39578 .14025 L
.42183 .14366 L
.44789 .15025 L
.47394 .16034 L
.47599 .16128 L
.5 .17443 L
.51844 .18734 L
.52606 .19355 L
.54662 .21339 L
.55211 .21962 L
.56712 .23945 L
.57817 .25755 L
.58227 .2655 L
.59322 .29156 L
.60058 .31761 L
.60422 .3392 L
.60471 .34367 L
.6058 .36972 L
.60422 .39297 L
.60387 .39578 L
.59886 .42183 L
.59054 .44789 L
.57848 .47394 L
.57817 .47453 L
.562 .5 L
.55211 .51255 L
.53968 .52606 L
.52606 .53862 L
.50853 .55211 L
.5 .55773 L
.47394 .57183 L
.45901 .57817 L
.44789 .5819 L
.42183 .5885 L
.39578 .59192 L
.36972 .59231 L
.34367 .58968 L
.31761 .58392 L
.29972 .57817 L
.29156 .57477 L
.2655 .56178 L
.25025 .55211 L
.23945 .54409 L
.21914 .52606 L
.21339 .52008 L
.19681 .5 L
Mistroke
.18734 .48608 L
.18031 .47394 L
.16827 .44789 L
.16128 .42714 L
.15996 .42183 L
.15493 .39578 L
.153 .36972 L
.15409 .34367 L
.15823 .31761 L
.16128 .3045 L
.16559 .29156 L
.17653 .2655 L
.18734 .24609 L
.19169 .23945 L
.21221 .21339 L
.21339 .21211 L
.23945 .1881 L
.24041 .18734 L
.2655 .17038 L
.28271 .16128 L
.29156 .15739 L
Mfstroke
1 0 0 r
.03 w
.21687 .20845 Mdot
0 0 1 r
.3794 .36608 Mdot
1 0 0 r
.79703 .00495 m
.79703 .03418 L
.87129 .03418 L
.87129 .00495 L
F
0 0 1 r
.89604 .00495 m
.89604 .22324 L
.9703 .22324 L
.9703 .00495 L
F
1 0 1 r
.04 w
.64246 .58611 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P000182000`400?l00000o`00003ooooooolQ
ooooo`00ool0000Po`00007ooooo00000ol0003oooooooooo`0Mooooo`;oo`00>?ooool3ool00<7o
oooo0Ol00001ooooo`0000?o0000ooooooooool06oooool2ool003gooooo00?oo`00ooooooooool0
Q?oooolEool000Sooooo5Ol00?l8ooooo`7o00000Oooool00003o`000?oooooooooo01[ooooo00?o
o`00ooooooooool0?_ooool2ool008Cooooo5Ooo0008oooooaGo003o2?ooool1o`00007ooooo0000
0ol0003oooooooooo`0Hooooo`;oo`00@oooool00ooo003oooooooooo`21oooooaGoo`002?oooolE
o`00o`Sooooo0Ol00001ooooo`0000?o0000ooooooooool05_ooool2ool004Kooooo00?oo`00oooo
ooooool0P?oooolEool000Sooooo5Ol00?l8ooooo`7o00000Oooool00003o`000?oooooooooo01Go
oooo00?oo`00ooooooooool0Aoooool2ool0083ooooo5Ooo0008oooooaGo003o2?ooool1o`00007o
oooo00000ol0003oooooooooo`0Dooooo`03ool00?oooooooooo04[ooooo00?oo`00ooooooooool0
OOoooolEool000Sooooo5Ol00?l8ooooo`7o00000Oooool00003o`000?oooooooooo01?ooooo00?o
o`00ooooooooool0C?ooool00ooo003oooooooooo`1loooooaGoo`002?oooolEo`00o`Sooooo0Ol0
0001ooooo`0000?o0000ooooooooool04Oooool2ool0053ooooo0_oo001loooooaGoo`002?oooolE
o`00o`Sooooo0Ol00001ooooo`0000?o0000ooooooooool04?ooool00ooo003oooooooooo`1Boooo
o`;oo`00UooooolEo`00o`Sooooo0Ol00001ooooo`0000?o0000ooooooooool03oooool00ooo003o
ooooooooo`1Eooooo`03ool00?oooooooooo09Cooooo5Ol00?l8ooooo`7o00000Oooool00003o`00
0?oooooooooo00kooooo00?oo`00ooooooooool0E_ooool00ooo003oooooooooo`2DoooooaGo003o
2?ooool1o`00007ooooo00000ol0003oooooooooo`0=ooooo`03ool00?oooooooooo05Sooooo00?o
o`00ooooooooool0TooooolEo`00o`Sooooo0Ol00001ooooo`0000?o0000ooooooooool03Oooool0
0ooo003oooooooooo`1Iooooo`03ool00?oooooooooo09;ooooo5Ol00?l8ooooo`7o00000Oooool0
0003o`000?oooooooooo00cooooo00?oo`00ooooooooool0Foooool00ooo003oooooooooo`2Aoooo
oaGo003o2?ooool1o`00007ooooo00000ol0003oooooooooo`0;ooooo`03ool00?oooooooooo05go
oooo00?oo`00ooooooooool0T?oooolEo`00o`Sooooo0Ol00001ooooo`0000?o0000ooooooooool0
2oooool00ooo003oooooooooo`1Mooooo`03ool00?oooooooooo093ooooo5Ol00?l8ooooo`7o0000
0Oooool00003o`000?oooooooooo00[ooooo00?oo`00ooooooooool0Goooool00ooo003ooooooooo
o`2?oooooaGo003o2?ooool1o`00007ooooo00000ol0003oooooooooo`09ooooo`03ool00?oooooo
oooo067ooooo00?oo`00ooooooooool0S_oooolEo`00o`Sooooo0Ol00001ooooo`0000?o0000oooo
ooooool02?ooool00ooo003oooooooooo`1Sooooo`03ool00?oooooooooo08gooooo5Ol00?l8oooo
o`7o00000Oooool00003o`000?oooooooooo00Oooooo00?oo`00ooooooooool0IOooool00ooo003o
ooooooooo`2<oooooaGo003o2?ooool1o`00007ooooo00000ol0003oooooooooo`06ooooo`03ool0
0?oooooooooo06Oooooo00?oo`00ooooooooool0RooooolEo`00o`Sooooo0Ol00001ooooo`0000?o
0000ooooooooool01Oooool00ooo003oooooooooo`1Yooooo`03ool00?oooooooooo08[ooooo5Ol0
0?l8ooooo`7o00000Oooool00003o`000?oooooooooo00Gooooo00?oo`00ooooooooool0JOooool0
0ooo003oooooooooo`2:oooooaGo003o2?ooool1o`00007ooooo00000ol0003oooooooooo`04oooo
o`03ool00?oooooooooo06_ooooo00?oo`00ooooooooool0ROoooolEo`00o`Sooooo0Ol00001oooo
o`0000?o0000ooooooooool00oooool00ooo003oooooooooo`1/ooooo`03ool00?oooooooooo08Wo
oooo5Ol00?l8ooooo`7o00000Oooool00003o`000?oooooooooo00?ooooo00?oo`00ooooooooool0
KOooool00ooo003oooooooooo`28oooooaGo003o2?ooool1o`00007ooooo00000ol0003ooooooooo
o`02ooooo`03ool00?oooooooooo06kooooo00?oo`00ooooooooool0R?oooolEo`00o`Sooooo0Ol0
0001ooooo`0000?o0000ooooooooool00_ooool00ooo003oooooooooo`1_ooooo`03ool00?oooooo
oooo08Oooooo5Ol00?l8ooooo`7o00000Oooool00005o`000?oooooooooooooooooo0000L_ooool0
0ooo003oooooooooo`27oooooaGo003o2?ooool1o`00007ooooo00001?l0003ooooooooooooo001d
ooooo`03ool00?oooooooooo08Kooooo5Ol00?l8ooooo`7o00000Oooool00004o`000?oooooooooo
ool007Gooooo00?oo`00ooooooooool0QOoooolEo`00o`Sooooo0Ol00001ooooo`0000?o0000oooo
oooo0000M_ooool00ooo003oooooooooo`25oooooaGo003o2?ooool1o`00007ooooo00000ol0003o
ooooool00006ooooo`;oogl0Koooool00ooo003oooooooooo`24oooooaGo003o2?ooool1o`00007o
oooo00000ol0003oooooool00005ooooo`Coogl04oooool2oomo05Wooooo00?oo`00ooooooooool0
Q?oooolEo`00o`Sooooo0Ol00001ooooo`0000?o0000ool00?ooool01Oooool4oomo01;ooooo1?oo
O`0Booooo`;oogl0A?ooool00ooo003oooooooooo`24oooooaGo003o2?ooool1o`00007ooooo0000
0ol0003oooooooooo`05ooooo`?oogl04oooool4oomo017ooooo1?ooO`14ooooo`03ool00?oooooo
oooo08?ooooo5Ol00?l8ooooo`7o00000Oooool00003o`000?oooooooooo00Cooooo1?ooO`0Doooo
o`;oogl04_ooool4oomo04Cooooo00?oo`00ooooooooool0PooooolEo`00o`Sooooo0Ol00001oooo
o`0000?o0000ooooooooool01?ooool4oomo02Wooooo0_ooO`15ooooo`03ool00?oooooooooo08?o
oooo5Ol00?l8ooooo`7o00000Oooool00003o`000?oooooooooo00Gooooo0_ooO`1FoooooaKo003o
1Oooool00ooo003oooooooooo`23oooooaGo003o2?ooool1o`00007ooooo00000ol0003ooooooooo
o`1Jooooo`?o003o5_ooool6o`00o`03ool00?oooooooooo08;ooooo5Ol00?l8ooooo`7o00000Ooo
ool00003o`000?oooooooooo05Oooooo0ol00?lOooooo`?o003oP_oooolEo`00o`Sooooo0Ol00001
ooooo`0000?o0000ooooooooool0E?ooool3o`00ob;ooooo00?oo`00ooooooooool00ol00?mooooo
oaGo003o2?ooool1o`00007ooooo00000ol0003oooooooooo`1Aooooo`?o003o9Oooool00ooo003o
ooooooooo`03ooooo`?o003oO?oooolEo`00o`Sooooo0Ol00001ooooo`0000?o0000ooooooooool0
Coooool20000obWooooo00?oo`00ooooooooool01Oooool3o`00ogWooooo5Ol00?l8ooooo`7o0000
0Oooool00003o`000?oooooooooo04gooooo0P000?l[ooooo`03ool00?oooooooooo00Sooooo0_l0
0?mgoooooaGo003o2?ooool1o`00007ooooo00000ol0003oooooooooo`1:ooooo`<0003o;Oooool0
0ooo003oooooooooo`0:ooooo`;o003oMOoooolEo`00o`Sooooo0Ol00001ooooo`0000?o0000oooo
ooooool0B?ooool20000oc3ooooo00?oo`00ooooooooool03?ooool00ol00?ooooooooooo`1boooo
oaGo003o2?ooool1o`00007ooooo00000ol0003oooooooooo`17ooooo`030000oooooooooooo033o
oooo00?oo`00ooooooooool03Oooool2o`00og;ooooo5Ol00?l8ooooo`7o00000Oooool00003o`00
0?oooooooooo04Gooooo0P000?ldooooo`03ool00?oooooooooo00kooooo0_l00?m`oooooaGo003o
2?ooool1o`00007ooooo00000ol0003oooooooooo`14ooooo`030000oooooooooooo03Cooooo00?o
o`00ooooooooool04?ooool2o`00ofkooooo5Ol00?l8ooooo`7o00000Oooool00003o`000?oooooo
oooo02Cooooo0_ooO`0:ooooo`;oogl04Oooool00`000?ooooooooooo`0eooooo`03ool00?oooooo
oooo01;ooooo00?o003oooooooooool0JooooolEo`00o`Sooooo0Ol00001ooooo`0000?o0000oooo
ooooool08oooool4oomo00Sooooo1?ooO`0?ooooo`030000oooooooooooo03Kooooo00?oo`00oooo
ooooool04oooool00ol00?ooooooooooo`1ZoooooaGo003o2?ooool1o`00007ooooo00000ol0003o
ooooooooo`0Sooooo`Coogl02?ooool4oomo00gooooo00<0003oo`00ooooool0>?ooool00ooo003o
ooooooooo`0Dooooo`03o`00oooooooooooo06Wooooo5Ol00?l8ooooo`7o00000Oooool00003o`00
0?oooooooooo02Cooooo0_ooO`0:ooooo`;oogl03Oooool00`000?ooooooooooo`0iooooo`03ool0
0?oooooooooo01Gooooo00?o003oooooooooool0J?oooolEo`00o`Sooooo0Ol00001ooooo`0000?o
0000ooooooooool0>Oooool4ool00003ooooo`000?oooooo03_ooooo00?oo`00ooooooooool05_oo
ool00ol00?ooooooooooo`1WoooooaGo003o2?ooool1o`00007ooooo00000ol0003oooooooooo`0h
ooooo`Koo`00?Oooool00ooo003oooooooooo`0Gooooo`03o`00oooooooooooo06Kooooo5Ol00?l8
ooooo`7o00000Oooool00003o`000?oooooooooo03Oooooo2?oo000@ooooo`;oogl01oooool2oomo
02;ooooo00?oo`00ooooooooool05oooool00ol00?ooooooooooo`1UoooooaGo003o2?ooool1o`00
007ooooo00000ol0003oooooooooo`0^ooooo`;oogl01oooool8ool000oooooo1?ooO`05ooooo`Co
ogl08Oooool00ooo003oooooooooo`0Hooooo`03o`00oooooooooooo06Cooooo5Ol00?l8ooooo`7o
00000Oooool00003o`000?oooooooooo02gooooo1?ooO`06ooooo`Soo`003oooool4oomo00Gooooo
1?ooO`0Qooooo`03ool00?oooooooooo01Wooooo00?o003oooooooooool0HooooolEo`00o`Sooooo
0Ol00001ooooo`0000?o0000ooooooooool0;Oooool4oomo00Kooooo2?oo000@ooooo`;oogl01ooo
ool3oomo027ooooo00?oo`00ooooooooool06_ooool00ol00?ooooooooooo`1RoooooaGo003o2?oo
ool1o`00007ooooo00000ol0003oooooooooo`0^ooooo`;oogl02?ooool6ool001[ooooo1?ooO`0P
ooooo`03ool00?oooooooooo01_ooooo00?o003oooooooooool0HOoooolEo`00o`Sooooo0Ol00001
ooooo`0000?o0000ooooooooool0>?ooool00`000?ooo`00ool00002ool001_ooooo1?ooO`0Poooo
o`03ool00?oooooooooo01cooooo00?o003oooooooooool0H?oooolEo`00o`Sooooo0Ol00001oooo
o`0000?o0000ooooooooool0=oooool00`000?ooooooooooo`0Iooooo`;oogl01?ooool2oomo027o
oooo00?oo`00ooooooooool07?ooool00ol00?ooooooooooo`1PoooooaGo003o2?ooool1o`00007o
oooo00000ol0003oooooooooo`0fooooo`030000oooooooooooo01Wooooo1?ooO`0Uooooo`03ool0
0?oooooooooo01kooooo00?o003oooooooooool0O?ooool1o`00007ooooo00000ol0003ooooooooo
o`0fooooo`030000oooooooooooo01Wooooo1?ooO`0Uooooo`03ool00?oooooooooo01oooooo00?o
003oooooooooool0Noooool1o`00007ooooo00000ol0003oooooooooo`0eooooo`040000oooooooo
ogl0oomo01[ooooo0_ooO`0Vooooo`03ool00?oooooooooo023ooooo00?o003oooooooooool0N_oo
ool1o`00007ooooo00000ol0003oooooooooo`0dooooo`030000ooooooooogl000?oogl0@Oooool0
0ooo003oooooooooo`0Qooooo`03o`00oooooooooooo07Wooooo0Ol00001ooooo`0000?o0000oooo
ooooool0:oooool2oomo00Kooooo00<0003oooooooooool01?ooO`11ooooo`03ool00?oooooooooo
027ooooo00?o003oooooooooool0NOooool1o`00007ooooo00000ol0003oooooooooo`0Zooooo`Co
ogl01?ooool00`000?ooooooooooo`02ooooo`;oogl06?ooool2oomo017ooooo0_ooO`0Eooooo`03
ool00?oooooooooo02;ooooo00?o003oooooooooool0N?ooool1o`00007ooooo00000ol0003ooooo
ooooo`0Zooooo`Coogl01?ooool00`000?ooooooooooo`0Kooooo`Coogl03oooool4oomo01Cooooo
00?oo`00ooooooooool08oooool00ol00?ooooooooooo`1gooooo`7o00000Oooool00003o`000?oo
oooooooo02_ooooo0_ooO`04ooooo`030000oooooooooooo01cooooo1?ooO`0?ooooo`Coogl05?oo
ool00ooo003oooooooooo`0Sooooo`03o`00oooooooooooo07Oooooo0Ol00001ooooo`0000?o0000
ooooooooool0<Oooool00`000?ooooooooooo`0Mooooo`;oogl04Oooool2oomo01Cooooo00?oo`00
ooooooooool09Oooool00ol00?ooooooooooo`1fooooo`7o00000Oooool00003o`000?oooooooooo
033ooooo00<0003oooooooooool0Aoooool00ooo003oooooooooo`0Uooooo`03o`00oooooooooooo
07Kooooo0Ol00001ooooo`0000?o0000ooooooooool0<?ooool00`000?ooooooooooo`17ooooo`03
ool00?oooooooooo02Kooooo00?o003oooooooooool0MOooool1o`00007ooooo00000ol0003ooooo
ooooo`0_ooooo`030000oooooooooooo04Sooooo00?oo`00ooooooooool09oooool00ol00?oooooo
ooooo`1dooooo`7o00000Oooool00003o`000?oooooooooo02oooooo00<0003oooooooooool01ooo
ool2oomo00;ooooo0_ooO`0kooooo`03ool00?oooooooooo02Oooooo00?o003oooooooooool0M?oo
ool1o`00007ooooo00000ol0003oooooooooo`0^ooooo`030000oooooooooooo00Oooooo2?ooO`0i
ooooo`03ool00?oooooooooo02Wooooo00?o003oooooooooool0Loooool1o`00007ooooo00000ol0
003oooooooooo`0^ooooo`030000oooooooooooo00Oooooo2?ooO`0iooooo`03ool00?oooooooooo
02Wooooo00?o003oooooooooool0Loooool1o`00007ooooo00000ol0003oooooooooo`0]ooooo`03
0000oooooooooooo00Wooooo1_ooO`0Pooooo`;oogl05oooool00ooo003oooooooooo`0[ooooo`03
o`00oooooooooooo07;ooooo0Ol00001ooooo`0000?o0000ooooooooool0;Oooool00`000?oooooo
ooooo`0;ooooo`Coogl07oooool4oomo01Kooooo00?oo`00ooooooooool0:oooool00ol00?oooooo
ooooo`1booooo`7o00000Oooool00003o`000?oo003ooooo02gooooo00<0003oooooooooool03?oo
ool2oomo023ooooo1?ooO`0Fooooo`03ool00?oooooooooo02_ooooo00?o003oooooooooool0L_oo
ool1o`00007ooooo00000ol0003oo`00ooooo`0/ooooo`030000oooooooooooo033ooooo0_ooO`0F
ooooo`03ool00?oooooooooo02gooooo00?o003oooooooooool0LOooool1o`00007ooooo00000ol0
003oo`00ooooo`0/ooooo`030000oooooooooooo04Sooooo00?oo`00ooooooooool0;Oooool00ol0
0?ooooooooooo`1aooooo`7o00000Oooool00003o`000?ooooooo`0002cooooo00<0003ooooooooo
ool0B?ooool00ooo003oooooooooo`0]ooooo`03o`00oooooooooooo077ooooo0Ol00001ooooo`00
00?o0000oooooooo0000:oooool00`000?ooooooooooo`18ooooo`03ool00?oooooooooo02oooooo
00?o003oooooooooool0L?ooool1o`00007ooooo00001?l0003ooooooooooooo000Zooooo`030000
oooooooooooo00?ooooo0_ooO`13ooooo`03ool00?oooooooooo02oooooo00?o003oooooooooool0
L?ooool1o`00007ooooo00001?l0003ooooooooooooo000Zooooo`030000oooooooooooo00;ooooo
1?ooO`12ooooo`03ool00?oooooooooo02oooooo00?o003oooooooooool0L?ooool1o`00007ooooo
00001Ol0003oooooooooooooooooo`0002Wooooo00<0003oooooooooool00_ooool4oomo047ooooo
00?oo`00ooooooooool0<?ooool00ol00?ooooooooooo`1`ooooo`7o00000Oooool00005o`000?oo
oooooooooooooooo0000:?ooool00`000?ooooooooooo`04ooooo`;oogl0@_ooool00ooo003ooooo
ooooo`0aooooo`03o`00oooooooooooo06oooooo0Ol00001ooooo`0000?o0000ooooooooool00_oo
ool00ooo003oooooooooo`0Uooooo`030000oooooooooooo04Oooooo00?oo`00ooooooooool0<_oo
ool00ol00?ooooooooooo`1_ooooo`7o00000Oooool00003o`000?oooooooooo00;ooooo00?oo`00
ooooooooool09Oooool00`000?ooooooooooo`17ooooo`03ool00?oooooooooo03;ooooo00?o003o
ooooooooool0Koooool1o`00007ooooo00000ol0003oooooooooo`03ooooo`03ool00?oooooooooo
02Cooooo00<0003oooooooooool0A_ooool00ooo003oooooooooo`0cooooo`03o`00oooooooooooo
06oooooo0Ol00001ooooo`0000?o0000ooooooooool01?ooool00ooo003oooooooooo`0Sooooo`03
0000oooooooooooo04Gooooo00?oo`00ooooooooool0=?ooool00ol00?ooooooooooo`1_ooooo`7o
00000Oooool00003o`000?oooooooooo00Gooooo00?oo`00ooooooooool08Oooool00`000?oooooo
ooooo`15ooooo`03ool00?oooooooooo03Kooooo00?o003oooooooooool0K_ooool1o`00007ooooo
00000ol0003oooooooooo`06ooooo`03ool00?oooooooooo023ooooo00<0003oooooooooool0AOoo
ool00ooo003oooooooooo`09ooooo`;oogl0:oooool00ol00?ooooooooooo`1^ooooo`7o00000Ooo
ool00003o`000?oooooooooo00Kooooo00?oo`00ooooooooool08?ooool00`000?ooooooooooo`14
ooooo`03ool00?oooooooooo00Wooooo1?ooO`0Zooooo`03o`00oooooooooooo06kooooo0Ol00001
ooooo`0000?o0000ooooooooool01oooool00ooo003oooooooooo`0Oooooo`030000oooooooooooo
02Sooooo0_ooO`0Iooooo`03ool00?oooooooooo00[ooooo1?ooO`0Zooooo`03o`00oooooooooooo
06kooooo0Ol00001ooooo`0000?o0000ooooooooool01oooool00ooo003oooooooooo`0Oooooo`03
0000oooooooooooo02Oooooo1?ooO`0Gooooo`03ool00?oooooooooo00cooooo0_ooO`0[ooooo`03
o`00oooooooooooo06kooooo0Ol00001ooooo`0000?o0000ooooooooool02?ooool00ooo003ooooo
ooooo`0Nooooo`030000oooooooooooo02Oooooo1?ooO`0Gooooo`03ool00?oooooooooo03Wooooo
00?o003oooooooooool0K_ooool1o`00007ooooo00000ol0003oooooooooo`09ooooo`03ool00?oo
oooooooo01gooooo00<0003oooooooooool0:?ooool2oomo01;ooooo1?l00?l00oooooooo`00oooo
o`0kooooo`03o`00oooooooooooo06kooooo0Ol00001ooooo`0000?o0000ooooooooool02_ooool0
0ooo003oooooooooo`0Looooo`030000oooooooooooo03_ooooo1_l00?lmooooo`03o`00oooooooo
oooo06kooooo0Ol00001ooooo`0000?o0000ooooooooool02oooool00ooo003oooooooooo`0Koooo
o`030000oooooooooooo03Oooooo0_ooO`000ooooooo003oo`00o`06o`00occooooo00?o003ooooo
ooooool0K_ooool1o`00007ooooo00000ol0003oooooooooo`0<ooooo`03ool00?oooooooooo01[o
oooo00<0003oooooooooool0=_ooool4oomo00So003o??ooool00ol00?ooooooooooo`1^ooooo`7o
00000Oooool00003o`000?oooooooooo00gooooo00?oo`00ooooooooool06Oooool00`000?oooooo
ooooo`0fooooo`Coogl02?l00?llooooo`03o`00oooooooooooo06kooooo0Ol00001ooooo`0000?o
0000ooooooooool03Oooool2ool001[ooooo00<0003oooooooooool0=oooool2oomo0003ooooool0
0?oo003o00Ko003o??ooool00ol00?ooooooooooo`1^ooooo`7o00000Oooool00003o`000?oooooo
oooo00oooooo00?oo`00ooooooooool05oooool00`000?ooooooooooo`0jooooo`03ool00?l00?oo
003o00Co003o?Oooool00ol00?ooooooooooo`1^ooooo`7o00000Oooool00003o`000?oooooooooo
013ooooo00?oo`00ooooooooool05_ooool00`000?ooooooooooo`0iooooo`03ool00?oooooooooo
00Co003o?_ooool00ol00?ooooooooooo`1^ooooo`7o00000Oooool00003o`000?oooooooooo017o
oooo00?oo`00ooooooooool05Oooool00`000?ooooooooooo`0hooooo`03ool00?oooooooooo04?o
oooo00?o003oooooooooool0K_ooool1o`00007ooooo00000ol0003oooooooooo`0Booooo`03ool0
0?oooooooooo01Cooooo00<0003oooooooooool0=_ooool2ool004Kooooo00?o003oooooooooool0
K_ooool1o`00007ooooo00000ol0003oooooooooo`0Cooooo`03ool00?oooooooooo01?ooooo00<0
003oooooooooool0=Oooool00ooo003oooooooooo`16ooooo`03o`00oooooooooooo06kooooo0Ol0
0001ooooo`0000?o0000ooooooooool05?ooool2ool001?ooooo00<0003oooooooooool0=?ooool0
0ooo003oooooooooo`17ooooo`03o`00oooooooooooo06kooooo0Ol00001ooooo`0000?o0000oooo
ooooool05_ooool2ool0017ooooo00<0003oooooooooool0<_ooool2ool004[ooooo00?o003ooooo
ooooool0K_ooool1o`00007ooooo00000ol0003oooooooooo`0Hooooo`03ool00?oooooooooo00ko
oooo00<0003oooooooooool0<Oooool00ooo003oooooooooo`1:ooooo`03o`00oooooooooooo06ko
oooo0Ol00001ooooo`0000?o0000ooooooooool06Oooool2ool000kooooo00<0003oooooooooool0
;oooool2ool004gooooo00?o003oooooooooool0K_ooool1o`00007ooooo00000ol0003ooooooooo
o`0Kooooo`03ool00?oooooooooo00_ooooo00<0003oooooooooool0;_ooool00ooo003ooooooooo
o`1<ooooo`03o`00oooooooooooo06oooooo0Ol00001ooooo`0000?o0000ooooooooool07?ooool2
ool000_ooooo00<0003oooooooooool0;Oooool00ooo003oooooooooo`1=ooooo`03o`00oooooooo
oooo06oooooo0Ol00001ooooo`0000?o0000ooooooooool07_ooool3ool000Wooooo00<0003ooooo
ooooool0:_ooool2ool0053ooooo00?o003oooooooooool0Koooool1o`00007ooooo00000ol0003o
ooooooooo`0Qooooo`;oo`001oooool00`000?ooooooooooo`0Wooooo`?oo`00D_ooool00ol00?oo
ooooooooo`1_ooooo`7o00000Oooool00003o`000?oooooooooo02?ooooo0_oo0005ooooo`030000
oooooooooooo02Gooooo0_oo001Dooooo`03o`00oooooooooooo073ooooo0Ol00001ooooo`0000?o
0000ooooooooool09Oooool4ool00003ooooo`000?oooooo02;ooooo1?oo001Fooooo`03o`00oooo
oooooooo073ooooo0Ol00001ooooo`0000?o0000ooooooooool0:Oooool2ool00003o`00oooo003o
o`0001gooooo0ooo001Jooooo`03o`00oooooooooooo073ooooo0Ol00001ooooo`0000?o0000oooo
ooooool0:oooool00`000?ooooooooooo`03ool001Cooooo1_oo001Mooooo`03o`00oooooooooooo
073ooooo0Ol00001ooooo`0000?o0000ooooooooool0;?ooool00`000?ooooooooooo`02oooooaCo
o`00H_ooool00ol00?ooooooooooo`1aooooo`7o00000Oooool00003o`000?oooooooooo02cooooo
00<0003oooooooooool0N?ooool00ol00?ooooooooooo`1aooooo`7o00000Oooool00003o`000?oo
oooooooo02cooooo00<0003oooooooooool0N?ooool00ol00?ooooooooooo`1aooooo`7o00000Ooo
ool00003o`000?oooooooooo02gooooo00<0003oooooooooool0M_ooool00ol00?ooooooooooo`1b
ooooo`7o00000Oooool00003o`000?oooooooooo02gooooo00<0003oooooooooool0M_ooool00ol0
0?ooooooooooo`1booooo`7o00000Oooool00003o`000?oooooooooo02gooooo00<0003ooooooooo
ool0M_ooool00ol00?ooooooooooo`1booooo`7o00000Oooool00003o`000?oooooooooo02kooooo
00<0003oooooooooool0M?ooool00ol00?ooooooooooo`1cooooo`7o00000Oooool00003o`000?oo
oooooooo02kooooo00<0003oooooooooool0M?ooool00ol00?ooooooooooo`1cooooo`7o00000Ooo
ool00003o`000?oooooooooo02kooooo00<0003oooooooooool0M?ooool00ol00?ooooooooooo`1c
ooooo`7o00000Oooool00003o`000?oooooooooo02oooooo00<0003oooooooooool0L_ooool00ol0
0?ooooooooooo`1dooooo`7o00000Oooool00003o`000?oooooooooo02oooooo00<0003ooooooooo
ool0L_ooool00ol00?ooooooooooo`1dooooo`7o00000Oooool00003o`000?oooooooooo02oooooo
00<0003oooooooooool0L_ooool00ol00?ooooooooooo`1dooooo`7o00000Oooool00003o`000?oo
oooooooo033ooooo00<0003oooooooooool0Koooool2o`00ogOooooo0Ol00001ooooo`0000?o0000
ooooooooool0<?ooool00`000?ooooooooooo`1_ooooo`03o`00oooooooooooo07Kooooo0Ol00001
ooooo`0000?o0000ooooooooool0<Oooool00`000?ooooooooooo`1]ooooo`03o`00oooooooooooo
07Oooooo0Ol00001ooooo`0000?o0000ooooooooool0<_ooool00`000?ooooooooooo`1/ooooo`03
o`00oooooooooooo07Oooooo0Ol00001ooooo`0000?o0000ooooooooool0<_ooool00`000?oooooo
ooooo`1[ooooo`03o`00oooooooooooo063ooooo0_ooO`0Fooooo`7o00000Oooool00003o`000?oo
oooooooo03?ooooo00<0003oooooooooool0JOooool00ol00?ooooooooooo`1Pooooo`Coogl05Ooo
ool1o`00007ooooo00000ol0003oooooooooo`0dooooo`030000oooooooooooo06Sooooo00?o003o
ooooooooool0H?ooool4oomo01Gooooo0Ol00001ooooo`0000?o0000ooooooooool0=Oooool00`00
0?ooooooooooo`1Vooooo`03o`00oooooooooooo06;ooooo0_ooO`0Fooooo`7o00000Oooool00003
o`000?oooooooooo03Gooooo00?o003oooooooooool0I_ooool00ol00?ooooooooooo`1jooooo`7o
00000Oooool00003o`000?oooooooooo03Kooooo00?o003oooooooooool0I?ooool00ol00?oooooo
ooooo`1kooooo`7o00000Oooool00003o`000?oooooooooo03Oooooo00?o003oooooooooool0H_oo
ool00ol00?ooooooooooo`1looooo`7o00000Oooool00003o`000?oooooooooo03Sooooo00?o003o
ooooooooool0Goooool2o`00ogoooooo0Ol00001ooooo`0000?o0000ooooooooool0>Oooool00ol0
0?ooooooooooo`1Mooooo`03o`00oooooooooooo07oooooo0Ol00001ooooo`0000?o0000oooooooo
ool0>_ooool00ol00?ooooooooooo`1Kooooo`03o`00oooooooooooo083ooooo0Ol00001ooooo`00
00?o0000ooooooooool0>oooool00ol00?ooooooooooo`1Iooooo`03o`00oooooooooooo087ooooo
0Ol00001ooooo`0000?o0000ooooooooool0??ooool00ol00?ooooooooooo`1Gooooo`03o`00oooo
oooooooo08;ooooo0Ol00001ooooo`0000?o0000ooooooooool0?Oooool00ol00?ooooooooooo`1E
ooooo`03o`00oooooooooooo08?ooooo0Ol00001ooooo`0000?o0000ooooooooool0?_ooool00ol0
0?ooooooooooo`1Cooooo`03o`00oooooooooooo08Cooooo0Ol00001ooooo`0000?o0000oooooooo
ool0?oooool00ol00?ooooooooooo`1@ooooo`;o003o8Oooool2oomo06Cooooo0Ol00001ooooo`00
00?o0000ooooooooool0@?ooool00ol00?ooooooooooo`1>ooooo`03o`00oooooooooooo023ooooo
1?ooO`1Sooooo`7o00000Oooool00003o`000?oooooooooo047ooooo0_l00?m=ooooo`03o`00oooo
oooooooo027ooooo1?ooO`1Sooooo`7o00000Oooool00003o`000?oooooooooo04?ooooo00?o003o
ooooooooool0BOooool00ol00?ooooooooooo`0Sooooo`;oogl0=Oooool2oomo02gooooo0Ol00001
ooooo`0000?o0000ooooooooool0A?ooool2o`00odSooooo00?o003oooooooooool0Doooool2oomo
00Gooooo1?ooO`0/ooooo`7o00000Oooool00003o`000?oooooooooo04Kooooo0_l00?m5ooooo`03
o`00oooooooooooo05?ooooo1?ooO`04ooooo`Coogl0;?ooool1o`00007ooooo00000ol0003ooooo
ooooo`18ooooo`03o`00oooooooooooo043ooooo0_l00?lfooooo`;oogl07_ooool4oomo00Gooooo
0_ooO`0]ooooo`7o00000Oooool00003o`000?oooooooooo04Wooooo0_l00?lnooooo`;o003o=ooo
ool4oomo01kooooo0_ooO`0eooooo`7o00000Oooool00003o`000?oooooooooo04_ooooo0ol00?lj
ooooo`03o`00oooooooooooo03Oooooo1?ooO`1Eooooo`7o00000Oooool00003o`000?oooooooooo
04kooooo0_l00?lfooooo`;o003o:oooool5ool0o`_ooooo0_ooO`1Fooooo`7o00000Oooool00003
o`000?oooooooooo053ooooo0ol00?l`ooooo`?o003o;?ooool7ool0o`;oogl09Oooool2oomo03Wo
oooo0Ol00001ooooo`0000?o0000ooooooooool0Doooool2o`00ob[ooooo1?l00?l^ooooo`Woo`3o
0_ooO`0Sooooo`Coogl0>?ooool1o`00007ooooo00000ol0003oooooooooo`1Eooooo`?o003o8ooo
ool4o`00oc7ooooo2ooo0?l00oooO`3oooooooooo`0Qooooo`Coogl00oooool2oomo03?ooooo0Ol0
0001ooooo`0000?o0000ooooooooool0F?ooool3o`00oagooooo0ol00?leooooo`_oo`3o4oooool2
oomo013ooooo0_ooO`03ooooo`Coogl0<_ooool1o`00007ooooo00000ol0003oooooooooo`1Koooo
o`?o003o5?ooool6o`00ocSooooo2ooo0?l2ooooo`;oogl03_ooool4oomo01Cooooo1?ooO`0boooo
o`7o00000Oooool00003o`000?oooooooooo05kooooo5?l00?lnooooo`_oo`3o00?ooooooomo0?oo
O`000_ooO`0=ooooo`Coogl05Oooool2oomo03?ooooo0Ol00001ooooo`0000?o0000ooooooooool0
Roooool2oomo02?ooooo2ooo0?l00oooooooogl0oomo0002oomo00kooooo0_ooO`1;ooooo`7o0000
0Oooool00003o`000?oooooooooo08[ooooo1?ooO`0Sooooo`Woo`3o0oooool2oomo05cooooo0Ol0
0001ooooo`0000?o0000ooooooooool0R_ooool4oomo02Cooooo1ooo0?mRooooo`7o00000Oooool0
0003o`000?oooooooooo08_ooooo0_ooO`0Vooooo`Goo`3oHoooool1o`00007ooooo00000ol0003o
ooooooooo`2Fooooo`;oogl0>_ooool2oomo04Oooooo0Ol00001ooooo`0000?o0000ooooooooool0
UOooool4oomo00kooooo0_ooO`0Xooooo`Coogl0A_ooool1o`00007ooooo00000ol0003ooooooooo
o`2Eooooo`Coogl03Oooool4oomo02Oooooo1?ooO`16ooooo`7o00000Oooool00003o`000?oooooo
oooo09Kooooo0_ooO`0>ooooo`Coogl0:?ooool2oomo04Oooooo0Ol00001ooooo`0000?o0000oooo
ooooool0Yoooool2oomo07;ooooo0Ol00001ooooo`0000?o0000ooooooooool0joooool2oomo02ko
oooo0Ol00001ooooo`0000?o0000ooooooooool0j_ooool4oomo02gooooo0Ol00001ooooo`0000?o
0000ooooooooool0e_ooool2oomo01;ooooo1?ooO`0]ooooo`7o00000Oooool00003o`000?oooooo
oooo0=Gooooo1?ooO`0Booooo`;oogl0;_ooool1o`00007ooooo00000ol0003oooooooooo`2goooo
o`;oogl07?ooool4oomo04;ooooo0Ol00001ooooo`0000?o0000ooooooooool0]_ooool4oomo01co
oooo0_ooO`13ooooo`7o00000Oooool00003o`000?oooooooooo0;?ooooo0_ooO`000oooooooogl0
oomo0002oomo067ooooo0Ol00001ooooo`0000?o0000ooooooooool0Z?ooool2oomo00Sooooo1?oo
O`000oooooooogl0oomo000Jooooo`;oogl0A_ooool1o`00007ooooo00000ol0003oooooooooo`2V
ooooo`Googl01oooool4oomo01Oooooo0_ooO`03ooooo`Coogl0AOooool1o`00007ooooo00000ol0
003oooooooooo`2Uooooo`Koogl02?ooool2oomo01Oooooo1?ooO`02ooooo`Coogl0AOooool1o`00
007ooooo00000ol0003oooooooooo`2Uooooo`Googl08_ooool4oomo00?ooooo0_ooO`16ooooo`7o
00000Oooool00003o`000?oooooooooo07Kooooo0_ooO`0^ooooo`;oogl09Oooool2oomo04cooooo
0Ol00001ooooo`0000?o0000ooooooooool0MOooool4oomo0:;ooooo0Ol00001ooooo`0000?o0000
ooooooooool0MOooool4oomo00[ooooo0_ooO`2Fooooo`7o00000Oooool00003o`000?oooooooooo
07Kooooo0_ooO`0:ooooo`Coogl0:_ooool2oomo06Wooooo0Ol00001ooooo`0000?o0000oooooooo
ool0P_ooool4oomo02Wooooo1?ooO`1Xooooo`7o00000Oooool00003o`000?oooooooooo08?ooooo
0_ooO`0Tooooo`;oogl01?ooool4oomo06Sooooo0Ol00001ooooo`0000?o0000ooooooooool0Z?oo
ool4oomo00Cooooo0_ooO`1Yooooo`7o00000Oooool00003o`000?oooooooooo0:Sooooo1?ooO`1_
ooooo`7o00000Oooool00003o`000?oooooooooo0:Wooooo0_ooO`1`ooooo`7o00000Oooool00003
o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo
0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oooooo
oooo0?oooooo7?ooool1o`00007ooooo00000ol0003oooooooooo`24ooooo`;oogl0UOooool1o`00
007ooooo00000ol0003oooooooooo`23ooooo`Coogl0U?ooool1o`00007ooooo00000ol0003ooooo
ooooo`23ooooo`Coogl0U?ooool1o`00007ooooo00000ol0003oooooooooo`24ooooo`;oogl0;?oo
ool2oomo06Oooooo0Ol00001ooooo`0000?o0000ooooooooool0/Oooool4oomo06Kooooo0Ol00001
ooooo`0000?o0000ooooooooool0/Oooool4oomo06Kooooo0Ol00001ooooo`0000?o0000oooooooo
ool0/_ooool2oomo06Oooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o0000
0Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003oooooooooo`1k
ooooo`;oogl0W_ooool1o`00007ooooo00000ol0003oooooooooo`1jooooo`Coogl0WOooool1o`00
007ooooo00000ol0003oooooooooo`1jooooo`Coogl08?ooool2oomo07_ooooo0Ol00001ooooo`00
00?o0000ooooooooool0Noooool2oomo023ooooo1?ooO`1jooooo`7o00000Oooool00003o`000?oo
oooooooo09gooooo1?ooO`1jooooo`7o00000Oooool00003o`000?oooooooooo093ooooo0_ooO`0<
ooooo`;oogl0Noooool1o`00007ooooo00000ol0003oooooooooo`2?ooooo`Coogl0R?ooool1o`00
007ooooo00000ol0003oooooooooo`2?ooooo`Coogl0R?ooool1o`00007ooooo00000ol0003ooooo
ooooo`2@ooooo`;oogl08oooool2oomo06Cooooo0Ol00001ooooo`0000?o0000ooooooooool0]?oo
ool4oomo06?ooooo0Ol00001ooooo`0000?o0000ooooooooool0]?ooool4oomo06?ooooo0Ol00001
ooooo`0000?o0000ooooooooool0]Oooool2oomo06Cooooo0Ol00001ooooo`0000?o0000oooooooo
ool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo
00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolL
ooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003o
ooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o0000
0Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3o
oooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003
o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo
0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oooooo
oooo0?oooooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001oooo
o`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo
7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000
ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00
007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0
oooooolLooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo0000
0ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLoooo
o`7o00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003ooooo
ooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Ooo
ool00003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooo
oacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`00
0?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol0
0001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo
0?oooooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`00
00?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo08kooooo0_oo
O`2;ooooo`7o00000Oooool00003o`000?oooooooooo08gooooo1?ooO`2:ooooo`7o00000Oooool0
0003o`000?oooooooooo08gooooo1?ooO`2:ooooo`7o00000Oooool00003o`000?oooooooooo08ko
oooo0_ooO`2;ooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo
00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolL
ooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003o
ooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o0000
0Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3o
oooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003
o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo
0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oooooo
oooo0?oooooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001oooo
o`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo
7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000
ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00
007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0
oooooolLooooo`7o00000Oooool00?oo00008?l00001ooooo`00\
\>"],
  ImageRangeCache->{{{0, 287}, {287, 0}} -> {-1.01089, -1.01089, 0.00704453, \
0.00704453}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.49505 0.5 0.49505 [
[ 0 0 -0.125 0 ]
[ 0 0 -0.125 0 ]
[ 0 1 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
0 0 m
1 0 L
s
0 0 m
0 1 L
s
0 1 m
1 1 L
s
1 0 m
1 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
1 .5 0 r
.015 w
.03175 .1355 Mdot
.03435 .12523 Mdot
.11137 .12765 Mdot
.14107 .18841 Mdot
.16218 .24538 Mdot
.17294 .21053 Mdot
.18267 .18577 Mdot
.18434 .1304 Mdot
.18553 .30956 Mdot
.20401 .239 Mdot
.21247 .27571 Mdot
.21687 .20845 Mdot
.22376 .2799 Mdot
.22832 .27485 Mdot
.29063 .20974 Mdot
.29686 .25079 Mdot
.30487 .22936 Mdot
.30683 .34623 Mdot
.32055 .20902 Mdot
.32574 .21979 Mdot
.34472 .28521 Mdot
.35998 .36393 Mdot
.36335 .24976 Mdot
.3794 .36608 Mdot
.42386 .66992 Mdot
.44391 .74519 Mdot
.45059 .34198 Mdot
.47208 .67586 Mdot
.47436 .71381 Mdot
.49778 .59825 Mdot
.50874 .91643 Mdot
.51516 .76219 Mdot
.53655 .61374 Mdot
.56563 .75219 Mdot
.59189 .65665 Mdot
.59581 .61604 Mdot
.59923 .6556 Mdot
.60292 .68499 Mdot
.62656 .67779 Mdot
.63555 .72451 Mdot
.63919 .652 Mdot
.64169 .6004 Mdot
.64246 .58611 Mdot
.64496 .54267 Mdot
.64608 .77288 Mdot
.65077 .64308 Mdot
.66065 .57816 Mdot
.67474 .59169 Mdot
.69296 .563 Mdot
.72815 .65902 Mdot
.73169 .58879 Mdot
.74669 .61318 Mdot
.74821 .65474 Mdot
.75963 .63781 Mdot
.79673 .57809 Mdot
.80925 .55852 Mdot
.81525 .58444 Mdot
.83417 .62985 Mdot
.83598 .55526 Mdot
.91595 .49319 Mdot
1 0 0 r
.005 w
.00495 .28842 m
.00628 .29156 L
.01857 .31761 L
.03101 .33781 L
.03525 .34367 L
.05706 .36884 L
.05795 .36972 L
.08312 .39115 L
.08963 .39578 L
.10917 .40763 L
.13523 .41964 L
.14074 .42183 L
.16128 .42794 L
.18734 .43294 L
.21339 .43485 L
.23945 .43375 L
.2655 .42959 L
.29156 .42219 L
.29261 .42183 L
.31761 .41124 L
.34367 .39603 L
.34405 .39578 L
.36972 .37551 L
.37582 .36972 L
.39578 .34724 L
.39849 .34367 L
.41525 .31761 L
.42183 .30485 L
.4275 .29156 L
.436 .2655 L
.44117 .23945 L
.44325 .21339 L
.44232 .18734 L
.43834 .16128 L
.43114 .13523 L
.42183 .11212 L
.42037 .10917 L
.40546 .08312 L
.39578 .06961 L
.38528 .05706 L
.36972 .04137 L
.35758 .03101 L
.34367 .02092 L
.31761 .00569 L
.3162 .00495 L
s
.00495 .12854 m
.01344 .10917 L
.02832 .08312 L
.03101 .07912 L
.04848 .05706 L
.05706 .04802 L
.07619 .03101 L
.08312 .02579 L
.10917 .00934 L
.11742 .00495 L
s
0 0 1 r
.29156 .15739 m
.31761 .14824 L
.34367 .14249 L
.36972 .13986 L
.39578 .14025 L
.42183 .14366 L
.44789 .15025 L
.47394 .16034 L
.47599 .16128 L
.5 .17443 L
.51844 .18734 L
.52606 .19355 L
.54662 .21339 L
.55211 .21962 L
.56712 .23945 L
.57817 .25755 L
.58227 .2655 L
.59322 .29156 L
.60058 .31761 L
.60422 .3392 L
.60471 .34367 L
.6058 .36972 L
.60422 .39297 L
.60387 .39578 L
.59886 .42183 L
.59054 .44789 L
.57848 .47394 L
.57817 .47453 L
.562 .5 L
.55211 .51255 L
.53968 .52606 L
.52606 .53862 L
.50853 .55211 L
.5 .55773 L
.47394 .57183 L
.45901 .57817 L
.44789 .5819 L
.42183 .5885 L
.39578 .59192 L
.36972 .59231 L
.34367 .58968 L
.31761 .58392 L
.29972 .57817 L
.29156 .57477 L
.2655 .56178 L
.25025 .55211 L
.23945 .54409 L
.21914 .52606 L
.21339 .52008 L
.19681 .5 L
Mistroke
.18734 .48608 L
.18031 .47394 L
.16827 .44789 L
.16128 .42714 L
.15996 .42183 L
.15493 .39578 L
.153 .36972 L
.15409 .34367 L
.15823 .31761 L
.16128 .3045 L
.16559 .29156 L
.17653 .2655 L
.18734 .24609 L
.19169 .23945 L
.21221 .21339 L
.21339 .21211 L
.23945 .1881 L
.24041 .18734 L
.2655 .17038 L
.28271 .16128 L
.29156 .15739 L
Mfstroke
1 0 0 r
.03 w
.21687 .20845 Mdot
0 0 1 r
.3794 .36608 Mdot
1 0 0 r
.79703 .00495 m
.79703 .03758 L
.87129 .03758 L
.87129 .00495 L
F
0 0 1 r
.89604 .00495 m
.89604 .21985 L
.9703 .21985 L
.9703 .00495 L
F
1 0 1 r
.04 w
.64496 .54267 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P000182000`400?l00000o`00003ooooooolQ
ooooo`00ool0000Po`00007ooooo00000ol0003oooooooooo`0Mooooo`;oo`00>?ooool3ool00<7o
oooo0Ol00001ooooo`0000?o0000ooooooooool06oooool2ool003gooooo00?oo`00ooooooooool0
Q?oooolEool000Sooooo5Ol00?l8ooooo`7o00000Oooool00003o`000?oooooooooo01[ooooo00?o
o`00ooooooooool0?_ooool2ool008Cooooo5Ooo0008oooooaGo003o2?ooool1o`00007ooooo0000
0ol0003oooooooooo`0Hooooo`;oo`00@oooool00ooo003oooooooooo`21oooooaGoo`002?oooolE
o`00o`Sooooo0Ol00001ooooo`0000?o0000ooooooooool05_ooool2ool004Kooooo00?oo`00oooo
ooooool0P?oooolEool000Sooooo5Ol00?l8ooooo`7o00000Oooool00003o`000?oooooooooo01Go
oooo00?oo`00ooooooooool0Aoooool2ool0083ooooo5Ooo0008oooooaGo003o2?ooool1o`00007o
oooo00000ol0003oooooooooo`0Dooooo`03ool00?oooooooooo04[ooooo00?oo`00ooooooooool0
OOoooolEool000Sooooo5Ol00?l8ooooo`7o00000Oooool00003o`000?oooooooooo01?ooooo00?o
o`00ooooooooool0C?ooool00ooo003oooooooooo`1loooooaGoo`002?oooolEo`00o`Sooooo0Ol0
0001ooooo`0000?o0000ooooooooool04Oooool2ool0053ooooo0_oo001loooooaGoo`002?oooolE
o`00o`Sooooo0Ol00001ooooo`0000?o0000ooooooooool04?ooool00ooo003oooooooooo`1Boooo
o`;oo`00N_oooolEool000Sooooo5Ol00?l8ooooo`7o00000Oooool00003o`000?oooooooooo00oo
oooo00?oo`00ooooooooool0EOooool00ooo003oooooooooo`2DoooooaGo003o2?ooool1o`00007o
oooo00000ol0003oooooooooo`0>ooooo`03ool00?oooooooooo05Kooooo00?oo`00ooooooooool0
U?oooolEo`00o`Sooooo0Ol00001ooooo`0000?o0000ooooooooool03Oooool00ooo003ooooooooo
o`1Hooooo`03ool00?oooooooooo09?ooooo5Ol00?l8ooooo`7o00000Oooool00003o`000?oooooo
oooo00gooooo00?oo`00ooooooooool0FOooool00ooo003oooooooooo`2BoooooaGo003o2?ooool1
o`00007ooooo00000ol0003oooooooooo`0<ooooo`03ool00?oooooooooo05_ooooo00?oo`00oooo
ooooool0TOoooolEo`00o`Sooooo0Ol00001ooooo`0000?o0000ooooooooool02oooool00ooo003o
ooooooooo`1Mooooo`03ool00?oooooooooo093ooooo5Ol00?l8ooooo`7o00000Oooool00003o`00
0?oooooooooo00_ooooo00?oo`00ooooooooool0GOooool00ooo003oooooooooo`2@oooooaGo003o
2?ooool1o`00007ooooo00000ol0003oooooooooo`0:ooooo`03ool00?oooooooooo05oooooo00?o
o`00ooooooooool0SooooolEo`00o`Sooooo0Ol00001ooooo`0000?o0000ooooooooool02Oooool0
0ooo003oooooooooo`1Qooooo`03ool00?oooooooooo08kooooo5Ol00?l8ooooo`7o00000Oooool0
0003o`000?oooooooooo00Sooooo00?oo`00ooooooooool0Hoooool00ooo003oooooooooo`2=oooo
oaGo003o2?ooool1o`00007ooooo00000ol0003oooooooooo`07ooooo`03ool00?oooooooooo06Go
oooo00?oo`00ooooooooool0S?oooolEo`00o`Sooooo0Ol00001ooooo`0000?o0000ooooooooool0
1_ooool00ooo003oooooooooo`1Wooooo`03ool00?oooooooooo08_ooooo5Ol00?l8ooooo`7o0000
0Oooool00003o`000?oooooooooo00Gooooo00?oo`00ooooooooool0JOooool00ooo003ooooooooo
o`2:oooooaGo003o2?ooool1o`00007ooooo00000ol0003oooooooooo`05ooooo`03ool00?oooooo
oooo06Wooooo00?oo`00ooooooooool0R_oooolEo`00o`Sooooo0Ol00001ooooo`0000?o0000oooo
ooooool01?ooool00ooo003oooooooooo`1[ooooo`03ool00?oooooooooo08Wooooo5Ol00?l8oooo
o`7o00000Oooool00003o`000?oooooooooo00?ooooo00?oo`00ooooooooool0K?ooool00ooo003o
ooooooooo`29oooooaGo003o2?ooool1o`00007ooooo00000ol0003oooooooooo`03ooooo`03ool0
0?oooooooooo06gooooo00?oo`00ooooooooool0R?oooolEo`00o`Sooooo0Ol00001ooooo`0000?o
0000ooooooooool00_ooool00ooo003oooooooooo`1^ooooo`03ool00?oooooooooo08Sooooo5Ol0
0?l8ooooo`7o00000Oooool00003o`000?oooooooooo00;ooooo00?oo`00ooooooooool0Koooool0
0ooo003oooooooooo`27oooooaGo003o2?ooool1o`00007ooooo00001Ol0003ooooooooooooooooo
o`0007;ooooo00?oo`00ooooooooool0QooooolEo`00o`Sooooo0Ol00001ooooo`0000Co0000oooo
ooooooooo`00M?ooool00ooo003oooooooooo`26oooooaGo003o2?ooool1o`00007ooooo00001?l0
003ooooooooooooo001eooooo`03ool00?oooooooooo08Gooooo5Ol00?l8ooooo`7o00000Oooool0
0003o`000?ooooooo`0007Kooooo00?oo`00ooooooooool0QOoooolEo`00o`Sooooo0Ol00001oooo
o`0000?o0000oooooooo00001_ooool2oomo06oooooo00?oo`00ooooooooool0Q?oooolEo`00o`So
oooo0Ol00001ooooo`0000?o0000oooooooo00001Oooool4oomo01?ooooo0_ooO`1Iooooo`03ool0
0?oooooooooo08Cooooo5Ol00?l8ooooo`7o00000Oooool00003o`000?oo003ooooo00Gooooo1?oo
O`0Booooo`Coogl04_ooool2oomo04Cooooo00?oo`00ooooooooool0Q?oooolEo`00o`Sooooo0Ol0
0001ooooo`0000?o0000ooooooooool01Oooool3oomo01?ooooo1?ooO`0Aooooo`Coogl0A?ooool0
0ooo003oooooooooo`23oooooaGo003o2?ooool1o`00007ooooo00000ol0003oooooooooo`04oooo
o`Coogl05?ooool2oomo01;ooooo1?ooO`14ooooo`03ool00?oooooooooo08?ooooo5Ol00?l8oooo
o`7o00000Oooool00003o`000?oooooooooo00Cooooo1?ooO`0Yooooo`;oogl0AOooool00ooo003o
ooooooooo`23oooooaGo003o2?ooool1o`00007ooooo00000ol0003oooooooooo`05ooooo`;oogl0
E_oooolFo`00o`Gooooo00?oo`00ooooooooool0PooooolEo`00o`Sooooo0Ol00001ooooo`0000?o
0000ooooooooool0F_ooool3o`00oaKooooo1_l00?l00ooo003oooooooooo`22oooooaGo003o2?oo
ool1o`00007ooooo00000ol0003oooooooooo`1Gooooo`?o003o7oooool3o`00oh;ooooo5Ol00?l8
ooooo`7o00000Oooool00003o`000?oooooooooo05Cooooo0ol00?lRooooo`03ool00?oooooooooo
00?o003oOooooolEo`00o`Sooooo0Ol00001ooooo`0000?o0000ooooooooool0DOooool3o`00obGo
oooo00?oo`00ooooooooool00oooool3o`00ogcooooo5Ol00?l8ooooo`7o00000Oooool00003o`00
0?oooooooooo04oooooo0P000?lYooooo`03ool00?oooooooooo00Gooooo0ol00?mioooooaGo003o
2?ooool1o`00007ooooo00000ol0003oooooooooo`1=ooooo`80003o:oooool00ooo003ooooooooo
o`08ooooo`;o003oMooooolEo`00o`Sooooo0Ol00001ooooo`0000?o0000ooooooooool0B_ooool3
0000obgooooo00?oo`00ooooooooool02_ooool2o`00ogGooooo5Ol00?l8ooooo`7o00000Oooool0
0003o`000?oooooooooo04Sooooo0P000?l`ooooo`03ool00?oooooooooo00cooooo00?o003ooooo
ooooool0L_oooolEo`00o`Sooooo0Ol00001ooooo`0000?o0000ooooooooool0Aoooool00`000?oo
ooooooooo`0`ooooo`03ool00?oooooooooo00gooooo0_l00?mboooooaGo003o2?ooool1o`00007o
oooo00000ol0003oooooooooo`15ooooo`80003o=?ooool00ooo003oooooooooo`0>ooooo`;o003o
L?oooolEo`00o`Sooooo0Ol00001ooooo`0000?o0000ooooooooool0A?ooool00`000?oooooooooo
o`0dooooo`03ool00?oooooooooo013ooooo0_l00?m^oooooaGo003o2?ooool1o`00007ooooo0000
0ol0003oooooooooo`0Tooooo`;oogl02_ooool2oomo017ooooo00<0003oooooooooool0=Oooool0
0ooo003oooooooooo`0Booooo`03o`00oooooooooooo06_ooooo5Ol00?l8ooooo`7o00000Oooool0
0003o`000?oooooooooo02?ooooo1?ooO`08ooooo`Coogl03oooool00`000?ooooooooooo`0foooo
o`03ool00?oooooooooo01?ooooo00?o003oooooooooool0J_oooolEo`00o`Sooooo0Ol00001oooo
o`0000?o0000ooooooooool08oooool4oomo00Sooooo1?ooO`0=ooooo`030000ool00?oooooo03So
oooo00?oo`00ooooooooool05?ooool00ol00?ooooooooooo`1YoooooaGo003o2?ooool1o`00007o
oooo00000ol0003oooooooooo`0Tooooo`;oogl02_ooool2oomo00gooooo00<0003oooooooooool0
>Oooool00ooo003oooooooooo`0Eooooo`03o`00oooooooooooo06Sooooo5Ol00?l8ooooo`7o0000
0Oooool00003o`000?oooooooooo03Wooooo1?oo00000oooool0003oooooo`0kooooo`03ool00?oo
oooooooo01Kooooo00?o003oooooooooool0IooooolEo`00o`Sooooo0Ol00001ooooo`0000?o0000
ooooooooool0>?ooool6ool003gooooo00?oo`00ooooooooool05oooool00ol00?ooooooooooo`1V
oooooaGo003o2?ooool1o`00007ooooo00000ol0003oooooooooo`0gooooo`Soo`004?ooool2oomo
00Oooooo0_ooO`0Rooooo`03ool00?oooooooooo01Oooooo00?o003oooooooooool0IOoooolEo`00
o`Sooooo0Ol00001ooooo`0000?o0000ooooooooool0;_ooool2oomo00Oooooo2?oo000?ooooo`Co
ogl01Oooool4oomo027ooooo00?oo`00ooooooooool06?ooool00ol00?ooooooooooo`1ToooooaGo
003o2?ooool1o`00007ooooo00000ol0003oooooooooo`0]ooooo`Coogl01_ooool8ool000oooooo
1?ooO`05ooooo`Coogl08Oooool00ooo003oooooooooo`0Iooooo`03o`00oooooooooooo06?ooooo
5Ol00?l8ooooo`7o00000Oooool00003o`000?oooooooooo02gooooo1?ooO`06ooooo`Soo`004?oo
ool2oomo00Oooooo0oooO`0Qooooo`03ool00?oooooooooo01[ooooo00?o003oooooooooool0H_oo
oolEo`00o`Sooooo0Ol00001ooooo`0000?o0000ooooooooool0;_ooool2oomo00Sooooo1_oo000J
ooooo`Coogl08?ooool00ooo003oooooooooo`0Kooooo`03o`00oooooooooooo067ooooo5Ol00?l8
ooooo`7o00000Oooool00003o`000?oooooooooo03Sooooo00<0003oool00?oo00000_oo000Koooo
o`Coogl08?ooool00ooo003oooooooooo`0Looooo`03o`00oooooooooooo063ooooo5Ol00?l8oooo
o`7o00000Oooool00003o`000?oooooooooo03Oooooo00<0003oooooooooool06Oooool2oomo00Co
oooo0_ooO`0Qooooo`03ool00?oooooooooo01cooooo00?o003oooooooooool0OOooool1o`00007o
oooo00000ol0003oooooooooo`0fooooo`030000oooooooooooo01Wooooo1?ooO`0Uooooo`03ool0
0?oooooooooo01kooooo00?o003oooooooooool0O?ooool1o`00007ooooo00000ol0003ooooooooo
o`0fooooo`030000oooooooooooo01Wooooo1?ooO`0Uooooo`03ool00?oooooooooo01oooooo00?o
003oooooooooool0Noooool1o`00007ooooo00000ol0003oooooooooo`0eooooo`040000oooooooo
ogl0oomo01[ooooo0_ooO`0Vooooo`03ool00?oooooooooo023ooooo00?o003oooooooooool0N_oo
ool1o`00007ooooo00000ol0003oooooooooo`0dooooo`030000ooooooooogl000?oogl0@Oooool0
0ooo003oooooooooo`0Qooooo`03o`00oooooooooooo07Wooooo0Ol00001ooooo`0000?o0000oooo
ooooool0:oooool2oomo00Kooooo00<0003oooooooooool01?ooO`11ooooo`03ool00?oooooooooo
027ooooo00?o003oooooooooool0NOooool1o`00007ooooo00000ol0003oooooooooo`0Zooooo`Co
ogl01?ooool00`000?ooooooooooo`02ooooo`;oogl06?ooool2oomo017ooooo0_ooO`0Eooooo`03
ool00?oooooooooo02;ooooo00?o003oooooooooool0N?ooool1o`00007ooooo00000ol0003ooooo
ooooo`0Zooooo`Coogl01?ooool00`000?ooooooooooo`0Kooooo`Coogl03oooool4oomo01Cooooo
00?oo`00ooooooooool08oooool00ol00?ooooooooooo`1gooooo`7o00000Oooool00003o`000?oo
oooooooo02_ooooo0_ooO`04ooooo`030000oooooooooooo01cooooo1?ooO`0?ooooo`Coogl05?oo
ool00ooo003oooooooooo`0Sooooo`03o`00oooooooooooo07Oooooo0Ol00001ooooo`0000?o0000
ooooooooool0<Oooool00`000?ooooooooooo`0Mooooo`;oogl04Oooool2oomo01Cooooo00?oo`00
ooooooooool09Oooool00ol00?ooooooooooo`1fooooo`7o00000Oooool00003o`000?oooooooooo
033ooooo00<0003oooooooooool0Aoooool00ooo003oooooooooo`0Uooooo`03o`00oooooooooooo
07Kooooo0Ol00001ooooo`0000?o0000ooooooooool0<?ooool00`000?ooooooooooo`17ooooo`03
ool00?oooooooooo02Kooooo00?o003oooooooooool0MOooool1o`00007ooooo00000ol0003ooooo
ooooo`0_ooooo`030000oooooooooooo04Sooooo00?oo`00ooooooooool09oooool00ol00?oooooo
ooooo`1dooooo`7o00000Oooool00003o`000?oooooooooo02oooooo00<0003oooooooooool01ooo
ool2oomo00;ooooo0_ooO`0kooooo`03ool00?oooooooooo02Oooooo00?o003oooooooooool0M?oo
ool1o`00007ooooo00000ol0003oooooooooo`0^ooooo`030000oooooooooooo00Oooooo2?ooO`0i
ooooo`03ool00?oooooooooo02Wooooo00?o003oooooooooool0Loooool1o`00007ooooo00000ol0
003oooooooooo`0^ooooo`030000oooooooooooo00Oooooo2?ooO`0iooooo`03ool00?oooooooooo
02Wooooo00?o003oooooooooool0Loooool1o`00007ooooo00000ol0003oooooooooo`0]ooooo`03
0000oooooooooooo00Wooooo1_ooO`0Pooooo`;oogl05oooool00ooo003oooooooooo`0[ooooo`03
o`00oooooooooooo07;ooooo0Ol00001ooooo`0000?o0000ooooooooool0;Oooool00`000?oooooo
ooooo`0;ooooo`Coogl07oooool4oomo01Kooooo00?oo`00ooooooooool0:oooool00ol00?oooooo
ooooo`1booooo`7o00000Oooool00003o`000?oo003ooooo02gooooo00<0003oooooooooool03?oo
ool2oomo023ooooo1?ooO`0Fooooo`03ool00?oooooooooo02_ooooo00?o003oooooooooool0L_oo
ool1o`00007ooooo00000ol0003oo`00ooooo`0/ooooo`030000oooooooooooo033ooooo0_ooO`0F
ooooo`03ool00?oooooooooo02gooooo00?o003oooooooooool0LOooool1o`00007ooooo00000ol0
003oo`00ooooo`0/ooooo`030000oooooooooooo04Sooooo00?oo`00ooooooooool0;Oooool00ol0
0?ooooooooooo`1aooooo`7o00000Oooool00003o`000?ooooooo`0002cooooo00<0003ooooooooo
ool0B?ooool00ooo003oooooooooo`0]ooooo`03o`00oooooooooooo077ooooo0Ol00001ooooo`00
00?o0000oooooooo0000:oooool00`000?ooooooooooo`18ooooo`03ool00?oooooooooo02oooooo
00?o003oooooooooool0L?ooool1o`00007ooooo00001?l0003ooooooooooooo000Zooooo`030000
oooooooooooo00?ooooo0_ooO`13ooooo`03ool00?oooooooooo02oooooo00?o003oooooooooool0
L?ooool1o`00007ooooo00001?l0003ooooooooooooo000Zooooo`030000oooooooooooo00;ooooo
1?ooO`12ooooo`03ool00?oooooooooo02oooooo00?o003oooooooooool0L?ooool1o`00007ooooo
00001Ol0003oooooooooooooooooo`0002Wooooo00<0003oooooooooool00_ooool4oomo047ooooo
00?oo`00ooooooooool0<?ooool00ol00?ooooooooooo`1`ooooo`7o00000Oooool00005o`000?oo
oooooooooooooooo0000:?ooool00`000?ooooooooooo`04ooooo`;oogl0@_ooool00ooo003ooooo
ooooo`0aooooo`03o`00oooooooooooo06oooooo0Ol00001ooooo`0000?o0000ooooooooool00_oo
ool00ooo003oooooooooo`0Uooooo`030000oooooooooooo04Oooooo00?oo`00ooooooooool0<_oo
ool00ol00?ooooooooooo`1_ooooo`7o00000Oooool00003o`000?oooooooooo00;ooooo00?oo`00
ooooooooool09Oooool00`000?ooooooooooo`17ooooo`03ool00?oooooooooo03;ooooo00?o003o
ooooooooool0Koooool1o`00007ooooo00000ol0003oooooooooo`03ooooo`03ool00?oooooooooo
02Cooooo00<0003oooooooooool0A_ooool00ooo003oooooooooo`0cooooo`03o`00oooooooooooo
06oooooo0Ol00001ooooo`0000?o0000ooooooooool01?ooool00ooo003oooooooooo`0Sooooo`03
0000oooooooooooo04Gooooo00?oo`00ooooooooool0=?ooool00ol00?ooooooooooo`1_ooooo`7o
00000Oooool00003o`000?oooooooooo00Gooooo00?oo`00ooooooooool08Oooool00`000?oooooo
ooooo`15ooooo`03ool00?oooooooooo03Kooooo00?o003oooooooooool0K_ooool1o`00007ooooo
00000ol0003oooooooooo`06ooooo`03ool00?oooooooooo023ooooo00<0003oooooooooool0AOoo
ool00ooo003oooooooooo`09ooooo`;oogl0:oooool00ol00?ooooooooooo`1^ooooo`7o00000Ooo
ool00003o`000?oooooooooo00Kooooo00?oo`00ooooooooool08?ooool00`000?ooooooooooo`14
ooooo`03ool00?oooooooooo00Wooooo1?ooO`0Zooooo`03o`00oooooooooooo06kooooo0Ol00001
ooooo`0000?o0000ooooooooool01oooool00ooo003oooooooooo`0Oooooo`030000oooooooooooo
02Sooooo0_ooO`0Iooooo`03ool00?oooooooooo00[ooooo1?ooO`0Zooooo`03o`00oooooooooooo
06kooooo0Ol00001ooooo`0000?o0000ooooooooool01oooool00ooo003oooooooooo`0Oooooo`03
0000oooooooooooo02Oooooo1?ooO`0Gooooo`03ool00?oooooooooo00cooooo0_ooO`0[ooooo`03
o`00oooooooooooo06kooooo0Ol00001ooooo`0000?o0000ooooooooool02?ooool00ooo003ooooo
ooooo`0Nooooo`030000oooooooooooo02Oooooo1?ooO`0Gooooo`03ool00?oooooooooo03Wooooo
00?o003oooooooooool0K_ooool1o`00007ooooo00000ol0003oooooooooo`09ooooo`03ool00?oo
oooooooo01gooooo00<0003oooooooooool0:?ooool2oomo01;ooooo1?l00?l00oooooooo`00oooo
o`0kooooo`03o`00oooooooooooo06kooooo0Ol00001ooooo`0000?o0000ooooooooool02_ooool0
0ooo003oooooooooo`0Looooo`030000oooooooooooo03_ooooo1_l00?lmooooo`03o`00oooooooo
oooo06kooooo0Ol00001ooooo`0000?o0000ooooooooool02oooool00ooo003oooooooooo`0Koooo
o`030000oooooooooooo03Oooooo0_ooO`000ooooooo003oo`00o`06o`00occooooo00?o003ooooo
ooooool0K_ooool1o`00007ooooo00000ol0003oooooooooo`0<ooooo`03ool00?oooooooooo01[o
oooo00<0003oooooooooool0=_ooool4oomo00So003o??ooool00ol00?ooooooooooo`1^ooooo`7o
00000Oooool00003o`000?oooooooooo00gooooo00?oo`00ooooooooool06Oooool00`000?oooooo
ooooo`0fooooo`Coogl02?l00?llooooo`03o`00oooooooooooo06kooooo0Ol00001ooooo`0000?o
0000ooooooooool03Oooool2ool001[ooooo00<0003oooooooooool0=oooool2oomo0003ooooool0
0?oo003o00Ko003o??ooool00ol00?ooooooooooo`1^ooooo`7o00000Oooool00003o`000?oooooo
oooo00oooooo00?oo`00ooooooooool05oooool00`000?ooooooooooo`0jooooo`03ool00?l00?oo
003o00Co003o?Oooool00ol00?ooooooooooo`1^ooooo`7o00000Oooool00003o`000?oooooooooo
013ooooo00?oo`00ooooooooool05_ooool00`000?ooooooooooo`0iooooo`03ool00?oooooooooo
00Co003o?_ooool00ol00?ooooooooooo`1^ooooo`7o00000Oooool00003o`000?oooooooooo017o
oooo00?oo`00ooooooooool05Oooool00`000?ooooooooooo`0hooooo`03ool00?oooooooooo04?o
oooo00?o003oooooooooool0K_ooool1o`00007ooooo00000ol0003oooooooooo`0Booooo`03ool0
0?oooooooooo01Cooooo00<0003oooooooooool0=_ooool2ool004Kooooo00?o003oooooooooool0
K_ooool1o`00007ooooo00000ol0003oooooooooo`0Cooooo`03ool00?oooooooooo01?ooooo00<0
003oooooooooool0=Oooool00ooo003oooooooooo`16ooooo`03o`00oooooooooooo06kooooo0Ol0
0001ooooo`0000?o0000ooooooooool05?ooool2ool001?ooooo00<0003oooooooooool0=?ooool0
0ooo003oooooooooo`17ooooo`03o`00oooooooooooo06kooooo0Ol00001ooooo`0000?o0000oooo
ooooool05_ooool2ool0017ooooo00<0003oooooooooool0<_ooool2ool004[ooooo00?o003ooooo
ooooool0K_ooool1o`00007ooooo00000ol0003oooooooooo`0Hooooo`03ool00?oooooooooo00ko
oooo00<0003oooooooooool0<Oooool00ooo003oooooooooo`1:ooooo`03o`00oooooooooooo06ko
oooo0Ol00001ooooo`0000?o0000ooooooooool06Oooool2ool000kooooo00<0003oooooooooool0
;oooool2ool004gooooo00?o003oooooooooool0K_ooool1o`00007ooooo00000ol0003ooooooooo
o`0Kooooo`03ool00?oooooooooo00_ooooo00<0003oooooooooool0;_ooool00ooo003ooooooooo
o`1<ooooo`03o`00oooooooooooo06oooooo0Ol00001ooooo`0000?o0000ooooooooool07?ooool2
ool000_ooooo00<0003oooooooooool0;Oooool00ooo003oooooooooo`1=ooooo`03o`00oooooooo
oooo06oooooo0Ol00001ooooo`0000?o0000ooooooooool07_ooool3ool000Wooooo00<0003ooooo
ooooool0:_ooool2ool0053ooooo00?o003oooooooooool0Koooool1o`00007ooooo00000ol0003o
ooooooooo`0Qooooo`;oo`001oooool00`000?ooooooooooo`0Wooooo`?oo`00D_ooool00ol00?oo
ooooooooo`1_ooooo`7o00000Oooool00003o`000?oooooooooo02?ooooo0_oo0005ooooo`030000
oooooooooooo02Gooooo0_oo001Dooooo`03o`00oooooooooooo073ooooo0Ol00001ooooo`0000?o
0000ooooooooool09Oooool4ool00003ooooo`000?oooooo02;ooooo1?oo001Fooooo`03o`00oooo
oooooooo073ooooo0Ol00001ooooo`0000?o0000ooooooooool0:Oooool2ool00003o`00oooo003o
o`0001gooooo0ooo001Jooooo`03o`00oooooooooooo073ooooo0Ol00001ooooo`0000?o0000oooo
ooooool0:oooool00`000?ooooooooooo`03ool001Cooooo1_oo001Mooooo`03o`00oooooooooooo
073ooooo0Ol00001ooooo`0000?o0000ooooooooool0;?ooool00`000?ooooooooooo`02oooooaCo
o`00H_ooool00ol00?ooooooooooo`1aooooo`7o00000Oooool00003o`000?oooooooooo02cooooo
00<0003oooooooooool0N?ooool00ol00?ooooooooooo`1aooooo`7o00000Oooool00003o`000?oo
oooooooo02cooooo00<0003oooooooooool0N?ooool00ol00?ooooooooooo`1aooooo`7o00000Ooo
ool00003o`000?oooooooooo02gooooo00<0003oooooooooool0M_ooool00ol00?ooooooooooo`1b
ooooo`7o00000Oooool00003o`000?oooooooooo02gooooo00<0003oooooooooool0M_ooool00ol0
0?ooooooooooo`1booooo`7o00000Oooool00003o`000?oooooooooo02gooooo00<0003ooooooooo
ool0M_ooool00ol00?ooooooooooo`1booooo`7o00000Oooool00003o`000?oooooooooo02kooooo
00<0003oooooooooool0M?ooool00ol00?ooooooooooo`1cooooo`7o00000Oooool00003o`000?oo
oooooooo02kooooo00<0003oooooooooool0M?ooool00ol00?ooooooooooo`1cooooo`7o00000Ooo
ool00003o`000?oooooooooo02kooooo00<0003oooooooooool0M?ooool00ol00?ooooooooooo`1c
ooooo`7o00000Oooool00003o`000?oooooooooo02oooooo00<0003oooooooooool0L_ooool00ol0
0?ooooooooooo`1dooooo`7o00000Oooool00003o`000?oooooooooo02oooooo00<0003ooooooooo
ool0L_ooool00ol00?ooooooooooo`1dooooo`7o00000Oooool00003o`000?oooooooooo02oooooo
00<0003oooooooooool0L_ooool00ol00?ooooooooooo`1dooooo`7o00000Oooool00003o`000?oo
oooooooo033ooooo00<0003oooooooooool0Koooool2o`00ogOooooo0Ol00001ooooo`0000?o0000
ooooooooool0<?ooool00`000?ooooooooooo`1_ooooo`03o`00oooooooooooo07Kooooo0Ol00001
ooooo`0000?o0000ooooooooool0<Oooool00`000?ooooooooooo`1]ooooo`03o`00oooooooooooo
07Oooooo0Ol00001ooooo`0000?o0000ooooooooool0<_ooool00`000?ooooooooooo`1/ooooo`03
o`00oooooooooooo07Oooooo0Ol00001ooooo`0000?o0000ooooooooool0<_ooool00`000?oooooo
ooooo`1[ooooo`03o`00oooooooooooo063ooooo0_ooO`0Fooooo`7o00000Oooool00003o`000?oo
oooooooo03?ooooo00<0003oooooooooool0JOooool00ol00?ooooooooooo`1Pooooo`Coogl05Ooo
ool1o`00007ooooo00000ol0003oooooooooo`0dooooo`030000oooooooooooo06Sooooo00?o003o
ooooooooool0H?ooool4oomo01Gooooo0Ol00001ooooo`0000?o0000ooooooooool0=Oooool00`00
0?ooooooooooo`1Vooooo`03o`00oooooooooooo06;ooooo0_ooO`0Fooooo`7o00000Oooool00003
o`000?oooooooooo03Gooooo00?o003oooooooooool0I_ooool00ol00?ooooooooooo`1jooooo`7o
00000Oooool00003o`000?oooooooooo03Kooooo00?o003oooooooooool0I?ooool00ol00?oooooo
ooooo`1kooooo`7o00000Oooool00003o`000?oooooooooo03Oooooo00?o003oooooooooool0H_oo
ool00ol00?ooooooooooo`1looooo`7o00000Oooool00003o`000?oooooooooo03Sooooo00?o003o
ooooooooool0Goooool2o`00ogoooooo0Ol00001ooooo`0000?o0000ooooooooool0>Oooool00ol0
0?ooooooooooo`1Mooooo`03o`00oooooooooooo07oooooo0Ol00001ooooo`0000?o0000oooooooo
ool0>_ooool00ol00?ooooooooooo`1Kooooo`03o`00oooooooooooo083ooooo0Ol00001ooooo`00
00?o0000ooooooooool0>oooool00ol00?ooooooooooo`1Iooooo`03o`00oooooooooooo01Wooooo
1Ooo0?mSooooo`7o00000Oooool00003o`000?oooooooooo03cooooo00?o003oooooooooool0Eooo
ool00ol00?ooooooooooo`0Iooooo`Ooo`3oH_ooool1o`00007ooooo00000ol0003oooooooooo`0m
ooooo`03o`00oooooooooooo05Gooooo00?o003oooooooooool06Oooool9ool0of7ooooo0Ol00001
ooooo`0000?o0000ooooooooool0?_ooool00ol00?ooooooooooo`1Cooooo`03o`00oooooooooooo
01Wooooo2ooo0?mPooooo`7o00000Oooool00003o`000?oooooooooo03oooooo00?o003ooooooooo
ool0D?ooool2o`00oacooooo2ooo0?mPooooo`7o00000Oooool00003o`000?oooooooooo043ooooo
00?o003oooooooooool0C_ooool00ol00?ooooooooooo`0Looooo`_oo`3oH?ooool1o`00007ooooo
00000ol0003oooooooooo`11ooooo`;o003oCOooool00ol00?ooooooooooo`0Mooooo`_oo`3oH?oo
ool1o`00007ooooo00000ol0003oooooooooo`13ooooo`03o`00oooooooooooo04Wooooo00?o003o
ooooooooool07_ooool;ool0oc7ooooo0_ooO`0]ooooo`7o00000Oooool00003o`000?oooooooooo
04Cooooo0_l00?m8ooooo`03o`00oooooooooooo023ooooo2Ooo0?lZooooo`;oogl01Oooool4oomo
02cooooo0Ol00001ooooo`0000?o0000ooooooooool0A_ooool2o`00odGooooo00?o003ooooooooo
ool08_ooool7ool0ob[ooooo1?ooO`04ooooo`Coogl0;?ooool1o`00007ooooo00000ol0003ooooo
ooooo`18ooooo`03o`00oooooooooooo043ooooo0_l00?lVooooo`Goo`3o2oooool2oomo01kooooo
1?ooO`05ooooo`;oogl0;Oooool1o`00007ooooo00000ol0003oooooooooo`19ooooo`;o003o?_oo
ool2o`00ocOooooo1?ooO`0Nooooo`;oogl0=Oooool1o`00007ooooo00000ol0003oooooooooo`1;
ooooo`?o003o>_ooool00ol00?ooooooooooo`0gooooo`Coogl0EOooool1o`00007ooooo00000ol0
003oooooooooo`1>ooooo`;o003o=_ooool2o`00oc_ooooo0_ooO`1Fooooo`7o00000Oooool00003
o`000?oooooooooo053ooooo0ol00?l`ooooo`?o003o<oooool2oomo02Gooooo0_ooO`0iooooo`7o
00000Oooool00003o`000?oooooooooo05?ooooo0_l00?lZooooo`Co003o=Oooool4oomo02?ooooo
1?ooO`0hooooo`7o00000Oooool00003o`000?oooooooooo05Gooooo0ol00?lSooooo`Co003o=Ooo
ool2oomo00;ooooo1?ooO`0Sooooo`Coogl00oooool2oomo03?ooooo0Ol00001ooooo`0000?o0000
ooooooooool0F?ooool3o`00oagooooo0ol00?lhooooo`Coogl00_ooool2oomo01?ooooo0_ooO`0@
ooooo`;oogl00oooool4oomo03;ooooo0Ol00001ooooo`0000?o0000ooooooooool0Foooool3o`00
oaCooooo1_l00?lkooooo`Coogl01_ooool2oomo00kooooo1?ooO`0Dooooo`Coogl0<_ooool1o`00
007ooooo00000ol0003oooooooooo`1NoooooaCo003o@_ooool2oomo00Kooooo1?ooO`0=ooooo`Co
ogl05Oooool2oomo03?ooooo0Ol00001ooooo`0000?o0000ooooooooool0Roooool2oomo02Oooooo
0_ooO`06ooooo`Coogl03_ooool2oomo04_ooooo0Ol00001ooooo`0000?o0000ooooooooool0R_oo
ool4oomo02Gooooo1?ooO`06ooooo`;oogl0G?ooool1o`00007ooooo00000ol0003oooooooooo`2:
ooooo`Coogl09Oooool4oomo06Cooooo0Ol00001ooooo`0000?o0000ooooooooool0Roooool2oomo
02Oooooo0_ooO`1Uooooo`7o00000Oooool00003o`000?oooooooooo09Kooooo0_ooO`0jooooo`;o
ogl0Aoooool1o`00007ooooo00000ol0003oooooooooo`2Eooooo`Coogl03_ooool2oomo02Sooooo
1?ooO`16ooooo`7o00000Oooool00003o`000?oooooooooo09Gooooo1?ooO`0=ooooo`Coogl09ooo
ool4oomo04Kooooo0Ol00001ooooo`0000?o0000ooooooooool0U_ooool2oomo00kooooo1?ooO`0X
ooooo`;oogl0Aoooool1o`00007ooooo00000ol0003oooooooooo`2Wooooo`;oogl0L_ooool1o`00
007ooooo00000ol0003oooooooooo`3[ooooo`;oogl0;_ooool1o`00007ooooo00000ol0003ooooo
ooooo`3Zooooo`Coogl0;Oooool1o`00007ooooo00000ol0003oooooooooo`3Fooooo`;oogl04_oo
ool4oomo02gooooo0Ol00001ooooo`0000?o0000ooooooooool0eOooool4oomo01;ooooo0_ooO`0^
ooooo`7o00000Oooool00003o`000?oooooooooo0;Oooooo0_ooO`0Looooo`Coogl0@_ooool1o`00
007ooooo00000ol0003oooooooooo`2fooooo`Coogl07?ooool2oomo04?ooooo0Ol00001ooooo`00
00?o0000ooooooooool0/oooool2oomo0003ooooooooO`3oogl000;oogl0HOooool1o`00007ooooo
00000ol0003oooooooooo`2Xooooo`;oogl02?ooool4oomo0003ooooooooO`3oogl001[ooooo0_oo
O`16ooooo`7o00000Oooool00003o`000?oooooooooo0:Kooooo1OooO`07ooooo`Coogl05oooool2
oomo00?ooooo1?ooO`15ooooo`7o00000Oooool00003o`000?oooooooooo0:Gooooo1_ooO`08oooo
o`;oogl05oooool4oomo00;ooooo1?ooO`15ooooo`7o00000Oooool00003o`000?oooooooooo0:Go
oooo1OooO`0Rooooo`Coogl00oooool2oomo04Kooooo0Ol00001ooooo`0000?o0000ooooooooool0
M_ooool2oomo02kooooo0_ooO`0Uooooo`;oogl0C?ooool1o`00007ooooo00000ol0003ooooooooo
o`1eooooo`Coogl0X_ooool1o`00007ooooo00000ol0003oooooooooo`1eooooo`Coogl02_ooool2
oomo09Kooooo0Ol00001ooooo`0000?o0000ooooooooool0M_ooool2oomo00[ooooo1?ooO`0Zoooo
o`;oogl0JOooool1o`00007ooooo00000ol0003oooooooooo`22ooooo`Coogl0:Oooool4oomo06So
oooo0Ol00001ooooo`0000?o0000ooooooooool0Poooool2oomo02Cooooo0_ooO`04ooooo`Coogl0
J?ooool1o`00007ooooo00000ol0003oooooooooo`2Xooooo`Coogl01?ooool2oomo06Wooooo0Ol0
0001ooooo`0000?o0000ooooooooool0Z?ooool4oomo06oooooo0Ol00001ooooo`0000?o0000oooo
ooooool0ZOooool2oomo073ooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o
00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003ooooooooo
o`3ooooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool0
0003o`000?oooooooooo08Cooooo0_ooO`2Eooooo`7o00000Oooool00003o`000?oooooooooo08?o
oooo1?ooO`2Dooooo`7o00000Oooool00003o`000?oooooooooo08?ooooo1?ooO`2Dooooo`7o0000
0Oooool00003o`000?oooooooooo08Cooooo0_ooO`0/ooooo`;oogl0Ioooool1o`00007ooooo0000
0ol0003oooooooooo`2aooooo`Coogl0I_ooool1o`00007ooooo00000ol0003oooooooooo`2aoooo
o`Coogl0I_ooool1o`00007ooooo00000ol0003oooooooooo`2booooo`;oogl0Ioooool1o`00007o
oooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooo
oolLooooo`7o00000Oooool00003o`000?oooooooooo07_ooooo0_ooO`2Nooooo`7o00000Oooool0
0003o`000?oooooooooo07[ooooo1?ooO`2Mooooo`7o00000Oooool00003o`000?oooooooooo07[o
oooo1?ooO`0Pooooo`;oogl0Noooool1o`00007ooooo00000ol0003oooooooooo`1kooooo`;oogl0
8?ooool4oomo07[ooooo0Ol00001ooooo`0000?o0000ooooooooool0WOooool4oomo07[ooooo0Ol0
0001ooooo`0000?o0000ooooooooool0T?ooool2oomo00cooooo0_ooO`1kooooo`7o00000Oooool0
0003o`000?oooooooooo08oooooo1?ooO`28ooooo`7o00000Oooool00003o`000?oooooooooo08oo
oooo1?ooO`28ooooo`7o00000Oooool00003o`000?oooooooooo093ooooo0_ooO`0Sooooo`;oogl0
I?ooool1o`00007ooooo00000ol0003oooooooooo`2dooooo`Coogl0Hoooool1o`00007ooooo0000
0ol0003oooooooooo`2dooooo`Coogl0Hoooool1o`00007ooooo00000ol0003oooooooooo`2eoooo
o`;oogl0I?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`00
00?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?oo
ool1o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000oooo
ooooool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007o
oooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooo
oolLooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0
003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o
00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003ooooooooo
o`3ooooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool0
0003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooooaco
oooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oo
oooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001
ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo0?oo
oooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o
0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1
o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000oooooooo
ool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo
00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolL
ooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003o
ooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o0000
0Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3o
oooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003
o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo
0Ol00001ooooo`0000?o0000ooooooooool0S_ooool2oomo08_ooooo0Ol00001ooooo`0000?o0000
ooooooooool0SOooool4oomo08[ooooo0Ol00001ooooo`0000?o0000ooooooooool0SOooool4oomo
08[ooooo0Ol00001ooooo`0000?o0000ooooooooool0S_ooool2oomo08_ooooo0Ol00001ooooo`00
00?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?oo
ool1o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000oooo
ooooool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007o
oooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooo
oolLooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0
003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o
00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003ooooooooo
o`3ooooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool0
0003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooooaco
oooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oo
oooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001
ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo0?oo
oooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`00ool0
000Po`00007ooooo0000\
\>"],
  ImageRangeCache->{{{0, 287}, {287, 0}} -> {-1.01089, -1.01089, 0.00704453, \
0.00704453}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.49505 0.5 0.49505 [
[ 0 0 -0.125 0 ]
[ 0 0 -0.125 0 ]
[ 0 1 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
0 0 m
1 0 L
s
0 0 m
0 1 L
s
0 1 m
1 1 L
s
1 0 m
1 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
1 .5 0 r
.015 w
.03175 .1355 Mdot
.03435 .12523 Mdot
.11137 .12765 Mdot
.14107 .18841 Mdot
.16218 .24538 Mdot
.17294 .21053 Mdot
.18267 .18577 Mdot
.18434 .1304 Mdot
.18553 .30956 Mdot
.20401 .239 Mdot
.21247 .27571 Mdot
.21687 .20845 Mdot
.22376 .2799 Mdot
.22832 .27485 Mdot
.29063 .20974 Mdot
.29686 .25079 Mdot
.30487 .22936 Mdot
.30683 .34623 Mdot
.32055 .20902 Mdot
.32574 .21979 Mdot
.34472 .28521 Mdot
.35998 .36393 Mdot
.36335 .24976 Mdot
.3794 .36608 Mdot
.42386 .66992 Mdot
.44391 .74519 Mdot
.45059 .34198 Mdot
.47208 .67586 Mdot
.47436 .71381 Mdot
.49778 .59825 Mdot
.50874 .91643 Mdot
.51516 .76219 Mdot
.53655 .61374 Mdot
.56563 .75219 Mdot
.59189 .65665 Mdot
.59581 .61604 Mdot
.59923 .6556 Mdot
.60292 .68499 Mdot
.62656 .67779 Mdot
.63555 .72451 Mdot
.63919 .652 Mdot
.64169 .6004 Mdot
.64246 .58611 Mdot
.64496 .54267 Mdot
.64608 .77288 Mdot
.65077 .64308 Mdot
.66065 .57816 Mdot
.67474 .59169 Mdot
.69296 .563 Mdot
.72815 .65902 Mdot
.73169 .58879 Mdot
.74669 .61318 Mdot
.74821 .65474 Mdot
.75963 .63781 Mdot
.79673 .57809 Mdot
.80925 .55852 Mdot
.81525 .58444 Mdot
.83417 .62985 Mdot
.83598 .55526 Mdot
.91595 .49319 Mdot
1 0 0 r
.005 w
.00495 .28842 m
.00628 .29156 L
.01857 .31761 L
.03101 .33781 L
.03525 .34367 L
.05706 .36884 L
.05795 .36972 L
.08312 .39115 L
.08963 .39578 L
.10917 .40763 L
.13523 .41964 L
.14074 .42183 L
.16128 .42794 L
.18734 .43294 L
.21339 .43485 L
.23945 .43375 L
.2655 .42959 L
.29156 .42219 L
.29261 .42183 L
.31761 .41124 L
.34367 .39603 L
.34405 .39578 L
.36972 .37551 L
.37582 .36972 L
.39578 .34724 L
.39849 .34367 L
.41525 .31761 L
.42183 .30485 L
.4275 .29156 L
.436 .2655 L
.44117 .23945 L
.44325 .21339 L
.44232 .18734 L
.43834 .16128 L
.43114 .13523 L
.42183 .11212 L
.42037 .10917 L
.40546 .08312 L
.39578 .06961 L
.38528 .05706 L
.36972 .04137 L
.35758 .03101 L
.34367 .02092 L
.31761 .00569 L
.3162 .00495 L
s
.00495 .12854 m
.01344 .10917 L
.02832 .08312 L
.03101 .07912 L
.04848 .05706 L
.05706 .04802 L
.07619 .03101 L
.08312 .02579 L
.10917 .00934 L
.11742 .00495 L
s
0 0 1 r
.29156 .15739 m
.31761 .14824 L
.34367 .14249 L
.36972 .13986 L
.39578 .14025 L
.42183 .14366 L
.44789 .15025 L
.47394 .16034 L
.47599 .16128 L
.5 .17443 L
.51844 .18734 L
.52606 .19355 L
.54662 .21339 L
.55211 .21962 L
.56712 .23945 L
.57817 .25755 L
.58227 .2655 L
.59322 .29156 L
.60058 .31761 L
.60422 .3392 L
.60471 .34367 L
.6058 .36972 L
.60422 .39297 L
.60387 .39578 L
.59886 .42183 L
.59054 .44789 L
.57848 .47394 L
.57817 .47453 L
.562 .5 L
.55211 .51255 L
.53968 .52606 L
.52606 .53862 L
.50853 .55211 L
.5 .55773 L
.47394 .57183 L
.45901 .57817 L
.44789 .5819 L
.42183 .5885 L
.39578 .59192 L
.36972 .59231 L
.34367 .58968 L
.31761 .58392 L
.29972 .57817 L
.29156 .57477 L
.2655 .56178 L
.25025 .55211 L
.23945 .54409 L
.21914 .52606 L
.21339 .52008 L
.19681 .5 L
Mistroke
.18734 .48608 L
.18031 .47394 L
.16827 .44789 L
.16128 .42714 L
.15996 .42183 L
.15493 .39578 L
.153 .36972 L
.15409 .34367 L
.15823 .31761 L
.16128 .3045 L
.16559 .29156 L
.17653 .2655 L
.18734 .24609 L
.19169 .23945 L
.21221 .21339 L
.21339 .21211 L
.23945 .1881 L
.24041 .18734 L
.2655 .17038 L
.28271 .16128 L
.29156 .15739 L
Mfstroke
1 0 0 r
.03 w
.21687 .20845 Mdot
0 0 1 r
.3794 .36608 Mdot
1 0 0 r
.79703 .00495 m
.79703 .02212 L
.87129 .02212 L
.87129 .00495 L
F
0 0 1 r
.89604 .00495 m
.89604 .2353 L
.9703 .2353 L
.9703 .00495 L
F
1 0 1 r
.04 w
.64608 .77288 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P000182000`400?l00000o`00003ooooooolQ
ooooo`00ool0000Po`00007ooooo00000ol0003oooooooooo`0Mooooo`;oo`00>?ooool3ool00<7o
oooo0Ol00001ooooo`0000?o0000ooooooooool06oooool2ool003gooooo00?oo`00ooooooooool0
Q?oooolEool000Sooooo5Ol00?l8ooooo`7o00000Oooool00003o`000?oooooooooo01[ooooo00?o
o`00ooooooooool0?_ooool2ool008Cooooo5Ooo0008oooooaGo003o2?ooool1o`00007ooooo0000
0ol0003oooooooooo`0Hooooo`;oo`00@oooool00ooo003oooooooooo`21oooooaGoo`002?oooolE
o`00o`Sooooo0Ol00001ooooo`0000?o0000ooooooooool05_ooool2ool004Kooooo00?oo`00oooo
ooooool0P?oooolEool000Sooooo5Ol00?l8ooooo`7o00000Oooool00003o`000?oooooooooo01Go
oooo00?oo`00ooooooooool0Aoooool2ool0083ooooo5Ooo0008oooooaGo003o2?ooool1o`00007o
oooo00000ol0003oooooooooo`0Dooooo`03ool00?oooooooooo04[ooooo00?oo`00ooooooooool0
V_oooolEo`00o`Sooooo0Ol00001ooooo`0000?o0000ooooooooool04oooool00ooo003ooooooooo
o`1<ooooo`03ool00?oooooooooo09Wooooo5Ol00?l8ooooo`7o00000Oooool00003o`000?oooooo
oooo017ooooo0_oo001@ooooo`;oo`00VOoooolEo`00o`Sooooo0Ol00001ooooo`0000?o0000oooo
ooooool04?ooool00ooo003oooooooooo`1Booooo`;oo`00UooooolEo`00o`Sooooo0Ol00001oooo
o`0000?o0000ooooooooool03oooool00ooo003oooooooooo`1Eooooo`03ool00?oooooooooo09Co
oooo5Ol00?l8ooooo`7o00000Oooool00003o`000?oooooooooo00kooooo00?oo`00ooooooooool0
E_ooool00ooo003oooooooooo`2DoooooaGo003o2?ooool1o`00007ooooo00000ol0003ooooooooo
o`0=ooooo`03ool00?oooooooooo05Sooooo00?oo`00ooooooooool0TooooolEo`00o`Sooooo0Ol0
0001ooooo`0000?o0000ooooooooool03Oooool00ooo003oooooooooo`1Iooooo`03ool00?oooooo
oooo09;ooooo5Ol00?l8ooooo`7o00000Oooool00003o`000?oooooooooo00cooooo00?oo`00oooo
ooooool0Foooool00ooo003oooooooooo`2AoooooaGo003o2?ooool1o`00007ooooo00000ol0003o
ooooooooo`0;ooooo`03ool00?oooooooooo05gooooo00?oo`00ooooooooool0T?oooolEo`00o`So
oooo0Ol00001ooooo`0000?o0000ooooooooool02oooool00ooo003oooooooooo`1Mooooo`03ool0
0?oooooooooo093ooooo5Ol00?l8ooooo`7o00000Oooool00003o`000?oooooooooo00[ooooo00?o
o`00ooooooooool0Goooool00ooo003oooooooooo`2?oooooaGo003o2?ooool1o`00007ooooo0000
0ol0003oooooooooo`09ooooo`03ool00?oooooooooo067ooooo00?oo`00ooooooooool0S_oooolE
o`00o`Sooooo0Ol00001ooooo`0000?o0000ooooooooool02?ooool00ooo003oooooooooo`1Soooo
o`03ool00?oooooooooo08gooooo5Ol00?l8ooooo`7o00000Oooool00003o`000?oooooooooo00Oo
oooo00?oo`00ooooooooool0IOooool00ooo003oooooooooo`2<oooooaGo003o2?ooool1o`00007o
oooo00000ol0003oooooooooo`06ooooo`03ool00?oooooooooo06Oooooo00?oo`00ooooooooool0
RooooolEo`00o`Sooooo0Ol00001ooooo`0000?o0000ooooooooool01Oooool00ooo003ooooooooo
o`1Yooooo`03ool00?oooooooooo08[ooooo5Ol00?l8ooooo`7o00000Oooool00003o`000?oooooo
oooo00Gooooo00?oo`00ooooooooool0JOooool00ooo003oooooooooo`2:oooooaGo003o2?ooool1
o`00007ooooo00000ol0003oooooooooo`04ooooo`03ool00?oooooooooo06_ooooo00?oo`00oooo
ooooool0ROoooolEo`00o`Sooooo0Ol00001ooooo`0000?o0000ooooooooool00oooool00ooo003o
ooooooooo`1/ooooo`03ool00?oooooooooo08Wooooo5Ol00?l8ooooo`7o00000Oooool00003o`00
0?oooooooooo00?ooooo00?oo`00ooooooooool0KOooool00ooo003oooooooooo`28oooooaGo003o
2?ooool1o`00007ooooo00000ol0003oooooooooo`02ooooo`03ool00?oooooooooo06kooooo00?o
o`00ooooooooool0R?oooolEo`00o`Sooooo0Ol00001ooooo`0000?o0000ooooooooool00_ooool0
0ooo003oooooooooo`1_ooooo`03ool00?oooooooooo08Oooooo5Ol00?l8ooooo`7o00000Oooool0
0005o`000?oooooooooooooooooo0000L_ooool00ooo003oooooooooo`27oooooaGo003o2?ooool1
o`00007ooooo00001?l0003ooooooooooooo001dooooo`03ool00?oooooooooo08Kooooo5Ol00?l8
ooooo`7o00000Oooool00004o`000?ooooooooooool007Gooooo00?oo`00ooooooooool0QOoooolE
o`00o`Sooooo0Ol00001ooooo`0000?o0000oooooooo0000M_ooool00ooo003oooooooooo`25oooo
oaGo003o2?ooool1o`00007ooooo00000ol0003oooooool00006ooooo`;oogl0Koooool00ooo003o
ooooooooo`24oooooaGo003o2?ooool1o`00007ooooo00000ol0003oooooool00005ooooo`Coogl0
4oooool2oomo05Wooooo00?oo`00ooooooooool0Q?oooolEo`00o`Sooooo0Ol00001ooooo`0000?o
0000ool00?ooool01Oooool4oomo01;ooooo1?ooO`0Booooo`;oogl0A?ooool00ooo003ooooooooo
o`24oooooaGo003o2?ooool1o`00007ooooo00000ol0003oooooooooo`05ooooo`?oogl04oooool4
oomo017ooooo1?ooO`14ooooo`03ool00?oooooooooo08?ooooo5Ol00?l8ooooo`7o00000Oooool0
0003o`000?oooooooooo00Cooooo1?ooO`0Dooooo`;oogl04_ooool4oomo04Cooooo00?oo`00oooo
ooooool0PooooolEo`00o`Sooooo0Ol00001ooooo`0000?o0000ooooooooool01?ooool4oomo02Wo
oooo0_ooO`15ooooo`03ool00?oooooooooo08?ooooo5Ol00?l8ooooo`7o00000Oooool00003o`00
0?oooooooooo00Gooooo0_ooO`1FoooooaKo003o1Oooool00ooo003oooooooooo`23oooooaGo003o
2?ooool1o`00007ooooo00000ol0003oooooooooo`1Jooooo`?o003o5_ooool6o`00o`03ool00?oo
oooooooo08;ooooo5Ol00?l8ooooo`7o00000Oooool00003o`000?oooooooooo05Oooooo0ol00?lO
ooooo`?o003oP_oooolEo`00o`Sooooo0Ol00001ooooo`0000?o0000ooooooooool0E?ooool3o`00
ob;ooooo00?oo`00ooooooooool00ol00?mooooooaGo003o2?ooool1o`00007ooooo00000ol0003o
ooooooooo`1Aooooo`?o003o9Oooool00ooo003oooooooooo`03ooooo`?o003oO?oooolEo`00o`So
oooo0Ol00001ooooo`0000?o0000ooooooooool0Coooool20000obWooooo00?oo`00ooooooooool0
1Oooool3o`00ogWooooo5Ol00?l8ooooo`7o00000Oooool00003o`000?oooooooooo04gooooo0P00
0?l[ooooo`03ool00?oooooooooo00Sooooo0_l00?mgoooooaGo003o2?ooool1o`00007ooooo0000
0ol0003oooooooooo`1:ooooo`<0003o;Oooool00ooo003oooooooooo`0:ooooo`;o003oMOoooolE
o`00o`Sooooo0Ol00001ooooo`0000?o0000ooooooooool0B?ooool20000oc3ooooo00?oo`00oooo
ooooool03?ooool00ol00?ooooooooooo`1boooooaGo003o2?ooool1o`00007ooooo00000ol0003o
ooooooooo`17ooooo`030000oooooooooooo033ooooo00?oo`00ooooooooool03Oooool2o`00og;o
oooo5Ol00?l8ooooo`7o00000Oooool00003o`000?oooooooooo04Gooooo0P000?ldooooo`03ool0
0?oooooooooo00kooooo0_l00?m`oooooaGo003o2?ooool1o`00007ooooo00000ol0003ooooooooo
o`14ooooo`030000oooooooooooo03Cooooo00?oo`00ooooooooool04?ooool2o`00ofkooooo5Ol0
0?l8ooooo`7o00000Oooool00003o`000?oooooooooo02Cooooo0_ooO`0:ooooo`;oogl04Oooool0
0`000?ooooooooooo`0eooooo`03ool00?oooooooooo01;ooooo00?o003oooooooooool0JooooolE
o`00o`Sooooo0Ol00001ooooo`0000?o0000ooooooooool08oooool4oomo00Sooooo1?ooO`0?oooo
o`030000oooooooooooo03Kooooo00?oo`00ooooooooool04oooool00ol00?ooooooooooo`1Zoooo
oaGo003o2?ooool1o`00007ooooo00000ol0003oooooooooo`0Sooooo`Coogl02?ooool4oomo00go
oooo00<0003oo`00ooooool0>?ooool00ooo003oooooooooo`0Dooooo`03o`00oooooooooooo06Wo
oooo5Ol00?l8ooooo`7o00000Oooool00003o`000?oooooooooo02Cooooo0_ooO`0:ooooo`;oogl0
3Oooool00`000?ooooooooooo`0iooooo`03ool00?oooooooooo01Gooooo00?o003oooooooooool0
J?oooolEo`00o`Sooooo0Ol00001ooooo`0000?o0000ooooooooool0>Oooool4ool00003ooooo`00
0?oooooo03_ooooo00?oo`00ooooooooool05_ooool00ol00?ooooooooooo`1WoooooaGo003o2?oo
ool1o`00007ooooo00000ol0003oooooooooo`0hooooo`Koo`00?Oooool00ooo003oooooooooo`0G
ooooo`03o`00oooooooooooo06Kooooo5Ol00?l8ooooo`7o00000Oooool00003o`000?oooooooooo
03Oooooo2?oo000@ooooo`;oogl01oooool2oomo02;ooooo00?oo`00ooooooooool05oooool00ol0
0?ooooooooooo`1UoooooaGo003o2?ooool1o`00007ooooo00000ol0003oooooooooo`0^ooooo`;o
ogl01oooool8ool000oooooo1?ooO`05ooooo`Coogl08Oooool00ooo003oooooooooo`0Hooooo`03
o`00oooooooooooo06Cooooo5Ol00?l8ooooo`7o00000Oooool00003o`000?oooooooooo02gooooo
1?ooO`06ooooo`Soo`003oooool4oomo00Gooooo1?ooO`0Qooooo`03ool00?oooooooooo01Wooooo
00?o003oooooooooool0HooooolEo`00o`Sooooo0Ol00001ooooo`0000?o0000ooooooooool0;Ooo
ool4oomo00Kooooo2?oo000@ooooo`;oogl01oooool3oomo027ooooo00?oo`00ooooooooool06_oo
ool00ol00?ooooooooooo`1RoooooaGo003o2?ooool1o`00007ooooo00000ol0003oooooooooo`0^
ooooo`;oogl02?ooool6ool001[ooooo1?ooO`0Pooooo`03ool00?oooooooooo01_ooooo00?o003o
ooooooooool0HOoooolEo`00o`Sooooo0Ol00001ooooo`0000?o0000ooooooooool0>?ooool00`00
0?ooo`00ool00002ool001_ooooo1?ooO`0Pooooo`03ool00?oooooooooo01cooooo00?o003ooooo
ooooool0H?oooolEo`00o`Sooooo0Ol00001ooooo`0000?o0000ooooooooool0=oooool00`000?oo
ooooooooo`0Iooooo`;oogl01?ooool2oomo027ooooo00?oo`00ooooooooool07?ooool00ol00?oo
ooooooooo`1PoooooaGo003o2?ooool1o`00007ooooo00000ol0003oooooooooo`0fooooo`030000
oooooooooooo01Wooooo1?ooO`0Uooooo`03ool00?oooooooooo01kooooo00?o003oooooooooool0
GooooolEo`00o`Sooooo0Ol00001ooooo`0000?o0000ooooooooool0=_ooool00`000?oooooooooo
o`0Iooooo`Coogl09Oooool00ooo003oooooooooo`0Oooooo`03o`00oooooooooooo05kooooo5Ol0
0?l8ooooo`7o00000Oooool00003o`000?oooooooooo03Gooooo00@0003oooooooooO`3oogl06_oo
ool2oomo02Kooooo00?oo`00ooooooooool08?ooool00ol00?ooooooooooo`1MoooooaGo003o2?oo
ool1o`00007ooooo00000ol0003oooooooooo`0dooooo`030000ooooooooogl000?oogl0@Oooool0
0ooo003oooooooooo`0Qooooo`03o`00oooooooooooo07Wooooo0Ol00001ooooo`0000?o0000oooo
ooooool0:oooool2oomo00Kooooo00<0003oooooooooool01?ooO`11ooooo`03ool00?oooooooooo
027ooooo00?o003oooooooooool0NOooool1o`00007ooooo00000ol0003oooooooooo`0Zooooo`Co
ogl01?ooool00`000?ooooooooooo`02ooooo`;oogl06?ooool2oomo017ooooo0_ooO`0Eooooo`03
ool00?oooooooooo02;ooooo00?o003oooooooooool0N?ooool1o`00007ooooo00000ol0003ooooo
ooooo`0Zooooo`Coogl01?ooool00`000?ooooooooooo`0Kooooo`Coogl03oooool4oomo01Cooooo
00?oo`00ooooooooool08oooool00ol00?ooooooooooo`1gooooo`7o00000Oooool00003o`000?oo
oooooooo02_ooooo0_ooO`04ooooo`030000oooooooooooo01cooooo1?ooO`0?ooooo`Coogl05?oo
ool00ooo003oooooooooo`0Sooooo`03o`00oooooooooooo07Oooooo0Ol00001ooooo`0000?o0000
ooooooooool0<Oooool00`000?ooooooooooo`0Mooooo`;oogl04Oooool2oomo01Cooooo00?oo`00
ooooooooool09Oooool00ol00?ooooooooooo`1fooooo`7o00000Oooool00003o`000?oooooooooo
033ooooo00<0003oooooooooool0Aoooool00ooo003oooooooooo`0Uooooo`03o`00oooooooooooo
07Kooooo0Ol00001ooooo`0000?o0000ooooooooool0<?ooool00`000?ooooooooooo`17ooooo`03
ool00?oooooooooo02Kooooo00?o003oooooooooool0MOooool1o`00007ooooo00000ol0003ooooo
ooooo`0_ooooo`030000oooooooooooo04Sooooo00?oo`00ooooooooool09oooool00ol00?oooooo
ooooo`1dooooo`7o00000Oooool00003o`000?oooooooooo02oooooo00<0003oooooooooool01ooo
ool2oomo00;ooooo0_ooO`0kooooo`03ool00?oooooooooo02Oooooo00?o003oooooooooool0M?oo
ool1o`00007ooooo00000ol0003oooooooooo`0^ooooo`030000oooooooooooo00Oooooo2?ooO`0i
ooooo`03ool00?oooooooooo02Wooooo00?o003oooooooooool0Loooool1o`00007ooooo00000ol0
003oooooooooo`0^ooooo`030000oooooooooooo00Oooooo2?ooO`0iooooo`03ool00?oooooooooo
02Wooooo00?o003oooooooooool0Loooool1o`00007ooooo00000ol0003oooooooooo`0]ooooo`03
0000oooooooooooo00Wooooo1_ooO`0Pooooo`;oogl05oooool00ooo003oooooooooo`0[ooooo`03
o`00oooooooooooo07;ooooo0Ol00001ooooo`0000?o0000ooooooooool0;Oooool00`000?oooooo
ooooo`0;ooooo`Coogl07oooool4oomo01Kooooo00?oo`00ooooooooool0:oooool00ol00?oooooo
ooooo`1booooo`7o00000Oooool00003o`000?oo003ooooo02gooooo00<0003oooooooooool03?oo
ool2oomo023ooooo1?ooO`0Fooooo`03ool00?oooooooooo02_ooooo00?o003oooooooooool0L_oo
ool1o`00007ooooo00000ol0003oo`00ooooo`0/ooooo`030000oooooooooooo033ooooo0_ooO`0F
ooooo`03ool00?oooooooooo02gooooo00?o003oooooooooool0LOooool1o`00007ooooo00000ol0
003oo`00ooooo`0/ooooo`030000oooooooooooo04Sooooo00?oo`00ooooooooool0;Oooool00ol0
0?ooooooooooo`1aooooo`7o00000Oooool00003o`000?ooooooo`0002cooooo00<0003ooooooooo
ool0B?ooool00ooo003oooooooooo`0]ooooo`03o`00oooooooooooo077ooooo0Ol00001ooooo`00
00?o0000oooooooo0000:oooool00`000?ooooooooooo`18ooooo`03ool00?oooooooooo02oooooo
00?o003oooooooooool0L?ooool1o`00007ooooo00001?l0003ooooooooooooo000Zooooo`030000
oooooooooooo00?ooooo0_ooO`13ooooo`03ool00?oooooooooo02oooooo00?o003oooooooooool0
L?ooool1o`00007ooooo00001?l0003ooooooooooooo000Zooooo`030000oooooooooooo00;ooooo
1?ooO`12ooooo`03ool00?oooooooooo02oooooo00?o003oooooooooool0L?ooool1o`00007ooooo
00001Ol0003oooooooooooooooooo`0002Wooooo00<0003oooooooooool00_ooool4oomo047ooooo
00?oo`00ooooooooool0<?ooool00ol00?ooooooooooo`1`ooooo`7o00000Oooool00005o`000?oo
oooooooooooooooo0000:?ooool00`000?ooooooooooo`04ooooo`;oogl0@_ooool00ooo003ooooo
ooooo`0aooooo`03o`00oooooooooooo06oooooo0Ol00001ooooo`0000?o0000ooooooooool00_oo
ool00ooo003oooooooooo`0Uooooo`030000oooooooooooo04Oooooo00?oo`00ooooooooool0<_oo
ool00ol00?ooooooooooo`1_ooooo`7o00000Oooool00003o`000?oooooooooo00;ooooo00?oo`00
ooooooooool09Oooool00`000?ooooooooooo`17ooooo`03ool00?oooooooooo03;ooooo00?o003o
ooooooooool0Koooool1o`00007ooooo00000ol0003oooooooooo`03ooooo`03ool00?oooooooooo
02Cooooo00<0003oooooooooool0A_ooool00ooo003oooooooooo`0cooooo`03o`00oooooooooooo
06oooooo0Ol00001ooooo`0000?o0000ooooooooool01?ooool00ooo003oooooooooo`0Sooooo`03
0000oooooooooooo04Gooooo00?oo`00ooooooooool0=?ooool00ol00?ooooooooooo`1_ooooo`7o
00000Oooool00003o`000?oooooooooo00Gooooo00?oo`00ooooooooool08Oooool00`000?oooooo
ooooo`15ooooo`03ool00?oooooooooo03Kooooo00?o003oooooooooool0K_ooool1o`00007ooooo
00000ol0003oooooooooo`06ooooo`03ool00?oooooooooo023ooooo00<0003oooooooooool0AOoo
ool00ooo003oooooooooo`09ooooo`;oogl0:oooool00ol00?ooooooooooo`1^ooooo`7o00000Ooo
ool00003o`000?oooooooooo00Kooooo00?oo`00ooooooooool08?ooool00`000?ooooooooooo`14
ooooo`03ool00?oooooooooo00Wooooo1?ooO`0Zooooo`03o`00oooooooooooo06kooooo0Ol00001
ooooo`0000?o0000ooooooooool01oooool00ooo003oooooooooo`0Oooooo`030000oooooooooooo
02Sooooo0_ooO`0Iooooo`03ool00?oooooooooo00[ooooo1?ooO`0Zooooo`03o`00oooooooooooo
06kooooo0Ol00001ooooo`0000?o0000ooooooooool01oooool00ooo003oooooooooo`0Oooooo`03
0000oooooooooooo02Oooooo1?ooO`0Gooooo`03ool00?oooooooooo00cooooo0_ooO`0[ooooo`03
o`00oooooooooooo06kooooo0Ol00001ooooo`0000?o0000ooooooooool02?ooool00ooo003ooooo
ooooo`0Nooooo`030000oooooooooooo02Oooooo1?ooO`0Gooooo`03ool00?oooooooooo03Wooooo
00?o003oooooooooool0K_ooool1o`00007ooooo00000ol0003oooooooooo`09ooooo`03ool00?oo
oooooooo01gooooo00<0003oooooooooool0:?ooool2oomo01;ooooo1?l00?l00oooooooo`00oooo
o`0kooooo`03o`00oooooooooooo06kooooo0Ol00001ooooo`0000?o0000ooooooooool02_ooool0
0ooo003oooooooooo`0Looooo`030000oooooooooooo03_ooooo1_l00?lmooooo`03o`00oooooooo
oooo06kooooo0Ol00001ooooo`0000?o0000ooooooooool02oooool00ooo003oooooooooo`0Koooo
o`030000oooooooooooo03Oooooo0_ooO`000ooooooo003oo`00o`06o`00occooooo00?o003ooooo
ooooool0K_ooool1o`00007ooooo00000ol0003oooooooooo`0<ooooo`03ool00?oooooooooo01[o
oooo00<0003oooooooooool0=_ooool4oomo00So003o??ooool00ol00?ooooooooooo`1^ooooo`7o
00000Oooool00003o`000?oooooooooo00gooooo00?oo`00ooooooooool06Oooool00`000?oooooo
ooooo`0fooooo`Coogl02?l00?llooooo`03o`00oooooooooooo06kooooo0Ol00001ooooo`0000?o
0000ooooooooool03Oooool2ool001[ooooo00<0003oooooooooool0=oooool2oomo0003ooooool0
0?oo003o00Ko003o??ooool00ol00?ooooooooooo`1^ooooo`7o00000Oooool00003o`000?oooooo
oooo00oooooo00?oo`00ooooooooool05oooool00`000?ooooooooooo`0jooooo`03ool00?l00?oo
003o00Co003o?Oooool00ol00?ooooooooooo`1^ooooo`7o00000Oooool00003o`000?oooooooooo
013ooooo00?oo`00ooooooooool05_ooool00`000?ooooooooooo`0iooooo`03ool00?oooooooooo
00Co003o?_ooool00ol00?ooooooooooo`1^ooooo`7o00000Oooool00003o`000?oooooooooo017o
oooo00?oo`00ooooooooool05Oooool00`000?ooooooooooo`0hooooo`03ool00?oooooooooo04?o
oooo00?o003oooooooooool0K_ooool1o`00007ooooo00000ol0003oooooooooo`0Booooo`03ool0
0?oooooooooo01Cooooo00<0003oooooooooool0=_ooool2ool004Kooooo00?o003oooooooooool0
K_ooool1o`00007ooooo00000ol0003oooooooooo`0Cooooo`03ool00?oooooooooo01?ooooo00<0
003oooooooooool0=Oooool00ooo003oooooooooo`16ooooo`03o`00oooooooooooo06kooooo0Ol0
0001ooooo`0000?o0000ooooooooool05?ooool2ool001?ooooo00<0003oooooooooool0=?ooool0
0ooo003oooooooooo`17ooooo`03o`00oooooooooooo06kooooo0Ol00001ooooo`0000?o0000oooo
ooooool05_ooool2ool0017ooooo00<0003oooooooooool0<_ooool2ool004[ooooo00?o003ooooo
ooooool0K_ooool1o`00007ooooo00000ol0003oooooooooo`0Hooooo`03ool00?oooooooooo00ko
oooo00<0003oooooooooool0<Oooool00ooo003oooooooooo`1:ooooo`03o`00oooooooooooo06ko
oooo0Ol00001ooooo`0000?o0000ooooooooool06Oooool2ool000kooooo00<0003oooooooooool0
;oooool2ool004gooooo00?o003oooooooooool0K_ooool1o`00007ooooo00000ol0003ooooooooo
o`0Kooooo`03ool00?oooooooooo00_ooooo00<0003oooooooooool0;_ooool00ooo003ooooooooo
o`1<ooooo`03o`00oooooooooooo06oooooo0Ol00001ooooo`0000?o0000ooooooooool07?ooool2
ool000_ooooo00<0003oooooooooool0;Oooool00ooo003oooooooooo`1=ooooo`03o`00oooooooo
oooo06oooooo0Ol00001ooooo`0000?o0000ooooooooool07_ooool3ool000Wooooo00<0003ooooo
ooooool0:_ooool2ool0053ooooo00?o003oooooooooool0Koooool1o`00007ooooo00000ol0003o
ooooooooo`0Qooooo`;oo`001oooool00`000?ooooooooooo`0Wooooo`?oo`00D_ooool00ol00?oo
ooooooooo`1_ooooo`7o00000Oooool00003o`000?oooooooooo02?ooooo0_oo0005ooooo`030000
oooooooooooo02Gooooo0_oo001Dooooo`03o`00oooooooooooo073ooooo0Ol00001ooooo`0000?o
0000ooooooooool09Oooool4ool00003ooooo`000?oooooo02;ooooo1?oo001Fooooo`03o`00oooo
oooooooo073ooooo0Ol00001ooooo`0000?o0000ooooooooool0:Oooool2ool00003o`00oooo003o
o`0001gooooo0ooo001Jooooo`03o`00oooooooooooo073ooooo0Ol00001ooooo`0000?o0000oooo
ooooool0:oooool00`000?ooooooooooo`03ool001Cooooo1_oo001Mooooo`03o`00oooooooooooo
073ooooo0Ol00001ooooo`0000?o0000ooooooooool0;?ooool00`000?ooooooooooo`02oooooaCo
o`00H_ooool00ol00?ooooooooooo`1aooooo`7o00000Oooool00003o`000?oooooooooo02cooooo
00<0003oooooooooool0N?ooool00ol00?ooooooooooo`1aooooo`7o00000Oooool00003o`000?oo
oooooooo02cooooo00<0003oooooooooool0N?ooool00ol00?ooooooooooo`1aooooo`7o00000Ooo
ool00003o`000?oooooooooo02gooooo00<0003oooooooooool0M_ooool00ol00?ooooooooooo`1b
ooooo`7o00000Oooool00003o`000?oooooooooo02gooooo00<0003oooooooooool0M_ooool00ol0
0?ooooooooooo`1booooo`7o00000Oooool00003o`000?oooooooooo02gooooo00<0003ooooooooo
ool0M_ooool00ol00?ooooooooooo`1booooo`7o00000Oooool00003o`000?oooooooooo02kooooo
00<0003oooooooooool0M?ooool00ol00?ooooooooooo`1cooooo`7o00000Oooool00003o`000?oo
oooooooo02kooooo00<0003oooooooooool0M?ooool00ol00?ooooooooooo`1cooooo`7o00000Ooo
ool00003o`000?oooooooooo02kooooo00<0003oooooooooool0M?ooool00ol00?ooooooooooo`1c
ooooo`7o00000Oooool00003o`000?oooooooooo02oooooo00<0003oooooooooool0L_ooool00ol0
0?ooooooooooo`1dooooo`7o00000Oooool00003o`000?oooooooooo02oooooo00<0003ooooooooo
ool0L_ooool00ol00?ooooooooooo`1dooooo`7o00000Oooool00003o`000?oooooooooo02oooooo
00<0003oooooooooool0L_ooool00ol00?ooooooooooo`1dooooo`7o00000Oooool00003o`000?oo
oooooooo033ooooo00<0003oooooooooool0Koooool2o`00ogOooooo0Ol00001ooooo`0000?o0000
ooooooooool0<?ooool00`000?ooooooooooo`1_ooooo`03o`00oooooooooooo07Kooooo0Ol00001
ooooo`0000?o0000ooooooooool0<Oooool00`000?ooooooooooo`1]ooooo`03o`00oooooooooooo
07Oooooo0Ol00001ooooo`0000?o0000ooooooooool0<_ooool00`000?ooooooooooo`1/ooooo`03
o`00oooooooooooo07Oooooo0Ol00001ooooo`0000?o0000ooooooooool0<_ooool00`000?oooooo
ooooo`1[ooooo`03o`00oooooooooooo063ooooo0_ooO`0Fooooo`7o00000Oooool00003o`000?oo
oooooooo03?ooooo00<0003oooooooooool0JOooool00ol00?ooooooooooo`1Pooooo`Coogl05Ooo
ool1o`00007ooooo00000ol0003oooooooooo`0dooooo`030000oooooooooooo06Sooooo00?o003o
ooooooooool0H?ooool4oomo01Gooooo0Ol00001ooooo`0000?o0000ooooooooool0=Oooool00`00
0?ooooooooooo`1Vooooo`03o`00oooooooooooo06;ooooo0_ooO`0Fooooo`7o00000Oooool00003
o`000?oooooooooo03Gooooo00?o003oooooooooool0I_ooool00ol00?ooooooooooo`1jooooo`7o
00000Oooool00003o`000?oooooooooo03Kooooo00?o003oooooooooool0I?ooool00ol00?oooooo
ooooo`1kooooo`7o00000Oooool00003o`000?oooooooooo03Oooooo00?o003oooooooooool0H_oo
ool00ol00?ooooooooooo`1looooo`7o00000Oooool00003o`000?oooooooooo03Sooooo00?o003o
ooooooooool0Goooool2o`00ogoooooo0Ol00001ooooo`0000?o0000ooooooooool0>Oooool00ol0
0?ooooooooooo`1Mooooo`03o`00oooooooooooo07oooooo0Ol00001ooooo`0000?o0000oooooooo
ool0>_ooool00ol00?ooooooooooo`1Kooooo`03o`00oooooooooooo083ooooo0Ol00001ooooo`00
00?o0000ooooooooool0>oooool00ol00?ooooooooooo`1Iooooo`03o`00oooooooooooo087ooooo
0Ol00001ooooo`0000?o0000ooooooooool0??ooool00ol00?ooooooooooo`1Gooooo`03o`00oooo
oooooooo08;ooooo0Ol00001ooooo`0000?o0000ooooooooool0?Oooool00ol00?ooooooooooo`1E
ooooo`03o`00oooooooooooo08?ooooo0Ol00001ooooo`0000?o0000ooooooooool0?_ooool00ol0
0?ooooooooooo`1Cooooo`03o`00oooooooooooo08Cooooo0Ol00001ooooo`0000?o0000oooooooo
ool0?oooool00ol00?ooooooooooo`1@ooooo`;o003o8Oooool2oomo06Cooooo0Ol00001ooooo`00
00?o0000ooooooooool0@?ooool00ol00?ooooooooooo`1>ooooo`03o`00oooooooooooo023ooooo
1?ooO`1Sooooo`7o00000Oooool00003o`000?oooooooooo047ooooo0_l00?m=ooooo`03o`00oooo
oooooooo027ooooo1?ooO`1Sooooo`7o00000Oooool00003o`000?oooooooooo04?ooooo00?o003o
ooooooooool0BOooool00ol00?ooooooooooo`0Sooooo`;oogl0=Oooool2oomo02gooooo0Ol00001
ooooo`0000?o0000ooooooooool0A?ooool2o`00odSooooo00?o003oooooooooool0Doooool2oomo
00Gooooo1?ooO`0/ooooo`7o00000Oooool00003o`000?oooooooooo04Kooooo0_l00?m5ooooo`03
o`00oooooooooooo05?ooooo1?ooO`04ooooo`Coogl0;?ooool1o`00007ooooo00000ol0003ooooo
ooooo`18ooooo`03o`00oooooooooooo043ooooo0_l00?lfooooo`;oogl07_ooool4oomo00Gooooo
0_ooO`0]ooooo`7o00000Oooool00003o`000?oooooooooo04Wooooo0_l00?lnooooo`;o003o=ooo
ool4oomo01kooooo0_ooO`0eooooo`7o00000Oooool00003o`000?oooooooooo04_ooooo0ol00?lj
ooooo`03o`00oooooooooooo03Oooooo1?ooO`1Eooooo`7o00000Oooool00003o`000?oooooooooo
04kooooo0_l00?lfooooo`;o003o>oooool2oomo05Kooooo0Ol00001ooooo`0000?o0000oooooooo
ool0D?ooool3o`00oc3ooooo0ol00?lcooooo`;oogl09Oooool2oomo03Wooooo0Ol00001ooooo`00
00?o0000ooooooooool0Doooool2o`00ob[ooooo1?l00?leooooo`Coogl08oooool4oomo03Sooooo
0Ol00001ooooo`0000?o0000ooooooooool0EOooool3o`00ob?ooooo1?l00?leooooo`;oogl00_oo
ool4oomo02?ooooo1?ooO`03ooooo`;oogl0<oooool1o`00007ooooo00000ol0003oooooooooo`1H
ooooo`?o003o7Oooool3o`00ocSooooo1?ooO`02ooooo`;oogl04oooool2oomo013ooooo0_ooO`03
ooooo`Coogl0<_ooool1o`00007ooooo00000ol0003oooooooooo`1Kooooo`?o003o5?ooool6o`00
oc_ooooo1?ooO`06ooooo`;oogl03_ooool4oomo01Cooooo1?ooO`0booooo`7o00000Oooool00003
o`000?oooooooooo05kooooo5?l00?m2ooooo`;oogl01_ooool4oomo00gooooo1?ooO`0Eooooo`;o
ogl0<oooool1o`00007ooooo00000ol0003oooooooooo`2;ooooo`;oogl09oooool2oomo00Kooooo
1?ooO`0>ooooo`;oogl0Boooool1o`00007ooooo00000ol0003oooooooooo`2:ooooo`Coogl09Ooo
ool4oomo00Kooooo0_ooO`1Looooo`7o00000Oooool00003o`000?oooooooooo08[ooooo1?ooO`0U
ooooo`Coogl0I?ooool1o`00007ooooo00000ol0003oooooooooo`2;ooooo`;oogl09oooool2oomo
06Gooooo0Ol00001ooooo`0000?o0000ooooooooool0U_ooool2oomo03[ooooo0_ooO`17ooooo`7o
00000Oooool00003o`000?oooooooooo09Gooooo1?ooO`0>ooooo`;oogl0:?ooool4oomo04Kooooo
0Ol00001ooooo`0000?o0000ooooooooool0UOooool4oomo00gooooo1?ooO`0Wooooo`Coogl0A_oo
ool1o`00007ooooo00000ol0003oooooooooo`2Fooooo`;oogl03_ooool4oomo02Sooooo0_ooO`17
ooooo`7o00000Oooool00003o`000?oooooooooo0:Oooooo0_ooO`1booooo`7o00000Oooool00003
o`000?oooooooooo0>_ooooo0_ooO`0^ooooo`7o00000Oooool00003o`000?oooooooooo0>[ooooo
1?ooO`0]ooooo`7o00000Oooool00003o`000?oooooooooo0=Kooooo0_ooO`0Booooo`Coogl0;Ooo
ool1o`00007ooooo00000ol0003oooooooooo`3Eooooo`Coogl04_ooool2oomo02kooooo0Ol00001
ooooo`0000?o0000ooooooooool0]oooool2oomo01cooooo1?ooO`12ooooo`7o00000Oooool00003
o`000?oooooooooo0;Kooooo1?ooO`0Looooo`;oogl0@oooool1o`00007ooooo00000ol0003ooooo
ooooo`2cooooo`;oogl000?ooooooomo0?ooO`000_ooO`1Qooooo`7o00000Oooool00003o`000?oo
oooooooo0:Sooooo0_ooO`08ooooo`Coogl000?ooooooomo0?ooO`006_ooool2oomo04Kooooo0Ol0
0001ooooo`0000?o0000ooooooooool0Y_ooool5oomo00Oooooo1?ooO`0Gooooo`;oogl00oooool4
oomo04Gooooo0Ol00001ooooo`0000?o0000ooooooooool0YOooool6oomo00Sooooo0_ooO`0Goooo
o`Coogl00_ooool4oomo04Gooooo0Ol00001ooooo`0000?o0000ooooooooool0YOooool5oomo02;o
oooo1?ooO`03ooooo`;oogl0A_ooool1o`00007ooooo00000ol0003oooooooooo`1fooooo`;oogl0
;_ooool2oomo02Gooooo0_ooO`1<ooooo`7o00000Oooool00003o`000?oooooooooo07Gooooo1?oo
O`2Rooooo`7o00000Oooool00003o`000?oooooooooo07Gooooo1?ooO`0:ooooo`;oogl0U_ooool1
o`00007ooooo00000ol0003oooooooooo`1fooooo`;oogl02_ooool4oomo02[ooooo0_ooO`1Yoooo
o`7o00000Oooool00003o`000?oooooooooo08;ooooo1?ooO`0Yooooo`Coogl0J?ooool1o`00007o
oooo00000ol0003oooooooooo`23ooooo`;oogl09?ooool2oomo00Cooooo1?ooO`1Xooooo`7o0000
0Oooool00003o`000?oooooooooo0:Sooooo1?ooO`04ooooo`;oogl0JOooool1o`00007ooooo0000
0ol0003oooooooooo`2Xooooo`Coogl0Koooool1o`00007ooooo00000ol0003oooooooooo`2Yoooo
o`;oogl0L?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`00
00?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?oo
ool1o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000oooo
ooooool0Q?ooool2oomo09Gooooo0Ol00001ooooo`0000?o0000ooooooooool0Poooool4oomo09Co
oooo0Ol00001ooooo`0000?o0000ooooooooool0Poooool4oomo09Cooooo0Ol00001ooooo`0000?o
0000ooooooooool0Q?ooool2oomo02cooooo0_ooO`1Wooooo`7o00000Oooool00003o`000?oooooo
oooo0;7ooooo1?ooO`1Vooooo`7o00000Oooool00003o`000?oooooooooo0;7ooooo1?ooO`1Voooo
o`7o00000Oooool00003o`000?oooooooooo0;;ooooo0_ooO`1Wooooo`7o00000Oooool00003o`00
0?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol0
0001ooooo`0000?o0000ooooooooool0Noooool2oomo09kooooo0Ol00001ooooo`0000?o0000oooo
ooooool0N_ooool4oomo09gooooo0Ol00001ooooo`0000?o0000ooooooooool0N_ooool4oomo023o
oooo0_ooO`1kooooo`7o00000Oooool00003o`000?oooooooooo07_ooooo0_ooO`0Pooooo`Coogl0
N_ooool1o`00007ooooo00000ol0003oooooooooo`2Mooooo`Coogl04oooool5ool0of;ooooo0Ol0
0001ooooo`0000?o0000ooooooooool0T?ooool2oomo00cooooo0_ooO`0Cooooo`Ooo`3oHOooool1
o`00007ooooo00000ol0003oooooooooo`2?ooooo`Coogl07oooool9ool0of3ooooo0Ol00001oooo
o`0000?o0000ooooooooool0Soooool4oomo01kooooo2ooo0?mOooooo`7o00000Oooool00003o`00
0?oooooooooo093ooooo0_ooO`0Oooooo`_oo`3oGoooool1o`00007ooooo00000ol0003ooooooooo
o`2aooooo`_oo`3oGoooool1o`00007ooooo00000ol0003oooooooooo`2aooooo`_oo`3oGoooool1
o`00007ooooo00000ol0003oooooooooo`2aooooo`_oo`3oGoooool1o`00007ooooo00000ol0003o
ooooooooo`2booooo`Woo`3oH?ooool1o`00007ooooo00000ol0003oooooooooo`2cooooo`Ooo`3o
HOooool1o`00007ooooo00000ol0003oooooooooo`2dooooo`Goo`3oH_ooool1o`00007ooooo0000
0ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLoooo
o`7o00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003ooooo
ooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Ooo
ool00003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooo
oacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`00
0?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol0
0001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo
0?oooooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`00
00?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?oo
ool1o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000oooo
ooooool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007o
oooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooo
oolLooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0
003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o
00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003ooooooooo
o`3ooooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool0
0003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooooaco
oooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oo
oooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001
ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo0?oo
oooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o
0000ooooooooool0S_ooool2oomo08_ooooo0Ol00001ooooo`0000?o0000ooooooooool0SOooool4
oomo08[ooooo0Ol00001ooooo`0000?o0000ooooooooool0SOooool4oomo08[ooooo0Ol00001oooo
o`0000?o0000ooooooooool0S_ooool2oomo08_ooooo0Ol00001ooooo`0000?o0000ooooooooool0
oooooolLooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo0000
0ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLoooo
o`7o00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003ooooo
ooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Ooo
ool00003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooo
oacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`00
0?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol0
0001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo
0?oooooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`00
00?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?oo
ool1o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000oooo
ooooool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007o
oooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`00ool0000Po`00007ooooo0000
\
\>"],
  ImageRangeCache->{{{0, 287}, {287, 0}} -> {-1.01089, -1.01089, 0.00704453, \
0.00704453}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.49505 0.5 0.49505 [
[ 0 0 -0.125 0 ]
[ 0 0 -0.125 0 ]
[ 0 1 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
0 0 m
1 0 L
s
0 0 m
0 1 L
s
0 1 m
1 1 L
s
1 0 m
1 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
1 .5 0 r
.015 w
.03175 .1355 Mdot
.03435 .12523 Mdot
.11137 .12765 Mdot
.14107 .18841 Mdot
.16218 .24538 Mdot
.17294 .21053 Mdot
.18267 .18577 Mdot
.18434 .1304 Mdot
.18553 .30956 Mdot
.20401 .239 Mdot
.21247 .27571 Mdot
.21687 .20845 Mdot
.22376 .2799 Mdot
.22832 .27485 Mdot
.29063 .20974 Mdot
.29686 .25079 Mdot
.30487 .22936 Mdot
.30683 .34623 Mdot
.32055 .20902 Mdot
.32574 .21979 Mdot
.34472 .28521 Mdot
.35998 .36393 Mdot
.36335 .24976 Mdot
.3794 .36608 Mdot
.42386 .66992 Mdot
.44391 .74519 Mdot
.45059 .34198 Mdot
.47208 .67586 Mdot
.47436 .71381 Mdot
.49778 .59825 Mdot
.50874 .91643 Mdot
.51516 .76219 Mdot
.53655 .61374 Mdot
.56563 .75219 Mdot
.59189 .65665 Mdot
.59581 .61604 Mdot
.59923 .6556 Mdot
.60292 .68499 Mdot
.62656 .67779 Mdot
.63555 .72451 Mdot
.63919 .652 Mdot
.64169 .6004 Mdot
.64246 .58611 Mdot
.64496 .54267 Mdot
.64608 .77288 Mdot
.65077 .64308 Mdot
.66065 .57816 Mdot
.67474 .59169 Mdot
.69296 .563 Mdot
.72815 .65902 Mdot
.73169 .58879 Mdot
.74669 .61318 Mdot
.74821 .65474 Mdot
.75963 .63781 Mdot
.79673 .57809 Mdot
.80925 .55852 Mdot
.81525 .58444 Mdot
.83417 .62985 Mdot
.83598 .55526 Mdot
.91595 .49319 Mdot
1 0 0 r
.005 w
.00495 .28842 m
.00628 .29156 L
.01857 .31761 L
.03101 .33781 L
.03525 .34367 L
.05706 .36884 L
.05795 .36972 L
.08312 .39115 L
.08963 .39578 L
.10917 .40763 L
.13523 .41964 L
.14074 .42183 L
.16128 .42794 L
.18734 .43294 L
.21339 .43485 L
.23945 .43375 L
.2655 .42959 L
.29156 .42219 L
.29261 .42183 L
.31761 .41124 L
.34367 .39603 L
.34405 .39578 L
.36972 .37551 L
.37582 .36972 L
.39578 .34724 L
.39849 .34367 L
.41525 .31761 L
.42183 .30485 L
.4275 .29156 L
.436 .2655 L
.44117 .23945 L
.44325 .21339 L
.44232 .18734 L
.43834 .16128 L
.43114 .13523 L
.42183 .11212 L
.42037 .10917 L
.40546 .08312 L
.39578 .06961 L
.38528 .05706 L
.36972 .04137 L
.35758 .03101 L
.34367 .02092 L
.31761 .00569 L
.3162 .00495 L
s
.00495 .12854 m
.01344 .10917 L
.02832 .08312 L
.03101 .07912 L
.04848 .05706 L
.05706 .04802 L
.07619 .03101 L
.08312 .02579 L
.10917 .00934 L
.11742 .00495 L
s
0 0 1 r
.29156 .15739 m
.31761 .14824 L
.34367 .14249 L
.36972 .13986 L
.39578 .14025 L
.42183 .14366 L
.44789 .15025 L
.47394 .16034 L
.47599 .16128 L
.5 .17443 L
.51844 .18734 L
.52606 .19355 L
.54662 .21339 L
.55211 .21962 L
.56712 .23945 L
.57817 .25755 L
.58227 .2655 L
.59322 .29156 L
.60058 .31761 L
.60422 .3392 L
.60471 .34367 L
.6058 .36972 L
.60422 .39297 L
.60387 .39578 L
.59886 .42183 L
.59054 .44789 L
.57848 .47394 L
.57817 .47453 L
.562 .5 L
.55211 .51255 L
.53968 .52606 L
.52606 .53862 L
.50853 .55211 L
.5 .55773 L
.47394 .57183 L
.45901 .57817 L
.44789 .5819 L
.42183 .5885 L
.39578 .59192 L
.36972 .59231 L
.34367 .58968 L
.31761 .58392 L
.29972 .57817 L
.29156 .57477 L
.2655 .56178 L
.25025 .55211 L
.23945 .54409 L
.21914 .52606 L
.21339 .52008 L
.19681 .5 L
Mistroke
.18734 .48608 L
.18031 .47394 L
.16827 .44789 L
.16128 .42714 L
.15996 .42183 L
.15493 .39578 L
.153 .36972 L
.15409 .34367 L
.15823 .31761 L
.16128 .3045 L
.16559 .29156 L
.17653 .2655 L
.18734 .24609 L
.19169 .23945 L
.21221 .21339 L
.21339 .21211 L
.23945 .1881 L
.24041 .18734 L
.2655 .17038 L
.28271 .16128 L
.29156 .15739 L
Mfstroke
1 0 0 r
.03 w
.21687 .20845 Mdot
0 0 1 r
.3794 .36608 Mdot
1 0 0 r
.79703 .00495 m
.79703 .02937 L
.87129 .02937 L
.87129 .00495 L
F
0 0 1 r
.89604 .00495 m
.89604 .22805 L
.9703 .22805 L
.9703 .00495 L
F
1 0 1 r
.04 w
.65077 .64308 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P000182000`400?l00000o`00003ooooooolQ
ooooo`00ool0000Po`00007ooooo00000ol0003oooooooooo`0Mooooo`;oo`00>?ooool3ool00<7o
oooo0Ol00001ooooo`0000?o0000ooooooooool06oooool2ool003gooooo00?oo`00ooooooooool0
Q?oooolEool000Sooooo5Ol00?l8ooooo`7o00000Oooool00003o`000?oooooooooo01[ooooo00?o
o`00ooooooooool0?_ooool2ool008Cooooo5Ooo0008oooooaGo003o2?ooool1o`00007ooooo0000
0ol0003oooooooooo`0Hooooo`;oo`00@oooool00ooo003oooooooooo`21oooooaGoo`002?oooolE
o`00o`Sooooo0Ol00001ooooo`0000?o0000ooooooooool05_ooool2ool004Kooooo00?oo`00oooo
ooooool0P?oooolEool000Sooooo5Ol00?l8ooooo`7o00000Oooool00003o`000?oooooooooo01Go
oooo00?oo`00ooooooooool0Aoooool2ool0083ooooo5Ooo0008oooooaGo003o2?ooool1o`00007o
oooo00000ol0003oooooooooo`0Dooooo`03ool00?oooooooooo04[ooooo00?oo`00ooooooooool0
OOoooolEool000Sooooo5Ol00?l8ooooo`7o00000Oooool00003o`000?oooooooooo01?ooooo00?o
o`00ooooooooool0C?ooool00ooo003oooooooooo`1loooooaGoo`002?oooolEo`00o`Sooooo0Ol0
0001ooooo`0000?o0000ooooooooool04Oooool2ool0053ooooo0_oo002IoooooaGo003o2?ooool1
o`00007ooooo00000ol0003oooooooooo`0@ooooo`03ool00?oooooooooo05;ooooo0_oo002Goooo
oaGo003o2?ooool1o`00007ooooo00000ol0003oooooooooo`0?ooooo`03ool00?oooooooooo05Go
oooo00?oo`00ooooooooool0U?oooolEo`00o`Sooooo0Ol00001ooooo`0000?o0000ooooooooool0
3_ooool00ooo003oooooooooo`1Fooooo`03ool00?oooooooooo09Cooooo5Ol00?l8ooooo`7o0000
0Oooool00003o`000?oooooooooo00gooooo00?oo`00ooooooooool0F?ooool00ooo003ooooooooo
o`2CoooooaGo003o2?ooool1o`00007ooooo00000ol0003oooooooooo`0=ooooo`03ool00?oooooo
oooo05Wooooo00?oo`00ooooooooool0T_oooolEo`00o`Sooooo0Ol00001ooooo`0000?o0000oooo
ooooool03?ooool00ooo003oooooooooo`1Kooooo`03ool00?oooooooooo097ooooo5Ol00?l8oooo
o`7o00000Oooool00003o`000?oooooooooo00_ooooo00?oo`00ooooooooool0GOooool00ooo003o
ooooooooo`2@oooooaGo003o2?ooool1o`00007ooooo00000ol0003oooooooooo`0;ooooo`03ool0
0?oooooooooo05gooooo00?oo`00ooooooooool0T?oooolEo`00o`Sooooo0Ol00001ooooo`0000?o
0000ooooooooool02_ooool00ooo003oooooooooo`1Oooooo`03ool00?oooooooooo08oooooo5Ol0
0?l8ooooo`7o00000Oooool00003o`000?oooooooooo00Wooooo00?oo`00ooooooooool0HOooool0
0ooo003oooooooooo`2>oooooaGo003o2?ooool1o`00007ooooo00000ol0003oooooooooo`08oooo
o`03ool00?oooooooooo06?ooooo00?oo`00ooooooooool0SOoooolEo`00o`Sooooo0Ol00001oooo
o`0000?o0000ooooooooool01oooool00ooo003oooooooooo`1Uooooo`03ool00?oooooooooo08co
oooo5Ol00?l8ooooo`7o00000Oooool00003o`000?oooooooooo00Kooooo00?oo`00ooooooooool0
Ioooool00ooo003oooooooooo`2;oooooaGo003o2?ooool1o`00007ooooo00000ol0003ooooooooo
o`05ooooo`03ool00?oooooooooo06Wooooo00?oo`00ooooooooool0R_oooolEo`00o`Sooooo0Ol0
0001ooooo`0000?o0000ooooooooool01Oooool00ooo003oooooooooo`1Yooooo`03ool00?oooooo
oooo08[ooooo5Ol00?l8ooooo`7o00000Oooool00003o`000?oooooooooo00Cooooo00?oo`00oooo
ooooool0Joooool00ooo003oooooooooo`29oooooaGo003o2?ooool1o`00007ooooo00000ol0003o
ooooooooo`03ooooo`03ool00?oooooooooo06cooooo00?oo`00ooooooooool0ROoooolEo`00o`So
oooo0Ol00001ooooo`0000?o0000ooooooooool00oooool00ooo003oooooooooo`1]ooooo`03ool0
0?oooooooooo08Sooooo5Ol00?l8ooooo`7o00000Oooool00003o`000?oooooooooo00;ooooo00?o
o`00ooooooooool0K_ooool00ooo003oooooooooo`28oooooaGo003o2?ooool1o`00007ooooo0000
0ol0003oooooooooo`02ooooo`03ool00?oooooooooo06oooooo00?oo`00ooooooooool0QooooolE
o`00o`Sooooo0Ol00001ooooo`0000Go0000ooooooooooooooooool0001booooo`03ool00?oooooo
oooo08Oooooo5Ol00?l8ooooo`7o00000Oooool00004o`000?ooooooooooool007Cooooo00?oo`00
ooooooooool0Q_oooolEo`00o`Sooooo0Ol00001ooooo`0000Co0000ooooooooooooo`00MOooool0
0ooo003oooooooooo`25oooooaGo003o2?ooool1o`00007ooooo00000ol0003oooooool0001foooo
o`03ool00?oooooooooo08Gooooo5Ol00?l8ooooo`7o00000Oooool00003o`000?ooooooo`0000Ko
oooo0_ooO`1_ooooo`03ool00?oooooooooo08Cooooo5Ol00?l8ooooo`7o00000Oooool00003o`00
0?ooooooo`0000Gooooo1?ooO`0Cooooo`;oogl0FOooool00ooo003oooooooooo`24oooooaGo003o
2?ooool1o`00007ooooo00000ol0003oo`00ooooo`05ooooo`Coogl04_ooool4oomo01;ooooo0_oo
O`14ooooo`03ool00?oooooooooo08Cooooo5Ol00?l8ooooo`7o00000Oooool00003o`000?oooooo
oooo00Gooooo0oooO`0Cooooo`Coogl04Oooool4oomo04Cooooo00?oo`00ooooooooool0PooooolE
o`00o`Sooooo0Ol00001ooooo`0000?o0000ooooooooool01?ooool4oomo01Cooooo0_ooO`0Boooo
o`Coogl0A?ooool00ooo003oooooooooo`23oooooaGo003o2?ooool1o`00007ooooo00000ol0003o
ooooooooo`04ooooo`Coogl0:Oooool2oomo04Gooooo00?oo`00ooooooooool0PooooolEo`00o`So
oooo0Ol00001ooooo`0000?o0000ooooooooool01Oooool2oomo05Kooooo5_l00?l5ooooo`03ool0
0?oooooooooo08?ooooo5Ol00?l8ooooo`7o00000Oooool00003o`000?oooooooooo05[ooooo0ol0
0?lFooooo`Ko003o00?oo`00ooooooooool0P_oooolEo`00o`Sooooo0Ol00001ooooo`0000?o0000
ooooooooool0Eoooool3o`00oaoooooo0ol00?n2oooooaGo003o2?ooool1o`00007ooooo00000ol0
003oooooooooo`1Dooooo`?o003o8_ooool00ooo003oooooooooo`03o`00ogoooooo5Ol00?l8oooo
o`7o00000Oooool00003o`000?oooooooooo057ooooo0ol00?lUooooo`03ool00?oooooooooo00?o
oooo0ol00?mloooooaGo003o2?ooool1o`00007ooooo00000ol0003oooooooooo`1?ooooo`80003o
:Oooool00ooo003oooooooooo`05ooooo`?o003oNOoooolEo`00o`Sooooo0Ol00001ooooo`0000?o
0000ooooooooool0COooool20000ob_ooooo00?oo`00ooooooooool02?ooool2o`00ogOooooo5Ol0
0?l8ooooo`7o00000Oooool00003o`000?oooooooooo04[ooooo0`000?l]ooooo`03ool00?oooooo
oooo00[ooooo0_l00?meoooooaGo003o2?ooool1o`00007ooooo00000ol0003oooooooooo`18oooo
o`80003o<?ooool00ooo003oooooooooo`0<ooooo`03o`00oooooooooooo07;ooooo5Ol00?l8oooo
o`7o00000Oooool00003o`000?oooooooooo04Oooooo00<0003oooooooooool0<?ooool00ooo003o
ooooooooo`0=ooooo`;o003oL_oooolEo`00o`Sooooo0Ol00001ooooo`0000?o0000ooooooooool0
AOooool20000ocCooooo00?oo`00ooooooooool03_ooool2o`00og3ooooo5Ol00?l8ooooo`7o0000
0Oooool00003o`000?oooooooooo04Cooooo00<0003oooooooooool0=?ooool00ooo003ooooooooo
o`0@ooooo`;o003oK_oooolEo`00o`Sooooo0Ol00001ooooo`0000?o0000ooooooooool09?ooool2
oomo00[ooooo0_ooO`0Aooooo`030000oooooooooooo03Gooooo00?oo`00ooooooooool04_ooool0
0ol00?ooooooooooo`1[oooooaGo003o2?ooool1o`00007ooooo00000ol0003oooooooooo`0Soooo
o`Coogl02?ooool4oomo00oooooo00<0003oooooooooool0=_ooool00ooo003oooooooooo`0Coooo
o`03o`00oooooooooooo06[ooooo5Ol00?l8ooooo`7o00000Oooool00003o`000?oooooooooo02?o
oooo1?ooO`08ooooo`Coogl03Oooool00`000?oo003oooooo`0hooooo`03ool00?oooooooooo01Co
oooo00?o003oooooooooool0JOoooolEo`00o`Sooooo0Ol00001ooooo`0000?o0000ooooooooool0
9?ooool2oomo00[ooooo0_ooO`0=ooooo`030000oooooooooooo03Wooooo00?oo`00ooooooooool0
5Oooool00ol00?ooooooooooo`1XoooooaGo003o2?ooool1o`00007ooooo00000ol0003ooooooooo
o`0iooooo`Coo`0000?ooooo0000ooooool0>oooool00ooo003oooooooooo`0Fooooo`03o`00oooo
oooooooo06Oooooo5Ol00?l8ooooo`7o00000Oooool00003o`000?oooooooooo03Sooooo1_oo000m
ooooo`03ool00?oooooooooo01Oooooo00?o003oooooooooool0I_oooolEo`00o`Sooooo0Ol00001
ooooo`0000?o0000ooooooooool0=oooool8ool0013ooooo0_ooO`07ooooo`;oogl08_ooool00ooo
003oooooooooo`0Gooooo`03o`00oooooooooooo06Gooooo5Ol00?l8ooooo`7o00000Oooool00003
o`000?oooooooooo02kooooo0_ooO`07ooooo`Soo`003oooool4oomo00Gooooo1?ooO`0Qooooo`03
ool00?oooooooooo01Sooooo00?o003oooooooooool0I?oooolEo`00o`Sooooo0Ol00001ooooo`00
00?o0000ooooooooool0;Oooool4oomo00Kooooo2?oo000?ooooo`Coogl01Oooool4oomo027ooooo
00?oo`00ooooooooool06Oooool00ol00?ooooooooooo`1SoooooaGo003o2?ooool1o`00007ooooo
00000ol0003oooooooooo`0]ooooo`Coogl01_ooool8ool0013ooooo0_ooO`07ooooo`?oogl08Ooo
ool00ooo003oooooooooo`0Jooooo`03o`00oooooooooooo06;ooooo5Ol00?l8ooooo`7o00000Ooo
ool00003o`000?oooooooooo02kooooo0_ooO`08ooooo`Koo`006_ooool4oomo023ooooo00?oo`00
ooooooooool06oooool00ol00?ooooooooooo`1QoooooaGo003o2?ooool1o`00007ooooo00000ol0
003oooooooooo`0hooooo`030000oooo003oo`0000;oo`006oooool4oomo023ooooo00?oo`00oooo
ooooool07?ooool00ol00?ooooooooooo`1PoooooaGo003o2?ooool1o`00007ooooo00000ol0003o
ooooooooo`0gooooo`030000oooooooooooo01Wooooo0_ooO`04ooooo`;oogl08Oooool00ooo003o
ooooooooo`0Looooo`03o`00oooooooooooo063ooooo5Ol00?l8ooooo`7o00000Oooool00003o`00
0?oooooooooo03Kooooo00<0003oooooooooool06Oooool4oomo02Gooooo00?oo`00ooooooooool0
7_ooool00ol00?ooooooooooo`1OoooooaGo003o2?ooool1o`00007ooooo00000ol0003ooooooooo
o`0fooooo`030000oooooooooooo01Wooooo1?ooO`0Uooooo`03ool00?oooooooooo01oooooo00?o
003oooooooooool0Noooool1o`00007ooooo00000ol0003oooooooooo`0eooooo`040000oooooooo
ogl0oomo01[ooooo0_ooO`0Vooooo`03ool00?oooooooooo023ooooo00?o003oooooooooool0N_oo
ool1o`00007ooooo00000ol0003oooooooooo`0dooooo`030000ooooooooogl000?oogl0@Oooool0
0ooo003oooooooooo`0Qooooo`03o`00oooooooooooo07Wooooo0Ol00001ooooo`0000?o0000oooo
ooooool0:oooool2oomo00Kooooo00<0003oooooooooool01?ooO`11ooooo`03ool00?oooooooooo
027ooooo00?o003oooooooooool0NOooool1o`00007ooooo00000ol0003oooooooooo`0Zooooo`Co
ogl01?ooool00`000?ooooooooooo`02ooooo`;oogl06?ooool2oomo017ooooo0_ooO`0Eooooo`03
ool00?oooooooooo02;ooooo00?o003oooooooooool0N?ooool1o`00007ooooo00000ol0003ooooo
ooooo`0Zooooo`Coogl01?ooool00`000?ooooooooooo`0Kooooo`Coogl03oooool4oomo01Cooooo
00?oo`00ooooooooool08oooool00ol00?ooooooooooo`1gooooo`7o00000Oooool00003o`000?oo
oooooooo02_ooooo0_ooO`04ooooo`030000oooooooooooo01cooooo1?ooO`0?ooooo`Coogl05?oo
ool00ooo003oooooooooo`0Sooooo`03o`00oooooooooooo07Oooooo0Ol00001ooooo`0000?o0000
ooooooooool0<Oooool00`000?ooooooooooo`0Mooooo`;oogl04Oooool2oomo01Cooooo00?oo`00
ooooooooool09Oooool00ol00?ooooooooooo`1fooooo`7o00000Oooool00003o`000?oooooooooo
033ooooo00<0003oooooooooool0Aoooool00ooo003oooooooooo`0Uooooo`03o`00oooooooooooo
07Kooooo0Ol00001ooooo`0000?o0000ooooooooool0<?ooool00`000?ooooooooooo`17ooooo`03
ool00?oooooooooo02Kooooo00?o003oooooooooool0MOooool1o`00007ooooo00000ol0003ooooo
ooooo`0_ooooo`030000oooooooooooo04Sooooo00?oo`00ooooooooool09oooool00ol00?oooooo
ooooo`1dooooo`7o00000Oooool00003o`000?oooooooooo02oooooo00<0003oooooooooool01ooo
ool2oomo00;ooooo0_ooO`0kooooo`03ool00?oooooooooo02Oooooo00?o003oooooooooool0M?oo
ool1o`00007ooooo00000ol0003oooooooooo`0^ooooo`030000oooooooooooo00Oooooo2?ooO`0i
ooooo`03ool00?oooooooooo02Wooooo00?o003oooooooooool0Loooool1o`00007ooooo00000ol0
003oooooooooo`0^ooooo`030000oooooooooooo00Oooooo2?ooO`0iooooo`03ool00?oooooooooo
02Wooooo00?o003oooooooooool0Loooool1o`00007ooooo00000ol0003oooooooooo`0]ooooo`03
0000oooooooooooo00Wooooo1_ooO`0Pooooo`;oogl05oooool00ooo003oooooooooo`0[ooooo`03
o`00oooooooooooo07;ooooo0Ol00001ooooo`0000?o0000ooooooooool0;Oooool00`000?oooooo
ooooo`0;ooooo`Coogl07oooool4oomo01Kooooo00?oo`00ooooooooool0:oooool00ol00?oooooo
ooooo`1booooo`7o00000Oooool00003o`000?oo003ooooo02gooooo00<0003oooooooooool03?oo
ool2oomo023ooooo1?ooO`0Fooooo`03ool00?oooooooooo02_ooooo00?o003oooooooooool0L_oo
ool1o`00007ooooo00000ol0003oo`00ooooo`0/ooooo`030000oooooooooooo033ooooo0_ooO`0F
ooooo`03ool00?oooooooooo02gooooo00?o003oooooooooool0LOooool1o`00007ooooo00000ol0
003oo`00ooooo`0/ooooo`030000oooooooooooo04Sooooo00?oo`00ooooooooool0;Oooool00ol0
0?ooooooooooo`1aooooo`7o00000Oooool00003o`000?ooooooo`0002cooooo00<0003ooooooooo
ool0B?ooool00ooo003oooooooooo`0]ooooo`03o`00oooooooooooo077ooooo0Ol00001ooooo`00
00?o0000oooooooo0000:oooool00`000?ooooooooooo`18ooooo`03ool00?oooooooooo02oooooo
00?o003oooooooooool0L?ooool1o`00007ooooo00001?l0003ooooooooooooo000Zooooo`030000
oooooooooooo00?ooooo0_ooO`13ooooo`03ool00?oooooooooo02oooooo00?o003oooooooooool0
L?ooool1o`00007ooooo00001?l0003ooooooooooooo000Zooooo`030000oooooooooooo00;ooooo
1?ooO`12ooooo`03ool00?oooooooooo02oooooo00?o003oooooooooool0L?ooool1o`00007ooooo
00001Ol0003oooooooooooooooooo`0002Wooooo00<0003oooooooooool00_ooool4oomo047ooooo
00?oo`00ooooooooool0<?ooool00ol00?ooooooooooo`1`ooooo`7o00000Oooool00005o`000?oo
oooooooooooooooo0000:?ooool00`000?ooooooooooo`04ooooo`;oogl0@_ooool00ooo003ooooo
ooooo`0aooooo`03o`00oooooooooooo06oooooo0Ol00001ooooo`0000?o0000ooooooooool00_oo
ool00ooo003oooooooooo`0Uooooo`030000oooooooooooo04Oooooo00?oo`00ooooooooool0<_oo
ool00ol00?ooooooooooo`1_ooooo`7o00000Oooool00003o`000?oooooooooo00;ooooo00?oo`00
ooooooooool09Oooool00`000?ooooooooooo`17ooooo`03ool00?oooooooooo03;ooooo00?o003o
ooooooooool0Koooool1o`00007ooooo00000ol0003oooooooooo`03ooooo`03ool00?oooooooooo
02Cooooo00<0003oooooooooool0A_ooool00ooo003oooooooooo`0cooooo`03o`00oooooooooooo
06oooooo0Ol00001ooooo`0000?o0000ooooooooool01?ooool00ooo003oooooooooo`0Sooooo`03
0000oooooooooooo04Gooooo00?oo`00ooooooooool0=?ooool00ol00?ooooooooooo`1_ooooo`7o
00000Oooool00003o`000?oooooooooo00Gooooo00?oo`00ooooooooool08Oooool00`000?oooooo
ooooo`15ooooo`03ool00?oooooooooo03Kooooo00?o003oooooooooool0K_ooool1o`00007ooooo
00000ol0003oooooooooo`06ooooo`03ool00?oooooooooo023ooooo00<0003oooooooooool0AOoo
ool00ooo003oooooooooo`09ooooo`;oogl0:oooool00ol00?ooooooooooo`1^ooooo`7o00000Ooo
ool00003o`000?oooooooooo00Kooooo00?oo`00ooooooooool08?ooool00`000?ooooooooooo`14
ooooo`03ool00?oooooooooo00Wooooo1?ooO`0Zooooo`03o`00oooooooooooo06kooooo0Ol00001
ooooo`0000?o0000ooooooooool01oooool00ooo003oooooooooo`0Oooooo`030000oooooooooooo
02Sooooo0_ooO`0Iooooo`03ool00?oooooooooo00[ooooo1?ooO`0Zooooo`03o`00oooooooooooo
06kooooo0Ol00001ooooo`0000?o0000ooooooooool01oooool00ooo003oooooooooo`0Oooooo`03
0000oooooooooooo02Oooooo1?ooO`0Gooooo`03ool00?oooooooooo00cooooo0_ooO`0[ooooo`03
o`00oooooooooooo06kooooo0Ol00001ooooo`0000?o0000ooooooooool02?ooool00ooo003ooooo
ooooo`0Nooooo`030000oooooooooooo02Oooooo1?ooO`0Gooooo`03ool00?oooooooooo03Wooooo
00?o003oooooooooool0K_ooool1o`00007ooooo00000ol0003oooooooooo`09ooooo`03ool00?oo
oooooooo01gooooo00<0003oooooooooool0:?ooool2oomo01;ooooo1?l00?l00oooooooo`00oooo
o`0kooooo`03o`00oooooooooooo06kooooo0Ol00001ooooo`0000?o0000ooooooooool02_ooool0
0ooo003oooooooooo`0Looooo`030000oooooooooooo03_ooooo1_l00?lmooooo`03o`00oooooooo
oooo06kooooo0Ol00001ooooo`0000?o0000ooooooooool02oooool00ooo003oooooooooo`0Koooo
o`030000oooooooooooo03Oooooo0_ooO`000ooooooo003oo`00o`06o`00occooooo00?o003ooooo
ooooool0K_ooool1o`00007ooooo00000ol0003oooooooooo`0<ooooo`03ool00?oooooooooo01[o
oooo00<0003oooooooooool0=_ooool4oomo00So003o??ooool00ol00?ooooooooooo`1^ooooo`7o
00000Oooool00003o`000?oooooooooo00gooooo00?oo`00ooooooooool06Oooool00`000?oooooo
ooooo`0fooooo`Coogl02?l00?llooooo`03o`00oooooooooooo06kooooo0Ol00001ooooo`0000?o
0000ooooooooool03Oooool2ool001[ooooo00<0003oooooooooool0=oooool2oomo0003ooooool0
0?oo003o00Ko003o??ooool00ol00?ooooooooooo`1^ooooo`7o00000Oooool00003o`000?oooooo
oooo00oooooo00?oo`00ooooooooool05oooool00`000?ooooooooooo`0jooooo`03ool00?l00?oo
003o00Co003o?Oooool00ol00?ooooooooooo`1^ooooo`7o00000Oooool00003o`000?oooooooooo
013ooooo00?oo`00ooooooooool05_ooool00`000?ooooooooooo`0iooooo`03ool00?oooooooooo
00Co003o?_ooool00ol00?ooooooooooo`1^ooooo`7o00000Oooool00003o`000?oooooooooo017o
oooo00?oo`00ooooooooool05Oooool00`000?ooooooooooo`0hooooo`03ool00?oooooooooo04?o
oooo00?o003oooooooooool0K_ooool1o`00007ooooo00000ol0003oooooooooo`0Booooo`03ool0
0?oooooooooo01Cooooo00<0003oooooooooool0=_ooool2ool004Kooooo00?o003oooooooooool0
K_ooool1o`00007ooooo00000ol0003oooooooooo`0Cooooo`03ool00?oooooooooo01?ooooo00<0
003oooooooooool0=Oooool00ooo003oooooooooo`16ooooo`03o`00oooooooooooo06kooooo0Ol0
0001ooooo`0000?o0000ooooooooool05?ooool2ool001?ooooo00<0003oooooooooool0=?ooool0
0ooo003oooooooooo`17ooooo`03o`00oooooooooooo06kooooo0Ol00001ooooo`0000?o0000oooo
ooooool05_ooool2ool0017ooooo00<0003oooooooooool0<_ooool2ool004[ooooo00?o003ooooo
ooooool0K_ooool1o`00007ooooo00000ol0003oooooooooo`0Hooooo`03ool00?oooooooooo00ko
oooo00<0003oooooooooool0<Oooool00ooo003oooooooooo`1:ooooo`03o`00oooooooooooo06ko
oooo0Ol00001ooooo`0000?o0000ooooooooool06Oooool2ool000kooooo00<0003oooooooooool0
;oooool2ool004gooooo00?o003oooooooooool0K_ooool1o`00007ooooo00000ol0003ooooooooo
o`0Kooooo`03ool00?oooooooooo00_ooooo00<0003oooooooooool0;_ooool00ooo003ooooooooo
o`1<ooooo`03o`00oooooooooooo06oooooo0Ol00001ooooo`0000?o0000ooooooooool07?ooool2
ool000_ooooo00<0003oooooooooool0;Oooool00ooo003oooooooooo`1=ooooo`03o`00oooooooo
oooo06oooooo0Ol00001ooooo`0000?o0000ooooooooool07_ooool3ool000Wooooo00<0003ooooo
ooooool0:_ooool2ool0053ooooo00?o003oooooooooool0Koooool1o`00007ooooo00000ol0003o
ooooooooo`0Qooooo`;oo`001oooool00`000?ooooooooooo`0Wooooo`?oo`00D_ooool00ol00?oo
ooooooooo`1_ooooo`7o00000Oooool00003o`000?oooooooooo02?ooooo0_oo0005ooooo`030000
oooooooooooo02Gooooo0_oo001Dooooo`03o`00oooooooooooo073ooooo0Ol00001ooooo`0000?o
0000ooooooooool09Oooool4ool00003ooooo`000?oooooo02;ooooo1?oo001Fooooo`03o`00oooo
oooooooo073ooooo0Ol00001ooooo`0000?o0000ooooooooool0:Oooool2ool00003o`00oooo003o
o`0001gooooo0ooo001Jooooo`03o`00oooooooooooo073ooooo0Ol00001ooooo`0000?o0000oooo
ooooool0:oooool00`000?ooooooooooo`03ool001Cooooo1_oo001Mooooo`03o`00oooooooooooo
073ooooo0Ol00001ooooo`0000?o0000ooooooooool0;?ooool00`000?ooooooooooo`02oooooaCo
o`00H_ooool00ol00?ooooooooooo`1aooooo`7o00000Oooool00003o`000?oooooooooo02cooooo
00<0003oooooooooool0N?ooool00ol00?ooooooooooo`1aooooo`7o00000Oooool00003o`000?oo
oooooooo02cooooo00<0003oooooooooool0N?ooool00ol00?ooooooooooo`1aooooo`7o00000Ooo
ool00003o`000?oooooooooo02gooooo00<0003oooooooooool0M_ooool00ol00?ooooooooooo`1b
ooooo`7o00000Oooool00003o`000?oooooooooo02gooooo00<0003oooooooooool0M_ooool00ol0
0?ooooooooooo`1booooo`7o00000Oooool00003o`000?oooooooooo02gooooo00<0003ooooooooo
ool0M_ooool00ol00?ooooooooooo`1booooo`7o00000Oooool00003o`000?oooooooooo02kooooo
00<0003oooooooooool0M?ooool00ol00?ooooooooooo`1cooooo`7o00000Oooool00003o`000?oo
oooooooo02kooooo00<0003oooooooooool0M?ooool00ol00?ooooooooooo`1cooooo`7o00000Ooo
ool00003o`000?oooooooooo02kooooo00<0003oooooooooool0M?ooool00ol00?ooooooooooo`1c
ooooo`7o00000Oooool00003o`000?oooooooooo02oooooo00<0003oooooooooool0L_ooool00ol0
0?ooooooooooo`1dooooo`7o00000Oooool00003o`000?oooooooooo02oooooo00<0003ooooooooo
ool0L_ooool00ol00?ooooooooooo`1dooooo`7o00000Oooool00003o`000?oooooooooo02oooooo
00<0003oooooooooool0L_ooool00ol00?ooooooooooo`1dooooo`7o00000Oooool00003o`000?oo
oooooooo033ooooo00<0003oooooooooool0Koooool2o`00ogOooooo0Ol00001ooooo`0000?o0000
ooooooooool0<?ooool00`000?ooooooooooo`1_ooooo`03o`00oooooooooooo07Kooooo0Ol00001
ooooo`0000?o0000ooooooooool0<Oooool00`000?ooooooooooo`1]ooooo`03o`00oooooooooooo
07Oooooo0Ol00001ooooo`0000?o0000ooooooooool0<_ooool00`000?ooooooooooo`1/ooooo`03
o`00oooooooooooo07Oooooo0Ol00001ooooo`0000?o0000ooooooooool0<_ooool00`000?oooooo
ooooo`1[ooooo`03o`00oooooooooooo063ooooo0_ooO`0Fooooo`7o00000Oooool00003o`000?oo
oooooooo03?ooooo00<0003oooooooooool0JOooool00ol00?ooooooooooo`1Pooooo`Coogl05Ooo
ool1o`00007ooooo00000ol0003oooooooooo`0dooooo`030000oooooooooooo06Sooooo00?o003o
ooooooooool0H?ooool4oomo01Gooooo0Ol00001ooooo`0000?o0000ooooooooool0=Oooool00`00
0?ooooooooooo`1Vooooo`03o`00oooooooooooo06;ooooo0_ooO`0Fooooo`7o00000Oooool00003
o`000?oooooooooo03Gooooo00?o003oooooooooool0I_ooool00ol00?ooooooooooo`1jooooo`7o
00000Oooool00003o`000?oooooooooo03Kooooo00?o003oooooooooool0I?ooool00ol00?oooooo
ooooo`1kooooo`7o00000Oooool00003o`000?oooooooooo03Oooooo00?o003oooooooooool0H_oo
ool00ol00?ooooooooooo`1looooo`7o00000Oooool00003o`000?oooooooooo03Sooooo00?o003o
ooooooooool0Goooool2o`00ogoooooo0Ol00001ooooo`0000?o0000ooooooooool0>Oooool00ol0
0?ooooooooooo`1Mooooo`03o`00oooooooooooo07oooooo0Ol00001ooooo`0000?o0000oooooooo
ool0>_ooool00ol00?ooooooooooo`1Kooooo`03o`00oooooooooooo083ooooo0Ol00001ooooo`00
00?o0000ooooooooool0>oooool00ol00?ooooooooooo`1Iooooo`03o`00oooooooooooo087ooooo
0Ol00001ooooo`0000?o0000ooooooooool0??ooool00ol00?ooooooooooo`1Gooooo`03o`00oooo
oooooooo08;ooooo0Ol00001ooooo`0000?o0000ooooooooool0?Oooool00ol00?ooooooooooo`1E
ooooo`03o`00oooooooooooo08?ooooo0Ol00001ooooo`0000?o0000ooooooooool0?_ooool00ol0
0?ooooooooooo`1Cooooo`03o`00oooooooooooo08Cooooo0Ol00001ooooo`0000?o0000oooooooo
ool0?oooool00ol00?ooooooooooo`1@ooooo`;o003o8Oooool2oomo06Cooooo0Ol00001ooooo`00
00?o0000ooooooooool0@?ooool00ol00?ooooooooooo`1>ooooo`03o`00oooooooooooo023ooooo
1?ooO`1Sooooo`7o00000Oooool00003o`000?oooooooooo047ooooo0_l00?m=ooooo`03o`00oooo
oooooooo027ooooo1?ooO`1Sooooo`7o00000Oooool00003o`000?oooooooooo04?ooooo00?o003o
ooooooooool0BOooool00ol00?ooooooooooo`0Sooooo`;oogl0=Oooool2oomo02gooooo0Ol00001
ooooo`0000?o0000ooooooooool0A?ooool2o`00odSooooo00?o003oooooooooool0Doooool2oomo
00Gooooo1?ooO`0/ooooo`7o00000Oooool00003o`000?oooooooooo04Kooooo0_l00?m5ooooo`03
o`00oooooooooooo05?ooooo1?ooO`04ooooo`Coogl0;?ooool1o`00007ooooo00000ol0003ooooo
ooooo`18ooooo`03o`00oooooooooooo043ooooo0_l00?lfooooo`;oogl07_ooool4oomo00Gooooo
0_ooO`0]ooooo`7o00000Oooool00003o`000?oooooooooo04Wooooo0_l00?lnooooo`;o003o=ooo
ool4oomo01kooooo0_ooO`0eooooo`7o00000Oooool00003o`000?oooooooooo04_ooooo0ol00?lj
ooooo`03o`00oooooooooooo03Oooooo1?ooO`1Eooooo`7o00000Oooool00003o`000?oooooooooo
04kooooo0_l00?lfooooo`;o003o>oooool2oomo05Kooooo0Ol00001ooooo`0000?o0000oooooooo
ool0D?ooool3o`00oc3ooooo0ol00?lcooooo`;oogl09Oooool2oomo03Wooooo0Ol00001ooooo`00
00?o0000ooooooooool0Doooool2o`00ob[ooooo1?l00?leooooo`Coogl08oooool4oomo03Sooooo
0Ol00001ooooo`0000?o0000ooooooooool0EOooool3o`00ob?ooooo1?l00?leooooo`;oogl00_oo
ool4oomo02?ooooo1?ooO`03ooooo`;oogl0<oooool1o`00007ooooo00000ol0003oooooooooo`1H
ooooo`?o003o7Oooool3o`00ocSooooo1?ooO`02ooooo`;oogl04oooool2oomo013ooooo0_ooO`03
ooooo`Coogl0<_ooool1o`00007ooooo00000ol0003oooooooooo`1Kooooo`?o003o5?ooool6o`00
oc_ooooo1?ooO`06ooooo`;oogl03_ooool4oomo01Cooooo1?ooO`0booooo`7o00000Oooool00003
o`000?oooooooooo05kooooo5?l00?m2ooooo`;oogl01_ooool4oomo00gooooo1?ooO`0Eooooo`;o
ogl0<oooool1o`00007ooooo00000ol0003oooooooooo`2;ooooo`;oogl09oooool2oomo00Kooooo
1?ooO`0>ooooo`;oogl0Boooool1o`00007ooooo00000ol0003oooooooooo`2:ooooo`Coogl09Ooo
ool4oomo00Kooooo0_ooO`1Looooo`7o00000Oooool00003o`000?oooooooooo08[ooooo1?ooO`0U
ooooo`Coogl0I?ooool1o`00007ooooo00000ol0003oooooooooo`2;ooooo`;oogl09oooool2oomo
06Gooooo0Ol00001ooooo`0000?o0000ooooooooool0U_ooool2oomo03[ooooo0_ooO`17ooooo`7o
00000Oooool00003o`000?oooooooooo09Gooooo1?ooO`0>ooooo`;oogl0:?ooool4oomo04Kooooo
0Ol00001ooooo`0000?o0000ooooooooool0UOooool4oomo00gooooo1?ooO`0Wooooo`Coogl0A_oo
ool1o`00007ooooo00000ol0003oooooooooo`2Fooooo`;oogl03_ooool4oomo02Sooooo0_ooO`17
ooooo`7o00000Oooool00003o`000?oooooooooo0:Oooooo0_ooO`1booooo`7o00000Oooool00003
o`000?oooooooooo0;Gooooo1Ooo0?laooooo`;oogl0;_ooool1o`00007ooooo00000ol0003ooooo
ooooo`2dooooo`Ooo`3o;oooool4oomo02gooooo0Ol00001ooooo`0000?o0000ooooooooool0/ooo
ool9ool0oa[ooooo0_ooO`0Booooo`Coogl0;Oooool1o`00007ooooo00000ol0003oooooooooo`2b
ooooo`_oo`3o6?ooool4oomo01;ooooo0_ooO`0^ooooo`7o00000Oooool00003o`000?oooooooooo
0;;ooooo2ooo0?lHooooo`Coogl0@_ooool1o`00007ooooo00000ol0003oooooooooo`2booooo`_o
o`3o6Oooool2oomo04?ooooo0Ol00001ooooo`0000?o0000ooooooooool0/_ooool;ool0oekooooo
0Ol00001ooooo`0000?o0000ooooooooool0Z?ooool2oomo00Sooooo2ooo0?lFooooo`;oogl0A_oo
ool1o`00007ooooo00000ol0003oooooooooo`2Vooooo`Googl01oooool00oooO`3oo`3oool0o`07
ool0oa7ooooo0_ooO`03ooooo`Coogl0AOooool1o`00007ooooo00000ol0003oooooooooo`2Uoooo
o`Koogl02?ooool00oooO`3oo`3oool0o`05ool0oa7ooooo1?ooO`02ooooo`Coogl0AOooool1o`00
007ooooo00000ol0003oooooooooo`2Uooooo`Googl02oooool5ool0oa;ooooo1?ooO`03ooooo`;o
ogl0A_ooool1o`00007ooooo00000ol0003oooooooooo`1fooooo`;oogl0;_ooool2oomo02Gooooo
0_ooO`1<ooooo`7o00000Oooool00003o`000?oooooooooo07Gooooo1?ooO`2Rooooo`7o00000Ooo
ool00003o`000?oooooooooo07Gooooo1?ooO`0:ooooo`;oogl0U_ooool1o`00007ooooo00000ol0
003oooooooooo`1fooooo`;oogl02_ooool4oomo02[ooooo0_ooO`1Yooooo`7o00000Oooool00003
o`000?oooooooooo08;ooooo1?ooO`0Yooooo`Coogl0J?ooool1o`00007ooooo00000ol0003ooooo
ooooo`23ooooo`;oogl09?ooool2oomo00Cooooo1?ooO`1Xooooo`7o00000Oooool00003o`000?oo
oooooooo0:Sooooo1?ooO`04ooooo`;oogl0JOooool1o`00007ooooo00000ol0003oooooooooo`2X
ooooo`Coogl0Koooool1o`00007ooooo00000ol0003oooooooooo`2Yooooo`;oogl0L?ooool1o`00
007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0
oooooolLooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo0000
0ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0Q?ooool2oomo
09Gooooo0Ol00001ooooo`0000?o0000ooooooooool0Poooool4oomo09Cooooo0Ol00001ooooo`00
00?o0000ooooooooool0Poooool4oomo09Cooooo0Ol00001ooooo`0000?o0000ooooooooool0Q?oo
ool2oomo02cooooo0_ooO`1Wooooo`7o00000Oooool00003o`000?oooooooooo0;7ooooo1?ooO`1V
ooooo`7o00000Oooool00003o`000?oooooooooo0;7ooooo1?ooO`1Vooooo`7o00000Oooool00003
o`000?oooooooooo0;;ooooo0_ooO`1Wooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo
7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000
ooooooooool0Noooool2oomo09kooooo0Ol00001ooooo`0000?o0000ooooooooool0N_ooool4oomo
09gooooo0Ol00001ooooo`0000?o0000ooooooooool0N_ooool4oomo023ooooo0_ooO`1kooooo`7o
00000Oooool00003o`000?oooooooooo07_ooooo0_ooO`0Pooooo`Coogl0N_ooool1o`00007ooooo
00000ol0003oooooooooo`2Mooooo`Coogl0N_ooool1o`00007ooooo00000ol0003oooooooooo`2@
ooooo`;oogl03?ooool2oomo07_ooooo0Ol00001ooooo`0000?o0000ooooooooool0Soooool4oomo
08Sooooo0Ol00001ooooo`0000?o0000ooooooooool0Soooool4oomo08Sooooo0Ol00001ooooo`00
00?o0000ooooooooool0T?ooool2oomo02?ooooo0_ooO`1Tooooo`7o00000Oooool00003o`000?oo
oooooooo0;Cooooo1?ooO`1Sooooo`7o00000Oooool00003o`000?oooooooooo0;Cooooo1?ooO`1S
ooooo`7o00000Oooool00003o`000?oooooooooo0;Gooooo0_ooO`1Tooooo`7o00000Oooool00003
o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo
0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oooooo
oooo0?oooooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001oooo
o`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo
7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000
ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00
007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0
oooooolLooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo0000
0ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLoooo
o`7o00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003ooooo
ooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Ooo
ool00003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooo
oacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`00
0?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol0
0001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo
0?oooooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`00
00?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?oo
ool1o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000oooo
ooooool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007o
oooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooo
oolLooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0
003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o
00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003ooooooooo
o`2>ooooo`;oogl0Roooool1o`00007ooooo00000ol0003oooooooooo`2=ooooo`Coogl0R_ooool1
o`00007ooooo00000ol0003oooooooooo`2=ooooo`Coogl0R_ooool1o`00007ooooo00000ol0003o
ooooooooo`2>ooooo`;oogl0Roooool1o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo
0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oooooo
oooo0?oooooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001oooo
o`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo
7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000
ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00
007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0
oooooolLooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo0000
0ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLoooo
o`7o00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003ooooo
ooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Ooo
ool00003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooo
oacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`00
0?oooooooooo0?oooooo7?ooool1o`00007ooooo003oo`00023o00000Oooool00001\
\>"],
  ImageRangeCache->{{{0, 287}, {287, 0}} -> {-1.01089, -1.01089, 0.00704453, \
0.00704453}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.49505 0.5 0.49505 [
[ 0 0 -0.125 0 ]
[ 0 0 -0.125 0 ]
[ 0 1 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
0 0 m
1 0 L
s
0 0 m
0 1 L
s
0 1 m
1 1 L
s
1 0 m
1 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
1 .5 0 r
.015 w
.03175 .1355 Mdot
.03435 .12523 Mdot
.11137 .12765 Mdot
.14107 .18841 Mdot
.16218 .24538 Mdot
.17294 .21053 Mdot
.18267 .18577 Mdot
.18434 .1304 Mdot
.18553 .30956 Mdot
.20401 .239 Mdot
.21247 .27571 Mdot
.21687 .20845 Mdot
.22376 .2799 Mdot
.22832 .27485 Mdot
.29063 .20974 Mdot
.29686 .25079 Mdot
.30487 .22936 Mdot
.30683 .34623 Mdot
.32055 .20902 Mdot
.32574 .21979 Mdot
.34472 .28521 Mdot
.35998 .36393 Mdot
.36335 .24976 Mdot
.3794 .36608 Mdot
.42386 .66992 Mdot
.44391 .74519 Mdot
.45059 .34198 Mdot
.47208 .67586 Mdot
.47436 .71381 Mdot
.49778 .59825 Mdot
.50874 .91643 Mdot
.51516 .76219 Mdot
.53655 .61374 Mdot
.56563 .75219 Mdot
.59189 .65665 Mdot
.59581 .61604 Mdot
.59923 .6556 Mdot
.60292 .68499 Mdot
.62656 .67779 Mdot
.63555 .72451 Mdot
.63919 .652 Mdot
.64169 .6004 Mdot
.64246 .58611 Mdot
.64496 .54267 Mdot
.64608 .77288 Mdot
.65077 .64308 Mdot
.66065 .57816 Mdot
.67474 .59169 Mdot
.69296 .563 Mdot
.72815 .65902 Mdot
.73169 .58879 Mdot
.74669 .61318 Mdot
.74821 .65474 Mdot
.75963 .63781 Mdot
.79673 .57809 Mdot
.80925 .55852 Mdot
.81525 .58444 Mdot
.83417 .62985 Mdot
.83598 .55526 Mdot
.91595 .49319 Mdot
1 0 0 r
.005 w
.00495 .28842 m
.00628 .29156 L
.01857 .31761 L
.03101 .33781 L
.03525 .34367 L
.05706 .36884 L
.05795 .36972 L
.08312 .39115 L
.08963 .39578 L
.10917 .40763 L
.13523 .41964 L
.14074 .42183 L
.16128 .42794 L
.18734 .43294 L
.21339 .43485 L
.23945 .43375 L
.2655 .42959 L
.29156 .42219 L
.29261 .42183 L
.31761 .41124 L
.34367 .39603 L
.34405 .39578 L
.36972 .37551 L
.37582 .36972 L
.39578 .34724 L
.39849 .34367 L
.41525 .31761 L
.42183 .30485 L
.4275 .29156 L
.436 .2655 L
.44117 .23945 L
.44325 .21339 L
.44232 .18734 L
.43834 .16128 L
.43114 .13523 L
.42183 .11212 L
.42037 .10917 L
.40546 .08312 L
.39578 .06961 L
.38528 .05706 L
.36972 .04137 L
.35758 .03101 L
.34367 .02092 L
.31761 .00569 L
.3162 .00495 L
s
.00495 .12854 m
.01344 .10917 L
.02832 .08312 L
.03101 .07912 L
.04848 .05706 L
.05706 .04802 L
.07619 .03101 L
.08312 .02579 L
.10917 .00934 L
.11742 .00495 L
s
0 0 1 r
.29156 .15739 m
.31761 .14824 L
.34367 .14249 L
.36972 .13986 L
.39578 .14025 L
.42183 .14366 L
.44789 .15025 L
.47394 .16034 L
.47599 .16128 L
.5 .17443 L
.51844 .18734 L
.52606 .19355 L
.54662 .21339 L
.55211 .21962 L
.56712 .23945 L
.57817 .25755 L
.58227 .2655 L
.59322 .29156 L
.60058 .31761 L
.60422 .3392 L
.60471 .34367 L
.6058 .36972 L
.60422 .39297 L
.60387 .39578 L
.59886 .42183 L
.59054 .44789 L
.57848 .47394 L
.57817 .47453 L
.562 .5 L
.55211 .51255 L
.53968 .52606 L
.52606 .53862 L
.50853 .55211 L
.5 .55773 L
.47394 .57183 L
.45901 .57817 L
.44789 .5819 L
.42183 .5885 L
.39578 .59192 L
.36972 .59231 L
.34367 .58968 L
.31761 .58392 L
.29972 .57817 L
.29156 .57477 L
.2655 .56178 L
.25025 .55211 L
.23945 .54409 L
.21914 .52606 L
.21339 .52008 L
.19681 .5 L
Mistroke
.18734 .48608 L
.18031 .47394 L
.16827 .44789 L
.16128 .42714 L
.15996 .42183 L
.15493 .39578 L
.153 .36972 L
.15409 .34367 L
.15823 .31761 L
.16128 .3045 L
.16559 .29156 L
.17653 .2655 L
.18734 .24609 L
.19169 .23945 L
.21221 .21339 L
.21339 .21211 L
.23945 .1881 L
.24041 .18734 L
.2655 .17038 L
.28271 .16128 L
.29156 .15739 L
Mfstroke
1 0 0 r
.03 w
.21687 .20845 Mdot
0 0 1 r
.3794 .36608 Mdot
1 0 0 r
.79703 .00495 m
.79703 .03334 L
.87129 .03334 L
.87129 .00495 L
F
0 0 1 r
.89604 .00495 m
.89604 .22409 L
.9703 .22409 L
.9703 .00495 L
F
1 0 1 r
.04 w
.66065 .57816 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P000182000`400?l00000o`00003ooooooolQ
ooooo`00ool0000Po`00007ooooo00000ol0003oooooooooo`0Mooooo`;oo`00>?ooool3ool00<7o
oooo0Ol00001ooooo`0000?o0000ooooooooool06oooool2ool003gooooo00?oo`00ooooooooool0
Q?oooolEool000Sooooo5Ol00?l8ooooo`7o00000Oooool00003o`000?oooooooooo01[ooooo00?o
o`00ooooooooool0?_ooool2ool008Cooooo5Ooo0008oooooaGo003o2?ooool1o`00007ooooo0000
0ol0003oooooooooo`0Hooooo`;oo`00@oooool00ooo003oooooooooo`21oooooaGoo`002?oooolE
o`00o`Sooooo0Ol00001ooooo`0000?o0000ooooooooool05_ooool2ool004Kooooo00?oo`00oooo
ooooool0P?oooolEool000Sooooo5Ol00?l8ooooo`7o00000Oooool00003o`000?oooooooooo01Go
oooo00?oo`00ooooooooool0Aoooool2ool0083ooooo5Ooo0008oooooaGo003o2?ooool1o`00007o
oooo00000ol0003oooooooooo`0Dooooo`03ool00?oooooooooo04[ooooo00?oo`00ooooooooool0
OOoooolEool000Sooooo5Ol00?l8ooooo`7o00000Oooool00003o`000?oooooooooo01?ooooo00?o
o`00ooooooooool0C?ooool00ooo003oooooooooo`1loooooaGoo`002?oooolEo`00o`Sooooo0Ol0
0001ooooo`0000?o0000ooooooooool04Oooool2ool0053ooooo0_oo001loooooaGoo`002?oooolE
o`00o`Sooooo0Ol00001ooooo`0000?o0000ooooooooool04?ooool00ooo003oooooooooo`1Boooo
o`;oo`00UooooolEo`00o`Sooooo0Ol00001ooooo`0000?o0000ooooooooool03oooool00ooo003o
ooooooooo`1Eooooo`03ool00?oooooooooo09Cooooo5Ol00?l8ooooo`7o00000Oooool00003o`00
0?oooooooooo00kooooo00?oo`00ooooooooool0E_ooool00ooo003oooooooooo`2DoooooaGo003o
2?ooool1o`00007ooooo00000ol0003oooooooooo`0=ooooo`03ool00?oooooooooo05Sooooo00?o
o`00ooooooooool0TooooolEo`00o`Sooooo0Ol00001ooooo`0000?o0000ooooooooool03Oooool0
0ooo003oooooooooo`1Iooooo`03ool00?oooooooooo09;ooooo5Ol00?l8ooooo`7o00000Oooool0
0003o`000?oooooooooo00cooooo00?oo`00ooooooooool0Foooool00ooo003oooooooooo`2Aoooo
oaGo003o2?ooool1o`00007ooooo00000ol0003oooooooooo`0;ooooo`03ool00?oooooooooo05go
oooo00?oo`00ooooooooool0T?oooolEo`00o`Sooooo0Ol00001ooooo`0000?o0000ooooooooool0
2oooool00ooo003oooooooooo`1Mooooo`03ool00?oooooooooo093ooooo5Ol00?l8ooooo`7o0000
0Oooool00003o`000?oooooooooo00[ooooo00?oo`00ooooooooool0Goooool00ooo003ooooooooo
o`2?oooooaGo003o2?ooool1o`00007ooooo00000ol0003oooooooooo`09ooooo`03ool00?oooooo
oooo067ooooo00?oo`00ooooooooool0S_oooolEo`00o`Sooooo0Ol00001ooooo`0000?o0000oooo
ooooool02?ooool00ooo003oooooooooo`1Sooooo`03ool00?oooooooooo08gooooo5Ol00?l8oooo
o`7o00000Oooool00003o`000?oooooooooo00Oooooo00?oo`00ooooooooool0IOooool00ooo003o
ooooooooo`2<oooooaGo003o2?ooool1o`00007ooooo00000ol0003oooooooooo`06ooooo`03ool0
0?oooooooooo06Oooooo00?oo`00ooooooooool0RooooolEo`00o`Sooooo0Ol00001ooooo`0000?o
0000ooooooooool01Oooool00ooo003oooooooooo`1Yooooo`03ool00?oooooooooo08[ooooo5Ol0
0?l8ooooo`7o00000Oooool00003o`000?oooooooooo00Gooooo00?oo`00ooooooooool0JOooool0
0ooo003oooooooooo`2:oooooaGo003o2?ooool1o`00007ooooo00000ol0003oooooooooo`04oooo
o`03ool00?oooooooooo06_ooooo00?oo`00ooooooooool0ROoooolEo`00o`Sooooo0Ol00001oooo
o`0000?o0000ooooooooool00oooool00ooo003oooooooooo`1/ooooo`03ool00?oooooooooo08Wo
oooo5Ol00?l8ooooo`7o00000Oooool00003o`000?oooooooooo00?ooooo00?oo`00ooooooooool0
KOooool00ooo003oooooooooo`28oooooaGo003o2?ooool1o`00007ooooo00000ol0003ooooooooo
o`02ooooo`03ool00?oooooooooo06kooooo00?oo`00ooooooooool0R?oooolEo`00o`Sooooo0Ol0
0001ooooo`0000?o0000ooooooooool00_ooool00ooo003oooooooooo`1_ooooo`03ool00?oooooo
oooo08Oooooo5Ol00?l8ooooo`7o00000Oooool00005o`000?oooooooooooooooooo0000L_ooool0
0ooo003oooooooooo`27oooooaGo003o2?ooool1o`00007ooooo00001?l0003ooooooooooooo001d
ooooo`03ool00?oooooooooo08Kooooo5Ol00?l8ooooo`7o00000Oooool00004o`000?oooooooooo
ool007Gooooo00?oo`00ooooooooool0QOoooolEo`00o`Sooooo0Ol00001ooooo`0000?o0000oooo
oooo0000M_ooool00ooo003oooooooooo`25oooooaGo003o2?ooool1o`00007ooooo00000ol0003o
ooooool00006ooooo`;oogl0Koooool00ooo003oooooooooo`24oooooaGo003o2?ooool1o`00007o
oooo00000ol0003oooooool00005ooooo`Coogl04oooool2oomo05Wooooo00?oo`00ooooooooool0
Q?oooolEo`00o`Sooooo0Ol00001ooooo`0000?o0000ool00?ooool01Oooool4oomo01;ooooo1?oo
O`0Booooo`;oogl0A?ooool00ooo003oooooooooo`24oooooaGo003o2?ooool1o`00007ooooo0000
0ol0003oooooooooo`05ooooo`?oogl04oooool4oomo017ooooo1?ooO`14ooooo`03ool00?oooooo
oooo08?ooooo5Ol00?l8ooooo`7o00000Oooool00003o`000?oooooooooo00Cooooo1?ooO`0Doooo
o`;oogl04_ooool4oomo04Cooooo00?oo`00ooooooooool0PooooolEo`00o`Sooooo0Ol00001oooo
o`0000?o0000ooooooooool01?ooool4oomo02Wooooo0_ooO`15ooooo`03ool00?oooooooooo08?o
oooo5Ol00?l8ooooo`7o00000Oooool00003o`000?oooooooooo00Gooooo0_ooO`1FoooooaKo003o
1Oooool00ooo003oooooooooo`23oooooaGo003o2?ooool1o`00007ooooo00000ol0003ooooooooo
o`1Jooooo`?o003o5_ooool6o`00o`03ool00?oooooooooo08;ooooo5Ol00?l8ooooo`7o00000Ooo
ool00003o`000?oooooooooo05Oooooo0ol00?lOooooo`?o003oP_oooolEo`00o`Sooooo0Ol00001
ooooo`0000?o0000ooooooooool0E?ooool3o`00ob;ooooo00?oo`00ooooooooool00ol00?mooooo
oaGo003o2?ooool1o`00007ooooo00000ol0003oooooooooo`1Aooooo`?o003o9Oooool00ooo003o
ooooooooo`03ooooo`?o003oO?oooolEo`00o`Sooooo0Ol00001ooooo`0000?o0000ooooooooool0
Coooool20000obWooooo00?oo`00ooooooooool01Oooool3o`00ogWooooo5Ol00?l8ooooo`7o0000
0Oooool00003o`000?oooooooooo04gooooo0P000?l[ooooo`03ool00?oooooooooo00Sooooo0_l0
0?mgoooooaGo003o2?ooool1o`00007ooooo00000ol0003oooooooooo`1:ooooo`<0003o;Oooool0
0ooo003oooooooooo`0:ooooo`;o003oMOoooolEo`00o`Sooooo0Ol00001ooooo`0000?o0000oooo
ooooool0B?ooool20000oc3ooooo00?oo`00ooooooooool03?ooool00ol00?ooooooooooo`1boooo
oaGo003o2?ooool1o`00007ooooo00000ol0003oooooooooo`17ooooo`030000oooooooooooo033o
oooo00?oo`00ooooooooool03Oooool2o`00og;ooooo5Ol00?l8ooooo`7o00000Oooool00003o`00
0?oooooooooo04Gooooo0P000?ldooooo`03ool00?oooooooooo00kooooo0_l00?m`oooooaGo003o
2?ooool1o`00007ooooo00000ol0003oooooooooo`14ooooo`030000oooooooooooo03Cooooo00?o
o`00ooooooooool04?ooool2o`00ofkooooo5Ol00?l8ooooo`7o00000Oooool00003o`000?oooooo
oooo02Cooooo0_ooO`0:ooooo`;oogl04Oooool00`000?ooooooooooo`0eooooo`03ool00?oooooo
oooo01;ooooo00?o003oooooooooool0JooooolEo`00o`Sooooo0Ol00001ooooo`0000?o0000oooo
ooooool08oooool4oomo00Sooooo1?ooO`0?ooooo`030000oooooooooooo03Kooooo00?oo`00oooo
ooooool04oooool00ol00?ooooooooooo`1ZoooooaGo003o2?ooool1o`00007ooooo00000ol0003o
ooooooooo`0Sooooo`Coogl02?ooool4oomo00gooooo00<0003oo`00ooooool0>?ooool00ooo003o
ooooooooo`0Dooooo`03o`00oooooooooooo06Wooooo5Ol00?l8ooooo`7o00000Oooool00003o`00
0?oooooooooo02Cooooo0_ooO`0:ooooo`;oogl03Oooool00`000?ooooooooooo`0iooooo`03ool0
0?oooooooooo01Gooooo00?o003oooooooooool0J?oooolEo`00o`Sooooo0Ol00001ooooo`0000?o
0000ooooooooool0>Oooool4ool00003ooooo`000?oooooo03_ooooo00?oo`00ooooooooool05_oo
ool00ol00?ooooooooooo`1WoooooaGo003o2?ooool1o`00007ooooo00000ol0003oooooooooo`0h
ooooo`Koo`00?Oooool00ooo003oooooooooo`0Gooooo`03o`00oooooooooooo06Kooooo5Ol00?l8
ooooo`7o00000Oooool00003o`000?oooooooooo03Oooooo2?oo000@ooooo`;oogl01oooool2oomo
02;ooooo00?oo`00ooooooooool05oooool00ol00?ooooooooooo`1UoooooaGo003o2?ooool1o`00
007ooooo00000ol0003oooooooooo`0^ooooo`;oogl01oooool8ool000oooooo1?ooO`05ooooo`Co
ogl08Oooool00ooo003oooooooooo`0Hooooo`03o`00oooooooooooo06Cooooo5Ol00?l8ooooo`7o
00000Oooool00003o`000?oooooooooo02gooooo1?ooO`06ooooo`Soo`003oooool4oomo00Gooooo
1?ooO`0Qooooo`03ool00?oooooooooo01Wooooo00?o003oooooooooool0HooooolEo`00o`Sooooo
0Ol00001ooooo`0000?o0000ooooooooool0;Oooool4oomo00Kooooo2?oo000@ooooo`;oogl01ooo
ool3oomo027ooooo00?oo`00ooooooooool06_ooool00ol00?ooooooooooo`1RoooooaGo003o2?oo
ool1o`00007ooooo00000ol0003oooooooooo`0^ooooo`;oogl02?ooool6ool001[ooooo1?ooO`0P
ooooo`03ool00?oooooooooo01_ooooo00?o003oooooooooool0HOoooolEo`00o`Sooooo0Ol00001
ooooo`0000?o0000ooooooooool0>?ooool00`000?ooo`00ool00002ool001_ooooo1?ooO`0Poooo
o`03ool00?oooooooooo01cooooo00?o003oooooooooool0H?oooolEo`00o`Sooooo0Ol00001oooo
o`0000?o0000ooooooooool0=oooool00`000?ooooooooooo`0Iooooo`;oogl01?ooool2oomo027o
oooo00?oo`00ooooooooool07?ooool00ol00?ooooooooooo`1PoooooaGo003o2?ooool1o`00007o
oooo00000ol0003oooooooooo`0fooooo`030000oooooooooooo01Wooooo1?ooO`0Uooooo`03ool0
0?oooooooooo01kooooo00?o003oooooooooool0O?ooool1o`00007ooooo00000ol0003ooooooooo
o`0fooooo`030000oooooooooooo01Wooooo1?ooO`0Uooooo`03ool00?oooooooooo01oooooo00?o
003oooooooooool0Noooool1o`00007ooooo00000ol0003oooooooooo`0eooooo`040000oooooooo
ogl0oomo01[ooooo0_ooO`0Vooooo`03ool00?oooooooooo023ooooo00?o003oooooooooool0N_oo
ool1o`00007ooooo00000ol0003oooooooooo`0dooooo`030000ooooooooogl000?oogl0@Oooool0
0ooo003oooooooooo`0Qooooo`03o`00oooooooooooo07Wooooo0Ol00001ooooo`0000?o0000oooo
ooooool0:oooool2oomo00Kooooo00<0003oooooooooool01?ooO`11ooooo`03ool00?oooooooooo
027ooooo00?o003oooooooooool0NOooool1o`00007ooooo00000ol0003oooooooooo`0Zooooo`Co
ogl01?ooool00`000?ooooooooooo`02ooooo`;oogl06?ooool2oomo017ooooo0_ooO`0Eooooo`03
ool00?oooooooooo02;ooooo00?o003oooooooooool0N?ooool1o`00007ooooo00000ol0003ooooo
ooooo`0Zooooo`Coogl01?ooool00`000?ooooooooooo`0Kooooo`Coogl03oooool4oomo01Cooooo
00?oo`00ooooooooool08oooool00ol00?ooooooooooo`1gooooo`7o00000Oooool00003o`000?oo
oooooooo02_ooooo0_ooO`04ooooo`030000oooooooooooo01cooooo1?ooO`0?ooooo`Coogl05?oo
ool00ooo003oooooooooo`0Sooooo`03o`00oooooooooooo07Oooooo0Ol00001ooooo`0000?o0000
ooooooooool0<Oooool00`000?ooooooooooo`0Mooooo`;oogl04Oooool2oomo01Cooooo00?oo`00
ooooooooool09Oooool00ol00?ooooooooooo`1fooooo`7o00000Oooool00003o`000?oooooooooo
033ooooo00<0003oooooooooool0Aoooool00ooo003oooooooooo`0Uooooo`03o`00oooooooooooo
07Kooooo0Ol00001ooooo`0000?o0000ooooooooool0<?ooool00`000?ooooooooooo`17ooooo`03
ool00?oooooooooo02Kooooo00?o003oooooooooool0MOooool1o`00007ooooo00000ol0003ooooo
ooooo`0_ooooo`030000oooooooooooo04Sooooo00?oo`00ooooooooool09oooool00ol00?oooooo
ooooo`1dooooo`7o00000Oooool00003o`000?oooooooooo02oooooo00<0003oooooooooool01ooo
ool2oomo00;ooooo0_ooO`0kooooo`03ool00?oooooooooo02Oooooo00?o003oooooooooool0M?oo
ool1o`00007ooooo00000ol0003oooooooooo`0^ooooo`030000oooooooooooo00Oooooo2?ooO`0i
ooooo`03ool00?oooooooooo02Wooooo00?o003oooooooooool0Loooool1o`00007ooooo00000ol0
003oooooooooo`0^ooooo`030000oooooooooooo00Oooooo2?ooO`0iooooo`03ool00?oooooooooo
02Wooooo00?o003oooooooooool0Loooool1o`00007ooooo00000ol0003oooooooooo`0]ooooo`03
0000oooooooooooo00Wooooo1_ooO`0Pooooo`;oogl05oooool00ooo003oooooooooo`0[ooooo`03
o`00oooooooooooo07;ooooo0Ol00001ooooo`0000?o0000ooooooooool0;Oooool00`000?oooooo
ooooo`0;ooooo`Coogl07oooool4oomo01Kooooo00?oo`00ooooooooool0:oooool00ol00?oooooo
ooooo`1booooo`7o00000Oooool00003o`000?oo003ooooo02gooooo00<0003oooooooooool03?oo
ool2oomo023ooooo1?ooO`0Fooooo`03ool00?oooooooooo02_ooooo00?o003oooooooooool0L_oo
ool1o`00007ooooo00000ol0003oo`00ooooo`0/ooooo`030000oooooooooooo033ooooo0_ooO`0F
ooooo`03ool00?oooooooooo02gooooo00?o003oooooooooool0LOooool1o`00007ooooo00000ol0
003oo`00ooooo`0/ooooo`030000oooooooooooo04Sooooo00?oo`00ooooooooool0;Oooool00ol0
0?ooooooooooo`1aooooo`7o00000Oooool00003o`000?ooooooo`0002cooooo00<0003ooooooooo
ool0B?ooool00ooo003oooooooooo`0]ooooo`03o`00oooooooooooo077ooooo0Ol00001ooooo`00
00?o0000oooooooo0000:oooool00`000?ooooooooooo`18ooooo`03ool00?oooooooooo02oooooo
00?o003oooooooooool0L?ooool1o`00007ooooo00001?l0003ooooooooooooo000Zooooo`030000
oooooooooooo00?ooooo0_ooO`13ooooo`03ool00?oooooooooo02oooooo00?o003oooooooooool0
L?ooool1o`00007ooooo00001?l0003ooooooooooooo000Zooooo`030000oooooooooooo00;ooooo
1?ooO`12ooooo`03ool00?oooooooooo02oooooo00?o003oooooooooool0L?ooool1o`00007ooooo
00001Ol0003oooooooooooooooooo`0002Wooooo00<0003oooooooooool00_ooool4oomo047ooooo
00?oo`00ooooooooool0<?ooool00ol00?ooooooooooo`1`ooooo`7o00000Oooool00005o`000?oo
oooooooooooooooo0000:?ooool00`000?ooooooooooo`04ooooo`;oogl0@_ooool00ooo003ooooo
ooooo`0aooooo`03o`00oooooooooooo06oooooo0Ol00001ooooo`0000?o0000ooooooooool00_oo
ool00ooo003oooooooooo`0Uooooo`030000oooooooooooo04Oooooo00?oo`00ooooooooool0<_oo
ool00ol00?ooooooooooo`1_ooooo`7o00000Oooool00003o`000?oooooooooo00;ooooo00?oo`00
ooooooooool09Oooool00`000?ooooooooooo`17ooooo`03ool00?oooooooooo03;ooooo00?o003o
ooooooooool0Koooool1o`00007ooooo00000ol0003oooooooooo`03ooooo`03ool00?oooooooooo
02Cooooo00<0003oooooooooool0A_ooool00ooo003oooooooooo`0cooooo`03o`00oooooooooooo
06oooooo0Ol00001ooooo`0000?o0000ooooooooool01?ooool00ooo003oooooooooo`0Sooooo`03
0000oooooooooooo04Gooooo00?oo`00ooooooooool0=?ooool00ol00?ooooooooooo`1_ooooo`7o
00000Oooool00003o`000?oooooooooo00Gooooo00?oo`00ooooooooool08Oooool00`000?oooooo
ooooo`15ooooo`03ool00?oooooooooo03Kooooo00?o003oooooooooool0K_ooool1o`00007ooooo
00000ol0003oooooooooo`06ooooo`03ool00?oooooooooo023ooooo00<0003oooooooooool0AOoo
ool00ooo003oooooooooo`09ooooo`;oogl0:oooool00ol00?ooooooooooo`1^ooooo`7o00000Ooo
ool00003o`000?oooooooooo00Kooooo00?oo`00ooooooooool08?ooool00`000?ooooooooooo`14
ooooo`03ool00?oooooooooo00Wooooo1?ooO`0Zooooo`03o`00oooooooooooo06kooooo0Ol00001
ooooo`0000?o0000ooooooooool01oooool00ooo003oooooooooo`0Oooooo`030000oooooooooooo
02Sooooo0_ooO`0Iooooo`03ool00?oooooooooo00[ooooo1?ooO`0Zooooo`03o`00oooooooooooo
06kooooo0Ol00001ooooo`0000?o0000ooooooooool01oooool00ooo003oooooooooo`0Oooooo`03
0000oooooooooooo02Oooooo1?ooO`0Gooooo`03ool00?oooooooooo00cooooo0_ooO`0[ooooo`03
o`00oooooooooooo06kooooo0Ol00001ooooo`0000?o0000ooooooooool02?ooool00ooo003ooooo
ooooo`0Nooooo`030000oooooooooooo02Oooooo1?ooO`0Gooooo`03ool00?oooooooooo03Wooooo
00?o003oooooooooool0K_ooool1o`00007ooooo00000ol0003oooooooooo`09ooooo`03ool00?oo
oooooooo01gooooo00<0003oooooooooool0:?ooool2oomo01;ooooo1?l00?l00oooooooo`00oooo
o`0kooooo`03o`00oooooooooooo06kooooo0Ol00001ooooo`0000?o0000ooooooooool02_ooool0
0ooo003oooooooooo`0Looooo`030000oooooooooooo03_ooooo1_l00?lmooooo`03o`00oooooooo
oooo06kooooo0Ol00001ooooo`0000?o0000ooooooooool02oooool00ooo003oooooooooo`0Koooo
o`030000oooooooooooo03Oooooo0_ooO`000ooooooo003oo`00o`06o`00occooooo00?o003ooooo
ooooool0K_ooool1o`00007ooooo00000ol0003oooooooooo`0<ooooo`03ool00?oooooooooo01[o
oooo00<0003oooooooooool0=_ooool4oomo00So003o??ooool00ol00?ooooooooooo`1^ooooo`7o
00000Oooool00003o`000?oooooooooo00gooooo00?oo`00ooooooooool06Oooool00`000?oooooo
ooooo`0fooooo`Coogl02?l00?llooooo`03o`00oooooooooooo06kooooo0Ol00001ooooo`0000?o
0000ooooooooool03Oooool2ool001[ooooo00<0003oooooooooool0=oooool2oomo0003ooooool0
0?oo003o00Ko003o??ooool00ol00?ooooooooooo`1^ooooo`7o00000Oooool00003o`000?oooooo
oooo00oooooo00?oo`00ooooooooool05oooool00`000?ooooooooooo`0jooooo`03ool00?l00?oo
003o00Co003o?Oooool00ol00?ooooooooooo`1^ooooo`7o00000Oooool00003o`000?oooooooooo
013ooooo00?oo`00ooooooooool05_ooool00`000?ooooooooooo`0iooooo`03ool00?oooooooooo
00Co003o?_ooool00ol00?ooooooooooo`1^ooooo`7o00000Oooool00003o`000?oooooooooo017o
oooo00?oo`00ooooooooool05Oooool00`000?ooooooooooo`0hooooo`03ool00?oooooooooo04?o
oooo00?o003oooooooooool0K_ooool1o`00007ooooo00000ol0003oooooooooo`0Booooo`03ool0
0?oooooooooo01Cooooo00<0003oooooooooool0=_ooool2ool004Kooooo00?o003oooooooooool0
K_ooool1o`00007ooooo00000ol0003oooooooooo`0Cooooo`03ool00?oooooooooo01?ooooo00<0
003oooooooooool0=Oooool00ooo003oooooooooo`16ooooo`03o`00oooooooooooo06kooooo0Ol0
0001ooooo`0000?o0000ooooooooool05?ooool2ool001?ooooo00<0003oooooooooool0=?ooool0
0ooo003oooooooooo`17ooooo`03o`00oooooooooooo06kooooo0Ol00001ooooo`0000?o0000oooo
ooooool05_ooool2ool0017ooooo00<0003oooooooooool0<_ooool2ool004[ooooo00?o003ooooo
ooooool0K_ooool1o`00007ooooo00000ol0003oooooooooo`0Hooooo`03ool00?oooooooooo00ko
oooo00<0003oooooooooool0<Oooool00ooo003oooooooooo`1:ooooo`03o`00oooooooooooo06ko
oooo0Ol00001ooooo`0000?o0000ooooooooool06Oooool2ool000kooooo00<0003oooooooooool0
;oooool2ool004gooooo00?o003oooooooooool0K_ooool1o`00007ooooo00000ol0003ooooooooo
o`0Kooooo`03ool00?oooooooooo00_ooooo00<0003oooooooooool0;_ooool00ooo003ooooooooo
o`1<ooooo`03o`00oooooooooooo06oooooo0Ol00001ooooo`0000?o0000ooooooooool07?ooool2
ool000_ooooo00<0003oooooooooool0;Oooool00ooo003oooooooooo`1=ooooo`03o`00oooooooo
oooo06oooooo0Ol00001ooooo`0000?o0000ooooooooool07_ooool3ool000Wooooo00<0003ooooo
ooooool0:_ooool2ool0053ooooo00?o003oooooooooool0Koooool1o`00007ooooo00000ol0003o
ooooooooo`0Qooooo`;oo`001oooool00`000?ooooooooooo`0Wooooo`?oo`00D_ooool00ol00?oo
ooooooooo`1_ooooo`7o00000Oooool00003o`000?oooooooooo02?ooooo0_oo0005ooooo`030000
oooooooooooo02Gooooo0_oo001Dooooo`03o`00oooooooooooo073ooooo0Ol00001ooooo`0000?o
0000ooooooooool09Oooool4ool00003ooooo`000?oooooo02;ooooo1?oo001Fooooo`03o`00oooo
oooooooo073ooooo0Ol00001ooooo`0000?o0000ooooooooool0:Oooool2ool00003o`00oooo003o
o`0001gooooo0ooo001Jooooo`03o`00oooooooooooo073ooooo0Ol00001ooooo`0000?o0000oooo
ooooool0:oooool00`000?ooooooooooo`03ool001Cooooo1_oo001Mooooo`03o`00oooooooooooo
073ooooo0Ol00001ooooo`0000?o0000ooooooooool0;?ooool00`000?ooooooooooo`02oooooaCo
o`00H_ooool00ol00?ooooooooooo`1aooooo`7o00000Oooool00003o`000?oooooooooo02cooooo
00<0003oooooooooool0N?ooool00ol00?ooooooooooo`1aooooo`7o00000Oooool00003o`000?oo
oooooooo02cooooo00<0003oooooooooool0N?ooool00ol00?ooooooooooo`1aooooo`7o00000Ooo
ool00003o`000?oooooooooo02gooooo00<0003oooooooooool0M_ooool00ol00?ooooooooooo`1b
ooooo`7o00000Oooool00003o`000?oooooooooo02gooooo00<0003oooooooooool0M_ooool00ol0
0?ooooooooooo`1booooo`7o00000Oooool00003o`000?oooooooooo02gooooo00<0003ooooooooo
ool0M_ooool00ol00?ooooooooooo`1booooo`7o00000Oooool00003o`000?oooooooooo02kooooo
00<0003oooooooooool0M?ooool00ol00?ooooooooooo`1cooooo`7o00000Oooool00003o`000?oo
oooooooo02kooooo00<0003oooooooooool0M?ooool00ol00?ooooooooooo`1cooooo`7o00000Ooo
ool00003o`000?oooooooooo02kooooo00<0003oooooooooool0M?ooool00ol00?ooooooooooo`1c
ooooo`7o00000Oooool00003o`000?oooooooooo02oooooo00<0003oooooooooool0L_ooool00ol0
0?ooooooooooo`1dooooo`7o00000Oooool00003o`000?oooooooooo02oooooo00<0003ooooooooo
ool0L_ooool00ol00?ooooooooooo`1dooooo`7o00000Oooool00003o`000?oooooooooo02oooooo
00<0003oooooooooool0L_ooool00ol00?ooooooooooo`1dooooo`7o00000Oooool00003o`000?oo
oooooooo033ooooo00<0003oooooooooool0Koooool2o`00ogOooooo0Ol00001ooooo`0000?o0000
ooooooooool0<?ooool00`000?ooooooooooo`1_ooooo`03o`00oooooooooooo07Kooooo0Ol00001
ooooo`0000?o0000ooooooooool0<Oooool00`000?ooooooooooo`1]ooooo`03o`00oooooooooooo
07Oooooo0Ol00001ooooo`0000?o0000ooooooooool0<_ooool00`000?ooooooooooo`1/ooooo`03
o`00oooooooooooo07Oooooo0Ol00001ooooo`0000?o0000ooooooooool0<_ooool00`000?oooooo
ooooo`1[ooooo`03o`00oooooooooooo063ooooo0_ooO`0Fooooo`7o00000Oooool00003o`000?oo
oooooooo03?ooooo00<0003oooooooooool0JOooool00ol00?ooooooooooo`1Pooooo`Coogl05Ooo
ool1o`00007ooooo00000ol0003oooooooooo`0dooooo`030000oooooooooooo06Sooooo00?o003o
ooooooooool0H?ooool4oomo01Gooooo0Ol00001ooooo`0000?o0000ooooooooool0=Oooool00`00
0?ooooooooooo`1Vooooo`03o`00oooooooooooo06;ooooo0_ooO`0Fooooo`7o00000Oooool00003
o`000?oooooooooo03Gooooo00?o003oooooooooool0I_ooool00ol00?ooooooooooo`1jooooo`7o
00000Oooool00003o`000?oooooooooo03Kooooo00?o003oooooooooool0I?ooool00ol00?oooooo
ooooo`1kooooo`7o00000Oooool00003o`000?oooooooooo03Oooooo00?o003oooooooooool0H_oo
ool00ol00?ooooooooooo`1looooo`7o00000Oooool00003o`000?oooooooooo03Sooooo00?o003o
ooooooooool0Goooool2o`00ogoooooo0Ol00001ooooo`0000?o0000ooooooooool0>Oooool00ol0
0?ooooooooooo`1Mooooo`03o`00oooooooooooo07oooooo0Ol00001ooooo`0000?o0000oooooooo
ool0>_ooool00ol00?ooooooooooo`1Kooooo`03o`00oooooooooooo083ooooo0Ol00001ooooo`00
00?o0000ooooooooool0>oooool00ol00?ooooooooooo`1Iooooo`03o`00oooooooooooo087ooooo
0Ol00001ooooo`0000?o0000ooooooooool0??ooool00ol00?ooooooooooo`1Gooooo`03o`00oooo
oooooooo08;ooooo0Ol00001ooooo`0000?o0000ooooooooool0?Oooool00ol00?ooooooooooo`1E
ooooo`03o`00oooooooooooo08?ooooo0Ol00001ooooo`0000?o0000ooooooooool0?_ooool00ol0
0?ooooooooooo`1Cooooo`03o`00oooooooooooo08Cooooo0Ol00001ooooo`0000?o0000oooooooo
ool0?oooool00ol00?ooooooooooo`1@ooooo`;o003o8Oooool2oomo06Cooooo0Ol00001ooooo`00
00?o0000ooooooooool0@?ooool00ol00?ooooooooooo`1>ooooo`03o`00oooooooooooo023ooooo
1?ooO`1Sooooo`7o00000Oooool00003o`000?oooooooooo047ooooo0_l00?m=ooooo`03o`00oooo
oooooooo027ooooo1?ooO`1Sooooo`7o00000Oooool00003o`000?oooooooooo04?ooooo00?o003o
ooooooooool0BOooool00ol00?ooooooooooo`0Sooooo`;oogl0=Oooool2oomo02gooooo0Ol00001
ooooo`0000?o0000ooooooooool0A?ooool2o`00odSooooo00?o003oooooooooool0Doooool2oomo
00Gooooo1?ooO`0/ooooo`7o00000Oooool00003o`000?oooooooooo04Kooooo0_l00?m5ooooo`03
o`00oooooooooooo05?ooooo1?ooO`04ooooo`Coogl0;?ooool1o`00007ooooo00000ol0003ooooo
ooooo`18ooooo`03o`00oooooooooooo043ooooo0_l00?lfooooo`;oogl07_ooool4oomo00Gooooo
0_ooO`0]ooooo`7o00000Oooool00003o`000?oooooooooo04Wooooo0_l00?lnooooo`;o003o;Ooo
ool5ool0o`Gooooo1?ooO`0Nooooo`;oogl0=Oooool1o`00007ooooo00000ol0003oooooooooo`1;
ooooo`?o003o>_ooool00ol00?ooooooooooo`0/ooooo`Ooo`3o1?ooool4oomo05Gooooo0Ol00001
ooooo`0000?o0000ooooooooool0C_ooool2o`00ocKooooo0_l00?l^ooooo`Woo`3o1?ooool2oomo
05Kooooo0Ol00001ooooo`0000?o0000ooooooooool0D?ooool3o`00oc3ooooo0ol00?l_ooooo`_o
o`3o8?ooool2oomo03Wooooo0Ol00001ooooo`0000?o0000ooooooooool0Doooool2o`00ob[ooooo
1?l00?lbooooo`_oo`3o7oooool4oomo03Sooooo0Ol00001ooooo`0000?o0000ooooooooool0EOoo
ool3o`00ob?ooooo1?l00?leooooo`03oomo0?oo0?ooo`3o00Woo`3o7oooool4oomo00?ooooo0_oo
O`0cooooo`7o00000Oooool00003o`000?oooooooooo05Sooooo0ol00?lMooooo`?o003o>?ooool2
oomo00_oo`3o3_ooool2oomo013ooooo0_ooO`03ooooo`Coogl0<_ooool1o`00007ooooo00000ol0
003oooooooooo`1Kooooo`?o003o5?ooool6o`00oc_ooooo0_ooO`0;ool0o`gooooo1?ooO`0Doooo
o`Coogl0<_ooool1o`00007ooooo00000ol0003oooooooooo`1NoooooaCo003o@_ooool2oomo00Wo
o`3o00?oogl0ooooooooool02oooool4oomo01Gooooo0_ooO`0cooooo`7o00000Oooool00003o`00
0?oooooooooo08_ooooo0_ooO`0Wooooo`;oogl000?oooooool0oooo0?l01Ooo0?l2oomo00kooooo
0_ooO`1;ooooo`7o00000Oooool00003o`000?oooooooooo08[ooooo1?ooO`0Uooooo`Coogl000?o
ooooool0oooo0?l00ooo0?l2oomo05cooooo0Ol00001ooooo`0000?o0000ooooooooool0R_ooool4
oomo02Gooooo1?ooO`1Tooooo`7o00000Oooool00003o`000?oooooooooo08_ooooo0_ooO`0Woooo
o`;oogl0IOooool1o`00007ooooo00000ol0003oooooooooo`2Fooooo`;oogl0>_ooool2oomo04Oo
oooo0Ol00001ooooo`0000?o0000ooooooooool0UOooool4oomo00kooooo0_ooO`0Xooooo`Coogl0
A_ooool1o`00007ooooo00000ol0003oooooooooo`2Eooooo`Coogl03Oooool4oomo02Oooooo1?oo
O`16ooooo`7o00000Oooool00003o`000?oooooooooo09Kooooo0_ooO`0>ooooo`Coogl0:?ooool2
oomo04Oooooo0Ol00001ooooo`0000?o0000ooooooooool0Yoooool2oomo07;ooooo0Ol00001oooo
o`0000?o0000ooooooooool0joooool2oomo02kooooo0Ol00001ooooo`0000?o0000ooooooooool0
j_ooool4oomo02gooooo0Ol00001ooooo`0000?o0000ooooooooool0e_ooool2oomo01;ooooo1?oo
O`0]ooooo`7o00000Oooool00003o`000?oooooooooo0=Gooooo1?ooO`0Booooo`;oogl0;_ooool1
o`00007ooooo00000ol0003oooooooooo`2gooooo`;oogl07?ooool4oomo04;ooooo0Ol00001oooo
o`0000?o0000ooooooooool0]_ooool4oomo01cooooo0_ooO`13ooooo`7o00000Oooool00003o`00
0?oooooooooo0;?ooooo0_ooO`000oooooooogl0oomo0002oomo067ooooo0Ol00001ooooo`0000?o
0000ooooooooool0Z?ooool2oomo00Sooooo1?ooO`000oooooooogl0oomo000Jooooo`;oogl0A_oo
ool1o`00007ooooo00000ol0003oooooooooo`2Vooooo`Googl01oooool4oomo01Oooooo0_ooO`03
ooooo`Coogl0AOooool1o`00007ooooo00000ol0003oooooooooo`2Uooooo`Koogl02?ooool2oomo
01Oooooo1?ooO`02ooooo`Coogl0AOooool1o`00007ooooo00000ol0003oooooooooo`2Uooooo`Go
ogl08_ooool4oomo00?ooooo0_ooO`16ooooo`7o00000Oooool00003o`000?oooooooooo07Kooooo
0_ooO`0^ooooo`;oogl09Oooool2oomo04cooooo0Ol00001ooooo`0000?o0000ooooooooool0MOoo
ool4oomo0:;ooooo0Ol00001ooooo`0000?o0000ooooooooool0MOooool4oomo00[ooooo0_ooO`2F
ooooo`7o00000Oooool00003o`000?oooooooooo07Kooooo0_ooO`0:ooooo`Coogl0:_ooool2oomo
06Wooooo0Ol00001ooooo`0000?o0000ooooooooool0P_ooool4oomo02Wooooo1?ooO`1Xooooo`7o
00000Oooool00003o`000?oooooooooo08?ooooo0_ooO`0Tooooo`;oogl01?ooool4oomo06Sooooo
0Ol00001ooooo`0000?o0000ooooooooool0Z?ooool4oomo00Cooooo0_ooO`1Yooooo`7o00000Ooo
ool00003o`000?oooooooooo0:Sooooo1?ooO`1_ooooo`7o00000Oooool00003o`000?oooooooooo
0:Wooooo0_ooO`1`ooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007o
oooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooo
oolLooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0
003oooooooooo`24ooooo`;oogl0UOooool1o`00007ooooo00000ol0003oooooooooo`23ooooo`Co
ogl0U?ooool1o`00007ooooo00000ol0003oooooooooo`23ooooo`Coogl0U?ooool1o`00007ooooo
00000ol0003oooooooooo`24ooooo`;oogl0;?ooool2oomo06Oooooo0Ol00001ooooo`0000?o0000
ooooooooool0/Oooool4oomo06Kooooo0Ol00001ooooo`0000?o0000ooooooooool0/Oooool4oomo
06Kooooo0Ol00001ooooo`0000?o0000ooooooooool0/_ooool2oomo06Oooooo0Ol00001ooooo`00
00?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?oo
ool1o`00007ooooo00000ol0003oooooooooo`1kooooo`;oogl0W_ooool1o`00007ooooo00000ol0
003oooooooooo`1jooooo`Coogl0WOooool1o`00007ooooo00000ol0003oooooooooo`1jooooo`Co
ogl08?ooool2oomo07_ooooo0Ol00001ooooo`0000?o0000ooooooooool0Noooool2oomo023ooooo
1?ooO`1jooooo`7o00000Oooool00003o`000?oooooooooo09gooooo1?ooO`1jooooo`7o00000Ooo
ool00003o`000?oooooooooo093ooooo0_ooO`0<ooooo`;oogl0Noooool1o`00007ooooo00000ol0
003oooooooooo`2?ooooo`Coogl0R?ooool1o`00007ooooo00000ol0003oooooooooo`2?ooooo`Co
ogl0R?ooool1o`00007ooooo00000ol0003oooooooooo`2@ooooo`;oogl08oooool2oomo06Cooooo
0Ol00001ooooo`0000?o0000ooooooooool0]?ooool4oomo06?ooooo0Ol00001ooooo`0000?o0000
ooooooooool0]?ooool4oomo06?ooooo0Ol00001ooooo`0000?o0000ooooooooool0]Oooool2oomo
06Cooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`00
0?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol0
0001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo
0?oooooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`00
00?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?oo
ool1o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000oooo
ooooool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007o
oooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooo
oolLooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0
003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o
00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003ooooooooo
o`3ooooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool0
0003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooooaco
oooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oo
oooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001
ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo0?oo
oooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o
0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1
o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000oooooooo
ool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo
00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolL
ooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003o
ooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o0000
0Oooool00003o`000?oooooooooo08kooooo0_ooO`2;ooooo`7o00000Oooool00003o`000?oooooo
oooo08gooooo1?ooO`2:ooooo`7o00000Oooool00003o`000?oooooooooo08gooooo1?ooO`2:oooo
o`7o00000Oooool00003o`000?oooooooooo08kooooo0_ooO`2;ooooo`7o00000Oooool00003o`00
0?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol0
0001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo
0?oooooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`00
00?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?oo
ool1o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000oooo
ooooool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007o
oooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooo
oolLooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0
003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o
00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003ooooooooo
o`3ooooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool0
0003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooooaco
oooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool00?oo00008?l0
0001ooooo`00\
\>"],
  ImageRangeCache->{{{0, 287}, {287, 0}} -> {-1.01089, -1.01089, 0.00704453, \
0.00704453}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.49505 0.5 0.49505 [
[ 0 0 -0.125 0 ]
[ 0 0 -0.125 0 ]
[ 0 1 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
0 0 m
1 0 L
s
0 0 m
0 1 L
s
0 1 m
1 1 L
s
1 0 m
1 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
1 .5 0 r
.015 w
.03175 .1355 Mdot
.03435 .12523 Mdot
.11137 .12765 Mdot
.14107 .18841 Mdot
.16218 .24538 Mdot
.17294 .21053 Mdot
.18267 .18577 Mdot
.18434 .1304 Mdot
.18553 .30956 Mdot
.20401 .239 Mdot
.21247 .27571 Mdot
.21687 .20845 Mdot
.22376 .2799 Mdot
.22832 .27485 Mdot
.29063 .20974 Mdot
.29686 .25079 Mdot
.30487 .22936 Mdot
.30683 .34623 Mdot
.32055 .20902 Mdot
.32574 .21979 Mdot
.34472 .28521 Mdot
.35998 .36393 Mdot
.36335 .24976 Mdot
.3794 .36608 Mdot
.42386 .66992 Mdot
.44391 .74519 Mdot
.45059 .34198 Mdot
.47208 .67586 Mdot
.47436 .71381 Mdot
.49778 .59825 Mdot
.50874 .91643 Mdot
.51516 .76219 Mdot
.53655 .61374 Mdot
.56563 .75219 Mdot
.59189 .65665 Mdot
.59581 .61604 Mdot
.59923 .6556 Mdot
.60292 .68499 Mdot
.62656 .67779 Mdot
.63555 .72451 Mdot
.63919 .652 Mdot
.64169 .6004 Mdot
.64246 .58611 Mdot
.64496 .54267 Mdot
.64608 .77288 Mdot
.65077 .64308 Mdot
.66065 .57816 Mdot
.67474 .59169 Mdot
.69296 .563 Mdot
.72815 .65902 Mdot
.73169 .58879 Mdot
.74669 .61318 Mdot
.74821 .65474 Mdot
.75963 .63781 Mdot
.79673 .57809 Mdot
.80925 .55852 Mdot
.81525 .58444 Mdot
.83417 .62985 Mdot
.83598 .55526 Mdot
.91595 .49319 Mdot
1 0 0 r
.005 w
.00495 .28842 m
.00628 .29156 L
.01857 .31761 L
.03101 .33781 L
.03525 .34367 L
.05706 .36884 L
.05795 .36972 L
.08312 .39115 L
.08963 .39578 L
.10917 .40763 L
.13523 .41964 L
.14074 .42183 L
.16128 .42794 L
.18734 .43294 L
.21339 .43485 L
.23945 .43375 L
.2655 .42959 L
.29156 .42219 L
.29261 .42183 L
.31761 .41124 L
.34367 .39603 L
.34405 .39578 L
.36972 .37551 L
.37582 .36972 L
.39578 .34724 L
.39849 .34367 L
.41525 .31761 L
.42183 .30485 L
.4275 .29156 L
.436 .2655 L
.44117 .23945 L
.44325 .21339 L
.44232 .18734 L
.43834 .16128 L
.43114 .13523 L
.42183 .11212 L
.42037 .10917 L
.40546 .08312 L
.39578 .06961 L
.38528 .05706 L
.36972 .04137 L
.35758 .03101 L
.34367 .02092 L
.31761 .00569 L
.3162 .00495 L
s
.00495 .12854 m
.01344 .10917 L
.02832 .08312 L
.03101 .07912 L
.04848 .05706 L
.05706 .04802 L
.07619 .03101 L
.08312 .02579 L
.10917 .00934 L
.11742 .00495 L
s
0 0 1 r
.29156 .15739 m
.31761 .14824 L
.34367 .14249 L
.36972 .13986 L
.39578 .14025 L
.42183 .14366 L
.44789 .15025 L
.47394 .16034 L
.47599 .16128 L
.5 .17443 L
.51844 .18734 L
.52606 .19355 L
.54662 .21339 L
.55211 .21962 L
.56712 .23945 L
.57817 .25755 L
.58227 .2655 L
.59322 .29156 L
.60058 .31761 L
.60422 .3392 L
.60471 .34367 L
.6058 .36972 L
.60422 .39297 L
.60387 .39578 L
.59886 .42183 L
.59054 .44789 L
.57848 .47394 L
.57817 .47453 L
.562 .5 L
.55211 .51255 L
.53968 .52606 L
.52606 .53862 L
.50853 .55211 L
.5 .55773 L
.47394 .57183 L
.45901 .57817 L
.44789 .5819 L
.42183 .5885 L
.39578 .59192 L
.36972 .59231 L
.34367 .58968 L
.31761 .58392 L
.29972 .57817 L
.29156 .57477 L
.2655 .56178 L
.25025 .55211 L
.23945 .54409 L
.21914 .52606 L
.21339 .52008 L
.19681 .5 L
Mistroke
.18734 .48608 L
.18031 .47394 L
.16827 .44789 L
.16128 .42714 L
.15996 .42183 L
.15493 .39578 L
.153 .36972 L
.15409 .34367 L
.15823 .31761 L
.16128 .3045 L
.16559 .29156 L
.17653 .2655 L
.18734 .24609 L
.19169 .23945 L
.21221 .21339 L
.21339 .21211 L
.23945 .1881 L
.24041 .18734 L
.2655 .17038 L
.28271 .16128 L
.29156 .15739 L
Mfstroke
1 0 0 r
.03 w
.21687 .20845 Mdot
0 0 1 r
.3794 .36608 Mdot
1 0 0 r
.79703 .00495 m
.79703 .03124 L
.87129 .03124 L
.87129 .00495 L
F
0 0 1 r
.89604 .00495 m
.89604 .22619 L
.9703 .22619 L
.9703 .00495 L
F
1 0 1 r
.04 w
.67474 .59169 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P000182000`400?l00000o`00003ooooooolQ
ooooo`00ool0000Po`00007ooooo00000ol0003oooooooooo`0Mooooo`;oo`00>?ooool3ool00<7o
oooo0Ol00001ooooo`0000?o0000ooooooooool06oooool2ool003gooooo00?oo`00ooooooooool0
Q?oooolEool000Sooooo5Ol00?l8ooooo`7o00000Oooool00003o`000?oooooooooo01[ooooo00?o
o`00ooooooooool0?_ooool2ool008Cooooo5Ooo0008oooooaGo003o2?ooool1o`00007ooooo0000
0ol0003oooooooooo`0Hooooo`;oo`00@oooool00ooo003oooooooooo`21oooooaGoo`002?oooolE
o`00o`Sooooo0Ol00001ooooo`0000?o0000ooooooooool05_ooool2ool004Kooooo00?oo`00oooo
ooooool0P?oooolEool000Sooooo5Ol00?l8ooooo`7o00000Oooool00003o`000?oooooooooo01Go
oooo00?oo`00ooooooooool0Aoooool2ool0083ooooo5Ooo0008oooooaGo003o2?ooool1o`00007o
oooo00000ol0003oooooooooo`0Dooooo`03ool00?oooooooooo04[ooooo00?oo`00ooooooooool0
OOoooolEool000Sooooo5Ol00?l8ooooo`7o00000Oooool00003o`000?oooooooooo01?ooooo00?o
o`00ooooooooool0C?ooool00ooo003oooooooooo`1loooooaGoo`002?oooolEo`00o`Sooooo0Ol0
0001ooooo`0000?o0000ooooooooool04Oooool2ool0053ooooo0_oo001loooooaGoo`002?oooolE
o`00o`Sooooo0Ol00001ooooo`0000?o0000ooooooooool04?ooool00ooo003oooooooooo`1Boooo
o`;oo`00UooooolEo`00o`Sooooo0Ol00001ooooo`0000?o0000ooooooooool03oooool00ooo003o
ooooooooo`1Eooooo`03ool00?oooooooooo09Cooooo5Ol00?l8ooooo`7o00000Oooool00003o`00
0?oooooooooo00kooooo00?oo`00ooooooooool0E_ooool00ooo003oooooooooo`2DoooooaGo003o
2?ooool1o`00007ooooo00000ol0003oooooooooo`0=ooooo`03ool00?oooooooooo05Sooooo00?o
o`00ooooooooool0TooooolEo`00o`Sooooo0Ol00001ooooo`0000?o0000ooooooooool03Oooool0
0ooo003oooooooooo`1Iooooo`03ool00?oooooooooo09;ooooo5Ol00?l8ooooo`7o00000Oooool0
0003o`000?oooooooooo00cooooo00?oo`00ooooooooool0Foooool00ooo003oooooooooo`2Aoooo
oaGo003o2?ooool1o`00007ooooo00000ol0003oooooooooo`0;ooooo`03ool00?oooooooooo05go
oooo00?oo`00ooooooooool0T?oooolEo`00o`Sooooo0Ol00001ooooo`0000?o0000ooooooooool0
2oooool00ooo003oooooooooo`1Mooooo`03ool00?oooooooooo093ooooo5Ol00?l8ooooo`7o0000
0Oooool00003o`000?oooooooooo00[ooooo00?oo`00ooooooooool0Goooool00ooo003ooooooooo
o`2?oooooaGo003o2?ooool1o`00007ooooo00000ol0003oooooooooo`09ooooo`03ool00?oooooo
oooo067ooooo00?oo`00ooooooooool0S_oooolEo`00o`Sooooo0Ol00001ooooo`0000?o0000oooo
ooooool02?ooool00ooo003oooooooooo`1Sooooo`03ool00?oooooooooo08gooooo5Ol00?l8oooo
o`7o00000Oooool00003o`000?oooooooooo00Oooooo00?oo`00ooooooooool0IOooool00ooo003o
ooooooooo`2<oooooaGo003o2?ooool1o`00007ooooo00000ol0003oooooooooo`06ooooo`03ool0
0?oooooooooo06Oooooo00?oo`00ooooooooool0RooooolEo`00o`Sooooo0Ol00001ooooo`0000?o
0000ooooooooool01Oooool00ooo003oooooooooo`1Yooooo`03ool00?oooooooooo08[ooooo5Ol0
0?l8ooooo`7o00000Oooool00003o`000?oooooooooo00Gooooo00?oo`00ooooooooool0JOooool0
0ooo003oooooooooo`2:oooooaGo003o2?ooool1o`00007ooooo00000ol0003oooooooooo`04oooo
o`03ool00?oooooooooo06_ooooo00?oo`00ooooooooool0ROoooolEo`00o`Sooooo0Ol00001oooo
o`0000?o0000ooooooooool00oooool00ooo003oooooooooo`1/ooooo`03ool00?oooooooooo08Wo
oooo5Ol00?l8ooooo`7o00000Oooool00003o`000?oooooooooo00?ooooo00?oo`00ooooooooool0
KOooool00ooo003oooooooooo`28oooooaGo003o2?ooool1o`00007ooooo00000ol0003ooooooooo
o`02ooooo`03ool00?oooooooooo06kooooo00?oo`00ooooooooool0R?oooolEo`00o`Sooooo0Ol0
0001ooooo`0000?o0000ooooooooool00_ooool00ooo003oooooooooo`1_ooooo`03ool00?oooooo
oooo08Oooooo5Ol00?l8ooooo`7o00000Oooool00005o`000?oooooooooooooooooo0000L_ooool0
0ooo003oooooooooo`27oooooaGo003o2?ooool1o`00007ooooo00001?l0003ooooooooooooo001d
ooooo`03ool00?oooooooooo08Kooooo5Ol00?l8ooooo`7o00000Oooool00004o`000?oooooooooo
ool007Gooooo00?oo`00ooooooooool0QOoooolEo`00o`Sooooo0Ol00001ooooo`0000?o0000oooo
oooo0000M_ooool00ooo003oooooooooo`25oooooaGo003o2?ooool1o`00007ooooo00000ol0003o
ooooool00006ooooo`;oogl0Koooool00ooo003oooooooooo`24oooooaGo003o2?ooool1o`00007o
oooo00000ol0003oooooool00005ooooo`Coogl04oooool2oomo05Wooooo00?oo`00ooooooooool0
Q?oooolEo`00o`Sooooo0Ol00001ooooo`0000?o0000ool00?ooool01Oooool4oomo01;ooooo1?oo
O`0Booooo`;oogl0A?ooool00ooo003oooooooooo`24oooooaGo003o2?ooool1o`00007ooooo0000
0ol0003oooooooooo`05ooooo`?oogl04oooool4oomo017ooooo1?ooO`14ooooo`03ool00?oooooo
oooo08?ooooo5Ol00?l8ooooo`7o00000Oooool00003o`000?oooooooooo00Cooooo1?ooO`0Doooo
o`;oogl04_ooool4oomo04Cooooo00?oo`00ooooooooool0PooooolEo`00o`Sooooo0Ol00001oooo
o`0000?o0000ooooooooool01?ooool4oomo02Wooooo0_ooO`15ooooo`03ool00?oooooooooo08?o
oooo5Ol00?l8ooooo`7o00000Oooool00003o`000?oooooooooo00Gooooo0_ooO`1FoooooaKo003o
1Oooool00ooo003oooooooooo`23oooooaGo003o2?ooool1o`00007ooooo00000ol0003ooooooooo
o`1Jooooo`?o003o5_ooool6o`00o`03ool00?oooooooooo08;ooooo5Ol00?l8ooooo`7o00000Ooo
ool00003o`000?oooooooooo05Oooooo0ol00?lOooooo`?o003oP_oooolEo`00o`Sooooo0Ol00001
ooooo`0000?o0000ooooooooool0E?ooool3o`00ob;ooooo00?oo`00ooooooooool00ol00?mooooo
oaGo003o2?ooool1o`00007ooooo00000ol0003oooooooooo`1Aooooo`?o003o9Oooool00ooo003o
ooooooooo`03ooooo`?o003oO?oooolEo`00o`Sooooo0Ol00001ooooo`0000?o0000ooooooooool0
Coooool20000obWooooo00?oo`00ooooooooool01Oooool3o`00ogWooooo5Ol00?l8ooooo`7o0000
0Oooool00003o`000?oooooooooo04gooooo0P000?l[ooooo`03ool00?oooooooooo00Sooooo0_l0
0?mgoooooaGo003o2?ooool1o`00007ooooo00000ol0003oooooooooo`1:ooooo`<0003o;Oooool0
0ooo003oooooooooo`0:ooooo`;o003oMOoooolEo`00o`Sooooo0Ol00001ooooo`0000?o0000oooo
ooooool0B?ooool20000oc3ooooo00?oo`00ooooooooool03?ooool00ol00?ooooooooooo`1boooo
oaGo003o2?ooool1o`00007ooooo00000ol0003oooooooooo`17ooooo`030000oooooooooooo033o
oooo00?oo`00ooooooooool03Oooool2o`00og;ooooo5Ol00?l8ooooo`7o00000Oooool00003o`00
0?oooooooooo04Gooooo0P000?ldooooo`03ool00?oooooooooo00kooooo0_l00?m`oooooaGo003o
2?ooool1o`00007ooooo00000ol0003oooooooooo`14ooooo`030000oooooooooooo03Cooooo00?o
o`00ooooooooool04?ooool2o`00ofkooooo5Ol00?l8ooooo`7o00000Oooool00003o`000?oooooo
oooo02Cooooo0_ooO`0:ooooo`;oogl04Oooool00`000?ooooooooooo`0eooooo`03ool00?oooooo
oooo01;ooooo00?o003oooooooooool0JooooolEo`00o`Sooooo0Ol00001ooooo`0000?o0000oooo
ooooool08oooool4oomo00Sooooo1?ooO`0?ooooo`030000oooooooooooo03Kooooo00?oo`00oooo
ooooool04oooool00ol00?ooooooooooo`1ZoooooaGo003o2?ooool1o`00007ooooo00000ol0003o
ooooooooo`0Sooooo`Coogl02?ooool4oomo00gooooo00<0003oo`00ooooool0>?ooool00ooo003o
ooooooooo`0Dooooo`03o`00oooooooooooo06Wooooo5Ol00?l8ooooo`7o00000Oooool00003o`00
0?oooooooooo02Cooooo0_ooO`0:ooooo`;oogl03Oooool00`000?ooooooooooo`0iooooo`03ool0
0?oooooooooo01Gooooo00?o003oooooooooool0J?oooolEo`00o`Sooooo0Ol00001ooooo`0000?o
0000ooooooooool0>Oooool4ool00003ooooo`000?oooooo03_ooooo00?oo`00ooooooooool05_oo
ool00ol00?ooooooooooo`1WoooooaGo003o2?ooool1o`00007ooooo00000ol0003oooooooooo`0h
ooooo`Koo`00?Oooool00ooo003oooooooooo`0Gooooo`03o`00oooooooooooo06Kooooo5Ol00?l8
ooooo`7o00000Oooool00003o`000?oooooooooo03Oooooo2?oo000@ooooo`;oogl01oooool2oomo
02;ooooo00?oo`00ooooooooool05oooool00ol00?ooooooooooo`1UoooooaGo003o2?ooool1o`00
007ooooo00000ol0003oooooooooo`0^ooooo`;oogl01oooool8ool000oooooo1?ooO`05ooooo`Co
ogl08Oooool00ooo003oooooooooo`0Hooooo`03o`00oooooooooooo06Cooooo5Ol00?l8ooooo`7o
00000Oooool00003o`000?oooooooooo02gooooo1?ooO`06ooooo`Soo`003oooool4oomo00Gooooo
1?ooO`0Qooooo`03ool00?oooooooooo01Wooooo00?o003oooooooooool0HooooolEo`00o`Sooooo
0Ol00001ooooo`0000?o0000ooooooooool0;Oooool4oomo00Kooooo2?oo000@ooooo`;oogl01ooo
ool3oomo027ooooo00?oo`00ooooooooool06_ooool00ol00?ooooooooooo`1RoooooaGo003o2?oo
ool1o`00007ooooo00000ol0003oooooooooo`0^ooooo`;oogl02?ooool6ool001[ooooo1?ooO`0P
ooooo`03ool00?oooooooooo01_ooooo00?o003oooooooooool0HOoooolEo`00o`Sooooo0Ol00001
ooooo`0000?o0000ooooooooool0>?ooool00`000?ooo`00ool00002ool001_ooooo1?ooO`0Poooo
o`03ool00?oooooooooo01cooooo00?o003oooooooooool0H?oooolEo`00o`Sooooo0Ol00001oooo
o`0000?o0000ooooooooool0=oooool00`000?ooooooooooo`0Iooooo`;oogl01?ooool2oomo027o
oooo00?oo`00ooooooooool07?ooool00ol00?ooooooooooo`1PoooooaGo003o2?ooool1o`00007o
oooo00000ol0003oooooooooo`0fooooo`030000oooooooooooo01Wooooo1?ooO`0Uooooo`03ool0
0?oooooooooo01kooooo00?o003oooooooooool0O?ooool1o`00007ooooo00000ol0003ooooooooo
o`0fooooo`030000oooooooooooo01Wooooo1?ooO`0Uooooo`03ool00?oooooooooo01oooooo00?o
003oooooooooool0Noooool1o`00007ooooo00000ol0003oooooooooo`0eooooo`040000oooooooo
ogl0oomo01[ooooo0_ooO`0Vooooo`03ool00?oooooooooo023ooooo00?o003oooooooooool0N_oo
ool1o`00007ooooo00000ol0003oooooooooo`0dooooo`030000ooooooooogl000?oogl0@Oooool0
0ooo003oooooooooo`0Qooooo`03o`00oooooooooooo07Wooooo0Ol00001ooooo`0000?o0000oooo
ooooool0:oooool2oomo00Kooooo00<0003oooooooooool01?ooO`11ooooo`03ool00?oooooooooo
027ooooo00?o003oooooooooool0NOooool1o`00007ooooo00000ol0003oooooooooo`0Zooooo`Co
ogl01?ooool00`000?ooooooooooo`02ooooo`;oogl06?ooool2oomo017ooooo0_ooO`0Eooooo`03
ool00?oooooooooo02;ooooo00?o003oooooooooool0N?ooool1o`00007ooooo00000ol0003ooooo
ooooo`0Zooooo`Coogl01?ooool00`000?ooooooooooo`0Kooooo`Coogl03oooool4oomo01Cooooo
00?oo`00ooooooooool08oooool00ol00?ooooooooooo`1gooooo`7o00000Oooool00003o`000?oo
oooooooo02_ooooo0_ooO`04ooooo`030000oooooooooooo01cooooo1?ooO`0?ooooo`Coogl05?oo
ool00ooo003oooooooooo`0Sooooo`03o`00oooooooooooo07Oooooo0Ol00001ooooo`0000?o0000
ooooooooool0<Oooool00`000?ooooooooooo`0Mooooo`;oogl04Oooool2oomo01Cooooo00?oo`00
ooooooooool09Oooool00ol00?ooooooooooo`1fooooo`7o00000Oooool00003o`000?oooooooooo
033ooooo00<0003oooooooooool0Aoooool00ooo003oooooooooo`0Uooooo`03o`00oooooooooooo
07Kooooo0Ol00001ooooo`0000?o0000ooooooooool0<?ooool00`000?ooooooooooo`17ooooo`03
ool00?oooooooooo02Kooooo00?o003oooooooooool0MOooool1o`00007ooooo00000ol0003ooooo
ooooo`0_ooooo`030000oooooooooooo04Sooooo00?oo`00ooooooooool09oooool00ol00?oooooo
ooooo`1dooooo`7o00000Oooool00003o`000?oooooooooo02oooooo00<0003oooooooooool01ooo
ool2oomo00;ooooo0_ooO`0kooooo`03ool00?oooooooooo02Oooooo00?o003oooooooooool0M?oo
ool1o`00007ooooo00000ol0003oooooooooo`0^ooooo`030000oooooooooooo00Oooooo2?ooO`0i
ooooo`03ool00?oooooooooo02Wooooo00?o003oooooooooool0Loooool1o`00007ooooo00000ol0
003oooooooooo`0^ooooo`030000oooooooooooo00Oooooo2?ooO`0iooooo`03ool00?oooooooooo
02Wooooo00?o003oooooooooool0Loooool1o`00007ooooo00000ol0003oooooooooo`0]ooooo`03
0000oooooooooooo00Wooooo1_ooO`0Pooooo`;oogl05oooool00ooo003oooooooooo`0[ooooo`03
o`00oooooooooooo07;ooooo0Ol00001ooooo`0000?o0000ooooooooool0;Oooool00`000?oooooo
ooooo`0;ooooo`Coogl07oooool4oomo01Kooooo00?oo`00ooooooooool0:oooool00ol00?oooooo
ooooo`1booooo`7o00000Oooool00003o`000?oo003ooooo02gooooo00<0003oooooooooool03?oo
ool2oomo023ooooo1?ooO`0Fooooo`03ool00?oooooooooo02_ooooo00?o003oooooooooool0L_oo
ool1o`00007ooooo00000ol0003oo`00ooooo`0/ooooo`030000oooooooooooo033ooooo0_ooO`0F
ooooo`03ool00?oooooooooo02gooooo00?o003oooooooooool0LOooool1o`00007ooooo00000ol0
003oo`00ooooo`0/ooooo`030000oooooooooooo04Sooooo00?oo`00ooooooooool0;Oooool00ol0
0?ooooooooooo`1aooooo`7o00000Oooool00003o`000?ooooooo`0002cooooo00<0003ooooooooo
ool0B?ooool00ooo003oooooooooo`0]ooooo`03o`00oooooooooooo077ooooo0Ol00001ooooo`00
00?o0000oooooooo0000:oooool00`000?ooooooooooo`18ooooo`03ool00?oooooooooo02oooooo
00?o003oooooooooool0L?ooool1o`00007ooooo00001?l0003ooooooooooooo000Zooooo`030000
oooooooooooo00?ooooo0_ooO`13ooooo`03ool00?oooooooooo02oooooo00?o003oooooooooool0
L?ooool1o`00007ooooo00001?l0003ooooooooooooo000Zooooo`030000oooooooooooo00;ooooo
1?ooO`12ooooo`03ool00?oooooooooo02oooooo00?o003oooooooooool0L?ooool1o`00007ooooo
00001Ol0003oooooooooooooooooo`0002Wooooo00<0003oooooooooool00_ooool4oomo047ooooo
00?oo`00ooooooooool0<?ooool00ol00?ooooooooooo`1`ooooo`7o00000Oooool00005o`000?oo
oooooooooooooooo0000:?ooool00`000?ooooooooooo`04ooooo`;oogl0@_ooool00ooo003ooooo
ooooo`0aooooo`03o`00oooooooooooo06oooooo0Ol00001ooooo`0000?o0000ooooooooool00_oo
ool00ooo003oooooooooo`0Uooooo`030000oooooooooooo04Oooooo00?oo`00ooooooooool0<_oo
ool00ol00?ooooooooooo`1_ooooo`7o00000Oooool00003o`000?oooooooooo00;ooooo00?oo`00
ooooooooool09Oooool00`000?ooooooooooo`17ooooo`03ool00?oooooooooo03;ooooo00?o003o
ooooooooool0Koooool1o`00007ooooo00000ol0003oooooooooo`03ooooo`03ool00?oooooooooo
02Cooooo00<0003oooooooooool0A_ooool00ooo003oooooooooo`0cooooo`03o`00oooooooooooo
06oooooo0Ol00001ooooo`0000?o0000ooooooooool01?ooool00ooo003oooooooooo`0Sooooo`03
0000oooooooooooo04Gooooo00?oo`00ooooooooool0=?ooool00ol00?ooooooooooo`1_ooooo`7o
00000Oooool00003o`000?oooooooooo00Gooooo00?oo`00ooooooooool08Oooool00`000?oooooo
ooooo`15ooooo`03ool00?oooooooooo03Kooooo00?o003oooooooooool0K_ooool1o`00007ooooo
00000ol0003oooooooooo`06ooooo`03ool00?oooooooooo023ooooo00<0003oooooooooool0AOoo
ool00ooo003oooooooooo`09ooooo`;oogl0:oooool00ol00?ooooooooooo`1^ooooo`7o00000Ooo
ool00003o`000?oooooooooo00Kooooo00?oo`00ooooooooool08?ooool00`000?ooooooooooo`14
ooooo`03ool00?oooooooooo00Wooooo1?ooO`0Zooooo`03o`00oooooooooooo06kooooo0Ol00001
ooooo`0000?o0000ooooooooool01oooool00ooo003oooooooooo`0Oooooo`030000oooooooooooo
02Sooooo0_ooO`0Iooooo`03ool00?oooooooooo00[ooooo1?ooO`0Zooooo`03o`00oooooooooooo
06kooooo0Ol00001ooooo`0000?o0000ooooooooool01oooool00ooo003oooooooooo`0Oooooo`03
0000oooooooooooo02Oooooo1?ooO`0Gooooo`03ool00?oooooooooo00cooooo0_ooO`0[ooooo`03
o`00oooooooooooo06kooooo0Ol00001ooooo`0000?o0000ooooooooool02?ooool00ooo003ooooo
ooooo`0Nooooo`030000oooooooooooo02Oooooo1?ooO`0Gooooo`03ool00?oooooooooo03Wooooo
00?o003oooooooooool0K_ooool1o`00007ooooo00000ol0003oooooooooo`09ooooo`03ool00?oo
oooooooo01gooooo00<0003oooooooooool0:?ooool2oomo01;ooooo1?l00?l00oooooooo`00oooo
o`0kooooo`03o`00oooooooooooo06kooooo0Ol00001ooooo`0000?o0000ooooooooool02_ooool0
0ooo003oooooooooo`0Looooo`030000oooooooooooo03_ooooo1_l00?lmooooo`03o`00oooooooo
oooo06kooooo0Ol00001ooooo`0000?o0000ooooooooool02oooool00ooo003oooooooooo`0Koooo
o`030000oooooooooooo03Oooooo0_ooO`000ooooooo003oo`00o`06o`00occooooo00?o003ooooo
ooooool0K_ooool1o`00007ooooo00000ol0003oooooooooo`0<ooooo`03ool00?oooooooooo01[o
oooo00<0003oooooooooool0=_ooool4oomo00So003o??ooool00ol00?ooooooooooo`1^ooooo`7o
00000Oooool00003o`000?oooooooooo00gooooo00?oo`00ooooooooool06Oooool00`000?oooooo
ooooo`0fooooo`Coogl02?l00?llooooo`03o`00oooooooooooo06kooooo0Ol00001ooooo`0000?o
0000ooooooooool03Oooool2ool001[ooooo00<0003oooooooooool0=oooool2oomo0003ooooool0
0?oo003o00Ko003o??ooool00ol00?ooooooooooo`1^ooooo`7o00000Oooool00003o`000?oooooo
oooo00oooooo00?oo`00ooooooooool05oooool00`000?ooooooooooo`0jooooo`03ool00?l00?oo
003o00Co003o?Oooool00ol00?ooooooooooo`1^ooooo`7o00000Oooool00003o`000?oooooooooo
013ooooo00?oo`00ooooooooool05_ooool00`000?ooooooooooo`0iooooo`03ool00?oooooooooo
00Co003o?_ooool00ol00?ooooooooooo`1^ooooo`7o00000Oooool00003o`000?oooooooooo017o
oooo00?oo`00ooooooooool05Oooool00`000?ooooooooooo`0hooooo`03ool00?oooooooooo04?o
oooo00?o003oooooooooool0K_ooool1o`00007ooooo00000ol0003oooooooooo`0Booooo`03ool0
0?oooooooooo01Cooooo00<0003oooooooooool0=_ooool2ool004Kooooo00?o003oooooooooool0
K_ooool1o`00007ooooo00000ol0003oooooooooo`0Cooooo`03ool00?oooooooooo01?ooooo00<0
003oooooooooool0=Oooool00ooo003oooooooooo`16ooooo`03o`00oooooooooooo06kooooo0Ol0
0001ooooo`0000?o0000ooooooooool05?ooool2ool001?ooooo00<0003oooooooooool0=?ooool0
0ooo003oooooooooo`17ooooo`03o`00oooooooooooo06kooooo0Ol00001ooooo`0000?o0000oooo
ooooool05_ooool2ool0017ooooo00<0003oooooooooool0<_ooool2ool004[ooooo00?o003ooooo
ooooool0K_ooool1o`00007ooooo00000ol0003oooooooooo`0Hooooo`03ool00?oooooooooo00ko
oooo00<0003oooooooooool0<Oooool00ooo003oooooooooo`1:ooooo`03o`00oooooooooooo06ko
oooo0Ol00001ooooo`0000?o0000ooooooooool06Oooool2ool000kooooo00<0003oooooooooool0
;oooool2ool004gooooo00?o003oooooooooool0K_ooool1o`00007ooooo00000ol0003ooooooooo
o`0Kooooo`03ool00?oooooooooo00_ooooo00<0003oooooooooool0;_ooool00ooo003ooooooooo
o`1<ooooo`03o`00oooooooooooo06oooooo0Ol00001ooooo`0000?o0000ooooooooool07?ooool2
ool000_ooooo00<0003oooooooooool0;Oooool00ooo003oooooooooo`1=ooooo`03o`00oooooooo
oooo06oooooo0Ol00001ooooo`0000?o0000ooooooooool07_ooool3ool000Wooooo00<0003ooooo
ooooool0:_ooool2ool0053ooooo00?o003oooooooooool0Koooool1o`00007ooooo00000ol0003o
ooooooooo`0Qooooo`;oo`001oooool00`000?ooooooooooo`0Wooooo`?oo`00D_ooool00ol00?oo
ooooooooo`1_ooooo`7o00000Oooool00003o`000?oooooooooo02?ooooo0_oo0005ooooo`030000
oooooooooooo02Gooooo0_oo001Dooooo`03o`00oooooooooooo073ooooo0Ol00001ooooo`0000?o
0000ooooooooool09Oooool4ool00003ooooo`000?oooooo02;ooooo1?oo001Fooooo`03o`00oooo
oooooooo073ooooo0Ol00001ooooo`0000?o0000ooooooooool0:Oooool2ool00003o`00oooo003o
o`0001gooooo0ooo001Jooooo`03o`00oooooooooooo073ooooo0Ol00001ooooo`0000?o0000oooo
ooooool0:oooool00`000?ooooooooooo`03ool001Cooooo1_oo001Mooooo`03o`00oooooooooooo
073ooooo0Ol00001ooooo`0000?o0000ooooooooool0;?ooool00`000?ooooooooooo`02oooooaCo
o`00H_ooool00ol00?ooooooooooo`1aooooo`7o00000Oooool00003o`000?oooooooooo02cooooo
00<0003oooooooooool0N?ooool00ol00?ooooooooooo`1aooooo`7o00000Oooool00003o`000?oo
oooooooo02cooooo00<0003oooooooooool0N?ooool00ol00?ooooooooooo`1aooooo`7o00000Ooo
ool00003o`000?oooooooooo02gooooo00<0003oooooooooool0M_ooool00ol00?ooooooooooo`1b
ooooo`7o00000Oooool00003o`000?oooooooooo02gooooo00<0003oooooooooool0M_ooool00ol0
0?ooooooooooo`1booooo`7o00000Oooool00003o`000?oooooooooo02gooooo00<0003ooooooooo
ool0M_ooool00ol00?ooooooooooo`1booooo`7o00000Oooool00003o`000?oooooooooo02kooooo
00<0003oooooooooool0M?ooool00ol00?ooooooooooo`1cooooo`7o00000Oooool00003o`000?oo
oooooooo02kooooo00<0003oooooooooool0M?ooool00ol00?ooooooooooo`1cooooo`7o00000Ooo
ool00003o`000?oooooooooo02kooooo00<0003oooooooooool0M?ooool00ol00?ooooooooooo`1c
ooooo`7o00000Oooool00003o`000?oooooooooo02oooooo00<0003oooooooooool0L_ooool00ol0
0?ooooooooooo`1dooooo`7o00000Oooool00003o`000?oooooooooo02oooooo00<0003ooooooooo
ool0L_ooool00ol00?ooooooooooo`1dooooo`7o00000Oooool00003o`000?oooooooooo02oooooo
00<0003oooooooooool0L_ooool00ol00?ooooooooooo`1dooooo`7o00000Oooool00003o`000?oo
oooooooo033ooooo00<0003oooooooooool0Koooool2o`00ogOooooo0Ol00001ooooo`0000?o0000
ooooooooool0<?ooool00`000?ooooooooooo`1_ooooo`03o`00oooooooooooo07Kooooo0Ol00001
ooooo`0000?o0000ooooooooool0<Oooool00`000?ooooooooooo`1]ooooo`03o`00oooooooooooo
07Oooooo0Ol00001ooooo`0000?o0000ooooooooool0<_ooool00`000?ooooooooooo`1/ooooo`03
o`00oooooooooooo07Oooooo0Ol00001ooooo`0000?o0000ooooooooool0<_ooool00`000?oooooo
ooooo`1[ooooo`03o`00oooooooooooo063ooooo0_ooO`0Fooooo`7o00000Oooool00003o`000?oo
oooooooo03?ooooo00<0003oooooooooool0JOooool00ol00?ooooooooooo`1Pooooo`Coogl05Ooo
ool1o`00007ooooo00000ol0003oooooooooo`0dooooo`030000oooooooooooo06Sooooo00?o003o
ooooooooool0H?ooool4oomo01Gooooo0Ol00001ooooo`0000?o0000ooooooooool0=Oooool00`00
0?ooooooooooo`1Vooooo`03o`00oooooooooooo06;ooooo0_ooO`0Fooooo`7o00000Oooool00003
o`000?oooooooooo03Gooooo00?o003oooooooooool0I_ooool00ol00?ooooooooooo`1jooooo`7o
00000Oooool00003o`000?oooooooooo03Kooooo00?o003oooooooooool0I?ooool00ol00?oooooo
ooooo`1kooooo`7o00000Oooool00003o`000?oooooooooo03Oooooo00?o003oooooooooool0H_oo
ool00ol00?ooooooooooo`1looooo`7o00000Oooool00003o`000?oooooooooo03Sooooo00?o003o
ooooooooool0Goooool2o`00ogoooooo0Ol00001ooooo`0000?o0000ooooooooool0>Oooool00ol0
0?ooooooooooo`1Mooooo`03o`00oooooooooooo07oooooo0Ol00001ooooo`0000?o0000oooooooo
ool0>_ooool00ol00?ooooooooooo`1Kooooo`03o`00oooooooooooo083ooooo0Ol00001ooooo`00
00?o0000ooooooooool0>oooool00ol00?ooooooooooo`1Iooooo`03o`00oooooooooooo087ooooo
0Ol00001ooooo`0000?o0000ooooooooool0??ooool00ol00?ooooooooooo`1Gooooo`03o`00oooo
oooooooo08;ooooo0Ol00001ooooo`0000?o0000ooooooooool0?Oooool00ol00?ooooooooooo`1E
ooooo`03o`00oooooooooooo08?ooooo0Ol00001ooooo`0000?o0000ooooooooool0?_ooool00ol0
0?ooooooooooo`1Cooooo`03o`00oooooooooooo08Cooooo0Ol00001ooooo`0000?o0000oooooooo
ool0?oooool00ol00?ooooooooooo`1@ooooo`;o003o8Oooool2oomo06Cooooo0Ol00001ooooo`00
00?o0000ooooooooool0@?ooool00ol00?ooooooooooo`1>ooooo`03o`00oooooooooooo023ooooo
1?ooO`1Sooooo`7o00000Oooool00003o`000?oooooooooo047ooooo0_l00?m=ooooo`03o`00oooo
oooooooo027ooooo1?ooO`1Sooooo`7o00000Oooool00003o`000?oooooooooo04?ooooo00?o003o
ooooooooool0BOooool00ol00?ooooooooooo`0Sooooo`;oogl0=Oooool2oomo02gooooo0Ol00001
ooooo`0000?o0000ooooooooool0A?ooool2o`00odSooooo00?o003oooooooooool0Doooool2oomo
00Gooooo1?ooO`0/ooooo`7o00000Oooool00003o`000?oooooooooo04Kooooo0_l00?m5ooooo`03
o`00oooooooooooo05?ooooo1?ooO`04ooooo`Coogl0;?ooool1o`00007ooooo00000ol0003ooooo
ooooo`18ooooo`03o`00oooooooooooo043ooooo0_l00?lfooooo`;oogl07_ooool4oomo00Gooooo
0_ooO`0]ooooo`7o00000Oooool00003o`000?oooooooooo04Wooooo0_l00?lnooooo`;o003o=ooo
ool4oomo01kooooo0_ooO`0eooooo`7o00000Oooool00003o`000?oooooooooo04_ooooo0ol00?lj
ooooo`03o`00oooooooooooo03Oooooo1?ooO`1Eooooo`7o00000Oooool00003o`000?oooooooooo
04kooooo0_l00?lfooooo`;o003o>oooool2oomo05Kooooo0Ol00001ooooo`0000?o0000oooooooo
ool0D?ooool3o`00oc3ooooo0ol00?lcooooo`;oogl000?oooooool0oooo0?l00ooo0?lOooooo`;o
ogl0>Oooool1o`00007ooooo00000ol0003oooooooooo`1Cooooo`;o003o:_ooool4o`00ocGooooo
0oooO`07ool0oagooooo1?ooO`0hooooo`7o00000Oooool00003o`000?oooooooooo05Gooooo0ol0
0?lSooooo`Co003o=Oooool2oomo00;ooooo0_ooO`09ool0oacooooo1?ooO`03ooooo`;oogl0<ooo
ool1o`00007ooooo00000ol0003oooooooooo`1Hooooo`?o003o7Oooool3o`00ocSooooo1?ooO`02
ooooo`_oo`3o2_ooool2oomo013ooooo0_ooO`03ooooo`Coogl0<_ooool1o`00007ooooo00000ol0
003oooooooooo`1Kooooo`?o003o5?ooool6o`00oc_ooooo1?ooO`02ooooo`_oo`3o2Oooool4oomo
01Cooooo1?ooO`0booooo`7o00000Oooool00003o`000?oooooooooo05kooooo5?l00?m2ooooo`;o
ogl00oooool;ool0o`Wooooo1?ooO`0Eooooo`;oogl0<oooool1o`00007ooooo00000ol0003ooooo
ooooo`2;ooooo`;oogl09oooool2oomo00?ooooo2ooo0?l:ooooo`;oogl0Boooool1o`00007ooooo
00000ol0003oooooooooo`2:ooooo`Coogl09Oooool4oomo00;ooooo2ooo0?mGooooo`7o00000Ooo
ool00003o`000?oooooooooo08[ooooo1?ooO`0Uooooo`Coogl00oooool9ool0oeSooooo0Ol00001
ooooo`0000?o0000ooooooooool0Roooool2oomo02Oooooo0_ooO`05ooooo`Ooo`3oFOooool1o`00
007ooooo00000ol0003oooooooooo`2Fooooo`;oogl09?ooool5ool0oa7ooooo0_ooO`17ooooo`7o
00000Oooool00003o`000?oooooooooo09Gooooo1?ooO`0>ooooo`;oogl0:?ooool4oomo04Kooooo
0Ol00001ooooo`0000?o0000ooooooooool0UOooool4oomo00gooooo1?ooO`0Wooooo`Coogl0A_oo
ool1o`00007ooooo00000ol0003oooooooooo`2Fooooo`;oogl03_ooool4oomo02Sooooo0_ooO`17
ooooo`7o00000Oooool00003o`000?oooooooooo0:Oooooo0_ooO`1booooo`7o00000Oooool00003
o`000?oooooooooo0>_ooooo0_ooO`0^ooooo`7o00000Oooool00003o`000?oooooooooo0>[ooooo
1?ooO`0]ooooo`7o00000Oooool00003o`000?oooooooooo0=Kooooo0_ooO`0Booooo`Coogl0;Ooo
ool1o`00007ooooo00000ol0003oooooooooo`3Eooooo`Coogl04_ooool2oomo02kooooo0Ol00001
ooooo`0000?o0000ooooooooool0]oooool2oomo01cooooo1?ooO`12ooooo`7o00000Oooool00003
o`000?oooooooooo0;Kooooo1?ooO`0Looooo`;oogl0@oooool1o`00007ooooo00000ol0003ooooo
ooooo`2cooooo`;oogl000?ooooooomo0?ooO`000_ooO`1Qooooo`7o00000Oooool00003o`000?oo
oooooooo0:Sooooo0_ooO`08ooooo`Coogl000?ooooooomo0?ooO`006_ooool2oomo04Kooooo0Ol0
0001ooooo`0000?o0000ooooooooool0Y_ooool5oomo00Oooooo1?ooO`0Gooooo`;oogl00oooool4
oomo04Gooooo0Ol00001ooooo`0000?o0000ooooooooool0YOooool6oomo00Sooooo0_ooO`0Goooo
o`Coogl00_ooool4oomo04Gooooo0Ol00001ooooo`0000?o0000ooooooooool0YOooool5oomo02;o
oooo1?ooO`03ooooo`;oogl0A_ooool1o`00007ooooo00000ol0003oooooooooo`1fooooo`;oogl0
;_ooool2oomo02Gooooo0_ooO`1<ooooo`7o00000Oooool00003o`000?oooooooooo07Gooooo1?oo
O`2Rooooo`7o00000Oooool00003o`000?oooooooooo07Gooooo1?ooO`0:ooooo`;oogl0U_ooool1
o`00007ooooo00000ol0003oooooooooo`1fooooo`;oogl02_ooool4oomo02[ooooo0_ooO`1Yoooo
o`7o00000Oooool00003o`000?oooooooooo08;ooooo1?ooO`0Yooooo`Coogl0J?ooool1o`00007o
oooo00000ol0003oooooooooo`23ooooo`;oogl09?ooool2oomo00Cooooo1?ooO`1Xooooo`7o0000
0Oooool00003o`000?oooooooooo0:Sooooo1?ooO`04ooooo`;oogl0JOooool1o`00007ooooo0000
0ol0003oooooooooo`2Xooooo`Coogl0Koooool1o`00007ooooo00000ol0003oooooooooo`2Yoooo
o`;oogl0L?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`00
00?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?oo
ool1o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000oooo
ooooool0Q?ooool2oomo09Gooooo0Ol00001ooooo`0000?o0000ooooooooool0Poooool4oomo09Co
oooo0Ol00001ooooo`0000?o0000ooooooooool0Poooool4oomo09Cooooo0Ol00001ooooo`0000?o
0000ooooooooool0Q?ooool2oomo02cooooo0_ooO`1Wooooo`7o00000Oooool00003o`000?oooooo
oooo0;7ooooo1?ooO`1Vooooo`7o00000Oooool00003o`000?oooooooooo0;7ooooo1?ooO`1Voooo
o`7o00000Oooool00003o`000?oooooooooo0;;ooooo0_ooO`1Wooooo`7o00000Oooool00003o`00
0?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol0
0001ooooo`0000?o0000ooooooooool0Noooool2oomo09kooooo0Ol00001ooooo`0000?o0000oooo
ooooool0N_ooool4oomo09gooooo0Ol00001ooooo`0000?o0000ooooooooool0N_ooool4oomo023o
oooo0_ooO`1kooooo`7o00000Oooool00003o`000?oooooooooo07_ooooo0_ooO`0Pooooo`Coogl0
N_ooool1o`00007ooooo00000ol0003oooooooooo`2Mooooo`Coogl0N_ooool1o`00007ooooo0000
0ol0003oooooooooo`2@ooooo`;oogl03?ooool2oomo07_ooooo0Ol00001ooooo`0000?o0000oooo
ooooool0Soooool4oomo08Sooooo0Ol00001ooooo`0000?o0000ooooooooool0Soooool4oomo08So
oooo0Ol00001ooooo`0000?o0000ooooooooool0T?ooool2oomo02?ooooo0_ooO`1Tooooo`7o0000
0Oooool00003o`000?oooooooooo0;Cooooo1?ooO`1Sooooo`7o00000Oooool00003o`000?oooooo
oooo0;Cooooo1?ooO`1Sooooo`7o00000Oooool00003o`000?oooooooooo0;Gooooo0_ooO`1Toooo
o`7o00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003ooooo
ooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Ooo
ool00003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooo
oacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`00
0?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol0
0001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo
0?oooooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`00
00?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?oo
ool1o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000oooo
ooooool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007o
oooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooo
oolLooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0
003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o
00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003ooooooooo
o`3ooooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool0
0003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooooaco
oooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oo
oooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001
ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo0?oo
oooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o
0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1
o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000oooooooo
ool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo
00000ol0003oooooooooo`2>ooooo`;oogl0Roooool1o`00007ooooo00000ol0003oooooooooo`2=
ooooo`Coogl0R_ooool1o`00007ooooo00000ol0003oooooooooo`2=ooooo`Coogl0R_ooool1o`00
007ooooo00000ol0003oooooooooo`2>ooooo`;oogl0Roooool1o`00007ooooo00000ol0003ooooo
ooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Ooo
ool00003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooo
oacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`00
0?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol0
0001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo
0?oooooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`00
00?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?oo
ool1o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000oooo
ooooool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007o
oooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooo
oolLooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0
003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o
00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo003oo`00023o00000Ooo
ool00001\
\>"],
  ImageRangeCache->{{{0, 287}, {287, 0}} -> {-1.01089, -1.01089, 0.00704453, \
0.00704453}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.49505 0.5 0.49505 [
[ 0 0 -0.125 0 ]
[ 0 0 -0.125 0 ]
[ 0 1 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
0 0 m
1 0 L
s
0 0 m
0 1 L
s
0 1 m
1 1 L
s
1 0 m
1 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
1 .5 0 r
.015 w
.03175 .1355 Mdot
.03435 .12523 Mdot
.11137 .12765 Mdot
.14107 .18841 Mdot
.16218 .24538 Mdot
.17294 .21053 Mdot
.18267 .18577 Mdot
.18434 .1304 Mdot
.18553 .30956 Mdot
.20401 .239 Mdot
.21247 .27571 Mdot
.21687 .20845 Mdot
.22376 .2799 Mdot
.22832 .27485 Mdot
.29063 .20974 Mdot
.29686 .25079 Mdot
.30487 .22936 Mdot
.30683 .34623 Mdot
.32055 .20902 Mdot
.32574 .21979 Mdot
.34472 .28521 Mdot
.35998 .36393 Mdot
.36335 .24976 Mdot
.3794 .36608 Mdot
.42386 .66992 Mdot
.44391 .74519 Mdot
.45059 .34198 Mdot
.47208 .67586 Mdot
.47436 .71381 Mdot
.49778 .59825 Mdot
.50874 .91643 Mdot
.51516 .76219 Mdot
.53655 .61374 Mdot
.56563 .75219 Mdot
.59189 .65665 Mdot
.59581 .61604 Mdot
.59923 .6556 Mdot
.60292 .68499 Mdot
.62656 .67779 Mdot
.63555 .72451 Mdot
.63919 .652 Mdot
.64169 .6004 Mdot
.64246 .58611 Mdot
.64496 .54267 Mdot
.64608 .77288 Mdot
.65077 .64308 Mdot
.66065 .57816 Mdot
.67474 .59169 Mdot
.69296 .563 Mdot
.72815 .65902 Mdot
.73169 .58879 Mdot
.74669 .61318 Mdot
.74821 .65474 Mdot
.75963 .63781 Mdot
.79673 .57809 Mdot
.80925 .55852 Mdot
.81525 .58444 Mdot
.83417 .62985 Mdot
.83598 .55526 Mdot
.91595 .49319 Mdot
1 0 0 r
.005 w
.00495 .28842 m
.00628 .29156 L
.01857 .31761 L
.03101 .33781 L
.03525 .34367 L
.05706 .36884 L
.05795 .36972 L
.08312 .39115 L
.08963 .39578 L
.10917 .40763 L
.13523 .41964 L
.14074 .42183 L
.16128 .42794 L
.18734 .43294 L
.21339 .43485 L
.23945 .43375 L
.2655 .42959 L
.29156 .42219 L
.29261 .42183 L
.31761 .41124 L
.34367 .39603 L
.34405 .39578 L
.36972 .37551 L
.37582 .36972 L
.39578 .34724 L
.39849 .34367 L
.41525 .31761 L
.42183 .30485 L
.4275 .29156 L
.436 .2655 L
.44117 .23945 L
.44325 .21339 L
.44232 .18734 L
.43834 .16128 L
.43114 .13523 L
.42183 .11212 L
.42037 .10917 L
.40546 .08312 L
.39578 .06961 L
.38528 .05706 L
.36972 .04137 L
.35758 .03101 L
.34367 .02092 L
.31761 .00569 L
.3162 .00495 L
s
.00495 .12854 m
.01344 .10917 L
.02832 .08312 L
.03101 .07912 L
.04848 .05706 L
.05706 .04802 L
.07619 .03101 L
.08312 .02579 L
.10917 .00934 L
.11742 .00495 L
s
0 0 1 r
.29156 .15739 m
.31761 .14824 L
.34367 .14249 L
.36972 .13986 L
.39578 .14025 L
.42183 .14366 L
.44789 .15025 L
.47394 .16034 L
.47599 .16128 L
.5 .17443 L
.51844 .18734 L
.52606 .19355 L
.54662 .21339 L
.55211 .21962 L
.56712 .23945 L
.57817 .25755 L
.58227 .2655 L
.59322 .29156 L
.60058 .31761 L
.60422 .3392 L
.60471 .34367 L
.6058 .36972 L
.60422 .39297 L
.60387 .39578 L
.59886 .42183 L
.59054 .44789 L
.57848 .47394 L
.57817 .47453 L
.562 .5 L
.55211 .51255 L
.53968 .52606 L
.52606 .53862 L
.50853 .55211 L
.5 .55773 L
.47394 .57183 L
.45901 .57817 L
.44789 .5819 L
.42183 .5885 L
.39578 .59192 L
.36972 .59231 L
.34367 .58968 L
.31761 .58392 L
.29972 .57817 L
.29156 .57477 L
.2655 .56178 L
.25025 .55211 L
.23945 .54409 L
.21914 .52606 L
.21339 .52008 L
.19681 .5 L
Mistroke
.18734 .48608 L
.18031 .47394 L
.16827 .44789 L
.16128 .42714 L
.15996 .42183 L
.15493 .39578 L
.153 .36972 L
.15409 .34367 L
.15823 .31761 L
.16128 .3045 L
.16559 .29156 L
.17653 .2655 L
.18734 .24609 L
.19169 .23945 L
.21221 .21339 L
.21339 .21211 L
.23945 .1881 L
.24041 .18734 L
.2655 .17038 L
.28271 .16128 L
.29156 .15739 L
Mfstroke
1 0 0 r
.03 w
.21687 .20845 Mdot
0 0 1 r
.3794 .36608 Mdot
1 0 0 r
.79703 .00495 m
.79703 .03196 L
.87129 .03196 L
.87129 .00495 L
F
0 0 1 r
.89604 .00495 m
.89604 .22546 L
.9703 .22546 L
.9703 .00495 L
F
1 0 1 r
.04 w
.69296 .563 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P000182000`400?l00000o`00003ooooooolQ
ooooo`00ool0000Po`00007ooooo00000ol0003oooooooooo`0Mooooo`;oo`00>?ooool3ool00<7o
oooo0Ol00001ooooo`0000?o0000ooooooooool06oooool2ool003gooooo00?oo`00ooooooooool0
Q?oooolEool000Sooooo5Ol00?l8ooooo`7o00000Oooool00003o`000?oooooooooo01[ooooo00?o
o`00ooooooooool0?_ooool2ool008Cooooo5Ooo0008oooooaGo003o2?ooool1o`00007ooooo0000
0ol0003oooooooooo`0Hooooo`;oo`00@oooool00ooo003oooooooooo`21oooooaGoo`002?oooolE
o`00o`Sooooo0Ol00001ooooo`0000?o0000ooooooooool05_ooool2ool004Kooooo00?oo`00oooo
ooooool0P?oooolEool000Sooooo5Ol00?l8ooooo`7o00000Oooool00003o`000?oooooooooo01Go
oooo00?oo`00ooooooooool0Aoooool2ool0083ooooo5Ooo0008oooooaGo003o2?ooool1o`00007o
oooo00000ol0003oooooooooo`0Dooooo`03ool00?oooooooooo04[ooooo00?oo`00ooooooooool0
OOoooolEool000Sooooo5Ol00?l8ooooo`7o00000Oooool00003o`000?oooooooooo01?ooooo00?o
o`00ooooooooool0C?ooool00ooo003oooooooooo`1loooooaGoo`002?oooolEo`00o`Sooooo0Ol0
0001ooooo`0000?o0000ooooooooool04Oooool2ool0053ooooo0_oo001loooooaGoo`002?oooolE
o`00o`Sooooo0Ol00001ooooo`0000?o0000ooooooooool04?ooool00ooo003oooooooooo`1Boooo
o`;oo`00UooooolEo`00o`Sooooo0Ol00001ooooo`0000?o0000ooooooooool03oooool00ooo003o
ooooooooo`1Eooooo`03ool00?oooooooooo09Cooooo5Ol00?l8ooooo`7o00000Oooool00003o`00
0?oooooooooo00kooooo00?oo`00ooooooooool0E_ooool00ooo003oooooooooo`2DoooooaGo003o
2?ooool1o`00007ooooo00000ol0003oooooooooo`0=ooooo`03ool00?oooooooooo05Sooooo00?o
o`00ooooooooool0TooooolEo`00o`Sooooo0Ol00001ooooo`0000?o0000ooooooooool03Oooool0
0ooo003oooooooooo`1Iooooo`03ool00?oooooooooo09;ooooo5Ol00?l8ooooo`7o00000Oooool0
0003o`000?oooooooooo00cooooo00?oo`00ooooooooool0Foooool00ooo003oooooooooo`2Aoooo
oaGo003o2?ooool1o`00007ooooo00000ol0003oooooooooo`0;ooooo`03ool00?oooooooooo05go
oooo00?oo`00ooooooooool0T?oooolEo`00o`Sooooo0Ol00001ooooo`0000?o0000ooooooooool0
2oooool00ooo003oooooooooo`1Mooooo`03ool00?oooooooooo093ooooo5Ol00?l8ooooo`7o0000
0Oooool00003o`000?oooooooooo00[ooooo00?oo`00ooooooooool0Goooool00ooo003ooooooooo
o`2?oooooaGo003o2?ooool1o`00007ooooo00000ol0003oooooooooo`09ooooo`03ool00?oooooo
oooo067ooooo00?oo`00ooooooooool0S_oooolEo`00o`Sooooo0Ol00001ooooo`0000?o0000oooo
ooooool02?ooool00ooo003oooooooooo`1Sooooo`03ool00?oooooooooo08gooooo5Ol00?l8oooo
o`7o00000Oooool00003o`000?oooooooooo00Oooooo00?oo`00ooooooooool0IOooool00ooo003o
ooooooooo`2<oooooaGo003o2?ooool1o`00007ooooo00000ol0003oooooooooo`06ooooo`03ool0
0?oooooooooo06Oooooo00?oo`00ooooooooool0RooooolEo`00o`Sooooo0Ol00001ooooo`0000?o
0000ooooooooool01Oooool00ooo003oooooooooo`1Yooooo`03ool00?oooooooooo08[ooooo5Ol0
0?l8ooooo`7o00000Oooool00003o`000?oooooooooo00Gooooo00?oo`00ooooooooool0JOooool0
0ooo003oooooooooo`2:oooooaGo003o2?ooool1o`00007ooooo00000ol0003oooooooooo`04oooo
o`03ool00?oooooooooo06_ooooo00?oo`00ooooooooool0ROoooolEo`00o`Sooooo0Ol00001oooo
o`0000?o0000ooooooooool00oooool00ooo003oooooooooo`1/ooooo`03ool00?oooooooooo08Wo
oooo5Ol00?l8ooooo`7o00000Oooool00003o`000?oooooooooo00?ooooo00?oo`00ooooooooool0
KOooool00ooo003oooooooooo`28oooooaGo003o2?ooool1o`00007ooooo00000ol0003ooooooooo
o`02ooooo`03ool00?oooooooooo06kooooo00?oo`00ooooooooool0R?oooolEo`00o`Sooooo0Ol0
0001ooooo`0000?o0000ooooooooool00_ooool00ooo003oooooooooo`1_ooooo`03ool00?oooooo
oooo08Oooooo5Ol00?l8ooooo`7o00000Oooool00005o`000?oooooooooooooooooo0000L_ooool0
0ooo003oooooooooo`27oooooaGo003o2?ooool1o`00007ooooo00001?l0003ooooooooooooo001d
ooooo`03ool00?oooooooooo08Kooooo5Ol00?l8ooooo`7o00000Oooool00004o`000?oooooooooo
ool007Gooooo00?oo`00ooooooooool0QOoooolEo`00o`Sooooo0Ol00001ooooo`0000?o0000oooo
oooo0000M_ooool00ooo003oooooooooo`25oooooaGo003o2?ooool1o`00007ooooo00000ol0003o
ooooool00006ooooo`;oogl0Koooool00ooo003oooooooooo`24oooooaGo003o2?ooool1o`00007o
oooo00000ol0003oooooool00005ooooo`Coogl04oooool2oomo05Wooooo00?oo`00ooooooooool0
Q?oooolEo`00o`Sooooo0Ol00001ooooo`0000?o0000ool00?ooool01Oooool4oomo01;ooooo1?oo
O`0Booooo`;oogl0A?ooool00ooo003oooooooooo`24oooooaGo003o2?ooool1o`00007ooooo0000
0ol0003oooooooooo`05ooooo`?oogl04oooool4oomo017ooooo1?ooO`14ooooo`03ool00?oooooo
oooo08?ooooo5Ol00?l8ooooo`7o00000Oooool00003o`000?oooooooooo00Cooooo1?ooO`0Doooo
o`;oogl04_ooool4oomo04Cooooo00?oo`00ooooooooool0PooooolEo`00o`Sooooo0Ol00001oooo
o`0000?o0000ooooooooool01?ooool4oomo02Wooooo0_ooO`15ooooo`03ool00?oooooooooo08?o
oooo5Ol00?l8ooooo`7o00000Oooool00003o`000?oooooooooo00Gooooo0_ooO`1FoooooaKo003o
1Oooool00ooo003oooooooooo`23oooooaGo003o2?ooool1o`00007ooooo00000ol0003ooooooooo
o`1Jooooo`?o003o5_ooool6o`00o`03ool00?oooooooooo08;ooooo5Ol00?l8ooooo`7o00000Ooo
ool00003o`000?oooooooooo05Oooooo0ol00?lOooooo`?o003oP_oooolEo`00o`Sooooo0Ol00001
ooooo`0000?o0000ooooooooool0E?ooool3o`00ob;ooooo00?oo`00ooooooooool00ol00?mooooo
oaGo003o2?ooool1o`00007ooooo00000ol0003oooooooooo`1Aooooo`?o003o9Oooool00ooo003o
ooooooooo`03ooooo`?o003oO?oooolEo`00o`Sooooo0Ol00001ooooo`0000?o0000ooooooooool0
Coooool20000obWooooo00?oo`00ooooooooool01Oooool3o`00ogWooooo5Ol00?l8ooooo`7o0000
0Oooool00003o`000?oooooooooo04gooooo0P000?l[ooooo`03ool00?oooooooooo00Sooooo0_l0
0?mgoooooaGo003o2?ooool1o`00007ooooo00000ol0003oooooooooo`1:ooooo`<0003o;Oooool0
0ooo003oooooooooo`0:ooooo`;o003oMOoooolEo`00o`Sooooo0Ol00001ooooo`0000?o0000oooo
ooooool0B?ooool20000oc3ooooo00?oo`00ooooooooool03?ooool00ol00?ooooooooooo`1boooo
oaGo003o2?ooool1o`00007ooooo00000ol0003oooooooooo`17ooooo`030000oooooooooooo033o
oooo00?oo`00ooooooooool03Oooool2o`00og;ooooo5Ol00?l8ooooo`7o00000Oooool00003o`00
0?oooooooooo04Gooooo0P000?ldooooo`03ool00?oooooooooo00kooooo0_l00?m`oooooaGo003o
2?ooool1o`00007ooooo00000ol0003oooooooooo`14ooooo`030000oooooooooooo03Cooooo00?o
o`00ooooooooool04?ooool2o`00ofkooooo5Ol00?l8ooooo`7o00000Oooool00003o`000?oooooo
oooo02Cooooo0_ooO`0:ooooo`;oogl04Oooool00`000?ooooooooooo`0eooooo`03ool00?oooooo
oooo01;ooooo00?o003oooooooooool0JooooolEo`00o`Sooooo0Ol00001ooooo`0000?o0000oooo
ooooool08oooool4oomo00Sooooo1?ooO`0?ooooo`030000oooooooooooo03Kooooo00?oo`00oooo
ooooool04oooool00ol00?ooooooooooo`1ZoooooaGo003o2?ooool1o`00007ooooo00000ol0003o
ooooooooo`0Sooooo`Coogl02?ooool4oomo00gooooo00<0003oo`00ooooool0>?ooool00ooo003o
ooooooooo`0Dooooo`03o`00oooooooooooo06Wooooo5Ol00?l8ooooo`7o00000Oooool00003o`00
0?oooooooooo02Cooooo0_ooO`0:ooooo`;oogl03Oooool00`000?ooooooooooo`0iooooo`03ool0
0?oooooooooo01Gooooo00?o003oooooooooool0J?oooolEo`00o`Sooooo0Ol00001ooooo`0000?o
0000ooooooooool0>Oooool4ool00003ooooo`000?oooooo03_ooooo00?oo`00ooooooooool05_oo
ool00ol00?ooooooooooo`1WoooooaGo003o2?ooool1o`00007ooooo00000ol0003oooooooooo`0h
ooooo`Koo`00?Oooool00ooo003oooooooooo`0Gooooo`03o`00oooooooooooo06Kooooo5Ol00?l8
ooooo`7o00000Oooool00003o`000?oooooooooo03Oooooo2?oo000@ooooo`;oogl01oooool2oomo
02;ooooo00?oo`00ooooooooool05oooool00ol00?ooooooooooo`1UoooooaGo003o2?ooool1o`00
007ooooo00000ol0003oooooooooo`0^ooooo`;oogl01oooool8ool000oooooo1?ooO`05ooooo`Co
ogl08Oooool00ooo003oooooooooo`0Hooooo`03o`00oooooooooooo06Cooooo5Ol00?l8ooooo`7o
00000Oooool00003o`000?oooooooooo02gooooo1?ooO`06ooooo`Soo`003oooool4oomo00Gooooo
1?ooO`0Qooooo`03ool00?oooooooooo01Wooooo00?o003oooooooooool0HooooolEo`00o`Sooooo
0Ol00001ooooo`0000?o0000ooooooooool0;Oooool4oomo00Kooooo2?oo000@ooooo`;oogl01ooo
ool3oomo027ooooo00?oo`00ooooooooool06_ooool00ol00?ooooooooooo`1RoooooaGo003o2?oo
ool1o`00007ooooo00000ol0003oooooooooo`0^ooooo`;oogl02?ooool6ool001[ooooo1?ooO`0P
ooooo`03ool00?oooooooooo01_ooooo00?o003oooooooooool0HOoooolEo`00o`Sooooo0Ol00001
ooooo`0000?o0000ooooooooool0>?ooool00`000?ooo`00ool00002ool001_ooooo1?ooO`0Poooo
o`03ool00?oooooooooo01cooooo00?o003oooooooooool0H?oooolEo`00o`Sooooo0Ol00001oooo
o`0000?o0000ooooooooool0=oooool00`000?ooooooooooo`0Iooooo`;oogl01?ooool2oomo027o
oooo00?oo`00ooooooooool07?ooool00ol00?ooooooooooo`1PoooooaGo003o2?ooool1o`00007o
oooo00000ol0003oooooooooo`0fooooo`030000oooooooooooo01Wooooo1?ooO`0Uooooo`03ool0
0?oooooooooo01kooooo00?o003oooooooooool0O?ooool1o`00007ooooo00000ol0003ooooooooo
o`0fooooo`030000oooooooooooo01Wooooo1?ooO`0Uooooo`03ool00?oooooooooo01oooooo00?o
003oooooooooool0Noooool1o`00007ooooo00000ol0003oooooooooo`0eooooo`040000oooooooo
ogl0oomo01[ooooo0_ooO`0Vooooo`03ool00?oooooooooo023ooooo00?o003oooooooooool0N_oo
ool1o`00007ooooo00000ol0003oooooooooo`0dooooo`030000ooooooooogl000?oogl0@Oooool0
0ooo003oooooooooo`0Qooooo`03o`00oooooooooooo07Wooooo0Ol00001ooooo`0000?o0000oooo
ooooool0:oooool2oomo00Kooooo00<0003oooooooooool01?ooO`11ooooo`03ool00?oooooooooo
027ooooo00?o003oooooooooool0NOooool1o`00007ooooo00000ol0003oooooooooo`0Zooooo`Co
ogl01?ooool00`000?ooooooooooo`02ooooo`;oogl06?ooool2oomo017ooooo0_ooO`0Eooooo`03
ool00?oooooooooo02;ooooo00?o003oooooooooool0N?ooool1o`00007ooooo00000ol0003ooooo
ooooo`0Zooooo`Coogl01?ooool00`000?ooooooooooo`0Kooooo`Coogl03oooool4oomo01Cooooo
00?oo`00ooooooooool08oooool00ol00?ooooooooooo`1gooooo`7o00000Oooool00003o`000?oo
oooooooo02_ooooo0_ooO`04ooooo`030000oooooooooooo01cooooo1?ooO`0?ooooo`Coogl05?oo
ool00ooo003oooooooooo`0Sooooo`03o`00oooooooooooo07Oooooo0Ol00001ooooo`0000?o0000
ooooooooool0<Oooool00`000?ooooooooooo`0Mooooo`;oogl04Oooool2oomo01Cooooo00?oo`00
ooooooooool09Oooool00ol00?ooooooooooo`1fooooo`7o00000Oooool00003o`000?oooooooooo
033ooooo00<0003oooooooooool0Aoooool00ooo003oooooooooo`0Uooooo`03o`00oooooooooooo
07Kooooo0Ol00001ooooo`0000?o0000ooooooooool0<?ooool00`000?ooooooooooo`17ooooo`03
ool00?oooooooooo02Kooooo00?o003oooooooooool0MOooool1o`00007ooooo00000ol0003ooooo
ooooo`0_ooooo`030000oooooooooooo04Sooooo00?oo`00ooooooooool09oooool00ol00?oooooo
ooooo`1dooooo`7o00000Oooool00003o`000?oooooooooo02oooooo00<0003oooooooooool01ooo
ool2oomo00;ooooo0_ooO`0kooooo`03ool00?oooooooooo02Oooooo00?o003oooooooooool0M?oo
ool1o`00007ooooo00000ol0003oooooooooo`0^ooooo`030000oooooooooooo00Oooooo2?ooO`0i
ooooo`03ool00?oooooooooo02Wooooo00?o003oooooooooool0Loooool1o`00007ooooo00000ol0
003oooooooooo`0^ooooo`030000oooooooooooo00Oooooo2?ooO`0iooooo`03ool00?oooooooooo
02Wooooo00?o003oooooooooool0Loooool1o`00007ooooo00000ol0003oooooooooo`0]ooooo`03
0000oooooooooooo00Wooooo1_ooO`0Pooooo`;oogl05oooool00ooo003oooooooooo`0[ooooo`03
o`00oooooooooooo07;ooooo0Ol00001ooooo`0000?o0000ooooooooool0;Oooool00`000?oooooo
ooooo`0;ooooo`Coogl07oooool4oomo01Kooooo00?oo`00ooooooooool0:oooool00ol00?oooooo
ooooo`1booooo`7o00000Oooool00003o`000?oo003ooooo02gooooo00<0003oooooooooool03?oo
ool2oomo023ooooo1?ooO`0Fooooo`03ool00?oooooooooo02_ooooo00?o003oooooooooool0L_oo
ool1o`00007ooooo00000ol0003oo`00ooooo`0/ooooo`030000oooooooooooo033ooooo0_ooO`0F
ooooo`03ool00?oooooooooo02gooooo00?o003oooooooooool0LOooool1o`00007ooooo00000ol0
003oo`00ooooo`0/ooooo`030000oooooooooooo04Sooooo00?oo`00ooooooooool0;Oooool00ol0
0?ooooooooooo`1aooooo`7o00000Oooool00003o`000?ooooooo`0002cooooo00<0003ooooooooo
ool0B?ooool00ooo003oooooooooo`0]ooooo`03o`00oooooooooooo077ooooo0Ol00001ooooo`00
00?o0000oooooooo0000:oooool00`000?ooooooooooo`18ooooo`03ool00?oooooooooo02oooooo
00?o003oooooooooool0L?ooool1o`00007ooooo00001?l0003ooooooooooooo000Zooooo`030000
oooooooooooo00?ooooo0_ooO`13ooooo`03ool00?oooooooooo02oooooo00?o003oooooooooool0
L?ooool1o`00007ooooo00001?l0003ooooooooooooo000Zooooo`030000oooooooooooo00;ooooo
1?ooO`12ooooo`03ool00?oooooooooo02oooooo00?o003oooooooooool0L?ooool1o`00007ooooo
00001Ol0003oooooooooooooooooo`0002Wooooo00<0003oooooooooool00_ooool4oomo047ooooo
00?oo`00ooooooooool0<?ooool00ol00?ooooooooooo`1`ooooo`7o00000Oooool00005o`000?oo
oooooooooooooooo0000:?ooool00`000?ooooooooooo`04ooooo`;oogl0@_ooool00ooo003ooooo
ooooo`0aooooo`03o`00oooooooooooo06oooooo0Ol00001ooooo`0000?o0000ooooooooool00_oo
ool00ooo003oooooooooo`0Uooooo`030000oooooooooooo04Oooooo00?oo`00ooooooooool0<_oo
ool00ol00?ooooooooooo`1_ooooo`7o00000Oooool00003o`000?oooooooooo00;ooooo00?oo`00
ooooooooool09Oooool00`000?ooooooooooo`17ooooo`03ool00?oooooooooo03;ooooo00?o003o
ooooooooool0Koooool1o`00007ooooo00000ol0003oooooooooo`03ooooo`03ool00?oooooooooo
02Cooooo00<0003oooooooooool0A_ooool00ooo003oooooooooo`0cooooo`03o`00oooooooooooo
06oooooo0Ol00001ooooo`0000?o0000ooooooooool01?ooool00ooo003oooooooooo`0Sooooo`03
0000oooooooooooo04Gooooo00?oo`00ooooooooool0=?ooool00ol00?ooooooooooo`1_ooooo`7o
00000Oooool00003o`000?oooooooooo00Gooooo00?oo`00ooooooooool08Oooool00`000?oooooo
ooooo`15ooooo`03ool00?oooooooooo03Kooooo00?o003oooooooooool0K_ooool1o`00007ooooo
00000ol0003oooooooooo`06ooooo`03ool00?oooooooooo023ooooo00<0003oooooooooool0AOoo
ool00ooo003oooooooooo`09ooooo`;oogl0:oooool00ol00?ooooooooooo`1^ooooo`7o00000Ooo
ool00003o`000?oooooooooo00Kooooo00?oo`00ooooooooool08?ooool00`000?ooooooooooo`14
ooooo`03ool00?oooooooooo00Wooooo1?ooO`0Zooooo`03o`00oooooooooooo06kooooo0Ol00001
ooooo`0000?o0000ooooooooool01oooool00ooo003oooooooooo`0Oooooo`030000oooooooooooo
02Sooooo0_ooO`0Iooooo`03ool00?oooooooooo00[ooooo1?ooO`0Zooooo`03o`00oooooooooooo
06kooooo0Ol00001ooooo`0000?o0000ooooooooool01oooool00ooo003oooooooooo`0Oooooo`03
0000oooooooooooo02Oooooo1?ooO`0Gooooo`03ool00?oooooooooo00cooooo0_ooO`0[ooooo`03
o`00oooooooooooo06kooooo0Ol00001ooooo`0000?o0000ooooooooool02?ooool00ooo003ooooo
ooooo`0Nooooo`030000oooooooooooo02Oooooo1?ooO`0Gooooo`03ool00?oooooooooo03Wooooo
00?o003oooooooooool0K_ooool1o`00007ooooo00000ol0003oooooooooo`09ooooo`03ool00?oo
oooooooo01gooooo00<0003oooooooooool0:?ooool2oomo01;ooooo1?l00?l00oooooooo`00oooo
o`0kooooo`03o`00oooooooooooo06kooooo0Ol00001ooooo`0000?o0000ooooooooool02_ooool0
0ooo003oooooooooo`0Looooo`030000oooooooooooo03_ooooo1_l00?lmooooo`03o`00oooooooo
oooo06kooooo0Ol00001ooooo`0000?o0000ooooooooool02oooool00ooo003oooooooooo`0Koooo
o`030000oooooooooooo03Oooooo0_ooO`000ooooooo003oo`00o`06o`00occooooo00?o003ooooo
ooooool0K_ooool1o`00007ooooo00000ol0003oooooooooo`0<ooooo`03ool00?oooooooooo01[o
oooo00<0003oooooooooool0=_ooool4oomo00So003o??ooool00ol00?ooooooooooo`1^ooooo`7o
00000Oooool00003o`000?oooooooooo00gooooo00?oo`00ooooooooool06Oooool00`000?oooooo
ooooo`0fooooo`Coogl02?l00?llooooo`03o`00oooooooooooo06kooooo0Ol00001ooooo`0000?o
0000ooooooooool03Oooool2ool001[ooooo00<0003oooooooooool0=oooool2oomo0003ooooool0
0?oo003o00Ko003o??ooool00ol00?ooooooooooo`1^ooooo`7o00000Oooool00003o`000?oooooo
oooo00oooooo00?oo`00ooooooooool05oooool00`000?ooooooooooo`0jooooo`03ool00?l00?oo
003o00Co003o?Oooool00ol00?ooooooooooo`1^ooooo`7o00000Oooool00003o`000?oooooooooo
013ooooo00?oo`00ooooooooool05_ooool00`000?ooooooooooo`0iooooo`03ool00?oooooooooo
00Co003o?_ooool00ol00?ooooooooooo`1^ooooo`7o00000Oooool00003o`000?oooooooooo017o
oooo00?oo`00ooooooooool05Oooool00`000?ooooooooooo`0hooooo`03ool00?oooooooooo04?o
oooo00?o003oooooooooool0K_ooool1o`00007ooooo00000ol0003oooooooooo`0Booooo`03ool0
0?oooooooooo01Cooooo00<0003oooooooooool0=_ooool2ool004Kooooo00?o003oooooooooool0
K_ooool1o`00007ooooo00000ol0003oooooooooo`0Cooooo`03ool00?oooooooooo01?ooooo00<0
003oooooooooool0=Oooool00ooo003oooooooooo`16ooooo`03o`00oooooooooooo06kooooo0Ol0
0001ooooo`0000?o0000ooooooooool05?ooool2ool001?ooooo00<0003oooooooooool0=?ooool0
0ooo003oooooooooo`17ooooo`03o`00oooooooooooo06kooooo0Ol00001ooooo`0000?o0000oooo
ooooool05_ooool2ool0017ooooo00<0003oooooooooool0<_ooool2ool004[ooooo00?o003ooooo
ooooool0K_ooool1o`00007ooooo00000ol0003oooooooooo`0Hooooo`03ool00?oooooooooo00ko
oooo00<0003oooooooooool0<Oooool00ooo003oooooooooo`1:ooooo`03o`00oooooooooooo06ko
oooo0Ol00001ooooo`0000?o0000ooooooooool06Oooool2ool000kooooo00<0003oooooooooool0
;oooool2ool004gooooo00?o003oooooooooool0K_ooool1o`00007ooooo00000ol0003ooooooooo
o`0Kooooo`03ool00?oooooooooo00_ooooo00<0003oooooooooool0;_ooool00ooo003ooooooooo
o`1<ooooo`03o`00oooooooooooo06oooooo0Ol00001ooooo`0000?o0000ooooooooool07?ooool2
ool000_ooooo00<0003oooooooooool0;Oooool00ooo003oooooooooo`1=ooooo`03o`00oooooooo
oooo06oooooo0Ol00001ooooo`0000?o0000ooooooooool07_ooool3ool000Wooooo00<0003ooooo
ooooool0:_ooool2ool0053ooooo00?o003oooooooooool0Koooool1o`00007ooooo00000ol0003o
ooooooooo`0Qooooo`;oo`001oooool00`000?ooooooooooo`0Wooooo`?oo`00D_ooool00ol00?oo
ooooooooo`1_ooooo`7o00000Oooool00003o`000?oooooooooo02?ooooo0_oo0005ooooo`030000
oooooooooooo02Gooooo0_oo001Dooooo`03o`00oooooooooooo073ooooo0Ol00001ooooo`0000?o
0000ooooooooool09Oooool4ool00003ooooo`000?oooooo02;ooooo1?oo001Fooooo`03o`00oooo
oooooooo073ooooo0Ol00001ooooo`0000?o0000ooooooooool0:Oooool2ool00003o`00oooo003o
o`0001gooooo0ooo001Jooooo`03o`00oooooooooooo073ooooo0Ol00001ooooo`0000?o0000oooo
ooooool0:oooool00`000?ooooooooooo`03ool001Cooooo1_oo001Mooooo`03o`00oooooooooooo
073ooooo0Ol00001ooooo`0000?o0000ooooooooool0;?ooool00`000?ooooooooooo`02oooooaCo
o`00H_ooool00ol00?ooooooooooo`1aooooo`7o00000Oooool00003o`000?oooooooooo02cooooo
00<0003oooooooooool0N?ooool00ol00?ooooooooooo`1aooooo`7o00000Oooool00003o`000?oo
oooooooo02cooooo00<0003oooooooooool0N?ooool00ol00?ooooooooooo`1aooooo`7o00000Ooo
ool00003o`000?oooooooooo02gooooo00<0003oooooooooool0M_ooool00ol00?ooooooooooo`1b
ooooo`7o00000Oooool00003o`000?oooooooooo02gooooo00<0003oooooooooool0M_ooool00ol0
0?ooooooooooo`1booooo`7o00000Oooool00003o`000?oooooooooo02gooooo00<0003ooooooooo
ool0M_ooool00ol00?ooooooooooo`1booooo`7o00000Oooool00003o`000?oooooooooo02kooooo
00<0003oooooooooool0M?ooool00ol00?ooooooooooo`1cooooo`7o00000Oooool00003o`000?oo
oooooooo02kooooo00<0003oooooooooool0M?ooool00ol00?ooooooooooo`1cooooo`7o00000Ooo
ool00003o`000?oooooooooo02kooooo00<0003oooooooooool0M?ooool00ol00?ooooooooooo`1c
ooooo`7o00000Oooool00003o`000?oooooooooo02oooooo00<0003oooooooooool0L_ooool00ol0
0?ooooooooooo`1dooooo`7o00000Oooool00003o`000?oooooooooo02oooooo00<0003ooooooooo
ool0L_ooool00ol00?ooooooooooo`1dooooo`7o00000Oooool00003o`000?oooooooooo02oooooo
00<0003oooooooooool0L_ooool00ol00?ooooooooooo`1dooooo`7o00000Oooool00003o`000?oo
oooooooo033ooooo00<0003oooooooooool0Koooool2o`00ogOooooo0Ol00001ooooo`0000?o0000
ooooooooool0<?ooool00`000?ooooooooooo`1_ooooo`03o`00oooooooooooo07Kooooo0Ol00001
ooooo`0000?o0000ooooooooool0<Oooool00`000?ooooooooooo`1]ooooo`03o`00oooooooooooo
07Oooooo0Ol00001ooooo`0000?o0000ooooooooool0<_ooool00`000?ooooooooooo`1/ooooo`03
o`00oooooooooooo07Oooooo0Ol00001ooooo`0000?o0000ooooooooool0<_ooool00`000?oooooo
ooooo`1[ooooo`03o`00oooooooooooo063ooooo0_ooO`0Fooooo`7o00000Oooool00003o`000?oo
oooooooo03?ooooo00<0003oooooooooool0JOooool00ol00?ooooooooooo`1Pooooo`Coogl05Ooo
ool1o`00007ooooo00000ol0003oooooooooo`0dooooo`030000oooooooooooo06Sooooo00?o003o
ooooooooool0H?ooool4oomo01Gooooo0Ol00001ooooo`0000?o0000ooooooooool0=Oooool00`00
0?ooooooooooo`1Vooooo`03o`00oooooooooooo06;ooooo0_ooO`0Fooooo`7o00000Oooool00003
o`000?oooooooooo03Gooooo00?o003oooooooooool0I_ooool00ol00?ooooooooooo`1jooooo`7o
00000Oooool00003o`000?oooooooooo03Kooooo00?o003oooooooooool0I?ooool00ol00?oooooo
ooooo`1kooooo`7o00000Oooool00003o`000?oooooooooo03Oooooo00?o003oooooooooool0H_oo
ool00ol00?ooooooooooo`1looooo`7o00000Oooool00003o`000?oooooooooo03Sooooo00?o003o
ooooooooool0Goooool2o`00ogoooooo0Ol00001ooooo`0000?o0000ooooooooool0>Oooool00ol0
0?ooooooooooo`1Mooooo`03o`00oooooooooooo07oooooo0Ol00001ooooo`0000?o0000oooooooo
ool0>_ooool00ol00?ooooooooooo`1Kooooo`03o`00oooooooooooo083ooooo0Ol00001ooooo`00
00?o0000ooooooooool0>oooool00ol00?ooooooooooo`1Iooooo`03o`00oooooooooooo087ooooo
0Ol00001ooooo`0000?o0000ooooooooool0??ooool00ol00?ooooooooooo`1Gooooo`03o`00oooo
oooooooo08;ooooo0Ol00001ooooo`0000?o0000ooooooooool0?Oooool00ol00?ooooooooooo`1E
ooooo`03o`00oooooooooooo08?ooooo0Ol00001ooooo`0000?o0000ooooooooool0?_ooool00ol0
0?ooooooooooo`1Cooooo`03o`00oooooooooooo08Cooooo0Ol00001ooooo`0000?o0000oooooooo
ool0?oooool00ol00?ooooooooooo`1@ooooo`;o003o8Oooool2oomo06Cooooo0Ol00001ooooo`00
00?o0000ooooooooool0@?ooool00ol00?ooooooooooo`1>ooooo`03o`00oooooooooooo023ooooo
1?ooO`1Sooooo`7o00000Oooool00003o`000?oooooooooo047ooooo0_l00?m=ooooo`03o`00oooo
oooooooo027ooooo1?ooO`09ooooo`Goo`3oEOooool1o`00007ooooo00000ol0003oooooooooo`13
ooooo`03o`00oooooooooooo04Wooooo00?o003oooooooooool08oooool2oomo00Wooooo1ooo0?lU
ooooo`;oogl0;Oooool1o`00007ooooo00000ol0003oooooooooo`14ooooo`;o003oB?ooool00ol0
0?ooooooooooo`0^ooooo`Woo`3o7?ooool2oomo00Gooooo1?ooO`0/ooooo`7o00000Oooool00003
o`000?oooooooooo04Kooooo0_l00?m5ooooo`03o`00oooooooooooo02kooooo2ooo0?lJooooo`Co
ogl01?ooool4oomo02cooooo0Ol00001ooooo`0000?o0000ooooooooool0B?ooool00ol00?oooooo
ooooo`10ooooo`;o003o<Oooool;ool0oa[ooooo1?ooO`05ooooo`;oogl0;Oooool1o`00007ooooo
00000ol0003oooooooooo`19ooooo`;o003o?_ooool2o`00oc?ooooo2ooo0?lKooooo`;oogl0=Ooo
ool1o`00007ooooo00000ol0003oooooooooo`1;ooooo`?o003o>_ooool00ol00?ooooooooooo`0c
ooooo`_oo`3oD_ooool1o`00007ooooo00000ol0003oooooooooo`1>ooooo`;o003o=_ooool2o`00
ocKooooo2ooo0?mBooooo`7o00000Oooool00003o`000?oooooooooo053ooooo0ol00?l`ooooo`?o
003o<oooool2oomo00Cooooo2Ooo0?lHooooo`;oogl0>Oooool1o`00007ooooo00000ol0003ooooo
ooooo`1Cooooo`;o003o:_ooool4o`00ocGooooo1?ooO`04ooooo`Ooo`3o6?ooool4oomo03Sooooo
0Ol00001ooooo`0000?o0000ooooooooool0EOooool3o`00ob?ooooo1?l00?leooooo`;oogl00_oo
ool4oomo00Gooooo1Ooo0?lIooooo`Coogl00oooool2oomo03?ooooo0Ol00001ooooo`0000?o0000
ooooooooool0F?ooool3o`00oagooooo0ol00?lhooooo`Coogl00_ooool2oomo01?ooooo0_ooO`0@
ooooo`;oogl00oooool4oomo03;ooooo0Ol00001ooooo`0000?o0000ooooooooool0Foooool3o`00
oaCooooo1_l00?lkooooo`Coogl01_ooool2oomo00kooooo1?ooO`0Dooooo`Coogl0<_ooool1o`00
007ooooo00000ol0003oooooooooo`1NoooooaCo003o@_ooool2oomo00Kooooo1?ooO`0=ooooo`Co
ogl05Oooool2oomo03?ooooo0Ol00001ooooo`0000?o0000ooooooooool0Roooool2oomo02Oooooo
0_ooO`06ooooo`Coogl03_ooool2oomo04_ooooo0Ol00001ooooo`0000?o0000ooooooooool0R_oo
ool4oomo02Gooooo1?ooO`06ooooo`;oogl0G?ooool1o`00007ooooo00000ol0003oooooooooo`2:
ooooo`Coogl09Oooool4oomo06Cooooo0Ol00001ooooo`0000?o0000ooooooooool0Roooool2oomo
02Oooooo0_ooO`1Uooooo`7o00000Oooool00003o`000?oooooooooo09Kooooo0_ooO`0jooooo`;o
ogl0Aoooool1o`00007ooooo00000ol0003oooooooooo`2Eooooo`Coogl03_ooool2oomo02Sooooo
1?ooO`16ooooo`7o00000Oooool00003o`000?oooooooooo09Gooooo1?ooO`0=ooooo`Coogl09ooo
ool4oomo04Kooooo0Ol00001ooooo`0000?o0000ooooooooool0U_ooool2oomo00kooooo1?ooO`0X
ooooo`;oogl0Aoooool1o`00007ooooo00000ol0003oooooooooo`2Wooooo`;oogl0L_ooool1o`00
007ooooo00000ol0003oooooooooo`3[ooooo`;oogl0;_ooool1o`00007ooooo00000ol0003ooooo
ooooo`3Zooooo`Coogl0;Oooool1o`00007ooooo00000ol0003oooooooooo`3Fooooo`;oogl04_oo
ool4oomo02gooooo0Ol00001ooooo`0000?o0000ooooooooool0eOooool4oomo01;ooooo0_ooO`0^
ooooo`7o00000Oooool00003o`000?oooooooooo0;Oooooo0_ooO`0Looooo`Coogl0@_ooool1o`00
007ooooo00000ol0003oooooooooo`2fooooo`Coogl07?ooool2oomo04?ooooo0Ol00001ooooo`00
00?o0000ooooooooool0/oooool2oomo0003ooooooooO`3oogl000;oogl0HOooool1o`00007ooooo
00000ol0003oooooooooo`2Xooooo`;oogl02?ooool4oomo0003ooooooooO`3oogl001[ooooo0_oo
O`16ooooo`7o00000Oooool00003o`000?oooooooooo0:Kooooo1OooO`07ooooo`Coogl05oooool2
oomo00?ooooo1?ooO`15ooooo`7o00000Oooool00003o`000?oooooooooo0:Gooooo1_ooO`08oooo
o`;oogl05oooool4oomo00;ooooo1?ooO`15ooooo`7o00000Oooool00003o`000?oooooooooo0:Go
oooo1OooO`0Rooooo`Coogl00oooool2oomo04Kooooo0Ol00001ooooo`0000?o0000ooooooooool0
M_ooool2oomo02kooooo0_ooO`0Uooooo`;oogl0C?ooool1o`00007ooooo00000ol0003ooooooooo
o`1eooooo`Coogl0X_ooool1o`00007ooooo00000ol0003oooooooooo`1eooooo`Coogl02_ooool2
oomo09Kooooo0Ol00001ooooo`0000?o0000ooooooooool0M_ooool2oomo00[ooooo1?ooO`0Zoooo
o`;oogl0JOooool1o`00007ooooo00000ol0003oooooooooo`22ooooo`Coogl0:Oooool4oomo06So
oooo0Ol00001ooooo`0000?o0000ooooooooool0Poooool2oomo02Cooooo0_ooO`04ooooo`Coogl0
J?ooool1o`00007ooooo00000ol0003oooooooooo`2Xooooo`Coogl01?ooool2oomo06Wooooo0Ol0
0001ooooo`0000?o0000ooooooooool0Z?ooool4oomo06oooooo0Ol00001ooooo`0000?o0000oooo
ooooool0ZOooool2oomo073ooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o
00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003ooooooooo
o`3ooooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool0
0003o`000?oooooooooo08Cooooo0_ooO`2Eooooo`7o00000Oooool00003o`000?oooooooooo08?o
oooo1?ooO`2Dooooo`7o00000Oooool00003o`000?oooooooooo08?ooooo1?ooO`2Dooooo`7o0000
0Oooool00003o`000?oooooooooo08Cooooo0_ooO`0/ooooo`;oogl0Ioooool1o`00007ooooo0000
0ol0003oooooooooo`2aooooo`Coogl0I_ooool1o`00007ooooo00000ol0003oooooooooo`2aoooo
o`Coogl0I_ooool1o`00007ooooo00000ol0003oooooooooo`2booooo`;oogl0Ioooool1o`00007o
oooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooo
oolLooooo`7o00000Oooool00003o`000?oooooooooo07_ooooo0_ooO`2Nooooo`7o00000Oooool0
0003o`000?oooooooooo07[ooooo1?ooO`2Mooooo`7o00000Oooool00003o`000?oooooooooo07[o
oooo1?ooO`0Pooooo`;oogl0Noooool1o`00007ooooo00000ol0003oooooooooo`1kooooo`;oogl0
8?ooool4oomo07[ooooo0Ol00001ooooo`0000?o0000ooooooooool0WOooool4oomo07[ooooo0Ol0
0001ooooo`0000?o0000ooooooooool0T?ooool2oomo00cooooo0_ooO`1kooooo`7o00000Oooool0
0003o`000?oooooooooo08oooooo1?ooO`28ooooo`7o00000Oooool00003o`000?oooooooooo08oo
oooo1?ooO`28ooooo`7o00000Oooool00003o`000?oooooooooo093ooooo0_ooO`0Sooooo`;oogl0
I?ooool1o`00007ooooo00000ol0003oooooooooo`2dooooo`Coogl0Hoooool1o`00007ooooo0000
0ol0003oooooooooo`2dooooo`Coogl0Hoooool1o`00007ooooo00000ol0003oooooooooo`2eoooo
o`;oogl0I?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`00
00?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?oo
ool1o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000oooo
ooooool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007o
oooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooo
oolLooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0
003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o
00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003ooooooooo
o`3ooooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool0
0003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooooaco
oooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oo
oooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001
ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo0?oo
oooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o
0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1
o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000oooooooo
ool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo
00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolL
ooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003o
ooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o0000
0Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3o
oooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003
o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo
0Ol00001ooooo`0000?o0000ooooooooool0S_ooool2oomo08_ooooo0Ol00001ooooo`0000?o0000
ooooooooool0SOooool4oomo08[ooooo0Ol00001ooooo`0000?o0000ooooooooool0SOooool4oomo
08[ooooo0Ol00001ooooo`0000?o0000ooooooooool0S_ooool2oomo08_ooooo0Ol00001ooooo`00
00?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?oo
ool1o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000oooo
ooooool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007o
oooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooo
oolLooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0
003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o
00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003ooooooooo
o`3ooooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool0
0003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooooaco
oooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oo
oooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001
ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo0?oo
oooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`00ool0
000Po`00007ooooo0000\
\>"],
  ImageRangeCache->{{{0, 287}, {287, 0}} -> {-1.01089, -1.01089, 0.00704453, \
0.00704453}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.49505 0.5 0.49505 [
[ 0 0 -0.125 0 ]
[ 0 0 -0.125 0 ]
[ 0 1 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
0 0 m
1 0 L
s
0 0 m
0 1 L
s
0 1 m
1 1 L
s
1 0 m
1 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
1 .5 0 r
.015 w
.03175 .1355 Mdot
.03435 .12523 Mdot
.11137 .12765 Mdot
.14107 .18841 Mdot
.16218 .24538 Mdot
.17294 .21053 Mdot
.18267 .18577 Mdot
.18434 .1304 Mdot
.18553 .30956 Mdot
.20401 .239 Mdot
.21247 .27571 Mdot
.21687 .20845 Mdot
.22376 .2799 Mdot
.22832 .27485 Mdot
.29063 .20974 Mdot
.29686 .25079 Mdot
.30487 .22936 Mdot
.30683 .34623 Mdot
.32055 .20902 Mdot
.32574 .21979 Mdot
.34472 .28521 Mdot
.35998 .36393 Mdot
.36335 .24976 Mdot
.3794 .36608 Mdot
.42386 .66992 Mdot
.44391 .74519 Mdot
.45059 .34198 Mdot
.47208 .67586 Mdot
.47436 .71381 Mdot
.49778 .59825 Mdot
.50874 .91643 Mdot
.51516 .76219 Mdot
.53655 .61374 Mdot
.56563 .75219 Mdot
.59189 .65665 Mdot
.59581 .61604 Mdot
.59923 .6556 Mdot
.60292 .68499 Mdot
.62656 .67779 Mdot
.63555 .72451 Mdot
.63919 .652 Mdot
.64169 .6004 Mdot
.64246 .58611 Mdot
.64496 .54267 Mdot
.64608 .77288 Mdot
.65077 .64308 Mdot
.66065 .57816 Mdot
.67474 .59169 Mdot
.69296 .563 Mdot
.72815 .65902 Mdot
.73169 .58879 Mdot
.74669 .61318 Mdot
.74821 .65474 Mdot
.75963 .63781 Mdot
.79673 .57809 Mdot
.80925 .55852 Mdot
.81525 .58444 Mdot
.83417 .62985 Mdot
.83598 .55526 Mdot
.91595 .49319 Mdot
1 0 0 r
.005 w
.00495 .28842 m
.00628 .29156 L
.01857 .31761 L
.03101 .33781 L
.03525 .34367 L
.05706 .36884 L
.05795 .36972 L
.08312 .39115 L
.08963 .39578 L
.10917 .40763 L
.13523 .41964 L
.14074 .42183 L
.16128 .42794 L
.18734 .43294 L
.21339 .43485 L
.23945 .43375 L
.2655 .42959 L
.29156 .42219 L
.29261 .42183 L
.31761 .41124 L
.34367 .39603 L
.34405 .39578 L
.36972 .37551 L
.37582 .36972 L
.39578 .34724 L
.39849 .34367 L
.41525 .31761 L
.42183 .30485 L
.4275 .29156 L
.436 .2655 L
.44117 .23945 L
.44325 .21339 L
.44232 .18734 L
.43834 .16128 L
.43114 .13523 L
.42183 .11212 L
.42037 .10917 L
.40546 .08312 L
.39578 .06961 L
.38528 .05706 L
.36972 .04137 L
.35758 .03101 L
.34367 .02092 L
.31761 .00569 L
.3162 .00495 L
s
.00495 .12854 m
.01344 .10917 L
.02832 .08312 L
.03101 .07912 L
.04848 .05706 L
.05706 .04802 L
.07619 .03101 L
.08312 .02579 L
.10917 .00934 L
.11742 .00495 L
s
0 0 1 r
.29156 .15739 m
.31761 .14824 L
.34367 .14249 L
.36972 .13986 L
.39578 .14025 L
.42183 .14366 L
.44789 .15025 L
.47394 .16034 L
.47599 .16128 L
.5 .17443 L
.51844 .18734 L
.52606 .19355 L
.54662 .21339 L
.55211 .21962 L
.56712 .23945 L
.57817 .25755 L
.58227 .2655 L
.59322 .29156 L
.60058 .31761 L
.60422 .3392 L
.60471 .34367 L
.6058 .36972 L
.60422 .39297 L
.60387 .39578 L
.59886 .42183 L
.59054 .44789 L
.57848 .47394 L
.57817 .47453 L
.562 .5 L
.55211 .51255 L
.53968 .52606 L
.52606 .53862 L
.50853 .55211 L
.5 .55773 L
.47394 .57183 L
.45901 .57817 L
.44789 .5819 L
.42183 .5885 L
.39578 .59192 L
.36972 .59231 L
.34367 .58968 L
.31761 .58392 L
.29972 .57817 L
.29156 .57477 L
.2655 .56178 L
.25025 .55211 L
.23945 .54409 L
.21914 .52606 L
.21339 .52008 L
.19681 .5 L
Mistroke
.18734 .48608 L
.18031 .47394 L
.16827 .44789 L
.16128 .42714 L
.15996 .42183 L
.15493 .39578 L
.153 .36972 L
.15409 .34367 L
.15823 .31761 L
.16128 .3045 L
.16559 .29156 L
.17653 .2655 L
.18734 .24609 L
.19169 .23945 L
.21221 .21339 L
.21339 .21211 L
.23945 .1881 L
.24041 .18734 L
.2655 .17038 L
.28271 .16128 L
.29156 .15739 L
Mfstroke
1 0 0 r
.03 w
.21687 .20845 Mdot
0 0 1 r
.3794 .36608 Mdot
1 0 0 r
.79703 .00495 m
.79703 .02362 L
.87129 .02362 L
.87129 .00495 L
F
0 0 1 r
.89604 .00495 m
.89604 .23381 L
.9703 .23381 L
.9703 .00495 L
F
1 0 1 r
.04 w
.72815 .65902 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P000182000`400?l00000o`00003ooooooolQ
ooooo`00ool0000Po`00007ooooo00000ol0003oooooooooo`0Mooooo`;oo`00>?ooool3ool00<7o
oooo0Ol00001ooooo`0000?o0000ooooooooool06oooool2ool003gooooo00?oo`00ooooooooool0
Q?oooolEool000Sooooo5Ol00?l8ooooo`7o00000Oooool00003o`000?oooooooooo01[ooooo00?o
o`00ooooooooool0?_ooool2ool008Cooooo5Ooo0008oooooaGo003o2?ooool1o`00007ooooo0000
0ol0003oooooooooo`0Hooooo`;oo`00@oooool00ooo003oooooooooo`21oooooaGoo`002?oooolE
o`00o`Sooooo0Ol00001ooooo`0000?o0000ooooooooool05_ooool2ool004Kooooo00?oo`00oooo
ooooool0P?oooolEool000Sooooo5Ol00?l8ooooo`7o00000Oooool00003o`000?oooooooooo01Go
oooo00?oo`00ooooooooool0Aoooool2ool0083ooooo5Ooo0008oooooaGo003o2?ooool1o`00007o
oooo00000ol0003oooooooooo`0Dooooo`03ool00?oooooooooo04[ooooo00?oo`00ooooooooool0
V_oooolEo`00o`Sooooo0Ol00001ooooo`0000?o0000ooooooooool04oooool00ooo003ooooooooo
o`1<ooooo`03ool00?oooooooooo09Wooooo5Ol00?l8ooooo`7o00000Oooool00003o`000?oooooo
oooo017ooooo0_oo001@ooooo`;oo`00VOoooolEo`00o`Sooooo0Ol00001ooooo`0000?o0000oooo
ooooool04?ooool00ooo003oooooooooo`1Booooo`;oo`00UooooolEo`00o`Sooooo0Ol00001oooo
o`0000?o0000ooooooooool03oooool00ooo003oooooooooo`1Eooooo`03ool00?oooooooooo09Co
oooo5Ol00?l8ooooo`7o00000Oooool00003o`000?oooooooooo00kooooo00?oo`00ooooooooool0
E_ooool00ooo003oooooooooo`2DoooooaGo003o2?ooool1o`00007ooooo00000ol0003ooooooooo
o`0=ooooo`03ool00?oooooooooo05Sooooo00?oo`00ooooooooool0TooooolEo`00o`Sooooo0Ol0
0001ooooo`0000?o0000ooooooooool03Oooool00ooo003oooooooooo`1Iooooo`03ool00?oooooo
oooo09;ooooo5Ol00?l8ooooo`7o00000Oooool00003o`000?oooooooooo00cooooo00?oo`00oooo
ooooool0Foooool00ooo003oooooooooo`2AoooooaGo003o2?ooool1o`00007ooooo00000ol0003o
ooooooooo`0;ooooo`03ool00?oooooooooo05gooooo00?oo`00ooooooooool0T?oooolEo`00o`So
oooo0Ol00001ooooo`0000?o0000ooooooooool02oooool00ooo003oooooooooo`1Mooooo`03ool0
0?oooooooooo093ooooo5Ol00?l8ooooo`7o00000Oooool00003o`000?oooooooooo00[ooooo00?o
o`00ooooooooool0Goooool00ooo003oooooooooo`2?oooooaGo003o2?ooool1o`00007ooooo0000
0ol0003oooooooooo`09ooooo`03ool00?oooooooooo067ooooo00?oo`00ooooooooool0S_oooolE
o`00o`Sooooo0Ol00001ooooo`0000?o0000ooooooooool02?ooool00ooo003oooooooooo`1Soooo
o`03ool00?oooooooooo08gooooo5Ol00?l8ooooo`7o00000Oooool00003o`000?oooooooooo00Oo
oooo00?oo`00ooooooooool0IOooool00ooo003oooooooooo`2<oooooaGo003o2?ooool1o`00007o
oooo00000ol0003oooooooooo`06ooooo`03ool00?oooooooooo06Oooooo00?oo`00ooooooooool0
RooooolEo`00o`Sooooo0Ol00001ooooo`0000?o0000ooooooooool01Oooool00ooo003ooooooooo
o`1Yooooo`03ool00?oooooooooo08[ooooo5Ol00?l8ooooo`7o00000Oooool00003o`000?oooooo
oooo00Gooooo00?oo`00ooooooooool0JOooool00ooo003oooooooooo`2:oooooaGo003o2?ooool1
o`00007ooooo00000ol0003oooooooooo`04ooooo`03ool00?oooooooooo06_ooooo00?oo`00oooo
ooooool0ROoooolEo`00o`Sooooo0Ol00001ooooo`0000?o0000ooooooooool00oooool00ooo003o
ooooooooo`1/ooooo`03ool00?oooooooooo08Wooooo5Ol00?l8ooooo`7o00000Oooool00003o`00
0?oooooooooo00?ooooo00?oo`00ooooooooool0KOooool00ooo003oooooooooo`28oooooaGo003o
2?ooool1o`00007ooooo00000ol0003oooooooooo`02ooooo`03ool00?oooooooooo06kooooo00?o
o`00ooooooooool0R?oooolEo`00o`Sooooo0Ol00001ooooo`0000?o0000ooooooooool00_ooool0
0ooo003oooooooooo`1_ooooo`03ool00?oooooooooo08Oooooo5Ol00?l8ooooo`7o00000Oooool0
0005o`000?oooooooooooooooooo0000L_ooool00ooo003oooooooooo`27oooooaGo003o2?ooool1
o`00007ooooo00001?l0003ooooooooooooo001dooooo`03ool00?oooooooooo08Kooooo5Ol00?l8
ooooo`7o00000Oooool00004o`000?ooooooooooool007Gooooo00?oo`00ooooooooool0QOoooolE
o`00o`Sooooo0Ol00001ooooo`0000?o0000oooooooo0000M_ooool00ooo003oooooooooo`25oooo
oaGo003o2?ooool1o`00007ooooo00000ol0003oooooool00006ooooo`;oogl0Koooool00ooo003o
ooooooooo`24oooooaGo003o2?ooool1o`00007ooooo00000ol0003oooooool00005ooooo`Coogl0
4oooool2oomo05Wooooo00?oo`00ooooooooool0Q?oooolEo`00o`Sooooo0Ol00001ooooo`0000?o
0000ool00?ooool01Oooool4oomo01;ooooo1?ooO`0Booooo`;oogl0A?ooool00ooo003ooooooooo
o`24oooooaGo003o2?ooool1o`00007ooooo00000ol0003oooooooooo`05ooooo`?oogl04oooool4
oomo017ooooo1?ooO`14ooooo`03ool00?oooooooooo08?ooooo5Ol00?l8ooooo`7o00000Oooool0
0003o`000?oooooooooo00Cooooo1?ooO`0Dooooo`;oogl04_ooool4oomo04Cooooo00?oo`00oooo
ooooool0PooooolEo`00o`Sooooo0Ol00001ooooo`0000?o0000ooooooooool01?ooool4oomo02Wo
oooo0_ooO`15ooooo`03ool00?oooooooooo08?ooooo5Ol00?l8ooooo`7o00000Oooool00003o`00
0?oooooooooo00Gooooo0_ooO`1FoooooaKo003o1Oooool00ooo003oooooooooo`23oooooaGo003o
2?ooool1o`00007ooooo00000ol0003oooooooooo`1Jooooo`?o003o5_ooool6o`00o`03ool00?oo
oooooooo08;ooooo5Ol00?l8ooooo`7o00000Oooool00003o`000?oooooooooo05Oooooo0ol00?lO
ooooo`?o003oP_oooolEo`00o`Sooooo0Ol00001ooooo`0000?o0000ooooooooool0E?ooool3o`00
ob;ooooo00?oo`00ooooooooool00ol00?mooooooaGo003o2?ooool1o`00007ooooo00000ol0003o
ooooooooo`1Aooooo`?o003o9Oooool00ooo003oooooooooo`03ooooo`?o003oO?oooolEo`00o`So
oooo0Ol00001ooooo`0000?o0000ooooooooool0Coooool20000obWooooo00?oo`00ooooooooool0
1Oooool3o`00ogWooooo5Ol00?l8ooooo`7o00000Oooool00003o`000?oooooooooo04gooooo0P00
0?l[ooooo`03ool00?oooooooooo00Sooooo0_l00?mgoooooaGo003o2?ooool1o`00007ooooo0000
0ol0003oooooooooo`1:ooooo`<0003o;Oooool00ooo003oooooooooo`0:ooooo`;o003oMOoooolE
o`00o`Sooooo0Ol00001ooooo`0000?o0000ooooooooool0B?ooool20000oc3ooooo00?oo`00oooo
ooooool03?ooool00ol00?ooooooooooo`1boooooaGo003o2?ooool1o`00007ooooo00000ol0003o
ooooooooo`17ooooo`030000oooooooooooo033ooooo00?oo`00ooooooooool03Oooool2o`00og;o
oooo5Ol00?l8ooooo`7o00000Oooool00003o`000?oooooooooo04Gooooo0P000?ldooooo`03ool0
0?oooooooooo00kooooo0_l00?m`oooooaGo003o2?ooool1o`00007ooooo00000ol0003ooooooooo
o`14ooooo`030000oooooooooooo03Cooooo00?oo`00ooooooooool04?ooool2o`00ofkooooo5Ol0
0?l8ooooo`7o00000Oooool00003o`000?oooooooooo02Cooooo0_ooO`0:ooooo`;oogl04Oooool0
0`000?ooooooooooo`0eooooo`03ool00?oooooooooo01;ooooo00?o003oooooooooool0JooooolE
o`00o`Sooooo0Ol00001ooooo`0000?o0000ooooooooool08oooool4oomo00Sooooo1?ooO`0?oooo
o`030000oooooooooooo03Kooooo00?oo`00ooooooooool04oooool00ol00?ooooooooooo`1Zoooo
oaGo003o2?ooool1o`00007ooooo00000ol0003oooooooooo`0Sooooo`Coogl02?ooool4oomo00go
oooo00<0003oo`00ooooool0>?ooool00ooo003oooooooooo`0Dooooo`03o`00oooooooooooo06Wo
oooo5Ol00?l8ooooo`7o00000Oooool00003o`000?oooooooooo02Cooooo0_ooO`0:ooooo`;oogl0
3Oooool00`000?ooooooooooo`0iooooo`03ool00?oooooooooo01Gooooo00?o003oooooooooool0
J?oooolEo`00o`Sooooo0Ol00001ooooo`0000?o0000ooooooooool0>Oooool4ool00003ooooo`00
0?oooooo03_ooooo00?oo`00ooooooooool05_ooool00ol00?ooooooooooo`1WoooooaGo003o2?oo
ool1o`00007ooooo00000ol0003oooooooooo`0hooooo`Koo`00?Oooool00ooo003oooooooooo`0G
ooooo`03o`00oooooooooooo06Kooooo5Ol00?l8ooooo`7o00000Oooool00003o`000?oooooooooo
03Oooooo2?oo000@ooooo`;oogl01oooool2oomo02;ooooo00?oo`00ooooooooool05oooool00ol0
0?ooooooooooo`1UoooooaGo003o2?ooool1o`00007ooooo00000ol0003oooooooooo`0^ooooo`;o
ogl01oooool8ool000oooooo1?ooO`05ooooo`Coogl08Oooool00ooo003oooooooooo`0Hooooo`03
o`00oooooooooooo06Cooooo5Ol00?l8ooooo`7o00000Oooool00003o`000?oooooooooo02gooooo
1?ooO`06ooooo`Soo`003oooool4oomo00Gooooo1?ooO`0Qooooo`03ool00?oooooooooo01Wooooo
00?o003oooooooooool0HooooolEo`00o`Sooooo0Ol00001ooooo`0000?o0000ooooooooool0;Ooo
ool4oomo00Kooooo2?oo000@ooooo`;oogl01oooool3oomo027ooooo00?oo`00ooooooooool06_oo
ool00ol00?ooooooooooo`1RoooooaGo003o2?ooool1o`00007ooooo00000ol0003oooooooooo`0^
ooooo`;oogl02?ooool6ool001[ooooo1?ooO`0Pooooo`03ool00?oooooooooo01_ooooo00?o003o
ooooooooool0HOoooolEo`00o`Sooooo0Ol00001ooooo`0000?o0000ooooooooool0>?ooool00`00
0?ooo`00ool00002ool001_ooooo1?ooO`0Pooooo`03ool00?oooooooooo01cooooo00?o003ooooo
ooooool0H?oooolEo`00o`Sooooo0Ol00001ooooo`0000?o0000ooooooooool0=oooool00`000?oo
ooooooooo`0Iooooo`;oogl01?ooool2oomo027ooooo00?oo`00ooooooooool07?ooool00ol00?oo
ooooooooo`1PoooooaGo003o2?ooool1o`00007ooooo00000ol0003oooooooooo`0fooooo`030000
oooooooooooo01Wooooo1?ooO`0Uooooo`03ool00?oooooooooo01kooooo00?o003oooooooooool0
GooooolEo`00o`Sooooo0Ol00001ooooo`0000?o0000ooooooooool0=_ooool00`000?oooooooooo
o`0Iooooo`Coogl09Oooool00ooo003oooooooooo`0Oooooo`03o`00oooooooooooo05kooooo5Ol0
0?l8ooooo`7o00000Oooool00003o`000?oooooooooo03Gooooo00@0003oooooooooO`3oogl06_oo
ool2oomo02Kooooo00?oo`00ooooooooool08?ooool00ol00?ooooooooooo`1MoooooaGo003o2?oo
ool1o`00007ooooo00000ol0003oooooooooo`0dooooo`030000ooooooooogl000?oogl0@Oooool0
0ooo003oooooooooo`0Qooooo`03o`00oooooooooooo07Wooooo0Ol00001ooooo`0000?o0000oooo
ooooool0:oooool2oomo00Kooooo00<0003oooooooooool01?ooO`11ooooo`03ool00?oooooooooo
027ooooo00?o003oooooooooool0NOooool1o`00007ooooo00000ol0003oooooooooo`0Zooooo`Co
ogl01?ooool00`000?ooooooooooo`02ooooo`;oogl06?ooool2oomo017ooooo0_ooO`0Eooooo`03
ool00?oooooooooo02;ooooo00?o003oooooooooool0N?ooool1o`00007ooooo00000ol0003ooooo
ooooo`0Zooooo`Coogl01?ooool00`000?ooooooooooo`0Kooooo`Coogl03oooool4oomo01Cooooo
00?oo`00ooooooooool08oooool00ol00?ooooooooooo`1gooooo`7o00000Oooool00003o`000?oo
oooooooo02_ooooo0_ooO`04ooooo`030000oooooooooooo01cooooo1?ooO`0?ooooo`Coogl05?oo
ool00ooo003oooooooooo`0Sooooo`03o`00oooooooooooo07Oooooo0Ol00001ooooo`0000?o0000
ooooooooool0<Oooool00`000?ooooooooooo`0Mooooo`;oogl04Oooool2oomo01Cooooo00?oo`00
ooooooooool09Oooool00ol00?ooooooooooo`1fooooo`7o00000Oooool00003o`000?oooooooooo
033ooooo00<0003oooooooooool0Aoooool00ooo003oooooooooo`0Uooooo`03o`00oooooooooooo
07Kooooo0Ol00001ooooo`0000?o0000ooooooooool0<?ooool00`000?ooooooooooo`17ooooo`03
ool00?oooooooooo02Kooooo00?o003oooooooooool0MOooool1o`00007ooooo00000ol0003ooooo
ooooo`0_ooooo`030000oooooooooooo04Sooooo00?oo`00ooooooooool09oooool00ol00?oooooo
ooooo`1dooooo`7o00000Oooool00003o`000?oooooooooo02oooooo00<0003oooooooooool01ooo
ool2oomo00;ooooo0_ooO`0kooooo`03ool00?oooooooooo02Oooooo00?o003oooooooooool0M?oo
ool1o`00007ooooo00000ol0003oooooooooo`0^ooooo`030000oooooooooooo00Oooooo2?ooO`0i
ooooo`03ool00?oooooooooo02Wooooo00?o003oooooooooool0Loooool1o`00007ooooo00000ol0
003oooooooooo`0^ooooo`030000oooooooooooo00Oooooo2?ooO`0iooooo`03ool00?oooooooooo
02Wooooo00?o003oooooooooool0Loooool1o`00007ooooo00000ol0003oooooooooo`0]ooooo`03
0000oooooooooooo00Wooooo1_ooO`0Pooooo`;oogl05oooool00ooo003oooooooooo`0[ooooo`03
o`00oooooooooooo07;ooooo0Ol00001ooooo`0000?o0000ooooooooool0;Oooool00`000?oooooo
ooooo`0;ooooo`Coogl07oooool4oomo01Kooooo00?oo`00ooooooooool0:oooool00ol00?oooooo
ooooo`1booooo`7o00000Oooool00003o`000?oo003ooooo02gooooo00<0003oooooooooool03?oo
ool2oomo023ooooo1?ooO`0Fooooo`03ool00?oooooooooo02_ooooo00?o003oooooooooool0L_oo
ool1o`00007ooooo00000ol0003oo`00ooooo`0/ooooo`030000oooooooooooo033ooooo0_ooO`0F
ooooo`03ool00?oooooooooo02gooooo00?o003oooooooooool0LOooool1o`00007ooooo00000ol0
003oo`00ooooo`0/ooooo`030000oooooooooooo04Sooooo00?oo`00ooooooooool0;Oooool00ol0
0?ooooooooooo`1aooooo`7o00000Oooool00003o`000?ooooooo`0002cooooo00<0003ooooooooo
ool0B?ooool00ooo003oooooooooo`0]ooooo`03o`00oooooooooooo077ooooo0Ol00001ooooo`00
00?o0000oooooooo0000:oooool00`000?ooooooooooo`18ooooo`03ool00?oooooooooo02oooooo
00?o003oooooooooool0L?ooool1o`00007ooooo00001?l0003ooooooooooooo000Zooooo`030000
oooooooooooo00?ooooo0_ooO`13ooooo`03ool00?oooooooooo02oooooo00?o003oooooooooool0
L?ooool1o`00007ooooo00001?l0003ooooooooooooo000Zooooo`030000oooooooooooo00;ooooo
1?ooO`12ooooo`03ool00?oooooooooo02oooooo00?o003oooooooooool0L?ooool1o`00007ooooo
00001Ol0003oooooooooooooooooo`0002Wooooo00<0003oooooooooool00_ooool4oomo047ooooo
00?oo`00ooooooooool0<?ooool00ol00?ooooooooooo`1`ooooo`7o00000Oooool00005o`000?oo
oooooooooooooooo0000:?ooool00`000?ooooooooooo`04ooooo`;oogl0@_ooool00ooo003ooooo
ooooo`0aooooo`03o`00oooooooooooo06oooooo0Ol00001ooooo`0000?o0000ooooooooool00_oo
ool00ooo003oooooooooo`0Uooooo`030000oooooooooooo04Oooooo00?oo`00ooooooooool0<_oo
ool00ol00?ooooooooooo`1_ooooo`7o00000Oooool00003o`000?oooooooooo00;ooooo00?oo`00
ooooooooool09Oooool00`000?ooooooooooo`17ooooo`03ool00?oooooooooo03;ooooo00?o003o
ooooooooool0Koooool1o`00007ooooo00000ol0003oooooooooo`03ooooo`03ool00?oooooooooo
02Cooooo00<0003oooooooooool0A_ooool00ooo003oooooooooo`0cooooo`03o`00oooooooooooo
06oooooo0Ol00001ooooo`0000?o0000ooooooooool01?ooool00ooo003oooooooooo`0Sooooo`03
0000oooooooooooo04Gooooo00?oo`00ooooooooool0=?ooool00ol00?ooooooooooo`1_ooooo`7o
00000Oooool00003o`000?oooooooooo00Gooooo00?oo`00ooooooooool08Oooool00`000?oooooo
ooooo`15ooooo`03ool00?oooooooooo03Kooooo00?o003oooooooooool0K_ooool1o`00007ooooo
00000ol0003oooooooooo`06ooooo`03ool00?oooooooooo023ooooo00<0003oooooooooool0AOoo
ool00ooo003oooooooooo`09ooooo`;oogl0:oooool00ol00?ooooooooooo`1^ooooo`7o00000Ooo
ool00003o`000?oooooooooo00Kooooo00?oo`00ooooooooool08?ooool00`000?ooooooooooo`14
ooooo`03ool00?oooooooooo00Wooooo1?ooO`0Zooooo`03o`00oooooooooooo06kooooo0Ol00001
ooooo`0000?o0000ooooooooool01oooool00ooo003oooooooooo`0Oooooo`030000oooooooooooo
02Sooooo0_ooO`0Iooooo`03ool00?oooooooooo00[ooooo1?ooO`0Zooooo`03o`00oooooooooooo
06kooooo0Ol00001ooooo`0000?o0000ooooooooool01oooool00ooo003oooooooooo`0Oooooo`03
0000oooooooooooo02Oooooo1?ooO`0Gooooo`03ool00?oooooooooo00cooooo0_ooO`0[ooooo`03
o`00oooooooooooo06kooooo0Ol00001ooooo`0000?o0000ooooooooool02?ooool00ooo003ooooo
ooooo`0Nooooo`030000oooooooooooo02Oooooo1?ooO`0Gooooo`03ool00?oooooooooo03Wooooo
00?o003oooooooooool0K_ooool1o`00007ooooo00000ol0003oooooooooo`09ooooo`03ool00?oo
oooooooo01gooooo00<0003oooooooooool0:?ooool2oomo01;ooooo1?l00?l00oooooooo`00oooo
o`0kooooo`03o`00oooooooooooo06kooooo0Ol00001ooooo`0000?o0000ooooooooool02_ooool0
0ooo003oooooooooo`0Looooo`030000oooooooooooo03_ooooo1_l00?lmooooo`03o`00oooooooo
oooo06kooooo0Ol00001ooooo`0000?o0000ooooooooool02oooool00ooo003oooooooooo`0Koooo
o`030000oooooooooooo03Oooooo0_ooO`000ooooooo003oo`00o`06o`00occooooo00?o003ooooo
ooooool0K_ooool1o`00007ooooo00000ol0003oooooooooo`0<ooooo`03ool00?oooooooooo01[o
oooo00<0003oooooooooool0=_ooool4oomo00So003o??ooool00ol00?ooooooooooo`1^ooooo`7o
00000Oooool00003o`000?oooooooooo00gooooo00?oo`00ooooooooool06Oooool00`000?oooooo
ooooo`0fooooo`Coogl02?l00?llooooo`03o`00oooooooooooo06kooooo0Ol00001ooooo`0000?o
0000ooooooooool03Oooool2ool001[ooooo00<0003oooooooooool0=oooool2oomo0003ooooool0
0?oo003o00Ko003o??ooool00ol00?ooooooooooo`1^ooooo`7o00000Oooool00003o`000?oooooo
oooo00oooooo00?oo`00ooooooooool05oooool00`000?ooooooooooo`0jooooo`03ool00?l00?oo
003o00Co003o?Oooool00ol00?ooooooooooo`1^ooooo`7o00000Oooool00003o`000?oooooooooo
013ooooo00?oo`00ooooooooool05_ooool00`000?ooooooooooo`0iooooo`03ool00?oooooooooo
00Co003o?_ooool00ol00?ooooooooooo`1^ooooo`7o00000Oooool00003o`000?oooooooooo017o
oooo00?oo`00ooooooooool05Oooool00`000?ooooooooooo`0hooooo`03ool00?oooooooooo04?o
oooo00?o003oooooooooool0K_ooool1o`00007ooooo00000ol0003oooooooooo`0Booooo`03ool0
0?oooooooooo01Cooooo00<0003oooooooooool0=_ooool2ool004Kooooo00?o003oooooooooool0
K_ooool1o`00007ooooo00000ol0003oooooooooo`0Cooooo`03ool00?oooooooooo01?ooooo00<0
003oooooooooool0=Oooool00ooo003oooooooooo`16ooooo`03o`00oooooooooooo06kooooo0Ol0
0001ooooo`0000?o0000ooooooooool05?ooool2ool001?ooooo00<0003oooooooooool0=?ooool0
0ooo003oooooooooo`17ooooo`03o`00oooooooooooo06kooooo0Ol00001ooooo`0000?o0000oooo
ooooool05_ooool2ool0017ooooo00<0003oooooooooool0<_ooool2ool004[ooooo00?o003ooooo
ooooool0K_ooool1o`00007ooooo00000ol0003oooooooooo`0Hooooo`03ool00?oooooooooo00ko
oooo00<0003oooooooooool0<Oooool00ooo003oooooooooo`1:ooooo`03o`00oooooooooooo06ko
oooo0Ol00001ooooo`0000?o0000ooooooooool06Oooool2ool000kooooo00<0003oooooooooool0
;oooool2ool004gooooo00?o003oooooooooool0K_ooool1o`00007ooooo00000ol0003ooooooooo
o`0Kooooo`03ool00?oooooooooo00_ooooo00<0003oooooooooool0;_ooool00ooo003ooooooooo
o`1<ooooo`03o`00oooooooooooo06oooooo0Ol00001ooooo`0000?o0000ooooooooool07?ooool2
ool000_ooooo00<0003oooooooooool0;Oooool00ooo003oooooooooo`1=ooooo`03o`00oooooooo
oooo06oooooo0Ol00001ooooo`0000?o0000ooooooooool07_ooool3ool000Wooooo00<0003ooooo
ooooool0:_ooool2ool0053ooooo00?o003oooooooooool0Koooool1o`00007ooooo00000ol0003o
ooooooooo`0Qooooo`;oo`001oooool00`000?ooooooooooo`0Wooooo`?oo`00D_ooool00ol00?oo
ooooooooo`1_ooooo`7o00000Oooool00003o`000?oooooooooo02?ooooo0_oo0005ooooo`030000
oooooooooooo02Gooooo0_oo001Dooooo`03o`00oooooooooooo073ooooo0Ol00001ooooo`0000?o
0000ooooooooool09Oooool4ool00003ooooo`000?oooooo02;ooooo1?oo001Fooooo`03o`00oooo
oooooooo073ooooo0Ol00001ooooo`0000?o0000ooooooooool0:Oooool2ool00003o`00oooo003o
o`0001gooooo0ooo001Jooooo`03o`00oooooooooooo073ooooo0Ol00001ooooo`0000?o0000oooo
ooooool0:oooool00`000?ooooooooooo`03ool001Cooooo1_oo001Mooooo`03o`00oooooooooooo
073ooooo0Ol00001ooooo`0000?o0000ooooooooool0;?ooool00`000?ooooooooooo`02oooooaCo
o`00H_ooool00ol00?ooooooooooo`1aooooo`7o00000Oooool00003o`000?oooooooooo02cooooo
00<0003oooooooooool0N?ooool00ol00?ooooooooooo`1aooooo`7o00000Oooool00003o`000?oo
oooooooo02cooooo00<0003oooooooooool0N?ooool00ol00?ooooooooooo`1aooooo`7o00000Ooo
ool00003o`000?oooooooooo02gooooo00<0003oooooooooool0M_ooool00ol00?ooooooooooo`1b
ooooo`7o00000Oooool00003o`000?oooooooooo02gooooo00<0003oooooooooool0M_ooool00ol0
0?ooooooooooo`1booooo`7o00000Oooool00003o`000?oooooooooo02gooooo00<0003ooooooooo
ool0M_ooool00ol00?ooooooooooo`1booooo`7o00000Oooool00003o`000?oooooooooo02kooooo
00<0003oooooooooool0M?ooool00ol00?ooooooooooo`1cooooo`7o00000Oooool00003o`000?oo
oooooooo02kooooo00<0003oooooooooool0M?ooool00ol00?ooooooooooo`1cooooo`7o00000Ooo
ool00003o`000?oooooooooo02kooooo00<0003oooooooooool0M?ooool00ol00?ooooooooooo`1c
ooooo`7o00000Oooool00003o`000?oooooooooo02oooooo00<0003oooooooooool0L_ooool00ol0
0?ooooooooooo`1dooooo`7o00000Oooool00003o`000?oooooooooo02oooooo00<0003ooooooooo
ool0L_ooool00ol00?ooooooooooo`1dooooo`7o00000Oooool00003o`000?oooooooooo02oooooo
00<0003oooooooooool0L_ooool00ol00?ooooooooooo`1dooooo`7o00000Oooool00003o`000?oo
oooooooo033ooooo00<0003oooooooooool0Koooool2o`00ogOooooo0Ol00001ooooo`0000?o0000
ooooooooool0<?ooool00`000?ooooooooooo`1_ooooo`03o`00oooooooooooo07Kooooo0Ol00001
ooooo`0000?o0000ooooooooool0<Oooool00`000?ooooooooooo`1]ooooo`03o`00oooooooooooo
07Oooooo0Ol00001ooooo`0000?o0000ooooooooool0<_ooool00`000?ooooooooooo`1/ooooo`03
o`00oooooooooooo07Oooooo0Ol00001ooooo`0000?o0000ooooooooool0<_ooool00`000?oooooo
ooooo`1[ooooo`03o`00oooooooooooo063ooooo0_ooO`0Fooooo`7o00000Oooool00003o`000?oo
oooooooo03?ooooo00<0003oooooooooool0JOooool00ol00?ooooooooooo`1Pooooo`Coogl05Ooo
ool1o`00007ooooo00000ol0003oooooooooo`0dooooo`030000oooooooooooo06Sooooo00?o003o
ooooooooool0H?ooool4oomo01Gooooo0Ol00001ooooo`0000?o0000ooooooooool0=Oooool00`00
0?ooooooooooo`1Vooooo`03o`00oooooooooooo06;ooooo0_ooO`0Fooooo`7o00000Oooool00003
o`000?oooooooooo03Gooooo00?o003oooooooooool0I_ooool00ol00?ooooooooooo`1jooooo`7o
00000Oooool00003o`000?oooooooooo03Kooooo00?o003oooooooooool0I?ooool00ol00?oooooo
ooooo`1kooooo`7o00000Oooool00003o`000?oooooooooo03Oooooo00?o003oooooooooool0H_oo
ool00ol00?ooooooooooo`1looooo`7o00000Oooool00003o`000?oooooooooo03Sooooo00?o003o
ooooooooool0Goooool2o`00ogoooooo0Ol00001ooooo`0000?o0000ooooooooool0>Oooool00ol0
0?ooooooooooo`1Mooooo`03o`00oooooooooooo07oooooo0Ol00001ooooo`0000?o0000oooooooo
ool0>_ooool00ol00?ooooooooooo`1Kooooo`03o`00oooooooooooo083ooooo0Ol00001ooooo`00
00?o0000ooooooooool0>oooool00ol00?ooooooooooo`1Iooooo`03o`00oooooooooooo087ooooo
0Ol00001ooooo`0000?o0000ooooooooool0??ooool00ol00?ooooooooooo`1Gooooo`03o`00oooo
oooooooo08;ooooo0Ol00001ooooo`0000?o0000ooooooooool0?Oooool00ol00?ooooooooooo`1E
ooooo`03o`00oooooooooooo08?ooooo0Ol00001ooooo`0000?o0000ooooooooool0?_ooool00ol0
0?ooooooooooo`1Cooooo`03o`00oooooooooooo08Cooooo0Ol00001ooooo`0000?o0000oooooooo
ool0?oooool00ol00?ooooooooooo`1@ooooo`;o003o8Oooool2oomo06Cooooo0Ol00001ooooo`00
00?o0000ooooooooool0@?ooool00ol00?ooooooooooo`1>ooooo`03o`00oooooooooooo023ooooo
1?ooO`1Sooooo`7o00000Oooool00003o`000?oooooooooo047ooooo0_l00?m=ooooo`03o`00oooo
oooooooo027ooooo1?ooO`1Sooooo`7o00000Oooool00003o`000?oooooooooo04?ooooo00?o003o
ooooooooool0BOooool00ol00?ooooooooooo`0Sooooo`;oogl0=Oooool2oomo02gooooo0Ol00001
ooooo`0000?o0000ooooooooool0A?ooool2o`00odSooooo00?o003oooooooooool0Doooool2oomo
00Gooooo1?ooO`0/ooooo`7o00000Oooool00003o`000?oooooooooo04Kooooo0_l00?m5ooooo`03
o`00oooooooooooo05?ooooo1?ooO`04ooooo`Coogl0;?ooool1o`00007ooooo00000ol0003ooooo
ooooo`18ooooo`03o`00oooooooooooo043ooooo0_l00?lfooooo`;oogl07_ooool4oomo00Gooooo
0_ooO`0]ooooo`7o00000Oooool00003o`000?oooooooooo04Wooooo0_l00?lnooooo`;o003o=ooo
ool4oomo01kooooo0_ooO`0eooooo`7o00000Oooool00003o`000?oooooooooo04_ooooo0ol00?lj
ooooo`03o`00oooooooooooo03Oooooo1?ooO`1Eooooo`7o00000Oooool00003o`000?oooooooooo
04kooooo0_l00?lfooooo`;o003o>oooool2oomo05Kooooo0Ol00001ooooo`0000?o0000oooooooo
ool0D?ooool3o`00oc3ooooo0ol00?lcooooo`;oogl09Oooool2oomo03Wooooo0Ol00001ooooo`00
00?o0000ooooooooool0Doooool2o`00ob[ooooo1?l00?leooooo`Coogl08oooool4oomo03Sooooo
0Ol00001ooooo`0000?o0000ooooooooool0EOooool3o`00ob?ooooo1?l00?leooooo`;oogl00_oo
ool4oomo02?ooooo1?ooO`03ooooo`;oogl0<oooool1o`00007ooooo00000ol0003oooooooooo`1H
ooooo`?o003o7Oooool3o`00ocSooooo1?ooO`02ooooo`;oogl04oooool2oomo013ooooo0_ooO`03
ooooo`Coogl0<_ooool1o`00007ooooo00000ol0003oooooooooo`1Kooooo`?o003o5?ooool6o`00
oc_ooooo1?ooO`06ooooo`;oogl03_ooool4oomo01Cooooo1?ooO`0booooo`7o00000Oooool00003
o`000?oooooooooo05kooooo5?l00?m2ooooo`;oogl01_ooool4oomo00gooooo1?ooO`0Eooooo`;o
ogl0<oooool1o`00007ooooo00000ol0003oooooooooo`2;ooooo`;oogl09oooool2oomo00Kooooo
1?ooO`0>ooooo`;oogl0Boooool1o`00007ooooo00000ol0003oooooooooo`2:ooooo`Coogl09Ooo
ool4oomo00Kooooo0_ooO`1Looooo`7o00000Oooool00003o`000?oooooooooo08[ooooo1?ooO`0U
ooooo`Coogl0I?ooool1o`00007ooooo00000ol0003oooooooooo`2;ooooo`;oogl09oooool2oomo
06Gooooo0Ol00001ooooo`0000?o0000ooooooooool0U_ooool2oomo03[ooooo0_ooO`17ooooo`7o
00000Oooool00003o`000?oooooooooo09Gooooo1?ooO`0>ooooo`;oogl0:?ooool4oomo04Kooooo
0Ol00001ooooo`0000?o0000ooooooooool0UOooool4oomo00gooooo1?ooO`0Wooooo`Coogl0A_oo
ool1o`00007ooooo00000ol0003oooooooooo`2Fooooo`;oogl03_ooool4oomo02Sooooo0_ooO`17
ooooo`7o00000Oooool00003o`000?oooooooooo0:Oooooo0_ooO`1booooo`7o00000Oooool00003
o`000?oooooooooo0>_ooooo0_ooO`0^ooooo`7o00000Oooool00003o`000?oooooooooo0>[ooooo
1?ooO`0]ooooo`7o00000Oooool00003o`000?oooooooooo0=Kooooo0_ooO`0Booooo`Coogl0;Ooo
ool1o`00007ooooo00000ol0003oooooooooo`3Eooooo`Coogl04_ooool2oomo02kooooo0Ol00001
ooooo`0000?o0000ooooooooool0]oooool2oomo01cooooo1?ooO`12ooooo`7o00000Oooool00003
o`000?oooooooooo0;Kooooo1?ooO`0Aooooo`Goo`3o1_ooool2oomo04?ooooo0Ol00001ooooo`00
00?o0000ooooooooool0/oooool2oomo0003ooooooooO`3oogl000;oogl04?ooool7ool0od[ooooo
0Ol00001ooooo`0000?o0000ooooooooool0Z?ooool2oomo00Sooooo1?ooO`000oooooooogl0oomo
000@ooooo`Woo`3o00?ooooooomo0?ooO`00A_ooool1o`00007ooooo00000ol0003oooooooooo`2V
ooooo`Googl01oooool4oomo01;ooooo2ooo0?l3oomo04Gooooo0Ol00001ooooo`0000?o0000oooo
ooooool0YOooool6oomo00Sooooo0_ooO`0Cooooo`_oo`3o0oooO`15ooooo`7o00000Oooool00003
o`000?oooooooooo0:Gooooo1OooO`0Nooooo`_oo`3o0_ooO`16ooooo`7o00000Oooool00003o`00
0?oooooooooo07Kooooo0_ooO`0^ooooo`;oogl08?ooool;ool0odSooooo0Ol00001ooooo`0000?o
0000ooooooooool0MOooool4oomo04oooooo2ooo0?m8ooooo`7o00000Oooool00003o`000?oooooo
oooo07Gooooo1?ooO`0:ooooo`;oogl0A?ooool9ool0odWooooo0Ol00001ooooo`0000?o0000oooo
ooooool0M_ooool2oomo00[ooooo1?ooO`0Zooooo`;oogl06?ooool7ool0od[ooooo0Ol00001oooo
o`0000?o0000ooooooooool0P_ooool4oomo02Wooooo1?ooO`0Hooooo`Goo`3oBoooool1o`00007o
oooo00000ol0003oooooooooo`23ooooo`;oogl09?ooool2oomo00Cooooo1?ooO`1Xooooo`7o0000
0Oooool00003o`000?oooooooooo0:Sooooo1?ooO`04ooooo`;oogl0JOooool1o`00007ooooo0000
0ol0003oooooooooo`2Xooooo`Coogl0Koooool1o`00007ooooo00000ol0003oooooooooo`2Yoooo
o`;oogl0L?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`00
00?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?oo
ool1o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000oooo
ooooool0Q?ooool2oomo09Gooooo0Ol00001ooooo`0000?o0000ooooooooool0Poooool4oomo09Co
oooo0Ol00001ooooo`0000?o0000ooooooooool0Poooool4oomo09Cooooo0Ol00001ooooo`0000?o
0000ooooooooool0Q?ooool2oomo02cooooo0_ooO`1Wooooo`7o00000Oooool00003o`000?oooooo
oooo0;7ooooo1?ooO`1Vooooo`7o00000Oooool00003o`000?oooooooooo0;7ooooo1?ooO`1Voooo
o`7o00000Oooool00003o`000?oooooooooo0;;ooooo0_ooO`1Wooooo`7o00000Oooool00003o`00
0?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol0
0001ooooo`0000?o0000ooooooooool0Noooool2oomo09kooooo0Ol00001ooooo`0000?o0000oooo
ooooool0N_ooool4oomo09gooooo0Ol00001ooooo`0000?o0000ooooooooool0N_ooool4oomo023o
oooo0_ooO`1kooooo`7o00000Oooool00003o`000?oooooooooo07_ooooo0_ooO`0Pooooo`Coogl0
N_ooool1o`00007ooooo00000ol0003oooooooooo`2Mooooo`Coogl0N_ooool1o`00007ooooo0000
0ol0003oooooooooo`2@ooooo`;oogl03?ooool2oomo07_ooooo0Ol00001ooooo`0000?o0000oooo
ooooool0Soooool4oomo08Sooooo0Ol00001ooooo`0000?o0000ooooooooool0Soooool4oomo08So
oooo0Ol00001ooooo`0000?o0000ooooooooool0T?ooool2oomo02?ooooo0_ooO`1Tooooo`7o0000
0Oooool00003o`000?oooooooooo0;Cooooo1?ooO`1Sooooo`7o00000Oooool00003o`000?oooooo
oooo0;Cooooo1?ooO`1Sooooo`7o00000Oooool00003o`000?oooooooooo0;Gooooo0_ooO`1Toooo
o`7o00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003ooooo
ooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Ooo
ool00003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooo
oacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`00
0?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol0
0001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo
0?oooooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`00
00?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?oo
ool1o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000oooo
ooooool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007o
oooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooo
oolLooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0
003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o
00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003ooooooooo
o`3ooooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool0
0003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooooaco
oooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oo
oooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001
ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo0?oo
oooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o
0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1
o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000oooooooo
ool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo
00000ol0003oooooooooo`2>ooooo`;oogl0Roooool1o`00007ooooo00000ol0003oooooooooo`2=
ooooo`Coogl0R_ooool1o`00007ooooo00000ol0003oooooooooo`2=ooooo`Coogl0R_ooool1o`00
007ooooo00000ol0003oooooooooo`2>ooooo`;oogl0Roooool1o`00007ooooo00000ol0003ooooo
ooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Ooo
ool00003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooo
oacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`00
0?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol0
0001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo
0?oooooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`00
00?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?oo
ool1o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000oooo
ooooool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007o
oooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooo
oolLooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0
003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o
00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo003oo`00023o00000Ooo
ool00001\
\>"],
  ImageRangeCache->{{{0, 287}, {287, 0}} -> {-1.01089, -1.01089, 0.00704453, \
0.00704453}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.49505 0.5 0.49505 [
[ 0 0 -0.125 0 ]
[ 0 0 -0.125 0 ]
[ 0 1 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
0 0 m
1 0 L
s
0 0 m
0 1 L
s
0 1 m
1 1 L
s
1 0 m
1 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
1 .5 0 r
.015 w
.03175 .1355 Mdot
.03435 .12523 Mdot
.11137 .12765 Mdot
.14107 .18841 Mdot
.16218 .24538 Mdot
.17294 .21053 Mdot
.18267 .18577 Mdot
.18434 .1304 Mdot
.18553 .30956 Mdot
.20401 .239 Mdot
.21247 .27571 Mdot
.21687 .20845 Mdot
.22376 .2799 Mdot
.22832 .27485 Mdot
.29063 .20974 Mdot
.29686 .25079 Mdot
.30487 .22936 Mdot
.30683 .34623 Mdot
.32055 .20902 Mdot
.32574 .21979 Mdot
.34472 .28521 Mdot
.35998 .36393 Mdot
.36335 .24976 Mdot
.3794 .36608 Mdot
.42386 .66992 Mdot
.44391 .74519 Mdot
.45059 .34198 Mdot
.47208 .67586 Mdot
.47436 .71381 Mdot
.49778 .59825 Mdot
.50874 .91643 Mdot
.51516 .76219 Mdot
.53655 .61374 Mdot
.56563 .75219 Mdot
.59189 .65665 Mdot
.59581 .61604 Mdot
.59923 .6556 Mdot
.60292 .68499 Mdot
.62656 .67779 Mdot
.63555 .72451 Mdot
.63919 .652 Mdot
.64169 .6004 Mdot
.64246 .58611 Mdot
.64496 .54267 Mdot
.64608 .77288 Mdot
.65077 .64308 Mdot
.66065 .57816 Mdot
.67474 .59169 Mdot
.69296 .563 Mdot
.72815 .65902 Mdot
.73169 .58879 Mdot
.74669 .61318 Mdot
.74821 .65474 Mdot
.75963 .63781 Mdot
.79673 .57809 Mdot
.80925 .55852 Mdot
.81525 .58444 Mdot
.83417 .62985 Mdot
.83598 .55526 Mdot
.91595 .49319 Mdot
1 0 0 r
.005 w
.00495 .28842 m
.00628 .29156 L
.01857 .31761 L
.03101 .33781 L
.03525 .34367 L
.05706 .36884 L
.05795 .36972 L
.08312 .39115 L
.08963 .39578 L
.10917 .40763 L
.13523 .41964 L
.14074 .42183 L
.16128 .42794 L
.18734 .43294 L
.21339 .43485 L
.23945 .43375 L
.2655 .42959 L
.29156 .42219 L
.29261 .42183 L
.31761 .41124 L
.34367 .39603 L
.34405 .39578 L
.36972 .37551 L
.37582 .36972 L
.39578 .34724 L
.39849 .34367 L
.41525 .31761 L
.42183 .30485 L
.4275 .29156 L
.436 .2655 L
.44117 .23945 L
.44325 .21339 L
.44232 .18734 L
.43834 .16128 L
.43114 .13523 L
.42183 .11212 L
.42037 .10917 L
.40546 .08312 L
.39578 .06961 L
.38528 .05706 L
.36972 .04137 L
.35758 .03101 L
.34367 .02092 L
.31761 .00569 L
.3162 .00495 L
s
.00495 .12854 m
.01344 .10917 L
.02832 .08312 L
.03101 .07912 L
.04848 .05706 L
.05706 .04802 L
.07619 .03101 L
.08312 .02579 L
.10917 .00934 L
.11742 .00495 L
s
0 0 1 r
.29156 .15739 m
.31761 .14824 L
.34367 .14249 L
.36972 .13986 L
.39578 .14025 L
.42183 .14366 L
.44789 .15025 L
.47394 .16034 L
.47599 .16128 L
.5 .17443 L
.51844 .18734 L
.52606 .19355 L
.54662 .21339 L
.55211 .21962 L
.56712 .23945 L
.57817 .25755 L
.58227 .2655 L
.59322 .29156 L
.60058 .31761 L
.60422 .3392 L
.60471 .34367 L
.6058 .36972 L
.60422 .39297 L
.60387 .39578 L
.59886 .42183 L
.59054 .44789 L
.57848 .47394 L
.57817 .47453 L
.562 .5 L
.55211 .51255 L
.53968 .52606 L
.52606 .53862 L
.50853 .55211 L
.5 .55773 L
.47394 .57183 L
.45901 .57817 L
.44789 .5819 L
.42183 .5885 L
.39578 .59192 L
.36972 .59231 L
.34367 .58968 L
.31761 .58392 L
.29972 .57817 L
.29156 .57477 L
.2655 .56178 L
.25025 .55211 L
.23945 .54409 L
.21914 .52606 L
.21339 .52008 L
.19681 .5 L
Mistroke
.18734 .48608 L
.18031 .47394 L
.16827 .44789 L
.16128 .42714 L
.15996 .42183 L
.15493 .39578 L
.153 .36972 L
.15409 .34367 L
.15823 .31761 L
.16128 .3045 L
.16559 .29156 L
.17653 .2655 L
.18734 .24609 L
.19169 .23945 L
.21221 .21339 L
.21339 .21211 L
.23945 .1881 L
.24041 .18734 L
.2655 .17038 L
.28271 .16128 L
.29156 .15739 L
Mfstroke
1 0 0 r
.03 w
.21687 .20845 Mdot
0 0 1 r
.3794 .36608 Mdot
1 0 0 r
.79703 .00495 m
.79703 .02747 L
.87129 .02747 L
.87129 .00495 L
F
0 0 1 r
.89604 .00495 m
.89604 .22995 L
.9703 .22995 L
.9703 .00495 L
F
1 0 1 r
.04 w
.73169 .58879 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P000182000`400?l00000o`00003ooooooolQ
ooooo`00ool0000Po`00007ooooo00000ol0003oooooooooo`0Mooooo`;oo`00>?ooool3ool00<7o
oooo0Ol00001ooooo`0000?o0000ooooooooool06oooool2ool003gooooo00?oo`00ooooooooool0
Q?oooolEool000Sooooo5Ol00?l8ooooo`7o00000Oooool00003o`000?oooooooooo01[ooooo00?o
o`00ooooooooool0?_ooool2ool008Cooooo5Ooo0008oooooaGo003o2?ooool1o`00007ooooo0000
0ol0003oooooooooo`0Hooooo`;oo`00@oooool00ooo003oooooooooo`21oooooaGoo`002?oooolE
o`00o`Sooooo0Ol00001ooooo`0000?o0000ooooooooool05_ooool2ool004Kooooo00?oo`00oooo
ooooool0P?oooolEool000Sooooo5Ol00?l8ooooo`7o00000Oooool00003o`000?oooooooooo01Go
oooo00?oo`00ooooooooool0Aoooool2ool0083ooooo5Ooo0008oooooaGo003o2?ooool1o`00007o
oooo00000ol0003oooooooooo`0Dooooo`03ool00?oooooooooo04[ooooo00?oo`00ooooooooool0
OOoooolEool000Sooooo5Ol00?l8ooooo`7o00000Oooool00003o`000?oooooooooo01?ooooo00?o
o`00ooooooooool0C?ooool00ooo003oooooooooo`1loooooaGoo`002?oooolEo`00o`Sooooo0Ol0
0001ooooo`0000?o0000ooooooooool04Oooool2ool0053ooooo0_oo002IoooooaGo003o2?ooool1
o`00007ooooo00000ol0003oooooooooo`0@ooooo`03ool00?oooooooooo05;ooooo0_oo002Goooo
oaGo003o2?ooool1o`00007ooooo00000ol0003oooooooooo`0?ooooo`03ool00?oooooooooo05Go
oooo00?oo`00ooooooooool0U?oooolEo`00o`Sooooo0Ol00001ooooo`0000?o0000ooooooooool0
3_ooool00ooo003oooooooooo`1Fooooo`03ool00?oooooooooo09Cooooo5Ol00?l8ooooo`7o0000
0Oooool00003o`000?oooooooooo00gooooo00?oo`00ooooooooool0F?ooool00ooo003ooooooooo
o`2CoooooaGo003o2?ooool1o`00007ooooo00000ol0003oooooooooo`0=ooooo`03ool00?oooooo
oooo05Wooooo00?oo`00ooooooooool0T_oooolEo`00o`Sooooo0Ol00001ooooo`0000?o0000oooo
ooooool03?ooool00ooo003oooooooooo`1Kooooo`03ool00?oooooooooo097ooooo5Ol00?l8oooo
o`7o00000Oooool00003o`000?oooooooooo00_ooooo00?oo`00ooooooooool0GOooool00ooo003o
ooooooooo`2@oooooaGo003o2?ooool1o`00007ooooo00000ol0003oooooooooo`0;ooooo`03ool0
0?oooooooooo05gooooo00?oo`00ooooooooool0T?oooolEo`00o`Sooooo0Ol00001ooooo`0000?o
0000ooooooooool02_ooool00ooo003oooooooooo`1Oooooo`03ool00?oooooooooo08oooooo5Ol0
0?l8ooooo`7o00000Oooool00003o`000?oooooooooo00Wooooo00?oo`00ooooooooool0HOooool0
0ooo003oooooooooo`2>oooooaGo003o2?ooool1o`00007ooooo00000ol0003oooooooooo`08oooo
o`03ool00?oooooooooo06?ooooo00?oo`00ooooooooool0SOoooolEo`00o`Sooooo0Ol00001oooo
o`0000?o0000ooooooooool01oooool00ooo003oooooooooo`1Uooooo`03ool00?oooooooooo08co
oooo5Ol00?l8ooooo`7o00000Oooool00003o`000?oooooooooo00Kooooo00?oo`00ooooooooool0
Ioooool00ooo003oooooooooo`2;oooooaGo003o2?ooool1o`00007ooooo00000ol0003ooooooooo
o`05ooooo`03ool00?oooooooooo06Wooooo00?oo`00ooooooooool0R_oooolEo`00o`Sooooo0Ol0
0001ooooo`0000?o0000ooooooooool01Oooool00ooo003oooooooooo`1Yooooo`03ool00?oooooo
oooo08[ooooo5Ol00?l8ooooo`7o00000Oooool00003o`000?oooooooooo00Cooooo00?oo`00oooo
ooooool0Joooool00ooo003oooooooooo`29oooooaGo003o2?ooool1o`00007ooooo00000ol0003o
ooooooooo`03ooooo`03ool00?oooooooooo06cooooo00?oo`00ooooooooool0ROoooolEo`00o`So
oooo0Ol00001ooooo`0000?o0000ooooooooool00oooool00ooo003oooooooooo`1]ooooo`03ool0
0?oooooooooo08Sooooo5Ol00?l8ooooo`7o00000Oooool00003o`000?oooooooooo00;ooooo00?o
o`00ooooooooool0K_ooool00ooo003oooooooooo`28oooooaGo003o2?ooool1o`00007ooooo0000
0ol0003oooooooooo`02ooooo`03ool00?oooooooooo06oooooo00?oo`00ooooooooool0QooooolE
o`00o`Sooooo0Ol00001ooooo`0000Go0000ooooooooooooooooool0001booooo`03ool00?oooooo
oooo08Oooooo5Ol00?l8ooooo`7o00000Oooool00004o`000?ooooooooooool007Cooooo00?oo`00
ooooooooool0Q_oooolEo`00o`Sooooo0Ol00001ooooo`0000Co0000ooooooooooooo`00MOooool0
0ooo003oooooooooo`25oooooaGo003o2?ooool1o`00007ooooo00000ol0003oooooool0001foooo
o`03ool00?oooooooooo08Gooooo5Ol00?l8ooooo`7o00000Oooool00003o`000?ooooooo`0000Ko
oooo0_ooO`1_ooooo`03ool00?oooooooooo08Cooooo5Ol00?l8ooooo`7o00000Oooool00003o`00
0?ooooooo`0000Gooooo1?ooO`0Cooooo`;oogl0FOooool00ooo003oooooooooo`24oooooaGo003o
2?ooool1o`00007ooooo00000ol0003oo`00ooooo`05ooooo`Coogl04_ooool4oomo01;ooooo0_oo
O`14ooooo`03ool00?oooooooooo08Cooooo5Ol00?l8ooooo`7o00000Oooool00003o`000?oooooo
oooo00Gooooo0oooO`0Cooooo`Coogl04Oooool4oomo04Cooooo00?oo`00ooooooooool0PooooolE
o`00o`Sooooo0Ol00001ooooo`0000?o0000ooooooooool01?ooool4oomo01Cooooo0_ooO`0Boooo
o`Coogl0A?ooool00ooo003oooooooooo`23oooooaGo003o2?ooool1o`00007ooooo00000ol0003o
ooooooooo`04ooooo`Coogl0:Oooool2oomo04Gooooo00?oo`00ooooooooool0PooooolEo`00o`So
oooo0Ol00001ooooo`0000?o0000ooooooooool01Oooool2oomo05Kooooo5_l00?l5ooooo`03ool0
0?oooooooooo08?ooooo5Ol00?l8ooooo`7o00000Oooool00003o`000?oooooooooo05[ooooo0ol0
0?lFooooo`Ko003o00?oo`00ooooooooool0P_oooolEo`00o`Sooooo0Ol00001ooooo`0000?o0000
ooooooooool0Eoooool3o`00oaoooooo0ol00?n2oooooaGo003o2?ooool1o`00007ooooo00000ol0
003oooooooooo`1Dooooo`?o003o8_ooool00ooo003oooooooooo`03o`00ogoooooo5Ol00?l8oooo
o`7o00000Oooool00003o`000?oooooooooo057ooooo0ol00?lUooooo`03ool00?oooooooooo00?o
oooo0ol00?mloooooaGo003o2?ooool1o`00007ooooo00000ol0003oooooooooo`1?ooooo`80003o
:Oooool00ooo003oooooooooo`05ooooo`?o003oNOoooolEo`00o`Sooooo0Ol00001ooooo`0000?o
0000ooooooooool0COooool20000ob_ooooo00?oo`00ooooooooool02?ooool2o`00ogOooooo5Ol0
0?l8ooooo`7o00000Oooool00003o`000?oooooooooo04[ooooo0`000?l]ooooo`03ool00?oooooo
oooo00[ooooo0_l00?meoooooaGo003o2?ooool1o`00007ooooo00000ol0003oooooooooo`18oooo
o`80003o<?ooool00ooo003oooooooooo`0<ooooo`03o`00oooooooooooo07;ooooo5Ol00?l8oooo
o`7o00000Oooool00003o`000?oooooooooo04Oooooo00<0003oooooooooool0<?ooool00ooo003o
ooooooooo`0=ooooo`;o003oL_oooolEo`00o`Sooooo0Ol00001ooooo`0000?o0000ooooooooool0
AOooool20000ocCooooo00?oo`00ooooooooool03_ooool2o`00og3ooooo5Ol00?l8ooooo`7o0000
0Oooool00003o`000?oooooooooo04Cooooo00<0003oooooooooool0=?ooool00ooo003ooooooooo
o`0@ooooo`;o003oK_oooolEo`00o`Sooooo0Ol00001ooooo`0000?o0000ooooooooool09?ooool2
oomo00[ooooo0_ooO`0Aooooo`030000oooooooooooo03Gooooo00?oo`00ooooooooool04_ooool0
0ol00?ooooooooooo`1[oooooaGo003o2?ooool1o`00007ooooo00000ol0003oooooooooo`0Soooo
o`Coogl02?ooool4oomo00oooooo00<0003oooooooooool0=_ooool00ooo003oooooooooo`0Coooo
o`03o`00oooooooooooo06[ooooo5Ol00?l8ooooo`7o00000Oooool00003o`000?oooooooooo02?o
oooo1?ooO`08ooooo`Coogl03Oooool00`000?oo003oooooo`0hooooo`03ool00?oooooooooo01Co
oooo00?o003oooooooooool0JOoooolEo`00o`Sooooo0Ol00001ooooo`0000?o0000ooooooooool0
9?ooool2oomo00[ooooo0_ooO`0=ooooo`030000oooooooooooo03Wooooo00?oo`00ooooooooool0
5Oooool00ol00?ooooooooooo`1XoooooaGo003o2?ooool1o`00007ooooo00000ol0003ooooooooo
o`0iooooo`Coo`0000?ooooo0000ooooool0>oooool00ooo003oooooooooo`0Fooooo`03o`00oooo
oooooooo06Oooooo5Ol00?l8ooooo`7o00000Oooool00003o`000?oooooooooo03Sooooo1_oo000m
ooooo`03ool00?oooooooooo01Oooooo00?o003oooooooooool0I_oooolEo`00o`Sooooo0Ol00001
ooooo`0000?o0000ooooooooool0=oooool8ool0013ooooo0_ooO`07ooooo`;oogl08_ooool00ooo
003oooooooooo`0Gooooo`03o`00oooooooooooo06Gooooo5Ol00?l8ooooo`7o00000Oooool00003
o`000?oooooooooo02kooooo0_ooO`07ooooo`Soo`003oooool4oomo00Gooooo1?ooO`0Qooooo`03
ool00?oooooooooo01Sooooo00?o003oooooooooool0I?oooolEo`00o`Sooooo0Ol00001ooooo`00
00?o0000ooooooooool0;Oooool4oomo00Kooooo2?oo000?ooooo`Coogl01Oooool4oomo027ooooo
00?oo`00ooooooooool06Oooool00ol00?ooooooooooo`1SoooooaGo003o2?ooool1o`00007ooooo
00000ol0003oooooooooo`0]ooooo`Coogl01_ooool8ool0013ooooo0_ooO`07ooooo`?oogl08Ooo
ool00ooo003oooooooooo`0Jooooo`03o`00oooooooooooo06;ooooo5Ol00?l8ooooo`7o00000Ooo
ool00003o`000?oooooooooo02kooooo0_ooO`08ooooo`Koo`006_ooool4oomo023ooooo00?oo`00
ooooooooool06oooool00ol00?ooooooooooo`1QoooooaGo003o2?ooool1o`00007ooooo00000ol0
003oooooooooo`0hooooo`030000oooo003oo`0000;oo`006oooool4oomo023ooooo00?oo`00oooo
ooooool07?ooool00ol00?ooooooooooo`1PoooooaGo003o2?ooool1o`00007ooooo00000ol0003o
ooooooooo`0gooooo`030000oooooooooooo01Wooooo0_ooO`04ooooo`;oogl08Oooool00ooo003o
ooooooooo`0Looooo`03o`00oooooooooooo063ooooo5Ol00?l8ooooo`7o00000Oooool00003o`00
0?oooooooooo03Kooooo00<0003oooooooooool06Oooool4oomo02Gooooo00?oo`00ooooooooool0
7_ooool00ol00?ooooooooooo`1OoooooaGo003o2?ooool1o`00007ooooo00000ol0003ooooooooo
o`0fooooo`030000oooooooooooo01Wooooo1?ooO`0Uooooo`03ool00?oooooooooo01oooooo00?o
003oooooooooool0G_oooolEo`00o`Sooooo0Ol00001ooooo`0000?o0000ooooooooool0=Oooool0
10000?oooooooomo0?ooO`0Jooooo`;oogl09_ooool00ooo003oooooooooo`0Pooooo`03o`00oooo
oooooooo07[ooooo0Ol00001ooooo`0000?o0000ooooooooool0=?ooool00`000?oooooooomo0003
oomo047ooooo00?oo`00ooooooooool08Oooool00ol00?ooooooooooo`1iooooo`7o00000Oooool0
0003o`000?oooooooooo02_ooooo0_ooO`06ooooo`030000oooooooooooo00Coogl0@Oooool00ooo
003oooooooooo`0Qooooo`03o`00oooooooooooo07Wooooo0Ol00001ooooo`0000?o0000oooooooo
ool0:_ooool4oomo00Cooooo00<0003oooooooooool00_ooool2oomo01Sooooo0_ooO`0Aooooo`;o
ogl05Oooool00ooo003oooooooooo`0Rooooo`03o`00oooooooooooo07Sooooo0Ol00001ooooo`00
00?o0000ooooooooool0:_ooool4oomo00Cooooo00<0003oooooooooool06oooool4oomo00oooooo
1?ooO`0Dooooo`03ool00?oooooooooo02?ooooo00?o003oooooooooool0Moooool1o`00007ooooo
00000ol0003oooooooooo`0[ooooo`;oogl01?ooool00`000?ooooooooooo`0Looooo`Coogl03ooo
ool4oomo01Cooooo00?oo`00ooooooooool08oooool00ol00?ooooooooooo`1gooooo`7o00000Ooo
ool00003o`000?oooooooooo037ooooo00<0003oooooooooool07Oooool2oomo017ooooo0_ooO`0D
ooooo`03ool00?oooooooooo02Gooooo00?o003oooooooooool0M_ooool1o`00007ooooo00000ol0
003oooooooooo`0`ooooo`030000oooooooooooo04Oooooo00?oo`00ooooooooool09Oooool00ol0
0?ooooooooooo`1fooooo`7o00000Oooool00003o`000?oooooooooo033ooooo00<0003ooooooooo
ool0Aoooool00ooo003oooooooooo`0Vooooo`03o`00oooooooooooo07Gooooo0Ol00001ooooo`00
00?o0000ooooooooool0;oooool00`000?ooooooooooo`18ooooo`03ool00?oooooooooo02Oooooo
00?o003oooooooooool0M?ooool1o`00007ooooo00000ol0003oooooooooo`0_ooooo`030000oooo
oooooooo00Oooooo0_ooO`02ooooo`;oogl0>oooool00ooo003oooooooooo`0Wooooo`03o`00oooo
oooooooo07Cooooo0Ol00001ooooo`0000?o0000ooooooooool0;_ooool00`000?ooooooooooo`07
ooooo`Soogl0>Oooool00ooo003oooooooooo`0Yooooo`03o`00oooooooooooo07?ooooo0Ol00001
ooooo`0000?o0000ooooooooool0;_ooool00`000?ooooooooooo`07ooooo`Soogl0>Oooool00ooo
003oooooooooo`0Yooooo`03o`00oooooooooooo07?ooooo0Ol00001ooooo`0000?o0000oooooooo
ool0;Oooool00`000?ooooooooooo`09ooooo`Koogl08?ooool2oomo01Oooooo00?oo`00oooooooo
ool0:oooool00ol00?ooooooooooo`1booooo`7o00000Oooool00003o`000?oooooooooo02gooooo
00<0003oooooooooool02oooool4oomo01oooooo1?ooO`0Fooooo`03ool00?oooooooooo02_ooooo
00?o003oooooooooool0L_ooool1o`00007ooooo00000ol0003oo`00ooooo`0]ooooo`030000oooo
oooooooo00cooooo0_ooO`0Pooooo`Coogl05_ooool00ooo003oooooooooo`0[ooooo`03o`00oooo
oooooooo07;ooooo0Ol00001ooooo`0000?o0000ool00?ooool0;?ooool00`000?ooooooooooo`0`
ooooo`;oogl05_ooool00ooo003oooooooooo`0]ooooo`03o`00oooooooooooo077ooooo0Ol00001
ooooo`0000?o0000ool00?ooool0;?ooool00`000?ooooooooooo`18ooooo`03ool00?oooooooooo
02gooooo00?o003oooooooooool0LOooool1o`00007ooooo00000ol0003oooooool0000/ooooo`03
0000oooooooooooo04Sooooo00?oo`00ooooooooool0;Oooool00ol00?ooooooooooo`1aooooo`7o
00000Oooool00003o`000?ooooooo`0002_ooooo00<0003oooooooooool0B?ooool00ooo003ooooo
ooooo`0_ooooo`03o`00oooooooooooo073ooooo0Ol00001ooooo`0000Co0000ooooooooooooo`00
:_ooool00`000?ooooooooooo`03ooooo`;oogl0@oooool00ooo003oooooooooo`0_ooooo`03o`00
oooooooooooo073ooooo0Ol00001ooooo`0000Co0000ooooooooooooo`00:_ooool00`000?oooooo
ooooo`02ooooo`Coogl0@_ooool00ooo003oooooooooo`0_ooooo`03o`00oooooooooooo073ooooo
0Ol00001ooooo`0000Go0000ooooooooooooooooool0000Yooooo`030000oooooooooooo00;ooooo
1?ooO`11ooooo`03ool00?oooooooooo033ooooo00?o003oooooooooool0L?ooool1o`00007ooooo
00001Ol0003oooooooooooooooooo`0002Sooooo00<0003oooooooooool01?ooool2oomo04;ooooo
00?oo`00ooooooooool0<Oooool00ol00?ooooooooooo`1_ooooo`7o00000Oooool00003o`000?oo
oooooooo00;ooooo00?oo`00ooooooooool09Oooool00`000?ooooooooooo`17ooooo`03ool00?oo
oooooooo03;ooooo00?o003oooooooooool0Koooool1o`00007ooooo00000ol0003oooooooooo`02
ooooo`03ool00?oooooooooo02Gooooo00<0003oooooooooool0Aoooool00ooo003oooooooooo`0b
ooooo`03o`00oooooooooooo06oooooo0Ol00001ooooo`0000?o0000ooooooooool00oooool00ooo
003oooooooooo`0Tooooo`030000oooooooooooo04Kooooo00?oo`00ooooooooool0<oooool00ol0
0?ooooooooooo`1_ooooo`7o00000Oooool00003o`000?oooooooooo00Cooooo00?oo`00oooooooo
ool08oooool00`000?ooooooooooo`15ooooo`03ool00?oooooooooo03Cooooo00?o003ooooooooo
ool0Koooool1o`00007ooooo00000ol0003oooooooooo`05ooooo`03ool00?oooooooooo027ooooo
00<0003oooooooooool0AOooool00ooo003oooooooooo`0fooooo`03o`00oooooooooooo06kooooo
0Ol00001ooooo`0000?o0000ooooooooool01_ooool00ooo003oooooooooo`0Pooooo`030000oooo
oooooooo04Gooooo00?oo`00ooooooooool02Oooool2oomo02_ooooo00?o003oooooooooool0K_oo
ool1o`00007ooooo00000ol0003oooooooooo`06ooooo`03ool00?oooooooooo023ooooo00<0003o
ooooooooool0A?ooool00ooo003oooooooooo`09ooooo`Coogl0:_ooool00ol00?ooooooooooo`1^
ooooo`7o00000Oooool00003o`000?oooooooooo00Oooooo00?oo`00ooooooooool07oooool00`00
0?ooooooooooo`0Xooooo`;oogl06Oooool00ooo003oooooooooo`0:ooooo`Coogl0:_ooool00ol0
0?ooooooooooo`1^ooooo`7o00000Oooool00003o`000?oooooooooo00Oooooo00?oo`00oooooooo
ool07oooool00`000?ooooooooooo`0Wooooo`Coogl05oooool00ooo003oooooooooo`0<ooooo`;o
ogl0:oooool00ol00?ooooooooooo`1^ooooo`7o00000Oooool00003o`000?oooooooooo00Sooooo
00?oo`00ooooooooool07_ooool00`000?ooooooooooo`0Wooooo`Coogl05oooool00ooo003ooooo
ooooo`0iooooo`03o`00oooooooooooo06kooooo0Ol00001ooooo`0000?o0000ooooooooool02Ooo
ool00ooo003oooooooooo`0Mooooo`030000oooooooooooo02Sooooo0_ooO`0Booooo`Co003o00?o
ooooool00?ooool0>oooool00ol00?ooooooooooo`1^ooooo`7o00000Oooool00003o`000?oooooo
oooo00[ooooo00?oo`00ooooooooool07?ooool00`000?ooooooooooo`0kooooo`Ko003o?Oooool0
0ol00?ooooooooooo`1^ooooo`7o00000Oooool00003o`000?oooooooooo00_ooooo00?oo`00oooo
ooooool06oooool00`000?ooooooooooo`0gooooo`;oogl000?oooooo`00ool00?l01_l00?lloooo
o`03o`00oooooooooooo06kooooo0Ol00001ooooo`0000?o0000ooooooooool03?ooool00ooo003o
ooooooooo`0Jooooo`030000oooooooooooo03Kooooo1?ooO`08o`00occooooo00?o003ooooooooo
ool0K_ooool1o`00007ooooo00000ol0003oooooooooo`0=ooooo`03ool00?oooooooooo01Wooooo
00<0003oooooooooool0=_ooool4oomo00So003o??ooool00ol00?ooooooooooo`1^ooooo`7o0000
0Oooool00003o`000?oooooooooo00gooooo0_oo000Jooooo`030000oooooooooooo03Oooooo0_oo
O`000ooooooo003oo`00o`06o`00occooooo00?o003oooooooooool0K_ooool1o`00007ooooo0000
0ol0003oooooooooo`0?ooooo`03ool00?oooooooooo01Oooooo00<0003oooooooooool0>_ooool0
0ooo003o003oo`00o`04o`00ocgooooo00?o003oooooooooool0K_ooool1o`00007ooooo00000ol0
003oooooooooo`0@ooooo`03ool00?oooooooooo01Kooooo00<0003oooooooooool0>Oooool00ooo
003oooooooooo`04o`00ockooooo00?o003oooooooooool0K_ooool1o`00007ooooo00000ol0003o
ooooooooo`0Aooooo`03ool00?oooooooooo01Gooooo00<0003oooooooooool0>?ooool00ooo003o
ooooooooo`13ooooo`03o`00oooooooooooo06kooooo0Ol00001ooooo`0000?o0000ooooooooool0
4_ooool00ooo003oooooooooo`0Dooooo`030000oooooooooooo03Kooooo0_oo0016ooooo`03o`00
oooooooooooo06kooooo0Ol00001ooooo`0000?o0000ooooooooool04oooool00ooo003ooooooooo
o`0Cooooo`030000oooooooooooo03Gooooo00?oo`00ooooooooool0A_ooool00ol00?oooooooooo
o`1^ooooo`7o00000Oooool00003o`000?oooooooooo01Cooooo0_oo000Cooooo`030000oooooooo
oooo03Cooooo00?oo`00ooooooooool0Aoooool00ol00?ooooooooooo`1^ooooo`7o00000Oooool0
0003o`000?oooooooooo01Kooooo0_oo000Aooooo`030000oooooooooooo03;ooooo0_oo001:oooo
o`03o`00oooooooooooo06kooooo0Ol00001ooooo`0000?o0000ooooooooool06?ooool00ooo003o
ooooooooo`0>ooooo`030000oooooooooooo037ooooo00?oo`00ooooooooool0B_ooool00ol00?oo
ooooooooo`1^ooooo`7o00000Oooool00003o`000?oooooooooo01Wooooo0_oo000>ooooo`030000
oooooooooooo02oooooo0_oo001=ooooo`03o`00oooooooooooo06kooooo0Ol00001ooooo`0000?o
0000ooooooooool06oooool00ooo003oooooooooo`0;ooooo`030000oooooooooooo02kooooo00?o
o`00ooooooooool0C?ooool00ol00?ooooooooooo`1_ooooo`7o00000Oooool00003o`000?oooooo
oooo01cooooo0_oo000;ooooo`030000oooooooooooo02gooooo00?oo`00ooooooooool0COooool0
0ol00?ooooooooooo`1_ooooo`7o00000Oooool00003o`000?oooooooooo01kooooo0ooo0009oooo
o`030000oooooooooooo02[ooooo0_oo001@ooooo`03o`00oooooooooooo06oooooo0Ol00001oooo
o`0000?o0000ooooooooool08Oooool2ool000Oooooo00<0003oooooooooool09oooool3ool005;o
oooo00?o003oooooooooool0Koooool1o`00007ooooo00000ol0003oooooooooo`0Sooooo`;oo`00
1Oooool00`000?ooooooooooo`0Uooooo`;oo`00E?ooool00ol00?ooooooooooo`1`ooooo`7o0000
0Oooool00003o`000?oooooooooo02Gooooo1?oo00000oooool0003oooooo`0Rooooo`Coo`00E_oo
ool00ol00?ooooooooooo`1`ooooo`7o00000Oooool00003o`000?oooooooooo02Wooooo0_oo0000
0ol00?ooo`00ool0000Mooooo`?oo`00F_ooool00ol00?ooooooooooo`1`ooooo`7o00000Oooool0
0003o`000?oooooooooo02_ooooo00<0003oooooooooool00ooo000Dooooo`Koo`00GOooool00ol0
0?ooooooooooo`1`ooooo`7o00000Oooool00003o`000?oooooooooo02cooooo00<0003ooooooooo
ool00_oooolDool006;ooooo00?o003oooooooooool0LOooool1o`00007ooooo00000ol0003ooooo
ooooo`0/ooooo`030000oooooooooooo07Sooooo00?o003oooooooooool0LOooool1o`00007ooooo
00000ol0003oooooooooo`0/ooooo`030000oooooooooooo07Sooooo00?o003oooooooooool0LOoo
ool1o`00007ooooo00000ol0003oooooooooo`0]ooooo`030000oooooooooooo07Kooooo00?o003o
ooooooooool0L_ooool1o`00007ooooo00000ol0003oooooooooo`0]ooooo`030000oooooooooooo
07Kooooo00?o003oooooooooool0L_ooool1o`00007ooooo00000ol0003oooooooooo`0]ooooo`03
0000oooooooooooo07Kooooo00?o003oooooooooool0L_ooool1o`00007ooooo00000ol0003ooooo
ooooo`0^ooooo`030000oooooooooooo07Cooooo00?o003oooooooooool0Loooool1o`00007ooooo
00000ol0003oooooooooo`0^ooooo`030000oooooooooooo07Cooooo00?o003oooooooooool0Looo
ool1o`00007ooooo00000ol0003oooooooooo`0^ooooo`030000oooooooooooo07Cooooo00?o003o
ooooooooool0Loooool1o`00007ooooo00000ol0003oooooooooo`0_ooooo`030000oooooooooooo
07;ooooo00?o003oooooooooool0M?ooool1o`00007ooooo00000ol0003oooooooooo`0_ooooo`03
0000oooooooooooo07;ooooo00?o003oooooooooool0M?ooool1o`00007ooooo00000ol0003ooooo
ooooo`0_ooooo`030000oooooooooooo07;ooooo00?o003oooooooooool0M?ooool1o`00007ooooo
00000ol0003oooooooooo`0`ooooo`030000oooooooooooo06oooooo0_l00?mgooooo`7o00000Ooo
ool00003o`000?oooooooooo033ooooo00<0003oooooooooool0Koooool00ol00?ooooooooooo`1f
ooooo`7o00000Oooool00003o`000?oooooooooo037ooooo00<0003oooooooooool0KOooool00ol0
0?ooooooooooo`1gooooo`7o00000Oooool00003o`000?oooooooooo03;ooooo00<0003ooooooooo
ool0K?ooool00ol00?ooooooooooo`1gooooo`7o00000Oooool00003o`000?oooooooooo03;ooooo
00<0003oooooooooool0Joooool00ol00?ooooooooooo`1Pooooo`;oogl05_ooool1o`00007ooooo
00000ol0003oooooooooo`0cooooo`030000oooooooooooo06Wooooo00?o003oooooooooool0H?oo
ool4oomo01Gooooo0Ol00001ooooo`0000?o0000ooooooooool0=?ooool00`000?ooooooooooo`1X
ooooo`03o`00oooooooooooo063ooooo1?ooO`0Eooooo`7o00000Oooool00003o`000?oooooooooo
03Gooooo00<0003oooooooooool0I_ooool00ol00?ooooooooooo`1Rooooo`;oogl05_ooool1o`00
007ooooo00000ol0003oooooooooo`0eooooo`03o`00oooooooooooo06Kooooo00?o003ooooooooo
ool0N_ooool1o`00007ooooo00000ol0003oooooooooo`0fooooo`03o`00oooooooooooo06Cooooo
00?o003oooooooooool0Noooool1o`00007ooooo00000ol0003oooooooooo`0gooooo`03o`00oooo
oooooooo06;ooooo00?o003oooooooooool0O?ooool1o`00007ooooo00000ol0003oooooooooo`0h
ooooo`03o`00oooooooooooo05oooooo0_l00?moooooo`7o00000Oooool00003o`000?oooooooooo
03Wooooo00?o003oooooooooool0GOooool00ol00?ooooooooooo`1oooooo`7o00000Oooool00003
o`000?oooooooooo03[ooooo00?o003oooooooooool0Foooool00ol00?ooooooooooo`20ooooo`7o
00000Oooool00003o`000?oooooooooo03_ooooo00?o003oooooooooool0FOooool00ol00?oooooo
ooooo`21ooooo`7o00000Oooool00003o`000?oooooooooo03cooooo00?o003oooooooooool0Eooo
ool00ol00?ooooooooooo`22ooooo`7o00000Oooool00003o`000?oooooooooo03gooooo00?o003o
ooooooooool0EOooool00ol00?ooooooooooo`23ooooo`7o00000Oooool00003o`000?oooooooooo
03kooooo00?o003oooooooooool0Doooool00ol00?ooooooooooo`24ooooo`7o00000Oooool00003
o`000?oooooooooo03oooooo00?o003oooooooooool0D?ooool2o`00ob7ooooo0_ooO`1Tooooo`7o
00000Oooool00003o`000?oooooooooo043ooooo00?o003oooooooooool0C_ooool00ol00?oooooo
ooooo`0Pooooo`Coogl0Hoooool1o`00007ooooo00000ol0003oooooooooo`11ooooo`;o003oCOoo
ool00ol00?ooooooooooo`0Qooooo`Coogl0Hoooool1o`00007ooooo00000ol0003oooooooooo`13
ooooo`03o`00oooooooooooo04Wooooo00?o003oooooooooool08oooool2oomo03Gooooo0_ooO`0]
ooooo`7o00000Oooool00003o`000?oooooooooo04Cooooo0_l00?m8ooooo`03o`00oooooooooooo
05?ooooo0_ooO`05ooooo`Coogl0;?ooool1o`00007ooooo00000ol0003oooooooooo`16ooooo`;o
003oAOooool00ol00?ooooooooooo`1Cooooo`Coogl01?ooool4oomo02cooooo0Ol00001ooooo`00
00?o0000ooooooooool0B?ooool00ol00?ooooooooooo`10ooooo`;o003o=_ooool2oomo01kooooo
1?ooO`05ooooo`;oogl0;Oooool1o`00007ooooo00000ol0003oooooooooo`19ooooo`;o003o?_oo
ool2o`00ocOooooo1?ooO`0Nooooo`;oogl0=Oooool1o`00007ooooo00000ol0003oooooooooo`1;
ooooo`?o003o>_ooool00ol00?ooooooooooo`0gooooo`Coogl0EOooool1o`00007ooooo00000ol0
003oooooooooo`1>ooooo`;o003o=_ooool2o`00oc_ooooo0_ooO`1Fooooo`7o00000Oooool00003
o`000?oooooooooo053ooooo0ol00?l`ooooo`?o003o<oooool2oomo017ooooo1Ooo0?l?ooooo`;o
ogl0>Oooool1o`00007ooooo00000ol0003oooooooooo`1Cooooo`;o003o:_ooool4o`00ocGooooo
1?ooO`0?ooooo`Ooo`3o3Oooool4oomo03Sooooo0Ol00001ooooo`0000?o0000ooooooooool0EOoo
ool3o`00ob?ooooo1?l00?leooooo`;oogl00_ooool4oomo00kooooo2Ooo0?l<ooooo`Coogl00ooo
ool2oomo03?ooooo0Ol00001ooooo`0000?o0000ooooooooool0F?ooool3o`00oagooooo0ol00?lh
ooooo`Coogl00_ooool2oomo00kooooo2ooo0?l<ooooo`;oogl00oooool4oomo03;ooooo0Ol00001
ooooo`0000?o0000ooooooooool0Foooool3o`00oaCooooo1_l00?lkooooo`Coogl01_ooool2oomo
00[ooooo2ooo0?lAooooo`Coogl0<_ooool1o`00007ooooo00000ol0003oooooooooo`1NoooooaCo
003o@_ooool2oomo00Kooooo1?ooO`09ooooo`_oo`3o4_ooool2oomo03?ooooo0Ol00001ooooo`00
00?o0000ooooooooool0Roooool2oomo02Oooooo0_ooO`06ooooo`Coogl02Oooool;ool0odOooooo
0Ol00001ooooo`0000?o0000ooooooooool0R_ooool4oomo02Gooooo1?ooO`06ooooo`;oogl02_oo
ool;ool0odOooooo0Ol00001ooooo`0000?o0000ooooooooool0R_ooool4oomo02Gooooo1?ooO`0C
ooooo`Woo`3oB?ooool1o`00007ooooo00000ol0003oooooooooo`2;ooooo`;oogl09oooool2oomo
01Gooooo1ooo0?m9ooooo`7o00000Oooool00003o`000?oooooooooo09Kooooo0_ooO`0dooooo`Go
o`3o00?ooooooomo0?ooO`00Aoooool1o`00007ooooo00000ol0003oooooooooo`2Eooooo`Coogl0
3_ooool2oomo02Sooooo1?ooO`16ooooo`7o00000Oooool00003o`000?oooooooooo09Gooooo1?oo
O`0=ooooo`Coogl09oooool4oomo04Kooooo0Ol00001ooooo`0000?o0000ooooooooool0U_ooool2
oomo00kooooo1?ooO`0Xooooo`;oogl0Aoooool1o`00007ooooo00000ol0003oooooooooo`2Woooo
o`;oogl0L_ooool1o`00007ooooo00000ol0003oooooooooo`3[ooooo`;oogl0;_ooool1o`00007o
oooo00000ol0003oooooooooo`3Zooooo`Coogl0;Oooool1o`00007ooooo00000ol0003ooooooooo
o`3Fooooo`;oogl04_ooool4oomo02gooooo0Ol00001ooooo`0000?o0000ooooooooool0eOooool4
oomo01;ooooo0_ooO`0^ooooo`7o00000Oooool00003o`000?oooooooooo0;Oooooo0_ooO`0Loooo
o`Coogl0@_ooool1o`00007ooooo00000ol0003oooooooooo`2fooooo`Coogl07?ooool2oomo04?o
oooo0Ol00001ooooo`0000?o0000ooooooooool0/oooool2oomo0003ooooooooO`3oogl000;oogl0
HOooool1o`00007ooooo00000ol0003oooooooooo`2Xooooo`;oogl02?ooool4oomo0003oooooooo
O`3oogl001[ooooo0_ooO`16ooooo`7o00000Oooool00003o`000?oooooooooo0:Kooooo1OooO`07
ooooo`Coogl05oooool2oomo00?ooooo1?ooO`15ooooo`7o00000Oooool00003o`000?oooooooooo
0:Gooooo1_ooO`08ooooo`;oogl05oooool4oomo00;ooooo1?ooO`15ooooo`7o00000Oooool00003
o`000?oooooooooo0:Gooooo1OooO`0Rooooo`Coogl00oooool2oomo04Kooooo0Ol00001ooooo`00
00?o0000ooooooooool0M_ooool2oomo02kooooo0_ooO`0Uooooo`;oogl0C?ooool1o`00007ooooo
00000ol0003oooooooooo`1eooooo`Coogl0X_ooool1o`00007ooooo00000ol0003oooooooooo`1e
ooooo`Coogl02_ooool2oomo09Kooooo0Ol00001ooooo`0000?o0000ooooooooool0M_ooool2oomo
00[ooooo1?ooO`0Zooooo`;oogl0JOooool1o`00007ooooo00000ol0003oooooooooo`22ooooo`Co
ogl0:Oooool4oomo06Sooooo0Ol00001ooooo`0000?o0000ooooooooool0Poooool2oomo02Cooooo
0_ooO`04ooooo`Coogl0J?ooool1o`00007ooooo00000ol0003oooooooooo`2Xooooo`Coogl01?oo
ool2oomo06Wooooo0Ol00001ooooo`0000?o0000ooooooooool0Z?ooool4oomo06oooooo0Ol00001
ooooo`0000?o0000ooooooooool0ZOooool2oomo073ooooo0Ol00001ooooo`0000?o0000oooooooo
ool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo
00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolL
ooooo`7o00000Oooool00003o`000?oooooooooo08Cooooo0_ooO`2Eooooo`7o00000Oooool00003
o`000?oooooooooo08?ooooo1?ooO`2Dooooo`7o00000Oooool00003o`000?oooooooooo08?ooooo
1?ooO`2Dooooo`7o00000Oooool00003o`000?oooooooooo08Cooooo0_ooO`0/ooooo`;oogl0Iooo
ool1o`00007ooooo00000ol0003oooooooooo`2aooooo`Coogl0I_ooool1o`00007ooooo00000ol0
003oooooooooo`2aooooo`Coogl0I_ooool1o`00007ooooo00000ol0003oooooooooo`2booooo`;o
ogl0Ioooool1o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o
0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo07_ooooo0_ooO`2N
ooooo`7o00000Oooool00003o`000?oooooooooo07[ooooo1?ooO`2Mooooo`7o00000Oooool00003
o`000?oooooooooo07[ooooo1?ooO`0Pooooo`;oogl0Noooool1o`00007ooooo00000ol0003ooooo
ooooo`1kooooo`;oogl08?ooool4oomo07[ooooo0Ol00001ooooo`0000?o0000ooooooooool0WOoo
ool4oomo07[ooooo0Ol00001ooooo`0000?o0000ooooooooool0T?ooool2oomo00cooooo0_ooO`1k
ooooo`7o00000Oooool00003o`000?oooooooooo08oooooo1?ooO`28ooooo`7o00000Oooool00003
o`000?oooooooooo08oooooo1?ooO`28ooooo`7o00000Oooool00003o`000?oooooooooo093ooooo
0_ooO`0Sooooo`;oogl0I?ooool1o`00007ooooo00000ol0003oooooooooo`2dooooo`Coogl0Hooo
ool1o`00007ooooo00000ol0003oooooooooo`2dooooo`Coogl0Hoooool1o`00007ooooo00000ol0
003oooooooooo`2eooooo`;oogl0I?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooooaco
oooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oo
oooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001
ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo0?oo
oooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o
0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1
o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000oooooooo
ool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo
00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolL
ooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003o
ooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o0000
0Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3o
oooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003
o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo
0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oooooo
oooo0?oooooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001oooo
o`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo
7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000
ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00
007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0
oooooolLooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo0000
0ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLoooo
o`7o00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003ooooo
ooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0S_ooool2oomo08_ooooo0Ol0
0001ooooo`0000?o0000ooooooooool0SOooool4oomo08[ooooo0Ol00001ooooo`0000?o0000oooo
ooooool0SOooool4oomo08[ooooo0Ol00001ooooo`0000?o0000ooooooooool0S_ooool2oomo08_o
oooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oo
oooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001
ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo0?oo
oooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o
0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1
o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000oooooooo
ool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo
00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolL
ooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003o
ooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o0000
0Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3o
oooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003
o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo
0Ol00001ooooo`00ool0000Po`00007ooooo0000\
\>"],
  ImageRangeCache->{{{0, 287}, {287, 0}} -> {-1.01089, -1.01089, 0.00704453, \
0.00704453}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.49505 0.5 0.49505 [
[ 0 0 -0.125 0 ]
[ 0 0 -0.125 0 ]
[ 0 1 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
0 0 m
1 0 L
s
0 0 m
0 1 L
s
0 1 m
1 1 L
s
1 0 m
1 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
1 .5 0 r
.015 w
.03175 .1355 Mdot
.03435 .12523 Mdot
.11137 .12765 Mdot
.14107 .18841 Mdot
.16218 .24538 Mdot
.17294 .21053 Mdot
.18267 .18577 Mdot
.18434 .1304 Mdot
.18553 .30956 Mdot
.20401 .239 Mdot
.21247 .27571 Mdot
.21687 .20845 Mdot
.22376 .2799 Mdot
.22832 .27485 Mdot
.29063 .20974 Mdot
.29686 .25079 Mdot
.30487 .22936 Mdot
.30683 .34623 Mdot
.32055 .20902 Mdot
.32574 .21979 Mdot
.34472 .28521 Mdot
.35998 .36393 Mdot
.36335 .24976 Mdot
.3794 .36608 Mdot
.42386 .66992 Mdot
.44391 .74519 Mdot
.45059 .34198 Mdot
.47208 .67586 Mdot
.47436 .71381 Mdot
.49778 .59825 Mdot
.50874 .91643 Mdot
.51516 .76219 Mdot
.53655 .61374 Mdot
.56563 .75219 Mdot
.59189 .65665 Mdot
.59581 .61604 Mdot
.59923 .6556 Mdot
.60292 .68499 Mdot
.62656 .67779 Mdot
.63555 .72451 Mdot
.63919 .652 Mdot
.64169 .6004 Mdot
.64246 .58611 Mdot
.64496 .54267 Mdot
.64608 .77288 Mdot
.65077 .64308 Mdot
.66065 .57816 Mdot
.67474 .59169 Mdot
.69296 .563 Mdot
.72815 .65902 Mdot
.73169 .58879 Mdot
.74669 .61318 Mdot
.74821 .65474 Mdot
.75963 .63781 Mdot
.79673 .57809 Mdot
.80925 .55852 Mdot
.81525 .58444 Mdot
.83417 .62985 Mdot
.83598 .55526 Mdot
.91595 .49319 Mdot
1 0 0 r
.005 w
.00495 .28842 m
.00628 .29156 L
.01857 .31761 L
.03101 .33781 L
.03525 .34367 L
.05706 .36884 L
.05795 .36972 L
.08312 .39115 L
.08963 .39578 L
.10917 .40763 L
.13523 .41964 L
.14074 .42183 L
.16128 .42794 L
.18734 .43294 L
.21339 .43485 L
.23945 .43375 L
.2655 .42959 L
.29156 .42219 L
.29261 .42183 L
.31761 .41124 L
.34367 .39603 L
.34405 .39578 L
.36972 .37551 L
.37582 .36972 L
.39578 .34724 L
.39849 .34367 L
.41525 .31761 L
.42183 .30485 L
.4275 .29156 L
.436 .2655 L
.44117 .23945 L
.44325 .21339 L
.44232 .18734 L
.43834 .16128 L
.43114 .13523 L
.42183 .11212 L
.42037 .10917 L
.40546 .08312 L
.39578 .06961 L
.38528 .05706 L
.36972 .04137 L
.35758 .03101 L
.34367 .02092 L
.31761 .00569 L
.3162 .00495 L
s
.00495 .12854 m
.01344 .10917 L
.02832 .08312 L
.03101 .07912 L
.04848 .05706 L
.05706 .04802 L
.07619 .03101 L
.08312 .02579 L
.10917 .00934 L
.11742 .00495 L
s
0 0 1 r
.29156 .15739 m
.31761 .14824 L
.34367 .14249 L
.36972 .13986 L
.39578 .14025 L
.42183 .14366 L
.44789 .15025 L
.47394 .16034 L
.47599 .16128 L
.5 .17443 L
.51844 .18734 L
.52606 .19355 L
.54662 .21339 L
.55211 .21962 L
.56712 .23945 L
.57817 .25755 L
.58227 .2655 L
.59322 .29156 L
.60058 .31761 L
.60422 .3392 L
.60471 .34367 L
.6058 .36972 L
.60422 .39297 L
.60387 .39578 L
.59886 .42183 L
.59054 .44789 L
.57848 .47394 L
.57817 .47453 L
.562 .5 L
.55211 .51255 L
.53968 .52606 L
.52606 .53862 L
.50853 .55211 L
.5 .55773 L
.47394 .57183 L
.45901 .57817 L
.44789 .5819 L
.42183 .5885 L
.39578 .59192 L
.36972 .59231 L
.34367 .58968 L
.31761 .58392 L
.29972 .57817 L
.29156 .57477 L
.2655 .56178 L
.25025 .55211 L
.23945 .54409 L
.21914 .52606 L
.21339 .52008 L
.19681 .5 L
Mistroke
.18734 .48608 L
.18031 .47394 L
.16827 .44789 L
.16128 .42714 L
.15996 .42183 L
.15493 .39578 L
.153 .36972 L
.15409 .34367 L
.15823 .31761 L
.16128 .3045 L
.16559 .29156 L
.17653 .2655 L
.18734 .24609 L
.19169 .23945 L
.21221 .21339 L
.21339 .21211 L
.23945 .1881 L
.24041 .18734 L
.2655 .17038 L
.28271 .16128 L
.29156 .15739 L
Mfstroke
1 0 0 r
.03 w
.21687 .20845 Mdot
0 0 1 r
.3794 .36608 Mdot
1 0 0 r
.79703 .00495 m
.79703 .02508 L
.87129 .02508 L
.87129 .00495 L
F
0 0 1 r
.89604 .00495 m
.89604 .23234 L
.9703 .23234 L
.9703 .00495 L
F
1 0 1 r
.04 w
.74669 .61318 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P000182000`400?l00000o`00003ooooooolQ
ooooo`00ool0000Po`00007ooooo00000ol0003oooooooooo`0Mooooo`;oo`00>?ooool3ool00<7o
oooo0Ol00001ooooo`0000?o0000ooooooooool06oooool2ool003gooooo00?oo`00ooooooooool0
Q?oooolEool000Sooooo5Ol00?l8ooooo`7o00000Oooool00003o`000?oooooooooo01[ooooo00?o
o`00ooooooooool0?_ooool2ool008Cooooo5Ooo0008oooooaGo003o2?ooool1o`00007ooooo0000
0ol0003oooooooooo`0Hooooo`;oo`00@oooool00ooo003oooooooooo`21oooooaGoo`002?oooolE
o`00o`Sooooo0Ol00001ooooo`0000?o0000ooooooooool05_ooool2ool004Kooooo00?oo`00oooo
ooooool0P?oooolEool000Sooooo5Ol00?l8ooooo`7o00000Oooool00003o`000?oooooooooo01Go
oooo00?oo`00ooooooooool0Aoooool2ool0083ooooo5Ooo0008oooooaGo003o2?ooool1o`00007o
oooo00000ol0003oooooooooo`0Dooooo`03ool00?oooooooooo04[ooooo00?oo`00ooooooooool0
OOoooolEool000Sooooo5Ol00?l8ooooo`7o00000Oooool00003o`000?oooooooooo01?ooooo00?o
o`00ooooooooool0C?ooool00ooo003oooooooooo`2IoooooaGo003o2?ooool1o`00007ooooo0000
0ol0003oooooooooo`0Aooooo`;oo`00D?ooool2ool009Wooooo5Ol00?l8ooooo`7o00000Oooool0
0003o`000?oooooooooo013ooooo00?oo`00ooooooooool0D_ooool2ool009Oooooo5Ol00?l8oooo
o`7o00000Oooool00003o`000?oooooooooo00oooooo00?oo`00ooooooooool0EOooool00ooo003o
ooooooooo`2DoooooaGo003o2?ooool1o`00007ooooo00000ol0003oooooooooo`0>ooooo`03ool0
0?oooooooooo05Kooooo00?oo`00ooooooooool0U?oooolEo`00o`Sooooo0Ol00001ooooo`0000?o
0000ooooooooool03Oooool00ooo003oooooooooo`1Hooooo`03ool00?oooooooooo09?ooooo5Ol0
0?l8ooooo`7o00000Oooool00003o`000?oooooooooo00gooooo00?oo`00ooooooooool0FOooool0
0ooo003oooooooooo`2BoooooaGo003o2?ooool1o`00007ooooo00000ol0003oooooooooo`0<oooo
o`03ool00?oooooooooo05_ooooo00?oo`00ooooooooool0TOoooolEo`00o`Sooooo0Ol00001oooo
o`0000?o0000ooooooooool02oooool00ooo003oooooooooo`1Mooooo`03ool00?oooooooooo093o
oooo5Ol00?l8ooooo`7o00000Oooool00003o`000?oooooooooo00_ooooo00?oo`00ooooooooool0
GOooool00ooo003oooooooooo`2@oooooaGo003o2?ooool1o`00007ooooo00000ol0003ooooooooo
o`0:ooooo`03ool00?oooooooooo05oooooo00?oo`00ooooooooool0SooooolEo`00o`Sooooo0Ol0
0001ooooo`0000?o0000ooooooooool02Oooool00ooo003oooooooooo`1Qooooo`03ool00?oooooo
oooo08kooooo5Ol00?l8ooooo`7o00000Oooool00003o`000?oooooooooo00Sooooo00?oo`00oooo
ooooool0Hoooool00ooo003oooooooooo`2=oooooaGo003o2?ooool1o`00007ooooo00000ol0003o
ooooooooo`07ooooo`03ool00?oooooooooo06Gooooo00?oo`00ooooooooool0S?oooolEo`00o`So
oooo0Ol00001ooooo`0000?o0000ooooooooool01_ooool00ooo003oooooooooo`1Wooooo`03ool0
0?oooooooooo08_ooooo5Ol00?l8ooooo`7o00000Oooool00003o`000?oooooooooo00Gooooo00?o
o`00ooooooooool0JOooool00ooo003oooooooooo`2:oooooaGo003o2?ooool1o`00007ooooo0000
0ol0003oooooooooo`05ooooo`03ool00?oooooooooo06Wooooo00?oo`00ooooooooool0R_oooolE
o`00o`Sooooo0Ol00001ooooo`0000?o0000ooooooooool01?ooool00ooo003oooooooooo`1[oooo
o`03ool00?oooooooooo08Wooooo5Ol00?l8ooooo`7o00000Oooool00003o`000?oooooooooo00?o
oooo00?oo`00ooooooooool0K?ooool00ooo003oooooooooo`29oooooaGo003o2?ooool1o`00007o
oooo00000ol0003oooooooooo`03ooooo`03ool00?oooooooooo06gooooo00?oo`00ooooooooool0
R?oooolEo`00o`Sooooo0Ol00001ooooo`0000?o0000ooooooooool00_ooool00ooo003ooooooooo
o`1^ooooo`03ool00?oooooooooo08Sooooo5Ol00?l8ooooo`7o00000Oooool00003o`000?oooooo
oooo00;ooooo00?oo`00ooooooooool0Koooool00ooo003oooooooooo`27oooooaGo003o2?ooool1
o`00007ooooo00001Ol0003oooooooooooooooooo`0007;ooooo00?oo`00ooooooooool0QooooolE
o`00o`Sooooo0Ol00001ooooo`0000Co0000ooooooooooooo`00M?ooool00ooo003oooooooooo`26
oooooaGo003o2?ooool1o`00007ooooo00001?l0003ooooooooooooo001eooooo`03ool00?oooooo
oooo08Gooooo5Ol00?l8ooooo`7o00000Oooool00003o`000?ooooooo`0007Kooooo00?oo`00oooo
ooooool0QOoooolEo`00o`Sooooo0Ol00001ooooo`0000?o0000oooooooo00001_ooool2oomo06oo
oooo00?oo`00ooooooooool0Q?oooolEo`00o`Sooooo0Ol00001ooooo`0000?o0000oooooooo0000
1Oooool4oomo01?ooooo0_ooO`1Iooooo`03ool00?oooooooooo08Cooooo5Ol00?l8ooooo`7o0000
0Oooool00003o`000?oo003ooooo00Gooooo1?ooO`0Booooo`Coogl04_ooool2oomo04Cooooo00?o
o`00ooooooooool0Q?oooolEo`00o`Sooooo0Ol00001ooooo`0000?o0000ooooooooool01Oooool3
oomo01?ooooo1?ooO`0Aooooo`Coogl0A?ooool00ooo003oooooooooo`23oooooaGo003o2?ooool1
o`00007ooooo00000ol0003oooooooooo`04ooooo`Coogl05?ooool2oomo01;ooooo1?ooO`14oooo
o`03ool00?oooooooooo08?ooooo5Ol00?l8ooooo`7o00000Oooool00003o`000?oooooooooo00Co
oooo1?ooO`0Yooooo`;oogl0AOooool00ooo003oooooooooo`23oooooaGo003o2?ooool1o`00007o
oooo00000ol0003oooooooooo`05ooooo`;oogl0E_oooolFo`00o`Gooooo00?oo`00ooooooooool0
PooooolEo`00o`Sooooo0Ol00001ooooo`0000?o0000ooooooooool0F_ooool3o`00oaKooooo1_l0
0?l00ooo003oooooooooo`22oooooaGo003o2?ooool1o`00007ooooo00000ol0003oooooooooo`1G
ooooo`?o003o7oooool3o`00oh;ooooo5Ol00?l8ooooo`7o00000Oooool00003o`000?oooooooooo
05Cooooo0ol00?lRooooo`03ool00?oooooooooo00?o003oOooooolEo`00o`Sooooo0Ol00001oooo
o`0000?o0000ooooooooool0DOooool3o`00obGooooo00?oo`00ooooooooool00oooool3o`00ogco
oooo5Ol00?l8ooooo`7o00000Oooool00003o`000?oooooooooo04oooooo0P000?lYooooo`03ool0
0?oooooooooo00Gooooo0ol00?mioooooaGo003o2?ooool1o`00007ooooo00000ol0003ooooooooo
o`1=ooooo`80003o:oooool00ooo003oooooooooo`08ooooo`;o003oMooooolEo`00o`Sooooo0Ol0
0001ooooo`0000?o0000ooooooooool0B_ooool30000obgooooo00?oo`00ooooooooool02_ooool2
o`00ogGooooo5Ol00?l8ooooo`7o00000Oooool00003o`000?oooooooooo04Sooooo0P000?l`oooo
o`03ool00?oooooooooo00cooooo00?o003oooooooooool0L_oooolEo`00o`Sooooo0Ol00001oooo
o`0000?o0000ooooooooool0Aoooool00`000?ooooooooooo`0`ooooo`03ool00?oooooooooo00go
oooo0_l00?mboooooaGo003o2?ooool1o`00007ooooo00000ol0003oooooooooo`15ooooo`80003o
=?ooool00ooo003oooooooooo`0>ooooo`;o003oL?oooolEo`00o`Sooooo0Ol00001ooooo`0000?o
0000ooooooooool0A?ooool00`000?ooooooooooo`0dooooo`03ool00?oooooooooo013ooooo0_l0
0?m^oooooaGo003o2?ooool1o`00007ooooo00000ol0003oooooooooo`0Tooooo`;oogl02_ooool2
oomo017ooooo00<0003oooooooooool0=Oooool00ooo003oooooooooo`0Booooo`03o`00oooooooo
oooo06_ooooo5Ol00?l8ooooo`7o00000Oooool00003o`000?oooooooooo02?ooooo1?ooO`08oooo
o`Coogl03oooool00`000?ooooooooooo`0fooooo`03ool00?oooooooooo01?ooooo00?o003ooooo
ooooool0J_oooolEo`00o`Sooooo0Ol00001ooooo`0000?o0000ooooooooool08oooool4oomo00So
oooo1?ooO`0=ooooo`030000ool00?oooooo03Sooooo00?oo`00ooooooooool05?ooool00ol00?oo
ooooooooo`1YoooooaGo003o2?ooool1o`00007ooooo00000ol0003oooooooooo`0Tooooo`;oogl0
2_ooool2oomo00gooooo00<0003oooooooooool0>Oooool00ooo003oooooooooo`0Eooooo`03o`00
oooooooooooo06Sooooo5Ol00?l8ooooo`7o00000Oooool00003o`000?oooooooooo03Wooooo1?oo
00000oooool0003oooooo`0kooooo`03ool00?oooooooooo01Kooooo00?o003oooooooooool0Iooo
oolEo`00o`Sooooo0Ol00001ooooo`0000?o0000ooooooooool0>?ooool6ool003gooooo00?oo`00
ooooooooool05oooool00ol00?ooooooooooo`1VoooooaGo003o2?ooool1o`00007ooooo00000ol0
003oooooooooo`0gooooo`Soo`004?ooool2oomo00Oooooo0_ooO`0Rooooo`03ool00?oooooooooo
01Oooooo00?o003oooooooooool0IOoooolEo`00o`Sooooo0Ol00001ooooo`0000?o0000oooooooo
ool0;_ooool2oomo00Oooooo2?oo000?ooooo`Coogl01Oooool4oomo027ooooo00?oo`00oooooooo
ool06?ooool00ol00?ooooooooooo`1ToooooaGo003o2?ooool1o`00007ooooo00000ol0003ooooo
ooooo`0]ooooo`Coogl01_ooool8ool000oooooo1?ooO`05ooooo`Coogl08Oooool00ooo003ooooo
ooooo`0Iooooo`03o`00oooooooooooo06?ooooo5Ol00?l8ooooo`7o00000Oooool00003o`000?oo
oooooooo02gooooo1?ooO`06ooooo`Soo`004?ooool2oomo00Oooooo0oooO`0Qooooo`03ool00?oo
oooooooo01[ooooo00?o003oooooooooool0H_oooolEo`00o`Sooooo0Ol00001ooooo`0000?o0000
ooooooooool0;_ooool2oomo00Sooooo1_oo000Jooooo`Coogl08?ooool00ooo003oooooooooo`0K
ooooo`03o`00oooooooooooo067ooooo5Ol00?l8ooooo`7o00000Oooool00003o`000?oooooooooo
03Sooooo00<0003oool00?oo00000_oo000Kooooo`Coogl08?ooool00ooo003oooooooooo`0Loooo
o`03o`00oooooooooooo063ooooo5Ol00?l8ooooo`7o00000Oooool00003o`000?oooooooooo03Oo
oooo00<0003oooooooooool06Oooool2oomo00Cooooo0_ooO`0Qooooo`03ool00?oooooooooo01co
oooo00?o003oooooooooool0H?oooolEo`00o`Sooooo0Ol00001ooooo`0000?o0000ooooooooool0
=_ooool00`000?ooooooooooo`0Iooooo`Coogl09Oooool00ooo003oooooooooo`0Nooooo`03o`00
oooooooooooo05oooooo5Ol00?l8ooooo`7o00000Oooool00003o`000?oooooooooo03Kooooo00<0
003oooooooooool06Oooool4oomo02Gooooo00?oo`00ooooooooool07oooool00ol00?oooooooooo
o`1NoooooaGo003o2?ooool1o`00007ooooo00000ol0003oooooooooo`0eooooo`040000oooooooo
ogl0oomo01[ooooo0_ooO`0Vooooo`03ool00?oooooooooo023ooooo00?o003oooooooooool0N_oo
ool1o`00007ooooo00000ol0003oooooooooo`0dooooo`030000ooooooooogl000?oogl0@Oooool0
0ooo003oooooooooo`0Qooooo`03o`00oooooooooooo07Wooooo0Ol00001ooooo`0000?o0000oooo
ooooool0:oooool2oomo00Kooooo00<0003oooooooooool01?ooO`11ooooo`03ool00?oooooooooo
027ooooo00?o003oooooooooool0NOooool1o`00007ooooo00000ol0003oooooooooo`0Zooooo`Co
ogl01?ooool00`000?ooooooooooo`02ooooo`;oogl06?ooool2oomo017ooooo0_ooO`0Eooooo`03
ool00?oooooooooo02;ooooo00?o003oooooooooool0N?ooool1o`00007ooooo00000ol0003ooooo
ooooo`0Zooooo`Coogl01?ooool00`000?ooooooooooo`0Kooooo`Coogl03oooool4oomo01Cooooo
00?oo`00ooooooooool08oooool00ol00?ooooooooooo`1gooooo`7o00000Oooool00003o`000?oo
oooooooo02_ooooo0_ooO`04ooooo`030000oooooooooooo01cooooo1?ooO`0?ooooo`Coogl05?oo
ool00ooo003oooooooooo`0Sooooo`03o`00oooooooooooo07Oooooo0Ol00001ooooo`0000?o0000
ooooooooool0<Oooool00`000?ooooooooooo`0Mooooo`;oogl04Oooool2oomo01Cooooo00?oo`00
ooooooooool09Oooool00ol00?ooooooooooo`1fooooo`7o00000Oooool00003o`000?oooooooooo
033ooooo00<0003oooooooooool0Aoooool00ooo003oooooooooo`0Uooooo`03o`00oooooooooooo
07Kooooo0Ol00001ooooo`0000?o0000ooooooooool0<?ooool00`000?ooooooooooo`17ooooo`03
ool00?oooooooooo02Kooooo00?o003oooooooooool0MOooool1o`00007ooooo00000ol0003ooooo
ooooo`0_ooooo`030000oooooooooooo04Sooooo00?oo`00ooooooooool09oooool00ol00?oooooo
ooooo`1dooooo`7o00000Oooool00003o`000?oooooooooo02oooooo00<0003oooooooooool01ooo
ool2oomo00;ooooo0_ooO`0kooooo`03ool00?oooooooooo02Oooooo00?o003oooooooooool0M?oo
ool1o`00007ooooo00000ol0003oooooooooo`0^ooooo`030000oooooooooooo00Oooooo2?ooO`0i
ooooo`03ool00?oooooooooo02Wooooo00?o003oooooooooool0Loooool1o`00007ooooo00000ol0
003oooooooooo`0^ooooo`030000oooooooooooo00Oooooo2?ooO`0iooooo`03ool00?oooooooooo
02Wooooo00?o003oooooooooool0Loooool1o`00007ooooo00000ol0003oooooooooo`0]ooooo`03
0000oooooooooooo00Wooooo1_ooO`0Pooooo`;oogl05oooool00ooo003oooooooooo`0[ooooo`03
o`00oooooooooooo07;ooooo0Ol00001ooooo`0000?o0000ooooooooool0;Oooool00`000?oooooo
ooooo`0;ooooo`Coogl07oooool4oomo01Kooooo00?oo`00ooooooooool0:oooool00ol00?oooooo
ooooo`1booooo`7o00000Oooool00003o`000?oo003ooooo02gooooo00<0003oooooooooool03?oo
ool2oomo023ooooo1?ooO`0Fooooo`03ool00?oooooooooo02_ooooo00?o003oooooooooool0L_oo
ool1o`00007ooooo00000ol0003oo`00ooooo`0/ooooo`030000oooooooooooo033ooooo0_ooO`0F
ooooo`03ool00?oooooooooo02gooooo00?o003oooooooooool0LOooool1o`00007ooooo00000ol0
003oo`00ooooo`0/ooooo`030000oooooooooooo04Sooooo00?oo`00ooooooooool0;Oooool00ol0
0?ooooooooooo`1aooooo`7o00000Oooool00003o`000?ooooooo`0002cooooo00<0003ooooooooo
ool0B?ooool00ooo003oooooooooo`0]ooooo`03o`00oooooooooooo077ooooo0Ol00001ooooo`00
00?o0000oooooooo0000:oooool00`000?ooooooooooo`18ooooo`03ool00?oooooooooo02oooooo
00?o003oooooooooool0L?ooool1o`00007ooooo00001?l0003ooooooooooooo000Zooooo`030000
oooooooooooo00?ooooo0_ooO`13ooooo`03ool00?oooooooooo02oooooo00?o003oooooooooool0
L?ooool1o`00007ooooo00001?l0003ooooooooooooo000Zooooo`030000oooooooooooo00;ooooo
1?ooO`12ooooo`03ool00?oooooooooo02oooooo00?o003oooooooooool0L?ooool1o`00007ooooo
00001Ol0003oooooooooooooooooo`0002Wooooo00<0003oooooooooool00_ooool4oomo047ooooo
00?oo`00ooooooooool0<?ooool00ol00?ooooooooooo`1`ooooo`7o00000Oooool00005o`000?oo
oooooooooooooooo0000:?ooool00`000?ooooooooooo`04ooooo`;oogl0@_ooool00ooo003ooooo
ooooo`0aooooo`03o`00oooooooooooo06oooooo0Ol00001ooooo`0000?o0000ooooooooool00_oo
ool00ooo003oooooooooo`0Uooooo`030000oooooooooooo04Oooooo00?oo`00ooooooooool0<_oo
ool00ol00?ooooooooooo`1_ooooo`7o00000Oooool00003o`000?oooooooooo00;ooooo00?oo`00
ooooooooool09Oooool00`000?ooooooooooo`17ooooo`03ool00?oooooooooo03;ooooo00?o003o
ooooooooool0Koooool1o`00007ooooo00000ol0003oooooooooo`03ooooo`03ool00?oooooooooo
02Cooooo00<0003oooooooooool0A_ooool00ooo003oooooooooo`0cooooo`03o`00oooooooooooo
06oooooo0Ol00001ooooo`0000?o0000ooooooooool01?ooool00ooo003oooooooooo`0Sooooo`03
0000oooooooooooo04Gooooo00?oo`00ooooooooool0=?ooool00ol00?ooooooooooo`1_ooooo`7o
00000Oooool00003o`000?oooooooooo00Gooooo00?oo`00ooooooooool08Oooool00`000?oooooo
ooooo`15ooooo`03ool00?oooooooooo03Kooooo00?o003oooooooooool0K_ooool1o`00007ooooo
00000ol0003oooooooooo`06ooooo`03ool00?oooooooooo023ooooo00<0003oooooooooool0AOoo
ool00ooo003oooooooooo`09ooooo`;oogl0:oooool00ol00?ooooooooooo`1^ooooo`7o00000Ooo
ool00003o`000?oooooooooo00Kooooo00?oo`00ooooooooool08?ooool00`000?ooooooooooo`14
ooooo`03ool00?oooooooooo00Wooooo1?ooO`0Zooooo`03o`00oooooooooooo06kooooo0Ol00001
ooooo`0000?o0000ooooooooool01oooool00ooo003oooooooooo`0Oooooo`030000oooooooooooo
02Sooooo0_ooO`0Iooooo`03ool00?oooooooooo00[ooooo1?ooO`0Zooooo`03o`00oooooooooooo
06kooooo0Ol00001ooooo`0000?o0000ooooooooool01oooool00ooo003oooooooooo`0Oooooo`03
0000oooooooooooo02Oooooo1?ooO`0Gooooo`03ool00?oooooooooo00cooooo0_ooO`0[ooooo`03
o`00oooooooooooo06kooooo0Ol00001ooooo`0000?o0000ooooooooool02?ooool00ooo003ooooo
ooooo`0Nooooo`030000oooooooooooo02Oooooo1?ooO`0Gooooo`03ool00?oooooooooo03Wooooo
00?o003oooooooooool0K_ooool1o`00007ooooo00000ol0003oooooooooo`09ooooo`03ool00?oo
oooooooo01gooooo00<0003oooooooooool0:?ooool2oomo01;ooooo1?l00?l00oooooooo`00oooo
o`0kooooo`03o`00oooooooooooo06kooooo0Ol00001ooooo`0000?o0000ooooooooool02_ooool0
0ooo003oooooooooo`0Looooo`030000oooooooooooo03_ooooo1_l00?lmooooo`03o`00oooooooo
oooo06kooooo0Ol00001ooooo`0000?o0000ooooooooool02oooool00ooo003oooooooooo`0Koooo
o`030000oooooooooooo03Oooooo0_ooO`000ooooooo003oo`00o`06o`00occooooo00?o003ooooo
ooooool0K_ooool1o`00007ooooo00000ol0003oooooooooo`0<ooooo`03ool00?oooooooooo01[o
oooo00<0003oooooooooool0=_ooool4oomo00So003o??ooool00ol00?ooooooooooo`1^ooooo`7o
00000Oooool00003o`000?oooooooooo00gooooo00?oo`00ooooooooool06Oooool00`000?oooooo
ooooo`0fooooo`Coogl02?l00?llooooo`03o`00oooooooooooo06kooooo0Ol00001ooooo`0000?o
0000ooooooooool03Oooool2ool001[ooooo00<0003oooooooooool0=oooool2oomo0003ooooool0
0?oo003o00Ko003o??ooool00ol00?ooooooooooo`1^ooooo`7o00000Oooool00003o`000?oooooo
oooo00oooooo00?oo`00ooooooooool05oooool00`000?ooooooooooo`0jooooo`03ool00?l00?oo
003o00Co003o?Oooool00ol00?ooooooooooo`1^ooooo`7o00000Oooool00003o`000?oooooooooo
013ooooo00?oo`00ooooooooool05_ooool00`000?ooooooooooo`0iooooo`03ool00?oooooooooo
00Co003o?_ooool00ol00?ooooooooooo`1^ooooo`7o00000Oooool00003o`000?oooooooooo017o
oooo00?oo`00ooooooooool05Oooool00`000?ooooooooooo`0hooooo`03ool00?oooooooooo04?o
oooo00?o003oooooooooool0K_ooool1o`00007ooooo00000ol0003oooooooooo`0Booooo`03ool0
0?oooooooooo01Cooooo00<0003oooooooooool0=_ooool2ool004Kooooo00?o003oooooooooool0
K_ooool1o`00007ooooo00000ol0003oooooooooo`0Cooooo`03ool00?oooooooooo01?ooooo00<0
003oooooooooool0=Oooool00ooo003oooooooooo`16ooooo`03o`00oooooooooooo06kooooo0Ol0
0001ooooo`0000?o0000ooooooooool05?ooool2ool001?ooooo00<0003oooooooooool0=?ooool0
0ooo003oooooooooo`17ooooo`03o`00oooooooooooo06kooooo0Ol00001ooooo`0000?o0000oooo
ooooool05_ooool2ool0017ooooo00<0003oooooooooool0<_ooool2ool004[ooooo00?o003ooooo
ooooool0K_ooool1o`00007ooooo00000ol0003oooooooooo`0Hooooo`03ool00?oooooooooo00ko
oooo00<0003oooooooooool0<Oooool00ooo003oooooooooo`1:ooooo`03o`00oooooooooooo06ko
oooo0Ol00001ooooo`0000?o0000ooooooooool06Oooool2ool000kooooo00<0003oooooooooool0
;oooool2ool004gooooo00?o003oooooooooool0K_ooool1o`00007ooooo00000ol0003ooooooooo
o`0Kooooo`03ool00?oooooooooo00_ooooo00<0003oooooooooool0;_ooool00ooo003ooooooooo
o`1<ooooo`03o`00oooooooooooo06oooooo0Ol00001ooooo`0000?o0000ooooooooool07?ooool2
ool000_ooooo00<0003oooooooooool0;Oooool00ooo003oooooooooo`1=ooooo`03o`00oooooooo
oooo06oooooo0Ol00001ooooo`0000?o0000ooooooooool07_ooool3ool000Wooooo00<0003ooooo
ooooool0:_ooool2ool0053ooooo00?o003oooooooooool0Koooool1o`00007ooooo00000ol0003o
ooooooooo`0Qooooo`;oo`001oooool00`000?ooooooooooo`0Wooooo`?oo`00D_ooool00ol00?oo
ooooooooo`1_ooooo`7o00000Oooool00003o`000?oooooooooo02?ooooo0_oo0005ooooo`030000
oooooooooooo02Gooooo0_oo001Dooooo`03o`00oooooooooooo073ooooo0Ol00001ooooo`0000?o
0000ooooooooool09Oooool4ool00003ooooo`000?oooooo02;ooooo1?oo001Fooooo`03o`00oooo
oooooooo073ooooo0Ol00001ooooo`0000?o0000ooooooooool0:Oooool2ool00003o`00oooo003o
o`0001gooooo0ooo001Jooooo`03o`00oooooooooooo073ooooo0Ol00001ooooo`0000?o0000oooo
ooooool0:oooool00`000?ooooooooooo`03ool001Cooooo1_oo001Mooooo`03o`00oooooooooooo
073ooooo0Ol00001ooooo`0000?o0000ooooooooool0;?ooool00`000?ooooooooooo`02oooooaCo
o`00H_ooool00ol00?ooooooooooo`1aooooo`7o00000Oooool00003o`000?oooooooooo02cooooo
00<0003oooooooooool0N?ooool00ol00?ooooooooooo`1aooooo`7o00000Oooool00003o`000?oo
oooooooo02cooooo00<0003oooooooooool0N?ooool00ol00?ooooooooooo`1aooooo`7o00000Ooo
ool00003o`000?oooooooooo02gooooo00<0003oooooooooool0M_ooool00ol00?ooooooooooo`1b
ooooo`7o00000Oooool00003o`000?oooooooooo02gooooo00<0003oooooooooool0M_ooool00ol0
0?ooooooooooo`1booooo`7o00000Oooool00003o`000?oooooooooo02gooooo00<0003ooooooooo
ool0M_ooool00ol00?ooooooooooo`1booooo`7o00000Oooool00003o`000?oooooooooo02kooooo
00<0003oooooooooool0M?ooool00ol00?ooooooooooo`1cooooo`7o00000Oooool00003o`000?oo
oooooooo02kooooo00<0003oooooooooool0M?ooool00ol00?ooooooooooo`1cooooo`7o00000Ooo
ool00003o`000?oooooooooo02kooooo00<0003oooooooooool0M?ooool00ol00?ooooooooooo`1c
ooooo`7o00000Oooool00003o`000?oooooooooo02oooooo00<0003oooooooooool0L_ooool00ol0
0?ooooooooooo`1dooooo`7o00000Oooool00003o`000?oooooooooo02oooooo00<0003ooooooooo
ool0L_ooool00ol00?ooooooooooo`1dooooo`7o00000Oooool00003o`000?oooooooooo02oooooo
00<0003oooooooooool0L_ooool00ol00?ooooooooooo`1dooooo`7o00000Oooool00003o`000?oo
oooooooo033ooooo00<0003oooooooooool0Koooool2o`00ogOooooo0Ol00001ooooo`0000?o0000
ooooooooool0<?ooool00`000?ooooooooooo`1_ooooo`03o`00oooooooooooo07Kooooo0Ol00001
ooooo`0000?o0000ooooooooool0<Oooool00`000?ooooooooooo`1]ooooo`03o`00oooooooooooo
07Oooooo0Ol00001ooooo`0000?o0000ooooooooool0<_ooool00`000?ooooooooooo`1/ooooo`03
o`00oooooooooooo07Oooooo0Ol00001ooooo`0000?o0000ooooooooool0<_ooool00`000?oooooo
ooooo`1[ooooo`03o`00oooooooooooo063ooooo0_ooO`0Fooooo`7o00000Oooool00003o`000?oo
oooooooo03?ooooo00<0003oooooooooool0JOooool00ol00?ooooooooooo`1Pooooo`Coogl05Ooo
ool1o`00007ooooo00000ol0003oooooooooo`0dooooo`030000oooooooooooo06Sooooo00?o003o
ooooooooool0H?ooool4oomo01Gooooo0Ol00001ooooo`0000?o0000ooooooooool0=Oooool00`00
0?ooooooooooo`1Vooooo`03o`00oooooooooooo06;ooooo0_ooO`0Fooooo`7o00000Oooool00003
o`000?oooooooooo03Gooooo00?o003oooooooooool0I_ooool00ol00?ooooooooooo`1jooooo`7o
00000Oooool00003o`000?oooooooooo03Kooooo00?o003oooooooooool0I?ooool00ol00?oooooo
ooooo`1kooooo`7o00000Oooool00003o`000?oooooooooo03Oooooo00?o003oooooooooool0H_oo
ool00ol00?ooooooooooo`1looooo`7o00000Oooool00003o`000?oooooooooo03Sooooo00?o003o
ooooooooool0Goooool2o`00ogoooooo0Ol00001ooooo`0000?o0000ooooooooool0>Oooool00ol0
0?ooooooooooo`1Mooooo`03o`00oooooooooooo07oooooo0Ol00001ooooo`0000?o0000oooooooo
ool0>_ooool00ol00?ooooooooooo`1Kooooo`03o`00oooooooooooo083ooooo0Ol00001ooooo`00
00?o0000ooooooooool0>oooool00ol00?ooooooooooo`1Iooooo`03o`00oooooooooooo087ooooo
0Ol00001ooooo`0000?o0000ooooooooool0??ooool00ol00?ooooooooooo`1Gooooo`03o`00oooo
oooooooo08;ooooo0Ol00001ooooo`0000?o0000ooooooooool0?Oooool00ol00?ooooooooooo`1E
ooooo`03o`00oooooooooooo08?ooooo0Ol00001ooooo`0000?o0000ooooooooool0?_ooool00ol0
0?ooooooooooo`1Cooooo`03o`00oooooooooooo08Cooooo0Ol00001ooooo`0000?o0000oooooooo
ool0?oooool00ol00?ooooooooooo`1@ooooo`;o003o8Oooool2oomo06Cooooo0Ol00001ooooo`00
00?o0000ooooooooool0@?ooool00ol00?ooooooooooo`1>ooooo`03o`00oooooooooooo023ooooo
1?ooO`1Sooooo`7o00000Oooool00003o`000?oooooooooo047ooooo0_l00?m=ooooo`03o`00oooo
oooooooo027ooooo1?ooO`1Sooooo`7o00000Oooool00003o`000?oooooooooo04?ooooo00?o003o
ooooooooool0BOooool00ol00?ooooooooooo`0Sooooo`;oogl0=Oooool2oomo02gooooo0Ol00001
ooooo`0000?o0000ooooooooool0A?ooool2o`00odSooooo00?o003oooooooooool0Doooool2oomo
00Gooooo1?ooO`0/ooooo`7o00000Oooool00003o`000?oooooooooo04Kooooo0_l00?m5ooooo`03
o`00oooooooooooo05?ooooo1?ooO`04ooooo`Coogl0;?ooool1o`00007ooooo00000ol0003ooooo
ooooo`18ooooo`03o`00oooooooooooo043ooooo0_l00?lfooooo`;oogl07_ooool4oomo00Gooooo
0_ooO`0]ooooo`7o00000Oooool00003o`000?oooooooooo04Wooooo0_l00?lnooooo`;o003o=ooo
ool4oomo01kooooo0_ooO`0eooooo`7o00000Oooool00003o`000?oooooooooo04_ooooo0ol00?lj
ooooo`03o`00oooooooooooo03Oooooo1?ooO`1Eooooo`7o00000Oooool00003o`000?oooooooooo
04kooooo0_l00?lfooooo`;o003o>oooool2oomo05Kooooo0Ol00001ooooo`0000?o0000oooooooo
ool0D?ooool3o`00oc3ooooo0ol00?lcooooo`;oogl09Oooool2oomo03Wooooo0Ol00001ooooo`00
00?o0000ooooooooool0Doooool2o`00ob[ooooo1?l00?leooooo`Coogl08oooool4oomo03Sooooo
0Ol00001ooooo`0000?o0000ooooooooool0EOooool3o`00ob?ooooo1?l00?leooooo`;oogl00_oo
ool4oomo02?ooooo1?ooO`03ooooo`;oogl0<oooool1o`00007ooooo00000ol0003oooooooooo`1H
ooooo`?o003o7Oooool3o`00ocSooooo1?ooO`02ooooo`;oogl04oooool2oomo013ooooo0_ooO`03
ooooo`Coogl0<_ooool1o`00007ooooo00000ol0003oooooooooo`1Kooooo`?o003o5?ooool6o`00
oc_ooooo1?ooO`06ooooo`;oogl03_ooool4oomo01Cooooo1?ooO`0booooo`7o00000Oooool00003
o`000?oooooooooo05kooooo5?l00?m2ooooo`;oogl01_ooool4oomo00gooooo1?ooO`0Eooooo`;o
ogl0<oooool1o`00007ooooo00000ol0003oooooooooo`2;ooooo`;oogl09oooool2oomo00Kooooo
1?ooO`0>ooooo`;oogl0Boooool1o`00007ooooo00000ol0003oooooooooo`2:ooooo`Coogl09Ooo
ool4oomo00Kooooo0_ooO`0Booooo`Goo`3oAOooool1o`00007ooooo00000ol0003oooooooooo`2:
ooooo`Coogl09Oooool4oomo01Wooooo1ooo0?m4ooooo`7o00000Oooool00003o`000?oooooooooo
08_ooooo0_ooO`0Wooooo`;oogl06Oooool9ool0od?ooooo0Ol00001ooooo`0000?o0000oooooooo
ool0U_ooool2oomo03Kooooo2ooo0?m2ooooo`7o00000Oooool00003o`000?oooooooooo09Gooooo
1?ooO`0>ooooo`;oogl09Oooool;ool0od;ooooo0Ol00001ooooo`0000?o0000ooooooooool0UOoo
ool4oomo00gooooo1?ooO`0Tooooo`_oo`3o@_ooool1o`00007ooooo00000ol0003oooooooooo`2F
ooooo`;oogl03_ooool4oomo02Cooooo2ooo0?m2ooooo`7o00000Oooool00003o`000?oooooooooo
0:Oooooo0_ooO`0Uooooo`_oo`3o@_ooool1o`00007ooooo00000ol0003oooooooooo`3?ooooo`Wo
o`3o4oooool2oomo02kooooo0Ol00001ooooo`0000?o0000ooooooooool0d?ooool7ool0oa?ooooo
1?ooO`0]ooooo`7o00000Oooool00003o`000?oooooooooo0=7ooooo1Ooo0?l2oomo01;ooooo1?oo
O`0]ooooo`7o00000Oooool00003o`000?oooooooooo0=Gooooo1?ooO`0Booooo`;oogl0;_ooool1
o`00007ooooo00000ol0003oooooooooo`2gooooo`;oogl07?ooool4oomo04;ooooo0Ol00001oooo
o`0000?o0000ooooooooool0]_ooool4oomo01cooooo0_ooO`13ooooo`7o00000Oooool00003o`00
0?oooooooooo0;?ooooo0_ooO`000oooooooogl0oomo0002oomo067ooooo0Ol00001ooooo`0000?o
0000ooooooooool0Z?ooool2oomo00Sooooo1?ooO`000oooooooogl0oomo000Jooooo`;oogl0A_oo
ool1o`00007ooooo00000ol0003oooooooooo`2Vooooo`Googl01oooool4oomo01Oooooo0_ooO`03
ooooo`Coogl0AOooool1o`00007ooooo00000ol0003oooooooooo`2Uooooo`Koogl02?ooool2oomo
01Oooooo1?ooO`02ooooo`Coogl0AOooool1o`00007ooooo00000ol0003oooooooooo`2Uooooo`Go
ogl08_ooool4oomo00?ooooo0_ooO`16ooooo`7o00000Oooool00003o`000?oooooooooo07Kooooo
0_ooO`0^ooooo`;oogl09Oooool2oomo04cooooo0Ol00001ooooo`0000?o0000ooooooooool0MOoo
ool4oomo0:;ooooo0Ol00001ooooo`0000?o0000ooooooooool0MOooool4oomo00[ooooo0_ooO`2F
ooooo`7o00000Oooool00003o`000?oooooooooo07Kooooo0_ooO`0:ooooo`Coogl0:_ooool2oomo
06Wooooo0Ol00001ooooo`0000?o0000ooooooooool0P_ooool4oomo02Wooooo1?ooO`1Xooooo`7o
00000Oooool00003o`000?oooooooooo08?ooooo0_ooO`0Tooooo`;oogl01?ooool4oomo06Sooooo
0Ol00001ooooo`0000?o0000ooooooooool0Z?ooool4oomo00Cooooo0_ooO`1Yooooo`7o00000Ooo
ool00003o`000?oooooooooo0:Sooooo1?ooO`1_ooooo`7o00000Oooool00003o`000?oooooooooo
0:Wooooo0_ooO`1`ooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007o
oooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooo
oolLooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0
003oooooooooo`24ooooo`;oogl0UOooool1o`00007ooooo00000ol0003oooooooooo`23ooooo`Co
ogl0U?ooool1o`00007ooooo00000ol0003oooooooooo`23ooooo`Coogl0U?ooool1o`00007ooooo
00000ol0003oooooooooo`24ooooo`;oogl0;?ooool2oomo06Oooooo0Ol00001ooooo`0000?o0000
ooooooooool0/Oooool4oomo06Kooooo0Ol00001ooooo`0000?o0000ooooooooool0/Oooool4oomo
06Kooooo0Ol00001ooooo`0000?o0000ooooooooool0/_ooool2oomo06Oooooo0Ol00001ooooo`00
00?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?oo
ool1o`00007ooooo00000ol0003oooooooooo`1kooooo`;oogl0W_ooool1o`00007ooooo00000ol0
003oooooooooo`1jooooo`Coogl0WOooool1o`00007ooooo00000ol0003oooooooooo`1jooooo`Co
ogl08?ooool2oomo07_ooooo0Ol00001ooooo`0000?o0000ooooooooool0Noooool2oomo023ooooo
1?ooO`1jooooo`7o00000Oooool00003o`000?oooooooooo09gooooo1?ooO`1jooooo`7o00000Ooo
ool00003o`000?oooooooooo093ooooo0_ooO`0<ooooo`;oogl0Noooool1o`00007ooooo00000ol0
003oooooooooo`2?ooooo`Coogl0R?ooool1o`00007ooooo00000ol0003oooooooooo`2?ooooo`Co
ogl0R?ooool1o`00007ooooo00000ol0003oooooooooo`2@ooooo`;oogl08oooool2oomo06Cooooo
0Ol00001ooooo`0000?o0000ooooooooool0]?ooool4oomo06?ooooo0Ol00001ooooo`0000?o0000
ooooooooool0]?ooool4oomo06?ooooo0Ol00001ooooo`0000?o0000ooooooooool0]Oooool2oomo
06Cooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`00
0?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol0
0001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo
0?oooooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`00
00?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?oo
ool1o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000oooo
ooooool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007o
oooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooo
oolLooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0
003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o
00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003ooooooooo
o`3ooooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool0
0003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooooaco
oooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oo
oooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001
ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo0?oo
oooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o
0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1
o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000oooooooo
ool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo
00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolL
ooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003o
ooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o0000
0Oooool00003o`000?oooooooooo08kooooo0_ooO`2;ooooo`7o00000Oooool00003o`000?oooooo
oooo08gooooo1?ooO`2:ooooo`7o00000Oooool00003o`000?oooooooooo08gooooo1?ooO`2:oooo
o`7o00000Oooool00003o`000?oooooooooo08kooooo0_ooO`2;ooooo`7o00000Oooool00003o`00
0?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol0
0001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo
0?oooooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`00
00?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?oo
ool1o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000oooo
ooooool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007o
oooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooo
oolLooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0
003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o
00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003ooooooooo
o`3ooooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool0
0003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooooaco
oooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool00?oo00008?l0
0001ooooo`00\
\>"],
  ImageRangeCache->{{{0, 287}, {287, 0}} -> {-1.01089, -1.01089, 0.00704453, \
0.00704453}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.49505 0.5 0.49505 [
[ 0 0 -0.125 0 ]
[ 0 0 -0.125 0 ]
[ 0 1 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
0 0 m
1 0 L
s
0 0 m
0 1 L
s
0 1 m
1 1 L
s
1 0 m
1 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
1 .5 0 r
.015 w
.03175 .1355 Mdot
.03435 .12523 Mdot
.11137 .12765 Mdot
.14107 .18841 Mdot
.16218 .24538 Mdot
.17294 .21053 Mdot
.18267 .18577 Mdot
.18434 .1304 Mdot
.18553 .30956 Mdot
.20401 .239 Mdot
.21247 .27571 Mdot
.21687 .20845 Mdot
.22376 .2799 Mdot
.22832 .27485 Mdot
.29063 .20974 Mdot
.29686 .25079 Mdot
.30487 .22936 Mdot
.30683 .34623 Mdot
.32055 .20902 Mdot
.32574 .21979 Mdot
.34472 .28521 Mdot
.35998 .36393 Mdot
.36335 .24976 Mdot
.3794 .36608 Mdot
.42386 .66992 Mdot
.44391 .74519 Mdot
.45059 .34198 Mdot
.47208 .67586 Mdot
.47436 .71381 Mdot
.49778 .59825 Mdot
.50874 .91643 Mdot
.51516 .76219 Mdot
.53655 .61374 Mdot
.56563 .75219 Mdot
.59189 .65665 Mdot
.59581 .61604 Mdot
.59923 .6556 Mdot
.60292 .68499 Mdot
.62656 .67779 Mdot
.63555 .72451 Mdot
.63919 .652 Mdot
.64169 .6004 Mdot
.64246 .58611 Mdot
.64496 .54267 Mdot
.64608 .77288 Mdot
.65077 .64308 Mdot
.66065 .57816 Mdot
.67474 .59169 Mdot
.69296 .563 Mdot
.72815 .65902 Mdot
.73169 .58879 Mdot
.74669 .61318 Mdot
.74821 .65474 Mdot
.75963 .63781 Mdot
.79673 .57809 Mdot
.80925 .55852 Mdot
.81525 .58444 Mdot
.83417 .62985 Mdot
.83598 .55526 Mdot
.91595 .49319 Mdot
1 0 0 r
.005 w
.00495 .28842 m
.00628 .29156 L
.01857 .31761 L
.03101 .33781 L
.03525 .34367 L
.05706 .36884 L
.05795 .36972 L
.08312 .39115 L
.08963 .39578 L
.10917 .40763 L
.13523 .41964 L
.14074 .42183 L
.16128 .42794 L
.18734 .43294 L
.21339 .43485 L
.23945 .43375 L
.2655 .42959 L
.29156 .42219 L
.29261 .42183 L
.31761 .41124 L
.34367 .39603 L
.34405 .39578 L
.36972 .37551 L
.37582 .36972 L
.39578 .34724 L
.39849 .34367 L
.41525 .31761 L
.42183 .30485 L
.4275 .29156 L
.436 .2655 L
.44117 .23945 L
.44325 .21339 L
.44232 .18734 L
.43834 .16128 L
.43114 .13523 L
.42183 .11212 L
.42037 .10917 L
.40546 .08312 L
.39578 .06961 L
.38528 .05706 L
.36972 .04137 L
.35758 .03101 L
.34367 .02092 L
.31761 .00569 L
.3162 .00495 L
s
.00495 .12854 m
.01344 .10917 L
.02832 .08312 L
.03101 .07912 L
.04848 .05706 L
.05706 .04802 L
.07619 .03101 L
.08312 .02579 L
.10917 .00934 L
.11742 .00495 L
s
0 0 1 r
.29156 .15739 m
.31761 .14824 L
.34367 .14249 L
.36972 .13986 L
.39578 .14025 L
.42183 .14366 L
.44789 .15025 L
.47394 .16034 L
.47599 .16128 L
.5 .17443 L
.51844 .18734 L
.52606 .19355 L
.54662 .21339 L
.55211 .21962 L
.56712 .23945 L
.57817 .25755 L
.58227 .2655 L
.59322 .29156 L
.60058 .31761 L
.60422 .3392 L
.60471 .34367 L
.6058 .36972 L
.60422 .39297 L
.60387 .39578 L
.59886 .42183 L
.59054 .44789 L
.57848 .47394 L
.57817 .47453 L
.562 .5 L
.55211 .51255 L
.53968 .52606 L
.52606 .53862 L
.50853 .55211 L
.5 .55773 L
.47394 .57183 L
.45901 .57817 L
.44789 .5819 L
.42183 .5885 L
.39578 .59192 L
.36972 .59231 L
.34367 .58968 L
.31761 .58392 L
.29972 .57817 L
.29156 .57477 L
.2655 .56178 L
.25025 .55211 L
.23945 .54409 L
.21914 .52606 L
.21339 .52008 L
.19681 .5 L
Mistroke
.18734 .48608 L
.18031 .47394 L
.16827 .44789 L
.16128 .42714 L
.15996 .42183 L
.15493 .39578 L
.153 .36972 L
.15409 .34367 L
.15823 .31761 L
.16128 .3045 L
.16559 .29156 L
.17653 .2655 L
.18734 .24609 L
.19169 .23945 L
.21221 .21339 L
.21339 .21211 L
.23945 .1881 L
.24041 .18734 L
.2655 .17038 L
.28271 .16128 L
.29156 .15739 L
Mfstroke
1 0 0 r
.03 w
.21687 .20845 Mdot
0 0 1 r
.3794 .36608 Mdot
1 0 0 r
.79703 .00495 m
.79703 .02276 L
.87129 .02276 L
.87129 .00495 L
F
0 0 1 r
.89604 .00495 m
.89604 .23466 L
.9703 .23466 L
.9703 .00495 L
F
1 0 1 r
.04 w
.74821 .65474 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P000182000`400?l00000o`00003ooooooolQ
ooooo`00ool0000Po`00007ooooo00000ol0003oooooooooo`0Mooooo`;oo`00>?ooool3ool00<7o
oooo0Ol00001ooooo`0000?o0000ooooooooool06oooool2ool003gooooo00?oo`00ooooooooool0
Q?oooolEool000Sooooo5Ol00?l8ooooo`7o00000Oooool00003o`000?oooooooooo01[ooooo00?o
o`00ooooooooool0?_ooool2ool008Cooooo5Ooo0008oooooaGo003o2?ooool1o`00007ooooo0000
0ol0003oooooooooo`0Hooooo`;oo`00@oooool00ooo003oooooooooo`21oooooaGoo`002?oooolE
o`00o`Sooooo0Ol00001ooooo`0000?o0000ooooooooool05_ooool2ool004Kooooo00?oo`00oooo
ooooool0P?oooolEool000Sooooo5Ol00?l8ooooo`7o00000Oooool00003o`000?oooooooooo01Go
oooo00?oo`00ooooooooool0Aoooool2ool0083ooooo5Ooo0008oooooaGo003o2?ooool1o`00007o
oooo00000ol0003oooooooooo`0Dooooo`03ool00?oooooooooo04[ooooo00?oo`00ooooooooool0
V_oooolEo`00o`Sooooo0Ol00001ooooo`0000?o0000ooooooooool04oooool00ooo003ooooooooo
o`1<ooooo`03ool00?oooooooooo09Wooooo5Ol00?l8ooooo`7o00000Oooool00003o`000?oooooo
oooo017ooooo0_oo001@ooooo`;oo`00VOoooolEo`00o`Sooooo0Ol00001ooooo`0000?o0000oooo
ooooool04?ooool00ooo003oooooooooo`1Booooo`;oo`00UooooolEo`00o`Sooooo0Ol00001oooo
o`0000?o0000ooooooooool03oooool00ooo003oooooooooo`1Eooooo`03ool00?oooooooooo09Co
oooo5Ol00?l8ooooo`7o00000Oooool00003o`000?oooooooooo00kooooo00?oo`00ooooooooool0
E_ooool00ooo003oooooooooo`2DoooooaGo003o2?ooool1o`00007ooooo00000ol0003ooooooooo
o`0=ooooo`03ool00?oooooooooo05Sooooo00?oo`00ooooooooool0TooooolEo`00o`Sooooo0Ol0
0001ooooo`0000?o0000ooooooooool03Oooool00ooo003oooooooooo`1Iooooo`03ool00?oooooo
oooo09;ooooo5Ol00?l8ooooo`7o00000Oooool00003o`000?oooooooooo00cooooo00?oo`00oooo
ooooool0Foooool00ooo003oooooooooo`2AoooooaGo003o2?ooool1o`00007ooooo00000ol0003o
ooooooooo`0;ooooo`03ool00?oooooooooo05gooooo00?oo`00ooooooooool0T?oooolEo`00o`So
oooo0Ol00001ooooo`0000?o0000ooooooooool02oooool00ooo003oooooooooo`1Mooooo`03ool0
0?oooooooooo093ooooo5Ol00?l8ooooo`7o00000Oooool00003o`000?oooooooooo00[ooooo00?o
o`00ooooooooool0Goooool00ooo003oooooooooo`2?oooooaGo003o2?ooool1o`00007ooooo0000
0ol0003oooooooooo`09ooooo`03ool00?oooooooooo067ooooo00?oo`00ooooooooool0S_oooolE
o`00o`Sooooo0Ol00001ooooo`0000?o0000ooooooooool02?ooool00ooo003oooooooooo`1Soooo
o`03ool00?oooooooooo08gooooo5Ol00?l8ooooo`7o00000Oooool00003o`000?oooooooooo00Oo
oooo00?oo`00ooooooooool0IOooool00ooo003oooooooooo`2<oooooaGo003o2?ooool1o`00007o
oooo00000ol0003oooooooooo`06ooooo`03ool00?oooooooooo06Oooooo00?oo`00ooooooooool0
RooooolEo`00o`Sooooo0Ol00001ooooo`0000?o0000ooooooooool01Oooool00ooo003ooooooooo
o`1Yooooo`03ool00?oooooooooo08[ooooo5Ol00?l8ooooo`7o00000Oooool00003o`000?oooooo
oooo00Gooooo00?oo`00ooooooooool0JOooool00ooo003oooooooooo`2:oooooaGo003o2?ooool1
o`00007ooooo00000ol0003oooooooooo`04ooooo`03ool00?oooooooooo06_ooooo00?oo`00oooo
ooooool0ROoooolEo`00o`Sooooo0Ol00001ooooo`0000?o0000ooooooooool00oooool00ooo003o
ooooooooo`1/ooooo`03ool00?oooooooooo08Wooooo5Ol00?l8ooooo`7o00000Oooool00003o`00
0?oooooooooo00?ooooo00?oo`00ooooooooool0KOooool00ooo003oooooooooo`28oooooaGo003o
2?ooool1o`00007ooooo00000ol0003oooooooooo`02ooooo`03ool00?oooooooooo06kooooo00?o
o`00ooooooooool0R?oooolEo`00o`Sooooo0Ol00001ooooo`0000?o0000ooooooooool00_ooool0
0ooo003oooooooooo`1_ooooo`03ool00?oooooooooo08Oooooo5Ol00?l8ooooo`7o00000Oooool0
0005o`000?oooooooooooooooooo0000L_ooool00ooo003oooooooooo`27oooooaGo003o2?ooool1
o`00007ooooo00001?l0003ooooooooooooo001dooooo`03ool00?oooooooooo08Kooooo5Ol00?l8
ooooo`7o00000Oooool00004o`000?ooooooooooool007Gooooo00?oo`00ooooooooool0QOoooolE
o`00o`Sooooo0Ol00001ooooo`0000?o0000oooooooo0000M_ooool00ooo003oooooooooo`25oooo
oaGo003o2?ooool1o`00007ooooo00000ol0003oooooool00006ooooo`;oogl0Koooool00ooo003o
ooooooooo`24oooooaGo003o2?ooool1o`00007ooooo00000ol0003oooooool00005ooooo`Coogl0
4oooool2oomo05Wooooo00?oo`00ooooooooool0Q?oooolEo`00o`Sooooo0Ol00001ooooo`0000?o
0000ool00?ooool01Oooool4oomo01;ooooo1?ooO`0Booooo`;oogl0A?ooool00ooo003ooooooooo
o`24oooooaGo003o2?ooool1o`00007ooooo00000ol0003oooooooooo`05ooooo`?oogl04oooool4
oomo017ooooo1?ooO`14ooooo`03ool00?oooooooooo08?ooooo5Ol00?l8ooooo`7o00000Oooool0
0003o`000?oooooooooo00Cooooo1?ooO`0Dooooo`;oogl04_ooool4oomo04Cooooo00?oo`00oooo
ooooool0PooooolEo`00o`Sooooo0Ol00001ooooo`0000?o0000ooooooooool01?ooool4oomo02Wo
oooo0_ooO`15ooooo`03ool00?oooooooooo08?ooooo5Ol00?l8ooooo`7o00000Oooool00003o`00
0?oooooooooo00Gooooo0_ooO`1FoooooaKo003o1Oooool00ooo003oooooooooo`23oooooaGo003o
2?ooool1o`00007ooooo00000ol0003oooooooooo`1Jooooo`?o003o5_ooool6o`00o`03ool00?oo
oooooooo08;ooooo5Ol00?l8ooooo`7o00000Oooool00003o`000?oooooooooo05Oooooo0ol00?lO
ooooo`?o003oP_oooolEo`00o`Sooooo0Ol00001ooooo`0000?o0000ooooooooool0E?ooool3o`00
ob;ooooo00?oo`00ooooooooool00ol00?mooooooaGo003o2?ooool1o`00007ooooo00000ol0003o
ooooooooo`1Aooooo`?o003o9Oooool00ooo003oooooooooo`03ooooo`?o003oO?oooolEo`00o`So
oooo0Ol00001ooooo`0000?o0000ooooooooool0Coooool20000obWooooo00?oo`00ooooooooool0
1Oooool3o`00ogWooooo5Ol00?l8ooooo`7o00000Oooool00003o`000?oooooooooo04gooooo0P00
0?l[ooooo`03ool00?oooooooooo00Sooooo0_l00?mgoooooaGo003o2?ooool1o`00007ooooo0000
0ol0003oooooooooo`1:ooooo`<0003o;Oooool00ooo003oooooooooo`0:ooooo`;o003oMOoooolE
o`00o`Sooooo0Ol00001ooooo`0000?o0000ooooooooool0B?ooool20000oc3ooooo00?oo`00oooo
ooooool03?ooool00ol00?ooooooooooo`1boooooaGo003o2?ooool1o`00007ooooo00000ol0003o
ooooooooo`17ooooo`030000oooooooooooo033ooooo00?oo`00ooooooooool03Oooool2o`00og;o
oooo5Ol00?l8ooooo`7o00000Oooool00003o`000?oooooooooo04Gooooo0P000?ldooooo`03ool0
0?oooooooooo00kooooo0_l00?m`oooooaGo003o2?ooool1o`00007ooooo00000ol0003ooooooooo
o`14ooooo`030000oooooooooooo03Cooooo00?oo`00ooooooooool04?ooool2o`00ofkooooo5Ol0
0?l8ooooo`7o00000Oooool00003o`000?oooooooooo02Cooooo0_ooO`0:ooooo`;oogl04Oooool0
0`000?ooooooooooo`0eooooo`03ool00?oooooooooo01;ooooo00?o003oooooooooool0JooooolE
o`00o`Sooooo0Ol00001ooooo`0000?o0000ooooooooool08oooool4oomo00Sooooo1?ooO`0?oooo
o`030000oooooooooooo03Kooooo00?oo`00ooooooooool04oooool00ol00?ooooooooooo`1Zoooo
oaGo003o2?ooool1o`00007ooooo00000ol0003oooooooooo`0Sooooo`Coogl02?ooool4oomo00go
oooo00<0003oo`00ooooool0>?ooool00ooo003oooooooooo`0Dooooo`03o`00oooooooooooo06Wo
oooo5Ol00?l8ooooo`7o00000Oooool00003o`000?oooooooooo02Cooooo0_ooO`0:ooooo`;oogl0
3Oooool00`000?ooooooooooo`0iooooo`03ool00?oooooooooo01Gooooo00?o003oooooooooool0
J?oooolEo`00o`Sooooo0Ol00001ooooo`0000?o0000ooooooooool0>Oooool4ool00003ooooo`00
0?oooooo03_ooooo00?oo`00ooooooooool05_ooool00ol00?ooooooooooo`1WoooooaGo003o2?oo
ool1o`00007ooooo00000ol0003oooooooooo`0hooooo`Koo`00?Oooool00ooo003oooooooooo`0G
ooooo`03o`00oooooooooooo06Kooooo5Ol00?l8ooooo`7o00000Oooool00003o`000?oooooooooo
03Oooooo2?oo000@ooooo`;oogl01oooool2oomo02;ooooo00?oo`00ooooooooool05oooool00ol0
0?ooooooooooo`1UoooooaGo003o2?ooool1o`00007ooooo00000ol0003oooooooooo`0^ooooo`;o
ogl01oooool8ool000oooooo1?ooO`05ooooo`Coogl08Oooool00ooo003oooooooooo`0Hooooo`03
o`00oooooooooooo06Cooooo5Ol00?l8ooooo`7o00000Oooool00003o`000?oooooooooo02gooooo
1?ooO`06ooooo`Soo`003oooool4oomo00Gooooo1?ooO`0Qooooo`03ool00?oooooooooo01Wooooo
00?o003oooooooooool0HooooolEo`00o`Sooooo0Ol00001ooooo`0000?o0000ooooooooool0;Ooo
ool4oomo00Kooooo2?oo000@ooooo`;oogl01oooool3oomo027ooooo00?oo`00ooooooooool06_oo
ool00ol00?ooooooooooo`1RoooooaGo003o2?ooool1o`00007ooooo00000ol0003oooooooooo`0^
ooooo`;oogl02?ooool6ool001[ooooo1?ooO`0Pooooo`03ool00?oooooooooo01_ooooo00?o003o
ooooooooool0HOoooolEo`00o`Sooooo0Ol00001ooooo`0000?o0000ooooooooool0>?ooool00`00
0?ooo`00ool00002ool001_ooooo1?ooO`0Pooooo`03ool00?oooooooooo01cooooo00?o003ooooo
ooooool0H?oooolEo`00o`Sooooo0Ol00001ooooo`0000?o0000ooooooooool0=oooool00`000?oo
ooooooooo`0Iooooo`;oogl01?ooool2oomo027ooooo00?oo`00ooooooooool07?ooool00ol00?oo
ooooooooo`1PoooooaGo003o2?ooool1o`00007ooooo00000ol0003oooooooooo`0fooooo`030000
oooooooooooo01Wooooo1?ooO`0Uooooo`03ool00?oooooooooo01kooooo00?o003oooooooooool0
GooooolEo`00o`Sooooo0Ol00001ooooo`0000?o0000ooooooooool0=_ooool00`000?oooooooooo
o`0Iooooo`Coogl09Oooool00ooo003oooooooooo`0Oooooo`03o`00oooooooooooo05kooooo5Ol0
0?l8ooooo`7o00000Oooool00003o`000?oooooooooo03Gooooo00@0003oooooooooO`3oogl06_oo
ool2oomo02Kooooo00?oo`00ooooooooool08?ooool00ol00?ooooooooooo`1MoooooaGo003o2?oo
ool1o`00007ooooo00000ol0003oooooooooo`0dooooo`030000ooooooooogl000?oogl0@Oooool0
0ooo003oooooooooo`0Qooooo`03o`00oooooooooooo07Wooooo0Ol00001ooooo`0000?o0000oooo
ooooool0:oooool2oomo00Kooooo00<0003oooooooooool01?ooO`11ooooo`03ool00?oooooooooo
027ooooo00?o003oooooooooool0NOooool1o`00007ooooo00000ol0003oooooooooo`0Zooooo`Co
ogl01?ooool00`000?ooooooooooo`02ooooo`;oogl06?ooool2oomo017ooooo0_ooO`0Eooooo`03
ool00?oooooooooo02;ooooo00?o003oooooooooool0N?ooool1o`00007ooooo00000ol0003ooooo
ooooo`0Zooooo`Coogl01?ooool00`000?ooooooooooo`0Kooooo`Coogl03oooool4oomo01Cooooo
00?oo`00ooooooooool08oooool00ol00?ooooooooooo`1gooooo`7o00000Oooool00003o`000?oo
oooooooo02_ooooo0_ooO`04ooooo`030000oooooooooooo01cooooo1?ooO`0?ooooo`Coogl05?oo
ool00ooo003oooooooooo`0Sooooo`03o`00oooooooooooo07Oooooo0Ol00001ooooo`0000?o0000
ooooooooool0<Oooool00`000?ooooooooooo`0Mooooo`;oogl04Oooool2oomo01Cooooo00?oo`00
ooooooooool09Oooool00ol00?ooooooooooo`1fooooo`7o00000Oooool00003o`000?oooooooooo
033ooooo00<0003oooooooooool0Aoooool00ooo003oooooooooo`0Uooooo`03o`00oooooooooooo
07Kooooo0Ol00001ooooo`0000?o0000ooooooooool0<?ooool00`000?ooooooooooo`17ooooo`03
ool00?oooooooooo02Kooooo00?o003oooooooooool0MOooool1o`00007ooooo00000ol0003ooooo
ooooo`0_ooooo`030000oooooooooooo04Sooooo00?oo`00ooooooooool09oooool00ol00?oooooo
ooooo`1dooooo`7o00000Oooool00003o`000?oooooooooo02oooooo00<0003oooooooooool01ooo
ool2oomo00;ooooo0_ooO`0kooooo`03ool00?oooooooooo02Oooooo00?o003oooooooooool0M?oo
ool1o`00007ooooo00000ol0003oooooooooo`0^ooooo`030000oooooooooooo00Oooooo2?ooO`0i
ooooo`03ool00?oooooooooo02Wooooo00?o003oooooooooool0Loooool1o`00007ooooo00000ol0
003oooooooooo`0^ooooo`030000oooooooooooo00Oooooo2?ooO`0iooooo`03ool00?oooooooooo
02Wooooo00?o003oooooooooool0Loooool1o`00007ooooo00000ol0003oooooooooo`0]ooooo`03
0000oooooooooooo00Wooooo1_ooO`0Pooooo`;oogl05oooool00ooo003oooooooooo`0[ooooo`03
o`00oooooooooooo07;ooooo0Ol00001ooooo`0000?o0000ooooooooool0;Oooool00`000?oooooo
ooooo`0;ooooo`Coogl07oooool4oomo01Kooooo00?oo`00ooooooooool0:oooool00ol00?oooooo
ooooo`1booooo`7o00000Oooool00003o`000?oo003ooooo02gooooo00<0003oooooooooool03?oo
ool2oomo023ooooo1?ooO`0Fooooo`03ool00?oooooooooo02_ooooo00?o003oooooooooool0L_oo
ool1o`00007ooooo00000ol0003oo`00ooooo`0/ooooo`030000oooooooooooo033ooooo0_ooO`0F
ooooo`03ool00?oooooooooo02gooooo00?o003oooooooooool0LOooool1o`00007ooooo00000ol0
003oo`00ooooo`0/ooooo`030000oooooooooooo04Sooooo00?oo`00ooooooooool0;Oooool00ol0
0?ooooooooooo`1aooooo`7o00000Oooool00003o`000?ooooooo`0002cooooo00<0003ooooooooo
ool0B?ooool00ooo003oooooooooo`0]ooooo`03o`00oooooooooooo077ooooo0Ol00001ooooo`00
00?o0000oooooooo0000:oooool00`000?ooooooooooo`18ooooo`03ool00?oooooooooo02oooooo
00?o003oooooooooool0L?ooool1o`00007ooooo00001?l0003ooooooooooooo000Zooooo`030000
oooooooooooo00?ooooo0_ooO`13ooooo`03ool00?oooooooooo02oooooo00?o003oooooooooool0
L?ooool1o`00007ooooo00001?l0003ooooooooooooo000Zooooo`030000oooooooooooo00;ooooo
1?ooO`12ooooo`03ool00?oooooooooo02oooooo00?o003oooooooooool0L?ooool1o`00007ooooo
00001Ol0003oooooooooooooooooo`0002Wooooo00<0003oooooooooool00_ooool4oomo047ooooo
00?oo`00ooooooooool0<?ooool00ol00?ooooooooooo`1`ooooo`7o00000Oooool00005o`000?oo
oooooooooooooooo0000:?ooool00`000?ooooooooooo`04ooooo`;oogl0@_ooool00ooo003ooooo
ooooo`0aooooo`03o`00oooooooooooo06oooooo0Ol00001ooooo`0000?o0000ooooooooool00_oo
ool00ooo003oooooooooo`0Uooooo`030000oooooooooooo04Oooooo00?oo`00ooooooooool0<_oo
ool00ol00?ooooooooooo`1_ooooo`7o00000Oooool00003o`000?oooooooooo00;ooooo00?oo`00
ooooooooool09Oooool00`000?ooooooooooo`17ooooo`03ool00?oooooooooo03;ooooo00?o003o
ooooooooool0Koooool1o`00007ooooo00000ol0003oooooooooo`03ooooo`03ool00?oooooooooo
02Cooooo00<0003oooooooooool0A_ooool00ooo003oooooooooo`0cooooo`03o`00oooooooooooo
06oooooo0Ol00001ooooo`0000?o0000ooooooooool01?ooool00ooo003oooooooooo`0Sooooo`03
0000oooooooooooo04Gooooo00?oo`00ooooooooool0=?ooool00ol00?ooooooooooo`1_ooooo`7o
00000Oooool00003o`000?oooooooooo00Gooooo00?oo`00ooooooooool08Oooool00`000?oooooo
ooooo`15ooooo`03ool00?oooooooooo03Kooooo00?o003oooooooooool0K_ooool1o`00007ooooo
00000ol0003oooooooooo`06ooooo`03ool00?oooooooooo023ooooo00<0003oooooooooool0AOoo
ool00ooo003oooooooooo`09ooooo`;oogl0:oooool00ol00?ooooooooooo`1^ooooo`7o00000Ooo
ool00003o`000?oooooooooo00Kooooo00?oo`00ooooooooool08?ooool00`000?ooooooooooo`14
ooooo`03ool00?oooooooooo00Wooooo1?ooO`0Zooooo`03o`00oooooooooooo06kooooo0Ol00001
ooooo`0000?o0000ooooooooool01oooool00ooo003oooooooooo`0Oooooo`030000oooooooooooo
02Sooooo0_ooO`0Iooooo`03ool00?oooooooooo00[ooooo1?ooO`0Zooooo`03o`00oooooooooooo
06kooooo0Ol00001ooooo`0000?o0000ooooooooool01oooool00ooo003oooooooooo`0Oooooo`03
0000oooooooooooo02Oooooo1?ooO`0Gooooo`03ool00?oooooooooo00cooooo0_ooO`0[ooooo`03
o`00oooooooooooo06kooooo0Ol00001ooooo`0000?o0000ooooooooool02?ooool00ooo003ooooo
ooooo`0Nooooo`030000oooooooooooo02Oooooo1?ooO`0Gooooo`03ool00?oooooooooo03Wooooo
00?o003oooooooooool0K_ooool1o`00007ooooo00000ol0003oooooooooo`09ooooo`03ool00?oo
oooooooo01gooooo00<0003oooooooooool0:?ooool2oomo01;ooooo1?l00?l00oooooooo`00oooo
o`0kooooo`03o`00oooooooooooo06kooooo0Ol00001ooooo`0000?o0000ooooooooool02_ooool0
0ooo003oooooooooo`0Looooo`030000oooooooooooo03_ooooo1_l00?lmooooo`03o`00oooooooo
oooo06kooooo0Ol00001ooooo`0000?o0000ooooooooool02oooool00ooo003oooooooooo`0Koooo
o`030000oooooooooooo03Oooooo0_ooO`000ooooooo003oo`00o`06o`00occooooo00?o003ooooo
ooooool0K_ooool1o`00007ooooo00000ol0003oooooooooo`0<ooooo`03ool00?oooooooooo01[o
oooo00<0003oooooooooool0=_ooool4oomo00So003o??ooool00ol00?ooooooooooo`1^ooooo`7o
00000Oooool00003o`000?oooooooooo00gooooo00?oo`00ooooooooool06Oooool00`000?oooooo
ooooo`0fooooo`Coogl02?l00?llooooo`03o`00oooooooooooo06kooooo0Ol00001ooooo`0000?o
0000ooooooooool03Oooool2ool001[ooooo00<0003oooooooooool0=oooool2oomo0003ooooool0
0?oo003o00Ko003o??ooool00ol00?ooooooooooo`1^ooooo`7o00000Oooool00003o`000?oooooo
oooo00oooooo00?oo`00ooooooooool05oooool00`000?ooooooooooo`0jooooo`03ool00?l00?oo
003o00Co003o?Oooool00ol00?ooooooooooo`1^ooooo`7o00000Oooool00003o`000?oooooooooo
013ooooo00?oo`00ooooooooool05_ooool00`000?ooooooooooo`0iooooo`03ool00?oooooooooo
00Co003o?_ooool00ol00?ooooooooooo`1^ooooo`7o00000Oooool00003o`000?oooooooooo017o
oooo00?oo`00ooooooooool05Oooool00`000?ooooooooooo`0hooooo`03ool00?oooooooooo04?o
oooo00?o003oooooooooool0K_ooool1o`00007ooooo00000ol0003oooooooooo`0Booooo`03ool0
0?oooooooooo01Cooooo00<0003oooooooooool0=_ooool2ool004Kooooo00?o003oooooooooool0
K_ooool1o`00007ooooo00000ol0003oooooooooo`0Cooooo`03ool00?oooooooooo01?ooooo00<0
003oooooooooool0=Oooool00ooo003oooooooooo`16ooooo`03o`00oooooooooooo06kooooo0Ol0
0001ooooo`0000?o0000ooooooooool05?ooool2ool001?ooooo00<0003oooooooooool0=?ooool0
0ooo003oooooooooo`17ooooo`03o`00oooooooooooo06kooooo0Ol00001ooooo`0000?o0000oooo
ooooool05_ooool2ool0017ooooo00<0003oooooooooool0<_ooool2ool004[ooooo00?o003ooooo
ooooool0K_ooool1o`00007ooooo00000ol0003oooooooooo`0Hooooo`03ool00?oooooooooo00ko
oooo00<0003oooooooooool0<Oooool00ooo003oooooooooo`1:ooooo`03o`00oooooooooooo06ko
oooo0Ol00001ooooo`0000?o0000ooooooooool06Oooool2ool000kooooo00<0003oooooooooool0
;oooool2ool004gooooo00?o003oooooooooool0K_ooool1o`00007ooooo00000ol0003ooooooooo
o`0Kooooo`03ool00?oooooooooo00_ooooo00<0003oooooooooool0;_ooool00ooo003ooooooooo
o`1<ooooo`03o`00oooooooooooo06oooooo0Ol00001ooooo`0000?o0000ooooooooool07?ooool2
ool000_ooooo00<0003oooooooooool0;Oooool00ooo003oooooooooo`1=ooooo`03o`00oooooooo
oooo06oooooo0Ol00001ooooo`0000?o0000ooooooooool07_ooool3ool000Wooooo00<0003ooooo
ooooool0:_ooool2ool0053ooooo00?o003oooooooooool0Koooool1o`00007ooooo00000ol0003o
ooooooooo`0Qooooo`;oo`001oooool00`000?ooooooooooo`0Wooooo`?oo`00D_ooool00ol00?oo
ooooooooo`1_ooooo`7o00000Oooool00003o`000?oooooooooo02?ooooo0_oo0005ooooo`030000
oooooooooooo02Gooooo0_oo001Dooooo`03o`00oooooooooooo073ooooo0Ol00001ooooo`0000?o
0000ooooooooool09Oooool4ool00003ooooo`000?oooooo02;ooooo1?oo001Fooooo`03o`00oooo
oooooooo073ooooo0Ol00001ooooo`0000?o0000ooooooooool0:Oooool2ool00003o`00oooo003o
o`0001gooooo0ooo001Jooooo`03o`00oooooooooooo073ooooo0Ol00001ooooo`0000?o0000oooo
ooooool0:oooool00`000?ooooooooooo`03ool001Cooooo1_oo001Mooooo`03o`00oooooooooooo
073ooooo0Ol00001ooooo`0000?o0000ooooooooool0;?ooool00`000?ooooooooooo`02oooooaCo
o`00H_ooool00ol00?ooooooooooo`1aooooo`7o00000Oooool00003o`000?oooooooooo02cooooo
00<0003oooooooooool0N?ooool00ol00?ooooooooooo`1aooooo`7o00000Oooool00003o`000?oo
oooooooo02cooooo00<0003oooooooooool0N?ooool00ol00?ooooooooooo`1aooooo`7o00000Ooo
ool00003o`000?oooooooooo02gooooo00<0003oooooooooool0M_ooool00ol00?ooooooooooo`1b
ooooo`7o00000Oooool00003o`000?oooooooooo02gooooo00<0003oooooooooool0M_ooool00ol0
0?ooooooooooo`1booooo`7o00000Oooool00003o`000?oooooooooo02gooooo00<0003ooooooooo
ool0M_ooool00ol00?ooooooooooo`1booooo`7o00000Oooool00003o`000?oooooooooo02kooooo
00<0003oooooooooool0M?ooool00ol00?ooooooooooo`1cooooo`7o00000Oooool00003o`000?oo
oooooooo02kooooo00<0003oooooooooool0M?ooool00ol00?ooooooooooo`1cooooo`7o00000Ooo
ool00003o`000?oooooooooo02kooooo00<0003oooooooooool0M?ooool00ol00?ooooooooooo`1c
ooooo`7o00000Oooool00003o`000?oooooooooo02oooooo00<0003oooooooooool0L_ooool00ol0
0?ooooooooooo`1dooooo`7o00000Oooool00003o`000?oooooooooo02oooooo00<0003ooooooooo
ool0L_ooool00ol00?ooooooooooo`1dooooo`7o00000Oooool00003o`000?oooooooooo02oooooo
00<0003oooooooooool0L_ooool00ol00?ooooooooooo`1dooooo`7o00000Oooool00003o`000?oo
oooooooo033ooooo00<0003oooooooooool0Koooool2o`00ogOooooo0Ol00001ooooo`0000?o0000
ooooooooool0<?ooool00`000?ooooooooooo`1_ooooo`03o`00oooooooooooo07Kooooo0Ol00001
ooooo`0000?o0000ooooooooool0<Oooool00`000?ooooooooooo`1]ooooo`03o`00oooooooooooo
07Oooooo0Ol00001ooooo`0000?o0000ooooooooool0<_ooool00`000?ooooooooooo`1/ooooo`03
o`00oooooooooooo07Oooooo0Ol00001ooooo`0000?o0000ooooooooool0<_ooool00`000?oooooo
ooooo`1[ooooo`03o`00oooooooooooo063ooooo0_ooO`0Fooooo`7o00000Oooool00003o`000?oo
oooooooo03?ooooo00<0003oooooooooool0JOooool00ol00?ooooooooooo`1Pooooo`Coogl05Ooo
ool1o`00007ooooo00000ol0003oooooooooo`0dooooo`030000oooooooooooo06Sooooo00?o003o
ooooooooool0H?ooool4oomo01Gooooo0Ol00001ooooo`0000?o0000ooooooooool0=Oooool00`00
0?ooooooooooo`1Vooooo`03o`00oooooooooooo06;ooooo0_ooO`0Fooooo`7o00000Oooool00003
o`000?oooooooooo03Gooooo00?o003oooooooooool0I_ooool00ol00?ooooooooooo`1jooooo`7o
00000Oooool00003o`000?oooooooooo03Kooooo00?o003oooooooooool0I?ooool00ol00?oooooo
ooooo`1kooooo`7o00000Oooool00003o`000?oooooooooo03Oooooo00?o003oooooooooool0H_oo
ool00ol00?ooooooooooo`1looooo`7o00000Oooool00003o`000?oooooooooo03Sooooo00?o003o
ooooooooool0Goooool2o`00ogoooooo0Ol00001ooooo`0000?o0000ooooooooool0>Oooool00ol0
0?ooooooooooo`1Mooooo`03o`00oooooooooooo07oooooo0Ol00001ooooo`0000?o0000oooooooo
ool0>_ooool00ol00?ooooooooooo`1Kooooo`03o`00oooooooooooo083ooooo0Ol00001ooooo`00
00?o0000ooooooooool0>oooool00ol00?ooooooooooo`1Iooooo`03o`00oooooooooooo087ooooo
0Ol00001ooooo`0000?o0000ooooooooool0??ooool00ol00?ooooooooooo`1Gooooo`03o`00oooo
oooooooo08;ooooo0Ol00001ooooo`0000?o0000ooooooooool0?Oooool00ol00?ooooooooooo`1E
ooooo`03o`00oooooooooooo08?ooooo0Ol00001ooooo`0000?o0000ooooooooool0?_ooool00ol0
0?ooooooooooo`1Cooooo`03o`00oooooooooooo08Cooooo0Ol00001ooooo`0000?o0000oooooooo
ool0?oooool00ol00?ooooooooooo`1@ooooo`;o003o8Oooool2oomo06Cooooo0Ol00001ooooo`00
00?o0000ooooooooool0@?ooool00ol00?ooooooooooo`1>ooooo`03o`00oooooooooooo023ooooo
1?ooO`1Sooooo`7o00000Oooool00003o`000?oooooooooo047ooooo0_l00?m=ooooo`03o`00oooo
oooooooo027ooooo1?ooO`1Sooooo`7o00000Oooool00003o`000?oooooooooo04?ooooo00?o003o
ooooooooool0BOooool00ol00?ooooooooooo`0Sooooo`;oogl0=Oooool2oomo02gooooo0Ol00001
ooooo`0000?o0000ooooooooool0A?ooool2o`00odSooooo00?o003oooooooooool0Doooool2oomo
00Gooooo1?ooO`0/ooooo`7o00000Oooool00003o`000?oooooooooo04Kooooo0_l00?m5ooooo`03
o`00oooooooooooo05?ooooo1?ooO`04ooooo`Coogl0;?ooool1o`00007ooooo00000ol0003ooooo
ooooo`18ooooo`03o`00oooooooooooo043ooooo0_l00?lfooooo`;oogl07_ooool4oomo00Gooooo
0_ooO`0]ooooo`7o00000Oooool00003o`000?oooooooooo04Wooooo0_l00?lnooooo`;o003o=ooo
ool4oomo01kooooo0_ooO`0eooooo`7o00000Oooool00003o`000?oooooooooo04_ooooo0ol00?lj
ooooo`03o`00oooooooooooo03Oooooo1?ooO`1Eooooo`7o00000Oooool00003o`000?oooooooooo
04kooooo0_l00?lfooooo`;o003o>oooool2oomo05Kooooo0Ol00001ooooo`0000?o0000oooooooo
ool0D?ooool3o`00oc3ooooo0ol00?lcooooo`;oogl09Oooool2oomo03Wooooo0Ol00001ooooo`00
00?o0000ooooooooool0Doooool2o`00ob[ooooo1?l00?leooooo`Coogl08oooool4oomo03Sooooo
0Ol00001ooooo`0000?o0000ooooooooool0EOooool3o`00ob?ooooo1?l00?leooooo`;oogl00_oo
ool4oomo02?ooooo1?ooO`03ooooo`;oogl0<oooool1o`00007ooooo00000ol0003oooooooooo`1H
ooooo`?o003o7Oooool3o`00ocSooooo1?ooO`02ooooo`;oogl04oooool2oomo013ooooo0_ooO`03
ooooo`Coogl0<_ooool1o`00007ooooo00000ol0003oooooooooo`1Kooooo`?o003o5?ooool6o`00
oc_ooooo1?ooO`06ooooo`;oogl03_ooool4oomo01Cooooo1?ooO`0booooo`7o00000Oooool00003
o`000?oooooooooo05kooooo5?l00?m2ooooo`;oogl01_ooool4oomo00gooooo1?ooO`0Eooooo`;o
ogl0<oooool1o`00007ooooo00000ol0003oooooooooo`2;ooooo`;oogl09oooool2oomo00Kooooo
1?ooO`0>ooooo`;oogl0Boooool1o`00007ooooo00000ol0003oooooooooo`2:ooooo`Coogl09Ooo
ool4oomo00Kooooo0_ooO`1Looooo`7o00000Oooool00003o`000?oooooooooo08[ooooo1?ooO`0U
ooooo`Coogl0I?ooool1o`00007ooooo00000ol0003oooooooooo`2;ooooo`;oogl09oooool2oomo
06Gooooo0Ol00001ooooo`0000?o0000ooooooooool0U_ooool2oomo03[ooooo0_ooO`17ooooo`7o
00000Oooool00003o`000?oooooooooo09Gooooo1?ooO`0>ooooo`;oogl0:?ooool4oomo04Kooooo
0Ol00001ooooo`0000?o0000ooooooooool0UOooool4oomo00gooooo1?ooO`0Wooooo`Coogl0A_oo
ool1o`00007ooooo00000ol0003oooooooooo`2Fooooo`;oogl03_ooool4oomo02Sooooo0_ooO`17
ooooo`7o00000Oooool00003o`000?oooooooooo0:Oooooo0_ooO`1booooo`7o00000Oooool00003
o`000?oooooooooo0>_ooooo0_ooO`0^ooooo`7o00000Oooool00003o`000?oooooooooo0>[ooooo
1?ooO`0]ooooo`7o00000Oooool00003o`000?oooooooooo0=Kooooo0_ooO`0Booooo`Coogl0;Ooo
ool1o`00007ooooo00000ol0003oooooooooo`3Eooooo`Coogl04_ooool2oomo02kooooo0Ol00001
ooooo`0000?o0000ooooooooool0]oooool2oomo01Sooooo1Ooo0?l3oomo04;ooooo0Ol00001oooo
o`0000?o0000ooooooooool0]_ooool4oomo01Kooooo1ooo0?l00oooO`3oooooooooo`11ooooo`7o
00000Oooool00003o`000?oooooooooo0;?ooooo0_ooO`000oooooooogl0oomo0002oomo01Gooooo
2Ooo0?m3ooooo`7o00000Oooool00003o`000?oooooooooo0:Sooooo0_ooO`08ooooo`Coogl000?o
oooooomo0?ooO`005Oooool;ool0od;ooooo0Ol00001ooooo`0000?o0000ooooooooool0Y_ooool5
oomo00Oooooo1?ooO`0Gooooo`03oomo0?oo0?ooo`3o00Woo`3o@_ooool1o`00007ooooo00000ol0
003oooooooooo`2Uooooo`Koogl02?ooool2oomo01Oooooo0_ooO`0;ool0od;ooooo0Ol00001oooo
o`0000?o0000ooooooooool0YOooool5oomo02;ooooo0_ooO`0;ool0od;ooooo0Ol00001ooooo`00
00?o0000ooooooooool0M_ooool2oomo02kooooo0_ooO`0Uooooo`03oomo0?oo0?ooo`3o00Woo`3o
@_ooool1o`00007ooooo00000ol0003oooooooooo`1eooooo`Coogl0E_ooool9ool0od?ooooo0Ol0
0001ooooo`0000?o0000ooooooooool0MOooool4oomo00[ooooo0_ooO`1;ooooo`Ooo`3oA?ooool1
o`00007ooooo00000ol0003oooooooooo`1fooooo`;oogl02_ooool4oomo02[ooooo0_ooO`0Ooooo
o`Goo`3oAOooool1o`00007ooooo00000ol0003oooooooooo`22ooooo`Coogl0:Oooool4oomo06So
oooo0Ol00001ooooo`0000?o0000ooooooooool0Poooool2oomo02Cooooo0_ooO`04ooooo`Coogl0
J?ooool1o`00007ooooo00000ol0003oooooooooo`2Xooooo`Coogl01?ooool2oomo06Wooooo0Ol0
0001ooooo`0000?o0000ooooooooool0Z?ooool4oomo06oooooo0Ol00001ooooo`0000?o0000oooo
ooooool0ZOooool2oomo073ooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o
00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003ooooooooo
o`3ooooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool0
0003o`000?oooooooooo08Cooooo0_ooO`2Eooooo`7o00000Oooool00003o`000?oooooooooo08?o
oooo1?ooO`2Dooooo`7o00000Oooool00003o`000?oooooooooo08?ooooo1?ooO`2Dooooo`7o0000
0Oooool00003o`000?oooooooooo08Cooooo0_ooO`0/ooooo`;oogl0Ioooool1o`00007ooooo0000
0ol0003oooooooooo`2aooooo`Coogl0I_ooool1o`00007ooooo00000ol0003oooooooooo`2aoooo
o`Coogl0I_ooool1o`00007ooooo00000ol0003oooooooooo`2booooo`;oogl0Ioooool1o`00007o
oooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooo
oolLooooo`7o00000Oooool00003o`000?oooooooooo07_ooooo0_ooO`2Nooooo`7o00000Oooool0
0003o`000?oooooooooo07[ooooo1?ooO`2Mooooo`7o00000Oooool00003o`000?oooooooooo07[o
oooo1?ooO`0Pooooo`;oogl0Noooool1o`00007ooooo00000ol0003oooooooooo`1kooooo`;oogl0
8?ooool4oomo07[ooooo0Ol00001ooooo`0000?o0000ooooooooool0WOooool4oomo07[ooooo0Ol0
0001ooooo`0000?o0000ooooooooool0T?ooool2oomo00cooooo0_ooO`1kooooo`7o00000Oooool0
0003o`000?oooooooooo08oooooo1?ooO`28ooooo`7o00000Oooool00003o`000?oooooooooo08oo
oooo1?ooO`28ooooo`7o00000Oooool00003o`000?oooooooooo093ooooo0_ooO`0Sooooo`;oogl0
I?ooool1o`00007ooooo00000ol0003oooooooooo`2dooooo`Coogl0Hoooool1o`00007ooooo0000
0ol0003oooooooooo`2dooooo`Coogl0Hoooool1o`00007ooooo00000ol0003oooooooooo`2eoooo
o`;oogl0I?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`00
00?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?oo
ool1o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000oooo
ooooool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007o
oooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooo
oolLooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0
003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o
00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003ooooooooo
o`3ooooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool0
0003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooooaco
oooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oo
oooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001
ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo0?oo
oooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o
0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1
o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000oooooooo
ool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo
00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolL
ooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003o
ooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o0000
0Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3o
oooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003
o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo
0Ol00001ooooo`0000?o0000ooooooooool0S_ooool2oomo08_ooooo0Ol00001ooooo`0000?o0000
ooooooooool0SOooool4oomo08[ooooo0Ol00001ooooo`0000?o0000ooooooooool0SOooool4oomo
08[ooooo0Ol00001ooooo`0000?o0000ooooooooool0S_ooool2oomo08_ooooo0Ol00001ooooo`00
00?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?oo
ool1o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000oooo
ooooool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007o
oooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooo
oolLooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0
003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o
00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003ooooooooo
o`3ooooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool0
0003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooooaco
oooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oo
oooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001
ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo0?oo
oooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`00ool0
000Po`00007ooooo0000\
\>"],
  ImageRangeCache->{{{0, 287}, {287, 0}} -> {-1.01089, -1.01089, 0.00704453, \
0.00704453}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.49505 0.5 0.49505 [
[ 0 0 -0.125 0 ]
[ 0 0 -0.125 0 ]
[ 0 1 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
0 0 m
1 0 L
s
0 0 m
0 1 L
s
0 1 m
1 1 L
s
1 0 m
1 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
1 .5 0 r
.015 w
.03175 .1355 Mdot
.03435 .12523 Mdot
.11137 .12765 Mdot
.14107 .18841 Mdot
.16218 .24538 Mdot
.17294 .21053 Mdot
.18267 .18577 Mdot
.18434 .1304 Mdot
.18553 .30956 Mdot
.20401 .239 Mdot
.21247 .27571 Mdot
.21687 .20845 Mdot
.22376 .2799 Mdot
.22832 .27485 Mdot
.29063 .20974 Mdot
.29686 .25079 Mdot
.30487 .22936 Mdot
.30683 .34623 Mdot
.32055 .20902 Mdot
.32574 .21979 Mdot
.34472 .28521 Mdot
.35998 .36393 Mdot
.36335 .24976 Mdot
.3794 .36608 Mdot
.42386 .66992 Mdot
.44391 .74519 Mdot
.45059 .34198 Mdot
.47208 .67586 Mdot
.47436 .71381 Mdot
.49778 .59825 Mdot
.50874 .91643 Mdot
.51516 .76219 Mdot
.53655 .61374 Mdot
.56563 .75219 Mdot
.59189 .65665 Mdot
.59581 .61604 Mdot
.59923 .6556 Mdot
.60292 .68499 Mdot
.62656 .67779 Mdot
.63555 .72451 Mdot
.63919 .652 Mdot
.64169 .6004 Mdot
.64246 .58611 Mdot
.64496 .54267 Mdot
.64608 .77288 Mdot
.65077 .64308 Mdot
.66065 .57816 Mdot
.67474 .59169 Mdot
.69296 .563 Mdot
.72815 .65902 Mdot
.73169 .58879 Mdot
.74669 .61318 Mdot
.74821 .65474 Mdot
.75963 .63781 Mdot
.79673 .57809 Mdot
.80925 .55852 Mdot
.81525 .58444 Mdot
.83417 .62985 Mdot
.83598 .55526 Mdot
.91595 .49319 Mdot
1 0 0 r
.005 w
.00495 .28842 m
.00628 .29156 L
.01857 .31761 L
.03101 .33781 L
.03525 .34367 L
.05706 .36884 L
.05795 .36972 L
.08312 .39115 L
.08963 .39578 L
.10917 .40763 L
.13523 .41964 L
.14074 .42183 L
.16128 .42794 L
.18734 .43294 L
.21339 .43485 L
.23945 .43375 L
.2655 .42959 L
.29156 .42219 L
.29261 .42183 L
.31761 .41124 L
.34367 .39603 L
.34405 .39578 L
.36972 .37551 L
.37582 .36972 L
.39578 .34724 L
.39849 .34367 L
.41525 .31761 L
.42183 .30485 L
.4275 .29156 L
.436 .2655 L
.44117 .23945 L
.44325 .21339 L
.44232 .18734 L
.43834 .16128 L
.43114 .13523 L
.42183 .11212 L
.42037 .10917 L
.40546 .08312 L
.39578 .06961 L
.38528 .05706 L
.36972 .04137 L
.35758 .03101 L
.34367 .02092 L
.31761 .00569 L
.3162 .00495 L
s
.00495 .12854 m
.01344 .10917 L
.02832 .08312 L
.03101 .07912 L
.04848 .05706 L
.05706 .04802 L
.07619 .03101 L
.08312 .02579 L
.10917 .00934 L
.11742 .00495 L
s
0 0 1 r
.29156 .15739 m
.31761 .14824 L
.34367 .14249 L
.36972 .13986 L
.39578 .14025 L
.42183 .14366 L
.44789 .15025 L
.47394 .16034 L
.47599 .16128 L
.5 .17443 L
.51844 .18734 L
.52606 .19355 L
.54662 .21339 L
.55211 .21962 L
.56712 .23945 L
.57817 .25755 L
.58227 .2655 L
.59322 .29156 L
.60058 .31761 L
.60422 .3392 L
.60471 .34367 L
.6058 .36972 L
.60422 .39297 L
.60387 .39578 L
.59886 .42183 L
.59054 .44789 L
.57848 .47394 L
.57817 .47453 L
.562 .5 L
.55211 .51255 L
.53968 .52606 L
.52606 .53862 L
.50853 .55211 L
.5 .55773 L
.47394 .57183 L
.45901 .57817 L
.44789 .5819 L
.42183 .5885 L
.39578 .59192 L
.36972 .59231 L
.34367 .58968 L
.31761 .58392 L
.29972 .57817 L
.29156 .57477 L
.2655 .56178 L
.25025 .55211 L
.23945 .54409 L
.21914 .52606 L
.21339 .52008 L
.19681 .5 L
Mistroke
.18734 .48608 L
.18031 .47394 L
.16827 .44789 L
.16128 .42714 L
.15996 .42183 L
.15493 .39578 L
.153 .36972 L
.15409 .34367 L
.15823 .31761 L
.16128 .3045 L
.16559 .29156 L
.17653 .2655 L
.18734 .24609 L
.19169 .23945 L
.21221 .21339 L
.21339 .21211 L
.23945 .1881 L
.24041 .18734 L
.2655 .17038 L
.28271 .16128 L
.29156 .15739 L
Mfstroke
1 0 0 r
.03 w
.21687 .20845 Mdot
0 0 1 r
.3794 .36608 Mdot
1 0 0 r
.79703 .00495 m
.79703 .02303 L
.87129 .02303 L
.87129 .00495 L
F
0 0 1 r
.89604 .00495 m
.89604 .2344 L
.9703 .2344 L
.9703 .00495 L
F
1 0 1 r
.04 w
.75963 .63781 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P000182000`400?l00000o`00003ooooooolQ
ooooo`00ool0000Po`00007ooooo00000ol0003oooooooooo`0Mooooo`;oo`00>?ooool3ool00<7o
oooo0Ol00001ooooo`0000?o0000ooooooooool06oooool2ool003gooooo00?oo`00ooooooooool0
Q?oooolEool000Sooooo5Ol00?l8ooooo`7o00000Oooool00003o`000?oooooooooo01[ooooo00?o
o`00ooooooooool0?_ooool2ool008Cooooo5Ooo0008oooooaGo003o2?ooool1o`00007ooooo0000
0ol0003oooooooooo`0Hooooo`;oo`00@oooool00ooo003oooooooooo`21oooooaGoo`002?oooolE
o`00o`Sooooo0Ol00001ooooo`0000?o0000ooooooooool05_ooool2ool004Kooooo00?oo`00oooo
ooooool0P?oooolEool000Sooooo5Ol00?l8ooooo`7o00000Oooool00003o`000?oooooooooo01Go
oooo00?oo`00ooooooooool0Aoooool2ool0083ooooo5Ooo0008oooooaGo003o2?ooool1o`00007o
oooo00000ol0003oooooooooo`0Dooooo`03ool00?oooooooooo04[ooooo00?oo`00ooooooooool0
V_oooolEo`00o`Sooooo0Ol00001ooooo`0000?o0000ooooooooool04oooool00ooo003ooooooooo
o`1<ooooo`03ool00?oooooooooo09Wooooo5Ol00?l8ooooo`7o00000Oooool00003o`000?oooooo
oooo017ooooo0_oo001@ooooo`;oo`00VOoooolEo`00o`Sooooo0Ol00001ooooo`0000?o0000oooo
ooooool04?ooool00ooo003oooooooooo`1Booooo`;oo`00UooooolEo`00o`Sooooo0Ol00001oooo
o`0000?o0000ooooooooool03oooool00ooo003oooooooooo`1Eooooo`03ool00?oooooooooo09Co
oooo5Ol00?l8ooooo`7o00000Oooool00003o`000?oooooooooo00kooooo00?oo`00ooooooooool0
E_ooool00ooo003oooooooooo`2DoooooaGo003o2?ooool1o`00007ooooo00000ol0003ooooooooo
o`0=ooooo`03ool00?oooooooooo05Sooooo00?oo`00ooooooooool0TooooolEo`00o`Sooooo0Ol0
0001ooooo`0000?o0000ooooooooool03Oooool00ooo003oooooooooo`1Iooooo`03ool00?oooooo
oooo09;ooooo5Ol00?l8ooooo`7o00000Oooool00003o`000?oooooooooo00cooooo00?oo`00oooo
ooooool0Foooool00ooo003oooooooooo`2AoooooaGo003o2?ooool1o`00007ooooo00000ol0003o
ooooooooo`0;ooooo`03ool00?oooooooooo05gooooo00?oo`00ooooooooool0T?oooolEo`00o`So
oooo0Ol00001ooooo`0000?o0000ooooooooool02oooool00ooo003oooooooooo`1Mooooo`03ool0
0?oooooooooo093ooooo5Ol00?l8ooooo`7o00000Oooool00003o`000?oooooooooo00[ooooo00?o
o`00ooooooooool0Goooool00ooo003oooooooooo`2?oooooaGo003o2?ooool1o`00007ooooo0000
0ol0003oooooooooo`09ooooo`03ool00?oooooooooo067ooooo00?oo`00ooooooooool0S_oooolE
o`00o`Sooooo0Ol00001ooooo`0000?o0000ooooooooool02?ooool00ooo003oooooooooo`1Soooo
o`03ool00?oooooooooo08gooooo5Ol00?l8ooooo`7o00000Oooool00003o`000?oooooooooo00Oo
oooo00?oo`00ooooooooool0IOooool00ooo003oooooooooo`2<oooooaGo003o2?ooool1o`00007o
oooo00000ol0003oooooooooo`06ooooo`03ool00?oooooooooo06Oooooo00?oo`00ooooooooool0
RooooolEo`00o`Sooooo0Ol00001ooooo`0000?o0000ooooooooool01Oooool00ooo003ooooooooo
o`1Yooooo`03ool00?oooooooooo08[ooooo5Ol00?l8ooooo`7o00000Oooool00003o`000?oooooo
oooo00Gooooo00?oo`00ooooooooool0JOooool00ooo003oooooooooo`2:oooooaGo003o2?ooool1
o`00007ooooo00000ol0003oooooooooo`04ooooo`03ool00?oooooooooo06_ooooo00?oo`00oooo
ooooool0ROoooolEo`00o`Sooooo0Ol00001ooooo`0000?o0000ooooooooool00oooool00ooo003o
ooooooooo`1/ooooo`03ool00?oooooooooo08Wooooo5Ol00?l8ooooo`7o00000Oooool00003o`00
0?oooooooooo00?ooooo00?oo`00ooooooooool0KOooool00ooo003oooooooooo`28oooooaGo003o
2?ooool1o`00007ooooo00000ol0003oooooooooo`02ooooo`03ool00?oooooooooo06kooooo00?o
o`00ooooooooool0R?oooolEo`00o`Sooooo0Ol00001ooooo`0000?o0000ooooooooool00_ooool0
0ooo003oooooooooo`1_ooooo`03ool00?oooooooooo08Oooooo5Ol00?l8ooooo`7o00000Oooool0
0005o`000?oooooooooooooooooo0000L_ooool00ooo003oooooooooo`27oooooaGo003o2?ooool1
o`00007ooooo00001?l0003ooooooooooooo001dooooo`03ool00?oooooooooo08Kooooo5Ol00?l8
ooooo`7o00000Oooool00004o`000?ooooooooooool007Gooooo00?oo`00ooooooooool0QOoooolE
o`00o`Sooooo0Ol00001ooooo`0000?o0000oooooooo0000M_ooool00ooo003oooooooooo`25oooo
oaGo003o2?ooool1o`00007ooooo00000ol0003oooooool00006ooooo`;oogl0Koooool00ooo003o
ooooooooo`24oooooaGo003o2?ooool1o`00007ooooo00000ol0003oooooool00005ooooo`Coogl0
4oooool2oomo05Wooooo00?oo`00ooooooooool0Q?oooolEo`00o`Sooooo0Ol00001ooooo`0000?o
0000ool00?ooool01Oooool4oomo01;ooooo1?ooO`0Booooo`;oogl0A?ooool00ooo003ooooooooo
o`24oooooaGo003o2?ooool1o`00007ooooo00000ol0003oooooooooo`05ooooo`?oogl04oooool4
oomo017ooooo1?ooO`14ooooo`03ool00?oooooooooo08?ooooo5Ol00?l8ooooo`7o00000Oooool0
0003o`000?oooooooooo00Cooooo1?ooO`0Dooooo`;oogl04_ooool4oomo04Cooooo00?oo`00oooo
ooooool0PooooolEo`00o`Sooooo0Ol00001ooooo`0000?o0000ooooooooool01?ooool4oomo02Wo
oooo0_ooO`15ooooo`03ool00?oooooooooo08?ooooo5Ol00?l8ooooo`7o00000Oooool00003o`00
0?oooooooooo00Gooooo0_ooO`1FoooooaKo003o1Oooool00ooo003oooooooooo`23oooooaGo003o
2?ooool1o`00007ooooo00000ol0003oooooooooo`1Jooooo`?o003o5_ooool6o`00o`03ool00?oo
oooooooo08;ooooo5Ol00?l8ooooo`7o00000Oooool00003o`000?oooooooooo05Oooooo0ol00?lO
ooooo`?o003oP_oooolEo`00o`Sooooo0Ol00001ooooo`0000?o0000ooooooooool0E?ooool3o`00
ob;ooooo00?oo`00ooooooooool00ol00?mooooooaGo003o2?ooool1o`00007ooooo00000ol0003o
ooooooooo`1Aooooo`?o003o9Oooool00ooo003oooooooooo`03ooooo`?o003oO?oooolEo`00o`So
oooo0Ol00001ooooo`0000?o0000ooooooooool0Coooool20000obWooooo00?oo`00ooooooooool0
1Oooool3o`00ogWooooo5Ol00?l8ooooo`7o00000Oooool00003o`000?oooooooooo04gooooo0P00
0?l[ooooo`03ool00?oooooooooo00Sooooo0_l00?mgoooooaGo003o2?ooool1o`00007ooooo0000
0ol0003oooooooooo`1:ooooo`<0003o;Oooool00ooo003oooooooooo`0:ooooo`;o003oMOoooolE
o`00o`Sooooo0Ol00001ooooo`0000?o0000ooooooooool0B?ooool20000oc3ooooo00?oo`00oooo
ooooool03?ooool00ol00?ooooooooooo`1boooooaGo003o2?ooool1o`00007ooooo00000ol0003o
ooooooooo`17ooooo`030000oooooooooooo033ooooo00?oo`00ooooooooool03Oooool2o`00og;o
oooo5Ol00?l8ooooo`7o00000Oooool00003o`000?oooooooooo04Gooooo0P000?ldooooo`03ool0
0?oooooooooo00kooooo0_l00?m`oooooaGo003o2?ooool1o`00007ooooo00000ol0003ooooooooo
o`14ooooo`030000oooooooooooo03Cooooo00?oo`00ooooooooool04?ooool2o`00ofkooooo5Ol0
0?l8ooooo`7o00000Oooool00003o`000?oooooooooo02Cooooo0_ooO`0:ooooo`;oogl04Oooool0
0`000?ooooooooooo`0eooooo`03ool00?oooooooooo01;ooooo00?o003oooooooooool0JooooolE
o`00o`Sooooo0Ol00001ooooo`0000?o0000ooooooooool08oooool4oomo00Sooooo1?ooO`0?oooo
o`030000oooooooooooo03Kooooo00?oo`00ooooooooool04oooool00ol00?ooooooooooo`1Zoooo
oaGo003o2?ooool1o`00007ooooo00000ol0003oooooooooo`0Sooooo`Coogl02?ooool4oomo00go
oooo00<0003oo`00ooooool0>?ooool00ooo003oooooooooo`0Dooooo`03o`00oooooooooooo06Wo
oooo5Ol00?l8ooooo`7o00000Oooool00003o`000?oooooooooo02Cooooo0_ooO`0:ooooo`;oogl0
3Oooool00`000?ooooooooooo`0iooooo`03ool00?oooooooooo01Gooooo00?o003oooooooooool0
J?oooolEo`00o`Sooooo0Ol00001ooooo`0000?o0000ooooooooool0>Oooool4ool00003ooooo`00
0?oooooo03_ooooo00?oo`00ooooooooool05_ooool00ol00?ooooooooooo`1WoooooaGo003o2?oo
ool1o`00007ooooo00000ol0003oooooooooo`0hooooo`Koo`00?Oooool00ooo003oooooooooo`0G
ooooo`03o`00oooooooooooo06Kooooo5Ol00?l8ooooo`7o00000Oooool00003o`000?oooooooooo
03Oooooo2?oo000@ooooo`;oogl01oooool2oomo02;ooooo00?oo`00ooooooooool05oooool00ol0
0?ooooooooooo`1UoooooaGo003o2?ooool1o`00007ooooo00000ol0003oooooooooo`0^ooooo`;o
ogl01oooool8ool000oooooo1?ooO`05ooooo`Coogl08Oooool00ooo003oooooooooo`0Hooooo`03
o`00oooooooooooo06Cooooo5Ol00?l8ooooo`7o00000Oooool00003o`000?oooooooooo02gooooo
1?ooO`06ooooo`Soo`003oooool4oomo00Gooooo1?ooO`0Qooooo`03ool00?oooooooooo01Wooooo
00?o003oooooooooool0HooooolEo`00o`Sooooo0Ol00001ooooo`0000?o0000ooooooooool0;Ooo
ool4oomo00Kooooo2?oo000@ooooo`;oogl01oooool3oomo027ooooo00?oo`00ooooooooool06_oo
ool00ol00?ooooooooooo`1RoooooaGo003o2?ooool1o`00007ooooo00000ol0003oooooooooo`0^
ooooo`;oogl02?ooool6ool001[ooooo1?ooO`0Pooooo`03ool00?oooooooooo01_ooooo00?o003o
ooooooooool0HOoooolEo`00o`Sooooo0Ol00001ooooo`0000?o0000ooooooooool0>?ooool00`00
0?ooo`00ool00002ool001_ooooo1?ooO`0Pooooo`03ool00?oooooooooo01cooooo00?o003ooooo
ooooool0H?oooolEo`00o`Sooooo0Ol00001ooooo`0000?o0000ooooooooool0=oooool00`000?oo
ooooooooo`0Iooooo`;oogl01?ooool2oomo027ooooo00?oo`00ooooooooool07?ooool00ol00?oo
ooooooooo`1PoooooaGo003o2?ooool1o`00007ooooo00000ol0003oooooooooo`0fooooo`030000
oooooooooooo01Wooooo1?ooO`0Uooooo`03ool00?oooooooooo01kooooo00?o003oooooooooool0
GooooolEo`00o`Sooooo0Ol00001ooooo`0000?o0000ooooooooool0=_ooool00`000?oooooooooo
o`0Iooooo`Coogl09Oooool00ooo003oooooooooo`0Oooooo`03o`00oooooooooooo05kooooo5Ol0
0?l8ooooo`7o00000Oooool00003o`000?oooooooooo03Gooooo00@0003oooooooooO`3oogl06_oo
ool2oomo02Kooooo00?oo`00ooooooooool08?ooool00ol00?ooooooooooo`1MoooooaGo003o2?oo
ool1o`00007ooooo00000ol0003oooooooooo`0dooooo`030000ooooooooogl000?oogl0@Oooool0
0ooo003oooooooooo`0Qooooo`03o`00oooooooooooo07Wooooo0Ol00001ooooo`0000?o0000oooo
ooooool0:oooool2oomo00Kooooo00<0003oooooooooool01?ooO`11ooooo`03ool00?oooooooooo
027ooooo00?o003oooooooooool0NOooool1o`00007ooooo00000ol0003oooooooooo`0Zooooo`Co
ogl01?ooool00`000?ooooooooooo`02ooooo`;oogl06?ooool2oomo017ooooo0_ooO`0Eooooo`03
ool00?oooooooooo02;ooooo00?o003oooooooooool0N?ooool1o`00007ooooo00000ol0003ooooo
ooooo`0Zooooo`Coogl01?ooool00`000?ooooooooooo`0Kooooo`Coogl03oooool4oomo01Cooooo
00?oo`00ooooooooool08oooool00ol00?ooooooooooo`1gooooo`7o00000Oooool00003o`000?oo
oooooooo02_ooooo0_ooO`04ooooo`030000oooooooooooo01cooooo1?ooO`0?ooooo`Coogl05?oo
ool00ooo003oooooooooo`0Sooooo`03o`00oooooooooooo07Oooooo0Ol00001ooooo`0000?o0000
ooooooooool0<Oooool00`000?ooooooooooo`0Mooooo`;oogl04Oooool2oomo01Cooooo00?oo`00
ooooooooool09Oooool00ol00?ooooooooooo`1fooooo`7o00000Oooool00003o`000?oooooooooo
033ooooo00<0003oooooooooool0Aoooool00ooo003oooooooooo`0Uooooo`03o`00oooooooooooo
07Kooooo0Ol00001ooooo`0000?o0000ooooooooool0<?ooool00`000?ooooooooooo`17ooooo`03
ool00?oooooooooo02Kooooo00?o003oooooooooool0MOooool1o`00007ooooo00000ol0003ooooo
ooooo`0_ooooo`030000oooooooooooo04Sooooo00?oo`00ooooooooool09oooool00ol00?oooooo
ooooo`1dooooo`7o00000Oooool00003o`000?oooooooooo02oooooo00<0003oooooooooool01ooo
ool2oomo00;ooooo0_ooO`0kooooo`03ool00?oooooooooo02Oooooo00?o003oooooooooool0M?oo
ool1o`00007ooooo00000ol0003oooooooooo`0^ooooo`030000oooooooooooo00Oooooo2?ooO`0i
ooooo`03ool00?oooooooooo02Wooooo00?o003oooooooooool0Loooool1o`00007ooooo00000ol0
003oooooooooo`0^ooooo`030000oooooooooooo00Oooooo2?ooO`0iooooo`03ool00?oooooooooo
02Wooooo00?o003oooooooooool0Loooool1o`00007ooooo00000ol0003oooooooooo`0]ooooo`03
0000oooooooooooo00Wooooo1_ooO`0Pooooo`;oogl05oooool00ooo003oooooooooo`0[ooooo`03
o`00oooooooooooo07;ooooo0Ol00001ooooo`0000?o0000ooooooooool0;Oooool00`000?oooooo
ooooo`0;ooooo`Coogl07oooool4oomo01Kooooo00?oo`00ooooooooool0:oooool00ol00?oooooo
ooooo`1booooo`7o00000Oooool00003o`000?oo003ooooo02gooooo00<0003oooooooooool03?oo
ool2oomo023ooooo1?ooO`0Fooooo`03ool00?oooooooooo02_ooooo00?o003oooooooooool0L_oo
ool1o`00007ooooo00000ol0003oo`00ooooo`0/ooooo`030000oooooooooooo033ooooo0_ooO`0F
ooooo`03ool00?oooooooooo02gooooo00?o003oooooooooool0LOooool1o`00007ooooo00000ol0
003oo`00ooooo`0/ooooo`030000oooooooooooo04Sooooo00?oo`00ooooooooool0;Oooool00ol0
0?ooooooooooo`1aooooo`7o00000Oooool00003o`000?ooooooo`0002cooooo00<0003ooooooooo
ool0B?ooool00ooo003oooooooooo`0]ooooo`03o`00oooooooooooo077ooooo0Ol00001ooooo`00
00?o0000oooooooo0000:oooool00`000?ooooooooooo`18ooooo`03ool00?oooooooooo02oooooo
00?o003oooooooooool0L?ooool1o`00007ooooo00001?l0003ooooooooooooo000Zooooo`030000
oooooooooooo00?ooooo0_ooO`13ooooo`03ool00?oooooooooo02oooooo00?o003oooooooooool0
L?ooool1o`00007ooooo00001?l0003ooooooooooooo000Zooooo`030000oooooooooooo00;ooooo
1?ooO`12ooooo`03ool00?oooooooooo02oooooo00?o003oooooooooool0L?ooool1o`00007ooooo
00001Ol0003oooooooooooooooooo`0002Wooooo00<0003oooooooooool00_ooool4oomo047ooooo
00?oo`00ooooooooool0<?ooool00ol00?ooooooooooo`1`ooooo`7o00000Oooool00005o`000?oo
oooooooooooooooo0000:?ooool00`000?ooooooooooo`04ooooo`;oogl0@_ooool00ooo003ooooo
ooooo`0aooooo`03o`00oooooooooooo06oooooo0Ol00001ooooo`0000?o0000ooooooooool00_oo
ool00ooo003oooooooooo`0Uooooo`030000oooooooooooo04Oooooo00?oo`00ooooooooool0<_oo
ool00ol00?ooooooooooo`1_ooooo`7o00000Oooool00003o`000?oooooooooo00;ooooo00?oo`00
ooooooooool09Oooool00`000?ooooooooooo`17ooooo`03ool00?oooooooooo03;ooooo00?o003o
ooooooooool0Koooool1o`00007ooooo00000ol0003oooooooooo`03ooooo`03ool00?oooooooooo
02Cooooo00<0003oooooooooool0A_ooool00ooo003oooooooooo`0cooooo`03o`00oooooooooooo
06oooooo0Ol00001ooooo`0000?o0000ooooooooool01?ooool00ooo003oooooooooo`0Sooooo`03
0000oooooooooooo04Gooooo00?oo`00ooooooooool0=?ooool00ol00?ooooooooooo`1_ooooo`7o
00000Oooool00003o`000?oooooooooo00Gooooo00?oo`00ooooooooool08Oooool00`000?oooooo
ooooo`15ooooo`03ool00?oooooooooo03Kooooo00?o003oooooooooool0K_ooool1o`00007ooooo
00000ol0003oooooooooo`06ooooo`03ool00?oooooooooo023ooooo00<0003oooooooooool0AOoo
ool00ooo003oooooooooo`09ooooo`;oogl0:oooool00ol00?ooooooooooo`1^ooooo`7o00000Ooo
ool00003o`000?oooooooooo00Kooooo00?oo`00ooooooooool08?ooool00`000?ooooooooooo`14
ooooo`03ool00?oooooooooo00Wooooo1?ooO`0Zooooo`03o`00oooooooooooo06kooooo0Ol00001
ooooo`0000?o0000ooooooooool01oooool00ooo003oooooooooo`0Oooooo`030000oooooooooooo
02Sooooo0_ooO`0Iooooo`03ool00?oooooooooo00[ooooo1?ooO`0Zooooo`03o`00oooooooooooo
06kooooo0Ol00001ooooo`0000?o0000ooooooooool01oooool00ooo003oooooooooo`0Oooooo`03
0000oooooooooooo02Oooooo1?ooO`0Gooooo`03ool00?oooooooooo00cooooo0_ooO`0[ooooo`03
o`00oooooooooooo06kooooo0Ol00001ooooo`0000?o0000ooooooooool02?ooool00ooo003ooooo
ooooo`0Nooooo`030000oooooooooooo02Oooooo1?ooO`0Gooooo`03ool00?oooooooooo03Wooooo
00?o003oooooooooool0K_ooool1o`00007ooooo00000ol0003oooooooooo`09ooooo`03ool00?oo
oooooooo01gooooo00<0003oooooooooool0:?ooool2oomo01;ooooo1?l00?l00oooooooo`00oooo
o`0kooooo`03o`00oooooooooooo06kooooo0Ol00001ooooo`0000?o0000ooooooooool02_ooool0
0ooo003oooooooooo`0Looooo`030000oooooooooooo03_ooooo1_l00?lmooooo`03o`00oooooooo
oooo06kooooo0Ol00001ooooo`0000?o0000ooooooooool02oooool00ooo003oooooooooo`0Koooo
o`030000oooooooooooo03Oooooo0_ooO`000ooooooo003oo`00o`06o`00occooooo00?o003ooooo
ooooool0K_ooool1o`00007ooooo00000ol0003oooooooooo`0<ooooo`03ool00?oooooooooo01[o
oooo00<0003oooooooooool0=_ooool4oomo00So003o??ooool00ol00?ooooooooooo`1^ooooo`7o
00000Oooool00003o`000?oooooooooo00gooooo00?oo`00ooooooooool06Oooool00`000?oooooo
ooooo`0fooooo`Coogl02?l00?llooooo`03o`00oooooooooooo06kooooo0Ol00001ooooo`0000?o
0000ooooooooool03Oooool2ool001[ooooo00<0003oooooooooool0=oooool2oomo0003ooooool0
0?oo003o00Ko003o??ooool00ol00?ooooooooooo`1^ooooo`7o00000Oooool00003o`000?oooooo
oooo00oooooo00?oo`00ooooooooool05oooool00`000?ooooooooooo`0jooooo`03ool00?l00?oo
003o00Co003o?Oooool00ol00?ooooooooooo`1^ooooo`7o00000Oooool00003o`000?oooooooooo
013ooooo00?oo`00ooooooooool05_ooool00`000?ooooooooooo`0iooooo`03ool00?oooooooooo
00Co003o?_ooool00ol00?ooooooooooo`1^ooooo`7o00000Oooool00003o`000?oooooooooo017o
oooo00?oo`00ooooooooool05Oooool00`000?ooooooooooo`0hooooo`03ool00?oooooooooo04?o
oooo00?o003oooooooooool0K_ooool1o`00007ooooo00000ol0003oooooooooo`0Booooo`03ool0
0?oooooooooo01Cooooo00<0003oooooooooool0=_ooool2ool004Kooooo00?o003oooooooooool0
K_ooool1o`00007ooooo00000ol0003oooooooooo`0Cooooo`03ool00?oooooooooo01?ooooo00<0
003oooooooooool0=Oooool00ooo003oooooooooo`16ooooo`03o`00oooooooooooo06kooooo0Ol0
0001ooooo`0000?o0000ooooooooool05?ooool2ool001?ooooo00<0003oooooooooool0=?ooool0
0ooo003oooooooooo`17ooooo`03o`00oooooooooooo06kooooo0Ol00001ooooo`0000?o0000oooo
ooooool05_ooool2ool0017ooooo00<0003oooooooooool0<_ooool2ool004[ooooo00?o003ooooo
ooooool0K_ooool1o`00007ooooo00000ol0003oooooooooo`0Hooooo`03ool00?oooooooooo00ko
oooo00<0003oooooooooool0<Oooool00ooo003oooooooooo`1:ooooo`03o`00oooooooooooo06ko
oooo0Ol00001ooooo`0000?o0000ooooooooool06Oooool2ool000kooooo00<0003oooooooooool0
;oooool2ool004gooooo00?o003oooooooooool0K_ooool1o`00007ooooo00000ol0003ooooooooo
o`0Kooooo`03ool00?oooooooooo00_ooooo00<0003oooooooooool0;_ooool00ooo003ooooooooo
o`1<ooooo`03o`00oooooooooooo06oooooo0Ol00001ooooo`0000?o0000ooooooooool07?ooool2
ool000_ooooo00<0003oooooooooool0;Oooool00ooo003oooooooooo`1=ooooo`03o`00oooooooo
oooo06oooooo0Ol00001ooooo`0000?o0000ooooooooool07_ooool3ool000Wooooo00<0003ooooo
ooooool0:_ooool2ool0053ooooo00?o003oooooooooool0Koooool1o`00007ooooo00000ol0003o
ooooooooo`0Qooooo`;oo`001oooool00`000?ooooooooooo`0Wooooo`?oo`00D_ooool00ol00?oo
ooooooooo`1_ooooo`7o00000Oooool00003o`000?oooooooooo02?ooooo0_oo0005ooooo`030000
oooooooooooo02Gooooo0_oo001Dooooo`03o`00oooooooooooo073ooooo0Ol00001ooooo`0000?o
0000ooooooooool09Oooool4ool00003ooooo`000?oooooo02;ooooo1?oo001Fooooo`03o`00oooo
oooooooo073ooooo0Ol00001ooooo`0000?o0000ooooooooool0:Oooool2ool00003o`00oooo003o
o`0001gooooo0ooo001Jooooo`03o`00oooooooooooo073ooooo0Ol00001ooooo`0000?o0000oooo
ooooool0:oooool00`000?ooooooooooo`03ool001Cooooo1_oo001Mooooo`03o`00oooooooooooo
073ooooo0Ol00001ooooo`0000?o0000ooooooooool0;?ooool00`000?ooooooooooo`02oooooaCo
o`00H_ooool00ol00?ooooooooooo`1aooooo`7o00000Oooool00003o`000?oooooooooo02cooooo
00<0003oooooooooool0N?ooool00ol00?ooooooooooo`1aooooo`7o00000Oooool00003o`000?oo
oooooooo02cooooo00<0003oooooooooool0N?ooool00ol00?ooooooooooo`1aooooo`7o00000Ooo
ool00003o`000?oooooooooo02gooooo00<0003oooooooooool0M_ooool00ol00?ooooooooooo`1b
ooooo`7o00000Oooool00003o`000?oooooooooo02gooooo00<0003oooooooooool0M_ooool00ol0
0?ooooooooooo`1booooo`7o00000Oooool00003o`000?oooooooooo02gooooo00<0003ooooooooo
ool0M_ooool00ol00?ooooooooooo`1booooo`7o00000Oooool00003o`000?oooooooooo02kooooo
00<0003oooooooooool0M?ooool00ol00?ooooooooooo`1cooooo`7o00000Oooool00003o`000?oo
oooooooo02kooooo00<0003oooooooooool0M?ooool00ol00?ooooooooooo`1cooooo`7o00000Ooo
ool00003o`000?oooooooooo02kooooo00<0003oooooooooool0M?ooool00ol00?ooooooooooo`1c
ooooo`7o00000Oooool00003o`000?oooooooooo02oooooo00<0003oooooooooool0L_ooool00ol0
0?ooooooooooo`1dooooo`7o00000Oooool00003o`000?oooooooooo02oooooo00<0003ooooooooo
ool0L_ooool00ol00?ooooooooooo`1dooooo`7o00000Oooool00003o`000?oooooooooo02oooooo
00<0003oooooooooool0L_ooool00ol00?ooooooooooo`1dooooo`7o00000Oooool00003o`000?oo
oooooooo033ooooo00<0003oooooooooool0Koooool2o`00ogOooooo0Ol00001ooooo`0000?o0000
ooooooooool0<?ooool00`000?ooooooooooo`1_ooooo`03o`00oooooooooooo07Kooooo0Ol00001
ooooo`0000?o0000ooooooooool0<Oooool00`000?ooooooooooo`1]ooooo`03o`00oooooooooooo
07Oooooo0Ol00001ooooo`0000?o0000ooooooooool0<_ooool00`000?ooooooooooo`1/ooooo`03
o`00oooooooooooo07Oooooo0Ol00001ooooo`0000?o0000ooooooooool0<_ooool00`000?oooooo
ooooo`1[ooooo`03o`00oooooooooooo063ooooo0_ooO`0Fooooo`7o00000Oooool00003o`000?oo
oooooooo03?ooooo00<0003oooooooooool0JOooool00ol00?ooooooooooo`1Pooooo`Coogl05Ooo
ool1o`00007ooooo00000ol0003oooooooooo`0dooooo`030000oooooooooooo06Sooooo00?o003o
ooooooooool0H?ooool4oomo01Gooooo0Ol00001ooooo`0000?o0000ooooooooool0=Oooool00`00
0?ooooooooooo`1Vooooo`03o`00oooooooooooo06;ooooo0_ooO`0Fooooo`7o00000Oooool00003
o`000?oooooooooo03Gooooo00?o003oooooooooool0I_ooool00ol00?ooooooooooo`1jooooo`7o
00000Oooool00003o`000?oooooooooo03Kooooo00?o003oooooooooool0I?ooool00ol00?oooooo
ooooo`1kooooo`7o00000Oooool00003o`000?oooooooooo03Oooooo00?o003oooooooooool0H_oo
ool00ol00?ooooooooooo`1looooo`7o00000Oooool00003o`000?oooooooooo03Sooooo00?o003o
ooooooooool0Goooool2o`00ogoooooo0Ol00001ooooo`0000?o0000ooooooooool0>Oooool00ol0
0?ooooooooooo`1Mooooo`03o`00oooooooooooo07oooooo0Ol00001ooooo`0000?o0000oooooooo
ool0>_ooool00ol00?ooooooooooo`1Kooooo`03o`00oooooooooooo083ooooo0Ol00001ooooo`00
00?o0000ooooooooool0>oooool00ol00?ooooooooooo`1Iooooo`03o`00oooooooooooo087ooooo
0Ol00001ooooo`0000?o0000ooooooooool0??ooool00ol00?ooooooooooo`1Gooooo`03o`00oooo
oooooooo08;ooooo0Ol00001ooooo`0000?o0000ooooooooool0?Oooool00ol00?ooooooooooo`1E
ooooo`03o`00oooooooooooo08?ooooo0Ol00001ooooo`0000?o0000ooooooooool0?_ooool00ol0
0?ooooooooooo`1Cooooo`03o`00oooooooooooo08Cooooo0Ol00001ooooo`0000?o0000oooooooo
ool0?oooool00ol00?ooooooooooo`1@ooooo`;o003o8Oooool2oomo06Cooooo0Ol00001ooooo`00
00?o0000ooooooooool0@?ooool00ol00?ooooooooooo`1>ooooo`03o`00oooooooooooo023ooooo
1?ooO`1Sooooo`7o00000Oooool00003o`000?oooooooooo047ooooo0_l00?m=ooooo`03o`00oooo
oooooooo027ooooo1?ooO`1Sooooo`7o00000Oooool00003o`000?oooooooooo04?ooooo00?o003o
ooooooooool0BOooool00ol00?ooooooooooo`0Sooooo`;oogl0=Oooool2oomo02gooooo0Ol00001
ooooo`0000?o0000ooooooooool0A?ooool2o`00odSooooo00?o003oooooooooool0Doooool2oomo
00Gooooo1?ooO`0/ooooo`7o00000Oooool00003o`000?oooooooooo04Kooooo0_l00?m5ooooo`03
o`00oooooooooooo05?ooooo1?ooO`04ooooo`Coogl0;?ooool1o`00007ooooo00000ol0003ooooo
ooooo`18ooooo`03o`00oooooooooooo043ooooo0_l00?lfooooo`;oogl07_ooool4oomo00Gooooo
0_ooO`0]ooooo`7o00000Oooool00003o`000?oooooooooo04Wooooo0_l00?lnooooo`;o003o=ooo
ool4oomo01kooooo0_ooO`0eooooo`7o00000Oooool00003o`000?oooooooooo04_ooooo0ol00?lj
ooooo`03o`00oooooooooooo03Oooooo1?ooO`1Eooooo`7o00000Oooool00003o`000?oooooooooo
04kooooo0_l00?lfooooo`;o003o>oooool2oomo05Kooooo0Ol00001ooooo`0000?o0000oooooooo
ool0D?ooool3o`00oc3ooooo0ol00?lcooooo`;oogl09Oooool2oomo03Wooooo0Ol00001ooooo`00
00?o0000ooooooooool0Doooool2o`00ob[ooooo1?l00?leooooo`Coogl08oooool4oomo03Sooooo
0Ol00001ooooo`0000?o0000ooooooooool0EOooool3o`00ob?ooooo1?l00?leooooo`;oogl00_oo
ool4oomo02?ooooo1?ooO`03ooooo`;oogl0<oooool1o`00007ooooo00000ol0003oooooooooo`1H
ooooo`?o003o7Oooool3o`00ocSooooo1?ooO`02ooooo`;oogl04oooool2oomo013ooooo0_ooO`03
ooooo`Coogl0<_ooool1o`00007ooooo00000ol0003oooooooooo`1Kooooo`?o003o5?ooool6o`00
oc_ooooo1?ooO`06ooooo`;oogl03_ooool4oomo01Cooooo1?ooO`0booooo`7o00000Oooool00003
o`000?oooooooooo05kooooo5?l00?m2ooooo`;oogl01_ooool4oomo00gooooo1?ooO`0Eooooo`;o
ogl0<oooool1o`00007ooooo00000ol0003oooooooooo`2;ooooo`;oogl09oooool2oomo00Kooooo
1?ooO`0>ooooo`;oogl0Boooool1o`00007ooooo00000ol0003oooooooooo`2:ooooo`Coogl09Ooo
ool4oomo00Kooooo0_ooO`1Looooo`7o00000Oooool00003o`000?oooooooooo08[ooooo1?ooO`0U
ooooo`Coogl0I?ooool1o`00007ooooo00000ol0003oooooooooo`2;ooooo`;oogl09oooool2oomo
06Gooooo0Ol00001ooooo`0000?o0000ooooooooool0U_ooool2oomo03[ooooo0_ooO`17ooooo`7o
00000Oooool00003o`000?oooooooooo09Gooooo1?ooO`0>ooooo`;oogl0:?ooool4oomo04Kooooo
0Ol00001ooooo`0000?o0000ooooooooool0UOooool4oomo00gooooo1?ooO`0Wooooo`Coogl0A_oo
ool1o`00007ooooo00000ol0003oooooooooo`2Fooooo`;oogl03_ooool4oomo02Sooooo0_ooO`17
ooooo`7o00000Oooool00003o`000?oooooooooo0:Oooooo0_ooO`0[ooooo`Goo`3o@_ooool1o`00
007ooooo00000ol0003oooooooooo`3Cooooo`Ooo`3o4Oooool2oomo02kooooo0Ol00001ooooo`00
00?o0000ooooooooool0d_ooool9ool0o`oooooo1?ooO`0]ooooo`7o00000Oooool00003o`000?oo
oooooooo0=7ooooo2ooo0?l>ooooo`Coogl0;Oooool1o`00007ooooo00000ol0003oooooooooo`3A
ooooo`_oo`3o3oooool2oomo02kooooo0Ol00001ooooo`0000?o0000ooooooooool0]oooool2oomo
01Sooooo2ooo0?loooooo`7o00000Oooool00003o`000?oooooooooo0;Kooooo1?ooO`0Gooooo`_o
o`3o?oooool1o`00007ooooo00000ol0003oooooooooo`2cooooo`;oogl000?ooooooomo0?ooO`00
0_ooO`0Gooooo`_oo`3o?oooool1o`00007ooooo00000ol0003oooooooooo`2Xooooo`;oogl02?oo
ool4oomo0003ooooooooO`3oogl001Wooooo2Ooo0?m0ooooo`7o00000Oooool00003o`000?oooooo
oooo0:Kooooo1OooO`07ooooo`Coogl05oooool2oomo00?ooooo00?oogl0ool0oooo0?l01Ooo0?m1
ooooo`7o00000Oooool00003o`000?oooooooooo0:Gooooo1_ooO`08ooooo`;oogl05oooool4oomo
00;ooooo0_ooO`05ool0od;ooooo0Ol00001ooooo`0000?o0000ooooooooool0YOooool5oomo02;o
oooo1?ooO`03ooooo`;oogl0A_ooool1o`00007ooooo00000ol0003oooooooooo`1fooooo`;oogl0
;_ooool2oomo02Gooooo0_ooO`1<ooooo`7o00000Oooool00003o`000?oooooooooo07Gooooo1?oo
O`2Rooooo`7o00000Oooool00003o`000?oooooooooo07Gooooo1?ooO`0:ooooo`;oogl0U_ooool1
o`00007ooooo00000ol0003oooooooooo`1fooooo`;oogl02_ooool4oomo02[ooooo0_ooO`1Yoooo
o`7o00000Oooool00003o`000?oooooooooo08;ooooo1?ooO`0Yooooo`Coogl0J?ooool1o`00007o
oooo00000ol0003oooooooooo`23ooooo`;oogl09?ooool2oomo00Cooooo1?ooO`1Xooooo`7o0000
0Oooool00003o`000?oooooooooo0:Sooooo1?ooO`04ooooo`;oogl0JOooool1o`00007ooooo0000
0ol0003oooooooooo`2Xooooo`Coogl0Koooool1o`00007ooooo00000ol0003oooooooooo`2Yoooo
o`;oogl0L?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`00
00?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?oo
ool1o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000oooo
ooooool0Q?ooool2oomo09Gooooo0Ol00001ooooo`0000?o0000ooooooooool0Poooool4oomo09Co
oooo0Ol00001ooooo`0000?o0000ooooooooool0Poooool4oomo09Cooooo0Ol00001ooooo`0000?o
0000ooooooooool0Q?ooool2oomo02cooooo0_ooO`1Wooooo`7o00000Oooool00003o`000?oooooo
oooo0;7ooooo1?ooO`1Vooooo`7o00000Oooool00003o`000?oooooooooo0;7ooooo1?ooO`1Voooo
o`7o00000Oooool00003o`000?oooooooooo0;;ooooo0_ooO`1Wooooo`7o00000Oooool00003o`00
0?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol0
0001ooooo`0000?o0000ooooooooool0Noooool2oomo09kooooo0Ol00001ooooo`0000?o0000oooo
ooooool0N_ooool4oomo09gooooo0Ol00001ooooo`0000?o0000ooooooooool0N_ooool4oomo023o
oooo0_ooO`1kooooo`7o00000Oooool00003o`000?oooooooooo07_ooooo0_ooO`0Pooooo`Coogl0
N_ooool1o`00007ooooo00000ol0003oooooooooo`2Mooooo`Coogl0N_ooool1o`00007ooooo0000
0ol0003oooooooooo`2@ooooo`;oogl03?ooool2oomo07_ooooo0Ol00001ooooo`0000?o0000oooo
ooooool0Soooool4oomo08Sooooo0Ol00001ooooo`0000?o0000ooooooooool0Soooool4oomo08So
oooo0Ol00001ooooo`0000?o0000ooooooooool0T?ooool2oomo02?ooooo0_ooO`1Tooooo`7o0000
0Oooool00003o`000?oooooooooo0;Cooooo1?ooO`1Sooooo`7o00000Oooool00003o`000?oooooo
oooo0;Cooooo1?ooO`1Sooooo`7o00000Oooool00003o`000?oooooooooo0;Gooooo0_ooO`1Toooo
o`7o00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003ooooo
ooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Ooo
ool00003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooo
oacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`00
0?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol0
0001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo
0?oooooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`00
00?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?oo
ool1o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000oooo
ooooool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007o
oooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooo
oolLooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0
003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o
00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003ooooooooo
o`3ooooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool0
0003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooooaco
oooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oo
oooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001
ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo0?oo
oooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o
0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1
o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000oooooooo
ool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo
00000ol0003oooooooooo`2>ooooo`;oogl0Roooool1o`00007ooooo00000ol0003oooooooooo`2=
ooooo`Coogl0R_ooool1o`00007ooooo00000ol0003oooooooooo`2=ooooo`Coogl0R_ooool1o`00
007ooooo00000ol0003oooooooooo`2>ooooo`;oogl0Roooool1o`00007ooooo00000ol0003ooooo
ooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Ooo
ool00003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooo
oacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`00
0?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol0
0001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo
0?oooooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`00
00?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?oo
ool1o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000oooo
ooooool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007o
oooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooo
oolLooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0
003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o
00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo003oo`00023o00000Ooo
ool00001\
\>"],
  ImageRangeCache->{{{0, 287}, {287, 0}} -> {-1.01089, -1.01089, 0.00704453, \
0.00704453}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.49505 0.5 0.49505 [
[ 0 0 -0.125 0 ]
[ 0 0 -0.125 0 ]
[ 0 1 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
0 0 m
1 0 L
s
0 0 m
0 1 L
s
0 1 m
1 1 L
s
1 0 m
1 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
1 .5 0 r
.015 w
.03175 .1355 Mdot
.03435 .12523 Mdot
.11137 .12765 Mdot
.14107 .18841 Mdot
.16218 .24538 Mdot
.17294 .21053 Mdot
.18267 .18577 Mdot
.18434 .1304 Mdot
.18553 .30956 Mdot
.20401 .239 Mdot
.21247 .27571 Mdot
.21687 .20845 Mdot
.22376 .2799 Mdot
.22832 .27485 Mdot
.29063 .20974 Mdot
.29686 .25079 Mdot
.30487 .22936 Mdot
.30683 .34623 Mdot
.32055 .20902 Mdot
.32574 .21979 Mdot
.34472 .28521 Mdot
.35998 .36393 Mdot
.36335 .24976 Mdot
.3794 .36608 Mdot
.42386 .66992 Mdot
.44391 .74519 Mdot
.45059 .34198 Mdot
.47208 .67586 Mdot
.47436 .71381 Mdot
.49778 .59825 Mdot
.50874 .91643 Mdot
.51516 .76219 Mdot
.53655 .61374 Mdot
.56563 .75219 Mdot
.59189 .65665 Mdot
.59581 .61604 Mdot
.59923 .6556 Mdot
.60292 .68499 Mdot
.62656 .67779 Mdot
.63555 .72451 Mdot
.63919 .652 Mdot
.64169 .6004 Mdot
.64246 .58611 Mdot
.64496 .54267 Mdot
.64608 .77288 Mdot
.65077 .64308 Mdot
.66065 .57816 Mdot
.67474 .59169 Mdot
.69296 .563 Mdot
.72815 .65902 Mdot
.73169 .58879 Mdot
.74669 .61318 Mdot
.74821 .65474 Mdot
.75963 .63781 Mdot
.79673 .57809 Mdot
.80925 .55852 Mdot
.81525 .58444 Mdot
.83417 .62985 Mdot
.83598 .55526 Mdot
.91595 .49319 Mdot
1 0 0 r
.005 w
.00495 .28842 m
.00628 .29156 L
.01857 .31761 L
.03101 .33781 L
.03525 .34367 L
.05706 .36884 L
.05795 .36972 L
.08312 .39115 L
.08963 .39578 L
.10917 .40763 L
.13523 .41964 L
.14074 .42183 L
.16128 .42794 L
.18734 .43294 L
.21339 .43485 L
.23945 .43375 L
.2655 .42959 L
.29156 .42219 L
.29261 .42183 L
.31761 .41124 L
.34367 .39603 L
.34405 .39578 L
.36972 .37551 L
.37582 .36972 L
.39578 .34724 L
.39849 .34367 L
.41525 .31761 L
.42183 .30485 L
.4275 .29156 L
.436 .2655 L
.44117 .23945 L
.44325 .21339 L
.44232 .18734 L
.43834 .16128 L
.43114 .13523 L
.42183 .11212 L
.42037 .10917 L
.40546 .08312 L
.39578 .06961 L
.38528 .05706 L
.36972 .04137 L
.35758 .03101 L
.34367 .02092 L
.31761 .00569 L
.3162 .00495 L
s
.00495 .12854 m
.01344 .10917 L
.02832 .08312 L
.03101 .07912 L
.04848 .05706 L
.05706 .04802 L
.07619 .03101 L
.08312 .02579 L
.10917 .00934 L
.11742 .00495 L
s
0 0 1 r
.29156 .15739 m
.31761 .14824 L
.34367 .14249 L
.36972 .13986 L
.39578 .14025 L
.42183 .14366 L
.44789 .15025 L
.47394 .16034 L
.47599 .16128 L
.5 .17443 L
.51844 .18734 L
.52606 .19355 L
.54662 .21339 L
.55211 .21962 L
.56712 .23945 L
.57817 .25755 L
.58227 .2655 L
.59322 .29156 L
.60058 .31761 L
.60422 .3392 L
.60471 .34367 L
.6058 .36972 L
.60422 .39297 L
.60387 .39578 L
.59886 .42183 L
.59054 .44789 L
.57848 .47394 L
.57817 .47453 L
.562 .5 L
.55211 .51255 L
.53968 .52606 L
.52606 .53862 L
.50853 .55211 L
.5 .55773 L
.47394 .57183 L
.45901 .57817 L
.44789 .5819 L
.42183 .5885 L
.39578 .59192 L
.36972 .59231 L
.34367 .58968 L
.31761 .58392 L
.29972 .57817 L
.29156 .57477 L
.2655 .56178 L
.25025 .55211 L
.23945 .54409 L
.21914 .52606 L
.21339 .52008 L
.19681 .5 L
Mistroke
.18734 .48608 L
.18031 .47394 L
.16827 .44789 L
.16128 .42714 L
.15996 .42183 L
.15493 .39578 L
.153 .36972 L
.15409 .34367 L
.15823 .31761 L
.16128 .3045 L
.16559 .29156 L
.17653 .2655 L
.18734 .24609 L
.19169 .23945 L
.21221 .21339 L
.21339 .21211 L
.23945 .1881 L
.24041 .18734 L
.2655 .17038 L
.28271 .16128 L
.29156 .15739 L
Mfstroke
1 0 0 r
.03 w
.21687 .20845 Mdot
0 0 1 r
.3794 .36608 Mdot
1 0 0 r
.79703 .00495 m
.79703 .02417 L
.87129 .02417 L
.87129 .00495 L
F
0 0 1 r
.89604 .00495 m
.89604 .23326 L
.9703 .23326 L
.9703 .00495 L
F
1 0 1 r
.04 w
.79673 .57809 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P000182000`400?l00000o`00003ooooooolQ
ooooo`00ool0000Po`00007ooooo00000ol0003oooooooooo`0Mooooo`;oo`00>?ooool3ool00<7o
oooo0Ol00001ooooo`0000?o0000ooooooooool06oooool2ool003gooooo00?oo`00ooooooooool0
Q?oooolEool000Sooooo5Ol00?l8ooooo`7o00000Oooool00003o`000?oooooooooo01[ooooo00?o
o`00ooooooooool0?_ooool2ool008Cooooo5Ooo0008oooooaGo003o2?ooool1o`00007ooooo0000
0ol0003oooooooooo`0Hooooo`;oo`00@oooool00ooo003oooooooooo`21oooooaGoo`002?oooolE
o`00o`Sooooo0Ol00001ooooo`0000?o0000ooooooooool05_ooool2ool004Kooooo00?oo`00oooo
ooooool0P?oooolEool000Sooooo5Ol00?l8ooooo`7o00000Oooool00003o`000?oooooooooo01Go
oooo00?oo`00ooooooooool0Aoooool2ool0083ooooo5Ooo0008oooooaGo003o2?ooool1o`00007o
oooo00000ol0003oooooooooo`0Dooooo`03ool00?oooooooooo04[ooooo00?oo`00ooooooooool0
OOoooolEool000Sooooo5Ol00?l8ooooo`7o00000Oooool00003o`000?oooooooooo01?ooooo00?o
o`00ooooooooool0C?ooool00ooo003oooooooooo`2IoooooaGo003o2?ooool1o`00007ooooo0000
0ol0003oooooooooo`0Aooooo`;oo`00D?ooool2ool009Wooooo5Ol00?l8ooooo`7o00000Oooool0
0003o`000?oooooooooo013ooooo00?oo`00ooooooooool0D_ooool2ool009Oooooo5Ol00?l8oooo
o`7o00000Oooool00003o`000?oooooooooo00oooooo00?oo`00ooooooooool0EOooool00ooo003o
ooooooooo`2DoooooaGo003o2?ooool1o`00007ooooo00000ol0003oooooooooo`0>ooooo`03ool0
0?oooooooooo05Kooooo00?oo`00ooooooooool0U?oooolEo`00o`Sooooo0Ol00001ooooo`0000?o
0000ooooooooool03Oooool00ooo003oooooooooo`1Hooooo`03ool00?oooooooooo09?ooooo5Ol0
0?l8ooooo`7o00000Oooool00003o`000?oooooooooo00gooooo00?oo`00ooooooooool0FOooool0
0ooo003oooooooooo`2BoooooaGo003o2?ooool1o`00007ooooo00000ol0003oooooooooo`0<oooo
o`03ool00?oooooooooo05_ooooo00?oo`00ooooooooool0TOoooolEo`00o`Sooooo0Ol00001oooo
o`0000?o0000ooooooooool02oooool00ooo003oooooooooo`1Mooooo`03ool00?oooooooooo093o
oooo5Ol00?l8ooooo`7o00000Oooool00003o`000?oooooooooo00_ooooo00?oo`00ooooooooool0
GOooool00ooo003oooooooooo`2@oooooaGo003o2?ooool1o`00007ooooo00000ol0003ooooooooo
o`0:ooooo`03ool00?oooooooooo05oooooo00?oo`00ooooooooool0SooooolEo`00o`Sooooo0Ol0
0001ooooo`0000?o0000ooooooooool02Oooool00ooo003oooooooooo`1Qooooo`03ool00?oooooo
oooo08kooooo5Ol00?l8ooooo`7o00000Oooool00003o`000?oooooooooo00Sooooo00?oo`00oooo
ooooool0Hoooool00ooo003oooooooooo`2=oooooaGo003o2?ooool1o`00007ooooo00000ol0003o
ooooooooo`07ooooo`03ool00?oooooooooo06Gooooo00?oo`00ooooooooool0S?oooolEo`00o`So
oooo0Ol00001ooooo`0000?o0000ooooooooool01_ooool00ooo003oooooooooo`1Wooooo`03ool0
0?oooooooooo08_ooooo5Ol00?l8ooooo`7o00000Oooool00003o`000?oooooooooo00Gooooo00?o
o`00ooooooooool0JOooool00ooo003oooooooooo`2:oooooaGo003o2?ooool1o`00007ooooo0000
0ol0003oooooooooo`05ooooo`03ool00?oooooooooo06Wooooo00?oo`00ooooooooool0R_oooolE
o`00o`Sooooo0Ol00001ooooo`0000?o0000ooooooooool01?ooool00ooo003oooooooooo`1[oooo
o`03ool00?oooooooooo08Wooooo5Ol00?l8ooooo`7o00000Oooool00003o`000?oooooooooo00?o
oooo00?oo`00ooooooooool0K?ooool00ooo003oooooooooo`29oooooaGo003o2?ooool1o`00007o
oooo00000ol0003oooooooooo`03ooooo`03ool00?oooooooooo06gooooo00?oo`00ooooooooool0
R?oooolEo`00o`Sooooo0Ol00001ooooo`0000?o0000ooooooooool00_ooool00ooo003ooooooooo
o`1^ooooo`03ool00?oooooooooo08Sooooo5Ol00?l8ooooo`7o00000Oooool00003o`000?oooooo
oooo00;ooooo00?oo`00ooooooooool0Koooool00ooo003oooooooooo`27oooooaGo003o2?ooool1
o`00007ooooo00001Ol0003oooooooooooooooooo`0007;ooooo00?oo`00ooooooooool0QooooolE
o`00o`Sooooo0Ol00001ooooo`0000Co0000ooooooooooooo`00M?ooool00ooo003oooooooooo`26
oooooaGo003o2?ooool1o`00007ooooo00001?l0003ooooooooooooo001eooooo`03ool00?oooooo
oooo08Gooooo5Ol00?l8ooooo`7o00000Oooool00003o`000?ooooooo`0007Kooooo00?oo`00oooo
ooooool0QOoooolEo`00o`Sooooo0Ol00001ooooo`0000?o0000oooooooo00001_ooool2oomo06oo
oooo00?oo`00ooooooooool0Q?oooolEo`00o`Sooooo0Ol00001ooooo`0000?o0000oooooooo0000
1Oooool4oomo01?ooooo0_ooO`1Iooooo`03ool00?oooooooooo08Cooooo5Ol00?l8ooooo`7o0000
0Oooool00003o`000?oo003ooooo00Gooooo1?ooO`0Booooo`Coogl04_ooool2oomo04Cooooo00?o
o`00ooooooooool0Q?oooolEo`00o`Sooooo0Ol00001ooooo`0000?o0000ooooooooool01Oooool3
oomo01?ooooo1?ooO`0Aooooo`Coogl0A?ooool00ooo003oooooooooo`23oooooaGo003o2?ooool1
o`00007ooooo00000ol0003oooooooooo`04ooooo`Coogl05?ooool2oomo01;ooooo1?ooO`14oooo
o`03ool00?oooooooooo08?ooooo5Ol00?l8ooooo`7o00000Oooool00003o`000?oooooooooo00Co
oooo1?ooO`0Yooooo`;oogl0AOooool00ooo003oooooooooo`23oooooaGo003o2?ooool1o`00007o
oooo00000ol0003oooooooooo`05ooooo`;oogl0E_oooolFo`00o`Gooooo00?oo`00ooooooooool0
PooooolEo`00o`Sooooo0Ol00001ooooo`0000?o0000ooooooooool0F_ooool3o`00oaKooooo1_l0
0?l00ooo003oooooooooo`22oooooaGo003o2?ooool1o`00007ooooo00000ol0003oooooooooo`1G
ooooo`?o003o7oooool3o`00oh;ooooo5Ol00?l8ooooo`7o00000Oooool00003o`000?oooooooooo
05Cooooo0ol00?lRooooo`03ool00?oooooooooo00?o003oOooooolEo`00o`Sooooo0Ol00001oooo
o`0000?o0000ooooooooool0DOooool3o`00obGooooo00?oo`00ooooooooool00oooool3o`00ogco
oooo5Ol00?l8ooooo`7o00000Oooool00003o`000?oooooooooo04oooooo0P000?lYooooo`03ool0
0?oooooooooo00Gooooo0ol00?mioooooaGo003o2?ooool1o`00007ooooo00000ol0003ooooooooo
o`1=ooooo`80003o:oooool00ooo003oooooooooo`08ooooo`;o003oMooooolEo`00o`Sooooo0Ol0
0001ooooo`0000?o0000ooooooooool0B_ooool30000obgooooo00?oo`00ooooooooool02_ooool2
o`00ogGooooo5Ol00?l8ooooo`7o00000Oooool00003o`000?oooooooooo04Sooooo0P000?l`oooo
o`03ool00?oooooooooo00cooooo00?o003oooooooooool0L_oooolEo`00o`Sooooo0Ol00001oooo
o`0000?o0000ooooooooool0Aoooool00`000?ooooooooooo`0`ooooo`03ool00?oooooooooo00go
oooo0_l00?mboooooaGo003o2?ooool1o`00007ooooo00000ol0003oooooooooo`15ooooo`80003o
=?ooool00ooo003oooooooooo`0>ooooo`;o003oL?oooolEo`00o`Sooooo0Ol00001ooooo`0000?o
0000ooooooooool0A?ooool00`000?ooooooooooo`0dooooo`03ool00?oooooooooo013ooooo0_l0
0?m^oooooaGo003o2?ooool1o`00007ooooo00000ol0003oooooooooo`0Tooooo`;oogl02_ooool2
oomo017ooooo00<0003oooooooooool0=Oooool00ooo003oooooooooo`0Booooo`03o`00oooooooo
oooo06_ooooo5Ol00?l8ooooo`7o00000Oooool00003o`000?oooooooooo02?ooooo1?ooO`08oooo
o`Coogl03oooool00`000?ooooooooooo`0fooooo`03ool00?oooooooooo01?ooooo00?o003ooooo
ooooool0J_oooolEo`00o`Sooooo0Ol00001ooooo`0000?o0000ooooooooool08oooool4oomo00So
oooo1?ooO`0=ooooo`030000ool00?oooooo03Sooooo00?oo`00ooooooooool05?ooool00ol00?oo
ooooooooo`1YoooooaGo003o2?ooool1o`00007ooooo00000ol0003oooooooooo`0Tooooo`;oogl0
2_ooool2oomo00gooooo00<0003oooooooooool0>Oooool00ooo003oooooooooo`0Eooooo`03o`00
oooooooooooo06Sooooo5Ol00?l8ooooo`7o00000Oooool00003o`000?oooooooooo03Wooooo1?oo
00000oooool0003oooooo`0kooooo`03ool00?oooooooooo01Kooooo00?o003oooooooooool0Iooo
oolEo`00o`Sooooo0Ol00001ooooo`0000?o0000ooooooooool0>?ooool6ool003gooooo00?oo`00
ooooooooool05oooool00ol00?ooooooooooo`1VoooooaGo003o2?ooool1o`00007ooooo00000ol0
003oooooooooo`0gooooo`Soo`004?ooool2oomo00Oooooo0_ooO`0Rooooo`03ool00?oooooooooo
01Oooooo00?o003oooooooooool0IOoooolEo`00o`Sooooo0Ol00001ooooo`0000?o0000oooooooo
ool0;_ooool2oomo00Oooooo2?oo000?ooooo`Coogl01Oooool4oomo027ooooo00?oo`00oooooooo
ool06?ooool00ol00?ooooooooooo`1ToooooaGo003o2?ooool1o`00007ooooo00000ol0003ooooo
ooooo`0]ooooo`Coogl01_ooool8ool000oooooo1?ooO`05ooooo`Coogl08Oooool00ooo003ooooo
ooooo`0Iooooo`03o`00oooooooooooo06?ooooo5Ol00?l8ooooo`7o00000Oooool00003o`000?oo
oooooooo02gooooo1?ooO`06ooooo`Soo`004?ooool2oomo00Oooooo0oooO`0Qooooo`03ool00?oo
oooooooo01[ooooo00?o003oooooooooool0H_oooolEo`00o`Sooooo0Ol00001ooooo`0000?o0000
ooooooooool0;_ooool2oomo00Sooooo1_oo000Jooooo`Coogl08?ooool00ooo003oooooooooo`0K
ooooo`03o`00oooooooooooo067ooooo5Ol00?l8ooooo`7o00000Oooool00003o`000?oooooooooo
03Sooooo00<0003oool00?oo00000_oo000Kooooo`Coogl08?ooool00ooo003oooooooooo`0Loooo
o`03o`00oooooooooooo063ooooo5Ol00?l8ooooo`7o00000Oooool00003o`000?oooooooooo03Oo
oooo00<0003oooooooooool06Oooool2oomo00Cooooo0_ooO`0Qooooo`03ool00?oooooooooo01co
oooo00?o003oooooooooool0H?oooolEo`00o`Sooooo0Ol00001ooooo`0000?o0000ooooooooool0
=_ooool00`000?ooooooooooo`0Iooooo`Coogl09Oooool00ooo003oooooooooo`0Nooooo`03o`00
oooooooooooo05oooooo5Ol00?l8ooooo`7o00000Oooool00003o`000?oooooooooo03Kooooo00<0
003oooooooooool06Oooool4oomo02Gooooo00?oo`00ooooooooool07oooool00ol00?oooooooooo
o`1NoooooaGo003o2?ooool1o`00007ooooo00000ol0003oooooooooo`0eooooo`040000oooooooo
ogl0oomo01[ooooo0_ooO`0Vooooo`03ool00?oooooooooo023ooooo00?o003oooooooooool0GOoo
oolEo`00o`Sooooo0Ol00001ooooo`0000?o0000ooooooooool0=?ooool00`000?oooooooomo0003
oomo047ooooo00?oo`00ooooooooool08Oooool00ol00?ooooooooooo`1iooooo`7o00000Oooool0
0003o`000?oooooooooo02_ooooo0_ooO`06ooooo`030000oooooooooooo00Coogl0@Oooool00ooo
003oooooooooo`0Qooooo`03o`00oooooooooooo07Wooooo0Ol00001ooooo`0000?o0000oooooooo
ool0:_ooool4oomo00Cooooo00<0003oooooooooool00_ooool2oomo01Sooooo0_ooO`0Aooooo`;o
ogl05Oooool00ooo003oooooooooo`0Rooooo`03o`00oooooooooooo07Sooooo0Ol00001ooooo`00
00?o0000ooooooooool0:_ooool4oomo00Cooooo00<0003oooooooooool06oooool4oomo00oooooo
1?ooO`0Dooooo`03ool00?oooooooooo02?ooooo00?o003oooooooooool0Moooool1o`00007ooooo
00000ol0003oooooooooo`0[ooooo`;oogl01?ooool00`000?ooooooooooo`0Looooo`Coogl03ooo
ool4oomo01Cooooo00?oo`00ooooooooool08oooool00ol00?ooooooooooo`1gooooo`7o00000Ooo
ool00003o`000?oooooooooo037ooooo00<0003oooooooooool07Oooool2oomo017ooooo0_ooO`0D
ooooo`03ool00?oooooooooo02Gooooo00?o003oooooooooool0M_ooool1o`00007ooooo00000ol0
003oooooooooo`0`ooooo`030000oooooooooooo04Oooooo00?oo`00ooooooooool09Oooool00ol0
0?ooooooooooo`1fooooo`7o00000Oooool00003o`000?oooooooooo033ooooo00<0003ooooooooo
ool0Aoooool00ooo003oooooooooo`0Vooooo`03o`00oooooooooooo07Gooooo0Ol00001ooooo`00
00?o0000ooooooooool0;oooool00`000?ooooooooooo`18ooooo`03ool00?oooooooooo02Oooooo
00?o003oooooooooool0M?ooool1o`00007ooooo00000ol0003oooooooooo`0_ooooo`030000oooo
oooooooo00Oooooo0_ooO`02ooooo`;oogl0>oooool00ooo003oooooooooo`0Wooooo`03o`00oooo
oooooooo07Cooooo0Ol00001ooooo`0000?o0000ooooooooool0;_ooool00`000?ooooooooooo`07
ooooo`Soogl0>Oooool00ooo003oooooooooo`0Yooooo`03o`00oooooooooooo07?ooooo0Ol00001
ooooo`0000?o0000ooooooooool0;_ooool00`000?ooooooooooo`07ooooo`Soogl0>Oooool00ooo
003oooooooooo`0Yooooo`03o`00oooooooooooo07?ooooo0Ol00001ooooo`0000?o0000oooooooo
ool0;Oooool00`000?ooooooooooo`09ooooo`Koogl08?ooool2oomo01Oooooo00?oo`00oooooooo
ool0:oooool00ol00?ooooooooooo`1booooo`7o00000Oooool00003o`000?oooooooooo02gooooo
00<0003oooooooooool02oooool4oomo01oooooo1?ooO`0Fooooo`03ool00?oooooooooo02_ooooo
00?o003oooooooooool0L_ooool1o`00007ooooo00000ol0003oo`00ooooo`0]ooooo`030000oooo
oooooooo00cooooo0_ooO`0Pooooo`Coogl05_ooool00ooo003oooooooooo`0[ooooo`03o`00oooo
oooooooo07;ooooo0Ol00001ooooo`0000?o0000ool00?ooool0;?ooool00`000?ooooooooooo`0`
ooooo`;oogl05_ooool00ooo003oooooooooo`0]ooooo`03o`00oooooooooooo077ooooo0Ol00001
ooooo`0000?o0000ool00?ooool0;?ooool00`000?ooooooooooo`18ooooo`03ool00?oooooooooo
02gooooo00?o003oooooooooool0LOooool1o`00007ooooo00000ol0003oooooool0000/ooooo`03
0000oooooooooooo04Sooooo00?oo`00ooooooooool0;Oooool00ol00?ooooooooooo`1aooooo`7o
00000Oooool00003o`000?ooooooo`0002_ooooo00<0003oooooooooool0B?ooool00ooo003ooooo
ooooo`0_ooooo`03o`00oooooooooooo073ooooo0Ol00001ooooo`0000Co0000ooooooooooooo`00
:_ooool00`000?ooooooooooo`03ooooo`;oogl0@oooool00ooo003oooooooooo`0_ooooo`03o`00
oooooooooooo073ooooo0Ol00001ooooo`0000Co0000ooooooooooooo`00:_ooool00`000?oooooo
ooooo`02ooooo`Coogl0@_ooool00ooo003oooooooooo`0_ooooo`03o`00oooooooooooo073ooooo
0Ol00001ooooo`0000Go0000ooooooooooooooooool0000Yooooo`030000oooooooooooo00;ooooo
1?ooO`11ooooo`03ool00?oooooooooo033ooooo00?o003oooooooooool0L?ooool1o`00007ooooo
00001Ol0003oooooooooooooooooo`0002Sooooo00<0003oooooooooool01?ooool2oomo04;ooooo
00?oo`00ooooooooool0<Oooool00ol00?ooooooooooo`1_ooooo`7o00000Oooool00003o`000?oo
oooooooo00;ooooo00?oo`00ooooooooool09Oooool00`000?ooooooooooo`17ooooo`03ool00?oo
oooooooo03;ooooo00?o003oooooooooool0Koooool1o`00007ooooo00000ol0003oooooooooo`02
ooooo`03ool00?oooooooooo02Gooooo00<0003oooooooooool0Aoooool00ooo003oooooooooo`0b
ooooo`03o`00oooooooooooo06oooooo0Ol00001ooooo`0000?o0000ooooooooool00oooool00ooo
003oooooooooo`0Tooooo`030000oooooooooooo04Kooooo00?oo`00ooooooooool0<oooool00ol0
0?ooooooooooo`1_ooooo`7o00000Oooool00003o`000?oooooooooo00Cooooo00?oo`00oooooooo
ool08oooool00`000?ooooooooooo`15ooooo`03ool00?oooooooooo03Cooooo00?o003ooooooooo
ool0Koooool1o`00007ooooo00000ol0003oooooooooo`05ooooo`03ool00?oooooooooo027ooooo
00<0003oooooooooool0AOooool00ooo003oooooooooo`0fooooo`03o`00oooooooooooo06kooooo
0Ol00001ooooo`0000?o0000ooooooooool01_ooool00ooo003oooooooooo`0Pooooo`030000oooo
oooooooo04Gooooo00?oo`00ooooooooool02Oooool2oomo02_ooooo00?o003oooooooooool0K_oo
ool1o`00007ooooo00000ol0003oooooooooo`06ooooo`03ool00?oooooooooo023ooooo00<0003o
ooooooooool0A?ooool00ooo003oooooooooo`09ooooo`Coogl0:_ooool00ol00?ooooooooooo`1^
ooooo`7o00000Oooool00003o`000?oooooooooo00Oooooo00?oo`00ooooooooool07oooool00`00
0?ooooooooooo`0Xooooo`;oogl06Oooool00ooo003oooooooooo`0:ooooo`Coogl0:_ooool00ol0
0?ooooooooooo`1^ooooo`7o00000Oooool00003o`000?oooooooooo00Oooooo00?oo`00oooooooo
ool07oooool00`000?ooooooooooo`0Wooooo`Coogl05oooool00ooo003oooooooooo`0<ooooo`;o
ogl0:oooool00ol00?ooooooooooo`1^ooooo`7o00000Oooool00003o`000?oooooooooo00Sooooo
00?oo`00ooooooooool07_ooool00`000?ooooooooooo`0Wooooo`Coogl05oooool00ooo003ooooo
ooooo`0iooooo`03o`00oooooooooooo06kooooo0Ol00001ooooo`0000?o0000ooooooooool02Ooo
ool00ooo003oooooooooo`0Mooooo`030000oooooooooooo02Sooooo0_ooO`0Booooo`Co003o00?o
ooooool00?ooool0>oooool00ol00?ooooooooooo`1^ooooo`7o00000Oooool00003o`000?oooooo
oooo00[ooooo00?oo`00ooooooooool07?ooool00`000?ooooooooooo`0kooooo`Ko003o?Oooool0
0ol00?ooooooooooo`1^ooooo`7o00000Oooool00003o`000?oooooooooo00_ooooo00?oo`00oooo
ooooool06oooool00`000?ooooooooooo`0gooooo`;oogl000?oooooo`00ool00?l01_l00?lloooo
o`03o`00oooooooooooo06kooooo0Ol00001ooooo`0000?o0000ooooooooool03?ooool00ooo003o
ooooooooo`0Jooooo`030000oooooooooooo03Kooooo1?ooO`08o`00occooooo00?o003ooooooooo
ool0K_ooool1o`00007ooooo00000ol0003oooooooooo`0=ooooo`03ool00?oooooooooo01Wooooo
00<0003oooooooooool0=_ooool4oomo00So003o??ooool00ol00?ooooooooooo`1^ooooo`7o0000
0Oooool00003o`000?oooooooooo00gooooo0_oo000Jooooo`030000oooooooooooo03Oooooo0_oo
O`000ooooooo003oo`00o`06o`00occooooo00?o003oooooooooool0K_ooool1o`00007ooooo0000
0ol0003oooooooooo`0?ooooo`03ool00?oooooooooo01Oooooo00<0003oooooooooool0>_ooool0
0ooo003o003oo`00o`04o`00ocgooooo00?o003oooooooooool0K_ooool1o`00007ooooo00000ol0
003oooooooooo`0@ooooo`03ool00?oooooooooo01Kooooo00<0003oooooooooool0>Oooool00ooo
003oooooooooo`04o`00ockooooo00?o003oooooooooool0K_ooool1o`00007ooooo00000ol0003o
ooooooooo`0Aooooo`03ool00?oooooooooo01Gooooo00<0003oooooooooool0>?ooool00ooo003o
ooooooooo`13ooooo`03o`00oooooooooooo06kooooo0Ol00001ooooo`0000?o0000ooooooooool0
4_ooool00ooo003oooooooooo`0Dooooo`030000oooooooooooo03Kooooo0_oo0016ooooo`03o`00
oooooooooooo06kooooo0Ol00001ooooo`0000?o0000ooooooooool04oooool00ooo003ooooooooo
o`0Cooooo`030000oooooooooooo03Gooooo00?oo`00ooooooooool0A_ooool00ol00?oooooooooo
o`1^ooooo`7o00000Oooool00003o`000?oooooooooo01Cooooo0_oo000Cooooo`030000oooooooo
oooo03Cooooo00?oo`00ooooooooool0Aoooool00ol00?ooooooooooo`1^ooooo`7o00000Oooool0
0003o`000?oooooooooo01Kooooo0_oo000Aooooo`030000oooooooooooo03;ooooo0_oo001:oooo
o`03o`00oooooooooooo06kooooo0Ol00001ooooo`0000?o0000ooooooooool06?ooool00ooo003o
ooooooooo`0>ooooo`030000oooooooooooo037ooooo00?oo`00ooooooooool0B_ooool00ol00?oo
ooooooooo`1^ooooo`7o00000Oooool00003o`000?oooooooooo01Wooooo0_oo000>ooooo`030000
oooooooooooo02oooooo0_oo001=ooooo`03o`00oooooooooooo06kooooo0Ol00001ooooo`0000?o
0000ooooooooool06oooool00ooo003oooooooooo`0;ooooo`030000oooooooooooo02kooooo00?o
o`00ooooooooool0C?ooool00ol00?ooooooooooo`1_ooooo`7o00000Oooool00003o`000?oooooo
oooo01cooooo0_oo000;ooooo`030000oooooooooooo02gooooo00?oo`00ooooooooool0COooool0
0ol00?ooooooooooo`1_ooooo`7o00000Oooool00003o`000?oooooooooo01kooooo0ooo0009oooo
o`030000oooooooooooo02[ooooo0_oo001@ooooo`03o`00oooooooooooo06oooooo0Ol00001oooo
o`0000?o0000ooooooooool08Oooool2ool000Oooooo00<0003oooooooooool09oooool3ool005;o
oooo00?o003oooooooooool0Koooool1o`00007ooooo00000ol0003oooooooooo`0Sooooo`;oo`00
1Oooool00`000?ooooooooooo`0Uooooo`;oo`00E?ooool00ol00?ooooooooooo`1`ooooo`7o0000
0Oooool00003o`000?oooooooooo02Gooooo1?oo00000oooool0003oooooo`0Rooooo`Coo`00E_oo
ool00ol00?ooooooooooo`1`ooooo`7o00000Oooool00003o`000?oooooooooo02Wooooo0_oo0000
0ol00?ooo`00ool0000Mooooo`?oo`00F_ooool00ol00?ooooooooooo`1`ooooo`7o00000Oooool0
0003o`000?oooooooooo02_ooooo00<0003oooooooooool00ooo000Dooooo`Koo`00GOooool00ol0
0?ooooooooooo`1`ooooo`7o00000Oooool00003o`000?oooooooooo02cooooo00<0003ooooooooo
ool00_oooolDool006;ooooo00?o003oooooooooool0LOooool1o`00007ooooo00000ol0003ooooo
ooooo`0/ooooo`030000oooooooooooo07Sooooo00?o003oooooooooool0LOooool1o`00007ooooo
00000ol0003oooooooooo`0/ooooo`030000oooooooooooo07Sooooo00?o003oooooooooool0LOoo
ool1o`00007ooooo00000ol0003oooooooooo`0]ooooo`030000oooooooooooo07Kooooo00?o003o
ooooooooool0L_ooool1o`00007ooooo00000ol0003oooooooooo`0]ooooo`030000oooooooooooo
07Kooooo00?o003oooooooooool0L_ooool1o`00007ooooo00000ol0003oooooooooo`0]ooooo`03
0000oooooooooooo07Kooooo00?o003oooooooooool0L_ooool1o`00007ooooo00000ol0003ooooo
ooooo`0^ooooo`030000oooooooooooo07Cooooo00?o003oooooooooool0Loooool1o`00007ooooo
00000ol0003oooooooooo`0^ooooo`030000oooooooooooo07Cooooo00?o003oooooooooool0Looo
ool1o`00007ooooo00000ol0003oooooooooo`0^ooooo`030000oooooooooooo07Cooooo00?o003o
ooooooooool0Loooool1o`00007ooooo00000ol0003oooooooooo`0_ooooo`030000oooooooooooo
07;ooooo00?o003oooooooooool0M?ooool1o`00007ooooo00000ol0003oooooooooo`0_ooooo`03
0000oooooooooooo07;ooooo00?o003oooooooooool0M?ooool1o`00007ooooo00000ol0003ooooo
ooooo`0_ooooo`030000oooooooooooo07;ooooo00?o003oooooooooool0M?ooool1o`00007ooooo
00000ol0003oooooooooo`0`ooooo`030000oooooooooooo06oooooo0_l00?mgooooo`7o00000Ooo
ool00003o`000?oooooooooo033ooooo00<0003oooooooooool0Koooool00ol00?ooooooooooo`1f
ooooo`7o00000Oooool00003o`000?oooooooooo037ooooo00<0003oooooooooool0KOooool00ol0
0?ooooooooooo`1gooooo`7o00000Oooool00003o`000?oooooooooo03;ooooo00<0003ooooooooo
ool0K?ooool00ol00?ooooooooooo`1gooooo`7o00000Oooool00003o`000?oooooooooo03;ooooo
00<0003oooooooooool0Joooool00ol00?ooooooooooo`1Pooooo`;oogl05_ooool1o`00007ooooo
00000ol0003oooooooooo`0cooooo`030000oooooooooooo06Wooooo00?o003oooooooooool0H?oo
ool4oomo01Gooooo0Ol00001ooooo`0000?o0000ooooooooool0=?ooool00`000?ooooooooooo`1X
ooooo`03o`00oooooooooooo063ooooo1?ooO`0Eooooo`7o00000Oooool00003o`000?oooooooooo
03Gooooo00<0003oooooooooool0I_ooool00ol00?ooooooooooo`1Rooooo`;oogl05_ooool1o`00
007ooooo00000ol0003oooooooooo`0eooooo`03o`00oooooooooooo06Kooooo00?o003ooooooooo
ool0N_ooool1o`00007ooooo00000ol0003oooooooooo`0fooooo`03o`00oooooooooooo06Cooooo
00?o003oooooooooool0Noooool1o`00007ooooo00000ol0003oooooooooo`0gooooo`03o`00oooo
oooooooo06;ooooo00?o003oooooooooool0O?ooool1o`00007ooooo00000ol0003oooooooooo`0h
ooooo`03o`00oooooooooooo05oooooo0_l00?moooooo`7o00000Oooool00003o`000?oooooooooo
03Wooooo00?o003oooooooooool0GOooool00ol00?ooooooooooo`1oooooo`7o00000Oooool00003
o`000?oooooooooo03[ooooo00?o003oooooooooool0Foooool00ol00?ooooooooooo`20ooooo`7o
00000Oooool00003o`000?oooooooooo03_ooooo00?o003oooooooooool0FOooool00ol00?oooooo
ooooo`21ooooo`7o00000Oooool00003o`000?oooooooooo03cooooo00?o003oooooooooool0Eooo
ool00ol00?ooooooooooo`22ooooo`7o00000Oooool00003o`000?oooooooooo03gooooo00?o003o
ooooooooool0EOooool00ol00?ooooooooooo`23ooooo`7o00000Oooool00003o`000?oooooooooo
03kooooo00?o003oooooooooool0Doooool00ol00?ooooooooooo`24ooooo`7o00000Oooool00003
o`000?oooooooooo03oooooo00?o003oooooooooool0D?ooool2o`00ob7ooooo0_ooO`1Tooooo`7o
00000Oooool00003o`000?oooooooooo043ooooo00?o003oooooooooool0C_ooool00ol00?oooooo
ooooo`0Pooooo`Coogl0Hoooool1o`00007ooooo00000ol0003oooooooooo`11ooooo`;o003oCOoo
ool00ol00?ooooooooooo`0Qooooo`Coogl0Hoooool1o`00007ooooo00000ol0003oooooooooo`13
ooooo`03o`00oooooooooooo04Wooooo00?o003oooooooooool08oooool2oomo03Gooooo0_ooO`0]
ooooo`7o00000Oooool00003o`000?oooooooooo04Cooooo0_l00?m8ooooo`03o`00oooooooooooo
05?ooooo0_ooO`05ooooo`Coogl0;?ooool1o`00007ooooo00000ol0003oooooooooo`16ooooo`;o
003oAOooool00ol00?ooooooooooo`1Cooooo`Coogl01?ooool4oomo02cooooo0Ol00001ooooo`00
00?o0000ooooooooool0B?ooool00ol00?ooooooooooo`10ooooo`;o003o=_ooool2oomo01kooooo
1?ooO`05ooooo`;oogl0;Oooool1o`00007ooooo00000ol0003oooooooooo`19ooooo`;o003o?_oo
ool2o`00ocOooooo1?ooO`0Iooooo`Goo`3o0_ooO`0eooooo`7o00000Oooool00003o`000?oooooo
oooo04_ooooo0ol00?ljooooo`03o`00oooooooooooo03Oooooo1?ooO`0Hooooo`Ooo`3o=_ooool1
o`00007ooooo00000ol0003oooooooooo`1>ooooo`;o003o=_ooool2o`00oc_ooooo0_ooO`0Hoooo
o`Woo`3o=Oooool1o`00007ooooo00000ol0003oooooooooo`1@ooooo`?o003o<?ooool3o`00oc?o
oooo0_ooO`0Qooooo`_oo`3o=?ooool1o`00007ooooo00000ol0003oooooooooo`1Cooooo`;o003o
:_ooool4o`00ocGooooo1?ooO`0Pooooo`_oo`3o=?ooool1o`00007ooooo00000ol0003ooooooooo
o`1Eooooo`?o003o8oooool4o`00ocGooooo0_ooO`02ooooo`Coogl08?ooool;ool0o`03oomo0?oo
oooooooo037ooooo0Ol00001ooooo`0000?o0000ooooooooool0F?ooool3o`00oagooooo0ol00?lh
ooooo`Coogl00_ooool2oomo01?ooooo0_ooO`0<ooooo`_oo`3o0_ooO`0booooo`7o00000Oooool0
0003o`000?oooooooooo05_ooooo0ol00?lDooooo`Ko003o>oooool4oomo00Kooooo0_ooO`0>oooo
o`Coogl02oooool;ool0o`;oogl0<_ooool1o`00007ooooo00000ol0003oooooooooo`1NoooooaCo
003o@_ooool2oomo00Kooooo1?ooO`0=ooooo`Coogl03?ooool9ool0o`;oogl0<oooool1o`00007o
oooo00000ol0003oooooooooo`2;ooooo`;oogl09oooool2oomo00Kooooo1?ooO`0>ooooo`;oogl0
3_ooool7ool0ocKooooo0Ol00001ooooo`0000?o0000ooooooooool0R_ooool4oomo02Gooooo1?oo
O`06ooooo`;oogl08?ooool5ool0ocOooooo0Ol00001ooooo`0000?o0000ooooooooool0R_ooool4
oomo02Gooooo1?ooO`1Tooooo`7o00000Oooool00003o`000?oooooooooo08_ooooo0_ooO`0Woooo
o`;oogl0IOooool1o`00007ooooo00000ol0003oooooooooo`2Fooooo`;oogl0>_ooool2oomo04Oo
oooo0Ol00001ooooo`0000?o0000ooooooooool0UOooool4oomo00kooooo0_ooO`0Xooooo`Coogl0
A_ooool1o`00007ooooo00000ol0003oooooooooo`2Eooooo`Coogl03Oooool4oomo02Oooooo1?oo
O`16ooooo`7o00000Oooool00003o`000?oooooooooo09Kooooo0_ooO`0>ooooo`Coogl0:?ooool2
oomo04Oooooo0Ol00001ooooo`0000?o0000ooooooooool0Yoooool2oomo07;ooooo0Ol00001oooo
o`0000?o0000ooooooooool0joooool2oomo02kooooo0Ol00001ooooo`0000?o0000ooooooooool0
j_ooool4oomo02gooooo0Ol00001ooooo`0000?o0000ooooooooool0e_ooool2oomo01;ooooo1?oo
O`0]ooooo`7o00000Oooool00003o`000?oooooooooo0=Gooooo1?ooO`0Booooo`;oogl0;_ooool1
o`00007ooooo00000ol0003oooooooooo`2gooooo`;oogl07?ooool4oomo04;ooooo0Ol00001oooo
o`0000?o0000ooooooooool0]_ooool4oomo01cooooo0_ooO`13ooooo`7o00000Oooool00003o`00
0?oooooooooo0;?ooooo0_ooO`000oooooooogl0oomo0002oomo067ooooo0Ol00001ooooo`0000?o
0000ooooooooool0Z?ooool2oomo00Sooooo1?ooO`000oooooooogl0oomo000Jooooo`;oogl0A_oo
ool1o`00007ooooo00000ol0003oooooooooo`2Vooooo`Googl01oooool4oomo01Oooooo0_ooO`03
ooooo`Coogl0AOooool1o`00007ooooo00000ol0003oooooooooo`2Uooooo`Koogl02?ooool2oomo
01Oooooo1?ooO`02ooooo`Coogl0AOooool1o`00007ooooo00000ol0003oooooooooo`2Uooooo`Go
ogl08_ooool4oomo00?ooooo0_ooO`16ooooo`7o00000Oooool00003o`000?oooooooooo07Kooooo
0_ooO`0^ooooo`;oogl09Oooool2oomo04cooooo0Ol00001ooooo`0000?o0000ooooooooool0MOoo
ool4oomo0:;ooooo0Ol00001ooooo`0000?o0000ooooooooool0MOooool4oomo00[ooooo0_ooO`2F
ooooo`7o00000Oooool00003o`000?oooooooooo07Kooooo0_ooO`0:ooooo`Coogl0:_ooool2oomo
06Wooooo0Ol00001ooooo`0000?o0000ooooooooool0P_ooool4oomo02Wooooo1?ooO`1Xooooo`7o
00000Oooool00003o`000?oooooooooo08?ooooo0_ooO`0Tooooo`;oogl01?ooool4oomo06Sooooo
0Ol00001ooooo`0000?o0000ooooooooool0Z?ooool4oomo00Cooooo0_ooO`1Yooooo`7o00000Ooo
ool00003o`000?oooooooooo0:Sooooo1?ooO`1_ooooo`7o00000Oooool00003o`000?oooooooooo
0:Wooooo0_ooO`1`ooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007o
oooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooo
oolLooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0
003oooooooooo`24ooooo`;oogl0UOooool1o`00007ooooo00000ol0003oooooooooo`23ooooo`Co
ogl0U?ooool1o`00007ooooo00000ol0003oooooooooo`23ooooo`Coogl0U?ooool1o`00007ooooo
00000ol0003oooooooooo`24ooooo`;oogl0;?ooool2oomo06Oooooo0Ol00001ooooo`0000?o0000
ooooooooool0/Oooool4oomo06Kooooo0Ol00001ooooo`0000?o0000ooooooooool0/Oooool4oomo
06Kooooo0Ol00001ooooo`0000?o0000ooooooooool0/_ooool2oomo06Oooooo0Ol00001ooooo`00
00?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?oo
ool1o`00007ooooo00000ol0003oooooooooo`1kooooo`;oogl0W_ooool1o`00007ooooo00000ol0
003oooooooooo`1jooooo`Coogl0WOooool1o`00007ooooo00000ol0003oooooooooo`1jooooo`Co
ogl08?ooool2oomo07_ooooo0Ol00001ooooo`0000?o0000ooooooooool0Noooool2oomo023ooooo
1?ooO`1jooooo`7o00000Oooool00003o`000?oooooooooo09gooooo1?ooO`1jooooo`7o00000Ooo
ool00003o`000?oooooooooo093ooooo0_ooO`0<ooooo`;oogl0Noooool1o`00007ooooo00000ol0
003oooooooooo`2?ooooo`Coogl0R?ooool1o`00007ooooo00000ol0003oooooooooo`2?ooooo`Co
ogl0R?ooool1o`00007ooooo00000ol0003oooooooooo`2@ooooo`;oogl08oooool2oomo06Cooooo
0Ol00001ooooo`0000?o0000ooooooooool0]?ooool4oomo06?ooooo0Ol00001ooooo`0000?o0000
ooooooooool0]?ooool4oomo06?ooooo0Ol00001ooooo`0000?o0000ooooooooool0]Oooool2oomo
06Cooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`00
0?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol0
0001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo
0?oooooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`00
00?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?oo
ool1o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000oooo
ooooool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007o
oooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooo
oolLooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0
003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o
00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003ooooooooo
o`3ooooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool0
0003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooooaco
oooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oo
oooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001
ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo0?oo
oooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o
0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1
o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000oooooooo
ool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo
00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolL
ooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003o
ooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o0000
0Oooool00003o`000?oooooooooo08kooooo0_ooO`2;ooooo`7o00000Oooool00003o`000?oooooo
oooo08gooooo1?ooO`2:ooooo`7o00000Oooool00003o`000?oooooooooo08gooooo1?ooO`2:oooo
o`7o00000Oooool00003o`000?oooooooooo08kooooo0_ooO`2;ooooo`7o00000Oooool00003o`00
0?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol0
0001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo
0?oooooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`00
00?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?oo
ool1o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000oooo
ooooool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007o
oooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooo
oolLooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0
003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o
00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003ooooooooo
o`3ooooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool0
0003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooooaco
oooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool00?oo00008?l0
0001ooooo`00\
\>"],
  ImageRangeCache->{{{0, 287}, {287, 0}} -> {-1.01089, -1.01089, 0.00704453, \
0.00704453}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.49505 0.5 0.49505 [
[ 0 0 -0.125 0 ]
[ 0 0 -0.125 0 ]
[ 0 1 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
0 0 m
1 0 L
s
0 0 m
0 1 L
s
0 1 m
1 1 L
s
1 0 m
1 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
1 .5 0 r
.015 w
.03175 .1355 Mdot
.03435 .12523 Mdot
.11137 .12765 Mdot
.14107 .18841 Mdot
.16218 .24538 Mdot
.17294 .21053 Mdot
.18267 .18577 Mdot
.18434 .1304 Mdot
.18553 .30956 Mdot
.20401 .239 Mdot
.21247 .27571 Mdot
.21687 .20845 Mdot
.22376 .2799 Mdot
.22832 .27485 Mdot
.29063 .20974 Mdot
.29686 .25079 Mdot
.30487 .22936 Mdot
.30683 .34623 Mdot
.32055 .20902 Mdot
.32574 .21979 Mdot
.34472 .28521 Mdot
.35998 .36393 Mdot
.36335 .24976 Mdot
.3794 .36608 Mdot
.42386 .66992 Mdot
.44391 .74519 Mdot
.45059 .34198 Mdot
.47208 .67586 Mdot
.47436 .71381 Mdot
.49778 .59825 Mdot
.50874 .91643 Mdot
.51516 .76219 Mdot
.53655 .61374 Mdot
.56563 .75219 Mdot
.59189 .65665 Mdot
.59581 .61604 Mdot
.59923 .6556 Mdot
.60292 .68499 Mdot
.62656 .67779 Mdot
.63555 .72451 Mdot
.63919 .652 Mdot
.64169 .6004 Mdot
.64246 .58611 Mdot
.64496 .54267 Mdot
.64608 .77288 Mdot
.65077 .64308 Mdot
.66065 .57816 Mdot
.67474 .59169 Mdot
.69296 .563 Mdot
.72815 .65902 Mdot
.73169 .58879 Mdot
.74669 .61318 Mdot
.74821 .65474 Mdot
.75963 .63781 Mdot
.79673 .57809 Mdot
.80925 .55852 Mdot
.81525 .58444 Mdot
.83417 .62985 Mdot
.83598 .55526 Mdot
.91595 .49319 Mdot
1 0 0 r
.005 w
.00495 .28842 m
.00628 .29156 L
.01857 .31761 L
.03101 .33781 L
.03525 .34367 L
.05706 .36884 L
.05795 .36972 L
.08312 .39115 L
.08963 .39578 L
.10917 .40763 L
.13523 .41964 L
.14074 .42183 L
.16128 .42794 L
.18734 .43294 L
.21339 .43485 L
.23945 .43375 L
.2655 .42959 L
.29156 .42219 L
.29261 .42183 L
.31761 .41124 L
.34367 .39603 L
.34405 .39578 L
.36972 .37551 L
.37582 .36972 L
.39578 .34724 L
.39849 .34367 L
.41525 .31761 L
.42183 .30485 L
.4275 .29156 L
.436 .2655 L
.44117 .23945 L
.44325 .21339 L
.44232 .18734 L
.43834 .16128 L
.43114 .13523 L
.42183 .11212 L
.42037 .10917 L
.40546 .08312 L
.39578 .06961 L
.38528 .05706 L
.36972 .04137 L
.35758 .03101 L
.34367 .02092 L
.31761 .00569 L
.3162 .00495 L
s
.00495 .12854 m
.01344 .10917 L
.02832 .08312 L
.03101 .07912 L
.04848 .05706 L
.05706 .04802 L
.07619 .03101 L
.08312 .02579 L
.10917 .00934 L
.11742 .00495 L
s
0 0 1 r
.29156 .15739 m
.31761 .14824 L
.34367 .14249 L
.36972 .13986 L
.39578 .14025 L
.42183 .14366 L
.44789 .15025 L
.47394 .16034 L
.47599 .16128 L
.5 .17443 L
.51844 .18734 L
.52606 .19355 L
.54662 .21339 L
.55211 .21962 L
.56712 .23945 L
.57817 .25755 L
.58227 .2655 L
.59322 .29156 L
.60058 .31761 L
.60422 .3392 L
.60471 .34367 L
.6058 .36972 L
.60422 .39297 L
.60387 .39578 L
.59886 .42183 L
.59054 .44789 L
.57848 .47394 L
.57817 .47453 L
.562 .5 L
.55211 .51255 L
.53968 .52606 L
.52606 .53862 L
.50853 .55211 L
.5 .55773 L
.47394 .57183 L
.45901 .57817 L
.44789 .5819 L
.42183 .5885 L
.39578 .59192 L
.36972 .59231 L
.34367 .58968 L
.31761 .58392 L
.29972 .57817 L
.29156 .57477 L
.2655 .56178 L
.25025 .55211 L
.23945 .54409 L
.21914 .52606 L
.21339 .52008 L
.19681 .5 L
Mistroke
.18734 .48608 L
.18031 .47394 L
.16827 .44789 L
.16128 .42714 L
.15996 .42183 L
.15493 .39578 L
.153 .36972 L
.15409 .34367 L
.15823 .31761 L
.16128 .3045 L
.16559 .29156 L
.17653 .2655 L
.18734 .24609 L
.19169 .23945 L
.21221 .21339 L
.21339 .21211 L
.23945 .1881 L
.24041 .18734 L
.2655 .17038 L
.28271 .16128 L
.29156 .15739 L
Mfstroke
1 0 0 r
.03 w
.21687 .20845 Mdot
0 0 1 r
.3794 .36608 Mdot
1 0 0 r
.79703 .00495 m
.79703 .02453 L
.87129 .02453 L
.87129 .00495 L
F
0 0 1 r
.89604 .00495 m
.89604 .23289 L
.9703 .23289 L
.9703 .00495 L
F
1 0 1 r
.04 w
.80925 .55852 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P000182000`400?l00000o`00003ooooooolQ
ooooo`00ool0000Po`00007ooooo00000ol0003oooooooooo`0Mooooo`;oo`00>?ooool3ool00<7o
oooo0Ol00001ooooo`0000?o0000ooooooooool06oooool2ool003gooooo00?oo`00ooooooooool0
Q?oooolEool000Sooooo5Ol00?l8ooooo`7o00000Oooool00003o`000?oooooooooo01[ooooo00?o
o`00ooooooooool0?_ooool2ool008Cooooo5Ooo0008oooooaGo003o2?ooool1o`00007ooooo0000
0ol0003oooooooooo`0Hooooo`;oo`00@oooool00ooo003oooooooooo`21oooooaGoo`002?oooolE
o`00o`Sooooo0Ol00001ooooo`0000?o0000ooooooooool05_ooool2ool004Kooooo00?oo`00oooo
ooooool0P?oooolEool000Sooooo5Ol00?l8ooooo`7o00000Oooool00003o`000?oooooooooo01Go
oooo00?oo`00ooooooooool0Aoooool2ool0083ooooo5Ooo0008oooooaGo003o2?ooool1o`00007o
oooo00000ol0003oooooooooo`0Dooooo`03ool00?oooooooooo04[ooooo00?oo`00ooooooooool0
OOoooolEool000Sooooo5Ol00?l8ooooo`7o00000Oooool00003o`000?oooooooooo01?ooooo00?o
o`00ooooooooool0C?ooool00ooo003oooooooooo`2IoooooaGo003o2?ooool1o`00007ooooo0000
0ol0003oooooooooo`0Aooooo`;oo`00D?ooool2ool009Wooooo5Ol00?l8ooooo`7o00000Oooool0
0003o`000?oooooooooo013ooooo00?oo`00ooooooooool0D_ooool2ool009Oooooo5Ol00?l8oooo
o`7o00000Oooool00003o`000?oooooooooo00oooooo00?oo`00ooooooooool0EOooool00ooo003o
ooooooooo`2DoooooaGo003o2?ooool1o`00007ooooo00000ol0003oooooooooo`0>ooooo`03ool0
0?oooooooooo05Kooooo00?oo`00ooooooooool0U?oooolEo`00o`Sooooo0Ol00001ooooo`0000?o
0000ooooooooool03Oooool00ooo003oooooooooo`1Hooooo`03ool00?oooooooooo09?ooooo5Ol0
0?l8ooooo`7o00000Oooool00003o`000?oooooooooo00gooooo00?oo`00ooooooooool0FOooool0
0ooo003oooooooooo`2BoooooaGo003o2?ooool1o`00007ooooo00000ol0003oooooooooo`0<oooo
o`03ool00?oooooooooo05_ooooo00?oo`00ooooooooool0TOoooolEo`00o`Sooooo0Ol00001oooo
o`0000?o0000ooooooooool02oooool00ooo003oooooooooo`1Mooooo`03ool00?oooooooooo093o
oooo5Ol00?l8ooooo`7o00000Oooool00003o`000?oooooooooo00_ooooo00?oo`00ooooooooool0
GOooool00ooo003oooooooooo`2@oooooaGo003o2?ooool1o`00007ooooo00000ol0003ooooooooo
o`0:ooooo`03ool00?oooooooooo05oooooo00?oo`00ooooooooool0SooooolEo`00o`Sooooo0Ol0
0001ooooo`0000?o0000ooooooooool02Oooool00ooo003oooooooooo`1Qooooo`03ool00?oooooo
oooo08kooooo5Ol00?l8ooooo`7o00000Oooool00003o`000?oooooooooo00Sooooo00?oo`00oooo
ooooool0Hoooool00ooo003oooooooooo`2=oooooaGo003o2?ooool1o`00007ooooo00000ol0003o
ooooooooo`07ooooo`03ool00?oooooooooo06Gooooo00?oo`00ooooooooool0S?oooolEo`00o`So
oooo0Ol00001ooooo`0000?o0000ooooooooool01_ooool00ooo003oooooooooo`1Wooooo`03ool0
0?oooooooooo08_ooooo5Ol00?l8ooooo`7o00000Oooool00003o`000?oooooooooo00Gooooo00?o
o`00ooooooooool0JOooool00ooo003oooooooooo`2:oooooaGo003o2?ooool1o`00007ooooo0000
0ol0003oooooooooo`05ooooo`03ool00?oooooooooo06Wooooo00?oo`00ooooooooool0R_oooolE
o`00o`Sooooo0Ol00001ooooo`0000?o0000ooooooooool01?ooool00ooo003oooooooooo`1[oooo
o`03ool00?oooooooooo08Wooooo5Ol00?l8ooooo`7o00000Oooool00003o`000?oooooooooo00?o
oooo00?oo`00ooooooooool0K?ooool00ooo003oooooooooo`29oooooaGo003o2?ooool1o`00007o
oooo00000ol0003oooooooooo`03ooooo`03ool00?oooooooooo06gooooo00?oo`00ooooooooool0
R?oooolEo`00o`Sooooo0Ol00001ooooo`0000?o0000ooooooooool00_ooool00ooo003ooooooooo
o`1^ooooo`03ool00?oooooooooo08Sooooo5Ol00?l8ooooo`7o00000Oooool00003o`000?oooooo
oooo00;ooooo00?oo`00ooooooooool0Koooool00ooo003oooooooooo`27oooooaGo003o2?ooool1
o`00007ooooo00001Ol0003oooooooooooooooooo`0007;ooooo00?oo`00ooooooooool0QooooolE
o`00o`Sooooo0Ol00001ooooo`0000Co0000ooooooooooooo`00M?ooool00ooo003oooooooooo`26
oooooaGo003o2?ooool1o`00007ooooo00001?l0003ooooooooooooo001eooooo`03ool00?oooooo
oooo08Gooooo5Ol00?l8ooooo`7o00000Oooool00003o`000?ooooooo`0007Kooooo00?oo`00oooo
ooooool0QOoooolEo`00o`Sooooo0Ol00001ooooo`0000?o0000oooooooo00001_ooool2oomo06oo
oooo00?oo`00ooooooooool0Q?oooolEo`00o`Sooooo0Ol00001ooooo`0000?o0000oooooooo0000
1Oooool4oomo01?ooooo0_ooO`1Iooooo`03ool00?oooooooooo08Cooooo5Ol00?l8ooooo`7o0000
0Oooool00003o`000?oo003ooooo00Gooooo1?ooO`0Booooo`Coogl04_ooool2oomo04Cooooo00?o
o`00ooooooooool0Q?oooolEo`00o`Sooooo0Ol00001ooooo`0000?o0000ooooooooool01Oooool3
oomo01?ooooo1?ooO`0Aooooo`Coogl0A?ooool00ooo003oooooooooo`23oooooaGo003o2?ooool1
o`00007ooooo00000ol0003oooooooooo`04ooooo`Coogl05?ooool2oomo01;ooooo1?ooO`14oooo
o`03ool00?oooooooooo08?ooooo5Ol00?l8ooooo`7o00000Oooool00003o`000?oooooooooo00Co
oooo1?ooO`0Yooooo`;oogl0AOooool00ooo003oooooooooo`23oooooaGo003o2?ooool1o`00007o
oooo00000ol0003oooooooooo`05ooooo`;oogl0E_oooolFo`00o`Gooooo00?oo`00ooooooooool0
PooooolEo`00o`Sooooo0Ol00001ooooo`0000?o0000ooooooooool0F_ooool3o`00oaKooooo1_l0
0?l00ooo003oooooooooo`22oooooaGo003o2?ooool1o`00007ooooo00000ol0003oooooooooo`1G
ooooo`?o003o7oooool3o`00oh;ooooo5Ol00?l8ooooo`7o00000Oooool00003o`000?oooooooooo
05Cooooo0ol00?lRooooo`03ool00?oooooooooo00?o003oOooooolEo`00o`Sooooo0Ol00001oooo
o`0000?o0000ooooooooool0DOooool3o`00obGooooo00?oo`00ooooooooool00oooool3o`00ogco
oooo5Ol00?l8ooooo`7o00000Oooool00003o`000?oooooooooo04oooooo0P000?lYooooo`03ool0
0?oooooooooo00Gooooo0ol00?mioooooaGo003o2?ooool1o`00007ooooo00000ol0003ooooooooo
o`1=ooooo`80003o:oooool00ooo003oooooooooo`08ooooo`;o003oMooooolEo`00o`Sooooo0Ol0
0001ooooo`0000?o0000ooooooooool0B_ooool30000obgooooo00?oo`00ooooooooool02_ooool2
o`00ogGooooo5Ol00?l8ooooo`7o00000Oooool00003o`000?oooooooooo04Sooooo0P000?l`oooo
o`03ool00?oooooooooo00cooooo00?o003oooooooooool0L_oooolEo`00o`Sooooo0Ol00001oooo
o`0000?o0000ooooooooool0Aoooool00`000?ooooooooooo`0`ooooo`03ool00?oooooooooo00go
oooo0_l00?mboooooaGo003o2?ooool1o`00007ooooo00000ol0003oooooooooo`15ooooo`80003o
=?ooool00ooo003oooooooooo`0>ooooo`;o003oL?oooolEo`00o`Sooooo0Ol00001ooooo`0000?o
0000ooooooooool0A?ooool00`000?ooooooooooo`0dooooo`03ool00?oooooooooo013ooooo0_l0
0?m^oooooaGo003o2?ooool1o`00007ooooo00000ol0003oooooooooo`0Tooooo`;oogl02_ooool2
oomo017ooooo00<0003oooooooooool0=Oooool00ooo003oooooooooo`0Booooo`03o`00oooooooo
oooo06_ooooo5Ol00?l8ooooo`7o00000Oooool00003o`000?oooooooooo02?ooooo1?ooO`08oooo
o`Coogl03oooool00`000?ooooooooooo`0fooooo`03ool00?oooooooooo01?ooooo00?o003ooooo
ooooool0J_oooolEo`00o`Sooooo0Ol00001ooooo`0000?o0000ooooooooool08oooool4oomo00So
oooo1?ooO`0=ooooo`030000ool00?oooooo03Sooooo00?oo`00ooooooooool05?ooool00ol00?oo
ooooooooo`1YoooooaGo003o2?ooool1o`00007ooooo00000ol0003oooooooooo`0Tooooo`;oogl0
2_ooool2oomo00gooooo00<0003oooooooooool0>Oooool00ooo003oooooooooo`0Eooooo`03o`00
oooooooooooo06Sooooo5Ol00?l8ooooo`7o00000Oooool00003o`000?oooooooooo03Wooooo1?oo
00000oooool0003oooooo`0kooooo`03ool00?oooooooooo01Kooooo00?o003oooooooooool0Iooo
oolEo`00o`Sooooo0Ol00001ooooo`0000?o0000ooooooooool0>?ooool6ool003gooooo00?oo`00
ooooooooool05oooool00ol00?ooooooooooo`1VoooooaGo003o2?ooool1o`00007ooooo00000ol0
003oooooooooo`0gooooo`Soo`004?ooool2oomo00Oooooo0_ooO`0Rooooo`03ool00?oooooooooo
01Oooooo00?o003oooooooooool0IOoooolEo`00o`Sooooo0Ol00001ooooo`0000?o0000oooooooo
ool0;_ooool2oomo00Oooooo2?oo000?ooooo`Coogl01Oooool4oomo027ooooo00?oo`00oooooooo
ool06?ooool00ol00?ooooooooooo`1ToooooaGo003o2?ooool1o`00007ooooo00000ol0003ooooo
ooooo`0]ooooo`Coogl01_ooool8ool000oooooo1?ooO`05ooooo`Coogl08Oooool00ooo003ooooo
ooooo`0Iooooo`03o`00oooooooooooo06?ooooo5Ol00?l8ooooo`7o00000Oooool00003o`000?oo
oooooooo02gooooo1?ooO`06ooooo`Soo`004?ooool2oomo00Oooooo0oooO`0Qooooo`03ool00?oo
oooooooo01[ooooo00?o003oooooooooool0H_oooolEo`00o`Sooooo0Ol00001ooooo`0000?o0000
ooooooooool0;_ooool2oomo00Sooooo1_oo000Jooooo`Coogl08?ooool00ooo003oooooooooo`0K
ooooo`03o`00oooooooooooo067ooooo5Ol00?l8ooooo`7o00000Oooool00003o`000?oooooooooo
03Sooooo00<0003oool00?oo00000_oo000Kooooo`Coogl08?ooool00ooo003oooooooooo`0Loooo
o`03o`00oooooooooooo063ooooo5Ol00?l8ooooo`7o00000Oooool00003o`000?oooooooooo03Oo
oooo00<0003oooooooooool06Oooool2oomo00Cooooo0_ooO`0Qooooo`03ool00?oooooooooo01co
oooo00?o003oooooooooool0H?oooolEo`00o`Sooooo0Ol00001ooooo`0000?o0000ooooooooool0
=_ooool00`000?ooooooooooo`0Iooooo`Coogl09Oooool00ooo003oooooooooo`0Nooooo`03o`00
oooooooooooo05oooooo5Ol00?l8ooooo`7o00000Oooool00003o`000?oooooooooo03Kooooo00<0
003oooooooooool06Oooool4oomo02Gooooo00?oo`00ooooooooool07oooool00ol00?oooooooooo
o`1NoooooaGo003o2?ooool1o`00007ooooo00000ol0003oooooooooo`0eooooo`040000oooooooo
ogl0oomo01[ooooo0_ooO`0Vooooo`03ool00?oooooooooo023ooooo00?o003oooooooooool0N_oo
ool1o`00007ooooo00000ol0003oooooooooo`0dooooo`030000ooooooooogl000?oogl0@Oooool0
0ooo003oooooooooo`0Qooooo`03o`00oooooooooooo07Wooooo0Ol00001ooooo`0000?o0000oooo
ooooool0:oooool2oomo00Kooooo00<0003oooooooooool01?ooO`11ooooo`03ool00?oooooooooo
027ooooo00?o003oooooooooool0NOooool1o`00007ooooo00000ol0003oooooooooo`0Zooooo`Co
ogl01?ooool00`000?ooooooooooo`02ooooo`;oogl06?ooool2oomo017ooooo0_ooO`0Eooooo`03
ool00?oooooooooo02;ooooo00?o003oooooooooool0N?ooool1o`00007ooooo00000ol0003ooooo
ooooo`0Zooooo`Coogl01?ooool00`000?ooooooooooo`0Kooooo`Coogl03oooool4oomo01Cooooo
00?oo`00ooooooooool08oooool00ol00?ooooooooooo`1gooooo`7o00000Oooool00003o`000?oo
oooooooo02_ooooo0_ooO`04ooooo`030000oooooooooooo01cooooo1?ooO`0?ooooo`Coogl05?oo
ool00ooo003oooooooooo`0Sooooo`03o`00oooooooooooo07Oooooo0Ol00001ooooo`0000?o0000
ooooooooool0<Oooool00`000?ooooooooooo`0Mooooo`;oogl04Oooool2oomo01Cooooo00?oo`00
ooooooooool09Oooool00ol00?ooooooooooo`1fooooo`7o00000Oooool00003o`000?oooooooooo
033ooooo00<0003oooooooooool0Aoooool00ooo003oooooooooo`0Uooooo`03o`00oooooooooooo
07Kooooo0Ol00001ooooo`0000?o0000ooooooooool0<?ooool00`000?ooooooooooo`17ooooo`03
ool00?oooooooooo02Kooooo00?o003oooooooooool0MOooool1o`00007ooooo00000ol0003ooooo
ooooo`0_ooooo`030000oooooooooooo04Sooooo00?oo`00ooooooooool09oooool00ol00?oooooo
ooooo`1dooooo`7o00000Oooool00003o`000?oooooooooo02oooooo00<0003oooooooooool01ooo
ool2oomo00;ooooo0_ooO`0kooooo`03ool00?oooooooooo02Oooooo00?o003oooooooooool0M?oo
ool1o`00007ooooo00000ol0003oooooooooo`0^ooooo`030000oooooooooooo00Oooooo2?ooO`0i
ooooo`03ool00?oooooooooo02Wooooo00?o003oooooooooool0Loooool1o`00007ooooo00000ol0
003oooooooooo`0^ooooo`030000oooooooooooo00Oooooo2?ooO`0iooooo`03ool00?oooooooooo
02Wooooo00?o003oooooooooool0Loooool1o`00007ooooo00000ol0003oooooooooo`0]ooooo`03
0000oooooooooooo00Wooooo1_ooO`0Pooooo`;oogl05oooool00ooo003oooooooooo`0[ooooo`03
o`00oooooooooooo07;ooooo0Ol00001ooooo`0000?o0000ooooooooool0;Oooool00`000?oooooo
ooooo`0;ooooo`Coogl07oooool4oomo01Kooooo00?oo`00ooooooooool0:oooool00ol00?oooooo
ooooo`1booooo`7o00000Oooool00003o`000?oo003ooooo02gooooo00<0003oooooooooool03?oo
ool2oomo023ooooo1?ooO`0Fooooo`03ool00?oooooooooo02_ooooo00?o003oooooooooool0L_oo
ool1o`00007ooooo00000ol0003oo`00ooooo`0/ooooo`030000oooooooooooo033ooooo0_ooO`0F
ooooo`03ool00?oooooooooo02gooooo00?o003oooooooooool0LOooool1o`00007ooooo00000ol0
003oo`00ooooo`0/ooooo`030000oooooooooooo04Sooooo00?oo`00ooooooooool0;Oooool00ol0
0?ooooooooooo`1aooooo`7o00000Oooool00003o`000?ooooooo`0002cooooo00<0003ooooooooo
ool0B?ooool00ooo003oooooooooo`0]ooooo`03o`00oooooooooooo077ooooo0Ol00001ooooo`00
00?o0000oooooooo0000:oooool00`000?ooooooooooo`18ooooo`03ool00?oooooooooo02oooooo
00?o003oooooooooool0L?ooool1o`00007ooooo00001?l0003ooooooooooooo000Zooooo`030000
oooooooooooo00?ooooo0_ooO`13ooooo`03ool00?oooooooooo02oooooo00?o003oooooooooool0
L?ooool1o`00007ooooo00001?l0003ooooooooooooo000Zooooo`030000oooooooooooo00;ooooo
1?ooO`12ooooo`03ool00?oooooooooo02oooooo00?o003oooooooooool0L?ooool1o`00007ooooo
00001Ol0003oooooooooooooooooo`0002Wooooo00<0003oooooooooool00_ooool4oomo047ooooo
00?oo`00ooooooooool0<?ooool00ol00?ooooooooooo`1`ooooo`7o00000Oooool00005o`000?oo
oooooooooooooooo0000:?ooool00`000?ooooooooooo`04ooooo`;oogl0@_ooool00ooo003ooooo
ooooo`0aooooo`03o`00oooooooooooo06oooooo0Ol00001ooooo`0000?o0000ooooooooool00_oo
ool00ooo003oooooooooo`0Uooooo`030000oooooooooooo04Oooooo00?oo`00ooooooooool0<_oo
ool00ol00?ooooooooooo`1_ooooo`7o00000Oooool00003o`000?oooooooooo00;ooooo00?oo`00
ooooooooool09Oooool00`000?ooooooooooo`17ooooo`03ool00?oooooooooo03;ooooo00?o003o
ooooooooool0Koooool1o`00007ooooo00000ol0003oooooooooo`03ooooo`03ool00?oooooooooo
02Cooooo00<0003oooooooooool0A_ooool00ooo003oooooooooo`0cooooo`03o`00oooooooooooo
06oooooo0Ol00001ooooo`0000?o0000ooooooooool01?ooool00ooo003oooooooooo`0Sooooo`03
0000oooooooooooo04Gooooo00?oo`00ooooooooool0=?ooool00ol00?ooooooooooo`1_ooooo`7o
00000Oooool00003o`000?oooooooooo00Gooooo00?oo`00ooooooooool08Oooool00`000?oooooo
ooooo`15ooooo`03ool00?oooooooooo03Kooooo00?o003oooooooooool0K_ooool1o`00007ooooo
00000ol0003oooooooooo`06ooooo`03ool00?oooooooooo023ooooo00<0003oooooooooool0AOoo
ool00ooo003oooooooooo`09ooooo`;oogl0:oooool00ol00?ooooooooooo`1^ooooo`7o00000Ooo
ool00003o`000?oooooooooo00Kooooo00?oo`00ooooooooool08?ooool00`000?ooooooooooo`14
ooooo`03ool00?oooooooooo00Wooooo1?ooO`0Zooooo`03o`00oooooooooooo06kooooo0Ol00001
ooooo`0000?o0000ooooooooool01oooool00ooo003oooooooooo`0Oooooo`030000oooooooooooo
02Sooooo0_ooO`0Iooooo`03ool00?oooooooooo00[ooooo1?ooO`0Zooooo`03o`00oooooooooooo
06kooooo0Ol00001ooooo`0000?o0000ooooooooool01oooool00ooo003oooooooooo`0Oooooo`03
0000oooooooooooo02Oooooo1?ooO`0Gooooo`03ool00?oooooooooo00cooooo0_ooO`0[ooooo`03
o`00oooooooooooo06kooooo0Ol00001ooooo`0000?o0000ooooooooool02?ooool00ooo003ooooo
ooooo`0Nooooo`030000oooooooooooo02Oooooo1?ooO`0Gooooo`03ool00?oooooooooo03Wooooo
00?o003oooooooooool0K_ooool1o`00007ooooo00000ol0003oooooooooo`09ooooo`03ool00?oo
oooooooo01gooooo00<0003oooooooooool0:?ooool2oomo01;ooooo1?l00?l00oooooooo`00oooo
o`0kooooo`03o`00oooooooooooo06kooooo0Ol00001ooooo`0000?o0000ooooooooool02_ooool0
0ooo003oooooooooo`0Looooo`030000oooooooooooo03_ooooo1_l00?lmooooo`03o`00oooooooo
oooo06kooooo0Ol00001ooooo`0000?o0000ooooooooool02oooool00ooo003oooooooooo`0Koooo
o`030000oooooooooooo03Oooooo0_ooO`000ooooooo003oo`00o`06o`00occooooo00?o003ooooo
ooooool0K_ooool1o`00007ooooo00000ol0003oooooooooo`0<ooooo`03ool00?oooooooooo01[o
oooo00<0003oooooooooool0=_ooool4oomo00So003o??ooool00ol00?ooooooooooo`1^ooooo`7o
00000Oooool00003o`000?oooooooooo00gooooo00?oo`00ooooooooool06Oooool00`000?oooooo
ooooo`0fooooo`Coogl02?l00?llooooo`03o`00oooooooooooo06kooooo0Ol00001ooooo`0000?o
0000ooooooooool03Oooool2ool001[ooooo00<0003oooooooooool0=oooool2oomo0003ooooool0
0?oo003o00Ko003o??ooool00ol00?ooooooooooo`1^ooooo`7o00000Oooool00003o`000?oooooo
oooo00oooooo00?oo`00ooooooooool05oooool00`000?ooooooooooo`0jooooo`03ool00?l00?oo
003o00Co003o?Oooool00ol00?ooooooooooo`1^ooooo`7o00000Oooool00003o`000?oooooooooo
013ooooo00?oo`00ooooooooool05_ooool00`000?ooooooooooo`0iooooo`03ool00?oooooooooo
00Co003o?_ooool00ol00?ooooooooooo`1^ooooo`7o00000Oooool00003o`000?oooooooooo017o
oooo00?oo`00ooooooooool05Oooool00`000?ooooooooooo`0hooooo`03ool00?oooooooooo04?o
oooo00?o003oooooooooool0K_ooool1o`00007ooooo00000ol0003oooooooooo`0Booooo`03ool0
0?oooooooooo01Cooooo00<0003oooooooooool0=_ooool2ool004Kooooo00?o003oooooooooool0
K_ooool1o`00007ooooo00000ol0003oooooooooo`0Cooooo`03ool00?oooooooooo01?ooooo00<0
003oooooooooool0=Oooool00ooo003oooooooooo`16ooooo`03o`00oooooooooooo06kooooo0Ol0
0001ooooo`0000?o0000ooooooooool05?ooool2ool001?ooooo00<0003oooooooooool0=?ooool0
0ooo003oooooooooo`17ooooo`03o`00oooooooooooo06kooooo0Ol00001ooooo`0000?o0000oooo
ooooool05_ooool2ool0017ooooo00<0003oooooooooool0<_ooool2ool004[ooooo00?o003ooooo
ooooool0K_ooool1o`00007ooooo00000ol0003oooooooooo`0Hooooo`03ool00?oooooooooo00ko
oooo00<0003oooooooooool0<Oooool00ooo003oooooooooo`1:ooooo`03o`00oooooooooooo06ko
oooo0Ol00001ooooo`0000?o0000ooooooooool06Oooool2ool000kooooo00<0003oooooooooool0
;oooool2ool004gooooo00?o003oooooooooool0K_ooool1o`00007ooooo00000ol0003ooooooooo
o`0Kooooo`03ool00?oooooooooo00_ooooo00<0003oooooooooool0;_ooool00ooo003ooooooooo
o`1<ooooo`03o`00oooooooooooo06oooooo0Ol00001ooooo`0000?o0000ooooooooool07?ooool2
ool000_ooooo00<0003oooooooooool0;Oooool00ooo003oooooooooo`1=ooooo`03o`00oooooooo
oooo06oooooo0Ol00001ooooo`0000?o0000ooooooooool07_ooool3ool000Wooooo00<0003ooooo
ooooool0:_ooool2ool0053ooooo00?o003oooooooooool0Koooool1o`00007ooooo00000ol0003o
ooooooooo`0Qooooo`;oo`001oooool00`000?ooooooooooo`0Wooooo`?oo`00D_ooool00ol00?oo
ooooooooo`1_ooooo`7o00000Oooool00003o`000?oooooooooo02?ooooo0_oo0005ooooo`030000
oooooooooooo02Gooooo0_oo001Dooooo`03o`00oooooooooooo073ooooo0Ol00001ooooo`0000?o
0000ooooooooool09Oooool4ool00003ooooo`000?oooooo02;ooooo1?oo001Fooooo`03o`00oooo
oooooooo073ooooo0Ol00001ooooo`0000?o0000ooooooooool0:Oooool2ool00003o`00oooo003o
o`0001gooooo0ooo001Jooooo`03o`00oooooooooooo073ooooo0Ol00001ooooo`0000?o0000oooo
ooooool0:oooool00`000?ooooooooooo`03ool001Cooooo1_oo001Mooooo`03o`00oooooooooooo
073ooooo0Ol00001ooooo`0000?o0000ooooooooool0;?ooool00`000?ooooooooooo`02oooooaCo
o`00H_ooool00ol00?ooooooooooo`1aooooo`7o00000Oooool00003o`000?oooooooooo02cooooo
00<0003oooooooooool0N?ooool00ol00?ooooooooooo`1aooooo`7o00000Oooool00003o`000?oo
oooooooo02cooooo00<0003oooooooooool0N?ooool00ol00?ooooooooooo`1aooooo`7o00000Ooo
ool00003o`000?oooooooooo02gooooo00<0003oooooooooool0M_ooool00ol00?ooooooooooo`1b
ooooo`7o00000Oooool00003o`000?oooooooooo02gooooo00<0003oooooooooool0M_ooool00ol0
0?ooooooooooo`1booooo`7o00000Oooool00003o`000?oooooooooo02gooooo00<0003ooooooooo
ool0M_ooool00ol00?ooooooooooo`1booooo`7o00000Oooool00003o`000?oooooooooo02kooooo
00<0003oooooooooool0M?ooool00ol00?ooooooooooo`1cooooo`7o00000Oooool00003o`000?oo
oooooooo02kooooo00<0003oooooooooool0M?ooool00ol00?ooooooooooo`1cooooo`7o00000Ooo
ool00003o`000?oooooooooo02kooooo00<0003oooooooooool0M?ooool00ol00?ooooooooooo`1c
ooooo`7o00000Oooool00003o`000?oooooooooo02oooooo00<0003oooooooooool0L_ooool00ol0
0?ooooooooooo`1dooooo`7o00000Oooool00003o`000?oooooooooo02oooooo00<0003ooooooooo
ool0L_ooool00ol00?ooooooooooo`1dooooo`7o00000Oooool00003o`000?oooooooooo02oooooo
00<0003oooooooooool0L_ooool00ol00?ooooooooooo`1dooooo`7o00000Oooool00003o`000?oo
oooooooo033ooooo00<0003oooooooooool0Koooool2o`00ogOooooo0Ol00001ooooo`0000?o0000
ooooooooool0<?ooool00`000?ooooooooooo`1_ooooo`03o`00oooooooooooo07Kooooo0Ol00001
ooooo`0000?o0000ooooooooool0<Oooool00`000?ooooooooooo`1]ooooo`03o`00oooooooooooo
07Oooooo0Ol00001ooooo`0000?o0000ooooooooool0<_ooool00`000?ooooooooooo`1/ooooo`03
o`00oooooooooooo07Oooooo0Ol00001ooooo`0000?o0000ooooooooool0<_ooool00`000?oooooo
ooooo`1[ooooo`03o`00oooooooooooo063ooooo0_ooO`0Fooooo`7o00000Oooool00003o`000?oo
oooooooo03?ooooo00<0003oooooooooool0JOooool00ol00?ooooooooooo`1Pooooo`Coogl05Ooo
ool1o`00007ooooo00000ol0003oooooooooo`0dooooo`030000oooooooooooo06Sooooo00?o003o
ooooooooool0H?ooool4oomo01Gooooo0Ol00001ooooo`0000?o0000ooooooooool0=Oooool00`00
0?ooooooooooo`1Vooooo`03o`00oooooooooooo06;ooooo0_ooO`0Fooooo`7o00000Oooool00003
o`000?oooooooooo03Gooooo00?o003oooooooooool0I_ooool00ol00?ooooooooooo`1jooooo`7o
00000Oooool00003o`000?oooooooooo03Kooooo00?o003oooooooooool0I?ooool00ol00?oooooo
ooooo`1kooooo`7o00000Oooool00003o`000?oooooooooo03Oooooo00?o003oooooooooool0H_oo
ool00ol00?ooooooooooo`1looooo`7o00000Oooool00003o`000?oooooooooo03Sooooo00?o003o
ooooooooool0Goooool2o`00ogoooooo0Ol00001ooooo`0000?o0000ooooooooool0>Oooool00ol0
0?ooooooooooo`1Mooooo`03o`00oooooooooooo07oooooo0Ol00001ooooo`0000?o0000oooooooo
ool0>_ooool00ol00?ooooooooooo`1Kooooo`03o`00oooooooooooo083ooooo0Ol00001ooooo`00
00?o0000ooooooooool0>oooool00ol00?ooooooooooo`1Iooooo`03o`00oooooooooooo087ooooo
0Ol00001ooooo`0000?o0000ooooooooool0??ooool00ol00?ooooooooooo`1Gooooo`03o`00oooo
oooooooo08;ooooo0Ol00001ooooo`0000?o0000ooooooooool0?Oooool00ol00?ooooooooooo`1E
ooooo`03o`00oooooooooooo08?ooooo0Ol00001ooooo`0000?o0000ooooooooool0?_ooool00ol0
0?ooooooooooo`1Cooooo`03o`00oooooooooooo08Cooooo0Ol00001ooooo`0000?o0000oooooooo
ool0?oooool00ol00?ooooooooooo`1@ooooo`;o003o8Oooool2oomo06Cooooo0Ol00001ooooo`00
00?o0000ooooooooool0@?ooool00ol00?ooooooooooo`1>ooooo`03o`00oooooooooooo023ooooo
1?ooO`0Zooooo`Goo`3o=?ooool1o`00007ooooo00000ol0003oooooooooo`11ooooo`;o003oCOoo
ool00ol00?ooooooooooo`0Qooooo`Coogl0:Oooool7ool0oc?ooooo0Ol00001ooooo`0000?o0000
ooooooooool0@oooool00ol00?ooooooooooo`19ooooo`03o`00oooooooooooo02?ooooo0_ooO`0Y
ooooo`Woo`3o0oooool2oomo02gooooo0Ol00001ooooo`0000?o0000ooooooooool0A?ooool2o`00
odSooooo00?o003oooooooooool0C_ooool;ool0o`03ooooooooO`3oogl000;oogl0;?ooool1o`00
007ooooo00000ol0003oooooooooo`16ooooo`;o003oAOooool00ol00?ooooooooooo`1?ooooo`_o
o`3o00?ooooooomo0?ooO`000_ooO`0/ooooo`7o00000Oooool00003o`000?oooooooooo04Sooooo
00?o003oooooooooool0@?ooool2o`00ocKooooo0_ooO`0Jooooo`_oo`3o0_ooool2oomo02gooooo
0Ol00001ooooo`0000?o0000ooooooooool0BOooool2o`00ockooooo0_l00?lgooooo`Coogl06Ooo
ool;ool0oc7ooooo0Ol00001ooooo`0000?o0000ooooooooool0Boooool3o`00oc[ooooo00?o003o
ooooooooool0=oooool4oomo01Wooooo2ooo0?laooooo`7o00000Oooool00003o`000?oooooooooo
04kooooo0_l00?lfooooo`;o003o>oooool2oomo01_ooooo2Ooo0?lbooooo`7o00000Oooool00003
o`000?oooooooooo053ooooo0ol00?l`ooooo`?o003o<oooool2oomo02Gooooo00?oogl0ool0oooo
0?l01Ooo0?lcooooo`7o00000Oooool00003o`000?oooooooooo05?ooooo0_l00?lZooooo`Co003o
=Oooool4oomo02?ooooo0oooO`05ool0ocCooooo0Ol00001ooooo`0000?o0000ooooooooool0EOoo
ool3o`00ob?ooooo1?l00?leooooo`;oogl00_ooool4oomo02?ooooo1?ooO`03ooooo`;oogl0<ooo
ool1o`00007ooooo00000ol0003oooooooooo`1Hooooo`?o003o7Oooool3o`00ocSooooo1?ooO`02
ooooo`;oogl04oooool2oomo013ooooo0_ooO`03ooooo`Coogl0<_ooool1o`00007ooooo00000ol0
003oooooooooo`1Kooooo`?o003o5?ooool6o`00oc_ooooo1?ooO`06ooooo`;oogl03_ooool4oomo
01Cooooo1?ooO`0booooo`7o00000Oooool00003o`000?oooooooooo05kooooo5?l00?m2ooooo`;o
ogl01_ooool4oomo00gooooo1?ooO`0Eooooo`;oogl0<oooool1o`00007ooooo00000ol0003ooooo
ooooo`2;ooooo`;oogl09oooool2oomo00Kooooo1?ooO`0>ooooo`;oogl0Boooool1o`00007ooooo
00000ol0003oooooooooo`2:ooooo`Coogl09Oooool4oomo00Kooooo0_ooO`1Looooo`7o00000Ooo
ool00003o`000?oooooooooo08[ooooo1?ooO`0Uooooo`Coogl0I?ooool1o`00007ooooo00000ol0
003oooooooooo`2;ooooo`;oogl09oooool2oomo06Gooooo0Ol00001ooooo`0000?o0000oooooooo
ool0U_ooool2oomo03[ooooo0_ooO`17ooooo`7o00000Oooool00003o`000?oooooooooo09Gooooo
1?ooO`0>ooooo`;oogl0:?ooool4oomo04Kooooo0Ol00001ooooo`0000?o0000ooooooooool0UOoo
ool4oomo00gooooo1?ooO`0Wooooo`Coogl0A_ooool1o`00007ooooo00000ol0003oooooooooo`2F
ooooo`;oogl03_ooool4oomo02Sooooo0_ooO`17ooooo`7o00000Oooool00003o`000?oooooooooo
0:Oooooo0_ooO`1booooo`7o00000Oooool00003o`000?oooooooooo0>_ooooo0_ooO`0^ooooo`7o
00000Oooool00003o`000?oooooooooo0>[ooooo1?ooO`0]ooooo`7o00000Oooool00003o`000?oo
oooooooo0=Kooooo0_ooO`0Booooo`Coogl0;Oooool1o`00007ooooo00000ol0003oooooooooo`3E
ooooo`Coogl04_ooool2oomo02kooooo0Ol00001ooooo`0000?o0000ooooooooool0]oooool2oomo
01cooooo1?ooO`12ooooo`7o00000Oooool00003o`000?oooooooooo0;Kooooo1?ooO`0Looooo`;o
ogl0@oooool1o`00007ooooo00000ol0003oooooooooo`2cooooo`;oogl000?ooooooomo0?ooO`00
0_ooO`1Qooooo`7o00000Oooool00003o`000?oooooooooo0:Sooooo0_ooO`08ooooo`Coogl000?o
oooooomo0?ooO`006_ooool2oomo04Kooooo0Ol00001ooooo`0000?o0000ooooooooool0Y_ooool5
oomo00Oooooo1?ooO`0Gooooo`;oogl00oooool4oomo04Gooooo0Ol00001ooooo`0000?o0000oooo
ooooool0YOooool6oomo00Sooooo0_ooO`0Gooooo`Coogl00_ooool4oomo04Gooooo0Ol00001oooo
o`0000?o0000ooooooooool0YOooool5oomo02;ooooo1?ooO`03ooooo`;oogl0A_ooool1o`00007o
oooo00000ol0003oooooooooo`1fooooo`;oogl0;_ooool2oomo02Gooooo0_ooO`1<ooooo`7o0000
0Oooool00003o`000?oooooooooo07Gooooo1?ooO`2Rooooo`7o00000Oooool00003o`000?oooooo
oooo07Gooooo1?ooO`0:ooooo`;oogl0U_ooool1o`00007ooooo00000ol0003oooooooooo`1foooo
o`;oogl02_ooool4oomo02[ooooo0_ooO`1Yooooo`7o00000Oooool00003o`000?oooooooooo08;o
oooo1?ooO`0Yooooo`Coogl0J?ooool1o`00007ooooo00000ol0003oooooooooo`23ooooo`;oogl0
9?ooool2oomo00Cooooo1?ooO`1Xooooo`7o00000Oooool00003o`000?oooooooooo0:Sooooo1?oo
O`04ooooo`;oogl0JOooool1o`00007ooooo00000ol0003oooooooooo`2Xooooo`Coogl0Koooool1
o`00007ooooo00000ol0003oooooooooo`2Yooooo`;oogl0L?ooool1o`00007ooooo00000ol0003o
ooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o0000
0Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3o
oooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0Q?ooool2oomo09Gooooo0Ol00001oooo
o`0000?o0000ooooooooool0Poooool4oomo09Cooooo0Ol00001ooooo`0000?o0000ooooooooool0
Poooool4oomo09Cooooo0Ol00001ooooo`0000?o0000ooooooooool0Q?ooool2oomo02cooooo0_oo
O`1Wooooo`7o00000Oooool00003o`000?oooooooooo0;7ooooo1?ooO`1Vooooo`7o00000Oooool0
0003o`000?oooooooooo0;7ooooo1?ooO`1Vooooo`7o00000Oooool00003o`000?oooooooooo0;;o
oooo0_ooO`1Wooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo
00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0Noooool2
oomo09kooooo0Ol00001ooooo`0000?o0000ooooooooool0N_ooool4oomo09gooooo0Ol00001oooo
o`0000?o0000ooooooooool0N_ooool4oomo023ooooo0_ooO`1kooooo`7o00000Oooool00003o`00
0?oooooooooo07_ooooo0_ooO`0Pooooo`Coogl0N_ooool1o`00007ooooo00000ol0003ooooooooo
o`2Mooooo`Coogl0N_ooool1o`00007ooooo00000ol0003oooooooooo`2@ooooo`;oogl03?ooool2
oomo07_ooooo0Ol00001ooooo`0000?o0000ooooooooool0Soooool4oomo08Sooooo0Ol00001oooo
o`0000?o0000ooooooooool0Soooool4oomo08Sooooo0Ol00001ooooo`0000?o0000ooooooooool0
T?ooool2oomo02?ooooo0_ooO`1Tooooo`7o00000Oooool00003o`000?oooooooooo0;Cooooo1?oo
O`1Sooooo`7o00000Oooool00003o`000?oooooooooo0;Cooooo1?ooO`1Sooooo`7o00000Oooool0
0003o`000?oooooooooo0;Gooooo0_ooO`1Tooooo`7o00000Oooool00003o`000?oooooooooo0?oo
oooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o
0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1
o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000oooooooo
ool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo
00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolL
ooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003o
ooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o0000
0Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3o
oooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003
o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo
0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oooooo
oooo0?oooooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001oooo
o`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo
7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000
ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00
007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0
oooooolLooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo0000
0ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLoooo
o`7o00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003ooooo
ooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Ooo
ool00003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooo
oacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`00
0?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003oooooooooo`2>ooooo`;oogl0Rooo
ool1o`00007ooooo00000ol0003oooooooooo`2=ooooo`Coogl0R_ooool1o`00007ooooo00000ol0
003oooooooooo`2=ooooo`Coogl0R_ooool1o`00007ooooo00000ol0003oooooooooo`2>ooooo`;o
ogl0Roooool1o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o
0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1
o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000oooooooo
ool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo
00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolL
ooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003o
ooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o0000
0Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3o
oooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003
o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo
0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oooooo
oooo0?oooooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001oooo
o`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo
7?ooool1o`00007ooooo003oo`00023o00000Oooool00001\
\>"],
  ImageRangeCache->{{{0, 287}, {287, 0}} -> {-1.01089, -1.01089, 0.00704453, \
0.00704453}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.49505 0.5 0.49505 [
[ 0 0 -0.125 0 ]
[ 0 0 -0.125 0 ]
[ 0 1 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
0 0 m
1 0 L
s
0 0 m
0 1 L
s
0 1 m
1 1 L
s
1 0 m
1 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
1 .5 0 r
.015 w
.03175 .1355 Mdot
.03435 .12523 Mdot
.11137 .12765 Mdot
.14107 .18841 Mdot
.16218 .24538 Mdot
.17294 .21053 Mdot
.18267 .18577 Mdot
.18434 .1304 Mdot
.18553 .30956 Mdot
.20401 .239 Mdot
.21247 .27571 Mdot
.21687 .20845 Mdot
.22376 .2799 Mdot
.22832 .27485 Mdot
.29063 .20974 Mdot
.29686 .25079 Mdot
.30487 .22936 Mdot
.30683 .34623 Mdot
.32055 .20902 Mdot
.32574 .21979 Mdot
.34472 .28521 Mdot
.35998 .36393 Mdot
.36335 .24976 Mdot
.3794 .36608 Mdot
.42386 .66992 Mdot
.44391 .74519 Mdot
.45059 .34198 Mdot
.47208 .67586 Mdot
.47436 .71381 Mdot
.49778 .59825 Mdot
.50874 .91643 Mdot
.51516 .76219 Mdot
.53655 .61374 Mdot
.56563 .75219 Mdot
.59189 .65665 Mdot
.59581 .61604 Mdot
.59923 .6556 Mdot
.60292 .68499 Mdot
.62656 .67779 Mdot
.63555 .72451 Mdot
.63919 .652 Mdot
.64169 .6004 Mdot
.64246 .58611 Mdot
.64496 .54267 Mdot
.64608 .77288 Mdot
.65077 .64308 Mdot
.66065 .57816 Mdot
.67474 .59169 Mdot
.69296 .563 Mdot
.72815 .65902 Mdot
.73169 .58879 Mdot
.74669 .61318 Mdot
.74821 .65474 Mdot
.75963 .63781 Mdot
.79673 .57809 Mdot
.80925 .55852 Mdot
.81525 .58444 Mdot
.83417 .62985 Mdot
.83598 .55526 Mdot
.91595 .49319 Mdot
1 0 0 r
.005 w
.00495 .28842 m
.00628 .29156 L
.01857 .31761 L
.03101 .33781 L
.03525 .34367 L
.05706 .36884 L
.05795 .36972 L
.08312 .39115 L
.08963 .39578 L
.10917 .40763 L
.13523 .41964 L
.14074 .42183 L
.16128 .42794 L
.18734 .43294 L
.21339 .43485 L
.23945 .43375 L
.2655 .42959 L
.29156 .42219 L
.29261 .42183 L
.31761 .41124 L
.34367 .39603 L
.34405 .39578 L
.36972 .37551 L
.37582 .36972 L
.39578 .34724 L
.39849 .34367 L
.41525 .31761 L
.42183 .30485 L
.4275 .29156 L
.436 .2655 L
.44117 .23945 L
.44325 .21339 L
.44232 .18734 L
.43834 .16128 L
.43114 .13523 L
.42183 .11212 L
.42037 .10917 L
.40546 .08312 L
.39578 .06961 L
.38528 .05706 L
.36972 .04137 L
.35758 .03101 L
.34367 .02092 L
.31761 .00569 L
.3162 .00495 L
s
.00495 .12854 m
.01344 .10917 L
.02832 .08312 L
.03101 .07912 L
.04848 .05706 L
.05706 .04802 L
.07619 .03101 L
.08312 .02579 L
.10917 .00934 L
.11742 .00495 L
s
0 0 1 r
.29156 .15739 m
.31761 .14824 L
.34367 .14249 L
.36972 .13986 L
.39578 .14025 L
.42183 .14366 L
.44789 .15025 L
.47394 .16034 L
.47599 .16128 L
.5 .17443 L
.51844 .18734 L
.52606 .19355 L
.54662 .21339 L
.55211 .21962 L
.56712 .23945 L
.57817 .25755 L
.58227 .2655 L
.59322 .29156 L
.60058 .31761 L
.60422 .3392 L
.60471 .34367 L
.6058 .36972 L
.60422 .39297 L
.60387 .39578 L
.59886 .42183 L
.59054 .44789 L
.57848 .47394 L
.57817 .47453 L
.562 .5 L
.55211 .51255 L
.53968 .52606 L
.52606 .53862 L
.50853 .55211 L
.5 .55773 L
.47394 .57183 L
.45901 .57817 L
.44789 .5819 L
.42183 .5885 L
.39578 .59192 L
.36972 .59231 L
.34367 .58968 L
.31761 .58392 L
.29972 .57817 L
.29156 .57477 L
.2655 .56178 L
.25025 .55211 L
.23945 .54409 L
.21914 .52606 L
.21339 .52008 L
.19681 .5 L
Mistroke
.18734 .48608 L
.18031 .47394 L
.16827 .44789 L
.16128 .42714 L
.15996 .42183 L
.15493 .39578 L
.153 .36972 L
.15409 .34367 L
.15823 .31761 L
.16128 .3045 L
.16559 .29156 L
.17653 .2655 L
.18734 .24609 L
.19169 .23945 L
.21221 .21339 L
.21339 .21211 L
.23945 .1881 L
.24041 .18734 L
.2655 .17038 L
.28271 .16128 L
.29156 .15739 L
Mfstroke
1 0 0 r
.03 w
.21687 .20845 Mdot
0 0 1 r
.3794 .36608 Mdot
1 0 0 r
.79703 .00495 m
.79703 .02282 L
.87129 .02282 L
.87129 .00495 L
F
0 0 1 r
.89604 .00495 m
.89604 .2346 L
.9703 .2346 L
.9703 .00495 L
F
1 0 1 r
.04 w
.81525 .58444 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P000182000`400?l00000o`00003ooooooolQ
ooooo`00ool0000Po`00007ooooo00000ol0003oooooooooo`0Mooooo`;oo`00>?ooool3ool00<7o
oooo0Ol00001ooooo`0000?o0000ooooooooool06oooool2ool003gooooo00?oo`00ooooooooool0
Q?oooolEool000Sooooo5Ol00?l8ooooo`7o00000Oooool00003o`000?oooooooooo01[ooooo00?o
o`00ooooooooool0?_ooool2ool008Cooooo5Ooo0008oooooaGo003o2?ooool1o`00007ooooo0000
0ol0003oooooooooo`0Hooooo`;oo`00@oooool00ooo003oooooooooo`21oooooaGoo`002?oooolE
o`00o`Sooooo0Ol00001ooooo`0000?o0000ooooooooool05_ooool2ool004Kooooo00?oo`00oooo
ooooool0P?oooolEool000Sooooo5Ol00?l8ooooo`7o00000Oooool00003o`000?oooooooooo01Go
oooo00?oo`00ooooooooool0Aoooool2ool0083ooooo5Ooo0008oooooaGo003o2?ooool1o`00007o
oooo00000ol0003oooooooooo`0Dooooo`03ool00?oooooooooo04[ooooo00?oo`00ooooooooool0
V_oooolEo`00o`Sooooo0Ol00001ooooo`0000?o0000ooooooooool04oooool00ooo003ooooooooo
o`1<ooooo`03ool00?oooooooooo09Wooooo5Ol00?l8ooooo`7o00000Oooool00003o`000?oooooo
oooo017ooooo0_oo001@ooooo`;oo`00VOoooolEo`00o`Sooooo0Ol00001ooooo`0000?o0000oooo
ooooool04?ooool00ooo003oooooooooo`1Booooo`;oo`00UooooolEo`00o`Sooooo0Ol00001oooo
o`0000?o0000ooooooooool03oooool00ooo003oooooooooo`1Eooooo`03ool00?oooooooooo09Co
oooo5Ol00?l8ooooo`7o00000Oooool00003o`000?oooooooooo00kooooo00?oo`00ooooooooool0
E_ooool00ooo003oooooooooo`2DoooooaGo003o2?ooool1o`00007ooooo00000ol0003ooooooooo
o`0=ooooo`03ool00?oooooooooo05Sooooo00?oo`00ooooooooool0TooooolEo`00o`Sooooo0Ol0
0001ooooo`0000?o0000ooooooooool03Oooool00ooo003oooooooooo`1Iooooo`03ool00?oooooo
oooo09;ooooo5Ol00?l8ooooo`7o00000Oooool00003o`000?oooooooooo00cooooo00?oo`00oooo
ooooool0Foooool00ooo003oooooooooo`2AoooooaGo003o2?ooool1o`00007ooooo00000ol0003o
ooooooooo`0;ooooo`03ool00?oooooooooo05gooooo00?oo`00ooooooooool0T?oooolEo`00o`So
oooo0Ol00001ooooo`0000?o0000ooooooooool02oooool00ooo003oooooooooo`1Mooooo`03ool0
0?oooooooooo093ooooo5Ol00?l8ooooo`7o00000Oooool00003o`000?oooooooooo00[ooooo00?o
o`00ooooooooool0Goooool00ooo003oooooooooo`2?oooooaGo003o2?ooool1o`00007ooooo0000
0ol0003oooooooooo`09ooooo`03ool00?oooooooooo067ooooo00?oo`00ooooooooool0S_oooolE
o`00o`Sooooo0Ol00001ooooo`0000?o0000ooooooooool02?ooool00ooo003oooooooooo`1Soooo
o`03ool00?oooooooooo08gooooo5Ol00?l8ooooo`7o00000Oooool00003o`000?oooooooooo00Oo
oooo00?oo`00ooooooooool0IOooool00ooo003oooooooooo`2<oooooaGo003o2?ooool1o`00007o
oooo00000ol0003oooooooooo`06ooooo`03ool00?oooooooooo06Oooooo00?oo`00ooooooooool0
RooooolEo`00o`Sooooo0Ol00001ooooo`0000?o0000ooooooooool01Oooool00ooo003ooooooooo
o`1Yooooo`03ool00?oooooooooo08[ooooo5Ol00?l8ooooo`7o00000Oooool00003o`000?oooooo
oooo00Gooooo00?oo`00ooooooooool0JOooool00ooo003oooooooooo`2:oooooaGo003o2?ooool1
o`00007ooooo00000ol0003oooooooooo`04ooooo`03ool00?oooooooooo06_ooooo00?oo`00oooo
ooooool0ROoooolEo`00o`Sooooo0Ol00001ooooo`0000?o0000ooooooooool00oooool00ooo003o
ooooooooo`1/ooooo`03ool00?oooooooooo08Wooooo5Ol00?l8ooooo`7o00000Oooool00003o`00
0?oooooooooo00?ooooo00?oo`00ooooooooool0KOooool00ooo003oooooooooo`28oooooaGo003o
2?ooool1o`00007ooooo00000ol0003oooooooooo`02ooooo`03ool00?oooooooooo06kooooo00?o
o`00ooooooooool0R?oooolEo`00o`Sooooo0Ol00001ooooo`0000?o0000ooooooooool00_ooool0
0ooo003oooooooooo`1_ooooo`03ool00?oooooooooo08Oooooo5Ol00?l8ooooo`7o00000Oooool0
0005o`000?oooooooooooooooooo0000L_ooool00ooo003oooooooooo`27oooooaGo003o2?ooool1
o`00007ooooo00001?l0003ooooooooooooo001dooooo`03ool00?oooooooooo08Kooooo5Ol00?l8
ooooo`7o00000Oooool00004o`000?ooooooooooool007Gooooo00?oo`00ooooooooool0QOoooolE
o`00o`Sooooo0Ol00001ooooo`0000?o0000oooooooo0000M_ooool00ooo003oooooooooo`25oooo
oaGo003o2?ooool1o`00007ooooo00000ol0003oooooool00006ooooo`;oogl0Koooool00ooo003o
ooooooooo`24oooooaGo003o2?ooool1o`00007ooooo00000ol0003oooooool00005ooooo`Coogl0
4oooool2oomo05Wooooo00?oo`00ooooooooool0Q?oooolEo`00o`Sooooo0Ol00001ooooo`0000?o
0000ool00?ooool01Oooool4oomo01;ooooo1?ooO`0Booooo`;oogl0A?ooool00ooo003ooooooooo
o`24oooooaGo003o2?ooool1o`00007ooooo00000ol0003oooooooooo`05ooooo`?oogl04oooool4
oomo017ooooo1?ooO`14ooooo`03ool00?oooooooooo08?ooooo5Ol00?l8ooooo`7o00000Oooool0
0003o`000?oooooooooo00Cooooo1?ooO`0Dooooo`;oogl04_ooool4oomo04Cooooo00?oo`00oooo
ooooool0PooooolEo`00o`Sooooo0Ol00001ooooo`0000?o0000ooooooooool01?ooool4oomo02Wo
oooo0_ooO`15ooooo`03ool00?oooooooooo08?ooooo5Ol00?l8ooooo`7o00000Oooool00003o`00
0?oooooooooo00Gooooo0_ooO`1FoooooaKo003o1Oooool00ooo003oooooooooo`23oooooaGo003o
2?ooool1o`00007ooooo00000ol0003oooooooooo`1Jooooo`?o003o5_ooool6o`00o`03ool00?oo
oooooooo08;ooooo5Ol00?l8ooooo`7o00000Oooool00003o`000?oooooooooo05Oooooo0ol00?lO
ooooo`?o003oP_oooolEo`00o`Sooooo0Ol00001ooooo`0000?o0000ooooooooool0E?ooool3o`00
ob;ooooo00?oo`00ooooooooool00ol00?mooooooaGo003o2?ooool1o`00007ooooo00000ol0003o
ooooooooo`1Aooooo`?o003o9Oooool00ooo003oooooooooo`03ooooo`?o003oO?oooolEo`00o`So
oooo0Ol00001ooooo`0000?o0000ooooooooool0Coooool20000obWooooo00?oo`00ooooooooool0
1Oooool3o`00ogWooooo5Ol00?l8ooooo`7o00000Oooool00003o`000?oooooooooo04gooooo0P00
0?l[ooooo`03ool00?oooooooooo00Sooooo0_l00?mgoooooaGo003o2?ooool1o`00007ooooo0000
0ol0003oooooooooo`1:ooooo`<0003o;Oooool00ooo003oooooooooo`0:ooooo`;o003oMOoooolE
o`00o`Sooooo0Ol00001ooooo`0000?o0000ooooooooool0B?ooool20000oc3ooooo00?oo`00oooo
ooooool03?ooool00ol00?ooooooooooo`1boooooaGo003o2?ooool1o`00007ooooo00000ol0003o
ooooooooo`17ooooo`030000oooooooooooo033ooooo00?oo`00ooooooooool03Oooool2o`00og;o
oooo5Ol00?l8ooooo`7o00000Oooool00003o`000?oooooooooo04Gooooo0P000?ldooooo`03ool0
0?oooooooooo00kooooo0_l00?m`oooooaGo003o2?ooool1o`00007ooooo00000ol0003ooooooooo
o`14ooooo`030000oooooooooooo03Cooooo00?oo`00ooooooooool04?ooool2o`00ofkooooo5Ol0
0?l8ooooo`7o00000Oooool00003o`000?oooooooooo02Cooooo0_ooO`0:ooooo`;oogl04Oooool0
0`000?ooooooooooo`0eooooo`03ool00?oooooooooo01;ooooo00?o003oooooooooool0JooooolE
o`00o`Sooooo0Ol00001ooooo`0000?o0000ooooooooool08oooool4oomo00Sooooo1?ooO`0?oooo
o`030000oooooooooooo03Kooooo00?oo`00ooooooooool04oooool00ol00?ooooooooooo`1Zoooo
oaGo003o2?ooool1o`00007ooooo00000ol0003oooooooooo`0Sooooo`Coogl02?ooool4oomo00go
oooo00<0003oo`00ooooool0>?ooool00ooo003oooooooooo`0Dooooo`03o`00oooooooooooo06Wo
oooo5Ol00?l8ooooo`7o00000Oooool00003o`000?oooooooooo02Cooooo0_ooO`0:ooooo`;oogl0
3Oooool00`000?ooooooooooo`0iooooo`03ool00?oooooooooo01Gooooo00?o003oooooooooool0
J?oooolEo`00o`Sooooo0Ol00001ooooo`0000?o0000ooooooooool0>Oooool4ool00003ooooo`00
0?oooooo03_ooooo00?oo`00ooooooooool05_ooool00ol00?ooooooooooo`1WoooooaGo003o2?oo
ool1o`00007ooooo00000ol0003oooooooooo`0hooooo`Koo`00?Oooool00ooo003oooooooooo`0G
ooooo`03o`00oooooooooooo06Kooooo5Ol00?l8ooooo`7o00000Oooool00003o`000?oooooooooo
03Oooooo2?oo000@ooooo`;oogl01oooool2oomo02;ooooo00?oo`00ooooooooool05oooool00ol0
0?ooooooooooo`1UoooooaGo003o2?ooool1o`00007ooooo00000ol0003oooooooooo`0^ooooo`;o
ogl01oooool8ool000oooooo1?ooO`05ooooo`Coogl08Oooool00ooo003oooooooooo`0Hooooo`03
o`00oooooooooooo06Cooooo5Ol00?l8ooooo`7o00000Oooool00003o`000?oooooooooo02gooooo
1?ooO`06ooooo`Soo`003oooool4oomo00Gooooo1?ooO`0Qooooo`03ool00?oooooooooo01Wooooo
00?o003oooooooooool0HooooolEo`00o`Sooooo0Ol00001ooooo`0000?o0000ooooooooool0;Ooo
ool4oomo00Kooooo2?oo000@ooooo`;oogl01oooool3oomo027ooooo00?oo`00ooooooooool06_oo
ool00ol00?ooooooooooo`1RoooooaGo003o2?ooool1o`00007ooooo00000ol0003oooooooooo`0^
ooooo`;oogl02?ooool6ool001[ooooo1?ooO`0Pooooo`03ool00?oooooooooo01_ooooo00?o003o
ooooooooool0HOoooolEo`00o`Sooooo0Ol00001ooooo`0000?o0000ooooooooool0>?ooool00`00
0?ooo`00ool00002ool001_ooooo1?ooO`0Pooooo`03ool00?oooooooooo01cooooo00?o003ooooo
ooooool0H?oooolEo`00o`Sooooo0Ol00001ooooo`0000?o0000ooooooooool0=oooool00`000?oo
ooooooooo`0Iooooo`;oogl01?ooool2oomo027ooooo00?oo`00ooooooooool07?ooool00ol00?oo
ooooooooo`1PoooooaGo003o2?ooool1o`00007ooooo00000ol0003oooooooooo`0fooooo`030000
oooooooooooo01Wooooo1?ooO`0Uooooo`03ool00?oooooooooo01kooooo00?o003oooooooooool0
GooooolEo`00o`Sooooo0Ol00001ooooo`0000?o0000ooooooooool0=_ooool00`000?oooooooooo
o`0Iooooo`Coogl09Oooool00ooo003oooooooooo`0Oooooo`03o`00oooooooooooo05kooooo5Ol0
0?l8ooooo`7o00000Oooool00003o`000?oooooooooo03Gooooo00@0003oooooooooO`3oogl06_oo
ool2oomo02Kooooo00?oo`00ooooooooool08?ooool00ol00?ooooooooooo`1MoooooaGo003o2?oo
ool1o`00007ooooo00000ol0003oooooooooo`0dooooo`030000ooooooooogl000?oogl0@Oooool0
0ooo003oooooooooo`0Qooooo`03o`00oooooooooooo07Wooooo0Ol00001ooooo`0000?o0000oooo
ooooool0:oooool2oomo00Kooooo00<0003oooooooooool01?ooO`11ooooo`03ool00?oooooooooo
027ooooo00?o003oooooooooool0NOooool1o`00007ooooo00000ol0003oooooooooo`0Zooooo`Co
ogl01?ooool00`000?ooooooooooo`02ooooo`;oogl06?ooool2oomo017ooooo0_ooO`0Eooooo`03
ool00?oooooooooo02;ooooo00?o003oooooooooool0N?ooool1o`00007ooooo00000ol0003ooooo
ooooo`0Zooooo`Coogl01?ooool00`000?ooooooooooo`0Kooooo`Coogl03oooool4oomo01Cooooo
00?oo`00ooooooooool08oooool00ol00?ooooooooooo`1gooooo`7o00000Oooool00003o`000?oo
oooooooo02_ooooo0_ooO`04ooooo`030000oooooooooooo01cooooo1?ooO`0?ooooo`Coogl05?oo
ool00ooo003oooooooooo`0Sooooo`03o`00oooooooooooo07Oooooo0Ol00001ooooo`0000?o0000
ooooooooool0<Oooool00`000?ooooooooooo`0Mooooo`;oogl04Oooool2oomo01Cooooo00?oo`00
ooooooooool09Oooool00ol00?ooooooooooo`1fooooo`7o00000Oooool00003o`000?oooooooooo
033ooooo00<0003oooooooooool0Aoooool00ooo003oooooooooo`0Uooooo`03o`00oooooooooooo
07Kooooo0Ol00001ooooo`0000?o0000ooooooooool0<?ooool00`000?ooooooooooo`17ooooo`03
ool00?oooooooooo02Kooooo00?o003oooooooooool0MOooool1o`00007ooooo00000ol0003ooooo
ooooo`0_ooooo`030000oooooooooooo04Sooooo00?oo`00ooooooooool09oooool00ol00?oooooo
ooooo`1dooooo`7o00000Oooool00003o`000?oooooooooo02oooooo00<0003oooooooooool01ooo
ool2oomo00;ooooo0_ooO`0kooooo`03ool00?oooooooooo02Oooooo00?o003oooooooooool0M?oo
ool1o`00007ooooo00000ol0003oooooooooo`0^ooooo`030000oooooooooooo00Oooooo2?ooO`0i
ooooo`03ool00?oooooooooo02Wooooo00?o003oooooooooool0Loooool1o`00007ooooo00000ol0
003oooooooooo`0^ooooo`030000oooooooooooo00Oooooo2?ooO`0iooooo`03ool00?oooooooooo
02Wooooo00?o003oooooooooool0Loooool1o`00007ooooo00000ol0003oooooooooo`0]ooooo`03
0000oooooooooooo00Wooooo1_ooO`0Pooooo`;oogl05oooool00ooo003oooooooooo`0[ooooo`03
o`00oooooooooooo07;ooooo0Ol00001ooooo`0000?o0000ooooooooool0;Oooool00`000?oooooo
ooooo`0;ooooo`Coogl07oooool4oomo01Kooooo00?oo`00ooooooooool0:oooool00ol00?oooooo
ooooo`1booooo`7o00000Oooool00003o`000?oo003ooooo02gooooo00<0003oooooooooool03?oo
ool2oomo023ooooo1?ooO`0Fooooo`03ool00?oooooooooo02_ooooo00?o003oooooooooool0L_oo
ool1o`00007ooooo00000ol0003oo`00ooooo`0/ooooo`030000oooooooooooo033ooooo0_ooO`0F
ooooo`03ool00?oooooooooo02gooooo00?o003oooooooooool0LOooool1o`00007ooooo00000ol0
003oo`00ooooo`0/ooooo`030000oooooooooooo04Sooooo00?oo`00ooooooooool0;Oooool00ol0
0?ooooooooooo`1aooooo`7o00000Oooool00003o`000?ooooooo`0002cooooo00<0003ooooooooo
ool0B?ooool00ooo003oooooooooo`0]ooooo`03o`00oooooooooooo077ooooo0Ol00001ooooo`00
00?o0000oooooooo0000:oooool00`000?ooooooooooo`18ooooo`03ool00?oooooooooo02oooooo
00?o003oooooooooool0L?ooool1o`00007ooooo00001?l0003ooooooooooooo000Zooooo`030000
oooooooooooo00?ooooo0_ooO`13ooooo`03ool00?oooooooooo02oooooo00?o003oooooooooool0
L?ooool1o`00007ooooo00001?l0003ooooooooooooo000Zooooo`030000oooooooooooo00;ooooo
1?ooO`12ooooo`03ool00?oooooooooo02oooooo00?o003oooooooooool0L?ooool1o`00007ooooo
00001Ol0003oooooooooooooooooo`0002Wooooo00<0003oooooooooool00_ooool4oomo047ooooo
00?oo`00ooooooooool0<?ooool00ol00?ooooooooooo`1`ooooo`7o00000Oooool00005o`000?oo
oooooooooooooooo0000:?ooool00`000?ooooooooooo`04ooooo`;oogl0@_ooool00ooo003ooooo
ooooo`0aooooo`03o`00oooooooooooo06oooooo0Ol00001ooooo`0000?o0000ooooooooool00_oo
ool00ooo003oooooooooo`0Uooooo`030000oooooooooooo04Oooooo00?oo`00ooooooooool0<_oo
ool00ol00?ooooooooooo`1_ooooo`7o00000Oooool00003o`000?oooooooooo00;ooooo00?oo`00
ooooooooool09Oooool00`000?ooooooooooo`17ooooo`03ool00?oooooooooo03;ooooo00?o003o
ooooooooool0Koooool1o`00007ooooo00000ol0003oooooooooo`03ooooo`03ool00?oooooooooo
02Cooooo00<0003oooooooooool0A_ooool00ooo003oooooooooo`0cooooo`03o`00oooooooooooo
06oooooo0Ol00001ooooo`0000?o0000ooooooooool01?ooool00ooo003oooooooooo`0Sooooo`03
0000oooooooooooo04Gooooo00?oo`00ooooooooool0=?ooool00ol00?ooooooooooo`1_ooooo`7o
00000Oooool00003o`000?oooooooooo00Gooooo00?oo`00ooooooooool08Oooool00`000?oooooo
ooooo`15ooooo`03ool00?oooooooooo03Kooooo00?o003oooooooooool0K_ooool1o`00007ooooo
00000ol0003oooooooooo`06ooooo`03ool00?oooooooooo023ooooo00<0003oooooooooool0AOoo
ool00ooo003oooooooooo`09ooooo`;oogl0:oooool00ol00?ooooooooooo`1^ooooo`7o00000Ooo
ool00003o`000?oooooooooo00Kooooo00?oo`00ooooooooool08?ooool00`000?ooooooooooo`14
ooooo`03ool00?oooooooooo00Wooooo1?ooO`0Zooooo`03o`00oooooooooooo06kooooo0Ol00001
ooooo`0000?o0000ooooooooool01oooool00ooo003oooooooooo`0Oooooo`030000oooooooooooo
02Sooooo0_ooO`0Iooooo`03ool00?oooooooooo00[ooooo1?ooO`0Zooooo`03o`00oooooooooooo
06kooooo0Ol00001ooooo`0000?o0000ooooooooool01oooool00ooo003oooooooooo`0Oooooo`03
0000oooooooooooo02Oooooo1?ooO`0Gooooo`03ool00?oooooooooo00cooooo0_ooO`0[ooooo`03
o`00oooooooooooo06kooooo0Ol00001ooooo`0000?o0000ooooooooool02?ooool00ooo003ooooo
ooooo`0Nooooo`030000oooooooooooo02Oooooo1?ooO`0Gooooo`03ool00?oooooooooo03Wooooo
00?o003oooooooooool0K_ooool1o`00007ooooo00000ol0003oooooooooo`09ooooo`03ool00?oo
oooooooo01gooooo00<0003oooooooooool0:?ooool2oomo01;ooooo1?l00?l00oooooooo`00oooo
o`0kooooo`03o`00oooooooooooo06kooooo0Ol00001ooooo`0000?o0000ooooooooool02_ooool0
0ooo003oooooooooo`0Looooo`030000oooooooooooo03_ooooo1_l00?lmooooo`03o`00oooooooo
oooo06kooooo0Ol00001ooooo`0000?o0000ooooooooool02oooool00ooo003oooooooooo`0Koooo
o`030000oooooooooooo03Oooooo0_ooO`000ooooooo003oo`00o`06o`00occooooo00?o003ooooo
ooooool0K_ooool1o`00007ooooo00000ol0003oooooooooo`0<ooooo`03ool00?oooooooooo01[o
oooo00<0003oooooooooool0=_ooool4oomo00So003o??ooool00ol00?ooooooooooo`1^ooooo`7o
00000Oooool00003o`000?oooooooooo00gooooo00?oo`00ooooooooool06Oooool00`000?oooooo
ooooo`0fooooo`Coogl02?l00?llooooo`03o`00oooooooooooo06kooooo0Ol00001ooooo`0000?o
0000ooooooooool03Oooool2ool001[ooooo00<0003oooooooooool0=oooool2oomo0003ooooool0
0?oo003o00Ko003o??ooool00ol00?ooooooooooo`1^ooooo`7o00000Oooool00003o`000?oooooo
oooo00oooooo00?oo`00ooooooooool05oooool00`000?ooooooooooo`0jooooo`03ool00?l00?oo
003o00Co003o?Oooool00ol00?ooooooooooo`1^ooooo`7o00000Oooool00003o`000?oooooooooo
013ooooo00?oo`00ooooooooool05_ooool00`000?ooooooooooo`0iooooo`03ool00?oooooooooo
00Co003o?_ooool00ol00?ooooooooooo`1^ooooo`7o00000Oooool00003o`000?oooooooooo017o
oooo00?oo`00ooooooooool05Oooool00`000?ooooooooooo`0hooooo`03ool00?oooooooooo04?o
oooo00?o003oooooooooool0K_ooool1o`00007ooooo00000ol0003oooooooooo`0Booooo`03ool0
0?oooooooooo01Cooooo00<0003oooooooooool0=_ooool2ool004Kooooo00?o003oooooooooool0
K_ooool1o`00007ooooo00000ol0003oooooooooo`0Cooooo`03ool00?oooooooooo01?ooooo00<0
003oooooooooool0=Oooool00ooo003oooooooooo`16ooooo`03o`00oooooooooooo06kooooo0Ol0
0001ooooo`0000?o0000ooooooooool05?ooool2ool001?ooooo00<0003oooooooooool0=?ooool0
0ooo003oooooooooo`17ooooo`03o`00oooooooooooo06kooooo0Ol00001ooooo`0000?o0000oooo
ooooool05_ooool2ool0017ooooo00<0003oooooooooool0<_ooool2ool004[ooooo00?o003ooooo
ooooool0K_ooool1o`00007ooooo00000ol0003oooooooooo`0Hooooo`03ool00?oooooooooo00ko
oooo00<0003oooooooooool0<Oooool00ooo003oooooooooo`1:ooooo`03o`00oooooooooooo06ko
oooo0Ol00001ooooo`0000?o0000ooooooooool06Oooool2ool000kooooo00<0003oooooooooool0
;oooool2ool004gooooo00?o003oooooooooool0K_ooool1o`00007ooooo00000ol0003ooooooooo
o`0Kooooo`03ool00?oooooooooo00_ooooo00<0003oooooooooool0;_ooool00ooo003ooooooooo
o`1<ooooo`03o`00oooooooooooo06oooooo0Ol00001ooooo`0000?o0000ooooooooool07?ooool2
ool000_ooooo00<0003oooooooooool0;Oooool00ooo003oooooooooo`1=ooooo`03o`00oooooooo
oooo06oooooo0Ol00001ooooo`0000?o0000ooooooooool07_ooool3ool000Wooooo00<0003ooooo
ooooool0:_ooool2ool0053ooooo00?o003oooooooooool0Koooool1o`00007ooooo00000ol0003o
ooooooooo`0Qooooo`;oo`001oooool00`000?ooooooooooo`0Wooooo`?oo`00D_ooool00ol00?oo
ooooooooo`1_ooooo`7o00000Oooool00003o`000?oooooooooo02?ooooo0_oo0005ooooo`030000
oooooooooooo02Gooooo0_oo001Dooooo`03o`00oooooooooooo073ooooo0Ol00001ooooo`0000?o
0000ooooooooool09Oooool4ool00003ooooo`000?oooooo02;ooooo1?oo001Fooooo`03o`00oooo
oooooooo073ooooo0Ol00001ooooo`0000?o0000ooooooooool0:Oooool2ool00003o`00oooo003o
o`0001gooooo0ooo001Jooooo`03o`00oooooooooooo073ooooo0Ol00001ooooo`0000?o0000oooo
ooooool0:oooool00`000?ooooooooooo`03ool001Cooooo1_oo001Mooooo`03o`00oooooooooooo
073ooooo0Ol00001ooooo`0000?o0000ooooooooool0;?ooool00`000?ooooooooooo`02oooooaCo
o`00H_ooool00ol00?ooooooooooo`1aooooo`7o00000Oooool00003o`000?oooooooooo02cooooo
00<0003oooooooooool0N?ooool00ol00?ooooooooooo`1aooooo`7o00000Oooool00003o`000?oo
oooooooo02cooooo00<0003oooooooooool0N?ooool00ol00?ooooooooooo`1aooooo`7o00000Ooo
ool00003o`000?oooooooooo02gooooo00<0003oooooooooool0M_ooool00ol00?ooooooooooo`1b
ooooo`7o00000Oooool00003o`000?oooooooooo02gooooo00<0003oooooooooool0M_ooool00ol0
0?ooooooooooo`1booooo`7o00000Oooool00003o`000?oooooooooo02gooooo00<0003ooooooooo
ool0M_ooool00ol00?ooooooooooo`1booooo`7o00000Oooool00003o`000?oooooooooo02kooooo
00<0003oooooooooool0M?ooool00ol00?ooooooooooo`1cooooo`7o00000Oooool00003o`000?oo
oooooooo02kooooo00<0003oooooooooool0M?ooool00ol00?ooooooooooo`1cooooo`7o00000Ooo
ool00003o`000?oooooooooo02kooooo00<0003oooooooooool0M?ooool00ol00?ooooooooooo`1c
ooooo`7o00000Oooool00003o`000?oooooooooo02oooooo00<0003oooooooooool0L_ooool00ol0
0?ooooooooooo`1dooooo`7o00000Oooool00003o`000?oooooooooo02oooooo00<0003ooooooooo
ool0L_ooool00ol00?ooooooooooo`1dooooo`7o00000Oooool00003o`000?oooooooooo02oooooo
00<0003oooooooooool0L_ooool00ol00?ooooooooooo`1dooooo`7o00000Oooool00003o`000?oo
oooooooo033ooooo00<0003oooooooooool0Koooool2o`00ogOooooo0Ol00001ooooo`0000?o0000
ooooooooool0<?ooool00`000?ooooooooooo`1_ooooo`03o`00oooooooooooo07Kooooo0Ol00001
ooooo`0000?o0000ooooooooool0<Oooool00`000?ooooooooooo`1]ooooo`03o`00oooooooooooo
07Oooooo0Ol00001ooooo`0000?o0000ooooooooool0<_ooool00`000?ooooooooooo`1/ooooo`03
o`00oooooooooooo07Oooooo0Ol00001ooooo`0000?o0000ooooooooool0<_ooool00`000?oooooo
ooooo`1[ooooo`03o`00oooooooooooo063ooooo0_ooO`0Fooooo`7o00000Oooool00003o`000?oo
oooooooo03?ooooo00<0003oooooooooool0JOooool00ol00?ooooooooooo`1Pooooo`Coogl05Ooo
ool1o`00007ooooo00000ol0003oooooooooo`0dooooo`030000oooooooooooo06Sooooo00?o003o
ooooooooool0H?ooool4oomo01Gooooo0Ol00001ooooo`0000?o0000ooooooooool0=Oooool00`00
0?ooooooooooo`1Vooooo`03o`00oooooooooooo06;ooooo0_ooO`0Fooooo`7o00000Oooool00003
o`000?oooooooooo03Gooooo00?o003oooooooooool0I_ooool00ol00?ooooooooooo`1jooooo`7o
00000Oooool00003o`000?oooooooooo03Kooooo00?o003oooooooooool0I?ooool00ol00?oooooo
ooooo`1kooooo`7o00000Oooool00003o`000?oooooooooo03Oooooo00?o003oooooooooool0H_oo
ool00ol00?ooooooooooo`1looooo`7o00000Oooool00003o`000?oooooooooo03Sooooo00?o003o
ooooooooool0Goooool2o`00ogoooooo0Ol00001ooooo`0000?o0000ooooooooool0>Oooool00ol0
0?ooooooooooo`1Mooooo`03o`00oooooooooooo07oooooo0Ol00001ooooo`0000?o0000oooooooo
ool0>_ooool00ol00?ooooooooooo`1Kooooo`03o`00oooooooooooo083ooooo0Ol00001ooooo`00
00?o0000ooooooooool0>oooool00ol00?ooooooooooo`1Iooooo`03o`00oooooooooooo087ooooo
0Ol00001ooooo`0000?o0000ooooooooool0??ooool00ol00?ooooooooooo`1Gooooo`03o`00oooo
oooooooo08;ooooo0Ol00001ooooo`0000?o0000ooooooooool0?Oooool00ol00?ooooooooooo`1E
ooooo`03o`00oooooooooooo08?ooooo0Ol00001ooooo`0000?o0000ooooooooool0?_ooool00ol0
0?ooooooooooo`1Cooooo`03o`00oooooooooooo08Cooooo0Ol00001ooooo`0000?o0000oooooooo
ool0?oooool00ol00?ooooooooooo`1@ooooo`;o003o8Oooool2oomo06Cooooo0Ol00001ooooo`00
00?o0000ooooooooool0@?ooool00ol00?ooooooooooo`1>ooooo`03o`00oooooooooooo023ooooo
1?ooO`1Sooooo`7o00000Oooool00003o`000?oooooooooo047ooooo0_l00?m=ooooo`03o`00oooo
oooooooo027ooooo1?ooO`1Sooooo`7o00000Oooool00003o`000?oooooooooo04?ooooo00?o003o
ooooooooool0BOooool00ol00?ooooooooooo`0Sooooo`;oogl0=Oooool2oomo02gooooo0Ol00001
ooooo`0000?o0000ooooooooool0A?ooool2o`00odSooooo00?o003oooooooooool0Doooool2oomo
00Gooooo1?ooO`0/ooooo`7o00000Oooool00003o`000?oooooooooo04Kooooo0_l00?m5ooooo`03
o`00oooooooooooo05?ooooo1?ooO`04ooooo`Coogl0;?ooool1o`00007ooooo00000ol0003ooooo
ooooo`18ooooo`03o`00oooooooooooo043ooooo0_l00?lfooooo`;oogl07_ooool4oomo00Gooooo
0_ooO`0]ooooo`7o00000Oooool00003o`000?oooooooooo04Wooooo0_l00?lnooooo`;o003o=ooo
ool4oomo01kooooo0_ooO`0eooooo`7o00000Oooool00003o`000?oooooooooo04_ooooo0ol00?lj
ooooo`03o`00oooooooooooo03Oooooo1?ooO`0Nooooo`Goo`3o<_ooool1o`00007ooooo00000ol0
003oooooooooo`1>ooooo`;o003o=_ooool2o`00oc_ooooo0_ooO`0Nooooo`Ooo`3o<Oooool1o`00
007ooooo00000ol0003oooooooooo`1@ooooo`?o003o<?ooool3o`00oc?ooooo0_ooO`0Uooooo`;o
ogl02Ooo0?l`ooooo`7o00000Oooool00003o`000?oooooooooo05?ooooo0_l00?lZooooo`Co003o
=Oooool4oomo02?ooooo0_ooO`0;ool0oboooooo0Ol00001ooooo`0000?o0000ooooooooool0EOoo
ool3o`00ob?ooooo1?l00?leooooo`;oogl00_ooool4oomo02?ooooo0_ooO`0;ool0oboooooo0Ol0
0001ooooo`0000?o0000ooooooooool0F?ooool3o`00oagooooo0ol00?lhooooo`Coogl00_ooool2
oomo01?ooooo0_ooO`0@ooooo`03oomo0?oo0?ooo`3o00Woo`3o;oooool1o`00007ooooo00000ol0
003oooooooooo`1Kooooo`?o003o5?ooool6o`00oc_ooooo1?ooO`06ooooo`;oogl03_ooool4oomo
013ooooo2ooo0?l_ooooo`7o00000Oooool00003o`000?oooooooooo05kooooo5?l00?m2ooooo`;o
ogl01_ooool4oomo00gooooo1?ooO`0@ooooo`_oo`3o;oooool1o`00007ooooo00000ol0003ooooo
ooooo`2;ooooo`;oogl09oooool2oomo00Kooooo1?ooO`0>ooooo`;oogl04_ooool9ool0oc3ooooo
0Ol00001ooooo`0000?o0000ooooooooool0R_ooool4oomo02Gooooo1?ooO`06ooooo`;oogl09?oo
ool7ool0oc7ooooo0Ol00001ooooo`0000?o0000ooooooooool0R_ooool4oomo02Gooooo1?ooO`0]
ooooo`Goo`3o<_ooool1o`00007ooooo00000ol0003oooooooooo`2;ooooo`;oogl09oooool2oomo
06Gooooo0Ol00001ooooo`0000?o0000ooooooooool0U_ooool2oomo03[ooooo0_ooO`17ooooo`7o
00000Oooool00003o`000?oooooooooo09Gooooo1?ooO`0>ooooo`;oogl0:?ooool4oomo04Kooooo
0Ol00001ooooo`0000?o0000ooooooooool0UOooool4oomo00gooooo1?ooO`0Wooooo`Coogl0A_oo
ool1o`00007ooooo00000ol0003oooooooooo`2Fooooo`;oogl03_ooool4oomo02Sooooo0_ooO`17
ooooo`7o00000Oooool00003o`000?oooooooooo0:Oooooo0_ooO`1booooo`7o00000Oooool00003
o`000?oooooooooo0>_ooooo0_ooO`0^ooooo`7o00000Oooool00003o`000?oooooooooo0>[ooooo
1?ooO`0]ooooo`7o00000Oooool00003o`000?oooooooooo0=Kooooo0_ooO`0Booooo`Coogl0;Ooo
ool1o`00007ooooo00000ol0003oooooooooo`3Eooooo`Coogl04_ooool2oomo02kooooo0Ol00001
ooooo`0000?o0000ooooooooool0]oooool2oomo01cooooo1?ooO`12ooooo`7o00000Oooool00003
o`000?oooooooooo0;Kooooo1?ooO`0Looooo`;oogl0@oooool1o`00007ooooo00000ol0003ooooo
ooooo`2cooooo`;oogl000?ooooooomo0?ooO`000_ooO`1Qooooo`7o00000Oooool00003o`000?oo
oooooooo0:Sooooo0_ooO`08ooooo`Coogl000?ooooooomo0?ooO`006_ooool2oomo04Kooooo0Ol0
0001ooooo`0000?o0000ooooooooool0Y_ooool5oomo00Oooooo1?ooO`0Gooooo`;oogl00oooool4
oomo04Gooooo0Ol00001ooooo`0000?o0000ooooooooool0YOooool6oomo00Sooooo0_ooO`0Goooo
o`Coogl00_ooool4oomo04Gooooo0Ol00001ooooo`0000?o0000ooooooooool0YOooool5oomo02;o
oooo1?ooO`03ooooo`;oogl0A_ooool1o`00007ooooo00000ol0003oooooooooo`1fooooo`;oogl0
;_ooool2oomo02Gooooo0_ooO`1<ooooo`7o00000Oooool00003o`000?oooooooooo07Gooooo1?oo
O`2Rooooo`7o00000Oooool00003o`000?oooooooooo07Gooooo1?ooO`0:ooooo`;oogl0U_ooool1
o`00007ooooo00000ol0003oooooooooo`1fooooo`;oogl02_ooool4oomo02[ooooo0_ooO`1Yoooo
o`7o00000Oooool00003o`000?oooooooooo08;ooooo1?ooO`0Yooooo`Coogl0J?ooool1o`00007o
oooo00000ol0003oooooooooo`23ooooo`;oogl09?ooool2oomo00Cooooo1?ooO`1Xooooo`7o0000
0Oooool00003o`000?oooooooooo0:Sooooo1?ooO`04ooooo`;oogl0JOooool1o`00007ooooo0000
0ol0003oooooooooo`2Xooooo`Coogl0Koooool1o`00007ooooo00000ol0003oooooooooo`2Yoooo
o`;oogl0L?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`00
00?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?oo
ool1o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000oooo
ooooool0Q?ooool2oomo09Gooooo0Ol00001ooooo`0000?o0000ooooooooool0Poooool4oomo09Co
oooo0Ol00001ooooo`0000?o0000ooooooooool0Poooool4oomo09Cooooo0Ol00001ooooo`0000?o
0000ooooooooool0Q?ooool2oomo02cooooo0_ooO`1Wooooo`7o00000Oooool00003o`000?oooooo
oooo0;7ooooo1?ooO`1Vooooo`7o00000Oooool00003o`000?oooooooooo0;7ooooo1?ooO`1Voooo
o`7o00000Oooool00003o`000?oooooooooo0;;ooooo0_ooO`1Wooooo`7o00000Oooool00003o`00
0?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol0
0001ooooo`0000?o0000ooooooooool0Noooool2oomo09kooooo0Ol00001ooooo`0000?o0000oooo
ooooool0N_ooool4oomo09gooooo0Ol00001ooooo`0000?o0000ooooooooool0N_ooool4oomo023o
oooo0_ooO`1kooooo`7o00000Oooool00003o`000?oooooooooo07_ooooo0_ooO`0Pooooo`Coogl0
N_ooool1o`00007ooooo00000ol0003oooooooooo`2Mooooo`Coogl0N_ooool1o`00007ooooo0000
0ol0003oooooooooo`2@ooooo`;oogl03?ooool2oomo07_ooooo0Ol00001ooooo`0000?o0000oooo
ooooool0Soooool4oomo08Sooooo0Ol00001ooooo`0000?o0000ooooooooool0Soooool4oomo08So
oooo0Ol00001ooooo`0000?o0000ooooooooool0T?ooool2oomo02?ooooo0_ooO`1Tooooo`7o0000
0Oooool00003o`000?oooooooooo0;Cooooo1?ooO`1Sooooo`7o00000Oooool00003o`000?oooooo
oooo0;Cooooo1?ooO`1Sooooo`7o00000Oooool00003o`000?oooooooooo0;Gooooo0_ooO`1Toooo
o`7o00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003ooooo
ooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Ooo
ool00003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooo
oacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`00
0?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol0
0001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo
0?oooooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`00
00?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?oo
ool1o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000oooo
ooooool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007o
oooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooo
oolLooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0
003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o
00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003ooooooooo
o`3ooooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool0
0003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooooaco
oooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oo
oooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001
ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo0?oo
oooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o
0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1
o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000oooooooo
ool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo
00000ol0003oooooooooo`2>ooooo`;oogl0Roooool1o`00007ooooo00000ol0003oooooooooo`2=
ooooo`Coogl0R_ooool1o`00007ooooo00000ol0003oooooooooo`2=ooooo`Coogl0R_ooool1o`00
007ooooo00000ol0003oooooooooo`2>ooooo`;oogl0Roooool1o`00007ooooo00000ol0003ooooo
ooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Ooo
ool00003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooo
oacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`00
0?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol0
0001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo
0?oooooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`00
00?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?oo
ool1o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000oooo
ooooool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007o
oooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooo
oolLooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0
003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o
00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo003oo`00023o00000Ooo
ool00001\
\>"],
  ImageRangeCache->{{{0, 287}, {287, 0}} -> {-1.01089, -1.01089, 0.00704453, \
0.00704453}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.49505 0.5 0.49505 [
[ 0 0 -0.125 0 ]
[ 0 0 -0.125 0 ]
[ 0 1 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
0 0 m
1 0 L
s
0 0 m
0 1 L
s
0 1 m
1 1 L
s
1 0 m
1 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
1 .5 0 r
.015 w
.03175 .1355 Mdot
.03435 .12523 Mdot
.11137 .12765 Mdot
.14107 .18841 Mdot
.16218 .24538 Mdot
.17294 .21053 Mdot
.18267 .18577 Mdot
.18434 .1304 Mdot
.18553 .30956 Mdot
.20401 .239 Mdot
.21247 .27571 Mdot
.21687 .20845 Mdot
.22376 .2799 Mdot
.22832 .27485 Mdot
.29063 .20974 Mdot
.29686 .25079 Mdot
.30487 .22936 Mdot
.30683 .34623 Mdot
.32055 .20902 Mdot
.32574 .21979 Mdot
.34472 .28521 Mdot
.35998 .36393 Mdot
.36335 .24976 Mdot
.3794 .36608 Mdot
.42386 .66992 Mdot
.44391 .74519 Mdot
.45059 .34198 Mdot
.47208 .67586 Mdot
.47436 .71381 Mdot
.49778 .59825 Mdot
.50874 .91643 Mdot
.51516 .76219 Mdot
.53655 .61374 Mdot
.56563 .75219 Mdot
.59189 .65665 Mdot
.59581 .61604 Mdot
.59923 .6556 Mdot
.60292 .68499 Mdot
.62656 .67779 Mdot
.63555 .72451 Mdot
.63919 .652 Mdot
.64169 .6004 Mdot
.64246 .58611 Mdot
.64496 .54267 Mdot
.64608 .77288 Mdot
.65077 .64308 Mdot
.66065 .57816 Mdot
.67474 .59169 Mdot
.69296 .563 Mdot
.72815 .65902 Mdot
.73169 .58879 Mdot
.74669 .61318 Mdot
.74821 .65474 Mdot
.75963 .63781 Mdot
.79673 .57809 Mdot
.80925 .55852 Mdot
.81525 .58444 Mdot
.83417 .62985 Mdot
.83598 .55526 Mdot
.91595 .49319 Mdot
1 0 0 r
.005 w
.00495 .28842 m
.00628 .29156 L
.01857 .31761 L
.03101 .33781 L
.03525 .34367 L
.05706 .36884 L
.05795 .36972 L
.08312 .39115 L
.08963 .39578 L
.10917 .40763 L
.13523 .41964 L
.14074 .42183 L
.16128 .42794 L
.18734 .43294 L
.21339 .43485 L
.23945 .43375 L
.2655 .42959 L
.29156 .42219 L
.29261 .42183 L
.31761 .41124 L
.34367 .39603 L
.34405 .39578 L
.36972 .37551 L
.37582 .36972 L
.39578 .34724 L
.39849 .34367 L
.41525 .31761 L
.42183 .30485 L
.4275 .29156 L
.436 .2655 L
.44117 .23945 L
.44325 .21339 L
.44232 .18734 L
.43834 .16128 L
.43114 .13523 L
.42183 .11212 L
.42037 .10917 L
.40546 .08312 L
.39578 .06961 L
.38528 .05706 L
.36972 .04137 L
.35758 .03101 L
.34367 .02092 L
.31761 .00569 L
.3162 .00495 L
s
.00495 .12854 m
.01344 .10917 L
.02832 .08312 L
.03101 .07912 L
.04848 .05706 L
.05706 .04802 L
.07619 .03101 L
.08312 .02579 L
.10917 .00934 L
.11742 .00495 L
s
0 0 1 r
.29156 .15739 m
.31761 .14824 L
.34367 .14249 L
.36972 .13986 L
.39578 .14025 L
.42183 .14366 L
.44789 .15025 L
.47394 .16034 L
.47599 .16128 L
.5 .17443 L
.51844 .18734 L
.52606 .19355 L
.54662 .21339 L
.55211 .21962 L
.56712 .23945 L
.57817 .25755 L
.58227 .2655 L
.59322 .29156 L
.60058 .31761 L
.60422 .3392 L
.60471 .34367 L
.6058 .36972 L
.60422 .39297 L
.60387 .39578 L
.59886 .42183 L
.59054 .44789 L
.57848 .47394 L
.57817 .47453 L
.562 .5 L
.55211 .51255 L
.53968 .52606 L
.52606 .53862 L
.50853 .55211 L
.5 .55773 L
.47394 .57183 L
.45901 .57817 L
.44789 .5819 L
.42183 .5885 L
.39578 .59192 L
.36972 .59231 L
.34367 .58968 L
.31761 .58392 L
.29972 .57817 L
.29156 .57477 L
.2655 .56178 L
.25025 .55211 L
.23945 .54409 L
.21914 .52606 L
.21339 .52008 L
.19681 .5 L
Mistroke
.18734 .48608 L
.18031 .47394 L
.16827 .44789 L
.16128 .42714 L
.15996 .42183 L
.15493 .39578 L
.153 .36972 L
.15409 .34367 L
.15823 .31761 L
.16128 .3045 L
.16559 .29156 L
.17653 .2655 L
.18734 .24609 L
.19169 .23945 L
.21221 .21339 L
.21339 .21211 L
.23945 .1881 L
.24041 .18734 L
.2655 .17038 L
.28271 .16128 L
.29156 .15739 L
Mfstroke
1 0 0 r
.03 w
.21687 .20845 Mdot
0 0 1 r
.3794 .36608 Mdot
1 0 0 r
.79703 .00495 m
.79703 .01978 L
.87129 .01978 L
.87129 .00495 L
F
0 0 1 r
.89604 .00495 m
.89604 .23764 L
.9703 .23764 L
.9703 .00495 L
F
1 0 1 r
.04 w
.83417 .62985 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P000182000`400?l00000o`00003ooooooolQ
ooooo`00ool0000Po`00007ooooo00000ol0003oooooooooo`0Mooooo`;oo`00>?ooool3ool00<7o
oooo0Ol00001ooooo`0000?o0000ooooooooool06oooool2ool003gooooo00?oo`00ooooooooool0
Q?oooolEool000Sooooo5Ol00?l8ooooo`7o00000Oooool00003o`000?oooooooooo01[ooooo00?o
o`00ooooooooool0?_ooool2ool008Cooooo5Ooo0008oooooaGo003o2?ooool1o`00007ooooo0000
0ol0003oooooooooo`0Hooooo`;oo`00@oooool00ooo003oooooooooo`21oooooaGoo`002?oooolE
o`00o`Sooooo0Ol00001ooooo`0000?o0000ooooooooool05_ooool2ool004Kooooo00?oo`00oooo
ooooool0P?oooolEool000Sooooo5Ol00?l8ooooo`7o00000Oooool00003o`000?oooooooooo01Go
oooo00?oo`00ooooooooool0Aoooool2ool009gooooo5Ol00?l8ooooo`7o00000Oooool00003o`00
0?oooooooooo01Cooooo00?oo`00ooooooooool0B_ooool00ooo003oooooooooo`2JoooooaGo003o
2?ooool1o`00007ooooo00000ol0003oooooooooo`0Cooooo`03ool00?oooooooooo04cooooo00?o
o`00ooooooooool0VOoooolEo`00o`Sooooo0Ol00001ooooo`0000?o0000ooooooooool04Oooool2
ool0053ooooo0_oo002IoooooaGo003o2?ooool1o`00007ooooo00000ol0003oooooooooo`0@oooo
o`03ool00?oooooooooo05;ooooo0_oo002GoooooaGo003o2?ooool1o`00007ooooo00000ol0003o
ooooooooo`0?ooooo`03ool00?oooooooooo05Gooooo00?oo`00ooooooooool0U?oooolEo`00o`So
oooo0Ol00001ooooo`0000?o0000ooooooooool03_ooool00ooo003oooooooooo`1Fooooo`03ool0
0?oooooooooo09Cooooo5Ol00?l8ooooo`7o00000Oooool00003o`000?oooooooooo00gooooo00?o
o`00ooooooooool0F?ooool00ooo003oooooooooo`2CoooooaGo003o2?ooool1o`00007ooooo0000
0ol0003oooooooooo`0=ooooo`03ool00?oooooooooo05Wooooo00?oo`00ooooooooool0T_oooolE
o`00o`Sooooo0Ol00001ooooo`0000?o0000ooooooooool03?ooool00ooo003oooooooooo`1Koooo
o`03ool00?oooooooooo097ooooo5Ol00?l8ooooo`7o00000Oooool00003o`000?oooooooooo00_o
oooo00?oo`00ooooooooool0GOooool00ooo003oooooooooo`2@oooooaGo003o2?ooool1o`00007o
oooo00000ol0003oooooooooo`0;ooooo`03ool00?oooooooooo05gooooo00?oo`00ooooooooool0
T?oooolEo`00o`Sooooo0Ol00001ooooo`0000?o0000ooooooooool02_ooool00ooo003ooooooooo
o`1Oooooo`03ool00?oooooooooo08oooooo5Ol00?l8ooooo`7o00000Oooool00003o`000?oooooo
oooo00Wooooo00?oo`00ooooooooool0HOooool00ooo003oooooooooo`2>oooooaGo003o2?ooool1
o`00007ooooo00000ol0003oooooooooo`08ooooo`03ool00?oooooooooo06?ooooo00?oo`00oooo
ooooool0SOoooolEo`00o`Sooooo0Ol00001ooooo`0000?o0000ooooooooool01oooool00ooo003o
ooooooooo`1Uooooo`03ool00?oooooooooo08cooooo5Ol00?l8ooooo`7o00000Oooool00003o`00
0?oooooooooo00Kooooo00?oo`00ooooooooool0Ioooool00ooo003oooooooooo`2;oooooaGo003o
2?ooool1o`00007ooooo00000ol0003oooooooooo`05ooooo`03ool00?oooooooooo06Wooooo00?o
o`00ooooooooool0R_oooolEo`00o`Sooooo0Ol00001ooooo`0000?o0000ooooooooool01Oooool0
0ooo003oooooooooo`1Yooooo`03ool00?oooooooooo08[ooooo5Ol00?l8ooooo`7o00000Oooool0
0003o`000?oooooooooo00Cooooo00?oo`00ooooooooool0Joooool00ooo003oooooooooo`29oooo
oaGo003o2?ooool1o`00007ooooo00000ol0003oooooooooo`03ooooo`03ool00?oooooooooo06co
oooo00?oo`00ooooooooool0ROoooolEo`00o`Sooooo0Ol00001ooooo`0000?o0000ooooooooool0
0oooool00ooo003oooooooooo`1]ooooo`03ool00?oooooooooo08Sooooo5Ol00?l8ooooo`7o0000
0Oooool00003o`000?oooooooooo00;ooooo00?oo`00ooooooooool0K_ooool00ooo003ooooooooo
o`28oooooaGo003o2?ooool1o`00007ooooo00000ol0003oooooooooo`02ooooo`03ool00?oooooo
oooo06oooooo00?oo`00ooooooooool0QooooolEo`00o`Sooooo0Ol00001ooooo`0000Go0000oooo
ooooooooooooool0001booooo`03ool00?oooooooooo08Oooooo5Ol00?l8ooooo`7o00000Oooool0
0004o`000?ooooooooooool007Cooooo00?oo`00ooooooooool0Q_oooolEo`00o`Sooooo0Ol00001
ooooo`0000Co0000ooooooooooooo`00MOooool00ooo003oooooooooo`25oooooaGo003o2?ooool1
o`00007ooooo00000ol0003oooooool0001fooooo`03ool00?oooooooooo08Gooooo5Ol00?l8oooo
o`7o00000Oooool00003o`000?ooooooo`0000Kooooo0_ooO`1_ooooo`03ool00?oooooooooo08Co
oooo5Ol00?l8ooooo`7o00000Oooool00003o`000?ooooooo`0000Gooooo1?ooO`0Cooooo`;oogl0
FOooool00ooo003oooooooooo`24oooooaGo003o2?ooool1o`00007ooooo00000ol0003oo`00oooo
o`05ooooo`Coogl04_ooool4oomo01;ooooo0_ooO`14ooooo`03ool00?oooooooooo08Cooooo5Ol0
0?l8ooooo`7o00000Oooool00003o`000?oooooooooo00Gooooo0oooO`0Cooooo`Coogl04Oooool4
oomo04Cooooo00?oo`00ooooooooool0PooooolEo`00o`Sooooo0Ol00001ooooo`0000?o0000oooo
ooooool01?ooool4oomo01Cooooo0_ooO`0Booooo`Coogl0A?ooool00ooo003oooooooooo`23oooo
oaGo003o2?ooool1o`00007ooooo00000ol0003oooooooooo`04ooooo`Coogl0:Oooool2oomo04Go
oooo00?oo`00ooooooooool0PooooolEo`00o`Sooooo0Ol00001ooooo`0000?o0000ooooooooool0
1Oooool2oomo05Kooooo5_l00?l5ooooo`03ool00?oooooooooo08?ooooo5Ol00?l8ooooo`7o0000
0Oooool00003o`000?oooooooooo05[ooooo0ol00?lFooooo`Ko003o00?oo`00ooooooooool0P_oo
oolEo`00o`Sooooo0Ol00001ooooo`0000?o0000ooooooooool0Eoooool3o`00oaoooooo0ol00?n2
oooooaGo003o2?ooool1o`00007ooooo00000ol0003oooooooooo`1Dooooo`?o003o8_ooool00ooo
003oooooooooo`03o`00ogoooooo5Ol00?l8ooooo`7o00000Oooool00003o`000?oooooooooo057o
oooo0ol00?lUooooo`03ool00?oooooooooo00?ooooo0ol00?mloooooaGo003o2?ooool1o`00007o
oooo00000ol0003oooooooooo`1?ooooo`80003o:Oooool00ooo003oooooooooo`05ooooo`?o003o
NOoooolEo`00o`Sooooo0Ol00001ooooo`0000?o0000ooooooooool0COooool20000ob_ooooo00?o
o`00ooooooooool02?ooool2o`00ogOooooo5Ol00?l8ooooo`7o00000Oooool00003o`000?oooooo
oooo04[ooooo0`000?l]ooooo`03ool00?oooooooooo00[ooooo0_l00?meoooooaGo003o2?ooool1
o`00007ooooo00000ol0003oooooooooo`18ooooo`80003o<?ooool00ooo003oooooooooo`0<oooo
o`03o`00oooooooooooo07;ooooo5Ol00?l8ooooo`7o00000Oooool00003o`000?oooooooooo04Oo
oooo00<0003oooooooooool0<?ooool00ooo003oooooooooo`0=ooooo`;o003oL_oooolEo`00o`So
oooo0Ol00001ooooo`0000?o0000ooooooooool0AOooool20000ocCooooo00?oo`00ooooooooool0
3_ooool2o`00og3ooooo5Ol00?l8ooooo`7o00000Oooool00003o`000?oooooooooo04Cooooo00<0
003oooooooooool0=?ooool00ooo003oooooooooo`0@ooooo`;o003oK_oooolEo`00o`Sooooo0Ol0
0001ooooo`0000?o0000ooooooooool09?ooool2oomo00[ooooo0_ooO`0Aooooo`030000oooooooo
oooo03Gooooo00?oo`00ooooooooool04_ooool00ol00?ooooooooooo`1[oooooaGo003o2?ooool1
o`00007ooooo00000ol0003oooooooooo`0Sooooo`Coogl02?ooool4oomo00oooooo00<0003ooooo
ooooool0=_ooool00ooo003oooooooooo`0Cooooo`03o`00oooooooooooo06[ooooo5Ol00?l8oooo
o`7o00000Oooool00003o`000?oooooooooo02?ooooo1?ooO`08ooooo`Coogl03Oooool00`000?oo
003oooooo`0hooooo`03ool00?oooooooooo01Cooooo00?o003oooooooooool0JOoooolEo`00o`So
oooo0Ol00001ooooo`0000?o0000ooooooooool09?ooool2oomo00[ooooo0_ooO`0=ooooo`030000
oooooooooooo03Wooooo00?oo`00ooooooooool05Oooool00ol00?ooooooooooo`1XoooooaGo003o
2?ooool1o`00007ooooo00000ol0003oooooooooo`0iooooo`Coo`0000?ooooo0000ooooool0>ooo
ool00ooo003oooooooooo`0Fooooo`03o`00oooooooooooo06Oooooo5Ol00?l8ooooo`7o00000Ooo
ool00003o`000?oooooooooo03Sooooo1_oo000mooooo`03ool00?oooooooooo01Oooooo00?o003o
ooooooooool0I_oooolEo`00o`Sooooo0Ol00001ooooo`0000?o0000ooooooooool0=oooool8ool0
013ooooo0_ooO`07ooooo`;oogl08_ooool00ooo003oooooooooo`0Gooooo`03o`00oooooooooooo
06Gooooo5Ol00?l8ooooo`7o00000Oooool00003o`000?oooooooooo02kooooo0_ooO`07ooooo`So
o`003oooool4oomo00Gooooo1?ooO`0Qooooo`03ool00?oooooooooo01Sooooo00?o003ooooooooo
ool0I?oooolEo`00o`Sooooo0Ol00001ooooo`0000?o0000ooooooooool0;Oooool4oomo00Kooooo
2?oo000?ooooo`Coogl01Oooool4oomo027ooooo00?oo`00ooooooooool06Oooool00ol00?oooooo
ooooo`1SoooooaGo003o2?ooool1o`00007ooooo00000ol0003oooooooooo`0]ooooo`Coogl01_oo
ool8ool0013ooooo0_ooO`07ooooo`?oogl08Oooool00ooo003oooooooooo`0Jooooo`03o`00oooo
oooooooo06;ooooo5Ol00?l8ooooo`7o00000Oooool00003o`000?oooooooooo02kooooo0_ooO`08
ooooo`Koo`006_ooool4oomo023ooooo00?oo`00ooooooooool06oooool00ol00?ooooooooooo`1Q
oooooaGo003o2?ooool1o`00007ooooo00000ol0003oooooooooo`0hooooo`030000oooo003oo`00
00;oo`006oooool4oomo023ooooo00?oo`00ooooooooool07?ooool00ol00?ooooooooooo`1Poooo
oaGo003o2?ooool1o`00007ooooo00000ol0003oooooooooo`0gooooo`030000oooooooooooo01Wo
oooo0_ooO`04ooooo`;oogl08Oooool00ooo003oooooooooo`0Looooo`03o`00oooooooooooo063o
oooo5Ol00?l8ooooo`7o00000Oooool00003o`000?oooooooooo03Kooooo00<0003oooooooooool0
6Oooool4oomo02Gooooo00?oo`00ooooooooool07_ooool00ol00?ooooooooooo`1OoooooaGo003o
2?ooool1o`00007ooooo00000ol0003oooooooooo`0fooooo`030000oooooooooooo01Wooooo1?oo
O`0Uooooo`03ool00?oooooooooo01oooooo00?o003oooooooooool0G_oooolEo`00o`Sooooo0Ol0
0001ooooo`0000?o0000ooooooooool0=Oooool010000?oooooooomo0?ooO`0Jooooo`;oogl09_oo
ool00ooo003oooooooooo`0Pooooo`03o`00oooooooooooo05gooooo5Ol00?l8ooooo`7o00000Ooo
ool00003o`000?oooooooooo03Cooooo00<0003oooooooooO`000oooO`11ooooo`03ool00?oooooo
oooo027ooooo00?o003oooooooooool0G?oooolEo`00o`Sooooo0Ol00001ooooo`0000?o0000oooo
ooooool0:oooool2oomo00Kooooo00<0003oooooooooool01?ooO`11ooooo`03ool00?oooooooooo
027ooooo00?o003oooooooooool0NOooool1o`00007ooooo00000ol0003oooooooooo`0Zooooo`Co
ogl01?ooool00`000?ooooooooooo`02ooooo`;oogl06?ooool2oomo017ooooo0_ooO`0Eooooo`03
ool00?oooooooooo02;ooooo00?o003oooooooooool0N?ooool1o`00007ooooo00000ol0003ooooo
ooooo`0Zooooo`Coogl01?ooool00`000?ooooooooooo`0Kooooo`Coogl03oooool4oomo01Cooooo
00?oo`00ooooooooool08oooool00ol00?ooooooooooo`1gooooo`7o00000Oooool00003o`000?oo
oooooooo02_ooooo0_ooO`04ooooo`030000oooooooooooo01cooooo1?ooO`0?ooooo`Coogl05?oo
ool00ooo003oooooooooo`0Sooooo`03o`00oooooooooooo07Oooooo0Ol00001ooooo`0000?o0000
ooooooooool0<Oooool00`000?ooooooooooo`0Mooooo`;oogl04Oooool2oomo01Cooooo00?oo`00
ooooooooool09Oooool00ol00?ooooooooooo`1fooooo`7o00000Oooool00003o`000?oooooooooo
033ooooo00<0003oooooooooool0Aoooool00ooo003oooooooooo`0Uooooo`03o`00oooooooooooo
07Kooooo0Ol00001ooooo`0000?o0000ooooooooool0<?ooool00`000?ooooooooooo`17ooooo`03
ool00?oooooooooo02Kooooo00?o003oooooooooool0MOooool1o`00007ooooo00000ol0003ooooo
ooooo`0_ooooo`030000oooooooooooo04Sooooo00?oo`00ooooooooool09oooool00ol00?oooooo
ooooo`1dooooo`7o00000Oooool00003o`000?oooooooooo02oooooo00<0003oooooooooool01ooo
ool2oomo00;ooooo0_ooO`0kooooo`03ool00?oooooooooo02Oooooo00?o003oooooooooool0M?oo
ool1o`00007ooooo00000ol0003oooooooooo`0^ooooo`030000oooooooooooo00Oooooo2?ooO`0i
ooooo`03ool00?oooooooooo02Wooooo00?o003oooooooooool0Loooool1o`00007ooooo00000ol0
003oooooooooo`0^ooooo`030000oooooooooooo00Oooooo2?ooO`0iooooo`03ool00?oooooooooo
02Wooooo00?o003oooooooooool0Loooool1o`00007ooooo00000ol0003oooooooooo`0]ooooo`03
0000oooooooooooo00Wooooo1_ooO`0Pooooo`;oogl05oooool00ooo003oooooooooo`0[ooooo`03
o`00oooooooooooo07;ooooo0Ol00001ooooo`0000?o0000ooooooooool0;Oooool00`000?oooooo
ooooo`0;ooooo`Coogl07oooool4oomo01Kooooo00?oo`00ooooooooool0:oooool00ol00?oooooo
ooooo`1booooo`7o00000Oooool00003o`000?oo003ooooo02gooooo00<0003oooooooooool03?oo
ool2oomo023ooooo1?ooO`0Fooooo`03ool00?oooooooooo02_ooooo00?o003oooooooooool0L_oo
ool1o`00007ooooo00000ol0003oo`00ooooo`0/ooooo`030000oooooooooooo033ooooo0_ooO`0F
ooooo`03ool00?oooooooooo02gooooo00?o003oooooooooool0LOooool1o`00007ooooo00000ol0
003oo`00ooooo`0/ooooo`030000oooooooooooo04Sooooo00?oo`00ooooooooool0;Oooool00ol0
0?ooooooooooo`1aooooo`7o00000Oooool00003o`000?ooooooo`0002cooooo00<0003ooooooooo
ool0B?ooool00ooo003oooooooooo`0]ooooo`03o`00oooooooooooo077ooooo0Ol00001ooooo`00
00?o0000oooooooo0000:oooool00`000?ooooooooooo`18ooooo`03ool00?oooooooooo02oooooo
00?o003oooooooooool0L?ooool1o`00007ooooo00001?l0003ooooooooooooo000Zooooo`030000
oooooooooooo00?ooooo0_ooO`13ooooo`03ool00?oooooooooo02oooooo00?o003oooooooooool0
L?ooool1o`00007ooooo00001?l0003ooooooooooooo000Zooooo`030000oooooooooooo00;ooooo
1?ooO`12ooooo`03ool00?oooooooooo02oooooo00?o003oooooooooool0L?ooool1o`00007ooooo
00001Ol0003oooooooooooooooooo`0002Wooooo00<0003oooooooooool00_ooool4oomo047ooooo
00?oo`00ooooooooool0<?ooool00ol00?ooooooooooo`1`ooooo`7o00000Oooool00005o`000?oo
oooooooooooooooo0000:?ooool00`000?ooooooooooo`04ooooo`;oogl0@_ooool00ooo003ooooo
ooooo`0aooooo`03o`00oooooooooooo06oooooo0Ol00001ooooo`0000?o0000ooooooooool00_oo
ool00ooo003oooooooooo`0Uooooo`030000oooooooooooo04Oooooo00?oo`00ooooooooool0<_oo
ool00ol00?ooooooooooo`1_ooooo`7o00000Oooool00003o`000?oooooooooo00;ooooo00?oo`00
ooooooooool09Oooool00`000?ooooooooooo`17ooooo`03ool00?oooooooooo03;ooooo00?o003o
ooooooooool0Koooool1o`00007ooooo00000ol0003oooooooooo`03ooooo`03ool00?oooooooooo
02Cooooo00<0003oooooooooool0A_ooool00ooo003oooooooooo`0cooooo`03o`00oooooooooooo
06oooooo0Ol00001ooooo`0000?o0000ooooooooool01?ooool00ooo003oooooooooo`0Sooooo`03
0000oooooooooooo04Gooooo00?oo`00ooooooooool0=?ooool00ol00?ooooooooooo`1_ooooo`7o
00000Oooool00003o`000?oooooooooo00Gooooo00?oo`00ooooooooool08Oooool00`000?oooooo
ooooo`15ooooo`03ool00?oooooooooo03Kooooo00?o003oooooooooool0K_ooool1o`00007ooooo
00000ol0003oooooooooo`06ooooo`03ool00?oooooooooo023ooooo00<0003oooooooooool0AOoo
ool00ooo003oooooooooo`09ooooo`;oogl0:oooool00ol00?ooooooooooo`1^ooooo`7o00000Ooo
ool00003o`000?oooooooooo00Kooooo00?oo`00ooooooooool08?ooool00`000?ooooooooooo`14
ooooo`03ool00?oooooooooo00Wooooo1?ooO`0Zooooo`03o`00oooooooooooo06kooooo0Ol00001
ooooo`0000?o0000ooooooooool01oooool00ooo003oooooooooo`0Oooooo`030000oooooooooooo
02Sooooo0_ooO`0Iooooo`03ool00?oooooooooo00[ooooo1?ooO`0Zooooo`03o`00oooooooooooo
06kooooo0Ol00001ooooo`0000?o0000ooooooooool01oooool00ooo003oooooooooo`0Oooooo`03
0000oooooooooooo02Oooooo1?ooO`0Gooooo`03ool00?oooooooooo00cooooo0_ooO`0[ooooo`03
o`00oooooooooooo06kooooo0Ol00001ooooo`0000?o0000ooooooooool02?ooool00ooo003ooooo
ooooo`0Nooooo`030000oooooooooooo02Oooooo1?ooO`0Gooooo`03ool00?oooooooooo03Wooooo
00?o003oooooooooool0K_ooool1o`00007ooooo00000ol0003oooooooooo`09ooooo`03ool00?oo
oooooooo01gooooo00<0003oooooooooool0:?ooool2oomo01;ooooo1?l00?l00oooooooo`00oooo
o`0kooooo`03o`00oooooooooooo06kooooo0Ol00001ooooo`0000?o0000ooooooooool02_ooool0
0ooo003oooooooooo`0Looooo`030000oooooooooooo03_ooooo1_l00?lmooooo`03o`00oooooooo
oooo06kooooo0Ol00001ooooo`0000?o0000ooooooooool02oooool00ooo003oooooooooo`0Koooo
o`030000oooooooooooo03Oooooo0_ooO`000ooooooo003oo`00o`06o`00occooooo00?o003ooooo
ooooool0K_ooool1o`00007ooooo00000ol0003oooooooooo`0<ooooo`03ool00?oooooooooo01[o
oooo00<0003oooooooooool0=_ooool4oomo00So003o??ooool00ol00?ooooooooooo`1^ooooo`7o
00000Oooool00003o`000?oooooooooo00gooooo00?oo`00ooooooooool06Oooool00`000?oooooo
ooooo`0fooooo`Coogl02?l00?llooooo`03o`00oooooooooooo06kooooo0Ol00001ooooo`0000?o
0000ooooooooool03Oooool2ool001[ooooo00<0003oooooooooool0=oooool2oomo0003ooooool0
0?oo003o00Ko003o??ooool00ol00?ooooooooooo`1^ooooo`7o00000Oooool00003o`000?oooooo
oooo00oooooo00?oo`00ooooooooool05oooool00`000?ooooooooooo`0jooooo`03ool00?l00?oo
003o00Co003o?Oooool00ol00?ooooooooooo`1^ooooo`7o00000Oooool00003o`000?oooooooooo
013ooooo00?oo`00ooooooooool05_ooool00`000?ooooooooooo`0iooooo`03ool00?oooooooooo
00Co003o?_ooool00ol00?ooooooooooo`1^ooooo`7o00000Oooool00003o`000?oooooooooo017o
oooo00?oo`00ooooooooool05Oooool00`000?ooooooooooo`0hooooo`03ool00?oooooooooo04?o
oooo00?o003oooooooooool0K_ooool1o`00007ooooo00000ol0003oooooooooo`0Booooo`03ool0
0?oooooooooo01Cooooo00<0003oooooooooool0=_ooool2ool004Kooooo00?o003oooooooooool0
K_ooool1o`00007ooooo00000ol0003oooooooooo`0Cooooo`03ool00?oooooooooo01?ooooo00<0
003oooooooooool0=Oooool00ooo003oooooooooo`16ooooo`03o`00oooooooooooo06kooooo0Ol0
0001ooooo`0000?o0000ooooooooool05?ooool2ool001?ooooo00<0003oooooooooool0=?ooool0
0ooo003oooooooooo`17ooooo`03o`00oooooooooooo06kooooo0Ol00001ooooo`0000?o0000oooo
ooooool05_ooool2ool0017ooooo00<0003oooooooooool0<_ooool2ool004[ooooo00?o003ooooo
ooooool0K_ooool1o`00007ooooo00000ol0003oooooooooo`0Hooooo`03ool00?oooooooooo00ko
oooo00<0003oooooooooool0<Oooool00ooo003oooooooooo`1:ooooo`03o`00oooooooooooo06ko
oooo0Ol00001ooooo`0000?o0000ooooooooool06Oooool2ool000kooooo00<0003oooooooooool0
;oooool2ool004gooooo00?o003oooooooooool0K_ooool1o`00007ooooo00000ol0003ooooooooo
o`0Kooooo`03ool00?oooooooooo00_ooooo00<0003oooooooooool0;_ooool00ooo003ooooooooo
o`1<ooooo`03o`00oooooooooooo06oooooo0Ol00001ooooo`0000?o0000ooooooooool07?ooool2
ool000_ooooo00<0003oooooooooool0;Oooool00ooo003oooooooooo`1=ooooo`03o`00oooooooo
oooo06oooooo0Ol00001ooooo`0000?o0000ooooooooool07_ooool3ool000Wooooo00<0003ooooo
ooooool0:_ooool2ool0053ooooo00?o003oooooooooool0Koooool1o`00007ooooo00000ol0003o
ooooooooo`0Qooooo`;oo`001oooool00`000?ooooooooooo`0Wooooo`?oo`00D_ooool00ol00?oo
ooooooooo`1_ooooo`7o00000Oooool00003o`000?oooooooooo02?ooooo0_oo0005ooooo`030000
oooooooooooo02Gooooo0_oo001Dooooo`03o`00oooooooooooo073ooooo0Ol00001ooooo`0000?o
0000ooooooooool09Oooool4ool00003ooooo`000?oooooo02;ooooo1?oo001Fooooo`03o`00oooo
oooooooo073ooooo0Ol00001ooooo`0000?o0000ooooooooool0:Oooool2ool00003o`00oooo003o
o`0001gooooo0ooo001Jooooo`03o`00oooooooooooo073ooooo0Ol00001ooooo`0000?o0000oooo
ooooool0:oooool00`000?ooooooooooo`03ool001Cooooo1_oo001Mooooo`03o`00oooooooooooo
073ooooo0Ol00001ooooo`0000?o0000ooooooooool0;?ooool00`000?ooooooooooo`02oooooaCo
o`00H_ooool00ol00?ooooooooooo`1aooooo`7o00000Oooool00003o`000?oooooooooo02cooooo
00<0003oooooooooool0N?ooool00ol00?ooooooooooo`1aooooo`7o00000Oooool00003o`000?oo
oooooooo02cooooo00<0003oooooooooool0N?ooool00ol00?ooooooooooo`1aooooo`7o00000Ooo
ool00003o`000?oooooooooo02gooooo00<0003oooooooooool0M_ooool00ol00?ooooooooooo`1b
ooooo`7o00000Oooool00003o`000?oooooooooo02gooooo00<0003oooooooooool0M_ooool00ol0
0?ooooooooooo`1booooo`7o00000Oooool00003o`000?oooooooooo02gooooo00<0003ooooooooo
ool0M_ooool00ol00?ooooooooooo`1booooo`7o00000Oooool00003o`000?oooooooooo02kooooo
00<0003oooooooooool0M?ooool00ol00?ooooooooooo`1cooooo`7o00000Oooool00003o`000?oo
oooooooo02kooooo00<0003oooooooooool0M?ooool00ol00?ooooooooooo`1cooooo`7o00000Ooo
ool00003o`000?oooooooooo02kooooo00<0003oooooooooool0M?ooool00ol00?ooooooooooo`1c
ooooo`7o00000Oooool00003o`000?oooooooooo02oooooo00<0003oooooooooool0L_ooool00ol0
0?ooooooooooo`1dooooo`7o00000Oooool00003o`000?oooooooooo02oooooo00<0003ooooooooo
ool0L_ooool00ol00?ooooooooooo`1dooooo`7o00000Oooool00003o`000?oooooooooo02oooooo
00<0003oooooooooool0L_ooool00ol00?ooooooooooo`1dooooo`7o00000Oooool00003o`000?oo
oooooooo033ooooo00<0003oooooooooool0Koooool2o`00ogOooooo0Ol00001ooooo`0000?o0000
ooooooooool0<?ooool00`000?ooooooooooo`1_ooooo`03o`00oooooooooooo07Kooooo0Ol00001
ooooo`0000?o0000ooooooooool0<Oooool00`000?ooooooooooo`1]ooooo`03o`00oooooooooooo
07Oooooo0Ol00001ooooo`0000?o0000ooooooooool0<_ooool00`000?ooooooooooo`1/ooooo`03
o`00oooooooooooo07Oooooo0Ol00001ooooo`0000?o0000ooooooooool0<_ooool00`000?oooooo
ooooo`1[ooooo`03o`00oooooooooooo063ooooo0_ooO`0Fooooo`7o00000Oooool00003o`000?oo
oooooooo03?ooooo00<0003oooooooooool0JOooool00ol00?ooooooooooo`1Pooooo`Coogl05Ooo
ool1o`00007ooooo00000ol0003oooooooooo`0dooooo`030000oooooooooooo06Sooooo00?o003o
ooooooooool0H?ooool4oomo01Gooooo0Ol00001ooooo`0000?o0000ooooooooool0=Oooool00`00
0?ooooooooooo`1Vooooo`03o`00oooooooooooo06;ooooo0_ooO`0Fooooo`7o00000Oooool00003
o`000?oooooooooo03Gooooo00?o003oooooooooool0I_ooool00ol00?ooooooooooo`1jooooo`7o
00000Oooool00003o`000?oooooooooo03Kooooo00?o003oooooooooool0I?ooool00ol00?oooooo
ooooo`1kooooo`7o00000Oooool00003o`000?oooooooooo03Oooooo00?o003oooooooooool0H_oo
ool00ol00?ooooooooooo`1looooo`7o00000Oooool00003o`000?oooooooooo03Sooooo00?o003o
ooooooooool0Goooool2o`00ogoooooo0Ol00001ooooo`0000?o0000ooooooooool0>Oooool00ol0
0?ooooooooooo`1Mooooo`03o`00oooooooooooo07oooooo0Ol00001ooooo`0000?o0000oooooooo
ool0>_ooool00ol00?ooooooooooo`1Kooooo`03o`00oooooooooooo083ooooo0Ol00001ooooo`00
00?o0000ooooooooool0>oooool00ol00?ooooooooooo`1Iooooo`03o`00oooooooooooo087ooooo
0Ol00001ooooo`0000?o0000ooooooooool0??ooool00ol00?ooooooooooo`1Gooooo`03o`00oooo
oooooooo08;ooooo0Ol00001ooooo`0000?o0000ooooooooool0?Oooool00ol00?ooooooooooo`1E
ooooo`03o`00oooooooooooo08?ooooo0Ol00001ooooo`0000?o0000ooooooooool0?_ooool00ol0
0?ooooooooooo`1Cooooo`03o`00oooooooooooo08Cooooo0Ol00001ooooo`0000?o0000oooooooo
ool0?oooool00ol00?ooooooooooo`1@ooooo`;o003o8Oooool2oomo06Cooooo0Ol00001ooooo`00
00?o0000ooooooooool0@?ooool00ol00?ooooooooooo`1>ooooo`03o`00oooooooooooo023ooooo
1?ooO`1Sooooo`7o00000Oooool00003o`000?oooooooooo047ooooo0_l00?m=ooooo`03o`00oooo
oooooooo027ooooo1?ooO`1Sooooo`7o00000Oooool00003o`000?oooooooooo04?ooooo00?o003o
ooooooooool0BOooool00ol00?ooooooooooo`0Sooooo`;oogl0=Oooool2oomo02gooooo0Ol00001
ooooo`0000?o0000ooooooooool0A?ooool2o`00odSooooo00?o003oooooooooool0Doooool2oomo
00Gooooo1?ooO`0/ooooo`7o00000Oooool00003o`000?oooooooooo04Kooooo0_l00?m5ooooo`03
o`00oooooooooooo05?ooooo1?ooO`04ooooo`Coogl0;?ooool1o`00007ooooo00000ol0003ooooo
ooooo`18ooooo`03o`00oooooooooooo043ooooo0_l00?lfooooo`;oogl07_ooool4oomo00Gooooo
0_ooO`0]ooooo`7o00000Oooool00003o`000?oooooooooo04Wooooo0_l00?lnooooo`;o003o=ooo
ool4oomo01kooooo0_ooO`0eooooo`7o00000Oooool00003o`000?oooooooooo04_ooooo0ol00?lj
ooooo`03o`00oooooooooooo03Oooooo1?ooO`1Eooooo`7o00000Oooool00003o`000?oooooooooo
04kooooo0_l00?lfooooo`;o003o>oooool2oomo05Kooooo0Ol00001ooooo`0000?o0000oooooooo
ool0D?ooool3o`00oc3ooooo0ol00?lcooooo`;oogl09Oooool2oomo03Wooooo0Ol00001ooooo`00
00?o0000ooooooooool0Doooool2o`00ob[ooooo1?l00?leooooo`Coogl08oooool4oomo03Sooooo
0Ol00001ooooo`0000?o0000ooooooooool0EOooool3o`00ob?ooooo1?l00?leooooo`;oogl00_oo
ool4oomo02?ooooo1?ooO`03ooooo`;oogl0<oooool1o`00007ooooo00000ol0003oooooooooo`1H
ooooo`?o003o7Oooool3o`00ocSooooo1?ooO`02ooooo`;oogl04oooool2oomo013ooooo0_ooO`03
ooooo`Coogl0<_ooool1o`00007ooooo00000ol0003oooooooooo`1Kooooo`?o003o5?ooool6o`00
oc_ooooo1?ooO`06ooooo`;oogl03_ooool4oomo01Cooooo1?ooO`0booooo`7o00000Oooool00003
o`000?oooooooooo05kooooo5?l00?m2ooooo`;oogl01_ooool4oomo00gooooo1?ooO`0Eooooo`;o
ogl0<oooool1o`00007ooooo00000ol0003oooooooooo`2;ooooo`;oogl09oooool2oomo00Kooooo
1?ooO`0>ooooo`;oogl0Boooool1o`00007ooooo00000ol0003oooooooooo`2:ooooo`Coogl09Ooo
ool4oomo00Kooooo0_ooO`1Looooo`7o00000Oooool00003o`000?oooooooooo08[ooooo1?ooO`0U
ooooo`Coogl0I?ooool1o`00007ooooo00000ol0003oooooooooo`2;ooooo`;oogl09oooool2oomo
06Gooooo0Ol00001ooooo`0000?o0000ooooooooool0U_ooool2oomo03[ooooo0_ooO`17ooooo`7o
00000Oooool00003o`000?oooooooooo09Gooooo1?ooO`0>ooooo`;oogl0:?ooool4oomo01Gooooo
1Ooo0?l/ooooo`7o00000Oooool00003o`000?oooooooooo09Gooooo1?ooO`0=ooooo`Coogl09ooo
ool4oomo01Cooooo1ooo0?l[ooooo`7o00000Oooool00003o`000?oooooooooo09Kooooo0_ooO`0>
ooooo`Coogl0:?ooool2oomo01Cooooo2Ooo0?lZooooo`7o00000Oooool00003o`000?oooooooooo
0:Oooooo0_ooO`0nooooo`_oo`3o:Oooool1o`00007ooooo00000ol0003oooooooooo`3Wooooo`_o
o`3o:Oooool1o`00007ooooo00000ol0003oooooooooo`3Wooooo`_oo`3o:Oooool1o`00007ooooo
00000ol0003oooooooooo`3Fooooo`;oogl03oooool;ool0obWooooo0Ol00001ooooo`0000?o0000
ooooooooool0eOooool4oomo00kooooo2ooo0?lYooooo`7o00000Oooool00003o`000?oooooooooo
0;Oooooo0_ooO`0Looooo`Coogl03oooool9ool0ob[ooooo0Ol00001ooooo`0000?o0000oooooooo
ool0]_ooool4oomo01cooooo0_ooO`0Aooooo`Ooo`3o:oooool1o`00007ooooo00000ol0003ooooo
ooooo`2cooooo`;oogl000?ooooooomo0?ooO`000_ooO`0`ooooo`Goo`3o;?ooool1o`00007ooooo
00000ol0003oooooooooo`2Xooooo`;oogl02?ooool4oomo0003ooooooooO`3oogl001[ooooo0_oo
O`16ooooo`7o00000Oooool00003o`000?oooooooooo0:Kooooo1OooO`07ooooo`Coogl05oooool2
oomo00?ooooo1?ooO`15ooooo`7o00000Oooool00003o`000?oooooooooo0:Gooooo1_ooO`08oooo
o`;oogl05oooool4oomo00;ooooo1?ooO`15ooooo`7o00000Oooool00003o`000?oooooooooo0:Go
oooo1OooO`0Rooooo`Coogl00oooool2oomo04Kooooo0Ol00001ooooo`0000?o0000ooooooooool0
M_ooool2oomo02kooooo0_ooO`0Uooooo`;oogl0C?ooool1o`00007ooooo00000ol0003ooooooooo
o`1eooooo`Coogl0X_ooool1o`00007ooooo00000ol0003oooooooooo`1eooooo`Coogl02_ooool2
oomo09Kooooo0Ol00001ooooo`0000?o0000ooooooooool0M_ooool2oomo00[ooooo1?ooO`0Zoooo
o`;oogl0JOooool1o`00007ooooo00000ol0003oooooooooo`22ooooo`Coogl0:Oooool4oomo06So
oooo0Ol00001ooooo`0000?o0000ooooooooool0Poooool2oomo02Cooooo0_ooO`04ooooo`Coogl0
J?ooool1o`00007ooooo00000ol0003oooooooooo`2Xooooo`Coogl01?ooool2oomo06Wooooo0Ol0
0001ooooo`0000?o0000ooooooooool0Z?ooool4oomo06oooooo0Ol00001ooooo`0000?o0000oooo
ooooool0ZOooool2oomo073ooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o
00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003ooooooooo
o`3ooooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool0
0003o`000?oooooooooo08Cooooo0_ooO`2Eooooo`7o00000Oooool00003o`000?oooooooooo08?o
oooo1?ooO`2Dooooo`7o00000Oooool00003o`000?oooooooooo08?ooooo1?ooO`2Dooooo`7o0000
0Oooool00003o`000?oooooooooo08Cooooo0_ooO`0/ooooo`;oogl0Ioooool1o`00007ooooo0000
0ol0003oooooooooo`2aooooo`Coogl0I_ooool1o`00007ooooo00000ol0003oooooooooo`2aoooo
o`Coogl0I_ooool1o`00007ooooo00000ol0003oooooooooo`2booooo`;oogl0Ioooool1o`00007o
oooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooo
oolLooooo`7o00000Oooool00003o`000?oooooooooo07_ooooo0_ooO`2Nooooo`7o00000Oooool0
0003o`000?oooooooooo07[ooooo1?ooO`2Mooooo`7o00000Oooool00003o`000?oooooooooo07[o
oooo1?ooO`0Pooooo`;oogl0Noooool1o`00007ooooo00000ol0003oooooooooo`1kooooo`;oogl0
8?ooool4oomo07[ooooo0Ol00001ooooo`0000?o0000ooooooooool0WOooool4oomo07[ooooo0Ol0
0001ooooo`0000?o0000ooooooooool0T?ooool2oomo00cooooo0_ooO`1kooooo`7o00000Oooool0
0003o`000?oooooooooo08oooooo1?ooO`28ooooo`7o00000Oooool00003o`000?oooooooooo08oo
oooo1?ooO`28ooooo`7o00000Oooool00003o`000?oooooooooo093ooooo0_ooO`0Sooooo`;oogl0
I?ooool1o`00007ooooo00000ol0003oooooooooo`2dooooo`Coogl0Hoooool1o`00007ooooo0000
0ol0003oooooooooo`2dooooo`Coogl0Hoooool1o`00007ooooo00000ol0003oooooooooo`2eoooo
o`;oogl0I?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`00
00?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?oo
ool1o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000oooo
ooooool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007o
oooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooo
oolLooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0
003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o
00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003ooooooooo
o`3ooooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool0
0003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooooaco
oooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oo
oooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001
ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo0?oo
oooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o
0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1
o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000oooooooo
ool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo
00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolL
ooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003o
ooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o0000
0Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3o
oooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003
o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo
0Ol00001ooooo`0000?o0000ooooooooool0S_ooool2oomo08_ooooo0Ol00001ooooo`0000?o0000
ooooooooool0SOooool4oomo08[ooooo0Ol00001ooooo`0000?o0000ooooooooool0SOooool4oomo
08[ooooo0Ol00001ooooo`0000?o0000ooooooooool0S_ooool2oomo08_ooooo0Ol00001ooooo`00
00?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?oo
ool1o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000oooo
ooooool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007o
oooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooo
oolLooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0
003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o
00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003ooooooooo
o`3ooooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool0
0003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooooaco
oooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oo
oooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001
ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo0?oo
oooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`00ool0
000Po`00007ooooo0000\
\>"],
  ImageRangeCache->{{{0, 287}, {287, 0}} -> {-1.01089, -1.01089, 0.00704453, \
0.00704453}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.49505 0.5 0.49505 [
[ 0 0 -0.125 0 ]
[ 0 0 -0.125 0 ]
[ 0 1 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
0 0 m
1 0 L
s
0 0 m
0 1 L
s
0 1 m
1 1 L
s
1 0 m
1 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
1 .5 0 r
.015 w
.03175 .1355 Mdot
.03435 .12523 Mdot
.11137 .12765 Mdot
.14107 .18841 Mdot
.16218 .24538 Mdot
.17294 .21053 Mdot
.18267 .18577 Mdot
.18434 .1304 Mdot
.18553 .30956 Mdot
.20401 .239 Mdot
.21247 .27571 Mdot
.21687 .20845 Mdot
.22376 .2799 Mdot
.22832 .27485 Mdot
.29063 .20974 Mdot
.29686 .25079 Mdot
.30487 .22936 Mdot
.30683 .34623 Mdot
.32055 .20902 Mdot
.32574 .21979 Mdot
.34472 .28521 Mdot
.35998 .36393 Mdot
.36335 .24976 Mdot
.3794 .36608 Mdot
.42386 .66992 Mdot
.44391 .74519 Mdot
.45059 .34198 Mdot
.47208 .67586 Mdot
.47436 .71381 Mdot
.49778 .59825 Mdot
.50874 .91643 Mdot
.51516 .76219 Mdot
.53655 .61374 Mdot
.56563 .75219 Mdot
.59189 .65665 Mdot
.59581 .61604 Mdot
.59923 .6556 Mdot
.60292 .68499 Mdot
.62656 .67779 Mdot
.63555 .72451 Mdot
.63919 .652 Mdot
.64169 .6004 Mdot
.64246 .58611 Mdot
.64496 .54267 Mdot
.64608 .77288 Mdot
.65077 .64308 Mdot
.66065 .57816 Mdot
.67474 .59169 Mdot
.69296 .563 Mdot
.72815 .65902 Mdot
.73169 .58879 Mdot
.74669 .61318 Mdot
.74821 .65474 Mdot
.75963 .63781 Mdot
.79673 .57809 Mdot
.80925 .55852 Mdot
.81525 .58444 Mdot
.83417 .62985 Mdot
.83598 .55526 Mdot
.91595 .49319 Mdot
1 0 0 r
.005 w
.00495 .28842 m
.00628 .29156 L
.01857 .31761 L
.03101 .33781 L
.03525 .34367 L
.05706 .36884 L
.05795 .36972 L
.08312 .39115 L
.08963 .39578 L
.10917 .40763 L
.13523 .41964 L
.14074 .42183 L
.16128 .42794 L
.18734 .43294 L
.21339 .43485 L
.23945 .43375 L
.2655 .42959 L
.29156 .42219 L
.29261 .42183 L
.31761 .41124 L
.34367 .39603 L
.34405 .39578 L
.36972 .37551 L
.37582 .36972 L
.39578 .34724 L
.39849 .34367 L
.41525 .31761 L
.42183 .30485 L
.4275 .29156 L
.436 .2655 L
.44117 .23945 L
.44325 .21339 L
.44232 .18734 L
.43834 .16128 L
.43114 .13523 L
.42183 .11212 L
.42037 .10917 L
.40546 .08312 L
.39578 .06961 L
.38528 .05706 L
.36972 .04137 L
.35758 .03101 L
.34367 .02092 L
.31761 .00569 L
.3162 .00495 L
s
.00495 .12854 m
.01344 .10917 L
.02832 .08312 L
.03101 .07912 L
.04848 .05706 L
.05706 .04802 L
.07619 .03101 L
.08312 .02579 L
.10917 .00934 L
.11742 .00495 L
s
0 0 1 r
.29156 .15739 m
.31761 .14824 L
.34367 .14249 L
.36972 .13986 L
.39578 .14025 L
.42183 .14366 L
.44789 .15025 L
.47394 .16034 L
.47599 .16128 L
.5 .17443 L
.51844 .18734 L
.52606 .19355 L
.54662 .21339 L
.55211 .21962 L
.56712 .23945 L
.57817 .25755 L
.58227 .2655 L
.59322 .29156 L
.60058 .31761 L
.60422 .3392 L
.60471 .34367 L
.6058 .36972 L
.60422 .39297 L
.60387 .39578 L
.59886 .42183 L
.59054 .44789 L
.57848 .47394 L
.57817 .47453 L
.562 .5 L
.55211 .51255 L
.53968 .52606 L
.52606 .53862 L
.50853 .55211 L
.5 .55773 L
.47394 .57183 L
.45901 .57817 L
.44789 .5819 L
.42183 .5885 L
.39578 .59192 L
.36972 .59231 L
.34367 .58968 L
.31761 .58392 L
.29972 .57817 L
.29156 .57477 L
.2655 .56178 L
.25025 .55211 L
.23945 .54409 L
.21914 .52606 L
.21339 .52008 L
.19681 .5 L
Mistroke
.18734 .48608 L
.18031 .47394 L
.16827 .44789 L
.16128 .42714 L
.15996 .42183 L
.15493 .39578 L
.153 .36972 L
.15409 .34367 L
.15823 .31761 L
.16128 .3045 L
.16559 .29156 L
.17653 .2655 L
.18734 .24609 L
.19169 .23945 L
.21221 .21339 L
.21339 .21211 L
.23945 .1881 L
.24041 .18734 L
.2655 .17038 L
.28271 .16128 L
.29156 .15739 L
Mfstroke
1 0 0 r
.03 w
.21687 .20845 Mdot
0 0 1 r
.3794 .36608 Mdot
1 0 0 r
.79703 .00495 m
.79703 .02323 L
.87129 .02323 L
.87129 .00495 L
F
0 0 1 r
.89604 .00495 m
.89604 .2342 L
.9703 .2342 L
.9703 .00495 L
F
1 0 1 r
.04 w
.83598 .55526 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P000182000`400?l00000o`00003ooooooolQ
ooooo`00ool0000Po`00007ooooo00000ol0003oooooooooo`0Mooooo`;oo`00>?ooool3ool00<7o
oooo0Ol00001ooooo`0000?o0000ooooooooool06oooool2ool003gooooo00?oo`00ooooooooool0
Q?oooolEool000Sooooo5Ol00?l8ooooo`7o00000Oooool00003o`000?oooooooooo01[ooooo00?o
o`00ooooooooool0?_ooool2ool008Cooooo5Ooo0008oooooaGo003o2?ooool1o`00007ooooo0000
0ol0003oooooooooo`0Hooooo`;oo`00@oooool00ooo003oooooooooo`21oooooaGoo`002?oooolE
o`00o`Sooooo0Ol00001ooooo`0000?o0000ooooooooool05_ooool2ool004Kooooo00?oo`00oooo
ooooool0P?oooolEool000Sooooo5Ol00?l8ooooo`7o00000Oooool00003o`000?oooooooooo01Go
oooo00?oo`00ooooooooool0Aoooool2ool0083ooooo5Ooo0008oooooaGo003o2?ooool1o`00007o
oooo00000ol0003oooooooooo`0Dooooo`03ool00?oooooooooo04[ooooo00?oo`00ooooooooool0
V_oooolEo`00o`Sooooo0Ol00001ooooo`0000?o0000ooooooooool04oooool00ooo003ooooooooo
o`1<ooooo`03ool00?oooooooooo09Wooooo5Ol00?l8ooooo`7o00000Oooool00003o`000?oooooo
oooo017ooooo0_oo001@ooooo`;oo`00VOoooolEo`00o`Sooooo0Ol00001ooooo`0000?o0000oooo
ooooool04?ooool00ooo003oooooooooo`1Booooo`;oo`00UooooolEo`00o`Sooooo0Ol00001oooo
o`0000?o0000ooooooooool03oooool00ooo003oooooooooo`1Eooooo`03ool00?oooooooooo09Co
oooo5Ol00?l8ooooo`7o00000Oooool00003o`000?oooooooooo00kooooo00?oo`00ooooooooool0
E_ooool00ooo003oooooooooo`2DoooooaGo003o2?ooool1o`00007ooooo00000ol0003ooooooooo
o`0=ooooo`03ool00?oooooooooo05Sooooo00?oo`00ooooooooool0TooooolEo`00o`Sooooo0Ol0
0001ooooo`0000?o0000ooooooooool03Oooool00ooo003oooooooooo`1Iooooo`03ool00?oooooo
oooo09;ooooo5Ol00?l8ooooo`7o00000Oooool00003o`000?oooooooooo00cooooo00?oo`00oooo
ooooool0Foooool00ooo003oooooooooo`2AoooooaGo003o2?ooool1o`00007ooooo00000ol0003o
ooooooooo`0;ooooo`03ool00?oooooooooo05gooooo00?oo`00ooooooooool0T?oooolEo`00o`So
oooo0Ol00001ooooo`0000?o0000ooooooooool02oooool00ooo003oooooooooo`1Mooooo`03ool0
0?oooooooooo093ooooo5Ol00?l8ooooo`7o00000Oooool00003o`000?oooooooooo00[ooooo00?o
o`00ooooooooool0Goooool00ooo003oooooooooo`2?oooooaGo003o2?ooool1o`00007ooooo0000
0ol0003oooooooooo`09ooooo`03ool00?oooooooooo067ooooo00?oo`00ooooooooool0S_oooolE
o`00o`Sooooo0Ol00001ooooo`0000?o0000ooooooooool02?ooool00ooo003oooooooooo`1Soooo
o`03ool00?oooooooooo08gooooo5Ol00?l8ooooo`7o00000Oooool00003o`000?oooooooooo00Oo
oooo00?oo`00ooooooooool0IOooool00ooo003oooooooooo`2<oooooaGo003o2?ooool1o`00007o
oooo00000ol0003oooooooooo`06ooooo`03ool00?oooooooooo06Oooooo00?oo`00ooooooooool0
RooooolEo`00o`Sooooo0Ol00001ooooo`0000?o0000ooooooooool01Oooool00ooo003ooooooooo
o`1Yooooo`03ool00?oooooooooo08[ooooo5Ol00?l8ooooo`7o00000Oooool00003o`000?oooooo
oooo00Gooooo00?oo`00ooooooooool0JOooool00ooo003oooooooooo`2:oooooaGo003o2?ooool1
o`00007ooooo00000ol0003oooooooooo`04ooooo`03ool00?oooooooooo06_ooooo00?oo`00oooo
ooooool0ROoooolEo`00o`Sooooo0Ol00001ooooo`0000?o0000ooooooooool00oooool00ooo003o
ooooooooo`1/ooooo`03ool00?oooooooooo08Wooooo5Ol00?l8ooooo`7o00000Oooool00003o`00
0?oooooooooo00?ooooo00?oo`00ooooooooool0KOooool00ooo003oooooooooo`28oooooaGo003o
2?ooool1o`00007ooooo00000ol0003oooooooooo`02ooooo`03ool00?oooooooooo06kooooo00?o
o`00ooooooooool0R?oooolEo`00o`Sooooo0Ol00001ooooo`0000?o0000ooooooooool00_ooool0
0ooo003oooooooooo`1_ooooo`03ool00?oooooooooo08Oooooo5Ol00?l8ooooo`7o00000Oooool0
0005o`000?oooooooooooooooooo0000L_ooool00ooo003oooooooooo`27oooooaGo003o2?ooool1
o`00007ooooo00001?l0003ooooooooooooo001dooooo`03ool00?oooooooooo08Kooooo5Ol00?l8
ooooo`7o00000Oooool00004o`000?ooooooooooool007Gooooo00?oo`00ooooooooool0QOoooolE
o`00o`Sooooo0Ol00001ooooo`0000?o0000oooooooo0000M_ooool00ooo003oooooooooo`25oooo
oaGo003o2?ooool1o`00007ooooo00000ol0003oooooool00006ooooo`80ogl0Koooool00ooo003o
ooooooooo`24oooooaGo003o2?ooool1o`00007ooooo00000ol0003oooooool00005ooooo`@0ogl0
4oooool20?mo05Wooooo00?oo`00ooooooooool0Q?oooolEo`00o`Sooooo0Ol00001ooooo`0000?o
0000ool00?ooool01Oooool40?mo01;ooooo103oO`0Booooo`80ogl0A?ooool00ooo003ooooooooo
o`24oooooaGo003o2?ooool1o`00007ooooo00000ol0003oooooooooo`05ooooo`<0ogl04oooool4
0?mo017ooooo103oO`14ooooo`03ool00?oooooooooo08?ooooo5Ol00?l8ooooo`7o00000Oooool0
0003o`000?oooooooooo00Cooooo103oO`0Dooooo`80ogl04_ooool40?mo04Cooooo00?oo`00oooo
ooooool0PooooolEo`00o`Sooooo0Ol00001ooooo`0000?o0000ooooooooool01?ooool40?mo02Wo
oooo0P3oO`15ooooo`03ool00?oooooooooo08?ooooo5Ol00?l8ooooo`7o00000Oooool00003o`00
0?oooooooooo00Gooooo0P3oO`1FoooooaKo003o1Oooool00ooo003oooooooooo`23oooooaGo003o
2?ooool1o`00007ooooo00000ol0003oooooooooo`1Jooooo`?o003o5_ooool6o`00o`03ool00?oo
oooooooo08;ooooo5Ol00?l8ooooo`7o00000Oooool00003o`000?oooooooooo05Oooooo0ol00?lO
ooooo`?o003oP_oooolEo`00o`Sooooo0Ol00001ooooo`0000?o0000ooooooooool0E?ooool3o`00
ob;ooooo00?oo`00ooooooooool00ol00?mooooooaGo003o2?ooool1o`00007ooooo00000ol0003o
ooooooooo`1Aooooo`?o003o9Oooool00ooo003oooooooooo`03ooooo`?o003oO?oooolEo`00o`So
oooo0Ol00001ooooo`0000?o0000ooooooooool0Coooool20000obWooooo00?oo`00ooooooooool0
1Oooool3o`00ogWooooo5Ol00?l8ooooo`7o00000Oooool00003o`000?oooooooooo04gooooo0P00
0?l[ooooo`03ool00?oooooooooo00Sooooo0_l00?mgoooooaGo003o2?ooool1o`00007ooooo0000
0ol0003oooooooooo`1:ooooo`<0003o;Oooool00ooo003oooooooooo`0:ooooo`;o003oMOoooolE
o`00o`Sooooo0Ol00001ooooo`0000?o0000ooooooooool0B?ooool20000oc3ooooo00?oo`00oooo
ooooool03?ooool00ol00?ooooooooooo`1boooooaGo003o2?ooool1o`00007ooooo00000ol0003o
ooooooooo`17ooooo`030000oooooooooooo033ooooo00?oo`00ooooooooool03Oooool2o`00og;o
oooo5Ol00?l8ooooo`7o00000Oooool00003o`000?oooooooooo04Gooooo0P000?ldooooo`03ool0
0?oooooooooo00kooooo0_l00?m`oooooaGo003o2?ooool1o`00007ooooo00000ol0003ooooooooo
o`14ooooo`030000oooooooooooo03Cooooo00?oo`00ooooooooool04?ooool2o`00ofkooooo5Ol0
0?l8ooooo`7o00000Oooool00003o`000?oooooooooo02Cooooo0P3oO`0:ooooo`80ogl04Oooool0
0`000?ooooooooooo`0eooooo`03ool00?oooooooooo01;ooooo00?o003oooooooooool0JooooolE
o`00o`Sooooo0Ol00001ooooo`0000?o0000ooooooooool08oooool40?mo00Sooooo103oO`0?oooo
o`030000oooooooooooo03Kooooo00?oo`00ooooooooool04oooool00ol00?ooooooooooo`1Zoooo
oaGo003o2?ooool1o`00007ooooo00000ol0003oooooooooo`0Sooooo`@0ogl02?ooool40?mo00go
oooo00<0003oo`00ooooool0>?ooool00ooo003oooooooooo`0Dooooo`03o`00oooooooooooo06Wo
oooo5Ol00?l8ooooo`7o00000Oooool00003o`000?oooooooooo02Cooooo0P3oO`0:ooooo`80ogl0
3Oooool00`000?ooooooooooo`0iooooo`03ool00?oooooooooo01Gooooo00?o003oooooooooool0
J?oooolEo`00o`Sooooo0Ol00001ooooo`0000?o0000ooooooooool0>Oooool40?l00003ooooo`00
0?oooooo03_ooooo00?oo`00ooooooooool05_ooool00ol00?ooooooooooo`1WoooooaGo003o2?oo
ool1o`00007ooooo00000ol0003oooooooooo`0hooooo`H0o`00?Oooool00ooo003oooooooooo`0G
ooooo`03o`00oooooooooooo06Kooooo5Ol00?l8ooooo`7o00000Oooool00003o`000?oooooooooo
03Oooooo203o000@ooooo`80ogl01oooool20?mo02;ooooo00?oo`00ooooooooool05oooool00ol0
0?ooooooooooo`1UoooooaGo003o2?ooool1o`00007ooooo00000ol0003oooooooooo`0^ooooo`80
ogl01oooool80?l000oooooo103oO`05ooooo`@0ogl08Oooool00ooo003oooooooooo`0Hooooo`03
o`00oooooooooooo06Cooooo5Ol00?l8ooooo`7o00000Oooool00003o`000?oooooooooo02gooooo
103oO`06ooooo`P0o`003oooool40?mo00Gooooo103oO`0Qooooo`03ool00?oooooooooo01Wooooo
00?o003oooooooooool0HooooolEo`00o`Sooooo0Ol00001ooooo`0000?o0000ooooooooool0;Ooo
ool40?mo00Kooooo203o000@ooooo`80ogl01oooool30?mo027ooooo00?oo`00ooooooooool06_oo
ool00ol00?ooooooooooo`1RoooooaGo003o2?ooool1o`00007ooooo00000ol0003oooooooooo`0^
ooooo`80ogl02?ooool60?l001[ooooo103oO`0Pooooo`03ool00?oooooooooo01_ooooo00?o003o
ooooooooool0HOoooolEo`00o`Sooooo0Ol00001ooooo`0000?o0000ooooooooool0>?ooool00`00
0?l0o`000?l000020?l001_ooooo103oO`0Pooooo`03ool00?oooooooooo01cooooo00?o003ooooo
ooooool0H?oooolEo`00o`Sooooo0Ol00001ooooo`0000?o0000ooooooooool0=oooool00`000?oo
ooooooooo`0Iooooo`80ogl01?ooool20?mo027ooooo00?oo`00ooooooooool07?ooool00ol00?oo
ooooooooo`1PoooooaGo003o2?ooool1o`00007ooooo00000ol0003oooooooooo`0fooooo`030000
oooooooooooo01Wooooo103oO`0Uooooo`03ool00?oooooooooo01kooooo00?o003oooooooooool0
GooooolEo`00o`Sooooo0Ol00001ooooo`0000?o0000ooooooooool0=_ooool00`000?oooooooooo
o`0Iooooo`@0ogl09Oooool00ooo003oooooooooo`0Oooooo`03o`00oooooooooooo05kooooo5Ol0
0?l8ooooo`7o00000Oooool00003o`000?oooooooooo03Gooooo00@0003oooooo`3oO`00ogl06_oo
ool20?mo02Kooooo00?oo`00ooooooooool08?ooool00ol00?ooooooooooo`1MoooooaGo003o2?oo
ool1o`00007ooooo00000ol0003oooooooooo`0dooooo`030000ooooool0ogl000<0ogl0@Oooool0
0ooo003oooooooooo`0Qooooo`03o`00oooooooooooo07Wooooo0Ol00001ooooo`0000?o0000oooo
ooooool0:oooool20?mo00Kooooo00<0003oooooooooool0103oO`11ooooo`03ool00?oooooooooo
027ooooo00?o003oooooooooool0NOooool1o`00007ooooo00000ol0003oooooooooo`0Zooooo`@0
ogl01?ooool00`000?ooooooooooo`02ooooo`80ogl06?ooool20?mo017ooooo0P3oO`0Eooooo`03
ool00?oooooooooo02;ooooo00?o003oooooooooool0N?ooool1o`00007ooooo00000ol0003ooooo
ooooo`0Zooooo`@0ogl01?ooool00`000?ooooooooooo`0Kooooo`@0ogl03oooool40?mo01Cooooo
00?oo`00ooooooooool08oooool00ol00?ooooooooooo`1gooooo`7o00000Oooool00003o`000?oo
oooooooo02_ooooo0P3oO`04ooooo`030000oooooooooooo01cooooo103oO`0?ooooo`@0ogl05?oo
ool00ooo003oooooooooo`0Sooooo`03o`00oooooooooooo07Oooooo0Ol00001ooooo`0000?o0000
ooooooooool0<Oooool00`000?ooooooooooo`0Mooooo`80ogl04Oooool20?mo01Cooooo00?oo`00
ooooooooool09Oooool00ol00?ooooooooooo`1fooooo`7o00000Oooool00003o`000?oooooooooo
033ooooo00<0003oooooooooool0Aoooool00ooo003oooooooooo`0Uooooo`03o`00oooooooooooo
07Kooooo0Ol00001ooooo`0000?o0000ooooooooool0<?ooool00`000?ooooooooooo`17ooooo`03
ool00?oooooooooo02Kooooo00?o003oooooooooool0MOooool1o`00007ooooo00000ol0003ooooo
ooooo`0_ooooo`030000oooooooooooo04Sooooo00?oo`00ooooooooool09oooool00ol00?oooooo
ooooo`1dooooo`7o00000Oooool00003o`000?oooooooooo02oooooo00<0003oooooooooool01ooo
ool20?mo00;ooooo0P3oO`0kooooo`03ool00?oooooooooo02Oooooo00?o003oooooooooool0M?oo
ool1o`00007ooooo00000ol0003oooooooooo`0^ooooo`030000oooooooooooo00Oooooo203oO`0i
ooooo`03ool00?oooooooooo02Wooooo00?o003oooooooooool0Loooool1o`00007ooooo00000ol0
003oooooooooo`0^ooooo`030000oooooooooooo00Oooooo203oO`0iooooo`03ool00?oooooooooo
02Wooooo00?o003oooooooooool0Loooool1o`00007ooooo00000ol0003oooooooooo`0]ooooo`03
0000oooooooooooo00Wooooo1P3oO`0Pooooo`80ogl05oooool00ooo003oooooooooo`0[ooooo`03
o`00oooooooooooo07;ooooo0Ol00001ooooo`0000?o0000ooooooooool0;Oooool00`000?oooooo
ooooo`0;ooooo`@0ogl07oooool40?mo01Kooooo00?oo`00ooooooooool0:oooool00ol00?oooooo
ooooo`1booooo`7o00000Oooool00003o`000?oo003ooooo02gooooo00<0003oooooooooool03?oo
ool20?mo023ooooo103oO`0Fooooo`03ool00?oooooooooo02_ooooo00?o003oooooooooool0L_oo
ool1o`00007ooooo00000ol0003oo`00ooooo`0/ooooo`030000oooooooooooo033ooooo0P3oO`0F
ooooo`03ool00?oooooooooo02gooooo00?o003oooooooooool0LOooool1o`00007ooooo00000ol0
003oo`00ooooo`0/ooooo`030000oooooooooooo04Sooooo00?oo`00ooooooooool0;Oooool00ol0
0?ooooooooooo`1aooooo`7o00000Oooool00003o`000?ooooooo`0002cooooo00<0003ooooooooo
ool0B?ooool00ooo003oooooooooo`0]ooooo`03o`00oooooooooooo077ooooo0Ol00001ooooo`00
00?o0000oooooooo0000:oooool00`000?ooooooooooo`18ooooo`03ool00?oooooooooo02oooooo
00?o003oooooooooool0L?ooool1o`00007ooooo00001?l0003ooooooooooooo000Zooooo`030000
oooooooooooo00?ooooo0P3oO`13ooooo`03ool00?oooooooooo02oooooo00?o003oooooooooool0
L?ooool1o`00007ooooo00001?l0003ooooooooooooo000Zooooo`030000oooooooooooo00;ooooo
103oO`12ooooo`03ool00?oooooooooo02oooooo00?o003oooooooooool0L?ooool1o`00007ooooo
00001Ol0003oooooooooooooooooo`0002Wooooo00<0003oooooooooool00_ooool40?mo047ooooo
00?oo`00ooooooooool0<?ooool00ol00?ooooooooooo`1`ooooo`7o00000Oooool00005o`000?oo
oooooooooooooooo0000:?ooool00`000?ooooooooooo`04ooooo`80ogl0@_ooool00ooo003ooooo
ooooo`0aooooo`03o`00oooooooooooo06oooooo0Ol00001ooooo`0000?o0000ooooooooool00_oo
ool00ooo003oooooooooo`0Uooooo`030000oooooooooooo04Oooooo00?oo`00ooooooooool0<_oo
ool00ol00?ooooooooooo`1_ooooo`7o00000Oooool00003o`000?oooooooooo00;ooooo00?oo`00
ooooooooool09Oooool00`000?ooooooooooo`17ooooo`03ool00?oooooooooo03;ooooo00?o003o
ooooooooool0Koooool1o`00007ooooo00000ol0003oooooooooo`03ooooo`03ool00?oooooooooo
02Cooooo00<0003oooooooooool0A_ooool00ooo003oooooooooo`0cooooo`03o`00oooooooooooo
06oooooo0Ol00001ooooo`0000?o0000ooooooooool01?ooool00ooo003oooooooooo`0Sooooo`03
0000oooooooooooo04Gooooo00?oo`00ooooooooool0=?ooool00ol00?ooooooooooo`1_ooooo`7o
00000Oooool00003o`000?oooooooooo00Gooooo00?oo`00ooooooooool08Oooool00`000?oooooo
ooooo`15ooooo`03ool00?oooooooooo03Kooooo00?o003oooooooooool0K_ooool1o`00007ooooo
00000ol0003oooooooooo`06ooooo`03ool00?oooooooooo023ooooo00<0003oooooooooool0AOoo
ool00ooo003oooooooooo`09ooooo`80ogl0:oooool00ol00?ooooooooooo`1^ooooo`7o00000Ooo
ool00003o`000?oooooooooo00Kooooo00?oo`00ooooooooool08?ooool00`000?ooooooooooo`14
ooooo`03ool00?oooooooooo00Wooooo103oO`0Zooooo`03o`00oooooooooooo06kooooo0Ol00001
ooooo`0000?o0000ooooooooool01oooool00ooo003oooooooooo`0Oooooo`030000oooooooooooo
02Sooooo0P3oO`0Iooooo`03ool00?oooooooooo00[ooooo103oO`0Zooooo`03o`00oooooooooooo
06kooooo0Ol00001ooooo`0000?o0000ooooooooool01oooool00ooo003oooooooooo`0Oooooo`03
0000oooooooooooo02Oooooo103oO`0Gooooo`03ool00?oooooooooo00cooooo0P3oO`0[ooooo`03
o`00oooooooooooo06kooooo0Ol00001ooooo`0000?o0000ooooooooool02?ooool00ooo003ooooo
ooooo`0Nooooo`030000oooooooooooo02Oooooo103oO`0Gooooo`03ool00?oooooooooo03Wooooo
00?o003oooooooooool0K_ooool1o`00007ooooo00000ol0003oooooooooo`09ooooo`03ool00?oo
oooooooo01gooooo00<0003oooooooooool0:?ooool20?mo01;ooooo10000?l00oooooooo`00oooo
o`0kooooo`03o`00oooooooooooo06kooooo0Ol00001ooooo`0000?o0000ooooooooool02_ooool0
0ooo003oooooooooo`0Looooo`030000oooooooooooo03_ooooo1P000?lmooooo`03o`00oooooooo
oooo06kooooo0Ol00001ooooo`0000?o0000ooooooooool02oooool00ooo003oooooooooo`0Koooo
o`030000oooooooooooo03Oooooo0P3oO`000oooool0003o0000o`060000occooooo00?o003ooooo
ooooool0K_ooool1o`00007ooooo00000ol0003oooooooooo`0<ooooo`03ool00?oooooooooo01[o
oooo00<0003oooooooooool0=_ooool40?mo00P0003o??ooool00ol00?ooooooooooo`1^ooooo`7o
00000Oooool00003o`000?oooooooooo00gooooo00?oo`00ooooooooool06Oooool00`000?oooooo
ooooo`0fooooo`@0ogl020000?llooooo`03o`00oooooooooooo06kooooo0Ol00001ooooo`0000?o
0000ooooooooool03Oooool2ool001[ooooo00<0003oooooooooool0=oooool20?mo0003ooooo`00
0?l0003o00H0003o??ooool00ol00?ooooooooooo`1^ooooo`7o00000Oooool00003o`000?oooooo
oooo00oooooo00?oo`00ooooooooool05oooool00`000?ooooooooooo`0jooooo`03ool000000?l0
003o00@0003o?Oooool00ol00?ooooooooooo`1^ooooo`7o00000Oooool00003o`000?oooooooooo
013ooooo00?oo`00ooooooooool05_ooool00`000?ooooooooooo`0iooooo`03ool00?oooooooooo
00@0003o?_ooool00ol00?ooooooooooo`1^ooooo`7o00000Oooool00003o`000?oooooooooo017o
oooo00?oo`00ooooooooool05Oooool00`000?ooooooooooo`0hooooo`03ool00?oooooooooo04?o
oooo00?o003oooooooooool0K_ooool1o`00007ooooo00000ol0003oooooooooo`0Booooo`03ool0
0?oooooooooo01Cooooo00<0003oooooooooool0=_ooool2ool004Kooooo00?o003oooooooooool0
K_ooool1o`00007ooooo00000ol0003oooooooooo`0Cooooo`03ool00?oooooooooo01?ooooo00<0
003oooooooooool0=Oooool00ooo003oooooooooo`16ooooo`03o`00oooooooooooo06kooooo0Ol0
0001ooooo`0000?o0000ooooooooool05?ooool2ool001?ooooo00<0003oooooooooool0=?ooool0
0ooo003oooooooooo`17ooooo`03o`00oooooooooooo06kooooo0Ol00001ooooo`0000?o0000oooo
ooooool05_ooool2ool0017ooooo00<0003oooooooooool0<_ooool2ool004[ooooo00?o003ooooo
ooooool0K_ooool1o`00007ooooo00000ol0003oooooooooo`0Hooooo`03ool00?oooooooooo00ko
oooo00<0003oooooooooool0<Oooool00ooo003oooooooooo`1:ooooo`03o`00oooooooooooo06ko
oooo0Ol00001ooooo`0000?o0000ooooooooool06Oooool2ool000kooooo00<0003oooooooooool0
;oooool2ool004gooooo00?o003oooooooooool0K_ooool1o`00007ooooo00000ol0003ooooooooo
o`0Kooooo`03ool00?oooooooooo00_ooooo00<0003oooooooooool0;_ooool00ooo003ooooooooo
o`1<ooooo`03o`00oooooooooooo06oooooo0Ol00001ooooo`0000?o0000ooooooooool07?ooool2
ool000_ooooo00<0003oooooooooool0;Oooool00ooo003oooooooooo`1=ooooo`03o`00oooooooo
oooo06oooooo0Ol00001ooooo`0000?o0000ooooooooool07_ooool3ool000Wooooo00<0003ooooo
ooooool0:_ooool2ool0053ooooo00?o003oooooooooool0Koooool1o`00007ooooo00000ol0003o
ooooooooo`0Qooooo`;oo`001oooool00`000?ooooooooooo`0Wooooo`?oo`00D_ooool00ol00?oo
ooooooooo`1_ooooo`7o00000Oooool00003o`000?oooooooooo02?ooooo0_oo0005ooooo`030000
oooooooooooo02Gooooo0_oo001Dooooo`03o`00oooooooooooo073ooooo0Ol00001ooooo`0000?o
0000ooooooooool09Oooool4ool00003ooooo`000?oooooo02;ooooo1?oo001Fooooo`03o`00oooo
oooooooo073ooooo0Ol00001ooooo`0000?o0000ooooooooool0:Oooool2ool00003o`00oooo003o
o`0001gooooo0ooo001Jooooo`03o`00oooooooooooo073ooooo0Ol00001ooooo`0000?o0000oooo
ooooool0:oooool00`000?ooooooooooo`03ool001Cooooo1_oo001Mooooo`03o`00oooooooooooo
073ooooo0Ol00001ooooo`0000?o0000ooooooooool0;?ooool00`000?ooooooooooo`02oooooaCo
o`00H_ooool00ol00?ooooooooooo`1aooooo`7o00000Oooool00003o`000?oooooooooo02cooooo
00<0003oooooooooool0N?ooool00ol00?ooooooooooo`1aooooo`7o00000Oooool00003o`000?oo
oooooooo02cooooo00<0003oooooooooool0N?ooool00ol00?ooooooooooo`1aooooo`7o00000Ooo
ool00003o`000?oooooooooo02gooooo00<0003oooooooooool0M_ooool00ol00?ooooooooooo`1b
ooooo`7o00000Oooool00003o`000?oooooooooo02gooooo00<0003oooooooooool0M_ooool00ol0
0?ooooooooooo`1booooo`7o00000Oooool00003o`000?oooooooooo02gooooo00<0003ooooooooo
ool0M_ooool00ol00?ooooooooooo`1booooo`7o00000Oooool00003o`000?oooooooooo02kooooo
00<0003oooooooooool0M?ooool00ol00?ooooooooooo`1cooooo`7o00000Oooool00003o`000?oo
oooooooo02kooooo00<0003oooooooooool0M?ooool00ol00?ooooooooooo`1cooooo`7o00000Ooo
ool00003o`000?oooooooooo02kooooo00<0003oooooooooool0M?ooool00ol00?ooooooooooo`1c
ooooo`7o00000Oooool00003o`000?oooooooooo02oooooo00<0003oooooooooool0L_ooool00ol0
0?ooooooooooo`1dooooo`7o00000Oooool00003o`000?oooooooooo02oooooo00<0003ooooooooo
ool0L_ooool00ol00?ooooooooooo`1dooooo`7o00000Oooool00003o`000?oooooooooo02oooooo
00<0003oooooooooool0L_ooool00ol00?ooooooooooo`1dooooo`7o00000Oooool00003o`000?oo
oooooooo033ooooo00<0003oooooooooool0Koooool2o`00ogOooooo0Ol00001ooooo`0000?o0000
ooooooooool0<?ooool00`000?ooooooooooo`1_ooooo`03o`00oooooooooooo07Kooooo0Ol00001
ooooo`0000?o0000ooooooooool0<Oooool00`000?ooooooooooo`1]ooooo`03o`00oooooooooooo
07Oooooo0Ol00001ooooo`0000?o0000ooooooooool0<_ooool00`000?ooooooooooo`1/ooooo`03
o`00oooooooooooo07Oooooo0Ol00001ooooo`0000?o0000ooooooooool0<_ooool00`000?oooooo
ooooo`1[ooooo`03o`00oooooooooooo063ooooo0P3oO`0Fooooo`7o00000Oooool00003o`000?oo
oooooooo03?ooooo00<0003oooooooooool0JOooool00ol00?ooooooooooo`1Pooooo`@0ogl05Ooo
ool1o`00007ooooo00000ol0003oooooooooo`0dooooo`030000oooooooooooo06Sooooo00?o003o
ooooooooool0H?ooool40?mo01Gooooo0Ol00001ooooo`0000?o0000ooooooooool0=Oooool00`00
0?ooooooooooo`1Vooooo`03o`00oooooooooooo06;ooooo0P3oO`0Fooooo`7o00000Oooool00003
o`000?oooooooooo03Gooooo00?o003oooooooooool0I_ooool00ol00?ooooooooooo`1jooooo`7o
00000Oooool00003o`000?oooooooooo03Kooooo00?o003oooooooooool0I?ooool00ol00?oooooo
ooooo`1kooooo`7o00000Oooool00003o`000?oooooooooo03Oooooo00?o003oooooooooool0H_oo
ool00ol00?ooooooooooo`1looooo`7o00000Oooool00003o`000?oooooooooo03Sooooo00?o003o
ooooooooool0Goooool2o`00ogoooooo0Ol00001ooooo`0000?o0000ooooooooool0>Oooool00ol0
0?ooooooooooo`1Mooooo`03o`00oooooooooooo07oooooo0Ol00001ooooo`0000?o0000oooooooo
ool0>_ooool00ol00?ooooooooooo`1Kooooo`03o`00oooooooooooo083ooooo0Ol00001ooooo`00
00?o0000ooooooooool0>oooool00ol00?ooooooooooo`1Iooooo`03o`00oooooooooooo087ooooo
0Ol00001ooooo`0000?o0000ooooooooool0??ooool00ol00?ooooooooooo`1Gooooo`03o`00oooo
oooooooo08;ooooo0Ol00001ooooo`0000?o0000ooooooooool0?Oooool00ol00?ooooooooooo`1E
ooooo`03o`00oooooooooooo08?ooooo0Ol00001ooooo`0000?o0000ooooooooool0?_ooool00ol0
0?ooooooooooo`1Cooooo`03o`00oooooooooooo08Cooooo0Ol00001ooooo`0000?o0000oooooooo
ool0?oooool00ol00?ooooooooooo`1@ooooo`;o003o8Oooool20?mo03?ooooo1@3o0?l/ooooo`7o
00000Oooool00003o`000?oooooooooo043ooooo00?o003oooooooooool0C_ooool00ol00?oooooo
ooooo`0Pooooo`@0ogl0<Oooool70?l0ob_ooooo0Ol00001ooooo`0000?o0000ooooooooool0@Ooo
ool2o`00odgooooo00?o003oooooooooool08Oooool40?mo033ooooo2@3o0?lZooooo`7o00000Ooo
ool00003o`000?oooooooooo04?ooooo00?o003oooooooooool0BOooool00ol00?ooooooooooo`0S
ooooo`80ogl0<?ooool;0?l0obWooooo0Ol00001ooooo`0000?o0000ooooooooool0A?ooool2o`00
odSooooo00?o003oooooooooool0Doooool20?mo0003ooooo`3o0?l0o`3o00T0o`3o:Oooool1o`00
007ooooo00000ol0003oooooooooo`16ooooo`;o003oAOooool00ol00?ooooooooooo`1Cooooo`@0
ogl02`3o0?lYooooo`7o00000Oooool00003o`000?oooooooooo04Sooooo00?o003oooooooooool0
@?ooool2o`00ocKooooo0P3oO`0Nooooo`@0ogl02`3o0?lYooooo`7o00000Oooool00003o`000?oo
oooooooo04Wooooo0_l00?lnooooo`;o003o=oooool40?mo01kooooo0P3oO`000oooool0o`3o0?l0
o`090?l0obWooooo0Ol00001ooooo`0000?o0000ooooooooool0Boooool3o`00oc[ooooo00?o003o
ooooooooool0=oooool40?mo02;ooooo2@3o0?lZooooo`7o00000Oooool00003o`000?oooooooooo
04kooooo0_l00?lfooooo`;o003o>oooool20?mo02Cooooo1`3o0?l[ooooo`7o00000Oooool00003
o`000?oooooooooo053ooooo0ol00?l`ooooo`?o003o<oooool20?mo02Gooooo0P3oO`08ooooo`D0
o`3o;?ooool1o`00007ooooo00000ol0003oooooooooo`1Cooooo`;o003o:_ooool4o`00ocGooooo
103oO`0Sooooo`@0ogl0>?ooool1o`00007ooooo00000ol0003oooooooooo`1Eooooo`?o003o8ooo
ool4o`00ocGooooo0P3oO`02ooooo`@0ogl08oooool40?mo00?ooooo0P3oO`0cooooo`7o00000Ooo
ool00003o`000?oooooooooo05Sooooo0ol00?lMooooo`?o003o>?ooool40?mo00;ooooo0P3oO`0C
ooooo`80ogl04?ooool20?mo00?ooooo103oO`0booooo`7o00000Oooool00003o`000?oooooooooo
05_ooooo0ol00?lDooooo`Ko003o>oooool40?mo00Kooooo0P3oO`0>ooooo`@0ogl05?ooool40?mo
03;ooooo0Ol00001ooooo`0000?o0000ooooooooool0G_oooolDo`00od;ooooo0P3oO`06ooooo`@0
ogl03Oooool40?mo01Gooooo0P3oO`0cooooo`7o00000Oooool00003o`000?oooooooooo08_ooooo
0P3oO`0Wooooo`80ogl01_ooool40?mo00kooooo0P3oO`1;ooooo`7o00000Oooool00003o`000?oo
oooooooo08[ooooo103oO`0Uooooo`@0ogl01_ooool20?mo05cooooo0Ol00001ooooo`0000?o0000
ooooooooool0R_ooool40?mo02Gooooo103oO`1Tooooo`7o00000Oooool00003o`000?oooooooooo
08_ooooo0P3oO`0Wooooo`80ogl0IOooool1o`00007ooooo00000ol0003oooooooooo`2Fooooo`80
ogl0>_ooool20?mo04Oooooo0Ol00001ooooo`0000?o0000ooooooooool0UOooool40?mo00kooooo
0P3oO`0Xooooo`@0ogl0A_ooool1o`00007ooooo00000ol0003oooooooooo`2Eooooo`@0ogl03Ooo
ool40?mo02Oooooo103oO`16ooooo`7o00000Oooool00003o`000?oooooooooo09Kooooo0P3oO`0>
ooooo`@0ogl0:?ooool20?mo04Oooooo0Ol00001ooooo`0000?o0000ooooooooool0Yoooool20?mo
07;ooooo0Ol00001ooooo`0000?o0000ooooooooool0joooool20?mo02kooooo0Ol00001ooooo`00
00?o0000ooooooooool0j_ooool40?mo02gooooo0Ol00001ooooo`0000?o0000ooooooooool0e_oo
ool20?mo01;ooooo103oO`0]ooooo`7o00000Oooool00003o`000?oooooooooo0=Gooooo103oO`0B
ooooo`80ogl0;_ooool1o`00007ooooo00000ol0003oooooooooo`2gooooo`80ogl07?ooool40?mo
04;ooooo0Ol00001ooooo`0000?o0000ooooooooool0]_ooool40?mo01cooooo0P3oO`13ooooo`7o
00000Oooool00003o`000?oooooooooo0;?ooooo0P3oO`000oooool0ogl00?mo00020?mo067ooooo
0Ol00001ooooo`0000?o0000ooooooooool0Z?ooool20?mo00Sooooo103oO`000oooool0ogl00?mo
000Jooooo`80ogl0A_ooool1o`00007ooooo00000ol0003oooooooooo`2Vooooo`D0ogl01oooool4
0?mo01Oooooo0P3oO`03ooooo`@0ogl0AOooool1o`00007ooooo00000ol0003oooooooooo`2Uoooo
o`H0ogl02?ooool20?mo01Oooooo103oO`02ooooo`@0ogl0AOooool1o`00007ooooo00000ol0003o
ooooooooo`2Uooooo`D0ogl08_ooool40?mo00?ooooo0P3oO`16ooooo`7o00000Oooool00003o`00
0?oooooooooo07Kooooo0P3oO`0^ooooo`80ogl09Oooool20?mo04cooooo0Ol00001ooooo`0000?o
0000ooooooooool0MOooool40?mo0:;ooooo0Ol00001ooooo`0000?o0000ooooooooool0MOooool4
0?mo00[ooooo0P3oO`2Fooooo`7o00000Oooool00003o`000?oooooooooo07Kooooo0P3oO`0:oooo
o`@0ogl0:_ooool20?mo06Wooooo0Ol00001ooooo`0000?o0000ooooooooool0P_ooool40?mo02Wo
oooo103oO`1Xooooo`7o00000Oooool00003o`000?oooooooooo08?ooooo0P3oO`0Tooooo`80ogl0
1?ooool40?mo06Sooooo0Ol00001ooooo`0000?o0000ooooooooool0Z?ooool40?mo00Cooooo0P3o
O`1Yooooo`7o00000Oooool00003o`000?oooooooooo0:Sooooo103oO`1_ooooo`7o00000Oooool0
0003o`000?oooooooooo0:Wooooo0P3oO`1`ooooo`7o00000Oooool00003o`000?oooooooooo0?oo
oooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o
0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1
o`00007ooooo00000ol0003oooooooooo`24ooooo`80ogl0UOooool1o`00007ooooo00000ol0003o
ooooooooo`23ooooo`@0ogl0U?ooool1o`00007ooooo00000ol0003oooooooooo`23ooooo`@0ogl0
U?ooool1o`00007ooooo00000ol0003oooooooooo`24ooooo`80ogl0;?ooool20?mo06Oooooo0Ol0
0001ooooo`0000?o0000ooooooooool0/Oooool40?mo06Kooooo0Ol00001ooooo`0000?o0000oooo
ooooool0/Oooool40?mo06Kooooo0Ol00001ooooo`0000?o0000ooooooooool0/_ooool20?mo06Oo
oooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oo
oooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003oooooooooo`1kooooo`80ogl0W_ooool1
o`00007ooooo00000ol0003oooooooooo`1jooooo`@0ogl0WOooool1o`00007ooooo00000ol0003o
ooooooooo`1jooooo`@0ogl08?ooool20?mo07_ooooo0Ol00001ooooo`0000?o0000ooooooooool0
Noooool20?mo023ooooo103oO`1jooooo`7o00000Oooool00003o`000?oooooooooo09gooooo103o
O`1jooooo`7o00000Oooool00003o`000?oooooooooo093ooooo0P3oO`0<ooooo`80ogl0Noooool1
o`00007ooooo00000ol0003oooooooooo`2?ooooo`@0ogl0R?ooool1o`00007ooooo00000ol0003o
ooooooooo`2?ooooo`@0ogl0R?ooool1o`00007ooooo00000ol0003oooooooooo`2@ooooo`80ogl0
8oooool20?mo06Cooooo0Ol00001ooooo`0000?o0000ooooooooool0]?ooool40?mo06?ooooo0Ol0
0001ooooo`0000?o0000ooooooooool0]?ooool40?mo06?ooooo0Ol00001ooooo`0000?o0000oooo
ooooool0]Oooool20?mo06Cooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o
00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003ooooooooo
o`3ooooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool0
0003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooooaco
oooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oo
oooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001
ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo0?oo
oooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o
0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1
o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000oooooooo
ool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo
00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolL
ooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003o
ooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o0000
0Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3o
oooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003
o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo
0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oooooo
oooo0?oooooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001oooo
o`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo
7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000
ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00
007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0
oooooolLooooo`7o00000Oooool00003o`000?oooooooooo08kooooo0P3oO`2;ooooo`7o00000Ooo
ool00003o`000?oooooooooo08gooooo103oO`2:ooooo`7o00000Oooool00003o`000?oooooooooo
08gooooo103oO`2:ooooo`7o00000Oooool00003o`000?oooooooooo08kooooo0P3oO`2;ooooo`7o
00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003ooooooooo
o`3ooooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool0
0003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooooaco
oooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oo
oooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001
ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo0?oo
oooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o
0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1
o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000oooooooo
ool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo
00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolL
ooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003o
ooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o0000
0Oooool00?oo00008?l00001ooooo`00\
\>"],
  ImageRangeCache->{{{0, 287}, {287, 0}} -> {-1.01089, -1.01089, 0.00704453, \
0.00704453}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.49505 0.5 0.49505 [
[ 0 0 -0.125 0 ]
[ 0 0 -0.125 0 ]
[ 0 1 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
0 0 m
1 0 L
s
0 0 m
0 1 L
s
0 1 m
1 1 L
s
1 0 m
1 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
1 .5 0 r
.015 w
.03175 .1355 Mdot
.03435 .12523 Mdot
.11137 .12765 Mdot
.14107 .18841 Mdot
.16218 .24538 Mdot
.17294 .21053 Mdot
.18267 .18577 Mdot
.18434 .1304 Mdot
.18553 .30956 Mdot
.20401 .239 Mdot
.21247 .27571 Mdot
.21687 .20845 Mdot
.22376 .2799 Mdot
.22832 .27485 Mdot
.29063 .20974 Mdot
.29686 .25079 Mdot
.30487 .22936 Mdot
.30683 .34623 Mdot
.32055 .20902 Mdot
.32574 .21979 Mdot
.34472 .28521 Mdot
.35998 .36393 Mdot
.36335 .24976 Mdot
.3794 .36608 Mdot
.42386 .66992 Mdot
.44391 .74519 Mdot
.45059 .34198 Mdot
.47208 .67586 Mdot
.47436 .71381 Mdot
.49778 .59825 Mdot
.50874 .91643 Mdot
.51516 .76219 Mdot
.53655 .61374 Mdot
.56563 .75219 Mdot
.59189 .65665 Mdot
.59581 .61604 Mdot
.59923 .6556 Mdot
.60292 .68499 Mdot
.62656 .67779 Mdot
.63555 .72451 Mdot
.63919 .652 Mdot
.64169 .6004 Mdot
.64246 .58611 Mdot
.64496 .54267 Mdot
.64608 .77288 Mdot
.65077 .64308 Mdot
.66065 .57816 Mdot
.67474 .59169 Mdot
.69296 .563 Mdot
.72815 .65902 Mdot
.73169 .58879 Mdot
.74669 .61318 Mdot
.74821 .65474 Mdot
.75963 .63781 Mdot
.79673 .57809 Mdot
.80925 .55852 Mdot
.81525 .58444 Mdot
.83417 .62985 Mdot
.83598 .55526 Mdot
.91595 .49319 Mdot
1 0 0 r
.005 w
.00495 .28842 m
.00628 .29156 L
.01857 .31761 L
.03101 .33781 L
.03525 .34367 L
.05706 .36884 L
.05795 .36972 L
.08312 .39115 L
.08963 .39578 L
.10917 .40763 L
.13523 .41964 L
.14074 .42183 L
.16128 .42794 L
.18734 .43294 L
.21339 .43485 L
.23945 .43375 L
.2655 .42959 L
.29156 .42219 L
.29261 .42183 L
.31761 .41124 L
.34367 .39603 L
.34405 .39578 L
.36972 .37551 L
.37582 .36972 L
.39578 .34724 L
.39849 .34367 L
.41525 .31761 L
.42183 .30485 L
.4275 .29156 L
.436 .2655 L
.44117 .23945 L
.44325 .21339 L
.44232 .18734 L
.43834 .16128 L
.43114 .13523 L
.42183 .11212 L
.42037 .10917 L
.40546 .08312 L
.39578 .06961 L
.38528 .05706 L
.36972 .04137 L
.35758 .03101 L
.34367 .02092 L
.31761 .00569 L
.3162 .00495 L
s
.00495 .12854 m
.01344 .10917 L
.02832 .08312 L
.03101 .07912 L
.04848 .05706 L
.05706 .04802 L
.07619 .03101 L
.08312 .02579 L
.10917 .00934 L
.11742 .00495 L
s
0 0 1 r
.29156 .15739 m
.31761 .14824 L
.34367 .14249 L
.36972 .13986 L
.39578 .14025 L
.42183 .14366 L
.44789 .15025 L
.47394 .16034 L
.47599 .16128 L
.5 .17443 L
.51844 .18734 L
.52606 .19355 L
.54662 .21339 L
.55211 .21962 L
.56712 .23945 L
.57817 .25755 L
.58227 .2655 L
.59322 .29156 L
.60058 .31761 L
.60422 .3392 L
.60471 .34367 L
.6058 .36972 L
.60422 .39297 L
.60387 .39578 L
.59886 .42183 L
.59054 .44789 L
.57848 .47394 L
.57817 .47453 L
.562 .5 L
.55211 .51255 L
.53968 .52606 L
.52606 .53862 L
.50853 .55211 L
.5 .55773 L
.47394 .57183 L
.45901 .57817 L
.44789 .5819 L
.42183 .5885 L
.39578 .59192 L
.36972 .59231 L
.34367 .58968 L
.31761 .58392 L
.29972 .57817 L
.29156 .57477 L
.2655 .56178 L
.25025 .55211 L
.23945 .54409 L
.21914 .52606 L
.21339 .52008 L
.19681 .5 L
Mistroke
.18734 .48608 L
.18031 .47394 L
.16827 .44789 L
.16128 .42714 L
.15996 .42183 L
.15493 .39578 L
.153 .36972 L
.15409 .34367 L
.15823 .31761 L
.16128 .3045 L
.16559 .29156 L
.17653 .2655 L
.18734 .24609 L
.19169 .23945 L
.21221 .21339 L
.21339 .21211 L
.23945 .1881 L
.24041 .18734 L
.2655 .17038 L
.28271 .16128 L
.29156 .15739 L
Mfstroke
1 0 0 r
.03 w
.21687 .20845 Mdot
0 0 1 r
.3794 .36608 Mdot
1 0 0 r
.79703 .00495 m
.79703 .02219 L
.87129 .02219 L
.87129 .00495 L
F
0 0 1 r
.89604 .00495 m
.89604 .23523 L
.9703 .23523 L
.9703 .00495 L
F
1 0 1 r
.04 w
.91595 .49319 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P000182000`400?l00000o`00003ooooooolQ
ooooo`00ool0000Po`00007ooooo00000ol0003oooooooooo`0Mooooo`;oo`00>?ooool3ool00<7o
oooo0Ol00001ooooo`0000?o0000ooooooooool06oooool2ool003gooooo00?oo`00ooooooooool0
Q?oooolEool000Sooooo5Ol00?l8ooooo`7o00000Oooool00003o`000?oooooooooo01[ooooo00?o
o`00ooooooooool0?_ooool2ool008Cooooo5Ooo0008oooooaGo003o2?ooool1o`00007ooooo0000
0ol0003oooooooooo`0Hooooo`;oo`00@oooool00ooo003oooooooooo`21oooooaGoo`002?oooolE
o`00o`Sooooo0Ol00001ooooo`0000?o0000ooooooooool05_ooool2ool004Kooooo00?oo`00oooo
ooooool0P?oooolEool000Sooooo5Ol00?l8ooooo`7o00000Oooool00003o`000?oooooooooo01Go
oooo00?oo`00ooooooooool0Aoooool2ool0083ooooo5Ooo0008oooooaGo003o2?ooool1o`00007o
oooo00000ol0003oooooooooo`0Dooooo`03ool00?oooooooooo04[ooooo00?oo`00ooooooooool0
V_oooolEo`00o`Sooooo0Ol00001ooooo`0000?o0000ooooooooool04oooool00ooo003ooooooooo
o`1<ooooo`03ool00?oooooooooo09Wooooo5Ol00?l8ooooo`7o00000Oooool00003o`000?oooooo
oooo017ooooo0_oo001@ooooo`;oo`00VOoooolEo`00o`Sooooo0Ol00001ooooo`0000?o0000oooo
ooooool04?ooool00ooo003oooooooooo`1Booooo`;oo`00UooooolEo`00o`Sooooo0Ol00001oooo
o`0000?o0000ooooooooool03oooool00ooo003oooooooooo`1Eooooo`03ool00?oooooooooo09Co
oooo5Ol00?l8ooooo`7o00000Oooool00003o`000?oooooooooo00kooooo00?oo`00ooooooooool0
E_ooool00ooo003oooooooooo`2DoooooaGo003o2?ooool1o`00007ooooo00000ol0003ooooooooo
o`0=ooooo`03ool00?oooooooooo05Sooooo00?oo`00ooooooooool0TooooolEo`00o`Sooooo0Ol0
0001ooooo`0000?o0000ooooooooool03Oooool00ooo003oooooooooo`1Iooooo`03ool00?oooooo
oooo09;ooooo5Ol00?l8ooooo`7o00000Oooool00003o`000?oooooooooo00cooooo00?oo`00oooo
ooooool0Foooool00ooo003oooooooooo`2AoooooaGo003o2?ooool1o`00007ooooo00000ol0003o
ooooooooo`0;ooooo`03ool00?oooooooooo05gooooo00?oo`00ooooooooool0T?oooolEo`00o`So
oooo0Ol00001ooooo`0000?o0000ooooooooool02oooool00ooo003oooooooooo`1Mooooo`03ool0
0?oooooooooo093ooooo5Ol00?l8ooooo`7o00000Oooool00003o`000?oooooooooo00[ooooo00?o
o`00ooooooooool0Goooool00ooo003oooooooooo`2?oooooaGo003o2?ooool1o`00007ooooo0000
0ol0003oooooooooo`09ooooo`03ool00?oooooooooo067ooooo00?oo`00ooooooooool0S_oooolE
o`00o`Sooooo0Ol00001ooooo`0000?o0000ooooooooool02?ooool00ooo003oooooooooo`1Soooo
o`03ool00?oooooooooo08gooooo5Ol00?l8ooooo`7o00000Oooool00003o`000?oooooooooo00Oo
oooo00?oo`00ooooooooool0IOooool00ooo003oooooooooo`2<oooooaGo003o2?ooool1o`00007o
oooo00000ol0003oooooooooo`06ooooo`03ool00?oooooooooo06Oooooo00?oo`00ooooooooool0
RooooolEo`00o`Sooooo0Ol00001ooooo`0000?o0000ooooooooool01Oooool00ooo003ooooooooo
o`1Yooooo`03ool00?oooooooooo08[ooooo5Ol00?l8ooooo`7o00000Oooool00003o`000?oooooo
oooo00Gooooo00?oo`00ooooooooool0JOooool00ooo003oooooooooo`2:oooooaGo003o2?ooool1
o`00007ooooo00000ol0003oooooooooo`04ooooo`03ool00?oooooooooo06_ooooo00?oo`00oooo
ooooool0ROoooolEo`00o`Sooooo0Ol00001ooooo`0000?o0000ooooooooool00oooool00ooo003o
ooooooooo`1/ooooo`03ool00?oooooooooo08Wooooo5Ol00?l8ooooo`7o00000Oooool00003o`00
0?oooooooooo00?ooooo00?oo`00ooooooooool0KOooool00ooo003oooooooooo`28oooooaGo003o
2?ooool1o`00007ooooo00000ol0003oooooooooo`02ooooo`03ool00?oooooooooo06kooooo00?o
o`00ooooooooool0R?oooolEo`00o`Sooooo0Ol00001ooooo`0000?o0000ooooooooool00_ooool0
0ooo003oooooooooo`1_ooooo`03ool00?oooooooooo08Oooooo5Ol00?l8ooooo`7o00000Oooool0
0005o`000?oooooooooooooooooo0000L_ooool00ooo003oooooooooo`27oooooaGo003o2?ooool1
o`00007ooooo00001?l0003ooooooooooooo001dooooo`03ool00?oooooooooo08Kooooo5Ol00?l8
ooooo`7o00000Oooool00004o`000?ooooooooooool007Gooooo00?oo`00ooooooooool0QOoooolE
o`00o`Sooooo0Ol00001ooooo`0000?o0000oooooooo0000M_ooool00ooo003oooooooooo`25oooo
oaGo003o2?ooool1o`00007ooooo00000ol0003oooooool00006ooooo`;oogl0Koooool00ooo003o
ooooooooo`24oooooaGo003o2?ooool1o`00007ooooo00000ol0003oooooool00005ooooo`Coogl0
4oooool2oomo05Wooooo00?oo`00ooooooooool0Q?oooolEo`00o`Sooooo0Ol00001ooooo`0000?o
0000ool00?ooool01Oooool4oomo01;ooooo1?ooO`0Booooo`;oogl0A?ooool00ooo003ooooooooo
o`24oooooaGo003o2?ooool1o`00007ooooo00000ol0003oooooooooo`05ooooo`?oogl04oooool4
oomo017ooooo1?ooO`14ooooo`03ool00?oooooooooo08?ooooo5Ol00?l8ooooo`7o00000Oooool0
0003o`000?oooooooooo00Cooooo1?ooO`0Dooooo`;oogl04_ooool4oomo04Cooooo00?oo`00oooo
ooooool0PooooolEo`00o`Sooooo0Ol00001ooooo`0000?o0000ooooooooool01?ooool4oomo02Wo
oooo0_ooO`15ooooo`03ool00?oooooooooo08?ooooo5Ol00?l8ooooo`7o00000Oooool00003o`00
0?oooooooooo00Gooooo0_ooO`1FoooooaKo003o1Oooool00ooo003oooooooooo`23oooooaGo003o
2?ooool1o`00007ooooo00000ol0003oooooooooo`1Jooooo`?o003o5_ooool6o`00o`03ool00?oo
oooooooo08;ooooo5Ol00?l8ooooo`7o00000Oooool00003o`000?oooooooooo05Oooooo0ol00?lO
ooooo`?o003oP_oooolEo`00o`Sooooo0Ol00001ooooo`0000?o0000ooooooooool0E?ooool3o`00
ob;ooooo00?oo`00ooooooooool00ol00?mooooooaGo003o2?ooool1o`00007ooooo00000ol0003o
ooooooooo`1Aooooo`?o003o9Oooool00ooo003oooooooooo`03ooooo`?o003oO?oooolEo`00o`So
oooo0Ol00001ooooo`0000?o0000ooooooooool0Coooool20000obWooooo00?oo`00ooooooooool0
1Oooool3o`00ogWooooo5Ol00?l8ooooo`7o00000Oooool00003o`000?oooooooooo04gooooo0P00
0?l[ooooo`03ool00?oooooooooo00Sooooo0_l00?mgoooooaGo003o2?ooool1o`00007ooooo0000
0ol0003oooooooooo`1:ooooo`<0003o;Oooool00ooo003oooooooooo`0:ooooo`;o003oMOoooolE
o`00o`Sooooo0Ol00001ooooo`0000?o0000ooooooooool0B?ooool20000oc3ooooo00?oo`00oooo
ooooool03?ooool00ol00?ooooooooooo`1boooooaGo003o2?ooool1o`00007ooooo00000ol0003o
ooooooooo`17ooooo`030000oooooooooooo033ooooo00?oo`00ooooooooool03Oooool2o`00og;o
oooo5Ol00?l8ooooo`7o00000Oooool00003o`000?oooooooooo04Gooooo0P000?ldooooo`03ool0
0?oooooooooo00kooooo0_l00?m`oooooaGo003o2?ooool1o`00007ooooo00000ol0003ooooooooo
o`14ooooo`030000oooooooooooo03Cooooo00?oo`00ooooooooool04?ooool2o`00ofkooooo5Ol0
0?l8ooooo`7o00000Oooool00003o`000?oooooooooo02Cooooo0_ooO`0:ooooo`;oogl04Oooool0
0`000?ooooooooooo`0eooooo`03ool00?oooooooooo01;ooooo00?o003oooooooooool0JooooolE
o`00o`Sooooo0Ol00001ooooo`0000?o0000ooooooooool08oooool4oomo00Sooooo1?ooO`0?oooo
o`030000oooooooooooo03Kooooo00?oo`00ooooooooool04oooool00ol00?ooooooooooo`1Zoooo
oaGo003o2?ooool1o`00007ooooo00000ol0003oooooooooo`0Sooooo`Coogl02?ooool4oomo00go
oooo00<0003oo`00ooooool0>?ooool00ooo003oooooooooo`0Dooooo`03o`00oooooooooooo06Wo
oooo5Ol00?l8ooooo`7o00000Oooool00003o`000?oooooooooo02Cooooo0_ooO`0:ooooo`;oogl0
3Oooool00`000?ooooooooooo`0iooooo`03ool00?oooooooooo01Gooooo00?o003oooooooooool0
J?oooolEo`00o`Sooooo0Ol00001ooooo`0000?o0000ooooooooool0>Oooool4ool00003ooooo`00
0?oooooo03_ooooo00?oo`00ooooooooool05_ooool00ol00?ooooooooooo`1WoooooaGo003o2?oo
ool1o`00007ooooo00000ol0003oooooooooo`0hooooo`Koo`00?Oooool00ooo003oooooooooo`0G
ooooo`03o`00oooooooooooo06Kooooo5Ol00?l8ooooo`7o00000Oooool00003o`000?oooooooooo
03Oooooo2?oo000@ooooo`;oogl01oooool2oomo02;ooooo00?oo`00ooooooooool05oooool00ol0
0?ooooooooooo`1UoooooaGo003o2?ooool1o`00007ooooo00000ol0003oooooooooo`0^ooooo`;o
ogl01oooool8ool000oooooo1?ooO`05ooooo`Coogl08Oooool00ooo003oooooooooo`0Hooooo`03
o`00oooooooooooo06Cooooo5Ol00?l8ooooo`7o00000Oooool00003o`000?oooooooooo02gooooo
1?ooO`06ooooo`Soo`003oooool4oomo00Gooooo1?ooO`0Qooooo`03ool00?oooooooooo01Wooooo
00?o003oooooooooool0HooooolEo`00o`Sooooo0Ol00001ooooo`0000?o0000ooooooooool0;Ooo
ool4oomo00Kooooo2?oo000@ooooo`;oogl01oooool3oomo027ooooo00?oo`00ooooooooool06_oo
ool00ol00?ooooooooooo`1RoooooaGo003o2?ooool1o`00007ooooo00000ol0003oooooooooo`0^
ooooo`;oogl02?ooool6ool001[ooooo1?ooO`0Pooooo`03ool00?oooooooooo01_ooooo00?o003o
ooooooooool0HOoooolEo`00o`Sooooo0Ol00001ooooo`0000?o0000ooooooooool0>?ooool00`00
0?ooo`00ool00002ool001_ooooo1?ooO`0Pooooo`03ool00?oooooooooo01cooooo00?o003ooooo
ooooool0H?oooolEo`00o`Sooooo0Ol00001ooooo`0000?o0000ooooooooool0=oooool00`000?oo
ooooooooo`0Iooooo`;oogl01?ooool2oomo027ooooo00?oo`00ooooooooool07?ooool00ol00?oo
ooooooooo`1PoooooaGo003o2?ooool1o`00007ooooo00000ol0003oooooooooo`0fooooo`030000
oooooooooooo01Wooooo1?ooO`0Uooooo`03ool00?oooooooooo01kooooo00?o003oooooooooool0
GooooolEo`00o`Sooooo0Ol00001ooooo`0000?o0000ooooooooool0=_ooool00`000?oooooooooo
o`0Iooooo`Coogl09Oooool00ooo003oooooooooo`0Oooooo`03o`00oooooooooooo05kooooo5Ol0
0?l8ooooo`7o00000Oooool00003o`000?oooooooooo03Gooooo00@0003oooooooooO`3oogl06_oo
ool2oomo02Kooooo00?oo`00ooooooooool08?ooool00ol00?ooooooooooo`1MoooooaGo003o2?oo
ool1o`00007ooooo00000ol0003oooooooooo`0dooooo`030000ooooooooogl000?oogl0@Oooool0
0ooo003oooooooooo`0Qooooo`03o`00oooooooooooo07Wooooo0Ol00001ooooo`0000?o0000oooo
ooooool0:oooool2oomo00Kooooo00<0003oooooooooool01?ooO`11ooooo`03ool00?oooooooooo
027ooooo00?o003oooooooooool0NOooool1o`00007ooooo00000ol0003oooooooooo`0Zooooo`Co
ogl01?ooool00`000?ooooooooooo`02ooooo`;oogl06?ooool2oomo017ooooo0_ooO`0Eooooo`03
ool00?oooooooooo02;ooooo00?o003oooooooooool0N?ooool1o`00007ooooo00000ol0003ooooo
ooooo`0Zooooo`Coogl01?ooool00`000?ooooooooooo`0Kooooo`Coogl03oooool4oomo01Cooooo
00?oo`00ooooooooool08oooool00ol00?ooooooooooo`1gooooo`7o00000Oooool00003o`000?oo
oooooooo02_ooooo0_ooO`04ooooo`030000oooooooooooo01cooooo1?ooO`0?ooooo`Coogl05?oo
ool00ooo003oooooooooo`0Sooooo`03o`00oooooooooooo07Oooooo0Ol00001ooooo`0000?o0000
ooooooooool0<Oooool00`000?ooooooooooo`0Mooooo`;oogl04Oooool2oomo01Cooooo00?oo`00
ooooooooool09Oooool00ol00?ooooooooooo`1fooooo`7o00000Oooool00003o`000?oooooooooo
033ooooo00<0003oooooooooool0Aoooool00ooo003oooooooooo`0Uooooo`03o`00oooooooooooo
07Kooooo0Ol00001ooooo`0000?o0000ooooooooool0<?ooool00`000?ooooooooooo`17ooooo`03
ool00?oooooooooo02Kooooo00?o003oooooooooool0MOooool1o`00007ooooo00000ol0003ooooo
ooooo`0_ooooo`030000oooooooooooo04Sooooo00?oo`00ooooooooool09oooool00ol00?oooooo
ooooo`1dooooo`7o00000Oooool00003o`000?oooooooooo02oooooo00<0003oooooooooool01ooo
ool2oomo00;ooooo0_ooO`0kooooo`03ool00?oooooooooo02Oooooo00?o003oooooooooool0M?oo
ool1o`00007ooooo00000ol0003oooooooooo`0^ooooo`030000oooooooooooo00Oooooo2?ooO`0i
ooooo`03ool00?oooooooooo02Wooooo00?o003oooooooooool0Loooool1o`00007ooooo00000ol0
003oooooooooo`0^ooooo`030000oooooooooooo00Oooooo2?ooO`0iooooo`03ool00?oooooooooo
02Wooooo00?o003oooooooooool0Loooool1o`00007ooooo00000ol0003oooooooooo`0]ooooo`03
0000oooooooooooo00Wooooo1_ooO`0Pooooo`;oogl05oooool00ooo003oooooooooo`0[ooooo`03
o`00oooooooooooo07;ooooo0Ol00001ooooo`0000?o0000ooooooooool0;Oooool00`000?oooooo
ooooo`0;ooooo`Coogl07oooool4oomo01Kooooo00?oo`00ooooooooool0:oooool00ol00?oooooo
ooooo`1booooo`7o00000Oooool00003o`000?oo003ooooo02gooooo00<0003oooooooooool03?oo
ool2oomo023ooooo1?ooO`0Fooooo`03ool00?oooooooooo02_ooooo00?o003oooooooooool0L_oo
ool1o`00007ooooo00000ol0003oo`00ooooo`0/ooooo`030000oooooooooooo033ooooo0_ooO`0F
ooooo`03ool00?oooooooooo02gooooo00?o003oooooooooool0LOooool1o`00007ooooo00000ol0
003oo`00ooooo`0/ooooo`030000oooooooooooo04Sooooo00?oo`00ooooooooool0;Oooool00ol0
0?ooooooooooo`1aooooo`7o00000Oooool00003o`000?ooooooo`0002cooooo00<0003ooooooooo
ool0B?ooool00ooo003oooooooooo`0]ooooo`03o`00oooooooooooo077ooooo0Ol00001ooooo`00
00?o0000oooooooo0000:oooool00`000?ooooooooooo`18ooooo`03ool00?oooooooooo02oooooo
00?o003oooooooooool0L?ooool1o`00007ooooo00001?l0003ooooooooooooo000Zooooo`030000
oooooooooooo00?ooooo0_ooO`13ooooo`03ool00?oooooooooo02oooooo00?o003oooooooooool0
L?ooool1o`00007ooooo00001?l0003ooooooooooooo000Zooooo`030000oooooooooooo00;ooooo
1?ooO`12ooooo`03ool00?oooooooooo02oooooo00?o003oooooooooool0L?ooool1o`00007ooooo
00001Ol0003oooooooooooooooooo`0002Wooooo00<0003oooooooooool00_ooool4oomo047ooooo
00?oo`00ooooooooool0<?ooool00ol00?ooooooooooo`1`ooooo`7o00000Oooool00005o`000?oo
oooooooooooooooo0000:?ooool00`000?ooooooooooo`04ooooo`;oogl0@_ooool00ooo003ooooo
ooooo`0aooooo`03o`00oooooooooooo06oooooo0Ol00001ooooo`0000?o0000ooooooooool00_oo
ool00ooo003oooooooooo`0Uooooo`030000oooooooooooo04Oooooo00?oo`00ooooooooool0<_oo
ool00ol00?ooooooooooo`1_ooooo`7o00000Oooool00003o`000?oooooooooo00;ooooo00?oo`00
ooooooooool09Oooool00`000?ooooooooooo`17ooooo`03ool00?oooooooooo03;ooooo00?o003o
ooooooooool0Koooool1o`00007ooooo00000ol0003oooooooooo`03ooooo`03ool00?oooooooooo
02Cooooo00<0003oooooooooool0A_ooool00ooo003oooooooooo`0cooooo`03o`00oooooooooooo
06oooooo0Ol00001ooooo`0000?o0000ooooooooool01?ooool00ooo003oooooooooo`0Sooooo`03
0000oooooooooooo04Gooooo00?oo`00ooooooooool0=?ooool00ol00?ooooooooooo`1_ooooo`7o
00000Oooool00003o`000?oooooooooo00Gooooo00?oo`00ooooooooool08Oooool00`000?oooooo
ooooo`15ooooo`03ool00?oooooooooo03Kooooo00?o003oooooooooool0K_ooool1o`00007ooooo
00000ol0003oooooooooo`06ooooo`03ool00?oooooooooo023ooooo00<0003oooooooooool0AOoo
ool00ooo003oooooooooo`09ooooo`;oogl0:oooool00ol00?ooooooooooo`1^ooooo`7o00000Ooo
ool00003o`000?oooooooooo00Kooooo00?oo`00ooooooooool08?ooool00`000?ooooooooooo`14
ooooo`03ool00?oooooooooo00Wooooo1?ooO`0Zooooo`03o`00oooooooooooo06kooooo0Ol00001
ooooo`0000?o0000ooooooooool01oooool00ooo003oooooooooo`0Oooooo`030000oooooooooooo
02Sooooo0_ooO`0Iooooo`03ool00?oooooooooo00[ooooo1?ooO`0Zooooo`03o`00oooooooooooo
06kooooo0Ol00001ooooo`0000?o0000ooooooooool01oooool00ooo003oooooooooo`0Oooooo`03
0000oooooooooooo02Oooooo1?ooO`0Gooooo`03ool00?oooooooooo00cooooo0_ooO`0[ooooo`03
o`00oooooooooooo06kooooo0Ol00001ooooo`0000?o0000ooooooooool02?ooool00ooo003ooooo
ooooo`0Nooooo`030000oooooooooooo02Oooooo1?ooO`0Gooooo`03ool00?oooooooooo03Wooooo
00?o003oooooooooool0K_ooool1o`00007ooooo00000ol0003oooooooooo`09ooooo`03ool00?oo
oooooooo01gooooo00<0003oooooooooool0:?ooool2oomo01;ooooo1?l00?l00oooooooo`00oooo
o`0kooooo`03o`00oooooooooooo06kooooo0Ol00001ooooo`0000?o0000ooooooooool02_ooool0
0ooo003oooooooooo`0Looooo`030000oooooooooooo03_ooooo1_l00?lmooooo`03o`00oooooooo
oooo06kooooo0Ol00001ooooo`0000?o0000ooooooooool02oooool00ooo003oooooooooo`0Koooo
o`030000oooooooooooo03Oooooo0_ooO`000ooooooo003oo`00o`06o`00occooooo00?o003ooooo
ooooool0K_ooool1o`00007ooooo00000ol0003oooooooooo`0<ooooo`03ool00?oooooooooo01[o
oooo00<0003oooooooooool0=_ooool4oomo00So003o??ooool00ol00?ooooooooooo`1^ooooo`7o
00000Oooool00003o`000?oooooooooo00gooooo00?oo`00ooooooooool06Oooool00`000?oooooo
ooooo`0fooooo`Coogl02?l00?llooooo`03o`00oooooooooooo06kooooo0Ol00001ooooo`0000?o
0000ooooooooool03Oooool2ool001[ooooo00<0003oooooooooool0=oooool2oomo0003ooooool0
0?oo003o00Ko003o??ooool00ol00?ooooooooooo`1^ooooo`7o00000Oooool00003o`000?oooooo
oooo00oooooo00?oo`00ooooooooool05oooool00`000?ooooooooooo`0jooooo`03ool00?l00?oo
003o00Co003o?Oooool00ol00?ooooooooooo`1^ooooo`7o00000Oooool00003o`000?oooooooooo
013ooooo00?oo`00ooooooooool05_ooool00`000?ooooooooooo`0iooooo`03ool00?oooooooooo
00Co003o?_ooool00ol00?ooooooooooo`1^ooooo`7o00000Oooool00003o`000?oooooooooo017o
oooo00?oo`00ooooooooool05Oooool00`000?ooooooooooo`0hooooo`03ool00?oooooooooo04?o
oooo00?o003oooooooooool0K_ooool1o`00007ooooo00000ol0003oooooooooo`0Booooo`03ool0
0?oooooooooo01Cooooo00<0003oooooooooool0=_ooool2ool004Kooooo00?o003oooooooooool0
K_ooool1o`00007ooooo00000ol0003oooooooooo`0Cooooo`03ool00?oooooooooo01?ooooo00<0
003oooooooooool0=Oooool00ooo003oooooooooo`16ooooo`03o`00oooooooooooo06kooooo0Ol0
0001ooooo`0000?o0000ooooooooool05?ooool2ool001?ooooo00<0003oooooooooool0=?ooool0
0ooo003oooooooooo`17ooooo`03o`00oooooooooooo06kooooo0Ol00001ooooo`0000?o0000oooo
ooooool05_ooool2ool0017ooooo00<0003oooooooooool0<_ooool2ool004[ooooo00?o003ooooo
ooooool0K_ooool1o`00007ooooo00000ol0003oooooooooo`0Hooooo`03ool00?oooooooooo00ko
oooo00<0003oooooooooool0<Oooool00ooo003oooooooooo`1:ooooo`03o`00oooooooooooo06ko
oooo0Ol00001ooooo`0000?o0000ooooooooool06Oooool2ool000kooooo00<0003oooooooooool0
;oooool2ool004gooooo00?o003oooooooooool0K_ooool1o`00007ooooo00000ol0003ooooooooo
o`0Kooooo`03ool00?oooooooooo00_ooooo00<0003oooooooooool0;_ooool00ooo003ooooooooo
o`1<ooooo`03o`00oooooooooooo06oooooo0Ol00001ooooo`0000?o0000ooooooooool07?ooool2
ool000_ooooo00<0003oooooooooool0;Oooool00ooo003oooooooooo`1=ooooo`03o`00oooooooo
oooo06oooooo0Ol00001ooooo`0000?o0000ooooooooool07_ooool3ool000Wooooo00<0003ooooo
ooooool0:_ooool2ool0053ooooo00?o003oooooooooool0Koooool1o`00007ooooo00000ol0003o
ooooooooo`0Qooooo`;oo`001oooool00`000?ooooooooooo`0Wooooo`?oo`00D_ooool00ol00?oo
ooooooooo`1_ooooo`7o00000Oooool00003o`000?oooooooooo02?ooooo0_oo0005ooooo`030000
oooooooooooo02Gooooo0_oo001Dooooo`03o`00oooooooooooo073ooooo0Ol00001ooooo`0000?o
0000ooooooooool09Oooool4ool00003ooooo`000?oooooo02;ooooo1?oo001Fooooo`03o`00oooo
oooooooo073ooooo0Ol00001ooooo`0000?o0000ooooooooool0:Oooool2ool00003o`00oooo003o
o`0001gooooo0ooo001Jooooo`03o`00oooooooooooo073ooooo0Ol00001ooooo`0000?o0000oooo
ooooool0:oooool00`000?ooooooooooo`03ool001Cooooo1_oo001Mooooo`03o`00oooooooooooo
073ooooo0Ol00001ooooo`0000?o0000ooooooooool0;?ooool00`000?ooooooooooo`02oooooaCo
o`00H_ooool00ol00?ooooooooooo`1aooooo`7o00000Oooool00003o`000?oooooooooo02cooooo
00<0003oooooooooool0N?ooool00ol00?ooooooooooo`1aooooo`7o00000Oooool00003o`000?oo
oooooooo02cooooo00<0003oooooooooool0N?ooool00ol00?ooooooooooo`1aooooo`7o00000Ooo
ool00003o`000?oooooooooo02gooooo00<0003oooooooooool0M_ooool00ol00?ooooooooooo`1b
ooooo`7o00000Oooool00003o`000?oooooooooo02gooooo00<0003oooooooooool0M_ooool00ol0
0?ooooooooooo`1booooo`7o00000Oooool00003o`000?oooooooooo02gooooo00<0003ooooooooo
ool0M_ooool00ol00?ooooooooooo`1booooo`7o00000Oooool00003o`000?oooooooooo02kooooo
00<0003oooooooooool0M?ooool00ol00?ooooooooooo`1cooooo`7o00000Oooool00003o`000?oo
oooooooo02kooooo00<0003oooooooooool0M?ooool00ol00?ooooooooooo`1cooooo`7o00000Ooo
ool00003o`000?oooooooooo02kooooo00<0003oooooooooool0M?ooool00ol00?ooooooooooo`1c
ooooo`7o00000Oooool00003o`000?oooooooooo02oooooo00<0003oooooooooool0L_ooool00ol0
0?ooooooooooo`1dooooo`7o00000Oooool00003o`000?oooooooooo02oooooo00<0003ooooooooo
ool0L_ooool00ol00?ooooooooooo`1dooooo`7o00000Oooool00003o`000?oooooooooo02oooooo
00<0003oooooooooool0L_ooool00ol00?ooooooooooo`1dooooo`7o00000Oooool00003o`000?oo
oooooooo033ooooo00<0003oooooooooool0Koooool2o`00oegooooo1Ooo0?lEooooo`7o00000Ooo
ool00003o`000?oooooooooo033ooooo00<0003oooooooooool0Koooool00ol00?ooooooooooo`1K
ooooo`Ooo`3o5?ooool1o`00007ooooo00000ol0003oooooooooo`0aooooo`030000oooooooooooo
06gooooo00?o003oooooooooool0Foooool9ool0oa?ooooo0Ol00001ooooo`0000?o0000oooooooo
ool0<_ooool00`000?ooooooooooo`1/ooooo`03o`00oooooooooooo05[ooooo2ooo0?lBooooo`7o
00000Oooool00003o`000?oooooooooo03;ooooo00<0003oooooooooool0Joooool00ol00?oooooo
ooooo`1Kooooo`_oo`3o4_ooool1o`00007ooooo00000ol0003oooooooooo`0cooooo`030000oooo
oooooooo06Wooooo00?o003oooooooooool0G?ooool;ool0oa;ooooo0Ol00001ooooo`0000?o0000
ooooooooool0=?ooool00`000?ooooooooooo`1Xooooo`03o`00oooooooooooo05cooooo2ooo0?lB
ooooo`7o00000Oooool00003o`000?oooooooooo03Gooooo00<0003oooooooooool0I_ooool00ol0
0?ooooooooooo`1Mooooo`_oo`3o4_ooool1o`00007ooooo00000ol0003oooooooooo`0eooooo`03
o`00oooooooooooo06Kooooo00?o003oooooooooool0G_ooool9ool0oa?ooooo0Ol00001ooooo`00
00?o0000ooooooooool0=_ooool00ol00?ooooooooooo`1Tooooo`03o`00oooooooooooo063ooooo
1ooo0?lDooooo`7o00000Oooool00003o`000?oooooooooo03Oooooo00?o003oooooooooool0H_oo
ool00ol00?ooooooooooo`1Rooooo`Goo`3o5Oooool1o`00007ooooo00000ol0003oooooooooo`0h
ooooo`03o`00oooooooooooo05oooooo0_l00?moooooo`7o00000Oooool00003o`000?oooooooooo
03Wooooo00?o003oooooooooool0GOooool00ol00?ooooooooooo`1oooooo`7o00000Oooool00003
o`000?oooooooooo03[ooooo00?o003oooooooooool0Foooool00ol00?ooooooooooo`20ooooo`7o
00000Oooool00003o`000?oooooooooo03_ooooo00?o003oooooooooool0FOooool00ol00?oooooo
ooooo`21ooooo`7o00000Oooool00003o`000?oooooooooo03cooooo00?o003oooooooooool0Eooo
ool00ol00?ooooooooooo`22ooooo`7o00000Oooool00003o`000?oooooooooo03gooooo00?o003o
ooooooooool0EOooool00ol00?ooooooooooo`23ooooo`7o00000Oooool00003o`000?oooooooooo
03kooooo00?o003oooooooooool0Doooool00ol00?ooooooooooo`24ooooo`7o00000Oooool00003
o`000?oooooooooo03oooooo00?o003oooooooooool0D?ooool2o`00ob7ooooo0_ooO`1Tooooo`7o
00000Oooool00003o`000?oooooooooo043ooooo00?o003oooooooooool0C_ooool00ol00?oooooo
ooooo`0Pooooo`Coogl0Hoooool1o`00007ooooo00000ol0003oooooooooo`11ooooo`;o003oCOoo
ool00ol00?ooooooooooo`0Qooooo`Coogl0Hoooool1o`00007ooooo00000ol0003oooooooooo`13
ooooo`03o`00oooooooooooo04Wooooo00?o003oooooooooool08oooool2oomo03Gooooo0_ooO`0]
ooooo`7o00000Oooool00003o`000?oooooooooo04Cooooo0_l00?m8ooooo`03o`00oooooooooooo
05?ooooo0_ooO`05ooooo`Coogl0;?ooool1o`00007ooooo00000ol0003oooooooooo`16ooooo`;o
003oAOooool00ol00?ooooooooooo`1Cooooo`Coogl01?ooool4oomo02cooooo0Ol00001ooooo`00
00?o0000ooooooooool0B?ooool00ol00?ooooooooooo`10ooooo`;o003o=_ooool2oomo01kooooo
1?ooO`05ooooo`;oogl0;Oooool1o`00007ooooo00000ol0003oooooooooo`19ooooo`;o003o?_oo
ool2o`00ocOooooo1?ooO`0Nooooo`;oogl0=Oooool1o`00007ooooo00000ol0003oooooooooo`1;
ooooo`?o003o>_ooool00ol00?ooooooooooo`0gooooo`Coogl0EOooool1o`00007ooooo00000ol0
003oooooooooo`1>ooooo`;o003o=_ooool2o`00oc_ooooo0_ooO`1Fooooo`7o00000Oooool00003
o`000?oooooooooo053ooooo0ol00?l`ooooo`?o003o<oooool2oomo02Gooooo0_ooO`0iooooo`7o
00000Oooool00003o`000?oooooooooo05?ooooo0_l00?lZooooo`Co003o=Oooool4oomo02?ooooo
1?ooO`0hooooo`7o00000Oooool00003o`000?oooooooooo05Gooooo0ol00?lSooooo`Co003o=Ooo
ool2oomo00;ooooo1?ooO`0Sooooo`Coogl00oooool2oomo03?ooooo0Ol00001ooooo`0000?o0000
ooooooooool0F?ooool3o`00oagooooo0ol00?lhooooo`Coogl00_ooool2oomo01?ooooo0_ooO`0@
ooooo`;oogl00oooool4oomo03;ooooo0Ol00001ooooo`0000?o0000ooooooooool0Foooool3o`00
oaCooooo1_l00?lkooooo`Coogl01_ooool2oomo00kooooo1?ooO`0Dooooo`Coogl0<_ooool1o`00
007ooooo00000ol0003oooooooooo`1NoooooaCo003o@_ooool2oomo00Kooooo1?ooO`0=ooooo`Co
ogl05Oooool2oomo03?ooooo0Ol00001ooooo`0000?o0000ooooooooool0Roooool2oomo02Oooooo
0_ooO`06ooooo`Coogl03_ooool2oomo04_ooooo0Ol00001ooooo`0000?o0000ooooooooool0R_oo
ool4oomo02Gooooo1?ooO`06ooooo`;oogl0G?ooool1o`00007ooooo00000ol0003oooooooooo`2:
ooooo`Coogl09Oooool4oomo06Cooooo0Ol00001ooooo`0000?o0000ooooooooool0Roooool2oomo
02Oooooo0_ooO`1Uooooo`7o00000Oooool00003o`000?oooooooooo09Kooooo0_ooO`0jooooo`;o
ogl0Aoooool1o`00007ooooo00000ol0003oooooooooo`2Eooooo`Coogl03_ooool2oomo02Sooooo
1?ooO`16ooooo`7o00000Oooool00003o`000?oooooooooo09Gooooo1?ooO`0=ooooo`Coogl09ooo
ool4oomo04Kooooo0Ol00001ooooo`0000?o0000ooooooooool0U_ooool2oomo00kooooo1?ooO`0X
ooooo`;oogl0Aoooool1o`00007ooooo00000ol0003oooooooooo`2Wooooo`;oogl0L_ooool1o`00
007ooooo00000ol0003oooooooooo`3[ooooo`;oogl0;_ooool1o`00007ooooo00000ol0003ooooo
ooooo`3Zooooo`Coogl0;Oooool1o`00007ooooo00000ol0003oooooooooo`3Fooooo`;oogl04_oo
ool4oomo02gooooo0Ol00001ooooo`0000?o0000ooooooooool0eOooool4oomo01;ooooo0_ooO`0^
ooooo`7o00000Oooool00003o`000?oooooooooo0;Oooooo0_ooO`0Looooo`Coogl0@_ooool1o`00
007ooooo00000ol0003oooooooooo`2fooooo`Coogl07?ooool2oomo04?ooooo0Ol00001ooooo`00
00?o0000ooooooooool0/oooool2oomo0003ooooooooO`3oogl000;oogl0HOooool1o`00007ooooo
00000ol0003oooooooooo`2Xooooo`;oogl02?ooool4oomo0003ooooooooO`3oogl001[ooooo0_oo
O`16ooooo`7o00000Oooool00003o`000?oooooooooo0:Kooooo1OooO`07ooooo`Coogl05oooool2
oomo00?ooooo1?ooO`15ooooo`7o00000Oooool00003o`000?oooooooooo0:Gooooo1_ooO`08oooo
o`;oogl05oooool4oomo00;ooooo1?ooO`15ooooo`7o00000Oooool00003o`000?oooooooooo0:Go
oooo1OooO`0Rooooo`Coogl00oooool2oomo04Kooooo0Ol00001ooooo`0000?o0000ooooooooool0
M_ooool2oomo02kooooo0_ooO`0Uooooo`;oogl0C?ooool1o`00007ooooo00000ol0003ooooooooo
o`1eooooo`Coogl0X_ooool1o`00007ooooo00000ol0003oooooooooo`1eooooo`Coogl02_ooool2
oomo09Kooooo0Ol00001ooooo`0000?o0000ooooooooool0M_ooool2oomo00[ooooo1?ooO`0Zoooo
o`;oogl0JOooool1o`00007ooooo00000ol0003oooooooooo`22ooooo`Coogl0:Oooool4oomo06So
oooo0Ol00001ooooo`0000?o0000ooooooooool0Poooool2oomo02Cooooo0_ooO`04ooooo`Coogl0
J?ooool1o`00007ooooo00000ol0003oooooooooo`2Xooooo`Coogl01?ooool2oomo06Wooooo0Ol0
0001ooooo`0000?o0000ooooooooool0Z?ooool4oomo06oooooo0Ol00001ooooo`0000?o0000oooo
ooooool0ZOooool2oomo073ooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o
00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003ooooooooo
o`3ooooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool0
0003o`000?oooooooooo08Cooooo0_ooO`2Eooooo`7o00000Oooool00003o`000?oooooooooo08?o
oooo1?ooO`2Dooooo`7o00000Oooool00003o`000?oooooooooo08?ooooo1?ooO`2Dooooo`7o0000
0Oooool00003o`000?oooooooooo08Cooooo0_ooO`0/ooooo`;oogl0Ioooool1o`00007ooooo0000
0ol0003oooooooooo`2aooooo`Coogl0I_ooool1o`00007ooooo00000ol0003oooooooooo`2aoooo
o`Coogl0I_ooool1o`00007ooooo00000ol0003oooooooooo`2booooo`;oogl0Ioooool1o`00007o
oooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooo
oolLooooo`7o00000Oooool00003o`000?oooooooooo07_ooooo0_ooO`2Nooooo`7o00000Oooool0
0003o`000?oooooooooo07[ooooo1?ooO`2Mooooo`7o00000Oooool00003o`000?oooooooooo07[o
oooo1?ooO`0Pooooo`;oogl0Noooool1o`00007ooooo00000ol0003oooooooooo`1kooooo`;oogl0
8?ooool4oomo07[ooooo0Ol00001ooooo`0000?o0000ooooooooool0WOooool4oomo07[ooooo0Ol0
0001ooooo`0000?o0000ooooooooool0T?ooool2oomo00cooooo0_ooO`1kooooo`7o00000Oooool0
0003o`000?oooooooooo08oooooo1?ooO`28ooooo`7o00000Oooool00003o`000?oooooooooo08oo
oooo1?ooO`28ooooo`7o00000Oooool00003o`000?oooooooooo093ooooo0_ooO`0Sooooo`;oogl0
I?ooool1o`00007ooooo00000ol0003oooooooooo`2dooooo`Coogl0Hoooool1o`00007ooooo0000
0ol0003oooooooooo`2dooooo`Coogl0Hoooool1o`00007ooooo00000ol0003oooooooooo`2eoooo
o`;oogl0I?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`00
00?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?oo
ool1o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000oooo
ooooool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007o
oooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooo
oolLooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0
003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o
00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003ooooooooo
o`3ooooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool0
0003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooooaco
oooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oo
oooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001
ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo0?oo
oooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o
0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1
o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000oooooooo
ool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo
00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolL
ooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003o
ooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o0000
0Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3o
oooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003
o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo
0Ol00001ooooo`0000?o0000ooooooooool0S_ooool2oomo08_ooooo0Ol00001ooooo`0000?o0000
ooooooooool0SOooool4oomo08[ooooo0Ol00001ooooo`0000?o0000ooooooooool0SOooool4oomo
08[ooooo0Ol00001ooooo`0000?o0000ooooooooool0S_ooool2oomo08_ooooo0Ol00001ooooo`00
00?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?oo
ool1o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000oooo
ooooool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007o
oooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooo
oolLooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0
003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o
00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003ooooooooo
o`3ooooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool0
0003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooooaco
oooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oo
oooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001
ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo0?oo
oooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`00ool0
000Po`00007ooooo0000\
\>"],
  ImageRangeCache->{{{0, 287}, {287, 0}} -> {-1.01089, -1.01089, 0.00704453, \
0.00704453}}]
}, Closed]]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Global visualization", "Subsection"],

Cell[CellGroupData[{

Cell["Computation", "Subsubsection"],

Cell[BoxData[
    \(\(p1\  = \ \(ClassProbabilitiesDataSet[{{x, y}}, tstModel]\  // \ 
            Flatten\)\  // \ First;\)\)], "Input"]
}, Closed]],

Cell[CellGroupData[{

Cell["Visualization", "Subsubsection"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(ContourPlot[p1, {x, \(-1\), 1}, {y, \(-1\), 1}, 
        PlotPoints \[Rule] 25, \ FrameTicks \[Rule] None, 
        ColorFunction \[Rule] \((RGBColor\  @@ \ \((#\ \((List\  @@ \ \ \
colors[\([1]\)])\)\  + \ \((1 - #)\)\ List\  @@ \ 
                        colors[\([2]\)])\) &)\)];\)\)], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% ContourGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.480769 0.5 0.480769 [
[ 0 0 -0.125 0 ]
[ 0 0 -0.125 0 ]
[ 0 1 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
0 0 m
1 0 L
s
0 0 m
0 1 L
s
0 1 m
1 1 L
s
1 0 m
1 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
.2 0 .8 r
.01923 .98077 m
.98077 .98077 L
.98077 .01923 L
.01923 .01923 L
F
0 g
.5 Mabswid
.3 0 .7 r
.01923 .97902 m
.05639 .94071 L
.05929 .93771 L
.09524 .90064 L
.09936 .8964 L
.1341 .86058 L
.13942 .85509 L
.17296 .82051 L
.17949 .81378 L
.21181 .78045 L
.21955 .77247 L
.25067 .74038 L
.25962 .73116 L
.28953 .70032 L
.29968 .68985 L
.32838 .66026 L
.33974 .64854 L
.36724 .62019 L
.37981 .60723 L
.4061 .58013 L
.41987 .56593 L
.44495 .54006 L
.45994 .52462 L
.48381 .5 L
.5 .48331 L
.52267 .45994 L
.54006 .442 L
.56152 .41987 L
.58013 .40069 L
.60038 .37981 L
.62019 .35938 L
.63924 .33974 L
.66026 .31807 L
.6781 .29968 L
.70032 .27677 L
.71695 .25962 L
.74038 .23546 L
.75581 .21955 L
.78045 .19415 L
.79467 .17949 L
.82051 .15284 L
.83353 .13942 L
.86058 .11153 L
.87238 .09936 L
.90064 .07022 L
.91124 .05929 L
.94071 .02893 L
.9501 .01923 L
.01923 .01923 L
F
0 g
.01923 .97902 m
.05639 .94071 L
.05929 .93771 L
.09524 .90064 L
.09936 .8964 L
.1341 .86058 L
.13942 .85509 L
.17296 .82051 L
.17949 .81378 L
.21181 .78045 L
.21955 .77247 L
.25067 .74038 L
.25962 .73116 L
.28953 .70032 L
.29968 .68985 L
.32838 .66026 L
.33974 .64854 L
.36724 .62019 L
.37981 .60723 L
.4061 .58013 L
.41987 .56593 L
.44495 .54006 L
.45994 .52462 L
.48381 .5 L
.5 .48331 L
.52267 .45994 L
.54006 .442 L
.56152 .41987 L
.58013 .40069 L
.60038 .37981 L
.62019 .35938 L
.63924 .33974 L
.66026 .31807 L
.6781 .29968 L
.70032 .27677 L
.71695 .25962 L
.74038 .23546 L
.75581 .21955 L
.78045 .19415 L
.79467 .17949 L
.82051 .15284 L
.83353 .13942 L
.86058 .11153 L
.87238 .09936 L
.90064 .07022 L
.91124 .05929 L
.94071 .02893 L
.9501 .01923 L
s
.4 0 .6 r
.01923 .84546 m
.04343 .82051 L
.05929 .80415 L
.08228 .78045 L
.09936 .76284 L
.12114 .74038 L
.13942 .72153 L
.16 .70032 L
.17949 .68022 L
.19885 .66026 L
.21955 .63892 L
.23771 .62019 L
.25962 .59761 L
.27657 .58013 L
.29968 .5563 L
.31542 .54006 L
.33974 .51499 L
.35428 .5 L
.37981 .47368 L
.39314 .45994 L
.41987 .43237 L
.432 .41987 L
.45994 .39106 L
.47085 .37981 L
.5 .34976 L
.50971 .33974 L
.54006 .30845 L
.54857 .29968 L
.58013 .26714 L
.58743 .25962 L
.62019 .22583 L
.62628 .21955 L
.66026 .18452 L
.66514 .17949 L
.70032 .14321 L
.704 .13942 L
.74038 .10191 L
.74286 .09936 L
.78045 .0606 L
.78171 .05929 L
.82051 .01929 L
.82057 .01923 L
.01923 .01923 L
F
0 g
.01923 .84546 m
.04343 .82051 L
.05929 .80415 L
.08228 .78045 L
.09936 .76284 L
.12114 .74038 L
.13942 .72153 L
.16 .70032 L
.17949 .68022 L
.19885 .66026 L
.21955 .63892 L
.23771 .62019 L
.25962 .59761 L
.27657 .58013 L
.29968 .5563 L
.31542 .54006 L
.33974 .51499 L
.35428 .5 L
.37981 .47368 L
.39314 .45994 L
.41987 .43237 L
.432 .41987 L
.45994 .39106 L
.47085 .37981 L
.5 .34976 L
.50971 .33974 L
.54006 .30845 L
.54857 .29968 L
.58013 .26714 L
.58743 .25962 L
.62019 .22583 L
.62628 .21955 L
.66026 .18452 L
.66514 .17949 L
.70032 .14321 L
.704 .13942 L
.74038 .10191 L
.74286 .09936 L
.78045 .0606 L
.78171 .05929 L
.82051 .01929 L
.82057 .01923 L
s
.5 0 .5 r
.01923 .73093 m
.04892 .70032 L
.05929 .68962 L
.08777 .66026 L
.09936 .64831 L
.12663 .62019 L
.13942 .607 L
.16549 .58013 L
.17949 .56569 L
.20434 .54006 L
.21955 .52439 L
.2432 .5 L
.25962 .48308 L
.28206 .45994 L
.29968 .44177 L
.32092 .41987 L
.33974 .40046 L
.35977 .37981 L
.37981 .35915 L
.39863 .33974 L
.41987 .31784 L
.43749 .29968 L
.45994 .27653 L
.47634 .25962 L
.5 .23523 L
.5152 .21955 L
.54006 .19392 L
.55406 .17949 L
.58013 .15261 L
.59292 .13942 L
.62019 .1113 L
.63177 .09936 L
.66026 .06999 L
.67063 .05929 L
.70032 .02869 L
.70949 .01923 L
.01923 .01923 L
F
0 g
.01923 .73093 m
.04892 .70032 L
.05929 .68962 L
.08777 .66026 L
.09936 .64831 L
.12663 .62019 L
.13942 .607 L
.16549 .58013 L
.17949 .56569 L
.20434 .54006 L
.21955 .52439 L
.2432 .5 L
.25962 .48308 L
.28206 .45994 L
.29968 .44177 L
.32092 .41987 L
.33974 .40046 L
.35977 .37981 L
.37981 .35915 L
.39863 .33974 L
.41987 .31784 L
.43749 .29968 L
.45994 .27653 L
.47634 .25962 L
.5 .23523 L
.5152 .21955 L
.54006 .19392 L
.55406 .17949 L
.58013 .15261 L
.59292 .13942 L
.62019 .1113 L
.63177 .09936 L
.66026 .06999 L
.67063 .05929 L
.70032 .02869 L
.70949 .01923 L
s
.6 0 .4 r
.01923 .62508 m
.02398 .62019 L
.05929 .58378 L
.06283 .58013 L
.09936 .54247 L
.10169 .54006 L
.13942 .50116 L
.14055 .5 L
.1794 .45994 L
.17949 .45985 L
.21826 .41987 L
.21955 .41854 L
.25712 .37981 L
.25962 .37723 L
.29598 .33974 L
.29968 .33592 L
.33483 .29968 L
.33974 .29462 L
.37369 .25962 L
.37981 .25331 L
.41255 .21955 L
.41987 .212 L
.4514 .17949 L
.45994 .17069 L
.49026 .13942 L
.5 .12938 L
.52912 .09936 L
.54006 .08807 L
.56798 .05929 L
.58013 .04677 L
.60683 .01923 L
.01923 .01923 L
F
0 g
.01923 .62508 m
.02398 .62019 L
.05929 .58378 L
.06283 .58013 L
.09936 .54247 L
.10169 .54006 L
.13942 .50116 L
.14055 .5 L
.1794 .45994 L
.17949 .45985 L
.21826 .41987 L
.21955 .41854 L
.25712 .37981 L
.25962 .37723 L
.29598 .33974 L
.29968 .33592 L
.33483 .29968 L
.33974 .29462 L
.37369 .25962 L
.37981 .25331 L
.41255 .21955 L
.41987 .212 L
.4514 .17949 L
.45994 .17069 L
.49026 .13942 L
.5 .12938 L
.52912 .09936 L
.54006 .08807 L
.56798 .05929 L
.58013 .04677 L
.60683 .01923 L
s
.7 0 .3 r
.01923 .52135 m
.03994 .5 L
.05929 .48004 L
.0788 .45994 L
.09936 .43874 L
.11766 .41987 L
.13942 .39743 L
.15651 .37981 L
.17949 .35612 L
.19537 .33974 L
.21955 .31481 L
.23423 .29968 L
.25962 .2735 L
.27308 .25962 L
.29968 .23219 L
.31194 .21955 L
.33974 .19088 L
.3508 .17949 L
.37981 .14958 L
.38966 .13942 L
.41987 .10827 L
.42851 .09936 L
.45994 .06696 L
.46737 .05929 L
.5 .02565 L
.50623 .01923 L
.01923 .01923 L
F
0 g
.01923 .52135 m
.03994 .5 L
.05929 .48004 L
.0788 .45994 L
.09936 .43874 L
.11766 .41987 L
.13942 .39743 L
.15651 .37981 L
.17949 .35612 L
.19537 .33974 L
.21955 .31481 L
.23423 .29968 L
.25962 .2735 L
.27308 .25962 L
.29968 .23219 L
.31194 .21955 L
.33974 .19088 L
.3508 .17949 L
.37981 .14958 L
.38966 .13942 L
.41987 .10827 L
.42851 .09936 L
.45994 .06696 L
.46737 .05929 L
.5 .02565 L
.50623 .01923 L
s
.8 0 .2 r
.01923 .41394 m
.05233 .37981 L
.05929 .37263 L
.09119 .33974 L
.09936 .33132 L
.13005 .29968 L
.13942 .29001 L
.1689 .25962 L
.17949 .2487 L
.20776 .21955 L
.21955 .20739 L
.24662 .17949 L
.25962 .16609 L
.28548 .13942 L
.29968 .12478 L
.32433 .09936 L
.33974 .08347 L
.36319 .05929 L
.37981 .04216 L
.40205 .01923 L
.01923 .01923 L
F
0 g
.01923 .41394 m
.05233 .37981 L
.05929 .37263 L
.09119 .33974 L
.09936 .33132 L
.13005 .29968 L
.13942 .29001 L
.1689 .25962 L
.17949 .2487 L
.20776 .21955 L
.21955 .20739 L
.24662 .17949 L
.25962 .16609 L
.28548 .13942 L
.29968 .12478 L
.32433 .09936 L
.33974 .08347 L
.36319 .05929 L
.37981 .04216 L
.40205 .01923 L
s
.9 0 .1 r
.01923 .29565 m
.05418 .25962 L
.05929 .25434 L
.09304 .21955 L
.09936 .21304 L
.1319 .17949 L
.13942 .17173 L
.17075 .13942 L
.17949 .13042 L
.20961 .09936 L
.21955 .08911 L
.24847 .05929 L
.25962 .0478 L
.28733 .01923 L
.01923 .01923 L
F
0 g
.01923 .29565 m
.05418 .25962 L
.05929 .25434 L
.09304 .21955 L
.09936 .21304 L
.1319 .17949 L
.13942 .17173 L
.17075 .13942 L
.17949 .13042 L
.20961 .09936 L
.21955 .08911 L
.24847 .05929 L
.25962 .0478 L
.28733 .01923 L
s
1 0 0 r
.01923 .15421 m
.03357 .13942 L
.05929 .11291 L
.07243 .09936 L
.09936 .0716 L
.11129 .05929 L
.13942 .03028 L
.15015 .01923 L
.01923 .01923 L
F
0 g
.01923 .15421 m
.03357 .13942 L
.05929 .11291 L
.07243 .09936 L
.09936 .0716 L
.11129 .05929 L
.13942 .03028 L
.15015 .01923 L
s
.1 0 .9 r
.98077 .16283 m
.96463 .17949 L
.94071 .20414 L
.92576 .21955 L
.90064 .24545 L
.8869 .25962 L
.86058 .28676 L
.84805 .29968 L
.82051 .32807 L
.80919 .33974 L
.78045 .36938 L
.77033 .37981 L
.74038 .41069 L
.73148 .41987 L
.70032 .452 L
.69262 .45994 L
.66026 .49331 L
.65376 .5 L
.62019 .53461 L
.61491 .54006 L
.58013 .57592 L
.57605 .58013 L
.54006 .61723 L
.53719 .62019 L
.5 .65854 L
.49834 .66026 L
.45994 .69985 L
.45948 .70032 L
.42062 .74038 L
.41987 .74116 L
.38177 .78045 L
.37981 .78247 L
.34291 .82051 L
.33974 .82377 L
.30405 .86058 L
.29968 .86508 L
.26519 .90064 L
.25962 .90639 L
.22633 .94071 L
.21955 .94771 L
.18748 .98077 L
.98077 .98077 L
F
0 g
.98077 .16283 m
.96463 .17949 L
.94071 .20414 L
.92576 .21955 L
.90064 .24545 L
.8869 .25962 L
.86058 .28676 L
.84805 .29968 L
.82051 .32807 L
.80919 .33974 L
.78045 .36938 L
.77033 .37981 L
.74038 .41069 L
.73148 .41987 L
.70032 .452 L
.69262 .45994 L
.66026 .49331 L
.65376 .5 L
.62019 .53461 L
.61491 .54006 L
.58013 .57592 L
.57605 .58013 L
.54006 .61723 L
.53719 .62019 L
.5 .65854 L
.49834 .66026 L
.45994 .69985 L
.45948 .70032 L
.42062 .74038 L
.41987 .74116 L
.38177 .78045 L
.37981 .78247 L
.34291 .82051 L
.33974 .82377 L
.30405 .86058 L
.29968 .86508 L
.26519 .90064 L
.25962 .90639 L
.22633 .94071 L
.21955 .94771 L
.18748 .98077 L
s
0 0 1 r
.98077 .46214 m
.94406 .5 L
.94071 .50345 L
.90519 .54006 L
.90064 .54476 L
.86633 .58013 L
.86058 .58606 L
.82748 .62019 L
.82051 .62737 L
.78862 .66026 L
.78045 .66868 L
.74976 .70032 L
.74038 .70999 L
.7109 .74038 L
.70032 .7513 L
.67204 .78045 L
.66026 .7926 L
.63319 .82051 L
.62019 .83391 L
.59433 .86058 L
.58013 .87522 L
.55547 .90064 L
.54006 .91653 L
.51661 .94071 L
.5 .95786 L
.47776 .98077 L
.98077 .98077 L
F
0 g
.98077 .46214 m
.94406 .5 L
.94071 .50345 L
.90519 .54006 L
.90064 .54476 L
.86633 .58013 L
.86058 .58606 L
.82748 .62019 L
.82051 .62737 L
.78862 .66026 L
.78045 .66868 L
.74976 .70032 L
.74038 .70999 L
.7109 .74038 L
.70032 .7513 L
.67204 .78045 L
.66026 .7926 L
.63319 .82051 L
.62019 .83391 L
.59433 .86058 L
.58013 .87522 L
.55547 .90064 L
.54006 .91653 L
.51661 .94071 L
.5 .95786 L
.47776 .98077 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P000182000`400?l00000o`00003ooooooolQ
ooooo`00o`00000P0000007ooooo00000`00003oooooooooo`3ooooooacooooo0@000001ooooo`00
00<00000ooooooooool0oooooolLooooo`4000000Oooool0000300000?oooooooooo0?oooooo7?oo
ool10000007ooooo00000`00003oooooooooo`3ooooooacooooo0@000001ooooo`0000<00000oooo
ooooool0:?ooool00ol0003oooooooooo`0Tooooo`03o`000?oooooooooo01kooooo00?o0000oooo
ooooool06oooool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo01[ooooo00?o0000oooo
ooooool07Oooool00ol0003oooooooooo`0Rooooo`03o`000?oooooooooo00_ooooo0@000001oooo
o`0000<00000ooooooooool00_oooolU0?l00003o`00003V01T0iP0I02@0iP0I00?o00000<`0<`3<
03<07`3<03<00ol00000/`1<0;<0C00J0;<0C003o`00002I06H0V@1V01X0V@1V00?o000007l0O`1o
07l06P1o07l00ol00000IP2I06H0V@0N06H0V@030000001<0;<0C02c0240C02c00?o000003<0c00c
0<`01`0c0<`5ooooo`4000000Oooool0000300000?oooooooooo00;ooooo903o00000ol00000iP0I
0>H06@0T0>H06@03o`00003<03<0c00c01l0c00c00?o00000;<0C02c04`06P2c04`00ol00000V@1V
09T0IP0J09T0IP03o`00001o07l0O`1o01X0O`1o00?o000006H0V@1V09T07P1V09T00`000000C02c
04`0/`0Q04`0/`03o`00000c0<`0<`3<00P0<`3<1Oooool10000007ooooo00000`00003ooooooooo
o`02ooooob<0o`0000?o00000>H06@3V01T0903V01T00ol00000c00c0<`0<`0O0<`0<`03o`00002c
04`0/`1<01/0/`1<00?o000009T0IP2I06H06@2I06H00ol00000O`1o07l0O`0J07l0O`03o`00001V
09T0IP2I01h0IP2I00<0000004`0/`1<0;<08@1<0;<00ol00000<`3<03<0c00903<0c0Gooooo0@00
0001ooooo`0000<00000ooooooooool00_oooolS0?l00003o`00003V01T0iP0I02<0iP0I00?o0000
0<`0<`3<03<07`3<03<00ol00000/`1<0;<0C00K0;<0C003o`00002I06H0V@1V01T0V@1V00?o0000
07l0O`1o07l06`1o07l00ol00000IP2I06H0V@0M06H0V@030000001<0;<0C02c0280C02c00?o0000
03<0c00c0<`02@0c0<`5ooooo`4000000Oooool0000300000?oooooooooo00;ooooo8P3o00000ol0
0000iP0I0>H06@0S0>H06@03o`00003<03<0c00c01l0c00c00?o00000;<0C02c04`06`2c04`00ol0
0000V@1V09T0IP0I09T0IP03o`00001o07l0O`1o01/0O`1o00?o000006H0V@1V09T07@1V09T00`00
0000C02c04`0/`0R04`0/`03o`00000c0<`0<`3<00X0<`3<1Oooool10000007ooooo00000`00003o
ooooooooo`02ooooob40o`0000?o00000>H06@3V01T08`3V01T00ol00000c00c0<`0<`0O0<`0<`03
o`00002c04`0/`1<01/0/`1<00?o000009T0IP2I06H06@2I06H00ol00000O`1o07l0O`0K07l0O`03
o`00001V09T0IP2I01d0IP2I00<0000004`0/`1<0;<08P1<0;<00ol00000<`3<03<0c00;03<0c0Go
oooo0@000001ooooo`0000<00000ooooooooool00_oooolP0?l00003o`00003V01T0iP0I02<0iP0I
00?o00000<`0<`3<03<07`3<03<00ol00000/`1<0;<0C00K0;<0C003o`00002I06H0V@1V01T0V@1V
00?o000007l0O`1o07l06`1o07l00ol00000IP2I06H0V@0M06H0V@030000001<0;<0C02c0280C02c
00?o000003<0c00c0<`0300c0<`5ooooo`4000000Oooool0000300000?oooooooooo00;ooooo7`3o
00000ol00000iP0I0>H06@0S0>H06@03o`00003<03<0c00c01l0c00c00?o00000;<0C02c04`06`2c
04`00ol00000V@1V09T0IP0I09T0IP03o`00001o07l0O`1o01/0O`1o00?o000006H0V@1V09T07@1V
09T00`000000C02c04`0/`0R04`0/`03o`00000c0<`0<`3<00d0<`3<1Oooool10000007ooooo0000
0`00003oooooooooo`02oooooah0o`0000?o00000>H06@3V01T0903V01T00ol00000c00c0<`0<`0N
0<`0<`03o`00002c04`0/`1<01/0/`1<00?o000009T0IP2I06H06@2I06H00ol00000O`1o07l0O`0K
07l0O`03o`00001V09T0IP2I01d0IP2I00<0000004`0/`1<0;<08P1<0;<00ol00000<`3<03<0c00>
03<0c0Gooooo0@000001ooooo`0000<00000ooooooooool00_oooolM0?l00003o`00003V01T0iP0I
02@0iP0I00?o00000<`0<`3<03<07P3<03<00ol00000/`1<0;<0C00K0;<0C003o`00002I06H0V@1V
01T0V@1V00?o000007l0O`1o07l06`1o07l00ol00000IP2I06H0V@0M06H0V@030000001<0;<0C02c
0280C02c00?o000003<0c00c0<`03`0c0<`5ooooo`4000000Oooool0000300000?oooooooooo00;o
oooo703o00000ol00000iP0I0>H06@0T0>H06@03o`00003<03<0c00c01h0c00c00?o00000;<0C02c
04`06`2c04`00ol00000V@1V09T0IP0I09T0IP03o`00001o07l0O`1o01/0O`1o00?o000006H0V@1V
09T07@1V09T00`000000C02c04`0/`0R04`0/`03o`00000c0<`0<`3<0100<`3<1Oooool10000007o
oooo00000`00003oooooooooo`02oooooaX0o`000_l0000V0>H06@03o`00003<03<0c00c01h0c00c
00?o00000;<0C02c04`06`2c04`00ol00000V@1V09T0IP0I09T0IP03o`00001o07l0O`1o01/0O`1o
00?o000006H0V@1V09T0701V09T00ol00000000004`0/`0S04`0/`03o`00000c0<`0<`3<0140<`3<
1Oooool10000007ooooo00000`00003oooooooooo`02oooooaT0o`0000?o00000>H06@3V01T09@3V
01T00ol00000c00c0<`0<`0N0<`0<`03o`00002c04`0/`1<01/0/`1<00?o000009T0IP2I06H06@2I
06H00ol00000O`1o07l0O`0K07l0O`03o`00001V09T0IP2I01d0IP2I00<0000004`0/`1<0;<08P1<
0;<00ol00000<`3<03<0c00B03<0c0Gooooo0@000001ooooo`0000<00000ooooooooool00_oooolH
0?l00003o`00003V01T0iP0I02D0iP0I00?o00000<`0<`3<03<07P3<03<00ol00000/`1<0;<0C00K
0;<0C003o`00002I06H0V@1V01T0V@1V00?o000007l0O`1o07l06`1o07l00ol00000IP2I06H0V@0M
06H0V@030000001<0;<0C02c0280C02c00?o000003<0c00c0<`04`0c0<`5ooooo`4000000Oooool0
000300000?oooooooooo00;ooooo5`3o00000ol00000iP0I0>H06@0U0>H06@03o`00003<03<0c00c
01h0c00c00?o00000;<0C02c04`06`2c04`00ol00000V@1V09T0IP0I09T0IP03o`00001o07l0O`1o
01/0O`1o00?o000006H0V@1V09T07@1V09T00`000000C02c04`0/`0R04`0/`03o`00000c0<`0<`3<
01@0<`3<1Oooool10000007ooooo00000`00003oooooooooo`02oooooaH0o`0000?o00000>H06@3V
01T09@3V01T00ol00000c00c0<`0<`0N0<`0<`03o`00002c04`0/`1<01/0/`1<00?o000009T0IP2I
06H06@2I06H00ol00000O`1o07l0O`0K07l0O`03o`00001V09T0IP2I01d0IP2I00<0000004`0/`1<
0;<08P1<0;<00ol00000<`3<03<0c00E03<0c0Gooooo0@000001ooooo`0000<00000ooooooooool0
0_oooolE0?l00003o`00003V01T0iP0I02D0iP0I00?o00000<`0<`3<03<07P3<03<00ol00000/`1<
0;<0C00K0;<0C003o`00002I06H0V@1V01T0V@1V00?o000007l0O`1o07l06`1o07l00ol00000IP2I
06H0V@0M06H0V@030000001<0;<0C02c0280C02c00?o000003<0c00c0<`05P0c0<`5ooooo`400000
0Oooool0000300000?oooooooooo00;ooooo503o00000ol00000iP0I0>H06@0U0>H06@03o`00003<
03<0c00c01h0c00c00?o00000;<0C02c04`06`2c04`00ol00000V@1V09T0IP0I09T0IP03o`00001o
07l0O`1o01/0O`1o00?o000006H0V@1V09T07@1V09T00`000000C02c04`0/`0R04`0/`03o`00000c
0<`0<`3<01L0<`3<1Oooool10000007ooooo00000`00003oooooooooo`02oooooa<0o`0000?o0000
0>H06@3V01T09@3V01T00ol00000c00c0<`0<`0N0<`0<`03o`00002c04`0/`1<01/0/`1<00?o0000
09T0IP2I06H06@2I06H00ol00000O`1o07l0O`0K07l0O`03o`00001V09T0IP2I01d0IP2I00<00000
04`0/`1<0;<08P1<0;<00ol00000<`3<03<0c00H03<0c0Gooooo0@000001ooooo`0000<00000oooo
ooooool00_oooolB0?l00003o`00003V01T0iP0I02D0iP0I00?o00000<`0<`3<03<07P3<03<00ol0
0000/`1<0;<0C00K0;<0C003o`00002I06H0V@1V01T0V@1V00?o000007l0O`1o07l06`1o07l00ol0
0000IP2I06H0V@0M06H0V@030000001<0;<0C02c0280C02c00?o000003<0c00c0<`06@0c0<`5oooo
o`4000000Oooool0000300000?oooooooooo00;ooooo4@3o00000ol00000iP0I0>H06@0U0>H06@03
o`00003<03<0c00c01h0c00c00?o00000;<0C02c04`06`2c04`00ol00000V@1V09T0IP0I09T0IP03
o`00001o07l0O`1o01/0O`1o00?o000006H0V@1V09T07@1V09T00`000000C02c04`0/`0R04`0/`03
o`00000c0<`0<`3<01X0<`3<1Oooool10000007ooooo00000`00003oooooooooo`02oooooa00o`00
00?o00000>H06@3V01T09@3V01T00ol00000c00c0<`0<`0N0<`0<`03o`00002c04`0/`1<01/0/`1<
00?o000009T0IP2I06H06@2I06H00ol00000O`1o07l0O`0K07l0O`03o`00001V09T0IP2I01d0IP2I
00<0000004`0/`1<0;<08P1<0;<00ol00000<`3<03<0c00K03<0c0Gooooo0@000001ooooo`0000<0
0000ooooooooool00_ooool?0?l00003o`00003V01T0iP0I02D0iP0I00?o00000<`0<`3<03<07P3<
03<00ol00000/`1<0;<0C00K0;<0C003o`00002I06H0V@1V01T0V@1V00?o000007l0O`1o07l06`1o
07l00ol00000IP2I06H0V@0M06H0V@030000001<0;<0C02c0280C02c00?o000003<0c00c0<`0700c
0<`5ooooo`4000000Oooool0000300000?oooooooooo00;ooooo3`3o00000ol00000iP0I0>H06@0T
0>H06@03o`00003<03<0c00c01h0c00c00?o00000;<0C02c04`06`2c04`00ol00000V@1V09T0IP0J
09T0IP03o`00001o07l0O`1o01X0O`1o00?o000006H0V@1V09T07@1V09T00ol00000C02c04`0/`0R
04`0/`03o`00000c0<`0<`3<01d0<`3<1Oooool10000007ooooo00000`00003oooooooooo`02oooo
o`h0o`0000?o00000>H06@3V01T0903V01T00ol00000c00c0<`0<`0N0<`0<`03o`00002c04`0/`1<
01/0/`1<00?o000009T0IP2I06H06P2I06H00ol00000O`1o07l0O`0J07l0O`03o`00001V09T0IP2I
01d0IP2I00<0000004`0/`1<0;<08P1<0;<00ol00000<`3<03<0c00N03<0c0Gooooo0@000001oooo
o`0000<00000ooooooooool00_ooool=0?l00003o`00003V01T0iP0I02@0iP0I00?o00000<`0<`3<
03<07P3<03<00ol00000/`1<0;<0C00K0;<0C003o`00002I06H0V@1V01X0V@1V00?o000007l0O`1o
07l06P1o07l00ol00000IP2I06H0V@0M06H0V@030000001<0;<0C02c0280C02c00?o000003<0c00c
0<`07`0c0<`5ooooo`4000000Oooool0000300000?oooooooooo00;ooooo303o00000ol00000iP0I
0>H06@0T0>H06@03o`00003<03<0c00c01h0c00c00?o00000;<0C02c04`06`2c04`00ol00000V@1V
09T0IP0J09T0IP03o`00001o07l0O`1o01X0O`1o00?o000006H0V@1V09T07@1V09T00`000000C02c
04`0/`0R04`0/`03o`00000c0<`0<`3<0200<`3<1Oooool10000007ooooo00000`00003ooooooooo
o`02ooooo`/0o`0000?o00000>H06@3V01T0903V01T00ol00000c00c0<`0<`0N0<`0<`03o`00002c
04`0/`1<01/0/`1<00?o000009T0IP2I06H06P2I06H00ol00000O`1o07l0O`0K07l0O`03o`00001V
09T0IP2I01`0IP2I00<0000004`0/`1<0;<08`1<0;<00ol00000<`3<03<0c00P03<0c0Gooooo0@00
0001ooooo`0000<00000ooooooooool00_ooool:0?l00003o`00003V01T0iP0I02@0iP0I00?o0000
0<`0<`3<03<07P3<03<00ol00000/`1<0;<0C00K0;<0C003o`00002I06H0V@1V01X0V@1V00?o0000
07l0O`1o07l06`1o07l00ol00000IP2I06H0V@0L06H0V@030000001<0;<0C02c02<0C02c00?o0000
03<0c00c0<`08@0c0<`5ooooo`4000000Oooool0000300000?oooooooooo00;ooooo2@3o00000ol0
0000iP0I0>H06@0T0>H06@03o`00003<03<0c00c01h0c00c00?o00000;<0C02c04`06`2c04`00ol0
0000V@1V09T0IP0J09T0IP03o`00001o07l0O`1o01/0O`1o00?o000006H0V@1V09T0701V09T00`00
0000C02c04`0/`0S04`0/`03o`00000c0<`0<`3<0280<`3<1Oooool10000007ooooo00000`00003o
ooooooooo`02ooooo`P0o`0000?o00000>H06@3V01T0903V01T00ol00000c00c0<`0<`0N0<`0<`03
o`00002c04`0/`1<01/0/`1<00?o000009T0IP2I06H06P2I06H00ol00000O`1o07l0O`0K07l0O`03
o`00001V09T0IP2I01`0IP2I00<0000004`0/`1<0;<08`1<0;<00ol00000<`3<03<0c00S03<0c0Go
oooo0@000001ooooo`0000<00000ooooooooool00_ooool70?l00003o`00003V01T0iP0I02@0iP0I
00?o00000<`0<`3<03<07P3<03<00ol00000/`1<0;<0C00K0;<0C003o`00002I06H0V@1V01X0V@1V
00?o000007l0O`1o07l06`1o07l00ol00000IP2I06H0V@0L06H0V@030000001<0;<0C02c02<0C02c
00?o000003<0c00c0<`0900c0<`5ooooo`4000000Oooool0000300000?oooooooooo00;ooooo1P3o
00000ol00000iP0I0>H06@0U0>H06@03o`00003<03<0c00c01d0c00c00?o00000;<0C02c04`06`2c
04`00ol00000V@1V09T0IP0J09T0IP03o`00001o07l0O`1o01/0O`1o00?o000006H0V@1V09T0701V
09T00`000000C02c04`0/`0S04`0/`03o`00000c0<`0<`3<02D0<`3<1Oooool10000007ooooo0000
0`00003oooooooooo`02ooooo`D0o`0000?o00000>H06@3V01T09@3V01T00ol00000c00c0<`0<`0M
0<`0<`03o`00002c04`0/`1<01/0/`1<00?o000009T0IP2I06H06P2I06H00ol00000O`1o07l0O`0K
07l0O`03o`00001V09T0IP2I01`0IP2I00<0000004`0/`1<0;<08`1<0;<00ol00000<`3<03<0c00V
03<0c0Gooooo0@000001ooooo`0000<00000ooooooooool00_ooool40?l00003o`00003V01T0iP0I
02D0iP0I00?o00000<`0<`3<03<07@3<03<00ol00000/`1<0;<0C00K0;<0C003o`00002I06H0V@1V
01X0V@1V00?o000007l0O`1o07l06P1o07l2o`0001h0IP2I00<0000004`0/`1<0;<08P1<0;<2o`00
02T0<`3<1Oooool10000007ooooo00000`00003oooooooooo`02ooooo`<0o`0000?o00000>H06@3V
01T09@3V01T00ol00000c00c0<`0<`0M0<`0<`03o`00002c04`0/`1<01`0/`1<00?o000009T0IP2I
06H06P2I06H00ol00000O`1o07l0O`0I07l0O`03o`00001V09T0IP2I01d0IP2I00?o000004`0/`1<
0;<08P1<0;<00ol00000<`3<03<0c00Y03<0c0Gooooo0@000001ooooo`0000<00000ooooooooool0
0_ooool20?l00003o`00003V01T0iP0I02D0iP0I00?o00000<`0<`3<03<07@3<03<00ol00000/`1<
0;<0C00L0;<0C003o`00002I06H0V@1V01X0V@1V00?o000007l0O`1o07l06@1o07l00ol00000IP2I
06H0V@0M06H0V@030000001<0;<0C02c0280C02c00?o000003<0c00c0<`0:P0c0<`5ooooo`400000
0Oooool0000300000?oooooooooo00;ooooo00<0o`00o`00003V01T09P3V01T00ol00000c00c0<`0
<`0M0<`0<`03o`00002c04`0/`1<01/0/`1<0_l0000L09T0IP03o`00001o07l0O`1o01T0O`1o00?o
000006H0V@1V09T07@1V09T00`000000C02c04`0/`0R04`0/`03o`00000c0<`0<`3<02/0<`3<1Ooo
ool10000007ooooo00000`00003oooooooooo`02ooooo`03o`00003V01T0iP0I02D0iP0I00?o0000
0<`0<`3<03<07@3<03<00ol00000/`1<0;<0C00K0;<0C003o`00002I06H0V@1V01/0V@1V00?o0000
07l0O`1o07l06P1o07l00ol00000IP2I06H0V@0L06H0V@030000001<0;<0C02c0280C02c00?o0000
03<0c00c0<`0;00c0<`5ooooo`4000000Oooool0000300000?oooooooooo00;ooooo9`3V01T00ol0
0000c00c0<`0<`0M0<`0<`03o`00002c04`0/`1<01/0/`1<00?o000009T0IP2I06H06`2I06H00ol0
0000O`1o07l0O`0J07l0O`03o`00001V09T0IP2I01`0IP2I00<0000004`0/`1<0;<08P1<0;<00ol0
0000<`3<03<0c00]03<0c0Gooooo0@000001ooooo`0000<00000ooooooooool00_oooolV0>H06@03
o`00003<03<0c00c01d0c00c00?o00000;<0C02c04`06`2c04`00ol00000V@1V09T0IP0K09T0IP03
o`00001o07l0O`1o01X0O`1o00?o000006H0V@1V09T0701V09T00`000000C02c04`0/`0R04`0/`03
o`00000c0<`0<`3<02h0<`3<00?o0000ooooooooool00_ooool10000007ooooo00000`00003ooooo
ooooo`02ooooobD0iP0I00?o00000<`0<`3<03<07@3<03<00ol00000/`1<0;<0C00K0;<0C003o`00
002I06H0V@1V01/0V@1V00?o000007l0O`1o07l06P1o07l00ol00000IP2I06H0V@0L06H0V@030000
001<0;<0C02c0280C02c00?o000003<0c00c0<`0;P0c0<`00ol0003oooooooooo`03ooooo`400000
0Oooool0000300000?oooooooooo00;ooooo903V01T00ol00000c00c0<`0<`0M0<`0<`03o`00002c
04`0/`1<01/0/`1<00?o000009T0IP2I06H06`2I06H00ol00000O`1o07l0O`0J07l0O`03o`00001V
09T0IP2I01`0IP2I00<0000004`0/`1<0;<08P1<0;<00ol00000<`3<03<0c00^03<0c003o`00000I
0>Kooooo00Cooooo0@000001ooooo`0000<00000ooooooooool00_oooolR0>H06@;o00007`3<03<0
0ol00000/`1<0;<0C00K0;<0C003o`00002I06H0V@1V01X0V@1V0_l0000L07l0O`03o`00001V09T0
IP2I01`0IP2I00<0000004`0/`1<0;<08P1<0;<00ol00000<`3<03<0c00^03<0c003o`00000I0>H0
6@3V00Gooooo0@000001ooooo`0000<00000ooooooooool00_oooolQ0>H06@03o`00003<03<0c00c
01h0c00c00?o00000;<0C02c04`06`2c04`00ol00000V@1V09T0IP0J09T0IP03o`00001o07l0O`1o
01/0O`1o00?o000006H0V@1V09T0701V09T00`000000C02c04`0/`0R04`0/`03o`00000c0<`0<`3<
02h0<`3<00Co000001T0iP0I0>H06@3V1Oooool10000007ooooo00000`00003oooooooooo`02oooo
ob00iP0I00?o00000<`0<`3<03<07P3<03<00ol00000/`1<0;<0C00K0;<0C003o`00002I06H0V@1V
01X0V@1V00?o000007l0O`1o07l06P1o07l2o`0001h0IP2I00<0000004`0/`1<0;<08P1<0;<00ol0
0000<`3<03<0c00^03<0c003o`00000I0>H06@3V00806@3V1Oooool10000007ooooo00000`00003o
ooooooooo`02ooooob00iP0I00?o00000<`0<`3<03<07P3<03<00ol00000/`1<0;<0C00J0;<0C003
o`00002I06H0V@1V01X0V@1V00?o000007l0O`1o07l06P1o07l00ol00000IP2I06H0V@0N06H0V@03
0000001<0;<0C02c0240C02c00?o000003<0c00c0<`0;P0c0<`00ol000006@3V01T0iP0301T0iPGo
oooo0@000001ooooo`0000<00000ooooooooool00_oooolO0>H06@03o`00003<03<0c00c01h0c00c
00?o00000;<0C02c04`06P2c04`00ol00000V@1V09T0IP0J09T0IP03o`00001o07l0O`1o01X0O`1o
00?o000006H0V@1V09T07P1V09T00`000000C02c04`0/`0Q04`0/`03o`00000c0<`0<`3<02h0<`3<
00?o000001T0iP0I0>H0100I0>H5ooooo`4000000Oooool0000300000?oooooooooo00;ooooo7P3V
01T00ol00000c00c0<`0<`0N0<`0<`03o`00002c04`0/`1<01X0/`1<00?o000009T0IP2I06H06P2I
06H00ol00000O`1o07l0O`0J07l0O`03o`00001V09T0IP2I01h0IP2I00<0000004`0/`1<0;<08@1<
0;<00ol00000<`3<03<0c00^03<0c003o`00000I0>H06@3V00D06@3V1Oooool10000007ooooo0000
0`00003oooooooooo`02oooooad0iP0I00?o00000<`0<`3<03<07P3<03<00ol00000/`1<0;<0C00K
0;<0C003o`00002I06H0V@1V01T0V@1V00?o000007l0O`1o07l06P1o07l00ol00000IP2I06H0V@0N
06H0V@030000001<0;<0C02c0240C02c00?o000003<0c00c0<`0;P0c0<`00ol000006@3V01T0iP06
01T0iPGooooo0@000001ooooo`0000<00000ooooooooool00_oooolL0>H06@03o`00003<03<0c00c
01h0c00c00?o00000;<0C02c04`06`2c04`00ol00000V@1V09T0IP0I09T0IP03o`00001o07l0O`1o
01/0O`1o00?o000006H0V@1V09T07@1V09T00`000000C02c04`0/`0R04`0/`03o`00000c0<`0<`3<
02d0<`3<00?o000001T0iP0I0>H01`0I0>H5ooooo`4000000Oooool0000300000?oooooooooo00;o
oooo6`3V01T00ol00000c00c0<`0<`0N0<`0<`03o`00002c04`0/`1<01/0/`1<00?o000009T0IP2I
06H06@2I06H00ol00000O`1o07l0O`0K07l0O`03o`00001V09T0IP2I01d0IP2I00<0000004`0/`1<
0;<08P1<0;<00ol00000<`3<03<0c00]03<0c003o`00000I0>H06@3V00P06@3V1Oooool10000007o
oooo00000`00003oooooooooo`02oooooaX0iP0I00?o00000<`0<`3<03<07P3<03<00ol00000/`1<
0;<0C00K0;<0C003o`00002I06H0V@1V01T0V@1V00?o000007l0O`1o07l06`1o07l00ol00000IP2I
06H0V@0M06H0V@030000001<0;<0C02c0280C02c00?o000003<0c00c0<`0;@0c0<`00ol000006@3V
01T0iP0901T0iPGooooo0@000001ooooo`0000<00000ooooooooool00_oooolI0>H06@03o`00003<
03<0c00c01h0c00c00?o00000;<0C02c04`06`2c04`00ol00000V@1V09T0IP0I09T0IP03o`00001o
07l0O`1o01/0O`1o00?o000006H0V@1V09T07@1V09T00`000000C02c04`0/`0R04`0/`03o`00000c
0<`0<`3<02h0<`3<00?o000001T0iP0I0>H02@0I0>H5ooooo`4000000Oooool0000300000?oooooo
oooo00;ooooo603V01T00ol00000c00c0<`0<`0N0<`0<`03o`00002c04`0/`1<01/0/`1<00?o0000
09T0IP2I06H06@2I06H00ol00000O`1o07l0O`0K07l0O`03o`00001V09T0IP2I01d0IP2I00<00000
04`0/`1<0;<08P1<0;<00ol00000<`3<03<0c00^03<0c003o`00000I0>H06@3V00X06@3V1Oooool1
0000007ooooo00000`00003oooooooooo`02oooooaL0iP0I00?o00000<`0<`3<03<07P3<03<00ol0
0000/`1<0;<0C00K0;<0C003o`00002I06H0V@1V01X0V@1V00?o000007l0O`1o07l06P1o07l00ol0
0000IP2I06H0V@0M06H0V@030000001<0;<0C02c0280C02c00?o000003<0c00c0<`0;P0c0<`00ol0
00006@3V01T0iP0;01T0iPGooooo0@000001ooooo`0000<00000ooooooooool00_oooolF0>H06@03
o`00003<03<0c00c01h0c00c00?o00000;<0C02c04`06`2c04`00ol00000V@1V09T0IP0J09T0IP03
o`00001o07l0O`1o01X0O`1o00?o000006H0V@1V09T07@1V09T00`000000C02c04`0/`0R04`0/`03
o`00000c0<`0<`3<02h0<`3<00?o000001T0iP0I0>H0300I0>H5ooooo`4000000Oooool000030000
0?oooooooooo00;ooooo5@3V01T00ol00000c00c0<`0<`0N0<`0<`03o`00002c04`0/`1<01/0/`1<
00?o000009T0IP2I06H06P2I06H00ol00000O`1o07l0O`0J07l0O`03o`00001V09T0IP2I01`0IP2I
0P00000T04`0/`03o`00000c0<`0<`3<02h0<`3<00?o000001T0iP0I0>H03@0I0>H5ooooo`400000
0Oooool0000300000?oooooooooo00;ooooo5@3V01T00ol00000c00c0<`0<`0M0<`0<`03o`00002c
04`0/`1<01/0/`1<00?o000009T0IP2I06H06P2I06H00ol00000O`1o07l0O`0J07l0O`03o`00001V
09T0IP2I01`0IP2I00<0000004`0/`1<0;<08`1<0;<00ol00000<`3<03<0c00^03<0c003o`00000I
0>H06@3V00h06@3V1Oooool10000007ooooo00000`00003oooooooooo`02oooooa@0iP0I00?o0000
0<`0<`3<03<07@3<03<00ol00000/`1<0;<0C00K0;<0C003o`00002I06H0V@1V01X0V@1V00?o0000
07l0O`1o07l06P1o07l00ol00000IP2I06H0V@0M06H0V@030000001<0;<0C02c0280C02c00?o0000
03<0c00c0<`0;P0c0<`00ol000006@3V01T0iP0?01T0iPGooooo0@000001ooooo`0000<00000oooo
ooooool00_oooolC0>H06@03o`00003<03<0c00c01d0c00c00?o00000;<0C02c04`06`2c04`00ol0
0000V@1V09T0IP0J09T0IP03o`00001o07l0O`1o01X0O`1o00?o000006H0V@1V09T07@1V09T00`00
0000C02c04`0/`0R04`0/`03o`00000c0<`0<`3<02h0<`3<00?o000001T0iP0I0>H0400I0>H5oooo
o`4000000Oooool0000300000?oooooooooo00;ooooo4P3V01T00ol00000c00c0<`0<`0M0<`0<`03
o`00002c04`0/`1<01/0/`1<00?o000009T0IP2I06H06P2I06H00ol00000O`1o07l0O`0J07l0O`03
o`00001V09T0IP2I01d0IP2I00<0000004`0/`1<0;<08P1<0;<00ol00000<`3<03<0c00^03<0c003
o`00000I0>H06@3V01406@3V1Oooool10000007ooooo00000`00003oooooooooo`02oooooa40iP0I
00?o00000<`0<`3<03<07@3<03<00ol00000/`1<0;<0C00K0;<0C003o`00002I06H0V@1V01X0V@1V
00?o000007l0O`1o07l06P1o07l00ol00000IP2I06H0V@0M06H0V@030000001<0;<0C02c0280C02c
00?o000003<0c00c0<`0;P0c0<`00ol000006@3V01T0iP0B01T0iPGooooo0@000001ooooo`0000<0
0000ooooooooool00_ooool@0>H06@03o`00003<03<0c00c01d0c00c00?o00000;<0C02c04`06`2c
04`00ol00000V@1V09T0IP0J09T0IP03o`00001o07l0O`1o01X0O`1o00?o000006H0V@1V09T07@1V
09T00`000000C02c04`0/`0R04`0/`03o`00000c0<`0<`3<02h0<`3<00?o000001T0iP0I0>H04`0I
0>H5ooooo`4000000Oooool0000300000?oooooooooo00;ooooo3`3V01T00ol00000c00c0<`0<`0M
0<`0<`03o`00002c04`0/`1<01/0/`1<00?o000009T0IP2I06H06P2I06H00ol00000O`1o07l0O`0J
07l0O`03o`00001V09T0IP2I01d0IP2I00<0000004`0/`1<0;<08P1<0;<00ol00000<`3<03<0c00^
03<0c003o`00000I0>H06@3V01@06@3V1Oooool10000007ooooo00000`00003oooooooooo`02oooo
o`h0iP0I00?o00000<`0<`3<03<07@3<03<00ol00000/`1<0;<0C00K0;<0C003o`00002I06H0V@1V
01X0V@1V00?o000007l0O`1o07l06P1o07l00ol00000IP2I06H0V@0M06H0V@030000001<0;<0C02c
0280C02c00?o000003<0c00c0<`0;P0c0<`00ol000006@3V01T0iP0E01T0iPGooooo0@000001oooo
o`0000<00000ooooooooool00_ooool=0>H06@03o`00003<03<0c00c01d0c00c00?o00000;<0C02c
04`06`2c04`00ol00000V@1V09T0IP0J09T0IP03o`00001o07l0O`1o01X0O`1o00?o000006H0V@1V
09T07@1V09T00`000000C02c04`0/`0R04`0/`03o`00000c0<`0<`3<02h0<`3<00?o000001T0iP0I
0>H05P0I0>H5ooooo`4000000Oooool0000300000?oooooooooo00;ooooo2`3V01T2o`0001l0c00c
00?o00000;<0C02c04`06`2c04`00ol00000V@1V09T0IP0J09T0IP03o`00001o07l0O`1o01X0O`1o
00?o000006H0V@1V09T07@1V09T00`000000C02c04`0/`0R04`0/`03o`00000c0<`0<`3<02h0<`3<
00?o000001T0iP0I0>H05`0I0>H5ooooo`4000000Oooool0000300000?oooooooooo00;ooooo2P3V
01T00ol00000c00c0<`0<`0N0<`0<`03o`00002c04`0/`1<01/0/`1<00?o000009T0IP2I06H06P2I
06H00ol00000O`1o07l0O`0J07l0O`03o`00001V09T0IP2I01d0IP2I00<0000004`0/`1<0;<08P1<
0;<00ol00000<`3<03<0c00^03<0c003o`00000I0>H06@3V01P06@3V1Oooool10000007ooooo0000
0`00003oooooooooo`02ooooo`T0iP0I00?o00000<`0<`3<03<07`3<03<00ol00000/`1<0;<0C00J
0;<0C003o`00002I06H0V@1V01X0V@1V00?o000007l0O`1o07l06`1o07l00ol00000IP2I06H0V@0L
06H0V@030000001<0;<0C02c0280C02c00?o000003<0c00c0<`0;P0c0<`00ol000006@3V01T0iP0I
01T0iPGooooo0@000001ooooo`0000<00000ooooooooool00_ooool80>H06@03o`00003<03<0c00c
01l0c00c00?o00000;<0C02c04`06P2c04`00ol00000V@1V09T0IP0J09T0IP03o`00001o07l0O`1o
01/0O`1o00?o000006H0V@1V09T0701V09T00`000000C02c04`0/`0R04`0/`03o`00000c0<`0<`3<
02h0<`3<00?o000001T0iP0I0>H06P0I0>H5ooooo`4000000Oooool0000300000?oooooooooo00;o
oooo1`3V01T00ol00000c00c0<`0<`0O0<`0<`03o`00002c04`0/`1<01X0/`1<00?o000009T0IP2I
06H06P2I06H00ol00000O`1o07l0O`0K07l0O`03o`00001V09T0IP2I01d0IP2I00<0000004`0/`1<
0;<08@1<0;<00ol00000<`3<03<0c00^03<0c003o`00000I0>H06@3V01/06@3V1Oooool10000007o
oooo00000`00003oooooooooo`02ooooo`H0iP0I00?o00000<`0<`3<03<07`3<03<00ol00000/`1<
0;<0C00J0;<0C003o`00002I06H0V@1V01X0V@1V00?o000007l0O`1o07l06`1o07l00ol00000IP2I
06H0V@0M06H0V@030000001<0;<0C02c0240C02c00?o000003<0c00c0<`0;P0c0<`00ol000006@3V
01T0iP0L01T0iPGooooo0@000001ooooo`0000<00000ooooooooool00_ooool50>H06@03o`00003<
03<0c00c01l0c00c00?o00000;<0C02c04`06`2c04`00ol00000V@1V09T0IP0I09T0IP03o`00001o
07l0O`1o01/0O`1o00?o000006H0V@1V09T07@1V09T00`000000C02c04`0/`0Q04`0/`03o`00000c
0<`0<`3<02h0<`3<00?o000001T0iP0I0>H07@0I0>H5ooooo`4000000Oooool0000300000?oooooo
oooo00;ooooo103V01T00ol00000c00c0<`0<`0O0<`0<`03o`00002c04`0/`1<01/0/`1<00?o0000
09T0IP2I06H06@2I06H00ol00000O`1o07l0O`0K07l0O`03o`00001V09T0IP2I01d0IP2I00<00000
04`0/`1<0;<08P1<0;<00ol00000<`3<03<0c00]03<0c003o`00000I0>H06@3V01h06@3V1Oooool1
0000007ooooo00000`00003oooooooooo`02ooooo`<0iP0I00?o00000<`0<`3<03<07`3<03<00ol0
0000/`1<0;<0C00K0;<0C003o`00002I06H0V@1V01T0V@1V00?o000007l0O`1o07l06`1o07l00ol0
0000IP2I06H0V@0M06H0V@030000001<0;<0C02c0280C02c00?o000003<0c00c0<`0;@0c0<`00ol0
00006@3V01T0iP0O01T0iPGooooo0@000001ooooo`0000<00000ooooooooool00_ooool20>H06@03
o`00003<03<0c00c01l0c00c00?o00000;<0C02c04`06`2c04`00ol00000V@1V09T0IP0I09T0IP03
o`00001o07l0O`1o01/0O`1o00?o000006H0V@1V09T07@1V09T00`000000C02c04`0/`0R04`0/`03
o`00000c0<`0<`3<02d0<`3<00?o000001T0iP0I0>H0800I0>H5ooooo`4000000Oooool000030000
0?oooooooooo00;ooooo00<0iP0Io`00003<03<0803<03<00ol00000/`1<0;<0C00K0;<0C003o`00
002I06H0V@1V01T0V@1V00?o000007l0O`1o07l06`1o07l00ol00000IP2I06H0V@0M06H0V@030000
001<0;<0C02c0280C02c00?o000003<0c00c0<`0;P0c0<`00ol000006@3V01T0iP0P01T0iPGooooo
0@000001ooooo`0000<00000ooooooooool00_ooool00ol00000c00c0<`0<`0O0<`0<`03o`00002c
04`0/`1<01/0/`1<00?o000009T0IP2I06H06@2I06H00ol00000O`1o07l0O`0K07l0O`03o`00001V
09T0IP2I01d0IP2I00<0000004`0/`1<0;<08P1<0;<00ol00000<`3<03<0c00^03<0c003o`00000I
0>H06@3V02406@3V1Oooool10000007ooooo00000`00003oooooooooo`02ooooob40c00c00?o0000
0;<0C02c04`06`2c04`00ol00000V@1V09T0IP0J09T0IP03o`00001o07l0O`1o01X0O`1o00?o0000
06H0V@1V09T07@1V09T00`000000C02c04`0/`0R04`0/`03o`00000c0<`0<`3<02h0<`3<00?o0000
01T0iP0I0>H08P0I0>H5ooooo`4000000Oooool0000300000?oooooooooo00;ooooo803<03<00ol0
0000/`1<0;<0C00K0;<0C003o`00002I06H0V@1V01X0V@1V00?o000007l0O`1o07l06P1o07l00ol0
0000IP2I06H0V@0L06H0V@800000901<0;<00ol00000<`3<03<0c00^03<0c003o`00000I0>H06@3V
02<06@3V1Oooool10000007ooooo00000`00003oooooooooo`02oooooal0c00c00?o00000;<0C02c
04`06`2c04`00ol00000V@1V09T0IP0J09T0IP03o`00001o07l0O`1o01X0O`1o00?o000006H0V@1V
09T0701V09T00`000000C02c04`0/`0S04`0/`03o`00000c0<`0<`3<02h0<`3<00?o000001T0iP0I
0>H0900I0>H5ooooo`4000000Oooool0000300000?oooooooooo00;ooooo7P3<03<00ol00000/`1<
0;<0C00K0;<0C003o`00002I06H0V@1V01X0V@1V00?o000007l0O`1o07l06P1o07l00ol00000IP2I
06H0V@0L06H0V@030000001<0;<0C02c02<0C02c00?o000003<0c00c0<`0;P0c0<`00ol000006@3V
01T0iP0U01T0iPGooooo0@000001ooooo`0000<00000ooooooooool00_oooolM0<`0<`03o`00002c
04`0/`1<01/0/`1<00?o000009T0IP2I06H06P2I06H00ol00000O`1o07l0O`0J07l0O`03o`00001V
09T0IP2I01d0IP2I00<0000004`0/`1<0;<08P1<0;<00ol00000<`3<03<0c00^03<0c003o`00000I
0>H06@3V02H06@3V1Oooool10000007ooooo00000`00003oooooooooo`02oooooa`0c00c00?o0000
0;<0C02c04`06`2c04`00ol00000V@1V09T0IP0J09T0IP03o`00001o07l0O`1o01X0O`1o00?o0000
06H0V@1V09T07@1V09T00`000000C02c04`0/`0R04`0/`03o`00000c0<`0<`3<02h0<`3<00?o0000
01T0iP0I0>H09`0I0>H5ooooo`4000000Oooool0000300000?oooooooooo00;ooooo6`3<03<00ol0
0000/`1<0;<0C00K0;<0C003o`00002I06H0V@1V01X0V@1V00?o000007l0O`1o07l06P1o07l00ol0
0000IP2I06H0V@0M06H0V@030000001<0;<0C02c0280C02c00?o000003<0c00c0<`0;P0c0<`00ol0
00006@3V01T0iP0X01T0iPGooooo0@000001ooooo`0000<00000ooooooooool00_oooolJ0<`0<`03
o`00002c04`0/`1<01/0/`1<00?o000009T0IP2I06H06P2I06H00ol00000O`1o07l0O`0J07l0O`03
o`00001V09T0IP2I01d0IP2I00<0000004`0/`1<0;<08P1<0;<00ol00000<`3<03<0c00^03<0c003
o`00000I0>H06@3V02T06@3V1Oooool10000007ooooo00000`00003oooooooooo`02oooooaT0c00c
00?o00000;<0C02c04`06`2c04`00ol00000V@1V09T0IP0J09T0IP03o`00001o07l0O`1o01X0O`1o
00?o000006H0V@1V09T07@1V09T00`000000C02c04`0/`0R04`0/`03o`00000c0<`0<`3<02h0<`3<
00?o000001T0iP0I0>H0:P0I0>H5ooooo`4000000Oooool0000300000?oooooooooo00;ooooo603<
03<00ol00000/`1<0;<0C00K0;<0C003o`00002I06H0V@1V01X0V@1V00?o000007l0O`1o07l06P1o
07l00ol00000IP2I06H0V@0M06H0V@030000001<0;<0C02c0280C02c00?o000003<0c00c0<`0;P0c
0<`00ol000006@3V01T0iP0[01T0iPGooooo0@000001ooooo`0000<00000ooooooooool00_oooolG
0<`0<`03o`00002c04`0/`1<01/0/`1<00?o000009T0IP2I06H06P2I06H00ol00000O`1o07l0O`0J
07l0O`03o`00001V09T0IP2I01d0IP2I00<0000004`0/`1<0;<08P1<0;<00ol00000<`3<03<0c00^
03<0c003o`00000I0>H06@3V02`06@3V1Oooool10000007ooooo00000`00003oooooooooo`02oooo
oaH0c00c00?o00000;<0C02c04`06`2c04`00ol00000V@1V09T0IP0I09T0IP;o0000701o07l00ol0
0000IP2I06H0V@0M06H0V@030000001<0;<0C02c0280C02c00?o000003<0c00c0<`0;P0c0<`00ol0
00006@3V01T0iP0]01T0iPGooooo0@000001ooooo`0000<00000ooooooooool00_oooolE0<`0<`03
o`00002c04`0/`1<01/0/`1<00?o000009T0IP2I06H06@2I06H00ol00000O`1o07l0O`0K07l0O`03
o`00001V09T0IP2I01d0IP2I00<0000004`0/`1<0;<08P1<0;<00ol00000<`3<03<0c00^03<0c003
o`00000I0>H06@3V02h06@3V1Oooool10000007ooooo00000`00003oooooooooo`02oooooa@0c00c
00?o00000;<0C02c04`06`2c04`00ol00000V@1V09T0IP0J09T0IP03o`00001o07l0O`1o01/0O`1o
00?o000006H0V@1V09T0701V09T00`000000C02c04`0/`0R04`0/`03o`00000c0<`0<`3<02h0<`3<
00?o000001T0iP0I0>H0;`0I0>H5ooooo`4000000Oooool0000300000?oooooooooo00;ooooo4`3<
03<00ol00000/`1<0;<0C00K0;<0C003o`00002I06H0V@1V01X0V@1V00?o000007l0O`1o07l06`1o
07l00ol00000IP2I06H0V@0L06H0V@030000001<0;<0C02c0280C02c00?o000003<0c00c0<`0;P0c
0<`00ol000006@3V01T0iP0`01T0iPGooooo0@000001ooooo`0000<00000ooooooooool00_oooolB
0<`0<`03o`00002c04`0/`1<01/0/`1<00?o000009T0IP2I06H06P2I06H00ol00000O`1o07l0O`0K
07l0O`03o`00001V09T0IP2I01`0IP2I00<0000004`0/`1<0;<08P1<0;<00ol00000<`3<03<0c00^
03<0c003o`00000I0>H06@3V03406@3V1Oooool10000007ooooo00000`00003oooooooooo`02oooo
oa40c00c00?o00000;<0C02c04`06`2c04`00ol00000V@1V09T0IP0J09T0IP03o`00001o07l0O`1o
01/0O`1o00?o000006H0V@1V09T07@1V09T00`000000C02c04`0/`0Q04`0/`03o`00000c0<`0<`3<
02h0<`3<00?o000001T0iP0I0>H0<P0I0>H5ooooo`4000000Oooool0000300000?oooooooooo00;o
oooo403<03<00ol00000/`1<0;<0C00K0;<0C003o`00002I06H0V@1V01X0V@1V00?o000007l0O`1o
07l06`1o07l00ol00000IP2I06H0V@0M06H0V@030000001<0;<0C02c0240C02c00?o000003<0c00c
0<`0;P0c0<`00ol000006@3V01T0iP0c01T0iPGooooo0@000001ooooo`0000<00000ooooooooool0
0_ooool?0<`0<`03o`00002c04`0/`1<01`0/`1<00?o000009T0IP2I06H06@2I06H00ol00000O`1o
07l0O`0K07l0O`03o`00001V09T0IP2I01d0IP2I00<0000004`0/`1<0;<08@1<0;<00ol00000<`3<
03<0c00^03<0c003o`00000I0>H06@3V03@06@3V1Oooool10000007ooooo00000`00003ooooooooo
o`02ooooo`h0c00c00?o00000;<0C02c04`0702c04`00ol00000V@1V09T0IP0I09T0IP03o`00001o
07l0O`1o01/0O`1o00?o000006H0V@1V09T07@1V09T00`000000C02c04`0/`0R04`0/`03o`00000c
0<`0<`3<02d0<`3<00?o000001T0iP0I0>H0=@0I0>H5ooooo`4000000Oooool0000300000?oooooo
oooo00;ooooo3@3<03<00ol00000/`1<0;<0C00L0;<0C003o`00002I06H0V@1V01T0V@1V00?o0000
07l0O`1o07l06`1o07l00ol00000IP2I06H0V@0M06H0V@030000001<0;<0C02c0280C02c00?o0000
03<0c00c0<`0;@0c0<`00ol000006@3V01T0iP0f01T0iPGooooo0@000001ooooo`0000<00000oooo
ooooool00_ooool<0<`0<`03o`00002c04`0/`1<01`0/`1<00?o000009T0IP2I06H06@2I06H00ol0
0000O`1o07l0O`0K07l0O`03o`00001V09T0IP2I01d0IP2I00<0000004`0/`1<0;<08P1<0;<00ol0
0000<`3<03<0c00]03<0c003o`00000I0>H06@3V03L06@3V1Oooool10000007ooooo00000`00003o
ooooooooo`02ooooo``0c00c00?o00000;<0C02c04`06`2c04`00ol00000V@1V09T0IP0I09T0IP03
o`00001o07l0O`1o01/0O`1o00?o000006H0V@1V09T07@1V09T00`000000C02c04`0/`0R04`0/`03
o`00000c0<`0<`3<02h0<`3<00?o000001T0iP0I0>H0=`0I0>H5ooooo`4000000Oooool000030000
0?oooooooooo00;ooooo2`3<03<00ol00000/`1<0;<0C00K0;<0C003o`00002I06H0V@1V01T0V@1V
00?o000007l0O`1o07l06`1o07l00ol00000IP2I06H0V@0M06H0V@030000001<0;<0C02c0280C02c
00?o000003<0c00c0<`0;P0c0<`00ol000006@3V01T0iP0h01T0iPGooooo0@000001ooooo`0000<0
0000ooooooooool00_ooool90<`0<`;o00007@2c04`00ol00000V@1V09T0IP0I09T0IP03o`00001o
07l0O`1o01X0O`1o0_l0000O06H0V@030000001<0;<0C02c0280C02c00?o000003<0c00c0<`0;@0c
0<`2o`0003/06@3V1Oooool10000007ooooo00000`00003oooooooooo`02ooooo`P0c00c00?o0000
0;<0C02c04`0702c04`00ol00000V@1V09T0IP0J09T0IP03o`00001o07l0O`1o01T0O`1o00?o0000
06H0V@1V09T07P1V09T00`000000C02c04`0/`0R04`0/`03o`00000c0<`0<`3<02d0<`3<00?o0000
01T0iP0I0>H0>`0I0>H5ooooo`4000000Oooool0000300000?oooooooooo00;ooooo1`3<03<00ol0
0000/`1<0;<0C00L0;<0C003o`00002I06H0V@1V01X0V@1V00?o000007l0O`1o07l06@1o07l00ol0
0000IP2I06H0V@0N06H0V@030000001<0;<0C02c0280C02c00?o000003<0c00c0<`0;@0c0<`00ol0
00006@3V01T0iP0l01T0iPGooooo0@000001ooooo`0000<00000ooooooooool00_ooool60<`0<`03
o`00002c04`0/`1<01`0/`1<00?o000009T0IP2I06H06P2I06H00ol00000O`1o07l0O`0I07l0O`03
o`00001V09T0IP2I01h0IP2I00<0000004`0/`1<0;<08P1<0;<00ol00000<`3<03<0c00]03<0c003
o`00000I0>H06@3V03d06@3V1Oooool10000007ooooo00000`00003oooooooooo`02ooooo`D0c00c
00?o00000;<0C02c04`0702c04`00ol00000V@1V09T0IP0J09T0IP03o`00001o07l0O`1o01T0O`1o
00?o000006H0V@1V09T07P1V09T00`000000C02c04`0/`0R04`0/`03o`00000c0<`0<`3<02d0<`3<
00?o000001T0iP0I0>H0?P0I0>H5ooooo`4000000Oooool0000300000?oooooooooo00;ooooo103<
03<00ol00000/`1<0;<0C00K0;<0C0;o0000702I06H00ol00000O`1o07l0O`0I07l0O`03o`00001V
09T0IP2I01h0IP2I00<0000004`0/`1<0;<08P1<0;<00ol00000<`3<03<0c00]03<0c003o`00000I
0>H06@3V03l06@3V1Oooool10000007ooooo00000`00003oooooooooo`02ooooo`<0c00c00?o0000
0;<0C02c04`06`2c04`00ol00000V@1V09T0IP0K09T0IP03o`00001o07l0O`1o01X0O`1o00?o0000
06H0V@1V09T07@1V09T00`000000C02c04`0/`0R04`0/`03o`00000c0<`0<`3<02d0<`3<00?o0000
01T0iP0I0>H0@00I0>H5ooooo`4000000Oooool0000300000?oooooooooo00;ooooo0P3<03<00ol0
0000/`1<0;<0C00K0;<0C003o`00002I06H0V@1V01/0V@1V00?o000007l0O`1o07l06P1o07l00ol0
0000IP2I06H0V@0M06H0V@030000001<0;<0C02c0280C02c00?o000003<0c00c0<`0;@0c0<`00ol0
00006@3V01T0iP1101T0iPGooooo0@000001ooooo`0000<00000ooooooooool00_ooool00`3<03?o
00000;<0C00L0;<0C003o`00002I06H0V@1V01/0V@1V00?o000007l0O`1o07l06P1o07l00ol00000
IP2I06H0V@0M06H0V@030000001<0;<0C02c0280C02c00?o000003<0c00c0<`0;@0c0<`00ol00000
6@3V01T0iP1201T0iPGooooo0@000001ooooo`0000<00000ooooooooool00_ooool00ol00000/`1<
0;<0C00K0;<0C003o`00002I06H0V@1V01/0V@1V00?o000007l0O`1o07l06P1o07l00ol00000IP2I
06H0V@0M06H0V@030000001<0;<0C02c0280C02c00?o000003<0c00c0<`0;@0c0<`00ol000006@3V
01T0iP1301T0iPGooooo0@000001ooooo`0000<00000ooooooooool00_oooolM0;<0C003o`00002I
06H0V@1V01/0V@1V00?o000007l0O`1o07l06P1o07l00ol00000IP2I06H0V@0M06H0V@030000001<
0;<0C02c0280C02c00?o000003<0c00c0<`0;@0c0<`00ol000006@3V01T0iP1401T0iPGooooo0@00
0001ooooo`0000<00000ooooooooool00_oooolL0;<0C003o`00002I06H0V@1V01X0V@1V0_l0000L
07l0O`03o`00001V09T0IP2I01d0IP2I00<0000004`0/`1<0;<08@1<0;<2o`0002l0<`3<00?o0000
01T0iP0I0>H0A@0I0>H5ooooo`4000000Oooool0000300000?oooooooooo00;ooooo6`2c04`00ol0
0000V@1V09T0IP0J09T0IP03o`00001o07l0O`1o01/0O`1o00?o000006H0V@1V09T07@1V09T00`00
0000C02c04`0/`0Q04`0/`03o`00000c0<`0<`3<02h0<`3<00?o000001T0iP0I0>H0AP0I0>H5oooo
o`4000000Oooool0000300000?oooooooooo00;ooooo6P2c04`00ol00000V@1V09T0IP0J09T0IP03
o`00001o07l0O`1o01/0O`1o00?o000006H0V@1V09T07@1V09T00`000000C02c04`0/`0Q04`0/`03
o`00000c0<`0<`3<02h0<`3<00?o000001T0iP0I0>H0A`0I0>H5ooooo`4000000Oooool000030000
0?oooooooooo00;ooooo6@2c04`00ol00000V@1V09T0IP0J09T0IP03o`00001o07l0O`1o01/0O`1o
00?o000006H0V@1V09T07@1V09T00`000000C02c04`0/`0Q04`0/`03o`00000c0<`0<`3<02h0<`3<
00?o000001T0iP0I0>H0B00I0>H5ooooo`4000000Oooool0000300000?oooooooooo00;ooooo602c
04`00ol00000V@1V09T0IP0J09T0IP03o`00001o07l0O`1o01/0O`1o00?o000006H0V@1V09T07@1V
09T00`000000C02c04`0/`0Q04`0/`03o`00000c0<`0<`3<02h0<`3<00?o000001T0iP0I0>H0B@0I
0>H5ooooo`4000000Oooool0000300000?oooooooooo00;ooooo5`2c04`00ol00000V@1V09T0IP0J
09T0IP03o`00001o07l0O`1o01/0O`1o00?o000006H0V@1V09T07@1V09T00`000000C02c04`0/`0Q
04`0/`03o`00000c0<`0<`3<02h0<`3<00?o000001T0iP0I0>H0BP0I0>H5ooooo`4000000Oooool0
000300000?oooooooooo00;ooooo5`2c04`00ol00000V@1V09T0IP0I09T0IP03o`00001o07l0O`1o
01/0O`1o00?o000006H0V@1V09T07@1V09T00`000000C02c04`0/`0Q04`0/`03o`00000c0<`0<`3<
02h0<`3<00?o000001T0iP0I0>H0B`0I0>H5ooooo`4000000Oooool0000300000?oooooooooo00;o
oooo5P2c04`00ol00000V@1V09T0IP0I09T0IP03o`00001o07l0O`1o01`0O`1o00?o000006H0V@1V
09T0701V09T00`000000C02c04`0/`0R04`0/`03o`00000c0<`0<`3<02d0<`3<00?o000001T0iP0I
0>H0C00I0>H5ooooo`4000000Oooool0000300000?oooooooooo00;ooooo5@2c04`00ol00000V@1V
09T0IP0I09T0IP03o`00001o07l0O`1o01`0O`1o00?o000006H0V@1V09T0701V09T00`000000C02c
04`0/`0R04`0/`03o`00000c0<`0<`3<02d0<`3<00?o000001T0iP0I0>H0C@0I0>H5ooooo`400000
0Oooool0000300000?oooooooooo00;ooooo502c04`00ol00000V@1V09T0IP0I09T0IP03o`00001o
07l0O`1o01`0O`1o00?o000006H0V@1V09T0701V09T00`000000C02c04`0/`0R04`0/`03o`00000c
0<`0<`3<02d0<`3<00?o000001T0iP0I0>H0CP0I0>H5ooooo`4000000Oooool0000300000?oooooo
oooo00;ooooo4`2c04`00ol00000V@1V09T0IP0I09T0IP03o`00001o07l0O`1o01`0O`1o00?o0000
06H0V@1V09T0701V09T00`000000C02c04`0/`0S04`0/`03o`00000c0<`0<`3<02d0<`3<00?o0000
01T0iP0I0>H0CP0I0>H5ooooo`4000000Oooool0000300000?oooooooooo00;ooooo4P2c04`00ol0
0000V@1V09T0IP0I09T0IP03o`00001o07l0O`1o01`0O`1o00?o000006H0V@1V09T0701V09T00`00
0000C02c04`0/`0S04`0/`03o`00000c0<`0<`3<02d0<`3<00?o000001T0iP0I0>H0C`0I0>H5oooo
o`4000000Oooool0000300000?oooooooooo00;ooooo4@2c04`00ol00000V@1V09T0IP0J09T0IP03
o`00001o07l0O`1o01X0O`1o0_l0000N06H0V@030000001<0;<0C02c0280C02c0_l0000_03<0c003
o`00000I0>H06@3V05006@3V00?o0000ooooooooool00_ooool10000007ooooo00000`00003ooooo
ooooo`02oooooa00/`1<00?o000009T0IP2I06H06P2I06H00ol00000O`1o07l0O`0J07l0O`03o`00
001V09T0IP2I01d0IP2I00<0000004`0/`1<0;<08P1<0;<00ol00000<`3<03<0c00^03<0c003o`00
000I0>H06@3V05006@3V00?o0000ooooooooool00oooool10000007ooooo00000`00003ooooooooo
o`02ooooo`l0/`1<00?o000009T0IP2I06H06P2I06H00ol00000O`1o07l0O`0J07l0O`03o`00001V
09T0IP2I01d0IP2I00<0000004`0/`1<0;<08P1<0;<00ol00000<`3<03<0c00^03<0c003o`00000I
0>H06@3V05006@3V00?o00000000ooooool01?ooool10000007ooooo00000`00003oooooooooo`02
ooooo`h0/`1<00?o000009T0IP2I06H06P2I06H00ol00000O`1o07l0O`0J07l0O`03o`00001V09T0
IP2I01d0IP2I00<0000004`0/`1<0;<08P1<0;<00ol00000<`3<03<0c00^03<0c003o`00000I0>H0
6@3V05006@3V00?o00000000o`000?l01Oooool10000007ooooo00000`00003oooooooooo`02oooo
o`d0/`1<00?o000009T0IP2I06H06P2I06H00ol00000O`1o07l0O`0J07l0O`03o`00001V09T0IP2I
01d0IP2I00<0000004`0/`1<0;<08P1<0;<00ol00000<`3<03<0c00^03<0c003o`00000I0>H06@3V
05006@3V00Co00000000o`000?l0003o1Oooool10000007ooooo00000`00003oooooooooo`02oooo
o``0/`1<00?o000009T0IP2I06H06P2I06H00ol00000O`1o07l0O`0J07l0O`03o`00001V09T0IP2I
01d0IP2I00<0000004`0/`1<0;<08P1<0;<00ol00000<`3<03<0c00^03<0c003o`00000I0>H06@3V
05006@3V00?o00000000o`000?l00P000?l5ooooo`4000000Oooool0000300000?oooooooooo00;o
oooo2`2c04`00ol00000V@1V09T0IP0J09T0IP03o`00001o07l0O`1o01X0O`1o00?o000006H0V@1V
09T07@1V09T00`000000C02c04`0/`0R04`0/`03o`00000c0<`0<`3<02h0<`3<00?o000001T0iP0I
0>H0D00I0>H00ol00000003o0000o`030000o`Gooooo0@000001ooooo`0000<00000ooooooooool0
0_ooool:0;<0C003o`00002I06H0V@1V01X0V@1V00?o000007l0O`1o07l06P1o07l00ol00000IP2I
06H0V@0M06H0V@030000001<0;<0C02c0280C02c00?o000003<0c00c0<`0;P0c0<`00ol000006@3V
01T0iP1@01T0iP03o`0000000?l0003o00@0003o1Oooool10000007ooooo00000`00003ooooooooo
o`02ooooo`T0/`1<00?o000009T0IP2I06H06P2I06H00ol00000O`1o07l0O`0J07l0O`03o`00001V
09T0IP2I01d0IP2I00<0000004`0/`1<0;<08P1<0;<00ol00000<`3<03<0c00^03<0c003o`00000I
0>H06@3V05006@3V00?o00000000o`000?l01@000?l5ooooo`4000000Oooool0000300000?oooooo
oooo00;ooooo202c04`00ol00000V@1V09T0IP0J09T0IP03o`00001o07l0O`1o01X0O`1o00?o0000
06H0V@1V09T07@1V09T00`000000C02c04`0/`0R04`0/`03o`00000c0<`0<`3<02h0<`3<00?o0000
01T0iP0I0>H0D00I0>H00ol00000003o0000o`060000o`Gooooo0@000001ooooo`0000<00000oooo
ooooool00_ooool70;<0C003o`00002I06H0V@1V01X0V@1V00?o000007l0O`1o07l06P1o07l00ol0
0000IP2I06H0V@0M06H0V@030000001<0;<0C02c0280C02c00?o000003<0c00c0<`0;P0c0<`00ol0
00006@3V01T0iP1@01T0iP03o`0000000?l0003o00L0003o1Oooool10000007ooooo00000`00003o
ooooooooo`02ooooo`H0/`1<00?o000009T0IP2I06H06P2I06H00ol00000O`1o07l0O`0J07l0O`03
o`00001V09T0IP2I01d0IP2I00<0000004`0/`1<0;<08P1<0;<00ol00000<`3<03<0c00^03<0c003
o`00000I0>H06@3V05006@3V00?o00000000o`000?l020000?l5ooooo`4000000Oooool000030000
0?oooooooooo00;ooooo1@2c04`00ol00000V@1V09T0IP0J09T0IP03o`00001o07l0O`1o01/0O`1o
00?o000006H0V@1V09T0701V09T00`000000C02c04`0/`0S04`0/`03o`00000c0<`0<`3<02d0<`3<
00?o000001T0iP0I0>H0D00I0>H00ol00000003o0000o`090000o`Gooooo0@000001ooooo`0000<0
0000ooooooooool00_ooool40;<0C003o`00002I06H0V@1V01X0V@1V00?o000007l0O`1o07l06`1o
07l00ol00000IP2I06H0V@0L06H0V@030000001<0;<0C02c02<0C02c00?o000003<0c00c0<`0;@0c
0<`00ol000006@3V01T0iP1@01T0iP03o`0000000?l0003o00X0003o1Oooool10000007ooooo0000
0`00003oooooooooo`02ooooo`<0/`1<00?o000009T0IP2I06H06P2I06H00ol00000O`1o07l0O`0K
07l0O`03o`00001V09T0IP2I01`0IP2I00<0000004`0/`1<0;<08`1<0;<00ol00000<`3<03<0c00]
03<0c003o`00000I0>H06@3V05006@3V00?o00000000o`000?l02`000?l5ooooo`4000000Oooool0
000300000?oooooooooo00;ooooo0P2c04`00ol00000V@1V09T0IP0J09T0IP03o`00001o07l0O`1o
01/0O`1o00?o000006H0V@1V09T0701V09T00`000000C02c04`0/`0S04`0/`03o`00000c0<`0<`3<
02d0<`3<00?o000001T0iP0I0>H0D00I0>H00ol00000003o0000o`0<0000o`Gooooo0@000001oooo
o`0000<00000ooooooooool00_ooool00`2c04co000009T0IP0K09T0IP03o`00001o07l0O`1o01/0
O`1o00?o000006H0V@1V09T0701V09T00`000000C02c04`0/`0S04`0/`03o`00000c0<`0<`3<02d0
<`3<00?o000001T0iP0I0>H0D00I0>H00ol00000003o0000o`0=0000o`Gooooo0@000001ooooo`00
00<00000ooooooooool00_ooool00ol00000V@1V09T0IP0J09T0IP03o`00001o07l0O`1o01/0O`1o
00?o000006H0V@1V09T0701V09T00`000000C02c04`0/`0S04`0/`03o`00000c0<`0<`3<02d0<`3<
00?o000001T0iP0I0>H0D00I0>H00ol00000003o0000o`0>0000o`Gooooo0@000001ooooo`0000<0
0000ooooooooool00_oooolL09T0IP03o`00001o07l0O`1o01X0O`1o0_l0000N06H0V@030000001<
0;<0C02c0280C02c0_l0000_03<0c003o`00000I0>H06@3V05006@3V00?o00000000o`000?l03`00
0?l5ooooo`4000000Oooool0000300000?oooooooooo00;ooooo6`2I06H00ol00000O`1o07l0O`0J
07l0O`03o`00001V09T0IP2I01d0IP2I00<0000004`0/`1<0;<08P1<0;<00ol00000<`3<03<0c00^
03<0c003o`00000I0>H06@3V05006@3V00?o00000000o`000?l040000?l5ooooo`4000000Oooool0
000300000?oooooooooo00;ooooo6P2I06H00ol00000O`1o07l0O`0J07l0O`03o`00001V09T0IP2I
01d0IP2I00<0000004`0/`1<0;<08P1<0;<00ol00000<`3<03<0c00^03<0c003o`00000I0>H06@3V
05006@3V00?o00000000o`000?l04@000?l5ooooo`4000000Oooool0000300000?oooooooooo00;o
oooo6@2I06H00ol00000O`1o07l0O`0J07l0O`03o`00001V09T0IP2I01d0IP2I00<0000004`0/`1<
0;<08P1<0;<00ol00000<`3<03<0c00^03<0c003o`00000I0>H06@3V05006@3V00?o00000000o`00
0?l04P000?l5ooooo`4000000Oooool0000300000?oooooooooo00;ooooo602I06H00ol00000O`1o
07l0O`0J07l0O`03o`00001V09T0IP2I01d0IP2I00<0000004`0/`1<0;<08P1<0;<00ol00000<`3<
03<0c00^03<0c003o`00000I0>H06@3V05006@3V00?o00000000o`000?l04`000?l5ooooo`400000
0Oooool0000300000?oooooooooo00;ooooo5`2I06H00ol00000O`1o07l0O`0K07l0O`03o`00001V
09T0IP2I01d0IP2I00<0000004`0/`1<0;<08P1<0;<00ol00000<`3<03<0c00^03<0c003o`00000I
0>H06@3V05006@3V00?o00000000o`000?l04`000?l5ooooo`4000000Oooool0000300000?oooooo
oooo00;ooooo5`2I06H00ol00000O`1o07l0O`0J07l0O`03o`00001V09T0IP2I01d0IP2I00<00000
04`0/`1<0;<08P1<0;<00ol00000<`3<03<0c00^03<0c003o`00000I0>H06@3V05006@3V00?o0000
0000o`000?l050000?l5ooooo`4000000Oooool0000300000?oooooooooo00;ooooo5P2I06H00ol0
0000O`1o07l0O`0J07l0O`03o`00001V09T0IP2I01d0IP2I00<0000004`0/`1<0;<08P1<0;<00ol0
0000<`3<03<0c00^03<0c003o`00000I0>H06@3V05006@3V00?o00000000o`000?l05@000?l5oooo
o`4000000Oooool0000300000?oooooooooo00;ooooo5@2I06H00ol00000O`1o07l0O`0J07l0O`03
o`00001V09T0IP2I01d0IP2I00<0000004`0/`1<0;<08P1<0;<00ol00000<`3<03<0c00^03<0c003
o`00000I0>H06@3V05006@3V00?o00000000o`000?l05P000?l5ooooo`4000000Oooool000030000
0?oooooooooo00;ooooo502I06H00ol00000O`1o07l0O`0J07l0O`03o`00001V09T0IP2I01d0IP2I
00<0000004`0/`1<0;<08P1<0;<00ol00000<`3<03<0c00^03<0c003o`00000I0>H06@3V05006@3V
00?o00000000o`000?l05`000?l5ooooo`4000000Oooool0000300000?oooooooooo00;ooooo4`2I
06H00ol00000O`1o07l0O`0J07l0O`03o`00001V09T0IP2I01d0IP2I00<0000004`0/`1<0;<08P1<
0;<00ol00000<`3<03<0c00^03<0c003o`00000I0>H06@3V05006@3V00?o00000000o`000?l06000
0?l5ooooo`4000000Oooool0000300000?oooooooooo00;ooooo4P2I06H00ol00000O`1o07l0O`0J
07l0O`03o`00001V09T0IP2I01d0IP2I00<0000004`0/`1<0;<08P1<0;<00ol00000<`3<03<0c00^
03<0c003o`00000I0>H06@3V05006@3V00?o00000000o`000?l06@000?l5ooooo`4000000Oooool0
000300000?oooooooooo00;ooooo4@2I06H00ol00000O`1o07l0O`0J07l0O`03o`00001V09T0IP2I
01d0IP2I00<0000004`0/`1<0;<08P1<0;<00ol00000<`3<03<0c00^03<0c003o`00000I0>H06@3V
05006@3V00?o00000000o`000?l06P000?l5ooooo`4000000Oooool0000300000?oooooooooo00;o
oooo402I06H00ol00000O`1o07l0O`0J07l0O`03o`00001V09T0IP2I01d0IP2I00<0000004`0/`1<
0;<08P1<0;<00ol00000<`3<03<0c00^03<0c003o`00000I0>H06@3V05006@3V00?o00000000o`00
0?l06`000?l5ooooo`4000000Oooool0000300000?oooooooooo00;ooooo3`2I06H00ol00000O`1o
07l0O`0J07l0O`03o`00001V09T0IP2I01d0IP2I00<0000004`0/`1<0;<08P1<0;<00ol00000<`3<
03<0c00^03<0c003o`00000I0>H06@3V05006@3V00?o00000000o`000?l070000?l5ooooo`400000
0Oooool0000300000?oooooooooo00;ooooo3P2I06H00ol00000O`1o07l0O`0J07l0O`03o`00001V
09T0IP2I01d0IP2I00<0000004`0/`1<0;<08P1<0;<00ol00000<`3<03<0c00^03<0c003o`00000I
0>H06@3V05006@3V00?o00000000o`000?l07@000?l5ooooo`4000000Oooool0000300000?oooooo
oooo00;ooooo3@2I06H00ol00000O`1o07l0O`0J07l0O`03o`00001V09T0IP2I01d0IP2I00<00000
04`0/`1<0;<08P1<0;<00ol00000<`3<03<0c00^03<0c003o`00000I0>H06@3V05006@3V00?o0000
0000o`000?l07P000?l5ooooo`4000000Oooool0000300000?oooooooooo00;ooooo302I06H00ol0
0000O`1o07l0O`0K07l0O`03o`00001V09T0IP2I01`0IP2I00<0000004`0/`1<0;<08`1<0;<00ol0
0000<`3<03<0c00]03<0c003o`00000I0>H06@3V05006@3V00?o00000000o`000?l07`000?l5oooo
o`4000000Oooool0000300000?oooooooooo00;ooooo2`2I06H00ol00000O`1o07l0O`0K07l0O`03
o`00001V09T0IP2I01`0IP2I00<0000004`0/`1<0;<08`1<0;<00ol00000<`3<03<0c00]03<0c003
o`00000I0>H06@3V05006@3V00?o00000000o`000?l080000?l5ooooo`4000000Oooool000030000
0?oooooooooo00;ooooo2P2I06H00ol00000O`1o07l0O`0K07l0O`03o`00001V09T0IP2I01`0IP2I
00<0000004`0/`1<0;<08`1<0;<00ol00000<`3<03<0c00]03<0c003o`00000I0>H06@3V05006@3V
00?o00000000o`000?l08@000?l5ooooo`4000000Oooool0000300000?oooooooooo00;ooooo2@2I
06H00ol00000O`1o07l0O`0K07l0O`03o`00001V09T0IP2I01`0IP2I00<0000004`0/`1<0;<08`1<
0;<00ol00000<`3<03<0c00]03<0c003o`00000I0>H06@3V05006@3V00?o00000000o`000?l08P00
0?l5ooooo`4000000Oooool0000300000?oooooooooo00;ooooo202I06H00ol00000O`1o07l0O`0K
07l0O`03o`00001V09T0IP2I01`0IP2I00<0000004`0/`1<0;<08`1<0;<00ol00000<`3<03<0c00]
03<0c003o`00000I0>H06@3V05006@3V00?o00000000o`000?l08`000?l5ooooo`4000000Oooool0
000300000?oooooooooo00;ooooo1`2I06H00ol00000O`1o07l0O`0K07l0O`03o`00001V09T0IP2I
01`0IP2I00<0000004`0/`1<0;<08`1<0;<00ol00000<`3<03<0c00]03<0c003o`00000I0>H06@3V
05006@3V00?o00000000o`000?l090000?l5ooooo`4000000Oooool0000300000?oooooooooo00;o
oooo1P2I06H00ol00000O`1o07l0O`0K07l0O`03o`00001V09T0IP2I01`0IP2I00<0000004`0/`1<
0;<08`1<0;<00ol00000<`3<03<0c00]03<0c003o`00000I0>H06@3V05006@3V00?o00000000o`00
0?l09@000?l5ooooo`4000000Oooool0000300000?oooooooooo00;ooooo1@2I06H00ol00000O`1o
07l0O`0J07l0O`;o00007P1V09T00`000000C02c04`0/`0R04`0/`;o0000;`0c0<`00ol000006@3V
01T0iP1@01T0iP03o`0000000?l0003o02H0003o1Oooool10000007ooooo00000`00003ooooooooo
o`02ooooo`@0V@1V00?o000007l0O`1o07l06P1o07l00ol00000IP2I06H0V@0M06H0V@030000001<
0;<0C02c0280C02c00?o000003<0c00c0<`0;P0c0<`00ol000006@3V01T0iP1@01T0iP03o`000000
0?l0003o02L0003o1Oooool10000007ooooo00000`00003oooooooooo`02ooooo`<0V@1V00?o0000
07l0O`1o07l06P1o07l00ol00000IP2I06H0V@0M06H0V@030000001<0;<0C02c0280C02c00?o0000
03<0c00c0<`0;P0c0<`00ol000006@3V01T0iP1@01T0iP03o`0000000?l0003o02P0003o1Oooool1
0000007ooooo00000`00003oooooooooo`02ooooo`80V@1V00?o000007l0O`1o07l06P1o07l00ol0
0000IP2I06H0V@0M06H0V@030000001<0;<0C02c0280C02c00?o000003<0c00c0<`0;P0c0<`00ol0
00006@3V01T0iP1@01T0iP03o`0000000?l0003o02T0003o1Oooool10000007ooooo00000`00003o
ooooooooo`02ooooo`0309T0I_l00000O`1o01`0O`1o00?o000006H0V@1V09T07@1V09T00`000000
C02c04`0/`0R04`0/`03o`00000c0<`0<`3<02d0<`3<00?o000001T0iP0I0>H0D@0I0>H00ol00000
003o0000o`0Y0000o`Gooooo0@000001ooooo`0000<00000ooooooooool00_ooool00ol00000O`1o
07l0O`0K07l0O`03o`00001V09T0IP2I01d0IP2I00<0000004`0/`1<0;<08P1<0;<00ol00000<`3<
03<0c00]03<0c003o`00000I0>H06@3V05406@3V00?o00000000o`000?l0:P000?l5ooooo`400000
0Oooool0000300000?oooooooooo00;ooooo7@1o07l00ol00000IP2I06H0V@0M06H0V@030000001<
0;<0C02c0280C02c00?o000003<0c00c0<`0;@0c0<`00ol000006@3V01T0iP1A01T0iP03o`000000
0?l0003o02/0003o1Oooool10000007ooooo00000`00003oooooooooo`02oooooa`0O`1o00?o0000
06H0V@1V09T07@1V09T00`000000C02c04`0/`0R04`0/`03o`00000c0<`0<`3<02d0<`3<00?o0000
01T0iP0I0>H0D@0I0>H00ol00000003o0000o`0/0000o`Gooooo0@000001ooooo`0000<00000oooo
ooooool00_oooolK07l0O`03o`00001V09T0IP2I01d0IP2I00<0000004`0/`1<0;<08P1<0;<00ol0
0000<`3<03<0c00]03<0c003o`00000I0>H06@3V05406@3V00?o00000000o`000?l0;@000?l5oooo
o`4000000Oooool0000300000?oooooooooo00;ooooo6P1o07l00ol00000IP2I06H0V@0M06H0V@03
0000001<0;<0C02c0280C02c00?o000003<0c00c0<`0;@0c0<`00ol000006@3V01T0iP1A01T0iP03
o`0000000?l0003o02h0003o1Oooool10000007ooooo00000`00003oooooooooo`02oooooaT0O`1o
00?o000006H0V@1V09T07@1V09T00`000000C02c04`0/`0R04`0/`03o`00000c0<`0<`3<02d0<`3<
00?o000001T0iP0I0>H0D@0I0>H00ol00000003o0000o`0_0000o`Gooooo0@000001ooooo`0000<0
0000ooooooooool00_oooolH07l0O`03o`00001V09T0IP2I01d0IP2I00<0000004`0/`1<0;<08P1<
0;<00ol00000<`3<03<0c00]03<0c003o`00000I0>H06@3V05406@3V00?o00000000o`000?l0<000
0?l5ooooo`4000000Oooool0000300000?oooooooooo00;ooooo5`1o07l00ol00000IP2I06H0V@0M
06H0V@030000001<0;<0C02c0280C02c00?o000003<0c00c0<`0;@0c0<`00ol000006@3V01T0iP1A
01T0iP03o`0000000?l0003o0340003o1Oooool10000007ooooo00000`00003oooooooooo`02oooo
oaH0O`1o00?o000006H0V@1V09T07@1V09T00`000000C02c04`0/`0R04`0/`03o`00000c0<`0<`3<
02d0<`3<00?o000001T0iP0I0>H0D@0I0>H00ol00000003o0000o`0b0000o`Gooooo0@000001oooo
o`0000<00000ooooooooool00_oooolE07l0O`03o`00001V09T0IP2I01d0IP2I00<0000004`0/`1<
0;<08P1<0;<00ol00000<`3<03<0c00]03<0c003o`00000I0>H06@3V05406@3V00?o00000000o`00
0?l0<`000?l5ooooo`4000000Oooool0000300000?oooooooooo00;ooooo501o07l00ol00000IP2I
06H0V@0M06H0V@030000001<0;<0C02c0280C02c00?o000003<0c00c0<`0;P0c0<`00ol000006@3V
01T0iP1?01T0iP;o0000=P000?l5ooooo`4000000Oooool0000300000?oooooooooo00;ooooo4`1o
07l00ol00000IP2I06H0V@0M06H0V@030000001<0;<0C02c0280C02c00?o000003<0c00c0<`0;P0c
0<`00ol000006@3V01T0iP1?01T0iP03o`0000000?l0003o03H0003o1Oooool10000007ooooo0000
0`00003oooooooooo`02oooooa80O`1o00?o000006H0V@1V09T07@1V09T00`000000C02c04`0/`0R
04`0/`03o`00000c0<`0<`3<02h0<`3<00?o000001T0iP0I0>H0C`0I0>H00ol00000003o0000o`0g
0000o`Gooooo0@000001ooooo`0000<00000ooooooooool00_oooolA07l0O`03o`00001V09T0IP2I
01d0IP2I00<0000004`0/`1<0;<08P1<0;<00ol00000<`3<03<0c00^03<0c003o`00000I0>H06@3V
05006@3V00?o00000000o`000?l0=`000?l5ooooo`4000000Oooool0000300000?oooooooooo00;o
oooo401o07l00ol00000IP2I06H0V@0M06H0V@030000001<0;<0C02c0280C02c00?o000003<0c00c
0<`0;P0c0<`00ol000006@3V01T0iP1@01T0iP03o`0000000?l0003o03P0003o1Oooool10000007o
oooo00000`00003oooooooooo`02ooooo`l0O`1o00?o000006H0V@1V09T07@1V09T00`000000C02c
04`0/`0R04`0/`03o`00000c0<`0<`3<02h0<`3<00?o000001T0iP0I0>H0D00I0>H00ol00000003o
0000o`0i0000o`Gooooo0@000001ooooo`0000<00000ooooooooool00_ooool>07l0O`03o`00001V
09T0IP2I01d0IP2I00<0000004`0/`1<0;<08P1<0;<00ol00000<`3<03<0c00^03<0c003o`00000I
0>H06@3V05006@3V00?o00000000o`000?l0>P000?l5ooooo`4000000Oooool0000300000?oooooo
oooo00;ooooo3@1o07l00ol00000IP2I06H0V@0M06H0V@030000001<0;<0C02c0280C02c00?o0000
03<0c00c0<`0;P0c0<`00ol000006@3V01T0iP1@01T0iP03o`0000000?l0003o03/0003o1Oooool1
0000007ooooo00000`00003oooooooooo`02ooooo``0O`1o00?o000006H0V@1V09T07@1V09T00`00
0000C02c04`0/`0R04`0/`03o`00000c0<`0<`3<02h0<`3<00?o000001T0iP0I0>H0D00I0>H00ol0
0000003o0000o`0l0000o`Gooooo0@000001ooooo`0000<00000ooooooooool00_ooool;07l0O`03
o`00001V09T0IP2I01d0IP2I00<0000004`0/`1<0;<08P1<0;<00ol00000<`3<03<0c00^03<0c003
o`00000I0>H06@3V05006@3V00?o00000000o`000?l0?@000?l5ooooo`4000000Oooool000030000
0?oooooooooo00;ooooo2P1o07l00ol00000IP2I06H0V@0M06H0V@030000001<0;<0C02c0280C02c
00?o000003<0c00c0<`0;P0c0<`00ol000006@3V01T0iP1@01T0iP03o`0000000?l0003o03h0003o
1Oooool10000007ooooo00000`00003oooooooooo`02ooooo`T0O`1o00?o000006H0V@1V09T07@1V
09T00`000000C02c04`0/`0R04`0/`03o`00000c0<`0<`3<02d0<`3<0_l0001B01T0iP03o`000000
0?l0003o03l0003o1Oooool10000007ooooo00000`00003oooooooooo`02ooooo`P0O`1o00?o0000
06H0V@1V09T07P1V09T00`000000C02c04`0/`0Q04`0/`03o`00000c0<`0<`3<02h0<`3<00?o0000
01T0iP0I0>H0D00I0>H00ol00000003o0000o`100000o`Gooooo0@000001ooooo`0000<00000oooo
ooooool00_ooool707l0O`03o`00001V09T0IP2I01h0IP2I00<0000004`0/`1<0;<08@1<0;<00ol0
0000<`3<03<0c00^03<0c003o`00000I0>H06@3V05006@3V00?o00000000o`000?l0@@000?l5oooo
o`4000000Oooool0000300000?oooooooooo00;ooooo1P1o07l00ol00000IP2I06H0V@0N06H0V@03
0000001<0;<0C02c0240C02c00?o000003<0c00c0<`0;P0c0<`00ol000006@3V01T0iP1@01T0iP03
o`0000000?l0003o0480003o1Oooool10000007ooooo00000`00003oooooooooo`02ooooo`D0O`1o
00?o000006H0V@1V09T07P1V09T00`000000C02c04`0/`0Q04`0/`03o`00000c0<`0<`3<02h0<`3<
00?o000001T0iP0I0>H0D00I0>H00ol00000003o0000o`130000o`Gooooo0@000001ooooo`0000<0
0000ooooooooool00_ooool407l0O`03o`00001V09T0IP2I01h0IP2I00<0000004`0/`1<0;<08@1<
0;<00ol00000<`3<03<0c00^03<0c003o`00000I0>H06@3V05006@3V00?o00000000o`000?l0A000
0?l5ooooo`4000000Oooool0000300000?oooooooooo00;ooooo0`1o07l00ol00000IP2I06H0V@0N
06H0V@030000001<0;<0C02c0240C02c00?o000003<0c00c0<`0;P0c0<`00ol000006@3V01T0iP1@
01T0iP03o`0000000?l0003o04D0003o1Oooool10000007ooooo00000`00003oooooooooo`02oooo
o`80O`1o00?o000006H0V@1V09T07@1V09T2000002<0C02c00?o000003<0c00c0<`0;P0c0<`00ol0
00006@3V01T0iP1@01T0iP03o`0000000?l0003o04H0003o1Oooool10000007ooooo00000`00003o
ooooooooo`02ooooo`0307l0Ool00000IP2I01h0IP2I00<0000004`0/`1<0;<08P1<0;<00ol00000
<`3<03<0c00^03<0c003o`00000I0>H06@3V05006@3V00?o00000000o`000?l0A`000?l5ooooo`40
00000Oooool0000300000?oooooooooo00;ooooo00?o000006H0V@1V09T07@1V09T00`000000C02c
04`0/`0R04`0/`03o`00000c0<`0<`3<02h0<`3<00?o000001T0iP0I0>H0D00I0>H00ol00000003o
0000o`180000o`Gooooo0@000001ooooo`0000<00000ooooooooool00_oooolO06H0V@030000001<
0;<0C02c02<0C02c00?o000003<0c00c0<`0;@0c0<`00ol000006@3V01T0iP1@01T0iP03o`000000
0?l0003o04T0003o1Oooool10000007ooooo00000`00003oooooooooo`02oooooah0IP2I00<00000
04`0/`1<0;<08`1<0;<00ol00000<`3<03<0c00]03<0c003o`00000I0>H06@3V05006@3V00?o0000
0000o`000?l0BP000?l5ooooo`4000000Oooool0000300000?oooooooooo00;ooooo7@1V09T00`00
0000C02c04`0/`0S04`0/`03o`00000c0<`0<`3<02d0<`3<00?o000001T0iP0I0>H0D00I0>H00ol0
0000003o0000o`1;0000o`Gooooo0@000001ooooo`0000<00000ooooooooool00_oooolL06H0V@03
0000001<0;<0C02c02<0C02c00?o000003<0c00c0<`0;@0c0<`00ol000006@3V01T0iP1@01T0iP03
o`0000000?l0003o04`0003o1Oooool10000007ooooo00000`00003oooooooooo`02oooooa/0IP2I
00<0000004`0/`1<0;<08`1<0;<00ol00000<`3<03<0c00]03<0c003o`00000I0>H06@3V05006@3V
00?o00000000o`000?l0C@000?l5ooooo`4000000Oooool0000300000?oooooooooo00;ooooo6P1V
09T00`000000C02c04`0/`0S04`0/`03o`00000c0<`0<`3<02d0<`3<00?o000001T0iP0I0>H0D00I
0>H00ol00000003o0000o`1>0000o`Gooooo0@000001ooooo`0000<00000ooooooooool00_oooolI
06H0V@030000001<0;<0C02c02<0C02c00?o000003<0c00c0<`0;@0c0<`00ol000006@3V01T0iP1@
01T0iP03o`0000000?l0003o04l0003o1Oooool10000007ooooo00000`00003oooooooooo`02oooo
oaP0IP2I00<0000004`0/`1<0;<08`1<0;<00ol00000<`3<03<0c00]03<0c003o`00000I0>H06@3V
05006@3V00?o00000000o`000?l0D0000?l5ooooo`4000000Oooool0000300000?oooooooooo00;o
oooo5`1V09T00`000000C02c04`0/`0S04`0/`03o`00000c0<`0<`3<02d0<`3<00?o000001T0iP0I
0>H0D00I0>H00ol00000003o0000o`1A0000o`Gooooo0@000001ooooo`0000<00000ooooooooool0
0_oooolF06H0V@030000001<0;<0C02c02<0C02c00?o000003<0c00c0<`0;@0c0<`00ol000006@3V
01T0iP1@01T0iP03o`0000000?l0003o0580003o1Oooool10000007ooooo00000`00003ooooooooo
o`02oooooaD0IP2I00<0000004`0/`1<0;<08`1<0;<00ol00000<`3<03<0c00]03<0c003o`00000I
0>H06@3V05006@3V00?o00000000o`000?l0D`000?l5ooooo`4000000Oooool0000300000?oooooo
oooo00;ooooo501V09T00`000000C02c04`0/`0R04`0/`;o0000;`0c0<`00ol000006@3V01T0iP1@
01T0iP03o`0000000?l0003o05@0003o1Oooool10000007ooooo00000`00003oooooooooo`02oooo
oa<0IP2I00<0000004`0/`1<0;<08P1<0;<00ol00000<`3<03<0c00^03<0c003o`00000I0>H06@3V
05006@3V00?o00000000o`000?l0E@000?l5ooooo`4000000Oooool0000300000?oooooooooo00;o
oooo4P1V09T00`000000C02c04`0/`0R04`0/`03o`00000c0<`0<`3<02h0<`3<00?o000001T0iP0I
0>H0D00I0>H00ol00000003o0000o`1F0000o`Gooooo0@000001ooooo`0000<00000ooooooooool0
0_oooolB06H0V@030000001<0;<0C02c0280C02c00?o000003<0c00c0<`0;P0c0<`00ol000006@3V
01T0iP1@01T0iP03o`0000000?l0003o05H0003o1Oooool10000007ooooo00000`00003ooooooooo
o`02oooooa40IP2I00<0000004`0/`1<0;<08P1<0;<00ol00000<`3<03<0c00^03<0c003o`00000I
0>H06@3V05006@3V00?o00000000o`000?l0E`000?l5ooooo`4000000Oooool0000300000?oooooo
oooo00;ooooo401V09T00`000000C02c04`0/`0R04`0/`03o`00000c0<`0<`3<02h0<`3<00?o0000
01T0iP0I0>H0D00I0>H00ol00000003o0000o`1H0000o`Gooooo0@000001ooooo`0000<00000oooo
ooooool00_ooool?06H0V@030000001<0;<0C02c0280C02c00?o000003<0c00c0<`0;P0c0<`00ol0
00006@3V01T0iP1@01T0iP03o`0000000?l0003o05T0003o1Oooool10000007ooooo00000`00003o
ooooooooo`02ooooo`h0IP2I00<0000004`0/`1<0;<08P1<0;<00ol00000<`3<03<0c00^03<0c003
o`00000I0>H06@3V05006@3V00?o00000000o`000?l0FP000?l5ooooo`4000000Oooool000030000
0?oooooooooo00;ooooo3@1V09T00`000000C02c04`0/`0R04`0/`03o`00000c0<`0<`3<02h0<`3<
00?o000001T0iP0I0>H0D00I0>H00ol00000003o0000o`1K0000o`Gooooo0@000001ooooo`0000<0
0000ooooooooool00_ooool<06H0V@030000001<0;<0C02c0280C02c00?o000003<0c00c0<`0;P0c
0<`00ol000006@3V01T0iP1@01T0iP03o`0000000?l0003o05`0003o1Oooool10000007ooooo0000
0`00003oooooooooo`02ooooo`/0IP2I00<0000004`0/`1<0;<08P1<0;<00ol00000<`3<03<0c00^
03<0c003o`00000I0>H06@3V05006@3V00?o00000000o`000?l0G@000?l5ooooo`4000000Oooool0
000300000?oooooooooo00;ooooo2P1V09T00`000000C02c04`0/`0R04`0/`03o`00000c0<`0<`3<
02h0<`3<00?o000001T0iP0I0>H0D00I0>H00ol00000003o0000o`1N0000o`Gooooo0@000001oooo
o`0000<00000ooooooooool00_ooool906H0V@030000001<0;<0C02c0280C02c00?o000003<0c00c
0<`0;P0c0<`00ol000006@3V01T0iP1@01T0iP03o`0000000?l0003o05l0003o1Oooool10000007o
oooo00000`00003oooooooooo`02ooooo`P0IP2I00<0000004`0/`1<0;<08P1<0;<00ol00000<`3<
03<0c00^03<0c003o`00000I0>H06@3V05006@3V00?o00000000o`000?l0H0000?l5ooooo`400000
0Oooool0000300000?oooooooooo00;ooooo1`1V09T00`000000C02c04`0/`0R04`0/`03o`00000c
0<`0<`3<02h0<`3<00?o000001T0iP0I0>H0D00I0>H00ol00000003o0000o`1Q0000o`Gooooo0@00
0001ooooo`0000<00000ooooooooool00_ooool606H0V@030000001<0;<0C02c02<0C02c00?o0000
03<0c00c0<`0;@0c0<`00ol000006@3V01T0iP1@01T0iP03o`0000000?l0003o0680003o1Oooool1
0000007ooooo00000`00003oooooooooo`02ooooo`D0IP2I00<0000004`0/`1<0;<08`1<0;<00ol0
0000<`3<03<0c00]03<0c003o`00000I0>H06@3V05006@3V00?o00000000o`000?l0H`000?l5oooo
o`4000000Oooool0000300000?oooooooooo00;ooooo101V09T00`000000C02c04`0/`0S04`0/`03
o`00000c0<`0<`3<02d0<`3<00?o000001T0iP0I0>H0D00I0>H00ol00000003o0000o`1T0000o`Go
oooo0@000001ooooo`0000<00000ooooooooool00_ooool306H0V@030000001<0;<0C02c02<0C02c
00?o000003<0c00c0<`0;@0c0<`00ol000006@3V01T0iP1@01T0iP03o`0000000?l0003o06D0003o
1Oooool10000007ooooo00000`00003oooooooooo`02ooooo`80IP2I00<0000004`0/`1<0;<08`1<
0;<00ol00000<`3<03<0c00]03<0c003o`00000I0>H06@3V05006@3V00?o00000000o`000?l0IP00
0?l5ooooo`4000000Oooool0000300000?oooooooooo00;ooooo00<0IP2I0000001<0;<0901<0;<0
0ol00000<`3<03<0c00]03<0c003o`00000I0>H06@3V05006@3V00?o00000000o`000?l0I`000?l5
ooooo`4000000Oooool0000300000?oooooooooo00;ooooo00<0000004`0/`1<0;<08`1<0;<00ol0
0000<`3<03<0c00]03<0c003o`00000I0>H06@3V05006@3V00?o00000000o`000?l0J0000?l5oooo
o`4000000Oooool0000300000?oooooooooo00;ooooo9@1<0;<00ol00000<`3<03<0c00]03<0c003
o`00000I0>H06@3V05006@3V00?o00000000o`000?l0J@000?l5ooooo`4000000Oooool000030000
0?oooooooooo00;ooooo901<0;<00ol00000<`3<03<0c00]03<0c003o`00000I0>H06@3V05006@3V
00?o00000000o`000?l0JP000?l5ooooo`4000000Oooool0000300000?oooooooooo00;ooooo8P1<
0;<2o`0002l0<`3<00?o000001T0iP0I0>H0D00I0>H00ol00000003o0000o`1[0000o`Gooooo0@00
0001ooooo`0000<00000ooooooooool00_oooolQ04`0/`03o`00000c0<`0<`3<02h0<`3<00?o0000
01T0iP0I0>H0D00I0>H00ol00000003o0000o`1/0000o`Gooooo0@000001ooooo`0000<00000oooo
ooooool00_oooolQ04`0/`03o`00000c0<`0<`3<02h0<`3<00?o000001T0iP0I0>H0D00I0>H00ol0
0000003o0000o`1/0000o`Gooooo0@000001ooooo`0000<00000ooooooooool00_oooolP04`0/`03
o`00000c0<`0<`3<02h0<`3<00?o000001T0iP0I0>H0D00I0>H00ol00000003o0000o`1]0000o`Go
oooo0@000001ooooo`0000<00000ooooooooool00_oooolO04`0/`03o`00000c0<`0<`3<02h0<`3<
00?o000001T0iP0I0>H0D00I0>H00ol00000003o0000o`1^0000o`Gooooo0@000001ooooo`0000<0
0000ooooooooool00_oooolN04`0/`03o`00000c0<`0<`3<02h0<`3<00?o000001T0iP0I0>H0D00I
0>H00ol00000003o0000o`1_0000o`Gooooo0@000001ooooo`0000<00000ooooooooool00_oooolM
04`0/`03o`00000c0<`0<`3<02h0<`3<00?o000001T0iP0I0>H0D00I0>H00ol00000003o0000o`1`
0000o`Gooooo0@000001ooooo`0000<00000ooooooooool00_oooolL04`0/`03o`00000c0<`0<`3<
02h0<`3<00?o000001T0iP0I0>H0D00I0>H00ol00000003o0000o`1a0000o`Gooooo0@000001oooo
o`0000<00000ooooooooool00_oooolK04`0/`03o`00000c0<`0<`3<02h0<`3<00?o000001T0iP0I
0>H0D00I0>H00ol00000003o0000o`1b0000o`Gooooo0@000001ooooo`0000<00000ooooooooool0
0_oooolJ04`0/`03o`00000c0<`0<`3<02h0<`3<00?o000001T0iP0I0>H0D00I0>H00ol00000003o
0000o`1c0000o`Gooooo0@000001ooooo`0000<00000ooooooooool00_oooolI04`0/`03o`00000c
0<`0<`3<02h0<`3<00?o000001T0iP0I0>H0D00I0>H00ol00000003o0000o`1d0000o`Gooooo0@00
0001ooooo`0000<00000ooooooooool00_oooolH04`0/`03o`00000c0<`0<`3<02h0<`3<00?o0000
01T0iP0I0>H0D00I0>H00ol00000003o0000o`1e0000o`Gooooo0@000001ooooo`0000<00000oooo
ooooool00_oooolG04`0/`03o`00000c0<`0<`3<02h0<`3<00?o000001T0iP0I0>H0D00I0>H00ol0
0000003o0000o`1f0000o`Gooooo0@000001ooooo`0000<00000ooooooooool00_oooolF04`0/`03
o`00000c0<`0<`3<02h0<`3<00?o000001T0iP0I0>H0C`0I0>H2o`0007T0003o1Oooool10000007o
oooo00000`00003oooooooooo`02oooooaH0C02c00?o000003<0c00c0<`0;@0c0<`00ol000006@3V
01T0iP1?01T0iP03o`0000000?l0003o07T0003o1Oooool10000007ooooo00000`00003ooooooooo
o`02oooooaD0C02c00?o000003<0c00c0<`0;@0c0<`00ol000006@3V01T0iP1?01T0iP03o`000000
0?l0003o07X0003o1Oooool10000007ooooo00000`00003oooooooooo`02oooooa@0C02c00?o0000
03<0c00c0<`0;@0c0<`00ol000006@3V01T0iP1?01T0iP03o`0000000?l0003o07/0003o1Oooool1
0000007ooooo00000`00003oooooooooo`02oooooa<0C02c00?o000003<0c00c0<`0;@0c0<`00ol0
00006@3V01T0iP1?01T0iP03o`0000000?l0003o07`0003o1Oooool10000007ooooo00000`00003o
ooooooooo`02oooooa80C02c00?o000003<0c00c0<`0;@0c0<`00ol000006@3V01T0iP1@01T0iP03
o`0000000?l0003o07`0003o1Oooool10000007ooooo00000`00003oooooooooo`02oooooa40C02c
00?o000003<0c00c0<`0;@0c0<`00ol000006@3V01T0iP1@01T0iP03o`0000000?l0003o07d0003o
1Oooool10000007ooooo00000`00003oooooooooo`02oooooa00C02c00?o000003<0c00c0<`0;@0c
0<`00ol000006@3V01T0iP1@01T0iP03o`0000000?l0003o07h0003o1Oooool10000007ooooo0000
0`00003oooooooooo`02ooooo`l0C02c00?o000003<0c00c0<`0;@0c0<`00ol000006@3V01T0iP1@
01T0iP03o`0000000?l0003o07l0003o1Oooool10000007ooooo00000`00003oooooooooo`02oooo
o`h0C02c00?o000003<0c00c0<`0;@0c0<`00ol000006@3V01T0iP1@01T0iP03o`0000000?l0003o
0800003o1Oooool10000007ooooo00000`00003oooooooooo`02ooooo`d0C02c00?o000003<0c00c
0<`0;@0c0<`00ol000006@3V01T0iP1@01T0iP03o`0000000?l0003o0840003o1Oooool10000007o
oooo00000`00003oooooooooo`02ooooo`/0C02c0_l0000_03<0c003o`00000I0>H06@3V05006@3V
00?o00000000o`000?l0PP000?l5ooooo`4000000Oooool0000300000?oooooooooo00;ooooo2P1<
0;<00ol00000<`3<03<0c00^03<0c003o`00000I0>H06@3V05006@3V00?o00000000o`000?l0P`00
0?l5ooooo`4000000Oooool0000300000?oooooooooo00;ooooo2@1<0;<00ol00000<`3<03<0c00^
03<0c003o`00000I0>H06@3V05006@3V00?o00000000o`000?l0Q0000?l5ooooo`4000000Oooool0
000300000?oooooooooo00;ooooo201<0;<00ol00000<`3<03<0c00^03<0c003o`00000I0>H06@3V
05006@3V00?o00000000o`000?l0Q@000?l5ooooo`4000000Oooool0000300000?oooooooooo00;o
oooo1`1<0;<00ol00000<`3<03<0c00^03<0c003o`00000I0>H06@3V05006@3V00?o00000000o`00
0?l0QP000?l5ooooo`4000000Oooool0000300000?oooooooooo00;ooooo1P1<0;<00ol00000<`3<
03<0c00^03<0c003o`00000I0>H06@3V05006@3V00?o00000000o`000?l0Q`000?l5ooooo`400000
0Oooool0000300000?oooooooooo00;ooooo1@1<0;<00ol00000<`3<03<0c00^03<0c003o`00000I
0>H06@3V05406@3V00?o00000000o`000?l0Q`000?l5ooooo`4000000Oooool0000300000?oooooo
oooo00;ooooo101<0;<00ol00000<`3<03<0c00^03<0c003o`00000I0>H06@3V05406@3V00?o0000
0000o`000?l0R0000?l5ooooo`4000000Oooool0000300000?oooooooooo00;ooooo0`1<0;<00ol0
0000<`3<03<0c00^03<0c003o`00000I0>H06@3V05406@3V00?o00000000o`000?l0R@000?l5oooo
o`4000000Oooool0000300000?oooooooooo00;ooooo0P1<0;<00ol00000<`3<03<0c00^03<0c003
o`00000I0>H06@3V05406@3V00?o00000000o`000?l0RP000?l5ooooo`4000000Oooool000030000
0?oooooooooo00;ooooo00<0C02co`00000c0<`0;`0c0<`00ol000006@3V01T0iP1A01T0iP03o`00
00000?l0003o08/0003o1Oooool10000007ooooo00000`00003oooooooooo`02ooooo`03o`00000c
0<`0<`3<02h0<`3<00?o000001T0iP0I0>H0D@0I0>H00ol00000003o0000o`2<0000o`Gooooo0@00
0001ooooo`0000<00000ooooooooool00_ooool`03<0c003o`00000I0>H06@3V05406@3V00?o0000
0000o`000?l0S@000?l5ooooo`4000000Oooool0000300000?oooooooooo0?oooooo7?ooool10000
007ooooo00000`00003oooooooooo`3ooooooacooooo0@000001ooooo`0000<00000ooooooooool0
oooooolLooooo`4000000Oooool0000300000?oooooooooo0?oooooo7?ooool10000007ooooo003o
0000020000000Oooool00001\
\>"],
  ImageRangeCache->{{{0, 287}, {287, 0}} -> {-1.04092, -1.04092, 0.00725378, \
0.00725378}}]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["A closer look: part #1(b)", "Section"],

Cell[CellGroupData[{

Cell["Setup", "Subsection"],

Cell[CellGroupData[{

Cell["Which model to examine", "Subsubsection"],

Cell[BoxData[
    \(\(tstModel\  = \ em2\  // \ Last;\)\)], "Input",
  CellFrame->True,
  Background->GrayLevel[0.849989]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Sample data point", "Subsubsection",
  CellFrame->False],

Cell[BoxData[
    \(\(xtst\  = \ xd[\([1]\)];\)\)], "Input",
  CellFrame->True,
  Background->GrayLevel[0.849989]]
}, Closed]],

Cell[CellGroupData[{

Cell["Generate graphic for selected mode", "Subsubsection"],

Cell[BoxData[{
    \(\(gmodel\  = \ 
        PlotMeansTwo[tstModel, \ pr, \ colors, \ 
          nS];\)\), "\[IndentingNewLine]", 
    \(\(gbase = Show[gdata, gmodel, \ nS];\)\)}], "Input"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData[{
  "Plot ",
  Cell[BoxData[
      \(TraditionalForm\`P(\[Omega]\_i | \[Theta], x\_j)\)]],
  " for sample point"
}], "Subsection"],

Cell[CellGroupData[{

Cell["Sample data point highlighted", "Subsubsection"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(\(\ \)\(PlotExampleOne[xtst, em2\  // \ Last, colors, gbase, 1, 
        yS];\)\)\)], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.49505 0.5 0.49505 [
[ 0 0 -0.125 0 ]
[ 0 0 -0.125 0 ]
[ 0 1 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
0 0 m
1 0 L
s
0 0 m
0 1 L
s
0 1 m
1 1 L
s
1 0 m
1 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
1 .5 0 r
.015 w
.03175 .1355 Mdot
.03435 .12523 Mdot
.11137 .12765 Mdot
.14107 .18841 Mdot
.16218 .24538 Mdot
.17294 .21053 Mdot
.18267 .18577 Mdot
.18434 .1304 Mdot
.18553 .30956 Mdot
.20401 .239 Mdot
.21247 .27571 Mdot
.21687 .20845 Mdot
.22376 .2799 Mdot
.22832 .27485 Mdot
.29063 .20974 Mdot
.29686 .25079 Mdot
.30487 .22936 Mdot
.30683 .34623 Mdot
.32055 .20902 Mdot
.32574 .21979 Mdot
.34472 .28521 Mdot
.35998 .36393 Mdot
.36335 .24976 Mdot
.3794 .36608 Mdot
.42386 .66992 Mdot
.44391 .74519 Mdot
.45059 .34198 Mdot
.47208 .67586 Mdot
.47436 .71381 Mdot
.49778 .59825 Mdot
.50874 .91643 Mdot
.51516 .76219 Mdot
.53655 .61374 Mdot
.56563 .75219 Mdot
.59189 .65665 Mdot
.59581 .61604 Mdot
.59923 .6556 Mdot
.60292 .68499 Mdot
.62656 .67779 Mdot
.63555 .72451 Mdot
.63919 .652 Mdot
.64169 .6004 Mdot
.64246 .58611 Mdot
.64496 .54267 Mdot
.64608 .77288 Mdot
.65077 .64308 Mdot
.66065 .57816 Mdot
.67474 .59169 Mdot
.69296 .563 Mdot
.72815 .65902 Mdot
.73169 .58879 Mdot
.74669 .61318 Mdot
.74821 .65474 Mdot
.75963 .63781 Mdot
.79673 .57809 Mdot
.80925 .55852 Mdot
.81525 .58444 Mdot
.83417 .62985 Mdot
.83598 .55526 Mdot
.91595 .49319 Mdot
1 0 0 r
.005 w
.16128 .17044 m
.18734 .17269 L
.21339 .17909 L
.2345 .18734 L
.23945 .19126 L
.2655 .20415 L
.27874 .21339 L
.29156 .22295 L
.31204 .23945 L
.31761 .24532 L
.33549 .2655 L
.34367 .28341 L
.34499 .29156 L
.34367 .29798 L
.31761 .3104 L
.29156 .30711 L
.2655 .30014 L
.24507 .29156 L
.23945 .28747 L
.21339 .27402 L
.20155 .2655 L
.18734 .25472 L
.16884 .23945 L
.16128 .2313 L
.14618 .21339 L
.13806 .18734 L
.16128 .17044 L
s
0 0 1 r
.65633 .57701 m
.68239 .56842 L
.70844 .56313 L
.7345 .56168 L
.76055 .5752 L
.76359 .57817 L
.76859 .60422 L
.76055 .62333 L
.75627 .63028 L
.7345 .65485 L
.73298 .65633 L
.70844 .6775 L
.69922 .68239 L
.68239 .69294 L
.65633 .70579 L
.64983 .70844 L
.63028 .71539 L
.60422 .72268 L
.57817 .72651 L
.55211 .7214 L
.53145 .70844 L
.52926 .68239 L
.54239 .65633 L
.55211 .63983 L
.56625 .63028 L
.57817 .6193 L
.60119 .60422 L
.60422 .60227 L
.63028 .58726 L
.65315 .57817 L
.65633 .57701 L
s
1 0 0 r
.03 w
.24141 .24033 Mdot
0 0 1 r
.64872 .64417 Mdot
1 0 0 r
.79703 .00495 m
.79703 .25248 L
.87129 .25248 L
.87129 .00495 L
F
0 0 1 r
.89604 .00495 m
.89604 .00495 L
.9703 .00495 L
.9703 .00495 L
F
1 0 1 r
.04 w
.03175 .1355 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P000182000`400?l00000o`00003ooooooolQ
ooooo`00o`00000P0000007ooooo00000`00003oooooooooo`3ooooooacooooo0@000001ooooo`00
00<00000ooooooooool0hOoooolE0?l002Gooooo0@000001ooooo`0000<00000ooooooooool0hOoo
oolE0?l002Gooooo0@000001ooooo`0000<00000ooooooooool0hOoooolE0?l002Gooooo0@000001
ooooo`0000<00000ooooooooool0hOoooolE0?l002Gooooo0@000001ooooo`0000<00000oooooooo
ool0hOoooolE0?l002Gooooo0@000001ooooo`0000<00000ooooooooool0hOoooolE0?l002Gooooo
0@000001ooooo`0000<00000ooooooooool0hOoooolE0?l002Gooooo0@000001ooooo`0000<00000
ooooooooool0hOoooolE0?l002Gooooo0@000001ooooo`0000<00000ooooooooool0hOoooolE0?l0
02Gooooo0@000001ooooo`0000<00000ooooooooool0hOoooolE0?l002Gooooo0@000001ooooo`00
00<00000ooooooooool0hOoooolE0?l002Gooooo0@000001ooooo`0000<00000ooooooooool0hOoo
oolE0?l002Gooooo0@000001ooooo`0000<00000ooooooooool0hOoooolE0?l002Gooooo0@000001
ooooo`0000<00000ooooooooool0hOoooolE0?l002Gooooo0@000001ooooo`0000<00000oooooooo
ool0hOoooolE0?l002Gooooo0@000001ooooo`0000<00000ooooooooool0hOoooolE0?l002Gooooo
0@000001ooooo`0000<00000ooooooooool0hOoooolE0?l002Gooooo0@000001ooooo`0000<00000
ooooooooool0hOoooolE0?l002Gooooo0@000001ooooo`0000<00000ooooooooool0hOoooolE0?l0
02Gooooo0@000001ooooo`0000<00000ooooooooool0hOoooolE0?l002Gooooo0@000001ooooo`00
00<00000ooooooooool0hOoooolE0?l002Gooooo0@000001ooooo`0000<00000ooooooooool0hOoo
oolE0?l002Gooooo0@000001ooooo`0000<00000ooooooooool0hOoooolE0?l002Gooooo0@000001
ooooo`0000<00000ooooooooool0hOoooolE0?l002Gooooo0@000001ooooo`0000<00000oooooooo
ool0hOoooolE0?l002Gooooo0@000001ooooo`0000<00000ooooooooool0hOoooolE0?l002Gooooo
0@000001ooooo`0000<00000ooooooooool0hOoooolE0?l002Gooooo0@000001ooooo`0000<00000
ooooooooool0hOoooolE0?l002Gooooo0@000001ooooo`0000<00000ooooooooool0hOoooolE0?l0
02Gooooo0@000001ooooo`0000<00000ooooooooool0hOoooolE0?l002Gooooo0@000001ooooo`00
00<00000ooooooooool0hOoooolE0?l002Gooooo0@000001ooooo`0000<00000ooooooooool0hOoo
oolE0?l002Gooooo0@000001ooooo`0000<00000ooooooooool01?ooool5ool0omSooooo5@3o000U
ooooo`4000000Oooool0000300000?oooooooooo00?ooooo1ooo0?lBooooo`;oogl0`ooooolE0?l0
02Gooooo0@000001ooooo`0000<00000ooooooooool00_ooool9ool0oa3ooooo1?ooO`0Booooo`;o
ogl0[_oooolE0?l002Gooooo0@000001ooooo`0000@00000oooooooooooooooo2ooo0?l?ooooo`Co
ogl04Oooool4oomo0:gooooo5@3o000Uooooo`4000000Oooool0000400000?ooooooooooooooo`_o
o`3o4?ooool2oomo01;ooooo1?ooO`2]oooooaD0o`009Oooool10000007ooooo00001000003ooooo
ooooooooool;ool0obGooooo0_ooO`2^oooooaD0o`009Oooool10000007ooooo00001000003ooooo
ooooooooool;ool0omGooooo5@3o000Uooooo`4000000Oooool0000400000?ooooooooooooooo`_o
o`3oeOoooolE0?l002Gooooo0@000001ooooo`0000<00000ooooooooool00_ooool9ool0omKooooo
5@3o000Uooooo`4000000Oooool0000300000?oooooooooo00?ooooo1ooo0?oGoooooaD0o`009Ooo
ool10000007ooooo00000`00003oooooooooo`04ooooo`Goo`3of?oooolE0?l002Gooooo0@000001
ooooo`0000<00000ooooooooool0hOoooolE0?l002Gooooo0@000001ooooo`0000<00000oooooooo
ool0hOoooolE0?l002Gooooo0@000001ooooo`0000<00000ooooooooool0hOoooolE0?l002Gooooo
0@000001ooooo`0000<00000ooooooooool0:_ooool60?l00;7ooooo5@3o000Uooooo`4000000Ooo
ool0000300000?oooooooooo02Wooooo00<0o`00ooooooooool01?ooool50?l00:cooooo5@3o000U
ooooo`4000000Oooool0000300000?oooooooooo02Oooooo0P3o000<ooooo`@0o`00Z?oooolE0?l0
02Gooooo0@000001ooooo`0000<00000ooooooooool09_ooool00`3o003oooooooooo`0@ooooo`@0
o`00Y?oooolE0?l002Gooooo0@000001ooooo`0000<00000ooooooooool09?ooool00oooO`00o`00
ooooo`09ooooo`;oogl02oooool30?l00:7ooooo5@3o000Uooooo`4000000Oooool0000300000?oo
oooooooo02?ooooo00Coogl00?l00?ooO`3oogl02?ooool4oomo00gooooo00?oo`00ooooooooool0
W_oooolE0?l002Gooooo0@000001ooooo`0000<00000ooooooooool08oooool01?ooO`00o`00oomo
0?ooO`08ooooo`Coogl03_ooool20?l009kooooo5@3o000Uooooo`4000000Oooool0000300000?oo
oooooooo02Cooooo00?oogl00?l00?ooool02Oooool2oomo017ooooo0P3o002LoooooaD0o`009Ooo
ool10000007ooooo00000`00003oooooooooo`0Uooooo`030?l00?oooooooooo01gooooo0P3o002J
oooooaD0o`009Oooool10000007ooooo00000`00003oooooooooo`0Uooooo`030?l00?oooooooooo
01oooooo0P3o002HoooooaD0o`009Oooool10000007ooooo00000`00003oooooooooo`0Vooooo`03
0?l00?oooooooooo017ooooo0_ooO`0=ooooo`80o`001?ooool2oomo00Oooooo0_ooO`27oooooaD0
o`009Oooool10000007ooooo00000`00003oooooooooo`0Vooooo`030?l00?oooooooooo00Gooooo
0_ooO`09ooooo`Coogl03_ooool00`3o003oooooooooo`04oomo00Gooooo1?ooO`26oooooaD0o`00
9Oooool10000007ooooo00000`00003oooooooooo`0Vooooo`030?l00?oooooooooo00Cooooo1?oo
O`08ooooo`Coogl03oooool00`3o003ooooooomo0003oomo00Gooooo1?ooO`26oooooaD0o`009Ooo
ool10000007ooooo00000`00003oooooooooo`0Wooooo`030?l00?oooooooooo00?ooooo1?ooO`09
ooooo`;oogl04Oooool0103o003ooooooomo0?ooO`07ooooo`?oogl0Q_oooolE0?l002Gooooo0@00
0001ooooo`0000<00000ooooooooool09oooool00`3o003oooooooooo`04ooooo`;oogl07_ooool0
0`3o003oooooooooo`07ooooo`Coogl0QOoooolE0?l002Gooooo0@000001ooooo`0000<00000oooo
ooooool0:?ooool00`3o003oooooooooo`0Tooooo`030?l00?oooooooooo00Kooooo1?ooO`25oooo
oaD0o`009Oooool10000007ooooo00000`00003oooooooooo`0Yooooo`030?l00?oooooooooo02Co
oooo0P3o00000oooooooogl0oomo0004ooooo`;oogl0Q_oooolE0?l002Gooooo0@000001ooooo`00
00<00000ooooooooool0:_ooool00`3o003oooooooooo`0Cooooo`Coo`003_ooool0103o003oogl0
oomo0?ooO`2;oooooaD0o`009Oooool10000007ooooo00000`00003oooooooooo`0[ooooo`030?l0
0?oooooooooo017ooooo1_oo000=ooooo`04oomo003o0000o`00oomo08_ooooo5@3o000Uooooo`40
00000Oooool0000300000?oooooooooo02cooooo00<0o`00ooooooooool02?ooool2oomo00Gooooo
2?oo000=ooooo`;oogl000<0o`00ooooooooool0ROoooolE0?l002Gooooo0@000001ooooo`0000<0
0000ooooooooool0;Oooool00`3o003oooooooooo`06ooooo`Coogl01?ooool8ool0013ooooo00<0
o`00ooooooooool0R?oooolE0?l002Gooooo0@000001ooooo`0000<00000ooooooooool0:oooool2
oomo0003ooooo`3o003ooooo00Kooooo1?ooO`04ooooo`Soo`004Oooool00`3o003oooooooooo`27
oooooaD0o`009Oooool10000007ooooo00000`00003oooooooooo`0Zooooo`Coogl000?ooooo0?l0
0?ooool01_ooool2oomo00Gooooo2?oo000;ooooo`;oogl01Oooool00`3o003oooooooooo`09oooo
o`;oogl0NooooolE0?l002Gooooo0@000001ooooo`0000<00000ooooooooool0:_ooool4oomo00;o
oooo00<0o`00ooooooooool03?ooool6ool000_ooooo1?ooO`04ooooo`030?l00?oooooooooo00So
oooo1?ooO`1joooooaD0o`009Oooool10000007ooooo00000`00003oooooooooo`0[ooooo`;oogl0
1?ooool00`3o003oooooooooo`0<ooooo`Coo`003?ooool4oomo00Gooooo00<0o`00ooooooooool0
1oooool4oomo07[ooooo5@3o000Uooooo`4000000Oooool0000300000?oooooooooo03;ooooo0P3o
000Mooooo`;oogl01oooool00`3o003oooooooooo`07ooooo`;oogl0]Oooool10000007ooooo0000
0`00003oooooooooo`0dooooo`030?l00?oooooooooo02Cooooo00<0o`00ooooooooool0_Oooool1
0000007ooooo00000`00003oooooooooo`0eooooo`030?l00?oooooooooo02Cooooo00<0o`00oooo
ooooool0_?ooool10000007ooooo00000`00003oooooooooo`0fooooo`80o`009Oooool00`3o003o
ooooooooo`2kooooo`4000000Oooool0000300000?oooooooooo03Sooooo0P3o00000oooO`3ooooo
ooooo`02oomo01kooooo00<0o`00ooooooooool0^oooool10000007ooooo00000`00003ooooooooo
o`0hooooo`;oogl00P3o0004oomo01kooooo00<0o`00ooooooooool0^_ooool10000007ooooo0000
0`00003oooooooooo`0hooooo`Coogl00P3o0002oomo01kooooo00<0o`00ooooooooool0^_ooool1
0000007ooooo00000`00003oooooooooo`0iooooo`Googl000<0o`00ooooooooool07Oooool00`3o
003oogl0oomo002jooooo`4000000Oooool0000300000?oooooooooo03_ooooo1?ooO`020?l001go
oooo00Coogl00?l00?ooO`3oogl0^Oooool10000007ooooo00000`00003oooooooooo`0looooo`;o
ogl00oooool20?l001_ooooo00Coogl00?l00?ooO`3oogl0^Oooool10000007ooooo00000`00003o
ooooooooo`13ooooo`80o`006_ooool00oooO`00o`00ooooo`2iooooo`4000000Oooool000030000
0?oooooooooo04Gooooo0P3o000Iooooo`030?l00?oooooooooo0;Sooooo0@000001ooooo`0000<0
0000ooooooooool0Aoooool20?l001Gooooo0P3o002kooooo`4000000Oooool0000300000?oooooo
oooo04Wooooo0`3o000@ooooo`80o`00_Oooool10000007ooooo00000`00003oooooooooo`0aoooo
o`;oogl06Oooool30?l000cooooo00<0o`00ooooooooool0_Oooool10000007ooooo00000`00003o
ooooooooo`0`ooooo`Coogl06oooool60?l000Cooooo0P3o0030ooooo`4000000Oooool000030000
0?oooooooooo033ooooo1?ooO`0Qooooo`@0o`00`_ooool10000007ooooo00000`00003ooooooooo
o`0aooooo`;oogl0j?ooool10000007ooooo00000`00003oooooooooo`3ooooooacooooo0@000001
ooooo`0000<00000ooooooooool0oooooolLooooo`4000000Oooool0000300000?oooooooooo0?oo
oooo7?ooool10000007ooooo00000`00003oooooooooo`3ooooooacooooo0@000001ooooo`0000<0
0000ooooooooool0oooooolLooooo`4000000Oooool0000300000?oooooooooo07gooooo0_ooO`2L
ooooo`4000000Oooool0000300000?oooooooooo07cooooo1?ooO`2Kooooo`4000000Oooool00003
00000?oooooooooo05Cooooo0_ooO`0Vooooo`Coogl0Voooool10000007ooooo00000`00003ooooo
ooooo`1Cooooo`Coogl09_ooool2oomo09cooooo0@000001ooooo`0000<00000ooooooooool0Dooo
ool4oomo0<Cooooo0@000001ooooo`0000<00000ooooooooool0E?ooool2oomo0<Gooooo0@000001
ooooo`0000<00000ooooooooool0oooooolLooooo`4000000Oooool0000300000?oooooooooo06?o
oooo0_ooO`04ooooo`;oogl0/?ooool10000007ooooo00000`00003oooooooooo`1Rooooo`Coogl0
0_ooool4oomo0:oooooo0@000001ooooo`0000<00000ooooooooool0H_ooool4oomo00;ooooo1?oo
O`2_ooooo`4000000Oooool0000300000?oooooooooo06?ooooo0_ooO`04ooooo`;oogl0/?ooool1
0000007ooooo00000`00003oooooooooo`3ooooooacooooo0@000001ooooo`0000<00000oooooooo
ool0oooooolLooooo`4000000Oooool0000300000?oooooooooo0?oooooo7?ooool10000007ooooo
00000`00003oooooooooo`3ooooooacooooo0@000001ooooo`0000<00000ooooooooool0oooooolL
ooooo`4000000Oooool0000300000?oooooooooo0?oooooo7?ooool10000007ooooo00000`00003o
ooooooooo`3ooooooacooooo0@000001ooooo`0000<00000ooooooooool0oooooolLooooo`400000
0Oooool0000300000?oooooooooo0?oooooo7?ooool10000007ooooo00000`00003oooooooooo`3o
oooooacooooo0@000001ooooo`0000<00000ooooooooool0oooooolLooooo`4000000Oooool00003
00000?oooooooooo0?oooooo7?ooool10000007ooooo00000`00003oooooooooo`3ooooooacooooo
0@000001ooooo`0000<00000ooooooooool0oooooolLooooo`4000000Oooool0000300000?oooooo
oooo0?oooooo7?ooool10000007ooooo00000`00003oooooooooo`3ooooooacooooo0@000001oooo
o`0000<00000ooooooooool0oooooolLooooo`4000000Oooool0000300000?oooooooooo0?oooooo
7?ooool10000007ooooo00000`00003oooooooooo`3ooooooacooooo0@000001ooooo`0000<00000
ooooooooool0oooooolLooooo`4000000Oooool0000300000?oooooooooo0?oooooo7?ooool10000
007ooooo00000`00003oooooooooo`3ooooooacooooo0@000001ooooo`0000<00000ooooooooool0
oooooolLooooo`4000000Oooool0000300000?oooooooooo0?oooooo7?ooool10000007ooooo0000
0`00003oooooooooo`3ooooooacooooo0@000001ooooo`0000<00000ooooooooool0oooooolLoooo
o`4000000Oooool0000300000?oooooooooo0?oooooo7?ooool10000007ooooo00000`00003ooooo
ooooo`3ooooooacooooo0@000001ooooo`0000<00000ooooooooool0oooooolLooooo`4000000Ooo
ool0000300000?oooooooooo0?oooooo7?ooool10000007ooooo00000`00003oooooooooo`3ooooo
oacooooo0@000001ooooo`0000<00000ooooooooool0oooooolLooooo`4000000Oooool000030000
0?oooooooooo0?oooooo7?ooool10000007ooooo00000`00003oooooooooo`3oooooo`Cooooo0_oo
O`0Fooooo`4000000Oooool0000300000?oooooooooo0?oooooo0oooool4oomo01Gooooo0@000001
ooooo`0000<00000ooooooooool0ooooool3ooooo`Coogl05Oooool10000007ooooo00000`00003o
ooooooooo`3oooooo`Cooooo0_ooO`0Fooooo`4000000Oooool0000300000?oooooooooo0?oooooo
7?ooool10000007ooooo00000`00003oooooooooo`3ooooooacooooo0@000001ooooo`0000<00000
ooooooooool0oooooolLooooo`4000000Oooool0000300000?oooooooooo0?oooooo7?ooool10000
007ooooo00000`00003oooooooooo`3ooooooacooooo0@000001ooooo`0000<00000ooooooooool0
oooooolLooooo`4000000Oooool0000300000?oooooooooo0?oooooo7?ooool10000007ooooo0000
0`00003oooooooooo`3ooooooacooooo0@000001ooooo`0000<00000ooooooooool0oooooolLoooo
o`4000000Oooool0000300000?oooooooooo0?oooooo7?ooool10000007ooooo00000`00003ooooo
ooooo`2eooooo`;oogl0I?ooool10000007ooooo00000`00003oooooooooo`2dooooo`Coogl0Hooo
ool10000007ooooo00000`00003oooooooooo`2dooooo`Coogl0Hoooool10000007ooooo00000`00
003oooooooooo`2eooooo`;oogl0=Oooool2oomo02gooooo0@000001ooooo`0000<00000oooooooo
ool0i?ooool2oomo00Gooooo1?ooO`0/ooooo`4000000Oooool0000300000?oooooooooo0>?ooooo
1?ooO`04ooooo`Coogl0;?ooool10000007ooooo00000`00003oooooooooo`33ooooo`;oogl07_oo
ool4oomo00Gooooo0_ooO`0]ooooo`4000000Oooool0000300000?oooooooooo0<;ooooo1?ooO`0;
0000oa?ooooo0_ooO`0eooooo`4000000Oooool0000300000?oooooooooo0<;ooooo10000?l;oooo
o`80003oB?ooool10000007ooooo00000`00003oooooooooo`2nooooo`@0003o00?ooooooomo0?oo
O`003_ooool20000odKooooo0@000001ooooo`0000<00000ooooooooool0^Oooool2oomo00<0003o
5oooool20000o`Wooooo0_ooO`0iooooo`4000000Oooool0000300000?oooooooooo0;Oooooo00D0
003oo`00ool00?l0003ooomo000Kooooo`03o`00o`000?oooooo00Gooooo1?ooO`0hooooo`400000
0Oooool0000300000?oooooooooo0;Cooooo0`000?l00oooooooogl0oomo0002oomo01cooooo00<0
003oooooooooool01?ooool4oomo00?ooooo0_ooO`0cooooo`4000000Oooool0000300000?oooooo
oooo0;;ooooo0P000?l3oomo00;ooooo0_ooO`0Cooooo`;oogl02?ooool00`000?ooooooooooo`05
ooooo`;oogl00oooool4oomo03;ooooo0@000001ooooo`0000<00000ooooooooool0/?ooool20000
o`03ooooooooO`3oogl000;oogl01_ooool2oomo00kooooo1?ooO`07ooooo`030000oooooooooooo
00[ooooo1?ooO`0booooo`4000000Oooool0000300000?oooooooooo0:kooooo0P000?l4ooooo`;o
ogl01_ooool4oomo00gooooo1?ooO`07ooooo`030000oooooooooooo00_ooooo0_ooO`0cooooo`40
00000Oooool0000300000?oooooooooo08_ooooo0_ooO`0Pooooo`030000oooooooooooo00Cooooo
0_ooO`06ooooo`Coogl03_ooool2oomo00Wooooo00<0003oooooooooool0?oooool10000007ooooo
00000`00003oooooooooo`2:ooooo`Coogl07Oooool20000o`Kooooo1?ooO`06ooooo`;oogl06_oo
ool00`000?ooooooooooo`0oooooo`4000000Oooool0000300000?oooooooooo08[ooooo1?ooO`0L
ooooo`030000oooooooooooo00Kooooo1?ooO`0Rooooo`030000oooooooooooo03oooooo0@000001
ooooo`0000<00000ooooooooool0Roooool2oomo01_ooooo00<0003oo`00ooooool02Oooool2oomo
02?ooooo00<0003oooooooooool0?oooool10000007ooooo00000`00003oooooooooo`2Fooooo`;o
ogl03_ooool20000ob[ooooo0_ooO`05ooooo`030000oooooooooooo03oooooo0@000001ooooo`00
00<00000ooooooooool0UOooool4oomo00cooooo00@0003oooooooooO`3oogl0:?ooool4oomo00?o
oooo00<0003oooooooooool0@?ooool10000007ooooo00000`00003oooooooooo`2Eooooo`Coogl0
2_ooool20000o`03ooooooooO`3oogl000;oogl09oooool4oomo00?ooooo00<0003oooooooooool0
@?ooool10000007ooooo00000`00003oooooooooo`2Fooooo`;oogl02_ooool010000?oooooooooo
ooooool4oomo02Sooooo0_ooO`04ooooo`030000oooooooooooo043ooooo0@000001ooooo`0000<0
0000ooooooooool0XOooool00`000?ooooooooooo`03ooooo`;oogl0;_ooool00`000?oooooooooo
o`11ooooo`4000000Oooool0000300000?oooooooooo0:3ooooo00<0003oooooooooool0<oooool0
0`000?ooooooooooo`0Booooo`;oogl0;_ooool10000007ooooo00000`00003oooooooooo`2Noooo
o`80003o=Oooool00`000?ooooooooooo`0Booooo`Coogl0;Oooool10000007ooooo00000`00003o
ooooooooo`2Mooooo`030000oooooooooooo01Gooooo1?l00?lLooooo`030000ooooO`3oogl001;o
oooo1?ooO`0]ooooo`4000000Oooool0000300000?oooooooooo09cooooo00<0003oooooooooool0
5Oooool6o`00oa[ooooo00<0003ooomo0?ooO`000_ooO`0Booooo`;oogl0;_ooool10000007ooooo
00000`00003oooooooooo`2Kooooo`030000oooooooooooo01Gooooo2?l00?lHooooo`030000oooo
ooooogl000?oogl0@_ooool10000007ooooo00000`00003oooooooooo`2Kooooo`030000oooooooo
oooo01Gooooo2?l00?lGooooo`040000ooooooooooooooooo`;oogl0@oooool10000007ooooo0000
0`00003oooooooooo`2Jooooo`030000oooooooooooo01Kooooo2?l00?lFooooo`030000oooooooo
oooo04Oooooo0@000001ooooo`0000<00000ooooooooool0VOooool00`000?ooooooooooo`0<oooo
o`;oogl02?ooool00oooO`3o003oo`00o`06o`00oaGooooo00<0003oooooooooool00_ooO`16oooo
o`4000000Oooool0000300000?oooooooooo09Wooooo00<0003oooooooooool02_ooool5oomo00Oo
oooo0_ooO`06o`00oa?ooooo0_ooO`000ol00?ooooooooooo`04oomo04Gooooo0@000001ooooo`00
00<00000ooooooooool0V?ooool00`000?ooooooooooo`0:ooooo`Koogl02?ooool2oomo00Co003o
4oooool2oomo0080003o0_ooool4oomo04Gooooo0@000001ooooo`0000<00000ooooooooool0V?oo
ool00`000?ooooooooooo`0:ooooo`Googl08_ooool01?ooO`00003ooomo0?ooO`03ooooo`;oogl0
A_ooool10000007ooooo00000`00003oooooooooo`1fooooo`;oogl07oooool00`000?oooooooooo
o`0<ooooo`;oogl09?ooool00`000?ooogl0oomo001<ooooo`4000000Oooool0000300000?oooooo
oooo07Gooooo1?ooO`0Nooooo`030000oooooooooooo037ooooo00<0003oooooooooool0COooool1
0000007ooooo00000`00003oooooooooo`1eooooo`Coogl02_ooool2oomo017ooooo00<0003ooooo
ooooool0<Oooool00`000?ooooooooooo`1>ooooo`4000000Oooool0000300000?oooooooooo07Ko
oooo0_ooO`0:ooooo`Coogl03oooool00`000?ooooooooooo`0Hooooo`;oogl05oooool00`000?oo
ooooooooo`1?ooooo`4000000Oooool0000300000?oooooooooo08;ooooo1?ooO`0?ooooo`030000
oooooooooooo01Oooooo1?ooO`0Dooooo`80003oD_ooool10000007ooooo00000`00003ooooooooo
o`23ooooo`;oogl03oooool00`000?ooooooooooo`0Booooo`;oogl01?ooool4oomo017ooooo0`00
0?mDooooo`4000000Oooool0000300000?oooooooooo09Cooooo00<0003oooooooooool04Oooool4
oomo00Cooooo0_ooO`0@ooooo`80003oEoooool10000007ooooo00000`00003oooooooooo`2Doooo
o`030000oooooooooooo017ooooo1?ooO`0Eooooo`030000oooooooooooo05Oooooo0@000001oooo
o`0000<00000ooooooooool0U?ooool00`000?ooooooooooo`0Booooo`;oogl05?ooool20000oe[o
oooo0@000001ooooo`0000<00000ooooooooool0U?ooool00`000?ooooooooooo`0Vooooo`80003o
G?ooool10000007ooooo00000`00003oooooooooo`2Eooooo`030000oooooooooooo02Cooooo00<0
003oooooooooool0G?ooool10000007ooooo00000`00003oooooooooo`2Eooooo`030000oooooooo
oooo02;ooooo0P000?mOooooo`4000000Oooool0000300000?oooooooooo09Gooooo00<0003ooooo
ooooool08?ooool20000of7ooooo0@000001ooooo`0000<00000ooooooooool0Q?ooool2oomo00oo
oooo0P000?lOooooo`80003oHoooool10000007ooooo00000`00003oooooooooo`23ooooo`Coogl0
4?ooool20000oa[ooooo0`000?mUooooo`4000000Oooool0000300000?oooooooooo08?ooooo1?oo
O`0Booooo`80003o5?ooool40000ofSooooo0@000001ooooo`0000<00000ooooooooool0Q?ooool2
oomo01Gooooo0`000?l>ooooo`<0003o0oooool2oomo06Oooooo0@000001ooooo`0000<00000oooo
ooooool0W_ooool30000o`Gooooo1P000?l5ooooo`Coogl0I_ooool10000007ooooo00000`00003o
ooooooooo`2Qooooo`D0003o2oooool4oomo06Kooooo0@000001ooooo`0000<00000ooooooooool0
/_ooool2oomo06Oooooo0@000001ooooo`0000<00000ooooooooool0oooooolLooooo`4000000Ooo
ool0000300000?oooooooooo0?oooooo7?ooool10000007ooooo00000`00003oooooooooo`1koooo
o`;oogl0W_ooool10000007ooooo00000`00003oooooooooo`1jooooo`Coogl0WOooool10000007o
oooo00000`00003oooooooooo`1jooooo`Coogl08?ooool2oomo07_ooooo0@000001ooooo`0000<0
0000ooooooooool0Noooool2oomo023ooooo1?ooO`1jooooo`4000000Oooool0000300000?oooooo
oooo09gooooo1?ooO`1jooooo`4000000Oooool0000300000?oooooooooo093ooooo0_ooO`0<oooo
o`;oogl0Noooool10000007ooooo00000`00003oooooooooo`2?ooooo`Coogl0R?ooool10000007o
oooo00000`00003oooooooooo`2?ooooo`Coogl0R?ooool10000007ooooo00000`00003ooooooooo
o`2@ooooo`;oogl08oooool2oomo06Cooooo0@000001ooooo`0000<00000ooooooooool0]?ooool4
oomo06?ooooo0@000001ooooo`0000<00000ooooooooool0]?ooool4oomo06?ooooo0@000001oooo
o`0000<00000ooooooooool0]Oooool2oomo06Cooooo0@000001ooooo`0000<00000ooooooooool0
oooooolLooooo`4000000Oooool0000300000?oooooooooo0?oooooo7?ooool10000007ooooo0000
0`00003oooooooooo`3ooooooacooooo0@000001ooooo`0000<00000ooooooooool0oooooolLoooo
o`4000000Oooool0000300000?oooooooooo0?oooooo7?ooool10000007ooooo00000`00003ooooo
ooooo`3ooooooacooooo0@000001ooooo`0000<00000ooooooooool0oooooolLooooo`4000000Ooo
ool0000300000?oooooooooo0?oooooo7?ooool10000007ooooo00000`00003oooooooooo`3ooooo
oacooooo0@000001ooooo`0000<00000ooooooooool0oooooolLooooo`4000000Oooool000030000
0?oooooooooo0?oooooo7?ooool10000007ooooo00000`00003oooooooooo`3ooooooacooooo0@00
0001ooooo`0000<00000ooooooooool0oooooolLooooo`4000000Oooool0000300000?oooooooooo
0?oooooo7?ooool10000007ooooo00000`00003oooooooooo`3ooooooacooooo0@000001ooooo`00
00<00000ooooooooool0oooooolLooooo`4000000Oooool0000300000?oooooooooo0?oooooo7?oo
ool10000007ooooo00000`00003oooooooooo`3ooooooacooooo0@000001ooooo`0000<00000oooo
ooooool0oooooolLooooo`4000000Oooool0000300000?oooooooooo0?oooooo7?ooool10000007o
oooo00000`00003oooooooooo`3ooooooacooooo0@000001ooooo`0000<00000ooooooooool0oooo
oolLooooo`4000000Oooool0000300000?oooooooooo0?oooooo7?ooool10000007ooooo00000`00
003oooooooooo`3ooooooacooooo0@000001ooooo`0000<00000ooooooooool0oooooolLooooo`40
00000Oooool0000300000?oooooooooo0?oooooo7?ooool10000007ooooo00000`00003ooooooooo
o`3ooooooacooooo0@000001ooooo`0000<00000ooooooooool0oooooolLooooo`4000000Oooool0
000300000?oooooooooo0?oooooo7?ooool10000007ooooo00000`00003oooooooooo`3ooooooaco
oooo0@000001ooooo`0000<00000ooooooooool0oooooolLooooo`4000000Oooool0000300000?oo
oooooooo0?oooooo7?ooool10000007ooooo00000`00003oooooooooo`3ooooooacooooo0@000001
ooooo`0000<00000ooooooooool0oooooolLooooo`4000000Oooool0000300000?oooooooooo0?oo
oooo7?ooool10000007ooooo00000`00003oooooooooo`3ooooooacooooo0@000001ooooo`0000<0
0000ooooooooool0oooooolLooooo`4000000Oooool0000300000?oooooooooo08kooooo0_ooO`2;
ooooo`4000000Oooool0000300000?oooooooooo08gooooo1?ooO`2:ooooo`4000000Oooool00003
00000?oooooooooo08gooooo1?ooO`2:ooooo`4000000Oooool0000300000?oooooooooo08kooooo
0_ooO`2;ooooo`4000000Oooool0000300000?oooooooooo0?oooooo7?ooool10000007ooooo0000
0`00003oooooooooo`3ooooooacooooo0@000001ooooo`0000<00000ooooooooool0oooooolLoooo
o`4000000Oooool0000300000?oooooooooo0?oooooo7?ooool10000007ooooo00000`00003ooooo
ooooo`3ooooooacooooo0@000001ooooo`0000<00000ooooooooool0oooooolLooooo`4000000Ooo
ool0000300000?oooooooooo0?oooooo7?ooool10000007ooooo00000`00003oooooooooo`3ooooo
oacooooo0@000001ooooo`0000<00000ooooooooool0oooooolLooooo`4000000Oooool000030000
0?oooooooooo0?oooooo7?ooool10000007ooooo00000`00003oooooooooo`3ooooooacooooo0@00
0001ooooo`0000<00000ooooooooool0oooooolLooooo`4000000Oooool0000300000?oooooooooo
0?oooooo7?ooool10000007ooooo00000`00003oooooooooo`3ooooooacooooo0@000001ooooo`00
00<00000ooooooooool0oooooolLooooo`4000000Oooool0000300000?oooooooooo0?oooooo7?oo
ool10000007ooooo00000`00003oooooooooo`3ooooooacooooo0@000001ooooo`0000<00000oooo
ooooool0oooooolLooooo`4000000Oooool0000300000?oooooooooo0?oooooo7?ooool10000007o
oooo00000`00003oooooooooo`3ooooooacooooo0@000001ooooo`0000<00000ooooooooool0oooo
oolLooooo`4000000Oooool00?l0000080000001ooooo`00\
\>"],
  ImageRangeCache->{{{0, 287}, {287, 0}} -> {-1.01089, -1.01089, 0.00704453, \
0.00704453}}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  "Corresponding  ",
  Cell[BoxData[
      \(TraditionalForm\`E[y\_ij]\  = P(\[Omega]\_i | \[Theta], x\_j)\)]],
  " for sample point"
}], "Subsubsection"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(\(\ \)\(\(PlotExampleOne[#, em2\  // \ Last, colors, gbase, 1, 
            yS] &\)\  /@ \ xd;\)\)\)], "Input"],

Cell[CellGroupData[{

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.49505 0.5 0.49505 [
[ 0 0 -0.125 0 ]
[ 0 0 -0.125 0 ]
[ 0 1 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
0 0 m
1 0 L
s
0 0 m
0 1 L
s
0 1 m
1 1 L
s
1 0 m
1 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
1 .5 0 r
.015 w
.03175 .1355 Mdot
.03435 .12523 Mdot
.11137 .12765 Mdot
.14107 .18841 Mdot
.16218 .24538 Mdot
.17294 .21053 Mdot
.18267 .18577 Mdot
.18434 .1304 Mdot
.18553 .30956 Mdot
.20401 .239 Mdot
.21247 .27571 Mdot
.21687 .20845 Mdot
.22376 .2799 Mdot
.22832 .27485 Mdot
.29063 .20974 Mdot
.29686 .25079 Mdot
.30487 .22936 Mdot
.30683 .34623 Mdot
.32055 .20902 Mdot
.32574 .21979 Mdot
.34472 .28521 Mdot
.35998 .36393 Mdot
.36335 .24976 Mdot
.3794 .36608 Mdot
.42386 .66992 Mdot
.44391 .74519 Mdot
.45059 .34198 Mdot
.47208 .67586 Mdot
.47436 .71381 Mdot
.49778 .59825 Mdot
.50874 .91643 Mdot
.51516 .76219 Mdot
.53655 .61374 Mdot
.56563 .75219 Mdot
.59189 .65665 Mdot
.59581 .61604 Mdot
.59923 .6556 Mdot
.60292 .68499 Mdot
.62656 .67779 Mdot
.63555 .72451 Mdot
.63919 .652 Mdot
.64169 .6004 Mdot
.64246 .58611 Mdot
.64496 .54267 Mdot
.64608 .77288 Mdot
.65077 .64308 Mdot
.66065 .57816 Mdot
.67474 .59169 Mdot
.69296 .563 Mdot
.72815 .65902 Mdot
.73169 .58879 Mdot
.74669 .61318 Mdot
.74821 .65474 Mdot
.75963 .63781 Mdot
.79673 .57809 Mdot
.80925 .55852 Mdot
.81525 .58444 Mdot
.83417 .62985 Mdot
.83598 .55526 Mdot
.91595 .49319 Mdot
1 0 0 r
.005 w
.16128 .17044 m
.18734 .17269 L
.21339 .17909 L
.2345 .18734 L
.23945 .19126 L
.2655 .20415 L
.27874 .21339 L
.29156 .22295 L
.31204 .23945 L
.31761 .24532 L
.33549 .2655 L
.34367 .28341 L
.34499 .29156 L
.34367 .29798 L
.31761 .3104 L
.29156 .30711 L
.2655 .30014 L
.24507 .29156 L
.23945 .28747 L
.21339 .27402 L
.20155 .2655 L
.18734 .25472 L
.16884 .23945 L
.16128 .2313 L
.14618 .21339 L
.13806 .18734 L
.16128 .17044 L
s
0 0 1 r
.65633 .57701 m
.68239 .56842 L
.70844 .56313 L
.7345 .56168 L
.76055 .5752 L
.76359 .57817 L
.76859 .60422 L
.76055 .62333 L
.75627 .63028 L
.7345 .65485 L
.73298 .65633 L
.70844 .6775 L
.69922 .68239 L
.68239 .69294 L
.65633 .70579 L
.64983 .70844 L
.63028 .71539 L
.60422 .72268 L
.57817 .72651 L
.55211 .7214 L
.53145 .70844 L
.52926 .68239 L
.54239 .65633 L
.55211 .63983 L
.56625 .63028 L
.57817 .6193 L
.60119 .60422 L
.60422 .60227 L
.63028 .58726 L
.65315 .57817 L
.65633 .57701 L
s
1 0 0 r
.03 w
.24141 .24033 Mdot
0 0 1 r
.64872 .64417 Mdot
1 0 0 r
.79703 .00495 m
.79703 .25248 L
.87129 .25248 L
.87129 .00495 L
F
0 0 1 r
.89604 .00495 m
.89604 .00495 L
.9703 .00495 L
.9703 .00495 L
F
1 0 1 r
.04 w
.03175 .1355 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P000182000`400?l00000o`00003ooooooolQ
ooooo`00o`00000P0000007ooooo00000`00003oooooooooo`3ooooooacooooo0@000001ooooo`00
00<00000ooooooooool0hOoooolE0?l002Gooooo0@000001ooooo`0000<00000ooooooooool0hOoo
oolE0?l002Gooooo0@000001ooooo`0000<00000ooooooooool0hOoooolE0?l002Gooooo0@000001
ooooo`0000<00000ooooooooool0hOoooolE0?l002Gooooo0@000001ooooo`0000<00000oooooooo
ool0hOoooolE0?l002Gooooo0@000001ooooo`0000<00000ooooooooool0hOoooolE0?l002Gooooo
0@000001ooooo`0000<00000ooooooooool0hOoooolE0?l002Gooooo0@000001ooooo`0000<00000
ooooooooool0hOoooolE0?l002Gooooo0@000001ooooo`0000<00000ooooooooool0hOoooolE0?l0
02Gooooo0@000001ooooo`0000<00000ooooooooool0hOoooolE0?l002Gooooo0@000001ooooo`00
00<00000ooooooooool0hOoooolE0?l002Gooooo0@000001ooooo`0000<00000ooooooooool0hOoo
oolE0?l002Gooooo0@000001ooooo`0000<00000ooooooooool0hOoooolE0?l002Gooooo0@000001
ooooo`0000<00000ooooooooool0hOoooolE0?l002Gooooo0@000001ooooo`0000<00000oooooooo
ool0hOoooolE0?l002Gooooo0@000001ooooo`0000<00000ooooooooool0hOoooolE0?l002Gooooo
0@000001ooooo`0000<00000ooooooooool0hOoooolE0?l002Gooooo0@000001ooooo`0000<00000
ooooooooool0hOoooolE0?l002Gooooo0@000001ooooo`0000<00000ooooooooool0hOoooolE0?l0
02Gooooo0@000001ooooo`0000<00000ooooooooool0hOoooolE0?l002Gooooo0@000001ooooo`00
00<00000ooooooooool0hOoooolE0?l002Gooooo0@000001ooooo`0000<00000ooooooooool0hOoo
oolE0?l002Gooooo0@000001ooooo`0000<00000ooooooooool0hOoooolE0?l002Gooooo0@000001
ooooo`0000<00000ooooooooool0hOoooolE0?l002Gooooo0@000001ooooo`0000<00000oooooooo
ool0hOoooolE0?l002Gooooo0@000001ooooo`0000<00000ooooooooool0hOoooolE0?l002Gooooo
0@000001ooooo`0000<00000ooooooooool0hOoooolE0?l002Gooooo0@000001ooooo`0000<00000
ooooooooool0hOoooolE0?l002Gooooo0@000001ooooo`0000<00000ooooooooool0hOoooolE0?l0
02Gooooo0@000001ooooo`0000<00000ooooooooool0hOoooolE0?l002Gooooo0@000001ooooo`00
00<00000ooooooooool0hOoooolE0?l002Gooooo0@000001ooooo`0000<00000ooooooooool0hOoo
oolE0?l002Gooooo0@000001ooooo`0000<00000ooooooooool01?ooool5ool0omSooooo5@3o000U
ooooo`4000000Oooool0000300000?oooooooooo00?ooooo1ooo0?lBooooo`;oogl0`ooooolE0?l0
02Gooooo0@000001ooooo`0000<00000ooooooooool00_ooool9ool0oa3ooooo1?ooO`0Booooo`;o
ogl0[_oooolE0?l002Gooooo0@000001ooooo`0000@00000oooooooooooooooo2ooo0?l?ooooo`Co
ogl04Oooool4oomo0:gooooo5@3o000Uooooo`4000000Oooool0000400000?ooooooooooooooo`_o
o`3o4?ooool2oomo01;ooooo1?ooO`2]oooooaD0o`009Oooool10000007ooooo00001000003ooooo
ooooooooool;ool0obGooooo0_ooO`2^oooooaD0o`009Oooool10000007ooooo00001000003ooooo
ooooooooool;ool0omGooooo5@3o000Uooooo`4000000Oooool0000400000?ooooooooooooooo`_o
o`3oeOoooolE0?l002Gooooo0@000001ooooo`0000<00000ooooooooool00_ooool9ool0omKooooo
5@3o000Uooooo`4000000Oooool0000300000?oooooooooo00?ooooo1ooo0?oGoooooaD0o`009Ooo
ool10000007ooooo00000`00003oooooooooo`04ooooo`Goo`3of?oooolE0?l002Gooooo0@000001
ooooo`0000<00000ooooooooool0hOoooolE0?l002Gooooo0@000001ooooo`0000<00000oooooooo
ool0hOoooolE0?l002Gooooo0@000001ooooo`0000<00000ooooooooool0hOoooolE0?l002Gooooo
0@000001ooooo`0000<00000ooooooooool0:_ooool60?l00;7ooooo5@3o000Uooooo`4000000Ooo
ool0000300000?oooooooooo02Wooooo00<0o`00ooooooooool01?ooool50?l00:cooooo5@3o000U
ooooo`4000000Oooool0000300000?oooooooooo02Oooooo0P3o000<ooooo`@0o`00Z?oooolE0?l0
02Gooooo0@000001ooooo`0000<00000ooooooooool09_ooool00`3o003oooooooooo`0@ooooo`@0
o`00Y?oooolE0?l002Gooooo0@000001ooooo`0000<00000ooooooooool09?ooool00oooO`00o`00
ooooo`09ooooo`;oogl02oooool30?l00:7ooooo5@3o000Uooooo`4000000Oooool0000300000?oo
oooooooo02?ooooo00Coogl00?l00?ooO`3oogl02?ooool4oomo00gooooo00?oo`00ooooooooool0
W_oooolE0?l002Gooooo0@000001ooooo`0000<00000ooooooooool08oooool01?ooO`00o`00oomo
0?ooO`08ooooo`Coogl03_ooool20?l009kooooo5@3o000Uooooo`4000000Oooool0000300000?oo
oooooooo02Cooooo00?oogl00?l00?ooool02Oooool2oomo017ooooo0P3o002LoooooaD0o`009Ooo
ool10000007ooooo00000`00003oooooooooo`0Uooooo`030?l00?oooooooooo01gooooo0P3o002J
oooooaD0o`009Oooool10000007ooooo00000`00003oooooooooo`0Uooooo`030?l00?oooooooooo
01oooooo0P3o002HoooooaD0o`009Oooool10000007ooooo00000`00003oooooooooo`0Vooooo`03
0?l00?oooooooooo017ooooo0_ooO`0=ooooo`80o`001?ooool2oomo00Oooooo0_ooO`27oooooaD0
o`009Oooool10000007ooooo00000`00003oooooooooo`0Vooooo`030?l00?oooooooooo00Gooooo
0_ooO`09ooooo`Coogl03_ooool00`3o003oooooooooo`04oomo00Gooooo1?ooO`26oooooaD0o`00
9Oooool10000007ooooo00000`00003oooooooooo`0Vooooo`030?l00?oooooooooo00Cooooo1?oo
O`08ooooo`Coogl03oooool00`3o003ooooooomo0003oomo00Gooooo1?ooO`26oooooaD0o`009Ooo
ool10000007ooooo00000`00003oooooooooo`0Wooooo`030?l00?oooooooooo00?ooooo1?ooO`09
ooooo`;oogl04Oooool0103o003ooooooomo0?ooO`07ooooo`?oogl0Q_oooolE0?l002Gooooo0@00
0001ooooo`0000<00000ooooooooool09oooool00`3o003oooooooooo`04ooooo`;oogl07_ooool0
0`3o003oooooooooo`07ooooo`Coogl0QOoooolE0?l002Gooooo0@000001ooooo`0000<00000oooo
ooooool0:?ooool00`3o003oooooooooo`0Tooooo`030?l00?oooooooooo00Kooooo1?ooO`25oooo
oaD0o`009Oooool10000007ooooo00000`00003oooooooooo`0Yooooo`030?l00?oooooooooo02Co
oooo0P3o00000oooooooogl0oomo0004ooooo`;oogl0Q_oooolE0?l002Gooooo0@000001ooooo`00
00<00000ooooooooool0:_ooool00`3o003oooooooooo`0Cooooo`Coo`003_ooool0103o003oogl0
oomo0?ooO`2;oooooaD0o`009Oooool10000007ooooo00000`00003oooooooooo`0[ooooo`030?l0
0?oooooooooo017ooooo1_oo000=ooooo`04oomo003o0000o`00oomo08_ooooo5@3o000Uooooo`40
00000Oooool0000300000?oooooooooo02cooooo00<0o`00ooooooooool02?ooool2oomo00Gooooo
2?oo000=ooooo`;oogl000<0o`00ooooooooool0ROoooolE0?l002Gooooo0@000001ooooo`0000<0
0000ooooooooool0;Oooool00`3o003oooooooooo`06ooooo`Coogl01?ooool8ool0013ooooo00<0
o`00ooooooooool0R?oooolE0?l002Gooooo0@000001ooooo`0000<00000ooooooooool0:oooool2
oomo0003ooooo`3o003ooooo00Kooooo1?ooO`04ooooo`Soo`004Oooool00`3o003oooooooooo`27
oooooaD0o`009Oooool10000007ooooo00000`00003oooooooooo`0Zooooo`Coogl000?ooooo0?l0
0?ooool01_ooool2oomo00Gooooo2?oo000;ooooo`;oogl01Oooool00`3o003oooooooooo`09oooo
o`;oogl0NooooolE0?l002Gooooo0@000001ooooo`0000<00000ooooooooool0:_ooool4oomo00;o
oooo00<0o`00ooooooooool03?ooool6ool000_ooooo1?ooO`04ooooo`030?l00?oooooooooo00So
oooo1?ooO`1joooooaD0o`009Oooool10000007ooooo00000`00003oooooooooo`0[ooooo`;oogl0
1?ooool00`3o003oooooooooo`0<ooooo`Coo`003?ooool4oomo00Gooooo00<0o`00ooooooooool0
1oooool4oomo07[ooooo5@3o000Uooooo`4000000Oooool0000300000?oooooooooo03;ooooo0P3o
000Mooooo`;oogl01oooool00`3o003oooooooooo`07ooooo`;oogl0]Oooool10000007ooooo0000
0`00003oooooooooo`0dooooo`030?l00?oooooooooo02Cooooo00<0o`00ooooooooool0_Oooool1
0000007ooooo00000`00003oooooooooo`0eooooo`030?l00?oooooooooo02Cooooo00<0o`00oooo
ooooool0_?ooool10000007ooooo00000`00003oooooooooo`0fooooo`80o`009Oooool00`3o003o
ooooooooo`2kooooo`4000000Oooool0000300000?oooooooooo03Sooooo0P3o00000oooO`3ooooo
ooooo`02oomo01kooooo00<0o`00ooooooooool0^oooool10000007ooooo00000`00003ooooooooo
o`0hooooo`;oogl00P3o0004oomo01kooooo00<0o`00ooooooooool0^_ooool10000007ooooo0000
0`00003oooooooooo`0hooooo`Coogl00P3o0002oomo01kooooo00<0o`00ooooooooool0^_ooool1
0000007ooooo00000`00003oooooooooo`0iooooo`Googl000<0o`00ooooooooool07Oooool00`3o
003oogl0oomo002jooooo`4000000Oooool0000300000?oooooooooo03_ooooo1?ooO`020?l001go
oooo00Coogl00?l00?ooO`3oogl0^Oooool10000007ooooo00000`00003oooooooooo`0looooo`;o
ogl00oooool20?l001_ooooo00Coogl00?l00?ooO`3oogl0^Oooool10000007ooooo00000`00003o
ooooooooo`13ooooo`80o`006_ooool00oooO`00o`00ooooo`2iooooo`4000000Oooool000030000
0?oooooooooo04Gooooo0P3o000Iooooo`030?l00?oooooooooo0;Sooooo0@000001ooooo`0000<0
0000ooooooooool0Aoooool20?l001Gooooo0P3o002kooooo`4000000Oooool0000300000?oooooo
oooo04Wooooo0`3o000@ooooo`80o`00_Oooool10000007ooooo00000`00003oooooooooo`0aoooo
o`;oogl06Oooool30?l000cooooo00<0o`00ooooooooool0_Oooool10000007ooooo00000`00003o
ooooooooo`0`ooooo`Coogl06oooool60?l000Cooooo0P3o0030ooooo`4000000Oooool000030000
0?oooooooooo033ooooo1?ooO`0Qooooo`@0o`00`_ooool10000007ooooo00000`00003ooooooooo
o`0aooooo`;oogl0j?ooool10000007ooooo00000`00003oooooooooo`3ooooooacooooo0@000001
ooooo`0000<00000ooooooooool0oooooolLooooo`4000000Oooool0000300000?oooooooooo0?oo
oooo7?ooool10000007ooooo00000`00003oooooooooo`3ooooooacooooo0@000001ooooo`0000<0
0000ooooooooool0oooooolLooooo`4000000Oooool0000300000?oooooooooo07gooooo0_ooO`2L
ooooo`4000000Oooool0000300000?oooooooooo07cooooo1?ooO`2Kooooo`4000000Oooool00003
00000?oooooooooo05Cooooo0_ooO`0Vooooo`Coogl0Voooool10000007ooooo00000`00003ooooo
ooooo`1Cooooo`Coogl09_ooool2oomo09cooooo0@000001ooooo`0000<00000ooooooooool0Dooo
ool4oomo0<Cooooo0@000001ooooo`0000<00000ooooooooool0E?ooool2oomo0<Gooooo0@000001
ooooo`0000<00000ooooooooool0oooooolLooooo`4000000Oooool0000300000?oooooooooo06?o
oooo0_ooO`04ooooo`;oogl0/?ooool10000007ooooo00000`00003oooooooooo`1Rooooo`Coogl0
0_ooool4oomo0:oooooo0@000001ooooo`0000<00000ooooooooool0H_ooool4oomo00;ooooo1?oo
O`2_ooooo`4000000Oooool0000300000?oooooooooo06?ooooo0_ooO`04ooooo`;oogl0/?ooool1
0000007ooooo00000`00003oooooooooo`3ooooooacooooo0@000001ooooo`0000<00000oooooooo
ool0oooooolLooooo`4000000Oooool0000300000?oooooooooo0?oooooo7?ooool10000007ooooo
00000`00003oooooooooo`3ooooooacooooo0@000001ooooo`0000<00000ooooooooool0oooooolL
ooooo`4000000Oooool0000300000?oooooooooo0?oooooo7?ooool10000007ooooo00000`00003o
ooooooooo`3ooooooacooooo0@000001ooooo`0000<00000ooooooooool0oooooolLooooo`400000
0Oooool0000300000?oooooooooo0?oooooo7?ooool10000007ooooo00000`00003oooooooooo`3o
oooooacooooo0@000001ooooo`0000<00000ooooooooool0oooooolLooooo`4000000Oooool00003
00000?oooooooooo0?oooooo7?ooool10000007ooooo00000`00003oooooooooo`3ooooooacooooo
0@000001ooooo`0000<00000ooooooooool0oooooolLooooo`4000000Oooool0000300000?oooooo
oooo0?oooooo7?ooool10000007ooooo00000`00003oooooooooo`3ooooooacooooo0@000001oooo
o`0000<00000ooooooooool0oooooolLooooo`4000000Oooool0000300000?oooooooooo0?oooooo
7?ooool10000007ooooo00000`00003oooooooooo`3ooooooacooooo0@000001ooooo`0000<00000
ooooooooool0oooooolLooooo`4000000Oooool0000300000?oooooooooo0?oooooo7?ooool10000
007ooooo00000`00003oooooooooo`3ooooooacooooo0@000001ooooo`0000<00000ooooooooool0
oooooolLooooo`4000000Oooool0000300000?oooooooooo0?oooooo7?ooool10000007ooooo0000
0`00003oooooooooo`3ooooooacooooo0@000001ooooo`0000<00000ooooooooool0oooooolLoooo
o`4000000Oooool0000300000?oooooooooo0?oooooo7?ooool10000007ooooo00000`00003ooooo
ooooo`3ooooooacooooo0@000001ooooo`0000<00000ooooooooool0oooooolLooooo`4000000Ooo
ool0000300000?oooooooooo0?oooooo7?ooool10000007ooooo00000`00003oooooooooo`3ooooo
oacooooo0@000001ooooo`0000<00000ooooooooool0oooooolLooooo`4000000Oooool000030000
0?oooooooooo0?oooooo7?ooool10000007ooooo00000`00003oooooooooo`3oooooo`Cooooo0_oo
O`0Fooooo`4000000Oooool0000300000?oooooooooo0?oooooo0oooool4oomo01Gooooo0@000001
ooooo`0000<00000ooooooooool0ooooool3ooooo`Coogl05Oooool10000007ooooo00000`00003o
ooooooooo`3oooooo`Cooooo0_ooO`0Fooooo`4000000Oooool0000300000?oooooooooo0?oooooo
7?ooool10000007ooooo00000`00003oooooooooo`3ooooooacooooo0@000001ooooo`0000<00000
ooooooooool0oooooolLooooo`4000000Oooool0000300000?oooooooooo0?oooooo7?ooool10000
007ooooo00000`00003oooooooooo`3ooooooacooooo0@000001ooooo`0000<00000ooooooooool0
oooooolLooooo`4000000Oooool0000300000?oooooooooo0?oooooo7?ooool10000007ooooo0000
0`00003oooooooooo`3ooooooacooooo0@000001ooooo`0000<00000ooooooooool0oooooolLoooo
o`4000000Oooool0000300000?oooooooooo0?oooooo7?ooool10000007ooooo00000`00003ooooo
ooooo`2eooooo`;oogl0I?ooool10000007ooooo00000`00003oooooooooo`2dooooo`Coogl0Hooo
ool10000007ooooo00000`00003oooooooooo`2dooooo`Coogl0Hoooool10000007ooooo00000`00
003oooooooooo`2eooooo`;oogl0=Oooool2oomo02gooooo0@000001ooooo`0000<00000oooooooo
ool0i?ooool2oomo00Gooooo1?ooO`0/ooooo`4000000Oooool0000300000?oooooooooo0>?ooooo
1?ooO`04ooooo`Coogl0;?ooool10000007ooooo00000`00003oooooooooo`33ooooo`;oogl07_oo
ool4oomo00Gooooo0_ooO`0]ooooo`4000000Oooool0000300000?oooooooooo0<;ooooo1?ooO`0;
0000oa?ooooo0_ooO`0eooooo`4000000Oooool0000300000?oooooooooo0<;ooooo10000?l;oooo
o`80003oB?ooool10000007ooooo00000`00003oooooooooo`2nooooo`@0003o00?ooooooomo0?oo
O`003_ooool20000odKooooo0@000001ooooo`0000<00000ooooooooool0^Oooool2oomo00<0003o
5oooool20000o`Wooooo0_ooO`0iooooo`4000000Oooool0000300000?oooooooooo0;Oooooo00D0
003oo`00ool00?l0003ooomo000Kooooo`03o`00o`000?oooooo00Gooooo1?ooO`0hooooo`400000
0Oooool0000300000?oooooooooo0;Cooooo0`000?l00oooooooogl0oomo0002oomo01cooooo00<0
003oooooooooool01?ooool4oomo00?ooooo0_ooO`0cooooo`4000000Oooool0000300000?oooooo
oooo0;;ooooo0P000?l3oomo00;ooooo0_ooO`0Cooooo`;oogl02?ooool00`000?ooooooooooo`05
ooooo`;oogl00oooool4oomo03;ooooo0@000001ooooo`0000<00000ooooooooool0/?ooool20000
o`03ooooooooO`3oogl000;oogl01_ooool2oomo00kooooo1?ooO`07ooooo`030000oooooooooooo
00[ooooo1?ooO`0booooo`4000000Oooool0000300000?oooooooooo0:kooooo0P000?l4ooooo`;o
ogl01_ooool4oomo00gooooo1?ooO`07ooooo`030000oooooooooooo00_ooooo0_ooO`0cooooo`40
00000Oooool0000300000?oooooooooo08_ooooo0_ooO`0Pooooo`030000oooooooooooo00Cooooo
0_ooO`06ooooo`Coogl03_ooool2oomo00Wooooo00<0003oooooooooool0?oooool10000007ooooo
00000`00003oooooooooo`2:ooooo`Coogl07Oooool20000o`Kooooo1?ooO`06ooooo`;oogl06_oo
ool00`000?ooooooooooo`0oooooo`4000000Oooool0000300000?oooooooooo08[ooooo1?ooO`0L
ooooo`030000oooooooooooo00Kooooo1?ooO`0Rooooo`030000oooooooooooo03oooooo0@000001
ooooo`0000<00000ooooooooool0Roooool2oomo01_ooooo00<0003oo`00ooooool02Oooool2oomo
02?ooooo00<0003oooooooooool0?oooool10000007ooooo00000`00003oooooooooo`2Fooooo`;o
ogl03_ooool20000ob[ooooo0_ooO`05ooooo`030000oooooooooooo03oooooo0@000001ooooo`00
00<00000ooooooooool0UOooool4oomo00cooooo00@0003oooooooooO`3oogl0:?ooool4oomo00?o
oooo00<0003oooooooooool0@?ooool10000007ooooo00000`00003oooooooooo`2Eooooo`Coogl0
2_ooool20000o`03ooooooooO`3oogl000;oogl09oooool4oomo00?ooooo00<0003oooooooooool0
@?ooool10000007ooooo00000`00003oooooooooo`2Fooooo`;oogl02_ooool010000?oooooooooo
ooooool4oomo02Sooooo0_ooO`04ooooo`030000oooooooooooo043ooooo0@000001ooooo`0000<0
0000ooooooooool0XOooool00`000?ooooooooooo`03ooooo`;oogl0;_ooool00`000?oooooooooo
o`11ooooo`4000000Oooool0000300000?oooooooooo0:3ooooo00<0003oooooooooool0<oooool0
0`000?ooooooooooo`0Booooo`;oogl0;_ooool10000007ooooo00000`00003oooooooooo`2Noooo
o`80003o=Oooool00`000?ooooooooooo`0Booooo`Coogl0;Oooool10000007ooooo00000`00003o
ooooooooo`2Mooooo`030000oooooooooooo01Gooooo1?l00?lLooooo`030000ooooO`3oogl001;o
oooo1?ooO`0]ooooo`4000000Oooool0000300000?oooooooooo09cooooo00<0003oooooooooool0
5Oooool6o`00oa[ooooo00<0003ooomo0?ooO`000_ooO`0Booooo`;oogl0;_ooool10000007ooooo
00000`00003oooooooooo`2Kooooo`030000oooooooooooo01Gooooo2?l00?lHooooo`030000oooo
ooooogl000?oogl0@_ooool10000007ooooo00000`00003oooooooooo`2Kooooo`030000oooooooo
oooo01Gooooo2?l00?lGooooo`040000ooooooooooooooooo`;oogl0@oooool10000007ooooo0000
0`00003oooooooooo`2Jooooo`030000oooooooooooo01Kooooo2?l00?lFooooo`030000oooooooo
oooo04Oooooo0@000001ooooo`0000<00000ooooooooool0VOooool00`000?ooooooooooo`0<oooo
o`;oogl02?ooool00oooO`3o003oo`00o`06o`00oaGooooo00<0003oooooooooool00_ooO`16oooo
o`4000000Oooool0000300000?oooooooooo09Wooooo00<0003oooooooooool02_ooool5oomo00Oo
oooo0_ooO`06o`00oa?ooooo0_ooO`000ol00?ooooooooooo`04oomo04Gooooo0@000001ooooo`00
00<00000ooooooooool0V?ooool00`000?ooooooooooo`0:ooooo`Koogl02?ooool2oomo00Co003o
4oooool2oomo0080003o0_ooool4oomo04Gooooo0@000001ooooo`0000<00000ooooooooool0V?oo
ool00`000?ooooooooooo`0:ooooo`Googl08_ooool01?ooO`00003ooomo0?ooO`03ooooo`;oogl0
A_ooool10000007ooooo00000`00003oooooooooo`1fooooo`;oogl07oooool00`000?oooooooooo
o`0<ooooo`;oogl09?ooool00`000?ooogl0oomo001<ooooo`4000000Oooool0000300000?oooooo
oooo07Gooooo1?ooO`0Nooooo`030000oooooooooooo037ooooo00<0003oooooooooool0COooool1
0000007ooooo00000`00003oooooooooo`1eooooo`Coogl02_ooool2oomo017ooooo00<0003ooooo
ooooool0<Oooool00`000?ooooooooooo`1>ooooo`4000000Oooool0000300000?oooooooooo07Ko
oooo0_ooO`0:ooooo`Coogl03oooool00`000?ooooooooooo`0Hooooo`;oogl05oooool00`000?oo
ooooooooo`1?ooooo`4000000Oooool0000300000?oooooooooo08;ooooo1?ooO`0?ooooo`030000
oooooooooooo01Oooooo1?ooO`0Dooooo`80003oD_ooool10000007ooooo00000`00003ooooooooo
o`23ooooo`;oogl03oooool00`000?ooooooooooo`0Booooo`;oogl01?ooool4oomo017ooooo0`00
0?mDooooo`4000000Oooool0000300000?oooooooooo09Cooooo00<0003oooooooooool04Oooool4
oomo00Cooooo0_ooO`0@ooooo`80003oEoooool10000007ooooo00000`00003oooooooooo`2Doooo
o`030000oooooooooooo017ooooo1?ooO`0Eooooo`030000oooooooooooo05Oooooo0@000001oooo
o`0000<00000ooooooooool0U?ooool00`000?ooooooooooo`0Booooo`;oogl05?ooool20000oe[o
oooo0@000001ooooo`0000<00000ooooooooool0U?ooool00`000?ooooooooooo`0Vooooo`80003o
G?ooool10000007ooooo00000`00003oooooooooo`2Eooooo`030000oooooooooooo02Cooooo00<0
003oooooooooool0G?ooool10000007ooooo00000`00003oooooooooo`2Eooooo`030000oooooooo
oooo02;ooooo0P000?mOooooo`4000000Oooool0000300000?oooooooooo09Gooooo00<0003ooooo
ooooool08?ooool20000of7ooooo0@000001ooooo`0000<00000ooooooooool0Q?ooool2oomo00oo
oooo0P000?lOooooo`80003oHoooool10000007ooooo00000`00003oooooooooo`23ooooo`Coogl0
4?ooool20000oa[ooooo0`000?mUooooo`4000000Oooool0000300000?oooooooooo08?ooooo1?oo
O`0Booooo`80003o5?ooool40000ofSooooo0@000001ooooo`0000<00000ooooooooool0Q?ooool2
oomo01Gooooo0`000?l>ooooo`<0003o0oooool2oomo06Oooooo0@000001ooooo`0000<00000oooo
ooooool0W_ooool30000o`Gooooo1P000?l5ooooo`Coogl0I_ooool10000007ooooo00000`00003o
ooooooooo`2Qooooo`D0003o2oooool4oomo06Kooooo0@000001ooooo`0000<00000ooooooooool0
/_ooool2oomo06Oooooo0@000001ooooo`0000<00000ooooooooool0oooooolLooooo`4000000Ooo
ool0000300000?oooooooooo0?oooooo7?ooool10000007ooooo00000`00003oooooooooo`1koooo
o`;oogl0W_ooool10000007ooooo00000`00003oooooooooo`1jooooo`Coogl0WOooool10000007o
oooo00000`00003oooooooooo`1jooooo`Coogl08?ooool2oomo07_ooooo0@000001ooooo`0000<0
0000ooooooooool0Noooool2oomo023ooooo1?ooO`1jooooo`4000000Oooool0000300000?oooooo
oooo09gooooo1?ooO`1jooooo`4000000Oooool0000300000?oooooooooo093ooooo0_ooO`0<oooo
o`;oogl0Noooool10000007ooooo00000`00003oooooooooo`2?ooooo`Coogl0R?ooool10000007o
oooo00000`00003oooooooooo`2?ooooo`Coogl0R?ooool10000007ooooo00000`00003ooooooooo
o`2@ooooo`;oogl08oooool2oomo06Cooooo0@000001ooooo`0000<00000ooooooooool0]?ooool4
oomo06?ooooo0@000001ooooo`0000<00000ooooooooool0]?ooool4oomo06?ooooo0@000001oooo
o`0000<00000ooooooooool0]Oooool2oomo06Cooooo0@000001ooooo`0000<00000ooooooooool0
oooooolLooooo`4000000Oooool0000300000?oooooooooo0?oooooo7?ooool10000007ooooo0000
0`00003oooooooooo`3ooooooacooooo0@000001ooooo`0000<00000ooooooooool0oooooolLoooo
o`4000000Oooool0000300000?oooooooooo0?oooooo7?ooool10000007ooooo00000`00003ooooo
ooooo`3ooooooacooooo0@000001ooooo`0000<00000ooooooooool0oooooolLooooo`4000000Ooo
ool0000300000?oooooooooo0?oooooo7?ooool10000007ooooo00000`00003oooooooooo`3ooooo
oacooooo0@000001ooooo`0000<00000ooooooooool0oooooolLooooo`4000000Oooool000030000
0?oooooooooo0?oooooo7?ooool10000007ooooo00000`00003oooooooooo`3ooooooacooooo0@00
0001ooooo`0000<00000ooooooooool0oooooolLooooo`4000000Oooool0000300000?oooooooooo
0?oooooo7?ooool10000007ooooo00000`00003oooooooooo`3ooooooacooooo0@000001ooooo`00
00<00000ooooooooool0oooooolLooooo`4000000Oooool0000300000?oooooooooo0?oooooo7?oo
ool10000007ooooo00000`00003oooooooooo`3ooooooacooooo0@000001ooooo`0000<00000oooo
ooooool0oooooolLooooo`4000000Oooool0000300000?oooooooooo0?oooooo7?ooool10000007o
oooo00000`00003oooooooooo`3ooooooacooooo0@000001ooooo`0000<00000ooooooooool0oooo
oolLooooo`4000000Oooool0000300000?oooooooooo0?oooooo7?ooool10000007ooooo00000`00
003oooooooooo`3ooooooacooooo0@000001ooooo`0000<00000ooooooooool0oooooolLooooo`40
00000Oooool0000300000?oooooooooo0?oooooo7?ooool10000007ooooo00000`00003ooooooooo
o`3ooooooacooooo0@000001ooooo`0000<00000ooooooooool0oooooolLooooo`4000000Oooool0
000300000?oooooooooo0?oooooo7?ooool10000007ooooo00000`00003oooooooooo`3ooooooaco
oooo0@000001ooooo`0000<00000ooooooooool0oooooolLooooo`4000000Oooool0000300000?oo
oooooooo0?oooooo7?ooool10000007ooooo00000`00003oooooooooo`3ooooooacooooo0@000001
ooooo`0000<00000ooooooooool0oooooolLooooo`4000000Oooool0000300000?oooooooooo0?oo
oooo7?ooool10000007ooooo00000`00003oooooooooo`3ooooooacooooo0@000001ooooo`0000<0
0000ooooooooool0oooooolLooooo`4000000Oooool0000300000?oooooooooo08kooooo0_ooO`2;
ooooo`4000000Oooool0000300000?oooooooooo08gooooo1?ooO`2:ooooo`4000000Oooool00003
00000?oooooooooo08gooooo1?ooO`2:ooooo`4000000Oooool0000300000?oooooooooo08kooooo
0_ooO`2;ooooo`4000000Oooool0000300000?oooooooooo0?oooooo7?ooool10000007ooooo0000
0`00003oooooooooo`3ooooooacooooo0@000001ooooo`0000<00000ooooooooool0oooooolLoooo
o`4000000Oooool0000300000?oooooooooo0?oooooo7?ooool10000007ooooo00000`00003ooooo
ooooo`3ooooooacooooo0@000001ooooo`0000<00000ooooooooool0oooooolLooooo`4000000Ooo
ool0000300000?oooooooooo0?oooooo7?ooool10000007ooooo00000`00003oooooooooo`3ooooo
oacooooo0@000001ooooo`0000<00000ooooooooool0oooooolLooooo`4000000Oooool000030000
0?oooooooooo0?oooooo7?ooool10000007ooooo00000`00003oooooooooo`3ooooooacooooo0@00
0001ooooo`0000<00000ooooooooool0oooooolLooooo`4000000Oooool0000300000?oooooooooo
0?oooooo7?ooool10000007ooooo00000`00003oooooooooo`3ooooooacooooo0@000001ooooo`00
00<00000ooooooooool0oooooolLooooo`4000000Oooool0000300000?oooooooooo0?oooooo7?oo
ool10000007ooooo00000`00003oooooooooo`3ooooooacooooo0@000001ooooo`0000<00000oooo
ooooool0oooooolLooooo`4000000Oooool0000300000?oooooooooo0?oooooo7?ooool10000007o
oooo00000`00003oooooooooo`3ooooooacooooo0@000001ooooo`0000<00000ooooooooool0oooo
oolLooooo`4000000Oooool00?l0000080000001ooooo`00\
\>"],
  ImageRangeCache->{{{0, 287}, {287, 0}} -> {-1.01089, -1.01089, 0.00704453, \
0.00704453}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.49505 0.5 0.49505 [
[ 0 0 -0.125 0 ]
[ 0 0 -0.125 0 ]
[ 0 1 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
0 0 m
1 0 L
s
0 0 m
0 1 L
s
0 1 m
1 1 L
s
1 0 m
1 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
1 .5 0 r
.015 w
.03175 .1355 Mdot
.03435 .12523 Mdot
.11137 .12765 Mdot
.14107 .18841 Mdot
.16218 .24538 Mdot
.17294 .21053 Mdot
.18267 .18577 Mdot
.18434 .1304 Mdot
.18553 .30956 Mdot
.20401 .239 Mdot
.21247 .27571 Mdot
.21687 .20845 Mdot
.22376 .2799 Mdot
.22832 .27485 Mdot
.29063 .20974 Mdot
.29686 .25079 Mdot
.30487 .22936 Mdot
.30683 .34623 Mdot
.32055 .20902 Mdot
.32574 .21979 Mdot
.34472 .28521 Mdot
.35998 .36393 Mdot
.36335 .24976 Mdot
.3794 .36608 Mdot
.42386 .66992 Mdot
.44391 .74519 Mdot
.45059 .34198 Mdot
.47208 .67586 Mdot
.47436 .71381 Mdot
.49778 .59825 Mdot
.50874 .91643 Mdot
.51516 .76219 Mdot
.53655 .61374 Mdot
.56563 .75219 Mdot
.59189 .65665 Mdot
.59581 .61604 Mdot
.59923 .6556 Mdot
.60292 .68499 Mdot
.62656 .67779 Mdot
.63555 .72451 Mdot
.63919 .652 Mdot
.64169 .6004 Mdot
.64246 .58611 Mdot
.64496 .54267 Mdot
.64608 .77288 Mdot
.65077 .64308 Mdot
.66065 .57816 Mdot
.67474 .59169 Mdot
.69296 .563 Mdot
.72815 .65902 Mdot
.73169 .58879 Mdot
.74669 .61318 Mdot
.74821 .65474 Mdot
.75963 .63781 Mdot
.79673 .57809 Mdot
.80925 .55852 Mdot
.81525 .58444 Mdot
.83417 .62985 Mdot
.83598 .55526 Mdot
.91595 .49319 Mdot
1 0 0 r
.005 w
.16128 .17044 m
.18734 .17269 L
.21339 .17909 L
.2345 .18734 L
.23945 .19126 L
.2655 .20415 L
.27874 .21339 L
.29156 .22295 L
.31204 .23945 L
.31761 .24532 L
.33549 .2655 L
.34367 .28341 L
.34499 .29156 L
.34367 .29798 L
.31761 .3104 L
.29156 .30711 L
.2655 .30014 L
.24507 .29156 L
.23945 .28747 L
.21339 .27402 L
.20155 .2655 L
.18734 .25472 L
.16884 .23945 L
.16128 .2313 L
.14618 .21339 L
.13806 .18734 L
.16128 .17044 L
s
0 0 1 r
.65633 .57701 m
.68239 .56842 L
.70844 .56313 L
.7345 .56168 L
.76055 .5752 L
.76359 .57817 L
.76859 .60422 L
.76055 .62333 L
.75627 .63028 L
.7345 .65485 L
.73298 .65633 L
.70844 .6775 L
.69922 .68239 L
.68239 .69294 L
.65633 .70579 L
.64983 .70844 L
.63028 .71539 L
.60422 .72268 L
.57817 .72651 L
.55211 .7214 L
.53145 .70844 L
.52926 .68239 L
.54239 .65633 L
.55211 .63983 L
.56625 .63028 L
.57817 .6193 L
.60119 .60422 L
.60422 .60227 L
.63028 .58726 L
.65315 .57817 L
.65633 .57701 L
s
1 0 0 r
.03 w
.24141 .24033 Mdot
0 0 1 r
.64872 .64417 Mdot
1 0 0 r
.79703 .00495 m
.79703 .25248 L
.87129 .25248 L
.87129 .00495 L
F
0 0 1 r
.89604 .00495 m
.89604 .00495 L
.9703 .00495 L
.9703 .00495 L
F
1 0 1 r
.04 w
.03435 .12523 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P000182000`400?l00000o`00003oo`3ooolQ
0?ooo`00ool0000Po`000040oooo00000ol00000oooo0?ooo`3o0?oooa`0oooo0Ol000010?ooo`00
00?o00000?ooo`3oool0h@3ooolEool002D0oooo0Ol000010?ooo`0000?o00000?ooo`3oool0h@3o
oolEool002D0oooo0Ol000010?ooo`0000?o00000?ooo`3oool0h@3ooolEool002D0oooo0Ol00001
0?ooo`0000?o00000?ooo`3oool0h@3ooolEool002D0oooo0Ol000010?ooo`0000?o00000?ooo`3o
ool0h@3ooolEool002D0oooo0Ol000010?ooo`0000?o00000?ooo`3oool0h@3ooolEool002D0oooo
0Ol000010?ooo`0000?o00000?ooo`3oool0h@3ooolEool002D0oooo0Ol000010?ooo`0000?o0000
0?ooo`3oool0h@3ooolEool002D0oooo0Ol000010?ooo`0000?o00000?ooo`3oool0h@3ooolEool0
02D0oooo0Ol000010?ooo`0000?o00000?ooo`3oool0h@3ooolEool002D0oooo0Ol000010?ooo`00
00?o00000?ooo`3oool0h@3ooolEool002D0oooo0Ol000010?ooo`0000?o00000?ooo`3oool0h@3o
oolEool002D0oooo0Ol000010?ooo`0000?o00000?ooo`3oool0h@3ooolEool002D0oooo0Ol00001
0?ooo`0000?o00000?ooo`3oool0h@3ooolEool002D0oooo0Ol000010?ooo`0000?o00000?ooo`3o
ool0h@3ooolEool002D0oooo0Ol000010?ooo`0000?o00000?ooo`3oool0h@3ooolEool002D0oooo
0Ol000010?ooo`0000?o00000?ooo`3oool0h@3ooolEool002D0oooo0Ol000010?ooo`0000?o0000
0?ooo`3oool0h@3ooolEool002D0oooo0Ol000010?ooo`0000?o00000?ooo`3oool0h@3ooolEool0
02D0oooo0Ol000010?ooo`0000?o00000?ooo`3oool0h@3ooolEool002D0oooo0Ol000010?ooo`00
00?o00000?ooo`3oool0h@3ooolEool002D0oooo0Ol000010?ooo`0000?o00000?ooo`3oool0h@3o
oolEool002D0oooo0Ol000010?ooo`0000?o00000?ooo`3oool0h@3ooolEool002D0oooo0Ol00001
0?ooo`0000?o00000?ooo`3oool0h@3ooolEool002D0oooo0Ol000010?ooo`0000?o00000?ooo`3o
ool0h@3ooolEool002D0oooo0Ol000010?ooo`0000?o00000?ooo`3oool0h@3ooolEool002D0oooo
0Ol000010?ooo`0000?o00000?ooo`3oool0h@3ooolEool002D0oooo0Ol000010?ooo`0000?o0000
0?ooo`3oool0h@3ooolEool002D0oooo0Ol000010?ooo`0000?o00000?ooo`3oool0h@3ooolEool0
02D0oooo0Ol000010?ooo`0000?o00000?ooo`3oool0103oool5ool0omP0oooo5Ooo000U0?ooo`7o
00000@3oool00003o`00003oool0oooo00<0oooo1ooo0?oG0?oooaGoo`009@3oool1o`000040oooo
00000ol00000oooo0?ooo`020?ooo`Woo`3oeP3ooolEool002D0oooo0Ol000010?ooo`0000Co0000
0?ooo`3oool0oooo2ooo0?oE0?oooaGoo`009@3oool1o`000040oooo00001?l00000oooo0?ooo`3o
ool;ool0oa00oooo0_ooO`330?oooaGoo`009@3oool1o`000040oooo00001?l00000oooo0?ooo`3o
ool;ool0o`l0oooo1?ooO`0B0?ooo`;oogl0[P3ooolEool002D0oooo0Ol000010?ooo`0000Co0000
0?ooo`3oool0oooo2ooo0?l?0?ooo`Coogl04@3oool4oomo0:d0oooo5Ooo000U0?ooo`7o00000@3o
ool00004o`00003oool0oooo0?ooo`_oo`3o403oool2oomo0180oooo1?ooO`2]0?oooaGoo`009@3o
ool1o`000040oooo00000ol00000oooo0?ooo`020?ooo`Woo`3o9P3oool2oomo0:h0oooo5Ooo000U
0?ooo`7o00000@3oool00003o`00003oool0oooo00<0oooo1ooo0?oG0?oooaGoo`009@3oool1o`00
0040oooo00000ol00000oooo0?ooo`040?ooo`Goo`3of03ooolEool002D0oooo0Ol000010?ooo`00
00?o00000?ooo`3oool0h@3ooolEool002D0oooo0Ol000010?ooo`0000?o00000?ooo`3oool0h@3o
oolEool002D0oooo0Ol000010?ooo`0000?o00000?ooo`3oool0h@3ooolEool002D0oooo0Ol00001
0?ooo`0000?o00000?ooo`3oool0h@3ooolEool002D0oooo0Ol000010?ooo`0000?o00000?ooo`3o
ool0h@3ooolEool002D0oooo0Ol000010?ooo`0000?o00000?ooo`3oool0h@3ooolEool002D0oooo
0Ol000010?ooo`0000?o00000?ooo`3oool0:P3oool6ool00;40oooo5Ooo000U0?ooo`7o00000@3o
ool00003o`00003oool0oooo02T0oooo00?oo`000?ooo`3oool0103oool5ool00:`0oooo5Ooo000U
0?ooo`7o00000@3oool00003o`00003oool0oooo02L0oooo0_oo000<0?ooo`Coo`00Z03ooolEool0
02D0oooo0Ol000010?ooo`0000?o00000?ooo`3oool09P3oool00ooo0000oooo0?ooo`0@0?ooo`Co
o`00Y03ooolEool002D0oooo0Ol000010?ooo`0000?o00000?ooo`3oool0903oool00oooO`3oo`00
0?ooo`090?ooo`;oogl02`3oool3ool00:40oooo5Ooo000U0?ooo`7o00000@3oool00003o`00003o
ool0oooo02<0oooo00Coogl0ool00?ooO`3oogl0203oool4oomo00d0oooo00?oo`000?ooo`3oool0
WP3ooolEool002D0oooo0Ol000010?ooo`0000?o00000?ooo`3oool08`3oool01?ooO`3oo`00oomo
0?ooO`080?ooo`Coogl03P3oool2ool009h0oooo5Ooo000U0?ooo`7o00000@3oool00003o`00003o
ool0oooo02@0oooo00?oogl0ool0003oool02@3oool2oomo0140oooo0_oo002L0?oooaGoo`009@3o
ool1o`000040oooo00000ol00000oooo0?ooo`0U0?ooo`03ool0003oool0oooo01d0oooo0_oo002J
0?oooaGoo`009@3oool1o`000040oooo00000ol00000oooo0?ooo`0U0?ooo`03ool0003oool0oooo
01l0oooo0_oo002H0?oooaGoo`009@3oool1o`000040oooo00000ol00000oooo0?ooo`0V0?ooo`03
ool0003oool0oooo0140oooo0_ooO`0=0?ooo`;oo`00103oool2oomo00L0oooo0_ooO`270?oooaGo
o`009@3oool1o`000040oooo00000ol00000oooo0?ooo`0V0?ooo`03ool0003oool0oooo00D0oooo
0_ooO`090?ooo`Coogl03P3oool00ooo0000oooo0?ooo`04oomo00D0oooo1?ooO`260?oooaGoo`00
9@3oool1o`000040oooo00000ol00000oooo0?ooo`0V0?ooo`03ool0003oool0oooo00@0oooo1?oo
O`080?ooo`Coogl03`3oool00ooo0000oooooomo0003oomo00D0oooo1?ooO`260?oooaGoo`009@3o
ool1o`000040oooo00000ol00000oooo0?ooo`0W0?ooo`03ool0003oool0oooo00<0oooo1?ooO`09
0?ooo`;oogl04@3oool01?oo0000oooooomo0?ooO`070?ooo`?oogl0QP3ooolEool002D0oooo0Ol0
00010?ooo`0000?o00000?ooo`3oool09`3oool00ooo0000oooo0?ooo`040?ooo`;oogl07P3oool0
0ooo0000oooo0?ooo`070?ooo`Coogl0Q@3ooolEool002D0oooo0Ol000010?ooo`0000?o00000?oo
o`3oool0:03oool00ooo0000oooo0?ooo`0T0?ooo`03ool0003oool0oooo00H0oooo1?ooO`250?oo
oaGoo`009@3oool1o`000040oooo00000ol00000oooo0?ooo`0Y0?ooo`03ool0003oool0oooo02@0
oooo0_oo00000`3oooooogl0oomo00040?ooo`;oogl0QP3ooolEool002D0oooo0Ol000010?ooo`00
00?o00000?ooo`3oool0:P3oool00ooo0000oooo0?ooo`0C0?ooo`Coo`003P3oool01?oo003oogl0
oomo0?ooO`2;0?oooaGoo`009@3oool1o`000040oooo00000ol00000oooo0?ooo`0[0?ooo`03ool0
003oool0oooo0140oooo1_oo000=0?ooo`04oomo0?oo003oo`00oomo08/0oooo5Ooo000U0?ooo`7o
00000@3oool00003o`00003oool0oooo02`0oooo00?oo`000?ooo`3oool0203oool2oomo00D0oooo
2?oo000=0?ooo`;oogl000?oo`000?ooo`3oool0R@3ooolEool002D0oooo0Ol000010?ooo`0000?o
00000?ooo`3oool0;@3oool00ooo0000oooo0?ooo`060?ooo`Coogl0103oool8ool00100oooo00?o
o`000?ooo`3oool0R03ooolEool002D0oooo0Ol000010?ooo`0000?o00000?ooo`3oool0:`3oool2
oomo00030?oooooo0000oooo00H0oooo1?ooO`040?ooo`Soo`004@3oool00ooo0000oooo0?ooo`27
0?oooaGoo`009@3oool1o`000040oooo00000ol00000oooo0?ooo`0Z0?ooo`Coogl000<0ooooool0
003oool01P3oool2oomo00D0oooo2?oo000;0?ooo`;oogl01@3oool00ooo0000oooo0?ooo`090?oo
o`;oogl0N`3ooolEool002D0oooo0Ol000010?ooo`0000?o00000?ooo`3oool0:P3oool4oomo0080
oooo00?oo`000?ooo`3oool0303oool6ool000/0oooo1?ooO`040?ooo`03ool0003oool0oooo00P0
oooo1?ooO`1j0?oooaGoo`009@3oool1o`000040oooo00000ol00000oooo0?ooo`0[0?ooo`;oogl0
103oool00ooo0000oooo0?ooo`0<0?ooo`Coo`00303oool4oomo00D0oooo00?oo`000?ooo`3oool0
1`3oool4oomo07X0oooo5Ooo000U0?ooo`7o00000@3oool00003o`00003oool0oooo0380oooo0_oo
000M0?ooo`;oogl01`3oool00ooo0000oooo0?ooo`070?ooo`;oogl0]@3oool1o`000040oooo0000
0ol00000oooo0?ooo`0d0?ooo`03ool0003oool0oooo02@0oooo00?oo`000?ooo`3oool0_@3oool1
o`000040oooo00000ol00000oooo0?ooo`0e0?ooo`03ool0003oool0oooo02@0oooo00?oo`000?oo
o`3oool0_03oool1o`000040oooo00000ol00000oooo0?ooo`0f0?ooo`;oo`009@3oool00ooo0000
oooo0?ooo`2k0?ooo`7o00000@3oool00003o`00003oool0oooo03P0oooo0_oo00000oooO`00oooo
0?ooo`02oomo01h0oooo00?oo`000?ooo`3oool0^`3oool1o`000040oooo00000ol00000oooo0?oo
o`0h0?ooo`;oogl00_oo0004oomo01h0oooo00?oo`000?ooo`3oool0^P3oool1o`000040oooo0000
0ol00000oooo0?ooo`0h0?ooo`Coogl00_oo0002oomo01h0oooo00?oo`000?ooo`3oool0^P3oool1
o`000040oooo00000ol00000oooo0?ooo`0i0?ooo`Googl000?oo`000?ooo`3oool07@3oool00ooo
003oogl0oomo002j0?ooo`7o00000@3oool00003o`00003oool0oooo03/0oooo1?ooO`02ool001d0
oooo00Coogl0ool00?ooO`3oogl0^@3oool1o`000040oooo00000ol00000oooo0?ooo`0l0?ooo`;o
ogl00`3oool2ool001/0oooo00Coogl0ool00?ooO`3oogl0^@3oool1o`000040oooo00000ol00000
oooo0?ooo`130?ooo`;oo`006P3oool00oooO`3oo`000?ooo`2i0?ooo`7o00000@3oool00003o`00
003oool0oooo04D0oooo0_oo000I0?ooo`03ool0003oool0oooo0;P0oooo0Ol000010?ooo`0000?o
00000?ooo`3oool0A`3oool2ool001D0oooo0_oo002k0?ooo`7o00000@3oool00003o`00003oool0
oooo04T0oooo0ooo000@0?ooo`;oo`00_@3oool1o`000040oooo00000ol00000oooo0?ooo`0a0?oo
o`;oogl06@3oool3ool000`0oooo00?oo`000?ooo`3oool0_@3oool1o`000040oooo00000ol00000
oooo0?ooo`0`0?ooo`Coogl06`3oool6ool000@0oooo0_oo00300?ooo`7o00000@3oool00003o`00
003oool0oooo0300oooo1?ooO`0Q0?ooo`Coo`00`P3oool1o`000040oooo00000ol00000oooo0?oo
o`0a0?ooo`;oogl0j03oool1o`000040oooo00000ol00000oooo0?ooo`3o0?oooa`0oooo0Ol00001
0?ooo`0000?o00000?ooo`3oool0o`3ooolL0?ooo`7o00000@3oool00003o`00003oool0oooo0?l0
oooo703oool1o`000040oooo00000ol00000oooo0?ooo`3o0?oooa`0oooo0Ol000010?ooo`0000?o
00000?ooo`3oool0o`3ooolL0?ooo`7o00000@3oool00003o`00003oool0oooo07d0oooo0_ooO`2L
0?ooo`7o00000@3oool00003o`00003oool0oooo07`0oooo1?ooO`2K0?ooo`7o00000@3oool00003
o`00003oool0oooo05@0oooo0_ooO`0V0?ooo`Coogl0V`3oool1o`000040oooo00000ol00000oooo
0?ooo`1C0?ooo`Coogl09P3oool2oomo09`0oooo0Ol000010?ooo`0000?o00000?ooo`3oool0D`3o
ool4oomo0<@0oooo0Ol000010?ooo`0000?o00000?ooo`3oool0E03oool2oomo0<D0oooo0Ol00001
0?ooo`0000?o00000?ooo`3oool0o`3ooolL0?ooo`7o00000@3oool00003o`00003oool0oooo06<0
oooo0_ooO`040?ooo`;oogl0/03oool1o`000040oooo00000ol00000oooo0?ooo`1R0?ooo`Coogl0
0P3oool4oomo0:l0oooo0Ol000010?ooo`0000?o00000?ooo`3oool0HP3oool4oomo0080oooo1?oo
O`2_0?ooo`7o00000@3oool00003o`00003oool0oooo06<0oooo0_ooO`040?ooo`;oogl0/03oool1
o`000040oooo00000ol00000oooo0?ooo`3o0?oooa`0oooo0Ol000010?ooo`0000?o00000?ooo`3o
ool0o`3ooolL0?ooo`7o00000@3oool00003o`00003oool0oooo0?l0oooo703oool1o`000040oooo
00000ol00000oooo0?ooo`3o0?oooa`0oooo0Ol000010?ooo`0000?o00000?ooo`3oool0o`3ooolL
0?ooo`7o00000@3oool00003o`00003oool0oooo0?l0oooo703oool1o`000040oooo00000ol00000
oooo0?ooo`3o0?oooa`0oooo0Ol000010?ooo`0000?o00000?ooo`3oool0o`3ooolL0?ooo`7o0000
0@3oool00003o`00003oool0oooo0?l0oooo703oool1o`000040oooo00000ol00000oooo0?ooo`3o
0?oooa`0oooo0Ol000010?ooo`0000?o00000?ooo`3oool0o`3ooolL0?ooo`7o00000@3oool00003
o`00003oool0oooo0?l0oooo703oool1o`000040oooo00000ol00000oooo0?ooo`3o0?oooa`0oooo
0Ol000010?ooo`0000?o00000?ooo`3oool0o`3ooolL0?ooo`7o00000@3oool00003o`00003oool0
oooo0?l0oooo703oool1o`000040oooo00000ol00000oooo0?ooo`3o0?oooa`0oooo0Ol000010?oo
o`0000?o00000?ooo`3oool0o`3ooolL0?ooo`7o00000@3oool00003o`00003oool0oooo0?l0oooo
703oool1o`000040oooo00000ol00000oooo0?ooo`3o0?oooa`0oooo0Ol000010?ooo`0000?o0000
0?ooo`3oool0o`3ooolL0?ooo`7o00000@3oool00003o`00003oool0oooo0?l0oooo703oool1o`00
0040oooo00000ol00000oooo0?ooo`3o0?oooa`0oooo0Ol000010?ooo`0000?o00000?ooo`3oool0
o`3ooolL0?ooo`7o00000@3oool00003o`00003oool0oooo0?l0oooo703oool1o`000040oooo0000
0ol00000oooo0?ooo`3o0?oooa`0oooo0Ol000010?ooo`0000?o00000?ooo`3oool0o`3ooolL0?oo
o`7o00000@3oool00003o`00003oool0oooo0?l0oooo703oool1o`000040oooo00000ol00000oooo
0?ooo`3o0?oooa`0oooo0Ol000010?ooo`0000?o00000?ooo`3oool0o`3ooolL0?ooo`7o00000@3o
ool00003o`00003oool0oooo0?l0oooo703oool1o`000040oooo00000ol00000oooo0?ooo`3o0?oo
oa`0oooo0Ol000010?ooo`0000?o00000?ooo`3oool0o`3ooolL0?ooo`7o00000@3oool00003o`00
003oool0oooo0?l0oooo703oool1o`000040oooo00000ol00000oooo0?ooo`3o0?ooo`@0oooo0_oo
O`0F0?ooo`7o00000@3oool00003o`00003oool0oooo0?l0oooo0`3oool4oomo01D0oooo0Ol00001
0?ooo`0000?o00000?ooo`3oool0o`3oool30?ooo`Coogl05@3oool1o`000040oooo00000ol00000
oooo0?ooo`3o0?ooo`@0oooo0_ooO`0F0?ooo`7o00000@3oool00003o`00003oool0oooo0?l0oooo
703oool1o`000040oooo00000ol00000oooo0?ooo`3o0?oooa`0oooo0Ol000010?ooo`0000?o0000
0?ooo`3oool0o`3ooolL0?ooo`7o00000@3oool00003o`00003oool0oooo0?l0oooo703oool1o`00
0040oooo00000ol00000oooo0?ooo`3o0?oooa`0oooo0Ol000010?ooo`0000?o00000?ooo`3oool0
o`3ooolL0?ooo`7o00000@3oool00003o`00003oool0oooo0?l0oooo703oool1o`000040oooo0000
0ol00000oooo0?ooo`3o0?oooa`0oooo0Ol000010?ooo`0000?o00000?ooo`3oool0o`3ooolL0?oo
o`7o00000@3oool00003o`00003oool0oooo0?l0oooo703oool1o`000040oooo00000ol00000oooo
0?ooo`2e0?ooo`;oogl0I03oool1o`000040oooo00000ol00000oooo0?ooo`2d0?ooo`Coogl0H`3o
ool1o`000040oooo00000ol00000oooo0?ooo`2d0?ooo`Coogl0H`3oool1o`000040oooo00000ol0
0000oooo0?ooo`2e0?ooo`;oogl0=@3oool2oomo02d0oooo0Ol000010?ooo`0000?o00000?ooo`3o
ool0i03oool2oomo00D0oooo1?ooO`0/0?ooo`7o00000@3oool00003o`00003oool0oooo0><0oooo
1?ooO`040?ooo`Coogl0;03oool1o`000040oooo00000ol00000oooo0?ooo`330?ooo`;oogl07P3o
ool4oomo00D0oooo0_ooO`0]0?ooo`7o00000@3oool00003o`00003oool0oooo0<80oooo1?ooO`0;
o`00oa<0oooo0_ooO`0e0?ooo`7o00000@3oool00003o`00003oool0oooo0<80oooo1?l00?l;0?oo
o`;o003oB03oool1o`000040oooo00000ol00000oooo0?ooo`2n0?ooo`Co003o00<0oooooomo0?oo
O`003P3oool2o`00odH0oooo0Ol000010?ooo`0000?o00000?ooo`3oool0^@3oool2oomo00?o003o
5`3oool2o`00o`T0oooo0_ooO`0i0?ooo`7o00000@3oool00003o`00003oool0oooo0;L0oooo1?l0
0?l00oooO`00oooo0?ooo`0I0?ooo`;o003o1P3oool4oomo03P0oooo0Ol000010?ooo`0000?o0000
0?ooo`3oool0]03oool3o`00o`030?ooooooO`3oogl000;oogl0703oool00ol00?l0oooo0?ooo`04
0?ooo`Coogl00`3oool2oomo03<0oooo0Ol000010?ooo`0000?o00000?ooo`3oool0/P3oool2o`00
o`?oogl00P3oool2oomo01<0oooo0_ooO`080?ooo`03o`00o`3oool0oooo00D0oooo0_ooO`030?oo
o`Coogl0<P3oool1o`000040oooo00000ol00000oooo0?ooo`2`0?ooo`;o003o00<0oooooomo0?oo
O`000_ooO`060?ooo`;oogl03P3oool4oomo00L0oooo00?o003o0?ooo`3oool02P3oool4oomo0380
oooo0Ol000010?ooo`0000?o00000?ooo`3oool0[P3oool2o`00o`@0oooo0_ooO`060?ooo`Coogl0
3@3oool4oomo00L0oooo00?o003o0?ooo`3oool02`3oool2oomo03<0oooo0Ol000010?ooo`0000?o
00000?ooo`3oool0R`3oool2oomo0200oooo00?o003o0?ooo`3oool0103oool2oomo00H0oooo1?oo
O`0>0?ooo`;oogl02@3oool00ol00?l0oooo0?ooo`0o0?ooo`7o00000@3oool00003o`00003oool0
oooo08X0oooo1?ooO`0M0?ooo`;o003o1P3oool4oomo00H0oooo0_ooO`0J0?ooo`03o`00o`3oool0
oooo03l0oooo0Ol000010?ooo`0000?o00000?ooo`3oool0RP3oool4oomo01`0oooo00?o003o0?oo
o`3oool01P3oool4oomo0280oooo00?o003o0?ooo`3oool0?`3oool1o`000040oooo00000ol00000
oooo0?ooo`2;0?ooo`;oogl06`3oool2o`00o`X0oooo0_ooO`0S0?ooo`03o`00o`3oool0oooo03l0
oooo0Ol000010?ooo`0000?o00000?ooo`3oool0UP3oool2oomo00h0oooo0_l00?lZ0?ooo`;oogl0
1@3oool00ol00?l0oooo0?ooo`0o0?ooo`7o00000@3oool00003o`00003oool0oooo09D0oooo1?oo
O`0<0?ooo`04o`00o`3oooooogl0oomo02P0oooo1?ooO`030?ooo`03o`00o`3oool0oooo0400oooo
0Ol000010?ooo`0000?o00000?ooo`3oool0U@3oool4oomo00X0oooo0_l00?l00`3oooooogl0oomo
0002oomo02L0oooo1?ooO`030?ooo`03o`00o`3oool0oooo0400oooo0Ol000010?ooo`0000?o0000
0?ooo`3oool0UP3oool2oomo00X0oooo00Co003o0?ooo`3oool0oooo1?ooO`0X0?ooo`;oogl0103o
ool00ol00?l0oooo0?ooo`100?ooo`7o00000@3oool00003o`00003oool0oooo0:40oooo00?o003o
0?ooo`3oool00`3oool2oomo02h0oooo00?o003o0?ooo`3oool0@@3oool1o`000040oooo00000ol0
0000oooo0?ooo`2P0?ooo`03o`00o`3oool0oooo03<0oooo00?o003o0?ooo`3oool04P3oool2oomo
02h0oooo0Ol000010?ooo`0000?o00000?ooo`3oool0WP3oool2o`00ocD0oooo00?o003o0?ooo`3o
ool04P3oool4oomo02d0oooo0Ol000010?ooo`0000?o00000?ooo`3oool0W@3oool00ol00?l0oooo
0?ooo`0E0?ooo`Co003o703oool00ol00?ooogl0oomo000B0?ooo`Coogl0;@3oool1o`000040oooo
00000ol00000oooo0?ooo`2L0?ooo`03o`00o`3oool0oooo01D0oooo1_l00?lJ0?ooo`03o`00oooo
O`3oogl000;oogl04P3oool2oomo02h0oooo0Ol000010?ooo`0000?o00000?ooo`3oool0V`3oool0
0ol00?l0oooo0?ooo`0E0?ooo`So003o603oool00ol00?l0oooooomo0003oomo0480oooo0Ol00001
0?ooo`0000?o00000?ooo`3oool0V`3oool00ol00?l0oooo0?ooo`0E0?ooo`So003o5`3oool01?l0
0?l0oooo0?ooo`3oool2oomo04<0oooo0Ol000010?ooo`0000?o00000?ooo`3oool0VP3oool00ol0
0?l0oooo0?ooo`0F0?ooo`So003o5P3oool00ol00?l0oooo0?ooo`170?ooo`7o00000@3oool00003
o`00003oool0oooo09T0oooo00?o003o0?ooo`3oool0303oool2oomo00P0oooo00?oogl0o`00ool0
0?l01_l00?lE0?ooo`03o`00o`3oool0oooo00;oogl0AP3oool1o`000040oooo00000ol00000oooo
0?ooo`2I0?ooo`03o`00o`3oool0oooo00X0oooo1OooO`070?ooo`;oogl01_l00?lC0?ooo`;oogl0
00?o003o0?ooo`3oool01?ooO`150?ooo`7o00000@3oool00003o`00003oool0oooo09P0oooo00?o
003o0?ooo`3oool02P3oool6oomo00P0oooo0_ooO`04o`00oa<0oooo0_ooO`02o`00o`80oooo1?oo
O`150?ooo`7o00000@3oool00003o`00003oool0oooo09P0oooo00?o003o0?ooo`3oool02P3oool5
oomo0280oooo00Coogl0o`00ooooO`3oogl00`3oool2oomo04H0oooo0Ol000010?ooo`0000?o0000
0?ooo`3oool0MP3oool2oomo01l0oooo00?o003o0?ooo`3oool0303oool2oomo02@0oooo00?o003o
oomo0?ooO`00C03oool1o`000040oooo00000ol00000oooo0?ooo`1e0?ooo`Coogl07P3oool00ol0
0?l0oooo0?ooo`0a0?ooo`03o`00o`3oool0oooo04d0oooo0Ol000010?ooo`0000?o00000?ooo`3o
ool0M@3oool4oomo00X0oooo0_ooO`0A0?ooo`03o`00o`3oool0oooo0340oooo00?o003o0?ooo`3o
ool0CP3oool1o`000040oooo00000ol00000oooo0?ooo`1f0?ooo`;oogl02P3oool4oomo00l0oooo
00?o003o0?ooo`3oool0603oool2oomo01L0oooo00?o003o0?ooo`3oool0C`3oool1o`000040oooo
00000ol00000oooo0?ooo`220?ooo`Coogl03`3oool00ol00?l0oooo0?ooo`0G0?ooo`Coogl0503o
ool2o`00oe80oooo0Ol000010?ooo`0000?o00000?ooo`3oool0P`3oool2oomo00l0oooo00?o003o
0?ooo`3oool04P3oool2oomo00@0oooo1?ooO`0A0?ooo`?o003oE03oool1o`000040oooo00000ol0
0000oooo0?ooo`2D0?ooo`03o`00o`3oool0oooo0140oooo1?ooO`040?ooo`;oogl0403oool2o`00
oeL0oooo0Ol000010?ooo`0000?o00000?ooo`3oool0U03oool00ol00?l0oooo0?ooo`0A0?ooo`Co
ogl05@3oool00ol00?l0oooo0?ooo`1G0?ooo`7o00000@3oool00003o`00003oool0oooo09@0oooo
00?o003o0?ooo`3oool04P3oool2oomo01@0oooo0_l00?mJ0?ooo`7o00000@3oool00003o`00003o
ool0oooo09@0oooo00?o003o0?ooo`3oool09P3oool2o`00oe`0oooo0Ol000010?ooo`0000?o0000
0?ooo`3oool0U@3oool00ol00?l0oooo0?ooo`0T0?ooo`03o`00o`3oool0oooo05`0oooo0Ol00001
0?ooo`0000?o00000?ooo`3oool0U@3oool00ol00?l0oooo0?ooo`0R0?ooo`;o003oG`3oool1o`00
0040oooo00000ol00000oooo0?ooo`2E0?ooo`03o`00o`3oool0oooo0200oooo0_l00?mQ0?ooo`7o
00000@3oool00003o`00003oool0oooo08@0oooo0_ooO`0?0?ooo`;o003o7`3oool2o`00of<0oooo
0Ol000010?ooo`0000?o00000?ooo`3oool0P`3oool4oomo0100oooo0_l00?lJ0?ooo`?o003oI@3o
ool1o`000040oooo00000ol00000oooo0?ooo`230?ooo`Coogl04P3oool2o`00oa@0oooo1?l00?mX
0?ooo`7o00000@3oool00003o`00003oool0oooo08@0oooo0_ooO`0E0?ooo`?o003o3P3oool3o`00
o`<0oooo0_ooO`1W0?ooo`7o00000@3oool00003o`00003oool0oooo09h0oooo0ol00?l50?ooo`Ko
003o1@3oool4oomo06H0oooo0Ol000010?ooo`0000?o00000?ooo`3oool0X@3oool5o`00o`/0oooo
1?ooO`1V0?ooo`7o00000@3oool00003o`00003oool0oooo0;80oooo0_ooO`1W0?ooo`7o00000@3o
ool00003o`00003oool0oooo0?l0oooo703oool1o`000040oooo00000ol00000oooo0?ooo`3o0?oo
oa`0oooo0Ol000010?ooo`0000?o00000?ooo`3oool0N`3oool2oomo09h0oooo0Ol000010?ooo`00
00?o00000?ooo`3oool0NP3oool4oomo09d0oooo0Ol000010?ooo`0000?o00000?ooo`3oool0NP3o
ool4oomo0200oooo0_ooO`1k0?ooo`7o00000@3oool00003o`00003oool0oooo07/0oooo0_ooO`0P
0?ooo`Coogl0NP3oool1o`000040oooo00000ol00000oooo0?ooo`2M0?ooo`Coogl0NP3oool1o`00
0040oooo00000ol00000oooo0?ooo`2@0?ooo`;oogl0303oool2oomo07/0oooo0Ol000010?ooo`00
00?o00000?ooo`3oool0S`3oool4oomo08P0oooo0Ol000010?ooo`0000?o00000?ooo`3oool0S`3o
ool4oomo08P0oooo0Ol000010?ooo`0000?o00000?ooo`3oool0T03oool2oomo02<0oooo0_ooO`1T
0?ooo`7o00000@3oool00003o`00003oool0oooo0;@0oooo1?ooO`1S0?ooo`7o00000@3oool00003
o`00003oool0oooo0;@0oooo1?ooO`1S0?ooo`7o00000@3oool00003o`00003oool0oooo0;D0oooo
0_ooO`1T0?ooo`7o00000@3oool00003o`00003oool0oooo0?l0oooo703oool1o`000040oooo0000
0ol00000oooo0?ooo`3o0?oooa`0oooo0Ol000010?ooo`0000?o00000?ooo`3oool0o`3ooolL0?oo
o`7o00000@3oool00003o`00003oool0oooo0?l0oooo703oool1o`000040oooo00000ol00000oooo
0?ooo`3o0?oooa`0oooo0Ol000010?ooo`0000?o00000?ooo`3oool0o`3ooolL0?ooo`7o00000@3o
ool00003o`00003oool0oooo0?l0oooo703oool1o`000040oooo00000ol00000oooo0?ooo`3o0?oo
oa`0oooo0Ol000010?ooo`0000?o00000?ooo`3oool0o`3ooolL0?ooo`7o00000@3oool00003o`00
003oool0oooo0?l0oooo703oool1o`000040oooo00000ol00000oooo0?ooo`3o0?oooa`0oooo0Ol0
00010?ooo`0000?o00000?ooo`3oool0o`3ooolL0?ooo`7o00000@3oool00003o`00003oool0oooo
0?l0oooo703oool1o`000040oooo00000ol00000oooo0?ooo`3o0?oooa`0oooo0Ol000010?ooo`00
00?o00000?ooo`3oool0o`3ooolL0?ooo`7o00000@3oool00003o`00003oool0oooo0?l0oooo703o
ool1o`000040oooo00000ol00000oooo0?ooo`3o0?oooa`0oooo0Ol000010?ooo`0000?o00000?oo
o`3oool0o`3ooolL0?ooo`7o00000@3oool00003o`00003oool0oooo0?l0oooo703oool1o`000040
oooo00000ol00000oooo0?ooo`3o0?oooa`0oooo0Ol000010?ooo`0000?o00000?ooo`3oool0o`3o
oolL0?ooo`7o00000@3oool00003o`00003oool0oooo0?l0oooo703oool1o`000040oooo00000ol0
0000oooo0?ooo`3o0?oooa`0oooo0Ol000010?ooo`0000?o00000?ooo`3oool0o`3ooolL0?ooo`7o
00000@3oool00003o`00003oool0oooo0?l0oooo703oool1o`000040oooo00000ol00000oooo0?oo
o`3o0?oooa`0oooo0Ol000010?ooo`0000?o00000?ooo`3oool0o`3ooolL0?ooo`7o00000@3oool0
0003o`00003oool0oooo0?l0oooo703oool1o`000040oooo00000ol00000oooo0?ooo`3o0?oooa`0
oooo0Ol000010?ooo`0000?o00000?ooo`3oool0o`3ooolL0?ooo`7o00000@3oool00003o`00003o
ool0oooo0?l0oooo703oool1o`000040oooo00000ol00000oooo0?ooo`3o0?oooa`0oooo0Ol00001
0?ooo`0000?o00000?ooo`3oool0o`3ooolL0?ooo`7o00000@3oool00003o`00003oool0oooo0?l0
oooo703oool1o`000040oooo00000ol00000oooo0?ooo`3o0?oooa`0oooo0Ol000010?ooo`0000?o
00000?ooo`3oool0o`3ooolL0?ooo`7o00000@3oool00003o`00003oool0oooo0?l0oooo703oool1
o`000040oooo00000ol00000oooo0?ooo`2>0?ooo`;oogl0R`3oool1o`000040oooo00000ol00000
oooo0?ooo`2=0?ooo`Coogl0RP3oool1o`000040oooo00000ol00000oooo0?ooo`2=0?ooo`Coogl0
RP3oool1o`000040oooo00000ol00000oooo0?ooo`2>0?ooo`;oogl0R`3oool1o`000040oooo0000
0ol00000oooo0?ooo`3o0?oooa`0oooo0Ol000010?ooo`0000?o00000?ooo`3oool0o`3ooolL0?oo
o`7o00000@3oool00003o`00003oool0oooo0?l0oooo703oool1o`000040oooo00000ol00000oooo
0?ooo`3o0?oooa`0oooo0Ol000010?ooo`0000?o00000?ooo`3oool0o`3ooolL0?ooo`7o00000@3o
ool00003o`00003oool0oooo0?l0oooo703oool1o`000040oooo00000ol00000oooo0?ooo`3o0?oo
oa`0oooo0Ol000010?ooo`0000?o00000?ooo`3oool0o`3ooolL0?ooo`7o00000@3oool00003o`00
003oool0oooo0?l0oooo703oool1o`000040oooo00000ol00000oooo0?ooo`3o0?oooa`0oooo0Ol0
00010?ooo`0000?o00000?ooo`3oool0o`3ooolL0?ooo`7o00000@3oool00003o`00003oool0oooo
0?l0oooo703oool1o`000040oooo00000ol00000oooo0?ooo`3o0?oooa`0oooo0Ol000010?ooo`00
00?o00000?ooo`3oool0o`3ooolL0?ooo`7o00000@3oool00003o`00003oool0oooo0?l0oooo703o
ool1o`000040oooo00000ol00000oooo0?ooo`3o0?oooa`0oooo0Ol000010?ooo`0000?o00000?oo
o`3oool0o`3ooolL0?ooo`7o00000@3oool00003o`00003oool0oooo0?l0oooo703oool1o`000040
oooo00000ol00000oooo0?ooo`3o0?oooa`0oooo0Ol000010?ooo`0000?o00000?ooo`3oool0o`3o
oolL0?ooo`7o00000@3oool00003o`00003oool0oooo0?l0oooo703oool1o`000040oooo003oo`00
023o00000@3oool00001\
\>"],
  ImageRangeCache->{{{0, 287}, {287, 0}} -> {-1.01089, -1.01089, 0.00704453, \
0.00704453}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.49505 0.5 0.49505 [
[ 0 0 -0.125 0 ]
[ 0 0 -0.125 0 ]
[ 0 1 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
0 0 m
1 0 L
s
0 0 m
0 1 L
s
0 1 m
1 1 L
s
1 0 m
1 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
1 .5 0 r
.015 w
.03175 .1355 Mdot
.03435 .12523 Mdot
.11137 .12765 Mdot
.14107 .18841 Mdot
.16218 .24538 Mdot
.17294 .21053 Mdot
.18267 .18577 Mdot
.18434 .1304 Mdot
.18553 .30956 Mdot
.20401 .239 Mdot
.21247 .27571 Mdot
.21687 .20845 Mdot
.22376 .2799 Mdot
.22832 .27485 Mdot
.29063 .20974 Mdot
.29686 .25079 Mdot
.30487 .22936 Mdot
.30683 .34623 Mdot
.32055 .20902 Mdot
.32574 .21979 Mdot
.34472 .28521 Mdot
.35998 .36393 Mdot
.36335 .24976 Mdot
.3794 .36608 Mdot
.42386 .66992 Mdot
.44391 .74519 Mdot
.45059 .34198 Mdot
.47208 .67586 Mdot
.47436 .71381 Mdot
.49778 .59825 Mdot
.50874 .91643 Mdot
.51516 .76219 Mdot
.53655 .61374 Mdot
.56563 .75219 Mdot
.59189 .65665 Mdot
.59581 .61604 Mdot
.59923 .6556 Mdot
.60292 .68499 Mdot
.62656 .67779 Mdot
.63555 .72451 Mdot
.63919 .652 Mdot
.64169 .6004 Mdot
.64246 .58611 Mdot
.64496 .54267 Mdot
.64608 .77288 Mdot
.65077 .64308 Mdot
.66065 .57816 Mdot
.67474 .59169 Mdot
.69296 .563 Mdot
.72815 .65902 Mdot
.73169 .58879 Mdot
.74669 .61318 Mdot
.74821 .65474 Mdot
.75963 .63781 Mdot
.79673 .57809 Mdot
.80925 .55852 Mdot
.81525 .58444 Mdot
.83417 .62985 Mdot
.83598 .55526 Mdot
.91595 .49319 Mdot
1 0 0 r
.005 w
.16128 .17044 m
.18734 .17269 L
.21339 .17909 L
.2345 .18734 L
.23945 .19126 L
.2655 .20415 L
.27874 .21339 L
.29156 .22295 L
.31204 .23945 L
.31761 .24532 L
.33549 .2655 L
.34367 .28341 L
.34499 .29156 L
.34367 .29798 L
.31761 .3104 L
.29156 .30711 L
.2655 .30014 L
.24507 .29156 L
.23945 .28747 L
.21339 .27402 L
.20155 .2655 L
.18734 .25472 L
.16884 .23945 L
.16128 .2313 L
.14618 .21339 L
.13806 .18734 L
.16128 .17044 L
s
0 0 1 r
.65633 .57701 m
.68239 .56842 L
.70844 .56313 L
.7345 .56168 L
.76055 .5752 L
.76359 .57817 L
.76859 .60422 L
.76055 .62333 L
.75627 .63028 L
.7345 .65485 L
.73298 .65633 L
.70844 .6775 L
.69922 .68239 L
.68239 .69294 L
.65633 .70579 L
.64983 .70844 L
.63028 .71539 L
.60422 .72268 L
.57817 .72651 L
.55211 .7214 L
.53145 .70844 L
.52926 .68239 L
.54239 .65633 L
.55211 .63983 L
.56625 .63028 L
.57817 .6193 L
.60119 .60422 L
.60422 .60227 L
.63028 .58726 L
.65315 .57817 L
.65633 .57701 L
s
1 0 0 r
.03 w
.24141 .24033 Mdot
0 0 1 r
.64872 .64417 Mdot
1 0 0 r
.79703 .00495 m
.79703 .25248 L
.87129 .25248 L
.87129 .00495 L
F
0 0 1 r
.89604 .00495 m
.89604 .00495 L
.9703 .00495 L
.9703 .00495 L
F
1 0 1 r
.04 w
.11137 .12765 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P000182000`400?l00000o`00003ooooooolQ
ooooo`00ool0000Po`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`00
00?o0000ooooooooool0hOoooolEool002Gooooo0Ol00001ooooo`0000?o0000ooooooooool0hOoo
oolEool002Gooooo0Ol00001ooooo`0000?o0000ooooooooool0hOoooolEool002Gooooo0Ol00001
ooooo`0000?o0000ooooooooool0hOoooolEool002Gooooo0Ol00001ooooo`0000?o0000oooooooo
ool0hOoooolEool002Gooooo0Ol00001ooooo`0000?o0000ooooooooool0hOoooolEool002Gooooo
0Ol00001ooooo`0000?o0000ooooooooool0hOoooolEool002Gooooo0Ol00001ooooo`0000?o0000
ooooooooool0hOoooolEool002Gooooo0Ol00001ooooo`0000?o0000ooooooooool0hOoooolEool0
02Gooooo0Ol00001ooooo`0000?o0000ooooooooool0hOoooolEool002Gooooo0Ol00001ooooo`00
00?o0000ooooooooool0hOoooolEool002Gooooo0Ol00001ooooo`0000?o0000ooooooooool0hOoo
oolEool002Gooooo0Ol00001ooooo`0000?o0000ooooooooool0hOoooolEool002Gooooo0Ol00001
ooooo`0000?o0000ooooooooool0hOoooolEool002Gooooo0Ol00001ooooo`0000?o0000oooooooo
ool0hOoooolEool002Gooooo0Ol00001ooooo`0000?o0000ooooooooool0hOoooolEool002Gooooo
0Ol00001ooooo`0000?o0000ooooooooool0hOoooolEool002Gooooo0Ol00001ooooo`0000?o0000
ooooooooool0hOoooolEool002Gooooo0Ol00001ooooo`0000?o0000ooooooooool0hOoooolEool0
02Gooooo0Ol00001ooooo`0000?o0000ooooooooool0hOoooolEool002Gooooo0Ol00001ooooo`00
00?o0000ooooooooool0hOoooolEool002Gooooo0Ol00001ooooo`0000?o0000ooooooooool0hOoo
oolEool002Gooooo0Ol00001ooooo`0000?o0000ooooooooool0hOoooolEool002Gooooo0Ol00001
ooooo`0000?o0000ooooooooool0hOoooolEool002Gooooo0Ol00001ooooo`0000?o0000oooooooo
ool0hOoooolEool002Gooooo0Ol00001ooooo`0000?o0000ooooooooool0hOoooolEool002Gooooo
0Ol00001ooooo`0000?o0000ooooooooool0hOoooolEool002Gooooo0Ol00001ooooo`0000?o0000
ooooooooool0hOoooolEool002Gooooo0Ol00001ooooo`0000?o0000ooooooooool0hOoooolEool0
02Gooooo0Ol00001ooooo`0000?o0000ooooooooool06_ooool5ool0ol;ooooo5Ooo000Uooooo`7o
00000Oooool00003o`000?oooooooooo01Wooooo1ooo0?o1oooooaGoo`009Oooool1o`00007ooooo
00000ol0003oooooooooo`0Hooooo`Woo`3o`?oooolEool002Gooooo0Ol00001ooooo`0000?o0000
ooooooooool01_ooool2oomo00oooooo2ooo0?nooooooaGoo`009Oooool1o`00007ooooo00000ol0
003oooooooooo`05ooooo`Coogl03_ooool;ool0okoooooo5Ooo000Uooooo`7o00000Oooool00003
o`000?oooooooooo00Gooooo1?ooO`0>ooooo`_oo`3o3oooool2oomo0:kooooo5Ooo000Uooooo`7o
00000Oooool00003o`000?oooooooooo00Gooooo0oooO`0?ooooo`_oo`3o3_ooool4oomo0:gooooo
5Ooo000Uooooo`7o00000Oooool00003o`000?oooooooooo00Cooooo1?ooO`0?ooooo`_oo`3o3_oo
ool4oomo0:gooooo5Ooo000Uooooo`7o00000Oooool00003o`000?oooooooooo00Cooooo1?ooO`0@
ooooo`Woo`3o4?ooool2oomo0:kooooo5Ooo000Uooooo`7o00000Oooool00003o`000?oooooooooo
00Gooooo0_ooO`0Booooo`Ooo`3o`OoooolEool002Gooooo0Ol00001ooooo`0000?o0000oooooooo
ool06_ooool5ool0ol;ooooo5Ooo000Uooooo`7o00000Oooool00003o`000?oooooooooo0>7ooooo
5Ooo000Uooooo`7o00000Oooool00003o`000?oooooooooo0>7ooooo5Ooo000Uooooo`7o00000Ooo
ool00003o`000?oooooooooo0>7ooooo5Ooo000Uooooo`7o00000Oooool00003o`000?oooooooooo
0>7ooooo5Ooo000Uooooo`7o00000Oooool00003o`000?oooooooooo0>7ooooo5Ooo000Uooooo`7o
00000Oooool00003o`000?oooooooooo0>7ooooo5Ooo000Uooooo`7o00000Oooool00003o`000?oo
oooooooo02[ooooo1_oo002aoooooaGoo`009Oooool1o`00007ooooo00000ol0003oooooooooo`0Y
ooooo`03ool00?oooooooooo00Cooooo1Ooo002/oooooaGoo`009Oooool1o`00007ooooo00000ol0
003oooooooooo`0Wooooo`;oo`003?ooool4ool00:Sooooo5Ooo000Uooooo`7o00000Oooool00003
o`000?oooooooooo02Kooooo00?oo`00ooooooooool04?ooool4ool00:Cooooo5Ooo000Uooooo`7o
00000Oooool00003o`000?oooooooooo02Cooooo00?oogl0ool00?ooool02Oooool2oomo00_ooooo
0ooo002QoooooaGoo`009Oooool1o`00007ooooo00000ol0003oooooooooo`0Sooooo`04oomo0?oo
003oogl0oomo00Sooooo1?ooO`0=ooooo`03ool00?oooooooooo09kooooo5Ooo000Uooooo`7o0000
0Oooool00003o`000?oooooooooo02?ooooo00Coogl0ool00?ooO`3oogl02?ooool4oomo00kooooo
0_oo002NoooooaGoo`009Oooool1o`00007ooooo00000ol0003oooooooooo`0Tooooo`03oomo0?oo
003ooooo00Wooooo0_ooO`0Aooooo`;oo`00W?oooolEool002Gooooo0Ol00001ooooo`0000?o0000
ooooooooool09Oooool00ooo003oooooooooo`0Mooooo`;oo`00V_oooolEool002Gooooo0Ol00001
ooooo`0000?o0000ooooooooool09Oooool00ooo003oooooooooo`0Oooooo`;oo`00V?oooolEool0
02Gooooo0Ol00001ooooo`0000?o0000ooooooooool09_ooool00ooo003oooooooooo`0Aooooo`;o
ogl03Oooool2ool000Cooooo0_ooO`07ooooo`;oogl0QooooolEool002Gooooo0Ol00001ooooo`00
00?o0000ooooooooool09_ooool00ooo003oooooooooo`05ooooo`;oogl02Oooool4oomo00kooooo
00?oo`00ooooooooool01?ooO`05ooooo`Coogl0Q_oooolEool002Gooooo0Ol00001ooooo`0000?o
0000ooooooooool09_ooool00ooo003oooooooooo`04ooooo`Coogl02?ooool4oomo00oooooo00?o
o`00ooooooooO`000oooO`05ooooo`Coogl0Q_oooolEool002Gooooo0Ol00001ooooo`0000?o0000
ooooooooool09oooool00ooo003oooooooooo`03ooooo`Coogl02Oooool2oomo017ooooo00Coo`00
ooooooooO`3oogl01oooool3oomo08Kooooo5Ooo000Uooooo`7o00000Oooool00003o`000?oooooo
oooo02Oooooo00?oo`00ooooooooool01?ooool2oomo01kooooo00?oo`00ooooooooool01oooool4
oomo08Gooooo5Ooo000Uooooo`7o00000Oooool00003o`000?oooooooooo02Sooooo00?oo`00oooo
ooooool09?ooool00ooo003oooooooooo`06ooooo`Coogl0QOoooolEool002Gooooo0Ol00001oooo
o`0000?o0000ooooooooool0:Oooool00ooo003oooooooooo`0Tooooo`;oo`0000?ooooooomo0?oo
O`001?ooool2oomo08Kooooo5Ooo000Uooooo`7o00000Oooool00003o`000?oooooooooo02[ooooo
00?oo`00ooooooooool04oooool4ool000kooooo00Coo`00oomo0?ooO`3oogl0RooooolEool002Go
oooo0Ol00001ooooo`0000?o0000ooooooooool0:oooool00ooo003oooooooooo`0Aooooo`Koo`00
3Oooool01?ooO`3oo`00ool00?ooO`2;oooooaGoo`009Oooool1o`00007ooooo00000ol0003ooooo
ooooo`0/ooooo`03ool00?oooooooooo00Sooooo0_ooO`05ooooo`Soo`003Oooool2oomo0003ool0
0?oooooooooo08Wooooo5Ooo000Uooooo`7o00000Oooool00003o`000?oooooooooo02gooooo00?o
o`00ooooooooool01_ooool4oomo00Cooooo2?oo000@ooooo`03ool00?oooooooooo08Sooooo5Ooo
000Uooooo`7o00000Oooool00003o`000?oooooooooo02_ooooo0_ooO`000oooooooo`00ooooo`06
ooooo`Coogl01?ooool8ool0017ooooo00?oo`00ooooooooool0QooooolEool002Gooooo0Ol00001
ooooo`0000?o0000ooooooooool0:_ooool4oomo0003oooooooo003ooooo00Kooooo0_ooO`05oooo
o`Soo`002oooool2oomo00Gooooo00?oo`00ooooooooool02Oooool2oomo07_ooooo5Ooo000Uoooo
o`7o00000Oooool00003o`000?oooooooooo02[ooooo1?ooO`02ooooo`03ool00?oooooooooo00co
oooo1_oo000;ooooo`Coogl01?ooool00ooo003oooooooooo`08ooooo`Coogl0N_oooolEool002Go
oooo0Ol00001ooooo`0000?o0000ooooooooool0:oooool2oomo00Cooooo00?oo`00ooooooooool0
3?ooool4ool000cooooo1?ooO`05ooooo`03ool00?oooooooooo00Oooooo1?ooO`1joooooaGoo`00
9Oooool1o`00007ooooo00000ol0003oooooooooo`0booooo`;oo`007Oooool2oomo00Oooooo00?o
o`00ooooooooool01oooool2oomo0;Gooooo0Ol00001ooooo`0000?o0000ooooooooool0=?ooool0
0ooo003oooooooooo`0Tooooo`03ool00?oooooooooo0;gooooo0Ol00001ooooo`0000?o0000oooo
ooooool0=Oooool00ooo003oooooooooo`0Tooooo`03ool00?oooooooooo0;cooooo0Ol00001oooo
o`0000?o0000ooooooooool0=_ooool2ool002Gooooo00?oo`00ooooooooool0^oooool1o`00007o
oooo00000ol0003oooooooooo`0hooooo`;oo`0000?oogl0ooooooooool00_ooO`0Nooooo`03ool0
0?oooooooooo0;_ooooo0Ol00001ooooo`0000?o0000ooooooooool0>?ooool2oomo00;oo`001?oo
O`0Nooooo`03ool00?oooooooooo0;[ooooo0Ol00001ooooo`0000?o0000ooooooooool0>?ooool4
oomo00;oo`000_ooO`0Nooooo`03ool00?oooooooooo0;[ooooo0Ol00001ooooo`0000?o0000oooo
ooooool0>Oooool5oomo0003ool00?oooooooooo01gooooo00?oo`00oomo0?ooO`00^_ooool1o`00
007ooooo00000ol0003oooooooooo`0kooooo`Coogl00_oo000Mooooo`04oomo0?oo003oogl0oomo
0;Wooooo0Ol00001ooooo`0000?o0000ooooooooool0??ooool2oomo00?ooooo0_oo000Kooooo`04
oomo0?oo003oogl0oomo0;Wooooo0Ol00001ooooo`0000?o0000ooooooooool0@oooool2ool001[o
oooo00?oogl0ool00?ooool0^Oooool1o`00007ooooo00000ol0003oooooooooo`15ooooo`;oo`00
6Oooool00ooo003oooooooooo`2hooooo`7o00000Oooool00003o`000?oooooooooo04Oooooo0_oo
000Eooooo`;oo`00^oooool1o`00007ooooo00000ol0003oooooooooo`19ooooo`?oo`004?ooool2
ool00;gooooo0Ol00001ooooo`0000?o0000ooooooooool0<Oooool2oomo01Wooooo0ooo000<oooo
o`03ool00?oooooooooo0;gooooo0Ol00001ooooo`0000?o0000ooooooooool0<?ooool4oomo01_o
oooo1_oo0004ooooo`;oo`00`?ooool1o`00007ooooo00000ol0003oooooooooo`0`ooooo`Coogl0
8Oooool4ool00<;ooooo0Ol00001ooooo`0000?o0000ooooooooool0<Oooool2oomo0>Sooooo0Ol0
0001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo
0?oooooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`00
00?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?oo
ool1o`00007ooooo00000ol0003oooooooooo`1mooooo`;oogl0W?ooool1o`00007ooooo00000ol0
003oooooooooo`1looooo`Coogl0Voooool1o`00007ooooo00000ol0003oooooooooo`1Dooooo`;o
ogl09_ooool4oomo09_ooooo0Ol00001ooooo`0000?o0000ooooooooool0Doooool4oomo02Kooooo
0_ooO`2Looooo`7o00000Oooool00003o`000?oooooooooo05?ooooo1?ooO`34ooooo`7o00000Ooo
ool00003o`000?oooooooooo05Cooooo0_ooO`35ooooo`7o00000Oooool00003o`000?oooooooooo
0?oooooo7?ooool1o`00007ooooo00000ol0003oooooooooo`1Sooooo`;oogl01?ooool2oomo0;3o
oooo0Ol00001ooooo`0000?o0000ooooooooool0H_ooool4oomo00;ooooo1?ooO`2_ooooo`7o0000
0Oooool00003o`000?oooooooooo06;ooooo1?ooO`02ooooo`Coogl0[oooool1o`00007ooooo0000
0ol0003oooooooooo`1Sooooo`;oogl01?ooool2oomo0;3ooooo0Ol00001ooooo`0000?o0000oooo
ooooool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007o
oooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooo
oolLooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0
003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o
00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003ooooooooo
o`3ooooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool0
0003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooooaco
oooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oo
oooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001
ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo0?oo
oooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o
0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1
o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000oooooooo
ool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo
00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolL
ooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003o
ooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o0000
0Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3o
oooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003
o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo
0Ol00001ooooo`0000?o0000ooooooooool0ooooool4ooooo`;oogl05_ooool1o`00007ooooo0000
0ol0003oooooooooo`3oooooo`?ooooo1?ooO`0Eooooo`7o00000Oooool00003o`000?oooooooooo
0?oooooo0oooool4oomo01Gooooo0Ol00001ooooo`0000?o0000ooooooooool0ooooool4ooooo`;o
ogl05_ooool1o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o
0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1
o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000oooooooo
ool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo
00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolL
ooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003o
ooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0]Oooool2oomo06Cooooo
0Ol00001ooooo`0000?o0000ooooooooool0]?ooool4oomo06?ooooo0Ol00001ooooo`0000?o0000
ooooooooool0]?ooool4oomo06?ooooo0Ol00001ooooo`0000?o0000ooooooooool0]Oooool2oomo
03Gooooo0_ooO`0]ooooo`7o00000Oooool00003o`000?oooooooooo0>Cooooo0_ooO`05ooooo`Co
ogl0;?ooool1o`00007ooooo00000ol0003oooooooooo`3Sooooo`Coogl01?ooool4oomo02cooooo
0Ol00001ooooo`0000?o0000ooooooooool0`oooool2oomo01kooooo1?ooO`05ooooo`;oogl0;Ooo
ool1o`00007ooooo00000ol0003oooooooooo`32ooooo`Coogl02ol00?lCooooo`;oogl0=Oooool1
o`00007ooooo00000ol0003oooooooooo`32ooooo`Co003o2oooool2o`00odSooooo0Ol00001oooo
o`0000?o0000ooooooooool0__ooool4o`00o`03ooooooooO`3oogl000kooooo0_l00?m6ooooo`7o
00000Oooool00003o`000?oooooooooo0;Wooooo0_ooO`03o`00oaOooooo0_l00?l9ooooo`;oogl0
>Oooool1o`00007ooooo00000ol0003oooooooooo`2gooooo`Co003o00?oogl0ooooooooool06Ooo
ool2o`00o`Kooooo1?ooO`0hooooo`7o00000Oooool00003o`000?oooooooooo0;Cooooo0ol00?l0
0oooooooogl0oomo0002oomo01cooooo00?o003oooooooooool01?ooool4oomo00?ooooo0_ooO`0c
ooooo`7o00000Oooool00003o`000?oooooooooo0;;ooooo0_l00?l3oomo00;ooooo0_ooO`0Coooo
o`;oogl02?ooool00ol00?ooooooooooo`05ooooo`;oogl00oooool4oomo03;ooooo0Ol00001oooo
o`0000?o0000ooooooooool0/?ooool2o`00o`03ooooooooO`3oogl000;oogl01_ooool2oomo00ko
oooo1?ooO`07ooooo`03o`00oooooooooooo00[ooooo1?ooO`0booooo`7o00000Oooool00003o`00
0?oooooooooo0:kooooo0_l00?l4ooooo`;oogl01_ooool4oomo00gooooo1?ooO`07ooooo`03o`00
oooooooooooo00_ooooo0_ooO`0cooooo`7o00000Oooool00003o`000?oooooooooo08_ooooo0_oo
O`0Pooooo`03o`00oooooooooooo00Cooooo0_ooO`06ooooo`Coogl03_ooool2oomo00Wooooo00?o
003oooooooooool0?oooool1o`00007ooooo00000ol0003oooooooooo`2:ooooo`Coogl07Oooool2
o`00o`Kooooo1?ooO`06ooooo`;oogl06_ooool00ol00?ooooooooooo`0oooooo`7o00000Oooool0
0003o`000?oooooooooo08[ooooo1?ooO`0Looooo`03o`00oooooooooooo00Kooooo1?ooO`0Roooo
o`03o`00oooooooooooo03oooooo0Ol00001ooooo`0000?o0000ooooooooool0Roooool2oomo01_o
oooo0_l00?l:ooooo`;oogl08oooool00ol00?ooooooooooo`0oooooo`7o00000Oooool00003o`00
0?oooooooooo09Kooooo0_ooO`0>ooooo`;o003o:_ooool2oomo00Gooooo00?o003oooooooooool0
?oooool1o`00007ooooo00000ol0003oooooooooo`2Eooooo`Coogl03?ooool01?l00?oooooooomo
0?ooO`0Xooooo`Coogl00oooool00ol00?ooooooooooo`10ooooo`7o00000Oooool00003o`000?oo
oooooooo09Gooooo1?ooO`0:ooooo`;o003o00?ooooooomo0?ooO`000_ooO`0Wooooo`Coogl00ooo
ool00ol00?ooooooooooo`10ooooo`7o00000Oooool00003o`000?oooooooooo09Kooooo0_ooO`0:
ooooo`04o`00ooooooooooooooooo`Coogl0:?ooool2oomo00Cooooo00?o003oooooooooool0@?oo
ool1o`00007ooooo00000ol0003oooooooooo`2Qooooo`03o`00oooooooooooo00?ooooo0_ooO`0^
ooooo`03o`00oooooooooooo047ooooo0Ol00001ooooo`0000?o0000ooooooooool0X?ooool00ol0
0?ooooooooooo`0cooooo`03o`00oooooooooooo01;ooooo0_ooO`0^ooooo`7o00000Oooool00003
o`000?oooooooooo09kooooo0_l00?leooooo`03o`00oooooooooooo01;ooooo1?ooO`0]ooooo`7o
00000Oooool00003o`000?oooooooooo09gooooo00?o003oooooooooool05Oooool4o`00oacooooo
00?o003ooomo0?ooO`004_ooool4oomo02gooooo0Ol00001ooooo`0000?o0000ooooooooool0W?oo
ool00ol00?ooooooooooo`0Eooooo`Ko003o6_ooool00ol00?ooogl0oomo0002oomo01;ooooo0_oo
O`0^ooooo`7o00000Oooool00003o`000?oooooooooo09_ooooo00?o003oooooooooool05Oooool8
o`00oaSooooo00?o003oooooooooO`000oooO`12ooooo`7o00000Oooool00003o`000?oooooooooo
09_ooooo00?o003oooooooooool05Oooool8o`00oaOooooo00Co003ooooooooooooooooo0_ooO`13
ooooo`7o00000Oooool00003o`000?oooooooooo09[ooooo00?o003oooooooooool05_ooool8o`00
oaKooooo00?o003oooooooooool0Aoooool1o`00007ooooo00000ol0003oooooooooo`2Iooooo`03
o`00oooooooooooo00cooooo0_ooO`08ooooo`03oomo0?l00?oo003o00Ko003o5Oooool00ol00?oo
ooooooooo`02oomo04Kooooo0Ol00001ooooo`0000?o0000ooooooooool0VOooool00ol00?oooooo
ooooo`0:ooooo`Googl01oooool2oomo00Ko003o4oooool2oomo0003o`00oooooooooooo00Coogl0
AOooool1o`00007ooooo00000ol0003oooooooooo`2Hooooo`03o`00oooooooooooo00[ooooo1_oo
O`08ooooo`;oogl01?l00?lCooooo`;oogl00_l00?l2ooooo`Coogl0AOooool1o`00007ooooo0000
0ol0003oooooooooo`2Hooooo`03o`00oooooooooooo00[ooooo1OooO`0Rooooo`04oomo0?l00?oo
ogl0oomo00?ooooo0_ooO`16ooooo`7o00000Oooool00003o`000?oooooooooo07Kooooo0_ooO`0O
ooooo`03o`00oooooooooooo00cooooo0_ooO`0Tooooo`03o`00ooooO`3oogl004cooooo0Ol00001
ooooo`0000?o0000ooooooooool0MOooool4oomo01kooooo00?o003oooooooooool0<Oooool00ol0
0?ooooooooooo`1=ooooo`7o00000Oooool00003o`000?oooooooooo07Gooooo1?ooO`0:ooooo`;o
ogl04Oooool00ol00?ooooooooooo`0aooooo`03o`00oooooooooooo04kooooo0Ol00001ooooo`00
00?o0000ooooooooool0M_ooool2oomo00[ooooo1?ooO`0?ooooo`03o`00oooooooooooo01Sooooo
0_ooO`0Gooooo`03o`00oooooooooooo04oooooo0Ol00001ooooo`0000?o0000ooooooooool0P_oo
ool4oomo00oooooo00?o003oooooooooool05oooool4oomo01Cooooo0_l00?mBooooo`7o00000Ooo
ool00003o`000?oooooooooo08?ooooo0_ooO`0?ooooo`03o`00oooooooooooo01;ooooo0_ooO`04
ooooo`Coogl04Oooool3o`00oeCooooo0Ol00001ooooo`0000?o0000ooooooooool0U?ooool00ol0
0?ooooooooooo`0Aooooo`Coogl01?ooool2oomo013ooooo0_l00?mGooooo`7o00000Oooool00003
o`000?oooooooooo09Cooooo00?o003oooooooooool04Oooool4oomo01Gooooo00?o003ooooooooo
ool0Eoooool1o`00007ooooo00000ol0003oooooooooo`2Dooooo`03o`00oooooooooooo01;ooooo
0_ooO`0Dooooo`;o003oF_ooool1o`00007ooooo00000ol0003oooooooooo`2Dooooo`03o`00oooo
oooooooo02Kooooo0_l00?mLooooo`7o00000Oooool00003o`000?oooooooooo09Gooooo00?o003o
ooooooooool09?ooool00ol00?ooooooooooo`1Looooo`7o00000Oooool00003o`000?oooooooooo
09Gooooo00?o003oooooooooool08_ooool2o`00oeoooooo0Ol00001ooooo`0000?o0000oooooooo
ool0UOooool00ol00?ooooooooooo`0Pooooo`;o003oHOooool1o`00007ooooo00000ol0003ooooo
ooooo`24ooooo`;oogl03oooool2o`00oaoooooo0_l00?mSooooo`7o00000Oooool00003o`000?oo
oooooooo08?ooooo1?ooO`0@ooooo`;o003o6_ooool3o`00ofGooooo0Ol00001ooooo`0000?o0000
ooooooooool0Poooool4oomo01;ooooo0_l00?lDooooo`Co003oJ?ooool1o`00007ooooo00000ol0
003oooooooooo`24ooooo`;oogl05Oooool3o`00o`kooooo0ol00?l3ooooo`;oogl0Ioooool1o`00
007ooooo00000ol0003oooooooooo`2Nooooo`?o003o1Oooool6o`00o`Gooooo1?ooO`1Vooooo`7o
00000Oooool00003o`000?oooooooooo0:7ooooo1Ol00?l;ooooo`Coogl0I_ooool1o`00007ooooo
00000ol0003oooooooooo`2booooo`;oogl0Ioooool1o`00007ooooo00000ol0003oooooooooo`3o
oooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003
o`000?oooooooooo07_ooooo0_ooO`2Nooooo`7o00000Oooool00003o`000?oooooooooo07[ooooo
1?ooO`2Mooooo`7o00000Oooool00003o`000?oooooooooo07[ooooo1?ooO`0Pooooo`;oogl0Nooo
ool1o`00007ooooo00000ol0003oooooooooo`1kooooo`;oogl08?ooool4oomo07[ooooo0Ol00001
ooooo`0000?o0000ooooooooool0WOooool4oomo07[ooooo0Ol00001ooooo`0000?o0000oooooooo
ool0T?ooool2oomo00cooooo0_ooO`1kooooo`7o00000Oooool00003o`000?oooooooooo08oooooo
1?ooO`28ooooo`7o00000Oooool00003o`000?oooooooooo08oooooo1?ooO`28ooooo`7o00000Ooo
ool00003o`000?oooooooooo093ooooo0_ooO`0Sooooo`;oogl0I?ooool1o`00007ooooo00000ol0
003oooooooooo`2dooooo`Coogl0Hoooool1o`00007ooooo00000ol0003oooooooooo`2dooooo`Co
ogl0Hoooool1o`00007ooooo00000ol0003oooooooooo`2eooooo`;oogl0I?ooool1o`00007ooooo
00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolL
ooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003o
ooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o0000
0Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3o
oooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003
o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo
0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oooooo
oooo0?oooooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001oooo
o`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo
7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000
ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00
007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0
oooooolLooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo0000
0ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLoooo
o`7o00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003ooooo
ooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Ooo
ool00003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooo
oacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`00
0?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol0
0001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo
0?oooooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`00
00?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?oo
ool1o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000oooo
ooooool0S_ooool2oomo08_ooooo0Ol00001ooooo`0000?o0000ooooooooool0SOooool4oomo08[o
oooo0Ol00001ooooo`0000?o0000ooooooooool0SOooool4oomo08[ooooo0Ol00001ooooo`0000?o
0000ooooooooool0S_ooool2oomo08_ooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolL
ooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003o
ooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o0000
0Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3o
oooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003
o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo
0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oooooo
oooo0?oooooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001oooo
o`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo
7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000
ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00
007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0
oooooolLooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo0000
0ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`00ool0000Po`00007ooooo0000\
\>"],
  ImageRangeCache->{{{0, 287}, {287, 0}} -> {-1.01089, -1.01089, 0.00704453, \
0.00704453}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.49505 0.5 0.49505 [
[ 0 0 -0.125 0 ]
[ 0 0 -0.125 0 ]
[ 0 1 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
0 0 m
1 0 L
s
0 0 m
0 1 L
s
0 1 m
1 1 L
s
1 0 m
1 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
1 .5 0 r
.015 w
.03175 .1355 Mdot
.03435 .12523 Mdot
.11137 .12765 Mdot
.14107 .18841 Mdot
.16218 .24538 Mdot
.17294 .21053 Mdot
.18267 .18577 Mdot
.18434 .1304 Mdot
.18553 .30956 Mdot
.20401 .239 Mdot
.21247 .27571 Mdot
.21687 .20845 Mdot
.22376 .2799 Mdot
.22832 .27485 Mdot
.29063 .20974 Mdot
.29686 .25079 Mdot
.30487 .22936 Mdot
.30683 .34623 Mdot
.32055 .20902 Mdot
.32574 .21979 Mdot
.34472 .28521 Mdot
.35998 .36393 Mdot
.36335 .24976 Mdot
.3794 .36608 Mdot
.42386 .66992 Mdot
.44391 .74519 Mdot
.45059 .34198 Mdot
.47208 .67586 Mdot
.47436 .71381 Mdot
.49778 .59825 Mdot
.50874 .91643 Mdot
.51516 .76219 Mdot
.53655 .61374 Mdot
.56563 .75219 Mdot
.59189 .65665 Mdot
.59581 .61604 Mdot
.59923 .6556 Mdot
.60292 .68499 Mdot
.62656 .67779 Mdot
.63555 .72451 Mdot
.63919 .652 Mdot
.64169 .6004 Mdot
.64246 .58611 Mdot
.64496 .54267 Mdot
.64608 .77288 Mdot
.65077 .64308 Mdot
.66065 .57816 Mdot
.67474 .59169 Mdot
.69296 .563 Mdot
.72815 .65902 Mdot
.73169 .58879 Mdot
.74669 .61318 Mdot
.74821 .65474 Mdot
.75963 .63781 Mdot
.79673 .57809 Mdot
.80925 .55852 Mdot
.81525 .58444 Mdot
.83417 .62985 Mdot
.83598 .55526 Mdot
.91595 .49319 Mdot
1 0 0 r
.005 w
.16128 .17044 m
.18734 .17269 L
.21339 .17909 L
.2345 .18734 L
.23945 .19126 L
.2655 .20415 L
.27874 .21339 L
.29156 .22295 L
.31204 .23945 L
.31761 .24532 L
.33549 .2655 L
.34367 .28341 L
.34499 .29156 L
.34367 .29798 L
.31761 .3104 L
.29156 .30711 L
.2655 .30014 L
.24507 .29156 L
.23945 .28747 L
.21339 .27402 L
.20155 .2655 L
.18734 .25472 L
.16884 .23945 L
.16128 .2313 L
.14618 .21339 L
.13806 .18734 L
.16128 .17044 L
s
0 0 1 r
.65633 .57701 m
.68239 .56842 L
.70844 .56313 L
.7345 .56168 L
.76055 .5752 L
.76359 .57817 L
.76859 .60422 L
.76055 .62333 L
.75627 .63028 L
.7345 .65485 L
.73298 .65633 L
.70844 .6775 L
.69922 .68239 L
.68239 .69294 L
.65633 .70579 L
.64983 .70844 L
.63028 .71539 L
.60422 .72268 L
.57817 .72651 L
.55211 .7214 L
.53145 .70844 L
.52926 .68239 L
.54239 .65633 L
.55211 .63983 L
.56625 .63028 L
.57817 .6193 L
.60119 .60422 L
.60422 .60227 L
.63028 .58726 L
.65315 .57817 L
.65633 .57701 L
s
1 0 0 r
.03 w
.24141 .24033 Mdot
0 0 1 r
.64872 .64417 Mdot
1 0 0 r
.79703 .00495 m
.79703 .25248 L
.87129 .25248 L
.87129 .00495 L
F
0 0 1 r
.89604 .00495 m
.89604 .00495 L
.9703 .00495 L
.9703 .00495 L
F
1 0 1 r
.04 w
.14107 .18841 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P000182000`400?l00000o`00003ooooooolQ
ooooo`00ool0000Po`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`00
00?o0000ooooooooool0hOoooolEool002Gooooo0Ol00001ooooo`0000?o0000ooooooooool0hOoo
oolEool002Gooooo0Ol00001ooooo`0000?o0000ooooooooool0hOoooolEool002Gooooo0Ol00001
ooooo`0000?o0000ooooooooool0hOoooolEool002Gooooo0Ol00001ooooo`0000?o0000oooooooo
ool0hOoooolEool002Gooooo0Ol00001ooooo`0000?o0000ooooooooool0hOoooolEool002Gooooo
0Ol00001ooooo`0000?o0000ooooooooool0hOoooolEool002Gooooo0Ol00001ooooo`0000?o0000
ooooooooool0hOoooolEool002Gooooo0Ol00001ooooo`0000?o0000ooooooooool0hOoooolEool0
02Gooooo0Ol00001ooooo`0000?o0000ooooooooool0hOoooolEool002Gooooo0Ol00001ooooo`00
00?o0000ooooooooool0hOoooolEool002Gooooo0Ol00001ooooo`0000?o0000ooooooooool0hOoo
oolEool002Gooooo0Ol00001ooooo`0000?o0000ooooooooool0hOoooolEool002Gooooo0Ol00001
ooooo`0000?o0000ooooooooool0hOoooolEool002Gooooo0Ol00001ooooo`0000?o0000oooooooo
ool0hOoooolEool002Gooooo0Ol00001ooooo`0000?o0000ooooooooool0hOoooolEool002Gooooo
0Ol00001ooooo`0000?o0000ooooooooool0hOoooolEool002Gooooo0Ol00001ooooo`0000?o0000
ooooooooool0hOoooolEool002Gooooo0Ol00001ooooo`0000?o0000ooooooooool0hOoooolEool0
02Gooooo0Ol00001ooooo`0000?o0000ooooooooool0hOoooolEool002Gooooo0Ol00001ooooo`00
00?o0000ooooooooool0hOoooolEool002Gooooo0Ol00001ooooo`0000?o0000ooooooooool0hOoo
oolEool002Gooooo0Ol00001ooooo`0000?o0000ooooooooool0hOoooolEool002Gooooo0Ol00001
ooooo`0000?o0000ooooooooool0hOoooolEool002Gooooo0Ol00001ooooo`0000?o0000oooooooo
ool0hOoooolEool002Gooooo0Ol00001ooooo`0000?o0000ooooooooool0hOoooolEool002Gooooo
0Ol00001ooooo`0000?o0000ooooooooool0hOoooolEool002Gooooo0Ol00001ooooo`0000?o0000
ooooooooool0hOoooolEool002Gooooo0Ol00001ooooo`0000?o0000ooooooooool0hOoooolEool0
02Gooooo0Ol00001ooooo`0000?o0000ooooooooool0hOoooolEool002Gooooo0Ol00001ooooo`00
00?o0000ooooooooool0hOoooolEool002Gooooo0Ol00001ooooo`0000?o0000ooooooooool0hOoo
oolEool002Gooooo0Ol00001ooooo`0000?o0000ooooooooool01_ooool2oomo0=Wooooo5Ooo000U
ooooo`7o00000Oooool00003o`000?oooooooooo00Gooooo1?ooO`0Cooooo`;oogl0`ooooolEool0
02Gooooo0Ol00001ooooo`0000?o0000ooooooooool01Oooool4oomo01;ooooo1?ooO`0Booooo`;o
ogl0[_oooolEool002Gooooo0Ol00001ooooo`0000?o0000ooooooooool01Oooool3oomo01?ooooo
1?ooO`0Aooooo`Coogl0[OoooolEool002Gooooo0Ol00001ooooo`0000?o0000ooooooooool01?oo
ool4oomo01Cooooo0_ooO`0Booooo`Coogl0[OoooolEool002Gooooo0Ol00001ooooo`0000?o0000
ooooooooool01?ooool4oomo02Wooooo0_ooO`2^oooooaGoo`009Oooool1o`00007ooooo00000ol0
003oooooooooo`05ooooo`;oogl0f_oooolEool002Gooooo0Ol00001ooooo`0000?o0000oooooooo
ool0hOoooolEool002Gooooo0Ol00001ooooo`0000?o0000ooooooooool0hOoooolEool002Gooooo
0Ol00001ooooo`0000?o0000ooooooooool0hOoooolEool002Gooooo0Ol00001ooooo`0000?o0000
ooooooooool0hOoooolEool002Gooooo0Ol00001ooooo`0000?o0000ooooooooool0hOoooolEool0
02Gooooo0Ol00001ooooo`0000?o0000ooooooooool0hOoooolEool002Gooooo0Ol00001ooooo`00
00?o0000ooooooooool0hOoooolEool002Gooooo0Ol00001ooooo`0000?o0000ooooooooool0:_oo
ool6ool00;7ooooo5Ooo000Uooooo`7o00000Oooool00003o`000?oooooooooo02?ooooo1Ooo0?l0
0oooooooo`00ooooo`05ooooo`Goo`00[?oooolEool002Gooooo0Ol00001ooooo`0000?o0000oooo
ooooool08_ooool7ool0o`cooooo1?oo002XoooooaGoo`009Oooool1o`00007ooooo00000ol0003o
ooooooooo`0Qooooo`Woo`3o3oooool4ool00:Cooooo5Ooo000Uooooo`7o00000Oooool00003o`00
0?oooooooooo023ooooo2ooo0?l5ooooo`;oogl02oooool3ool00:7ooooo5Ooo000Uooooo`7o0000
0Oooool00003o`000?oooooooooo023ooooo2ooo0?l4ooooo`Coogl03Oooool00ooo003ooooooooo
o`2NoooooaGoo`009Oooool1o`00007ooooo00000ol0003oooooooooo`0Pooooo`_oo`3o1?ooool4
oomo00kooooo0_oo002NoooooaGoo`009Oooool1o`00007ooooo00000ol0003oooooooooo`0Poooo
o`_oo`3o1Oooool2oomo017ooooo0_oo002LoooooaGoo`009Oooool1o`00007ooooo00000ol0003o
ooooooooo`0Pooooo`_oo`3o6_ooool2ool009[ooooo5Ooo000Uooooo`7o00000Oooool00003o`00
0?oooooooooo027ooooo2Ooo0?lMooooo`;oo`00V?oooolEool002Gooooo0Ol00001ooooo`0000?o
0000ooooooooool08_ooool7ool0oa7ooooo0_ooO`0=ooooo`;oo`001?ooool2oomo00Oooooo0_oo
O`27oooooaGoo`009Oooool1o`00007ooooo00000ol0003oooooooooo`0Sooooo`Goo`3o1_ooool2
oomo00Wooooo1?ooO`0>ooooo`03ool00?oooooooooo00Coogl01Oooool4oomo08Kooooo5Ooo000U
ooooo`7o00000Oooool00003o`000?oooooooooo02Kooooo00?oo`00ooooooooool01?ooool4oomo
00Sooooo1?ooO`0?ooooo`03ool00?ooooooogl000?oogl01Oooool4oomo08Kooooo5Ooo000Uoooo
o`7o00000Oooool00003o`000?oooooooooo02Oooooo00?oo`00ooooooooool00oooool4oomo00Wo
oooo0_ooO`0Aooooo`04ool00?ooooooogl0oomo00Oooooo0oooO`26oooooaGoo`009Oooool1o`00
007ooooo00000ol0003oooooooooo`0Wooooo`03ool00?oooooooooo00Cooooo0_ooO`0Nooooo`03
ool00?oooooooooo00Oooooo1?ooO`25oooooaGoo`009Oooool1o`00007ooooo00000ol0003ooooo
ooooo`0Xooooo`03ool00?oooooooooo02Cooooo00?oo`00ooooooooool01_ooool4oomo08Gooooo
5Ooo000Uooooo`7o00000Oooool00003o`000?oooooooooo02Wooooo00?oo`00ooooooooool09?oo
ool2ool00003ooooooooO`3oogl000Cooooo0_ooO`26oooooaGoo`009Oooool1o`00007ooooo0000
0ol0003oooooooooo`0Zooooo`03ool00?oooooooooo01?ooooo1?oo000>ooooo`04ool00?ooO`3o
ogl0oomo08_ooooo5Ooo000Uooooo`7o00000Oooool00003o`000?oooooooooo02_ooooo00?oo`00
ooooooooool04Oooool6ool000gooooo00Coogl0ool00?oo003oogl0RooooolEool002Gooooo0Ol0
0001ooooo`0000?o0000ooooooooool0;?ooool00ooo003oooooooooo`08ooooo`;oogl01Oooool8
ool000gooooo0_ooO`000ooo003oooooooooo`29oooooaGoo`009Oooool1o`00007ooooo00000ol0
003oooooooooo`0]ooooo`03ool00?oooooooooo00Kooooo1?ooO`04ooooo`Soo`004?ooool00ooo
003oooooooooo`28oooooaGoo`009Oooool1o`00007ooooo00000ol0003oooooooooo`0[ooooo`;o
ogl000?oooooool00?ooool01_ooool4oomo00Cooooo2?oo000Aooooo`03ool00?oooooooooo08Oo
oooo5Ooo000Uooooo`7o00000Oooool00003o`000?oooooooooo02[ooooo1?ooO`000oooooooo`00
ooooo`06ooooo`;oogl01Oooool8ool000_ooooo0_ooO`05ooooo`03ool00?oooooooooo00Wooooo
0_ooO`1koooooaGoo`009Oooool1o`00007ooooo00000ol0003oooooooooo`0Zooooo`Coogl00_oo
ool00ooo003oooooooooo`0<ooooo`Koo`002oooool4oomo00Cooooo00?oo`00ooooooooool02?oo
ool4oomo07[ooooo5Ooo000Uooooo`7o00000Oooool00003o`000?oooooooooo02_ooooo0_ooO`04
ooooo`03ool00?oooooooooo00cooooo1?oo000<ooooo`Coogl01Oooool00ooo003oooooooooo`07
ooooo`Coogl0N_oooolEool002Gooooo0Ol00001ooooo`0000?o0000ooooooooool0<_ooool2ool0
01gooooo0_ooO`07ooooo`03ool00?oooooooooo00Oooooo0_ooO`2eooooo`7o00000Oooool00003
o`000?oooooooooo03Cooooo00?oo`00ooooooooool09?ooool00ooo003oooooooooo`2mooooo`7o
00000Oooool00003o`000?oooooooooo03Gooooo00?oo`00ooooooooool09?ooool00ooo003ooooo
ooooo`2looooo`7o00000Oooool00003o`000?oooooooooo03Kooooo0_oo000Uooooo`03ool00?oo
oooooooo0;_ooooo0Ol00001ooooo`0000?o0000ooooooooool0>?ooool2ool00003oomo0?oooooo
oooo00;oogl07_ooool00ooo003oooooooooo`2kooooo`7o00000Oooool00003o`000?oooooooooo
03Sooooo0_ooO`02ool000Coogl07_ooool00ooo003oooooooooo`2jooooo`7o00000Oooool00003
o`000?oooooooooo03Sooooo1?ooO`02ool000;oogl07_ooool00ooo003oooooooooo`2jooooo`7o
00000Oooool00003o`000?oooooooooo03Wooooo1OooO`000ooo003oooooooooo`0Mooooo`03ool0
0?ooO`3oogl00;[ooooo0Ol00001ooooo`0000?o0000ooooooooool0>oooool4oomo00;oo`007Ooo
ool01?ooO`3oo`00oomo0?ooO`2iooooo`7o00000Oooool00003o`000?oooooooooo03cooooo0_oo
O`03ooooo`;oo`006oooool01?ooO`3oo`00oomo0?ooO`2iooooo`7o00000Oooool00003o`000?oo
oooooooo04?ooooo0_oo000Jooooo`03oomo0?oo003ooooo0;Wooooo0Ol00001ooooo`0000?o0000
ooooooooool0AOooool2ool001Wooooo00?oo`00ooooooooool0^?ooool1o`00007ooooo00000ol0
003oooooooooo`17ooooo`;oo`005Oooool2ool00;_ooooo0Ol00001ooooo`0000?o0000oooooooo
ool0BOooool3ool0013ooooo0_oo002mooooo`7o00000Oooool00003o`000?oooooooooo037ooooo
0_ooO`0Iooooo`?oo`003?ooool00ooo003oooooooooo`2mooooo`7o00000Oooool00003o`000?oo
oooooooo033ooooo1?ooO`0Kooooo`Koo`001?ooool2ool00<3ooooo0Ol00001ooooo`0000?o0000
ooooooooool0<?ooool4oomo027ooooo1?oo0032ooooo`7o00000Oooool00003o`000?oooooooooo
037ooooo0_ooO`3Xooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007o
oooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooo
oolLooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0
003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0OOooool2oomo09co
oooo0Ol00001ooooo`0000?o0000ooooooooool0O?ooool4oomo09_ooooo0Ol00001ooooo`0000?o
0000ooooooooool0E?ooool2oomo02Kooooo1?ooO`2Kooooo`7o00000Oooool00003o`000?oooooo
oooo05?ooooo1?ooO`0Vooooo`;oogl0W?ooool1o`00007ooooo00000ol0003oooooooooo`1Coooo
o`Coogl0a?ooool1o`00007ooooo00000ol0003oooooooooo`1Dooooo`;oogl0aOooool1o`00007o
oooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0Hooo
ool2oomo00Cooooo0_ooO`2`ooooo`7o00000Oooool00003o`000?oooooooooo06;ooooo1?ooO`02
ooooo`Coogl0[oooool1o`00007ooooo00000ol0003oooooooooo`1Rooooo`Coogl00_ooool4oomo
0:oooooo0Ol00001ooooo`0000?o0000ooooooooool0Hoooool2oomo00Cooooo0_ooO`2`ooooo`7o
00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003ooooooooo
o`3ooooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool0
0003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooooaco
oooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oo
oooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001
ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo0?oo
oooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o
0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1
o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000oooooooo
ool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo
00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolL
ooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003o
ooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o0000
0Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3o
oooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003
o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo
0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oooooo
oooo0?oooooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001oooo
o`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo
7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000
ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo1?ooool2oomo
01Kooooo0Ol00001ooooo`0000?o0000ooooooooool0ooooool3ooooo`Coogl05Oooool1o`00007o
oooo00000ol0003oooooooooo`3oooooo`?ooooo1?ooO`0Eooooo`7o00000Oooool00003o`000?oo
oooooooo0?oooooo1?ooool2oomo01Kooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolL
ooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003o
ooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o0000
0Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3o
oooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003
o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo
0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oooooo
oooo0;Gooooo0_ooO`1Tooooo`7o00000Oooool00003o`000?oooooooooo0;Cooooo1?ooO`1Soooo
o`7o00000Oooool00003o`000?oooooooooo0;Cooooo1?ooO`1Sooooo`7o00000Oooool00003o`00
0?oooooooooo0;Gooooo0_ooO`0eooooo`;oogl0;Oooool1o`00007ooooo00000ol0003ooooooooo
o`3Tooooo`;oogl01Oooool4oomo02cooooo0Ol00001ooooo`0000?o0000ooooooooool0hoooool4
oomo00Cooooo1?ooO`0/ooooo`7o00000Oooool00003o`000?oooooooooo0<?ooooo0_ooO`0Noooo
o`Coogl01Oooool2oomo02gooooo0Ol00001ooooo`0000?o0000ooooooooool0`_ooool4oomo00_o
003o4oooool2oomo03Gooooo0Ol00001ooooo`0000?o0000ooooooooool0`_ooool4o`00o`_ooooo
0_l00?m8ooooo`7o00000Oooool00003o`000?oooooooooo0;kooooo1?l00?l00oooooooogl0oomo
000>ooooo`;o003oA_ooool1o`00007ooooo00000ol0003oooooooooo`2iooooo`;oogl00ol00?lG
ooooo`;o003o2Oooool2oomo03Wooooo0Ol00001ooooo`0000?o0000ooooooooool0]oooool4o`00
o`03oomo0?oooooooooo01Wooooo0_l00?l6ooooo`Coogl0>?ooool1o`00007ooooo00000ol0003o
ooooooooo`2dooooo`?o003o00?ooooooomo0?ooO`000_ooO`0Looooo`03o`00oooooooooooo00Co
oooo1?ooO`03ooooo`;oogl0<oooool1o`00007ooooo00000ol0003oooooooooo`2booooo`;o003o
0oooO`02ooooo`;oogl04oooool2oomo00Sooooo00?o003oooooooooool01Oooool2oomo00?ooooo
1?ooO`0booooo`7o00000Oooool00003o`000?oooooooooo0;3ooooo0_l00?l00oooooooogl0oomo
0002oomo00Kooooo0_ooO`0>ooooo`Coogl01oooool00ol00?ooooooooooo`0:ooooo`Coogl0<_oo
ool1o`00007ooooo00000ol0003oooooooooo`2^ooooo`;o003o1?ooool2oomo00Kooooo1?ooO`0=
ooooo`Coogl01oooool00ol00?ooooooooooo`0;ooooo`;oogl0<oooool1o`00007ooooo00000ol0
003oooooooooo`2;ooooo`;oogl08?ooool00ol00?ooooooooooo`04ooooo`;oogl01_ooool4oomo
00kooooo0_ooO`09ooooo`03o`00oooooooooooo03oooooo0Ol00001ooooo`0000?o0000oooooooo
ool0R_ooool4oomo01gooooo0_l00?l6ooooo`Coogl01_ooool2oomo01[ooooo00?o003ooooooooo
ool0?oooool1o`00007ooooo00000ol0003oooooooooo`2:ooooo`Coogl07?ooool00ol00?oooooo
ooooo`06ooooo`Coogl08_ooool00ol00?ooooooooooo`0oooooo`7o00000Oooool00003o`000?oo
oooooooo08_ooooo0_ooO`0Kooooo`;o003o2_ooool2oomo02?ooooo00?o003oooooooooool0?ooo
ool1o`00007ooooo00000ol0003oooooooooo`2Fooooo`;oogl03_ooool2o`00ob[ooooo0_ooO`05
ooooo`03o`00oooooooooooo03oooooo0Ol00001ooooo`0000?o0000ooooooooool0UOooool4oomo
00cooooo00Co003oooooooooO`3oogl0:?ooool4oomo00?ooooo00?o003oooooooooool0@?ooool1
o`00007ooooo00000ol0003oooooooooo`2Eooooo`Coogl02_ooool2o`00o`03ooooooooO`3oogl0
00;oogl09oooool4oomo00?ooooo00?o003oooooooooool0@?ooool1o`00007ooooo00000ol0003o
ooooooooo`2Fooooo`;oogl02_ooool01?l00?ooooooooooooooool4oomo02Sooooo0_ooO`04oooo
o`03o`00oooooooooooo043ooooo0Ol00001ooooo`0000?o0000ooooooooool0XOooool00ol00?oo
ooooooooo`03ooooo`;oogl0;_ooool00ol00?ooooooooooo`11ooooo`7o00000Oooool00003o`00
0?oooooooooo0:3ooooo00?o003oooooooooool0<oooool00ol00?ooooooooooo`0Booooo`;oogl0
;_ooool1o`00007ooooo00000ol0003oooooooooo`2Nooooo`;o003o=Oooool00ol00?oooooooooo
o`0Booooo`Coogl0;Oooool1o`00007ooooo00000ol0003oooooooooo`2Mooooo`03o`00oooooooo
oooo01Gooooo1?l00?lLooooo`03o`00ooooO`3oogl001;ooooo1?ooO`0]ooooo`7o00000Oooool0
0003o`000?oooooooooo09cooooo00?o003oooooooooool05Oooool6o`00oa[ooooo00?o003ooomo
0?ooO`000_ooO`0Booooo`;oogl0;_ooool1o`00007ooooo00000ol0003oooooooooo`2Kooooo`03
o`00oooooooooooo01Gooooo2?l00?lHooooo`03o`00ooooooooogl000?oogl0@_ooool1o`00007o
oooo00000ol0003oooooooooo`2Kooooo`03o`00oooooooooooo01Gooooo2?l00?lGooooo`04o`00
ooooooooooooooooo`;oogl0@oooool1o`00007ooooo00000ol0003oooooooooo`2Jooooo`03o`00
oooooooooooo01Kooooo2?l00?lFooooo`03o`00oooooooooooo04Oooooo0Ol00001ooooo`0000?o
0000ooooooooool0VOooool00ol00?ooooooooooo`0<ooooo`;oogl02?ooool00oooO`3o003oo`00
o`06o`00oaGooooo00?o003oooooooooool00_ooO`16ooooo`7o00000Oooool00003o`000?oooooo
oooo09Wooooo00?o003oooooooooool02_ooool5oomo00Oooooo0_ooO`06o`00oa?ooooo0_ooO`00
0ol00?ooooooooooo`04oomo04Gooooo0Ol00001ooooo`0000?o0000ooooooooool0V?ooool00ol0
0?ooooooooooo`0:ooooo`Koogl02?ooool2oomo00Co003o4oooool2oomo00;o003o0_ooool4oomo
04Gooooo0Ol00001ooooo`0000?o0000ooooooooool0V?ooool00ol00?ooooooooooo`0:ooooo`Go
ogl08_ooool01?ooO`3o003ooomo0?ooO`03ooooo`;oogl0A_ooool1o`00007ooooo00000ol0003o
ooooooooo`1fooooo`;oogl07oooool00ol00?ooooooooooo`0<ooooo`;oogl09?ooool00ol00?oo
ogl0oomo001<ooooo`7o00000Oooool00003o`000?oooooooooo07Gooooo1?ooO`0Nooooo`03o`00
oooooooooooo037ooooo00?o003oooooooooool0COooool1o`00007ooooo00000ol0003ooooooooo
o`1eooooo`Coogl02_ooool2oomo017ooooo00?o003oooooooooool0<Oooool00ol00?oooooooooo
o`1>ooooo`7o00000Oooool00003o`000?oooooooooo07Kooooo0_ooO`0:ooooo`Coogl03oooool0
0ol00?ooooooooooo`0Hooooo`;oogl05oooool00ol00?ooooooooooo`1?ooooo`7o00000Oooool0
0003o`000?oooooooooo08;ooooo1?ooO`0?ooooo`03o`00oooooooooooo01Oooooo1?ooO`0Doooo
o`;o003oD_ooool1o`00007ooooo00000ol0003oooooooooo`23ooooo`;oogl03oooool00ol00?oo
ooooooooo`0Booooo`;oogl01?ooool4oomo017ooooo0ol00?mDooooo`7o00000Oooool00003o`00
0?oooooooooo09Cooooo00?o003oooooooooool04Oooool4oomo00Cooooo0_ooO`0@ooooo`;o003o
Eoooool1o`00007ooooo00000ol0003oooooooooo`2Dooooo`03o`00oooooooooooo017ooooo1?oo
O`0Eooooo`03o`00oooooooooooo05Oooooo0Ol00001ooooo`0000?o0000ooooooooool0U?ooool0
0ol00?ooooooooooo`0Booooo`;oogl05?ooool2o`00oe[ooooo0Ol00001ooooo`0000?o0000oooo
ooooool0U?ooool00ol00?ooooooooooo`0Vooooo`;o003oG?ooool1o`00007ooooo00000ol0003o
ooooooooo`2Eooooo`03o`00oooooooooooo02Cooooo00?o003oooooooooool0G?ooool1o`00007o
oooo00000ol0003oooooooooo`2Eooooo`03o`00oooooooooooo02;ooooo0_l00?mOooooo`7o0000
0Oooool00003o`000?oooooooooo09Gooooo00?o003oooooooooool08?ooool2o`00of7ooooo0Ol0
0001ooooo`0000?o0000ooooooooool0Q?ooool2oomo00oooooo0_l00?lOooooo`;o003oHoooool1
o`00007ooooo00000ol0003oooooooooo`23ooooo`Coogl04?ooool2o`00oa[ooooo0ol00?mUoooo
o`7o00000Oooool00003o`000?oooooooooo08?ooooo1?ooO`0Booooo`;o003o5?ooool4o`00ofSo
oooo0Ol00001ooooo`0000?o0000ooooooooool0Q?ooool2oomo01Gooooo0ol00?l>ooooo`?o003o
0oooool2oomo06Oooooo0Ol00001ooooo`0000?o0000ooooooooool0W_ooool3o`00o`Gooooo1_l0
0?l5ooooo`Coogl0I_ooool1o`00007ooooo00000ol0003oooooooooo`2Qooooo`Go003o2oooool4
oomo06Kooooo0Ol00001ooooo`0000?o0000ooooooooool0/_ooool2oomo06Oooooo0Ol00001oooo
o`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo
7?ooool1o`00007ooooo00000ol0003oooooooooo`1kooooo`;oogl0W_ooool1o`00007ooooo0000
0ol0003oooooooooo`1jooooo`Coogl0WOooool1o`00007ooooo00000ol0003oooooooooo`1joooo
o`Coogl08?ooool2oomo07_ooooo0Ol00001ooooo`0000?o0000ooooooooool0Noooool2oomo023o
oooo1?ooO`1jooooo`7o00000Oooool00003o`000?oooooooooo09gooooo1?ooO`1jooooo`7o0000
0Oooool00003o`000?oooooooooo093ooooo0_ooO`0<ooooo`;oogl0Noooool1o`00007ooooo0000
0ol0003oooooooooo`2?ooooo`Coogl0R?ooool1o`00007ooooo00000ol0003oooooooooo`2?oooo
o`Coogl0R?ooool1o`00007ooooo00000ol0003oooooooooo`2@ooooo`;oogl08oooool2oomo06Co
oooo0Ol00001ooooo`0000?o0000ooooooooool0]?ooool4oomo06?ooooo0Ol00001ooooo`0000?o
0000ooooooooool0]?ooool4oomo06?ooooo0Ol00001ooooo`0000?o0000ooooooooool0]Oooool2
oomo06Cooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003
o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo
0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oooooo
oooo0?oooooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001oooo
o`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo
7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000
ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00
007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0
oooooolLooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo0000
0ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLoooo
o`7o00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003ooooo
ooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Ooo
ool00003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooo
oacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`00
0?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol0
0001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo
0?oooooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`00
00?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?oo
ool1o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000oooo
ooooool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007o
oooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooo
oolLooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0
003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o
00000Oooool00003o`000?oooooooooo08kooooo0_ooO`2;ooooo`7o00000Oooool00003o`000?oo
oooooooo08gooooo1?ooO`2:ooooo`7o00000Oooool00003o`000?oooooooooo08gooooo1?ooO`2:
ooooo`7o00000Oooool00003o`000?oooooooooo08kooooo0_ooO`2;ooooo`7o00000Oooool00003
o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo
0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oooooo
oooo0?oooooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001oooo
o`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo
7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000
ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00
007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0
oooooolLooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo0000
0ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLoooo
o`7o00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003ooooo
ooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Ooo
ool00003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooo
oacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool00?oo0000
8?l00001ooooo`00\
\>"],
  ImageRangeCache->{{{0, 287}, {287, 0}} -> {-1.01089, -1.01089, 0.00704453, \
0.00704453}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.49505 0.5 0.49505 [
[ 0 0 -0.125 0 ]
[ 0 0 -0.125 0 ]
[ 0 1 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
0 0 m
1 0 L
s
0 0 m
0 1 L
s
0 1 m
1 1 L
s
1 0 m
1 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
1 .5 0 r
.015 w
.03175 .1355 Mdot
.03435 .12523 Mdot
.11137 .12765 Mdot
.14107 .18841 Mdot
.16218 .24538 Mdot
.17294 .21053 Mdot
.18267 .18577 Mdot
.18434 .1304 Mdot
.18553 .30956 Mdot
.20401 .239 Mdot
.21247 .27571 Mdot
.21687 .20845 Mdot
.22376 .2799 Mdot
.22832 .27485 Mdot
.29063 .20974 Mdot
.29686 .25079 Mdot
.30487 .22936 Mdot
.30683 .34623 Mdot
.32055 .20902 Mdot
.32574 .21979 Mdot
.34472 .28521 Mdot
.35998 .36393 Mdot
.36335 .24976 Mdot
.3794 .36608 Mdot
.42386 .66992 Mdot
.44391 .74519 Mdot
.45059 .34198 Mdot
.47208 .67586 Mdot
.47436 .71381 Mdot
.49778 .59825 Mdot
.50874 .91643 Mdot
.51516 .76219 Mdot
.53655 .61374 Mdot
.56563 .75219 Mdot
.59189 .65665 Mdot
.59581 .61604 Mdot
.59923 .6556 Mdot
.60292 .68499 Mdot
.62656 .67779 Mdot
.63555 .72451 Mdot
.63919 .652 Mdot
.64169 .6004 Mdot
.64246 .58611 Mdot
.64496 .54267 Mdot
.64608 .77288 Mdot
.65077 .64308 Mdot
.66065 .57816 Mdot
.67474 .59169 Mdot
.69296 .563 Mdot
.72815 .65902 Mdot
.73169 .58879 Mdot
.74669 .61318 Mdot
.74821 .65474 Mdot
.75963 .63781 Mdot
.79673 .57809 Mdot
.80925 .55852 Mdot
.81525 .58444 Mdot
.83417 .62985 Mdot
.83598 .55526 Mdot
.91595 .49319 Mdot
1 0 0 r
.005 w
.16128 .17044 m
.18734 .17269 L
.21339 .17909 L
.2345 .18734 L
.23945 .19126 L
.2655 .20415 L
.27874 .21339 L
.29156 .22295 L
.31204 .23945 L
.31761 .24532 L
.33549 .2655 L
.34367 .28341 L
.34499 .29156 L
.34367 .29798 L
.31761 .3104 L
.29156 .30711 L
.2655 .30014 L
.24507 .29156 L
.23945 .28747 L
.21339 .27402 L
.20155 .2655 L
.18734 .25472 L
.16884 .23945 L
.16128 .2313 L
.14618 .21339 L
.13806 .18734 L
.16128 .17044 L
s
0 0 1 r
.65633 .57701 m
.68239 .56842 L
.70844 .56313 L
.7345 .56168 L
.76055 .5752 L
.76359 .57817 L
.76859 .60422 L
.76055 .62333 L
.75627 .63028 L
.7345 .65485 L
.73298 .65633 L
.70844 .6775 L
.69922 .68239 L
.68239 .69294 L
.65633 .70579 L
.64983 .70844 L
.63028 .71539 L
.60422 .72268 L
.57817 .72651 L
.55211 .7214 L
.53145 .70844 L
.52926 .68239 L
.54239 .65633 L
.55211 .63983 L
.56625 .63028 L
.57817 .6193 L
.60119 .60422 L
.60422 .60227 L
.63028 .58726 L
.65315 .57817 L
.65633 .57701 L
s
1 0 0 r
.03 w
.24141 .24033 Mdot
0 0 1 r
.64872 .64417 Mdot
1 0 0 r
.79703 .00495 m
.79703 .25248 L
.87129 .25248 L
.87129 .00495 L
F
0 0 1 r
.89604 .00495 m
.89604 .00495 L
.9703 .00495 L
.9703 .00495 L
F
1 0 1 r
.04 w
.16218 .24538 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P000182000`400?l00000o`00003ooooooolQ
ooooo`00ool0000Po`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`00
00?o0000ooooooooool0hOoooolEool002Gooooo0Ol00001ooooo`0000?o0000ooooooooool0hOoo
oolEool002Gooooo0Ol00001ooooo`0000?o0000ooooooooool0hOoooolEool002Gooooo0Ol00001
ooooo`0000?o0000ooooooooool0hOoooolEool002Gooooo0Ol00001ooooo`0000?o0000oooooooo
ool0hOoooolEool002Gooooo0Ol00001ooooo`0000?o0000ooooooooool0hOoooolEool002Gooooo
0Ol00001ooooo`0000?o0000ooooooooool0hOoooolEool002Gooooo0Ol00001ooooo`0000?o0000
ooooooooool0hOoooolEool002Gooooo0Ol00001ooooo`0000?o0000ooooooooool0hOoooolEool0
02Gooooo0Ol00001ooooo`0000?o0000ooooooooool0hOoooolEool002Gooooo0Ol00001ooooo`00
00?o0000ooooooooool0hOoooolEool002Gooooo0Ol00001ooooo`0000?o0000ooooooooool0hOoo
oolEool002Gooooo0Ol00001ooooo`0000?o0000ooooooooool0hOoooolEool002Gooooo0Ol00001
ooooo`0000?o0000ooooooooool0hOoooolEool002Gooooo0Ol00001ooooo`0000?o0000oooooooo
ool0hOoooolEool002Gooooo0Ol00001ooooo`0000?o0000ooooooooool0hOoooolEool002Gooooo
0Ol00001ooooo`0000?o0000ooooooooool0hOoooolEool002Gooooo0Ol00001ooooo`0000?o0000
ooooooooool0hOoooolEool002Gooooo0Ol00001ooooo`0000?o0000ooooooooool0hOoooolEool0
02Gooooo0Ol00001ooooo`0000?o0000ooooooooool0hOoooolEool002Gooooo0Ol00001ooooo`00
00?o0000ooooooooool0hOoooolEool002Gooooo0Ol00001ooooo`0000?o0000ooooooooool0hOoo
oolEool002Gooooo0Ol00001ooooo`0000?o0000ooooooooool0hOoooolEool002Gooooo0Ol00001
ooooo`0000?o0000ooooooooool0hOoooolEool002Gooooo0Ol00001ooooo`0000?o0000oooooooo
ool0hOoooolEool002Gooooo0Ol00001ooooo`0000?o0000ooooooooool0hOoooolEool002Gooooo
0Ol00001ooooo`0000?o0000ooooooooool0hOoooolEool002Gooooo0Ol00001ooooo`0000?o0000
ooooooooool0hOoooolEool002Gooooo0Ol00001ooooo`0000?o0000ooooooooool0hOoooolEool0
02Gooooo0Ol00001ooooo`0000?o0000ooooooooool0hOoooolEool002Gooooo0Ol00001ooooo`00
00?o0000ooooooooool0hOoooolEool002Gooooo0Ol00001ooooo`0000?o0000ooooooooool0hOoo
oolEool002Gooooo0Ol00001ooooo`0000?o0000ooooooooool01_ooool2oomo0=Wooooo5Ooo000U
ooooo`7o00000Oooool00003o`000?oooooooooo00Gooooo1?ooO`0Cooooo`;oogl0`ooooolEool0
02Gooooo0Ol00001ooooo`0000?o0000ooooooooool01Oooool4oomo01;ooooo1?ooO`0Booooo`;o
ogl0[_oooolEool002Gooooo0Ol00001ooooo`0000?o0000ooooooooool01Oooool3oomo01?ooooo
1?ooO`0Aooooo`Coogl0[OoooolEool002Gooooo0Ol00001ooooo`0000?o0000ooooooooool01?oo
ool4oomo01Cooooo0_ooO`0Booooo`Coogl0[OoooolEool002Gooooo0Ol00001ooooo`0000?o0000
ooooooooool01?ooool4oomo02Wooooo0_ooO`2^oooooaGoo`009Oooool1o`00007ooooo00000ol0
003oooooooooo`05ooooo`;oogl0f_oooolEool002Gooooo0Ol00001ooooo`0000?o0000oooooooo
ool0hOoooolEool002Gooooo0Ol00001ooooo`0000?o0000ooooooooool0hOoooolEool002Gooooo
0Ol00001ooooo`0000?o0000ooooooooool0hOoooolEool002Gooooo0Ol00001ooooo`0000?o0000
ooooooooool0hOoooolEool002Gooooo0Ol00001ooooo`0000?o0000ooooooooool0hOoooolEool0
02Gooooo0Ol00001ooooo`0000?o0000ooooooooool0hOoooolEool002Gooooo0Ol00001ooooo`00
00?o0000ooooooooool0hOoooolEool002Gooooo0Ol00001ooooo`0000?o0000ooooooooool0:_oo
ool6ool00;7ooooo5Ooo000Uooooo`7o00000Oooool00003o`000?oooooooooo02Wooooo00?oo`00
ooooooooool01?ooool5ool00:cooooo5Ooo000Uooooo`7o00000Oooool00003o`000?oooooooooo
02Oooooo0_oo000<ooooo`Coo`00Z?oooolEool002Gooooo0Ol00001ooooo`0000?o0000oooooooo
ool09_ooool00ooo003oooooooooo`0@ooooo`Coo`00Y?oooolEool002Gooooo0Ol00001ooooo`00
00?o0000ooooooooool09?ooool00oooO`3oo`00ooooo`09ooooo`;oogl02oooool3ool00:7ooooo
5Ooo000Uooooo`7o00000Oooool00003o`000?oooooooooo02?ooooo00Coogl0ool00?ooO`3oogl0
2?ooool4oomo00gooooo00?oo`00ooooooooool0W_oooolEool002Gooooo0Ol00001ooooo`0000?o
0000ooooooooool08oooool01?ooO`3oo`00oomo0?ooO`08ooooo`Coogl03_ooool2ool009kooooo
5Ooo000Uooooo`7o00000Oooool00003o`000?oooooooooo02Cooooo00?oogl0ool00?ooool02Ooo
ool2oomo017ooooo0_oo002LoooooaGoo`009Oooool1o`00007ooooo00000ol0003oooooooooo`0U
ooooo`03ool00?oooooooooo01gooooo0_oo002JoooooaGoo`009Oooool1o`00007ooooo00000ol0
003oooooooooo`0Uooooo`03ool00?oooooooooo01oooooo0_oo002HoooooaGoo`009Oooool1o`00
007ooooo00000ol0003oooooooooo`0Vooooo`03ool00?oooooooooo017ooooo0_ooO`0=ooooo`;o
o`001?ooool2oomo00Oooooo0_ooO`27oooooaGoo`009Oooool1o`00007ooooo00000ol0003ooooo
ooooo`0Vooooo`03ool00?oooooooooo00Gooooo0_ooO`09ooooo`Coogl03_ooool00ooo003ooooo
ooooo`04oomo00Gooooo1?ooO`26oooooaGoo`009Oooool1o`00007ooooo00000ol0003ooooooooo
o`0Vooooo`03ool00?oooooooooo00Cooooo1?ooO`08ooooo`Coogl03oooool00ooo003ooooooomo
0003oomo00Gooooo1?ooO`26oooooaGoo`009Oooool1o`00007ooooo00000ol0003oooooooooo`0W
ooooo`03ool00?oooooooooo00?ooooo1?ooO`09ooooo`;oogl04Oooool01?oo003ooooooomo0?oo
O`07ooooo`?oogl0Q_oooolEool002Gooooo0Ol00001ooooo`0000?o0000ooooooooool09oooool0
0ooo003oooooooooo`04ooooo`;oogl07_ooool00ooo003oooooooooo`07ooooo`Coogl0QOoooolE
ool002Gooooo0Ol00001ooooo`0000?o0000ooooooooool0:?ooool00ooo003oooooooooo`0Toooo
o`03ool00?oooooooooo00Kooooo1?ooO`25oooooaGoo`009Oooool1o`00007ooooo00000ol0003o
ooooooooo`0Yooooo`03ool00?oooooooooo02Cooooo0_oo00000oooooooogl0oomo0004ooooo`;o
ogl0Q_oooolEool002Gooooo0Ol00001ooooo`0000?o0000ooooooooool0:Oooool5ool0oa;ooooo
1?oo000>ooooo`04ool00?ooO`3oogl0oomo08_ooooo5Ooo000Uooooo`7o00000Oooool00003o`00
0?oooooooooo02Sooooo1ooo0?l@ooooo`Koo`003Oooool01?ooO`3oo`00ool00?ooO`2;oooooaGo
o`009Oooool1o`00007ooooo00000ol0003oooooooooo`0Wooooo`Woo`3o1oooool2oomo00Gooooo
2?oo000=ooooo`;oogl000?oo`00ooooooooool0ROoooolEool002Gooooo0Ol00001ooooo`0000?o
0000ooooooooool09_ooool;ool0o`Gooooo1?ooO`04ooooo`Soo`004?ooool00ooo003ooooooooo
o`28oooooaGoo`009Oooool1o`00007ooooo00000ol0003oooooooooo`0Vooooo`_oo`3o1Oooool4
oomo00Cooooo2?oo000Aooooo`03ool00?oooooooooo08Oooooo5Ooo000Uooooo`7o00000Oooool0
0003o`000?oooooooooo02Kooooo2ooo0?l6ooooo`;oogl01Oooool8ool000_ooooo0_ooO`05oooo
o`03ool00?oooooooooo00Wooooo0_ooO`1koooooaGoo`009Oooool1o`00007ooooo00000ol0003o
ooooooooo`0Vooooo`_oo`3o3_ooool6ool000_ooooo1?ooO`04ooooo`03ool00?oooooooooo00So
oooo1?ooO`1joooooaGoo`009Oooool1o`00007ooooo00000ol0003oooooooooo`0Vooooo`_oo`3o
00?oo`00ooooooooool03?ooool4ool000cooooo1?ooO`05ooooo`03ool00?oooooooooo00Oooooo
1?ooO`1joooooaGoo`009Oooool1o`00007ooooo00000ol0003oooooooooo`0Wooooo`Woo`3o0_oo
ool2ool001gooooo0_ooO`07ooooo`03ool00?oooooooooo00Oooooo0_ooO`2eooooo`7o00000Ooo
ool00003o`000?oooooooooo02Sooooo1ooo0?l5ooooo`03ool00?oooooooooo02Cooooo00?oo`00
ooooooooool0_Oooool1o`00007ooooo00000ol0003oooooooooo`0Yooooo`Goo`3o1oooool00ooo
003oooooooooo`0Tooooo`03ool00?oooooooooo0;cooooo0Ol00001ooooo`0000?o0000oooooooo
ool0=_ooool2ool002Gooooo00?oo`00ooooooooool0^oooool1o`00007ooooo00000ol0003ooooo
ooooo`0hooooo`;oo`0000?oogl0ooooooooool00_ooO`0Nooooo`03ool00?oooooooooo0;_ooooo
0Ol00001ooooo`0000?o0000ooooooooool0>?ooool2oomo00;oo`001?ooO`0Nooooo`03ool00?oo
oooooooo0;[ooooo0Ol00001ooooo`0000?o0000ooooooooool0>?ooool4oomo00;oo`000_ooO`0N
ooooo`03ool00?oooooooooo0;[ooooo0Ol00001ooooo`0000?o0000ooooooooool0>Oooool5oomo
0003ool00?oooooooooo01gooooo00?oo`00oomo0?ooO`00^_ooool1o`00007ooooo00000ol0003o
ooooooooo`0kooooo`Coogl00_oo000Mooooo`04oomo0?oo003oogl0oomo0;Wooooo0Ol00001oooo
o`0000?o0000ooooooooool0??ooool2oomo00?ooooo0_oo000Kooooo`04oomo0?oo003oogl0oomo
0;Wooooo0Ol00001ooooo`0000?o0000ooooooooool0@oooool2ool001[ooooo00?oogl0ool00?oo
ool0^Oooool1o`00007ooooo00000ol0003oooooooooo`15ooooo`;oo`006Oooool00ooo003ooooo
ooooo`2hooooo`7o00000Oooool00003o`000?oooooooooo04Oooooo0_oo000Eooooo`;oo`00^ooo
ool1o`00007ooooo00000ol0003oooooooooo`19ooooo`?oo`004?ooool2ool00;gooooo0Ol00001
ooooo`0000?o0000ooooooooool0<Oooool2oomo01Wooooo0ooo000<ooooo`03ool00?oooooooooo
0;gooooo0Ol00001ooooo`0000?o0000ooooooooool0<?ooool4oomo01_ooooo1_oo0004ooooo`;o
o`00`?ooool1o`00007ooooo00000ol0003oooooooooo`0`ooooo`Coogl08Oooool4ool00<;ooooo
0Ol00001ooooo`0000?o0000ooooooooool0<Oooool2oomo0>Sooooo0Ol00001ooooo`0000?o0000
ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00
007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0
oooooolLooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo0000
0ol0003oooooooooo`1mooooo`;oogl0W?ooool1o`00007ooooo00000ol0003oooooooooo`1loooo
o`Coogl0Voooool1o`00007ooooo00000ol0003oooooooooo`1Dooooo`;oogl09_ooool4oomo09_o
oooo0Ol00001ooooo`0000?o0000ooooooooool0Doooool4oomo02Kooooo0_ooO`2Looooo`7o0000
0Oooool00003o`000?oooooooooo05?ooooo1?ooO`34ooooo`7o00000Oooool00003o`000?oooooo
oooo05Cooooo0_ooO`35ooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00
007ooooo00000ol0003oooooooooo`1Sooooo`;oogl01?ooool2oomo0;3ooooo0Ol00001ooooo`00
00?o0000ooooooooool0H_ooool4oomo00;ooooo1?ooO`2_ooooo`7o00000Oooool00003o`000?oo
oooooooo06;ooooo1?ooO`02ooooo`Coogl0[oooool1o`00007ooooo00000ol0003oooooooooo`1S
ooooo`;oogl01?ooool2oomo0;3ooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLoooo
o`7o00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003ooooo
ooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Ooo
ool00003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooo
oacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`00
0?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol0
0001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo
0?oooooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`00
00?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?oo
ool1o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000oooo
ooooool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007o
oooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooo
oolLooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0
003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o
00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003ooooooooo
o`3ooooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool0
0003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooooaco
oooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oo
oooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001
ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo0?oo
oooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o
0000ooooooooool0ooooool4ooooo`;oogl05_ooool1o`00007ooooo00000ol0003oooooooooo`3o
ooooo`?ooooo1?ooO`0Eooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo0oooool4oomo
01Gooooo0Ol00001ooooo`0000?o0000ooooooooool0ooooool4ooooo`;oogl05_ooool1o`00007o
oooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooo
oolLooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0
003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o
00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003ooooooooo
o`3ooooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool0
0003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooooaco
oooo0Ol00001ooooo`0000?o0000ooooooooool0]Oooool2oomo06Cooooo0Ol00001ooooo`0000?o
0000ooooooooool0]?ooool4oomo06?ooooo0Ol00001ooooo`0000?o0000ooooooooool0]?ooool4
oomo06?ooooo0Ol00001ooooo`0000?o0000ooooooooool0]Oooool2oomo03Gooooo0_ooO`0]oooo
o`7o00000Oooool00003o`000?oooooooooo0>Cooooo0_ooO`05ooooo`Coogl0;?ooool1o`00007o
oooo00000ol0003oooooooooo`3Sooooo`Coogl01?ooool4oomo02cooooo0Ol00001ooooo`0000?o
0000ooooooooool0`oooool2oomo01kooooo1?ooO`05ooooo`;oogl0;Oooool1o`00007ooooo0000
0ol0003oooooooooo`32ooooo`Coogl02ol00?lCooooo`;oogl0=Oooool1o`00007ooooo00000ol0
003oooooooooo`32ooooo`Co003o2oooool2o`00odSooooo0Ol00001ooooo`0000?o0000oooooooo
ool0__ooool4o`00o`03ooooooooO`3oogl000kooooo0_l00?m6ooooo`7o00000Oooool00003o`00
0?oooooooooo0;Wooooo0_ooO`03o`00oaOooooo0_l00?l9ooooo`;oogl0>Oooool1o`00007ooooo
00000ol0003oooooooooo`2gooooo`Co003o00?oogl0ooooooooool06Oooool2o`00o`Kooooo1?oo
O`0hooooo`7o00000Oooool00003o`000?oooooooooo0;Cooooo0ol00?l00oooooooogl0oomo0002
oomo01cooooo00?o003oooooooooool01?ooool4oomo00?ooooo0_ooO`0cooooo`7o00000Oooool0
0003o`000?oooooooooo0;;ooooo0_l00?l3oomo00;ooooo0_ooO`0Cooooo`;oogl02?ooool00ol0
0?ooooooooooo`05ooooo`;oogl00oooool4oomo03;ooooo0Ol00001ooooo`0000?o0000oooooooo
ool0/?ooool2o`00o`03ooooooooO`3oogl000;oogl01_ooool2oomo00kooooo1?ooO`07ooooo`03
o`00oooooooooooo00[ooooo1?ooO`0booooo`7o00000Oooool00003o`000?oooooooooo0:kooooo
0_l00?l4ooooo`;oogl01_ooool4oomo00gooooo1?ooO`07ooooo`03o`00oooooooooooo00_ooooo
0_ooO`0cooooo`7o00000Oooool00003o`000?oooooooooo08_ooooo0_ooO`0Pooooo`03o`00oooo
oooooooo00Cooooo0_ooO`06ooooo`Coogl03_ooool2oomo00Wooooo00?o003oooooooooool0?ooo
ool1o`00007ooooo00000ol0003oooooooooo`2:ooooo`Coogl07Oooool2o`00o`Kooooo1?ooO`06
ooooo`;oogl06_ooool00ol00?ooooooooooo`0oooooo`7o00000Oooool00003o`000?oooooooooo
08[ooooo1?ooO`0Looooo`03o`00oooooooooooo00Kooooo1?ooO`0Rooooo`03o`00oooooooooooo
03oooooo0Ol00001ooooo`0000?o0000ooooooooool0Roooool2oomo01_ooooo0_l00?l:ooooo`;o
ogl08oooool00ol00?ooooooooooo`0oooooo`7o00000Oooool00003o`000?oooooooooo09Kooooo
0_ooO`0>ooooo`;o003o:_ooool2oomo00Gooooo00?o003oooooooooool0?oooool1o`00007ooooo
00000ol0003oooooooooo`2Eooooo`Coogl03?ooool01?l00?oooooooomo0?ooO`0Xooooo`Coogl0
0oooool00ol00?ooooooooooo`10ooooo`7o00000Oooool00003o`000?oooooooooo09Gooooo1?oo
O`0:ooooo`;o003o00?ooooooomo0?ooO`000_ooO`0Wooooo`Coogl00oooool00ol00?oooooooooo
o`10ooooo`7o00000Oooool00003o`000?oooooooooo09Kooooo0_ooO`0:ooooo`04o`00oooooooo
ooooooooo`Coogl0:?ooool2oomo00Cooooo00?o003oooooooooool0@?ooool1o`00007ooooo0000
0ol0003oooooooooo`2Qooooo`03o`00oooooooooooo00?ooooo0_ooO`0^ooooo`03o`00oooooooo
oooo047ooooo0Ol00001ooooo`0000?o0000ooooooooool0X?ooool00ol00?ooooooooooo`0coooo
o`03o`00oooooooooooo01;ooooo0_ooO`0^ooooo`7o00000Oooool00003o`000?oooooooooo09ko
oooo0_l00?leooooo`03o`00oooooooooooo01;ooooo1?ooO`0]ooooo`7o00000Oooool00003o`00
0?oooooooooo09gooooo00?o003oooooooooool05Oooool4o`00oacooooo00?o003ooomo0?ooO`00
4_ooool4oomo02gooooo0Ol00001ooooo`0000?o0000ooooooooool0W?ooool00ol00?oooooooooo
o`0Eooooo`Ko003o6_ooool00ol00?ooogl0oomo0002oomo01;ooooo0_ooO`0^ooooo`7o00000Ooo
ool00003o`000?oooooooooo09_ooooo00?o003oooooooooool05Oooool8o`00oaSooooo00?o003o
ooooooooO`000oooO`12ooooo`7o00000Oooool00003o`000?oooooooooo09_ooooo00?o003ooooo
ooooool05Oooool8o`00oaOooooo00Co003ooooooooooooooooo0_ooO`13ooooo`7o00000Oooool0
0003o`000?oooooooooo09[ooooo00?o003oooooooooool05_ooool8o`00oaKooooo00?o003ooooo
ooooool0Aoooool1o`00007ooooo00000ol0003oooooooooo`2Iooooo`03o`00oooooooooooo00co
oooo0_ooO`08ooooo`03oomo0?l00?oo003o00Ko003o5Oooool00ol00?ooooooooooo`02oomo04Ko
oooo0Ol00001ooooo`0000?o0000ooooooooool0VOooool00ol00?ooooooooooo`0:ooooo`Googl0
1oooool2oomo00Ko003o4oooool2oomo0003o`00oooooooooooo00Coogl0AOooool1o`00007ooooo
00000ol0003oooooooooo`2Hooooo`03o`00oooooooooooo00[ooooo1_ooO`08ooooo`;oogl01?l0
0?lCooooo`;oogl00_l00?l2ooooo`Coogl0AOooool1o`00007ooooo00000ol0003oooooooooo`2H
ooooo`03o`00oooooooooooo00[ooooo1OooO`0Rooooo`04oomo0?l00?ooogl0oomo00?ooooo0_oo
O`16ooooo`7o00000Oooool00003o`000?oooooooooo07Kooooo0_ooO`0Oooooo`03o`00oooooooo
oooo00cooooo0_ooO`0Tooooo`03o`00ooooO`3oogl004cooooo0Ol00001ooooo`0000?o0000oooo
ooooool0MOooool4oomo01kooooo00?o003oooooooooool0<Oooool00ol00?ooooooooooo`1=oooo
o`7o00000Oooool00003o`000?oooooooooo07Gooooo1?ooO`0:ooooo`;oogl04Oooool00ol00?oo
ooooooooo`0aooooo`03o`00oooooooooooo04kooooo0Ol00001ooooo`0000?o0000ooooooooool0
M_ooool2oomo00[ooooo1?ooO`0?ooooo`03o`00oooooooooooo01Sooooo0_ooO`0Gooooo`03o`00
oooooooooooo04oooooo0Ol00001ooooo`0000?o0000ooooooooool0P_ooool4oomo00oooooo00?o
003oooooooooool05oooool4oomo01Cooooo0_l00?mBooooo`7o00000Oooool00003o`000?oooooo
oooo08?ooooo0_ooO`0?ooooo`03o`00oooooooooooo01;ooooo0_ooO`04ooooo`Coogl04Oooool3
o`00oeCooooo0Ol00001ooooo`0000?o0000ooooooooool0U?ooool00ol00?ooooooooooo`0Aoooo
o`Coogl01?ooool2oomo013ooooo0_l00?mGooooo`7o00000Oooool00003o`000?oooooooooo09Co
oooo00?o003oooooooooool04Oooool4oomo01Gooooo00?o003oooooooooool0Eoooool1o`00007o
oooo00000ol0003oooooooooo`2Dooooo`03o`00oooooooooooo01;ooooo0_ooO`0Dooooo`;o003o
F_ooool1o`00007ooooo00000ol0003oooooooooo`2Dooooo`03o`00oooooooooooo02Kooooo0_l0
0?mLooooo`7o00000Oooool00003o`000?oooooooooo09Gooooo00?o003oooooooooool09?ooool0
0ol00?ooooooooooo`1Looooo`7o00000Oooool00003o`000?oooooooooo09Gooooo00?o003ooooo
ooooool08_ooool2o`00oeoooooo0Ol00001ooooo`0000?o0000ooooooooool0UOooool00ol00?oo
ooooooooo`0Pooooo`;o003oHOooool1o`00007ooooo00000ol0003oooooooooo`24ooooo`;oogl0
3oooool2o`00oaoooooo0_l00?mSooooo`7o00000Oooool00003o`000?oooooooooo08?ooooo1?oo
O`0@ooooo`;o003o6_ooool3o`00ofGooooo0Ol00001ooooo`0000?o0000ooooooooool0Poooool4
oomo01;ooooo0_l00?lDooooo`Co003oJ?ooool1o`00007ooooo00000ol0003oooooooooo`24oooo
o`;oogl05Oooool3o`00o`kooooo0ol00?l3ooooo`;oogl0Ioooool1o`00007ooooo00000ol0003o
ooooooooo`2Nooooo`?o003o1Oooool6o`00o`Gooooo1?ooO`1Vooooo`7o00000Oooool00003o`00
0?oooooooooo0:7ooooo1Ol00?l;ooooo`Coogl0I_ooool1o`00007ooooo00000ol0003ooooooooo
o`2booooo`;oogl0Ioooool1o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001
ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo07_o
oooo0_ooO`2Nooooo`7o00000Oooool00003o`000?oooooooooo07[ooooo1?ooO`2Mooooo`7o0000
0Oooool00003o`000?oooooooooo07[ooooo1?ooO`0Pooooo`;oogl0Noooool1o`00007ooooo0000
0ol0003oooooooooo`1kooooo`;oogl08?ooool4oomo07[ooooo0Ol00001ooooo`0000?o0000oooo
ooooool0WOooool4oomo07[ooooo0Ol00001ooooo`0000?o0000ooooooooool0T?ooool2oomo00co
oooo0_ooO`1kooooo`7o00000Oooool00003o`000?oooooooooo08oooooo1?ooO`28ooooo`7o0000
0Oooool00003o`000?oooooooooo08oooooo1?ooO`28ooooo`7o00000Oooool00003o`000?oooooo
oooo093ooooo0_ooO`0Sooooo`;oogl0I?ooool1o`00007ooooo00000ol0003oooooooooo`2doooo
o`Coogl0Hoooool1o`00007ooooo00000ol0003oooooooooo`2dooooo`Coogl0Hoooool1o`00007o
oooo00000ol0003oooooooooo`2eooooo`;oogl0I?ooool1o`00007ooooo00000ol0003ooooooooo
o`3ooooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool0
0003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooooaco
oooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oo
oooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001
ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo0?oo
oooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o
0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1
o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000oooooooo
ool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo
00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolL
ooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003o
ooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o0000
0Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3o
oooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003
o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo
0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oooooo
oooo0?oooooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001oooo
o`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo
7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000
ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00
007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0
oooooolLooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo0000
0ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0S_ooool2oomo
08_ooooo0Ol00001ooooo`0000?o0000ooooooooool0SOooool4oomo08[ooooo0Ol00001ooooo`00
00?o0000ooooooooool0SOooool4oomo08[ooooo0Ol00001ooooo`0000?o0000ooooooooool0S_oo
ool2oomo08_ooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool0
0003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooooaco
oooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oo
oooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001
ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo0?oo
oooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o
0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1
o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000oooooooo
ool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo
00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolL
ooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003o
ooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o0000
0Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3o
oooooacooooo0Ol00001ooooo`00ool0000Po`00007ooooo0000\
\>"],
  ImageRangeCache->{{{0, 287}, {287, 0}} -> {-1.01089, -1.01089, 0.00704453, \
0.00704453}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.49505 0.5 0.49505 [
[ 0 0 -0.125 0 ]
[ 0 0 -0.125 0 ]
[ 0 1 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
0 0 m
1 0 L
s
0 0 m
0 1 L
s
0 1 m
1 1 L
s
1 0 m
1 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
1 .5 0 r
.015 w
.03175 .1355 Mdot
.03435 .12523 Mdot
.11137 .12765 Mdot
.14107 .18841 Mdot
.16218 .24538 Mdot
.17294 .21053 Mdot
.18267 .18577 Mdot
.18434 .1304 Mdot
.18553 .30956 Mdot
.20401 .239 Mdot
.21247 .27571 Mdot
.21687 .20845 Mdot
.22376 .2799 Mdot
.22832 .27485 Mdot
.29063 .20974 Mdot
.29686 .25079 Mdot
.30487 .22936 Mdot
.30683 .34623 Mdot
.32055 .20902 Mdot
.32574 .21979 Mdot
.34472 .28521 Mdot
.35998 .36393 Mdot
.36335 .24976 Mdot
.3794 .36608 Mdot
.42386 .66992 Mdot
.44391 .74519 Mdot
.45059 .34198 Mdot
.47208 .67586 Mdot
.47436 .71381 Mdot
.49778 .59825 Mdot
.50874 .91643 Mdot
.51516 .76219 Mdot
.53655 .61374 Mdot
.56563 .75219 Mdot
.59189 .65665 Mdot
.59581 .61604 Mdot
.59923 .6556 Mdot
.60292 .68499 Mdot
.62656 .67779 Mdot
.63555 .72451 Mdot
.63919 .652 Mdot
.64169 .6004 Mdot
.64246 .58611 Mdot
.64496 .54267 Mdot
.64608 .77288 Mdot
.65077 .64308 Mdot
.66065 .57816 Mdot
.67474 .59169 Mdot
.69296 .563 Mdot
.72815 .65902 Mdot
.73169 .58879 Mdot
.74669 .61318 Mdot
.74821 .65474 Mdot
.75963 .63781 Mdot
.79673 .57809 Mdot
.80925 .55852 Mdot
.81525 .58444 Mdot
.83417 .62985 Mdot
.83598 .55526 Mdot
.91595 .49319 Mdot
1 0 0 r
.005 w
.16128 .17044 m
.18734 .17269 L
.21339 .17909 L
.2345 .18734 L
.23945 .19126 L
.2655 .20415 L
.27874 .21339 L
.29156 .22295 L
.31204 .23945 L
.31761 .24532 L
.33549 .2655 L
.34367 .28341 L
.34499 .29156 L
.34367 .29798 L
.31761 .3104 L
.29156 .30711 L
.2655 .30014 L
.24507 .29156 L
.23945 .28747 L
.21339 .27402 L
.20155 .2655 L
.18734 .25472 L
.16884 .23945 L
.16128 .2313 L
.14618 .21339 L
.13806 .18734 L
.16128 .17044 L
s
0 0 1 r
.65633 .57701 m
.68239 .56842 L
.70844 .56313 L
.7345 .56168 L
.76055 .5752 L
.76359 .57817 L
.76859 .60422 L
.76055 .62333 L
.75627 .63028 L
.7345 .65485 L
.73298 .65633 L
.70844 .6775 L
.69922 .68239 L
.68239 .69294 L
.65633 .70579 L
.64983 .70844 L
.63028 .71539 L
.60422 .72268 L
.57817 .72651 L
.55211 .7214 L
.53145 .70844 L
.52926 .68239 L
.54239 .65633 L
.55211 .63983 L
.56625 .63028 L
.57817 .6193 L
.60119 .60422 L
.60422 .60227 L
.63028 .58726 L
.65315 .57817 L
.65633 .57701 L
s
1 0 0 r
.03 w
.24141 .24033 Mdot
0 0 1 r
.64872 .64417 Mdot
1 0 0 r
.79703 .00495 m
.79703 .25248 L
.87129 .25248 L
.87129 .00495 L
F
0 0 1 r
.89604 .00495 m
.89604 .00495 L
.9703 .00495 L
.9703 .00495 L
F
1 0 1 r
.04 w
.17294 .21053 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P000182000`400?l00000o`00003ooooooolQ
ooooo`00ool0000Po`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`00
00?o0000ooooooooool0hOoooolEool002Gooooo0Ol00001ooooo`0000?o0000ooooooooool0hOoo
oolEool002Gooooo0Ol00001ooooo`0000?o0000ooooooooool0hOoooolEool002Gooooo0Ol00001
ooooo`0000?o0000ooooooooool0hOoooolEool002Gooooo0Ol00001ooooo`0000?o0000oooooooo
ool0hOoooolEool002Gooooo0Ol00001ooooo`0000?o0000ooooooooool0hOoooolEool002Gooooo
0Ol00001ooooo`0000?o0000ooooooooool0hOoooolEool002Gooooo0Ol00001ooooo`0000?o0000
ooooooooool0hOoooolEool002Gooooo0Ol00001ooooo`0000?o0000ooooooooool0hOoooolEool0
02Gooooo0Ol00001ooooo`0000?o0000ooooooooool0hOoooolEool002Gooooo0Ol00001ooooo`00
00?o0000ooooooooool0hOoooolEool002Gooooo0Ol00001ooooo`0000?o0000ooooooooool0hOoo
oolEool002Gooooo0Ol00001ooooo`0000?o0000ooooooooool0hOoooolEool002Gooooo0Ol00001
ooooo`0000?o0000ooooooooool0hOoooolEool002Gooooo0Ol00001ooooo`0000?o0000oooooooo
ool0hOoooolEool002Gooooo0Ol00001ooooo`0000?o0000ooooooooool0hOoooolEool002Gooooo
0Ol00001ooooo`0000?o0000ooooooooool0hOoooolEool002Gooooo0Ol00001ooooo`0000?o0000
ooooooooool0hOoooolEool002Gooooo0Ol00001ooooo`0000?o0000ooooooooool0hOoooolEool0
02Gooooo0Ol00001ooooo`0000?o0000ooooooooool0hOoooolEool002Gooooo0Ol00001ooooo`00
00?o0000ooooooooool0hOoooolEool002Gooooo0Ol00001ooooo`0000?o0000ooooooooool0hOoo
oolEool002Gooooo0Ol00001ooooo`0000?o0000ooooooooool0hOoooolEool002Gooooo0Ol00001
ooooo`0000?o0000ooooooooool0hOoooolEool002Gooooo0Ol00001ooooo`0000?o0000oooooooo
ool0hOoooolEool002Gooooo0Ol00001ooooo`0000?o0000ooooooooool0hOoooolEool002Gooooo
0Ol00001ooooo`0000?o0000ooooooooool0hOoooolEool002Gooooo0Ol00001ooooo`0000?o0000
ooooooooool0hOoooolEool002Gooooo0Ol00001ooooo`0000?o0000ooooooooool0hOoooolEool0
02Gooooo0Ol00001ooooo`0000?o0000ooooooooool0hOoooolEool002Gooooo0Ol00001ooooo`00
00?o0000ooooooooool0hOoooolEool002Gooooo0Ol00001ooooo`0000?o0000ooooooooool0hOoo
oolEool002Gooooo0Ol00001ooooo`0000?o0000ooooooooool01_ooool2oomo0=Wooooo5Ooo000U
ooooo`7o00000Oooool00003o`000?oooooooooo00Gooooo1?ooO`0Cooooo`;oogl0`ooooolEool0
02Gooooo0Ol00001ooooo`0000?o0000ooooooooool01Oooool4oomo01;ooooo1?ooO`0Booooo`;o
ogl0[_oooolEool002Gooooo0Ol00001ooooo`0000?o0000ooooooooool01Oooool3oomo01?ooooo
1?ooO`0Aooooo`Coogl0[OoooolEool002Gooooo0Ol00001ooooo`0000?o0000ooooooooool01?oo
ool4oomo01Cooooo0_ooO`0Booooo`Coogl0[OoooolEool002Gooooo0Ol00001ooooo`0000?o0000
ooooooooool01?ooool4oomo02Wooooo0_ooO`2^oooooaGoo`009Oooool1o`00007ooooo00000ol0
003oooooooooo`05ooooo`;oogl0f_oooolEool002Gooooo0Ol00001ooooo`0000?o0000oooooooo
ool0hOoooolEool002Gooooo0Ol00001ooooo`0000?o0000ooooooooool0hOoooolEool002Gooooo
0Ol00001ooooo`0000?o0000ooooooooool0hOoooolEool002Gooooo0Ol00001ooooo`0000?o0000
ooooooooool0hOoooolEool002Gooooo0Ol00001ooooo`0000?o0000ooooooooool0hOoooolEool0
02Gooooo0Ol00001ooooo`0000?o0000ooooooooool0hOoooolEool002Gooooo0Ol00001ooooo`00
00?o0000ooooooooool0hOoooolEool002Gooooo0Ol00001ooooo`0000?o0000ooooooooool0:_oo
ool6ool00;7ooooo5Ooo000Uooooo`7o00000Oooool00003o`000?oooooooooo02Wooooo00?oo`00
ooooooooool01?ooool5ool00:cooooo5Ooo000Uooooo`7o00000Oooool00003o`000?oooooooooo
02Oooooo0_oo000<ooooo`Coo`00Z?oooolEool002Gooooo0Ol00001ooooo`0000?o0000oooooooo
ool09_ooool00ooo003oooooooooo`0@ooooo`Coo`00Y?oooolEool002Gooooo0Ol00001ooooo`00
00?o0000ooooooooool09?ooool00oooO`3oo`00ooooo`09ooooo`;oogl02oooool3ool00:7ooooo
5Ooo000Uooooo`7o00000Oooool00003o`000?oooooooooo02?ooooo00Coogl0ool00?ooO`3oogl0
2?ooool4oomo00gooooo00?oo`00ooooooooool0W_oooolEool002Gooooo0Ol00001ooooo`0000?o
0000ooooooooool08oooool01?ooO`3oo`00oomo0?ooO`08ooooo`Coogl03_ooool2ool009kooooo
5Ooo000Uooooo`7o00000Oooool00003o`000?oooooooooo02Cooooo00?oogl0ool00?ooool01Ooo
ool5ool0o`03oomo0?oooooooooo00oooooo0_oo002LoooooaGoo`009Oooool1o`00007ooooo0000
0ol0003oooooooooo`0Uooooo`03ool00?oooooooooo00?ooooo1ooo0?lCooooo`;oo`00V_oooolE
ool002Gooooo0Ol00001ooooo`0000?o0000ooooooooool09Oooool00ooo003oooooooooo`02oooo
o`Woo`3o5?ooool2ool009Sooooo5Ooo000Uooooo`7o00000Oooool00003o`000?oooooooooo02Ko
oooo00?oo`00ooooooooool02ooo0?l6ooooo`;oogl03Oooool2ool000Cooooo0_ooO`07ooooo`;o
ogl0QooooolEool002Gooooo0Ol00001ooooo`0000?o0000ooooooooool09_ooool00ooo003ooooo
ooooo`0;ool0o`Gooooo1?ooO`0>ooooo`03ool00?oooooooooo00Coogl01Oooool4oomo08Kooooo
5Ooo000Uooooo`7o00000Oooool00003o`000?oooooooooo02Kooooo00?oo`00ooooooooool02ooo
0?l5ooooo`Coogl03oooool00ooo003ooooooomo0003oomo00Gooooo1?ooO`26oooooaGoo`009Ooo
ool1o`00007ooooo00000ol0003oooooooooo`0Wooooo`03ool00?ooooooo`3o00[oo`3o1_ooool2
oomo017ooooo00Coo`00ooooooooO`3oogl01oooool3oomo08Kooooo5Ooo000Uooooo`7o00000Ooo
ool00003o`000?oooooooooo02Oooooo00?oo`00oooooooo0?l02_oo0?lJooooo`03ool00?oooooo
oooo00Oooooo1?ooO`25oooooaGoo`009Oooool1o`00007ooooo00000ol0003oooooooooo`0Xoooo
o`03ool00?ooooooo`3o00Soo`3o7?ooool00ooo003oooooooooo`06ooooo`Coogl0QOoooolEool0
02Gooooo0Ol00001ooooo`0000?o0000ooooooooool0:Oooool00ooo003oooooool0o`06ool0oako
oooo0_oo00000oooooooogl0oomo0004ooooo`;oogl0Q_oooolEool002Gooooo0Ol00001ooooo`00
00?o0000ooooooooool0:_ooool00ooo003oooooool0o`04ool0o`oooooo1?oo000>ooooo`04ool0
0?ooO`3oogl0oomo08_ooooo5Ooo000Uooooo`7o00000Oooool00003o`000?oooooooooo02_ooooo
00?oo`00ooooooooool04Oooool6ool000gooooo00Coogl0ool00?oo003oogl0RooooolEool002Go
oooo0Ol00001ooooo`0000?o0000ooooooooool0;?ooool00ooo003oooooooooo`08ooooo`;oogl0
1Oooool8ool000gooooo0_ooO`000ooo003oooooooooo`29oooooaGoo`009Oooool1o`00007ooooo
00000ol0003oooooooooo`0]ooooo`03ool00?oooooooooo00Kooooo1?ooO`04ooooo`Soo`004?oo
ool00ooo003oooooooooo`28oooooaGoo`009Oooool1o`00007ooooo00000ol0003oooooooooo`0[
ooooo`;oogl000?oooooool00?ooool01_ooool4oomo00Cooooo2?oo000Aooooo`03ool00?oooooo
oooo08Oooooo5Ooo000Uooooo`7o00000Oooool00003o`000?oooooooooo02[ooooo1?ooO`000ooo
ooooo`00ooooo`06ooooo`;oogl01Oooool8ool000_ooooo0_ooO`05ooooo`03ool00?oooooooooo
00Wooooo0_ooO`1koooooaGoo`009Oooool1o`00007ooooo00000ol0003oooooooooo`0Zooooo`Co
ogl00_ooool00ooo003oooooooooo`0<ooooo`Koo`002oooool4oomo00Cooooo00?oo`00oooooooo
ool02?ooool4oomo07[ooooo5Ooo000Uooooo`7o00000Oooool00003o`000?oooooooooo02_ooooo
0_ooO`04ooooo`03ool00?oooooooooo00cooooo1?oo000<ooooo`Coogl01Oooool00ooo003ooooo
ooooo`07ooooo`Coogl0N_oooolEool002Gooooo0Ol00001ooooo`0000?o0000ooooooooool0<_oo
ool2ool001gooooo0_ooO`07ooooo`03ool00?oooooooooo00Oooooo0_ooO`2eooooo`7o00000Ooo
ool00003o`000?oooooooooo03Cooooo00?oo`00ooooooooool09?ooool00ooo003oooooooooo`2m
ooooo`7o00000Oooool00003o`000?oooooooooo03Gooooo00?oo`00ooooooooool09?ooool00ooo
003oooooooooo`2looooo`7o00000Oooool00003o`000?oooooooooo03Kooooo0_oo000Uooooo`03
ool00?oooooooooo0;_ooooo0Ol00001ooooo`0000?o0000ooooooooool0>?ooool2ool00003oomo
0?oooooooooo00;oogl07_ooool00ooo003oooooooooo`2kooooo`7o00000Oooool00003o`000?oo
oooooooo03Sooooo0_ooO`02ool000Coogl07_ooool00ooo003oooooooooo`2jooooo`7o00000Ooo
ool00003o`000?oooooooooo03Sooooo1?ooO`02ool000;oogl07_ooool00ooo003oooooooooo`2j
ooooo`7o00000Oooool00003o`000?oooooooooo03Wooooo1OooO`000ooo003oooooooooo`0Moooo
o`03ool00?ooO`3oogl00;[ooooo0Ol00001ooooo`0000?o0000ooooooooool0>oooool4oomo00;o
o`007Oooool01?ooO`3oo`00oomo0?ooO`2iooooo`7o00000Oooool00003o`000?oooooooooo03co
oooo0_ooO`03ooooo`;oo`006oooool01?ooO`3oo`00oomo0?ooO`2iooooo`7o00000Oooool00003
o`000?oooooooooo04?ooooo0_oo000Jooooo`03oomo0?oo003ooooo0;Wooooo0Ol00001ooooo`00
00?o0000ooooooooool0AOooool2ool001Wooooo00?oo`00ooooooooool0^?ooool1o`00007ooooo
00000ol0003oooooooooo`17ooooo`;oo`005Oooool2ool00;_ooooo0Ol00001ooooo`0000?o0000
ooooooooool0BOooool3ool0013ooooo0_oo002mooooo`7o00000Oooool00003o`000?oooooooooo
037ooooo0_ooO`0Iooooo`?oo`003?ooool00ooo003oooooooooo`2mooooo`7o00000Oooool00003
o`000?oooooooooo033ooooo1?ooO`0Kooooo`Koo`001?ooool2ool00<3ooooo0Ol00001ooooo`00
00?o0000ooooooooool0<?ooool4oomo027ooooo1?oo0032ooooo`7o00000Oooool00003o`000?oo
oooooooo037ooooo0_ooO`3Xooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1
o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000oooooooo
ool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo
00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0OOooool2
oomo09cooooo0Ol00001ooooo`0000?o0000ooooooooool0O?ooool4oomo09_ooooo0Ol00001oooo
o`0000?o0000ooooooooool0E?ooool2oomo02Kooooo1?ooO`2Kooooo`7o00000Oooool00003o`00
0?oooooooooo05?ooooo1?ooO`0Vooooo`;oogl0W?ooool1o`00007ooooo00000ol0003ooooooooo
o`1Cooooo`Coogl0a?ooool1o`00007ooooo00000ol0003oooooooooo`1Dooooo`;oogl0aOooool1
o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000oooooooo
ool0Hoooool2oomo00Cooooo0_ooO`2`ooooo`7o00000Oooool00003o`000?oooooooooo06;ooooo
1?ooO`02ooooo`Coogl0[oooool1o`00007ooooo00000ol0003oooooooooo`1Rooooo`Coogl00_oo
ool4oomo0:oooooo0Ol00001ooooo`0000?o0000ooooooooool0Hoooool2oomo00Cooooo0_ooO`2`
ooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003o
ooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o0000
0Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3o
oooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003
o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo
0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oooooo
oooo0?oooooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001oooo
o`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo
7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000
ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00
007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0
oooooolLooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo0000
0ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLoooo
o`7o00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003ooooo
ooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Ooo
ool00003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooo
oacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`00
0?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol0
0001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo
0?oooooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`00
00?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo1?oo
ool2oomo01Kooooo0Ol00001ooooo`0000?o0000ooooooooool0ooooool3ooooo`Coogl05Oooool1
o`00007ooooo00000ol0003oooooooooo`3oooooo`?ooooo1?ooO`0Eooooo`7o00000Oooool00003
o`000?oooooooooo0?oooooo1?ooool2oomo01Kooooo0Ol00001ooooo`0000?o0000ooooooooool0
oooooolLooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo0000
0ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLoooo
o`7o00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003ooooo
ooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Ooo
ool00003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooo
oacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`00
0?oooooooooo0;Gooooo0_ooO`1Tooooo`7o00000Oooool00003o`000?oooooooooo0;Cooooo1?oo
O`1Sooooo`7o00000Oooool00003o`000?oooooooooo0;Cooooo1?ooO`1Sooooo`7o00000Oooool0
0003o`000?oooooooooo0;Gooooo0_ooO`0eooooo`;oogl0;Oooool1o`00007ooooo00000ol0003o
ooooooooo`3Tooooo`;oogl01Oooool4oomo02cooooo0Ol00001ooooo`0000?o0000ooooooooool0
hoooool4oomo00Cooooo1?ooO`0/ooooo`7o00000Oooool00003o`000?oooooooooo0<?ooooo0_oo
O`0Nooooo`Coogl01Oooool2oomo02gooooo0Ol00001ooooo`0000?o0000ooooooooool0`_ooool4
oomo00_o003o4oooool2oomo03Gooooo0Ol00001ooooo`0000?o0000ooooooooool0`_ooool4o`00
o`_ooooo0_l00?m8ooooo`7o00000Oooool00003o`000?oooooooooo0;kooooo1?l00?l00ooooooo
ogl0oomo000>ooooo`;o003oA_ooool1o`00007ooooo00000ol0003oooooooooo`2iooooo`;oogl0
0ol00?lGooooo`;o003o2Oooool2oomo03Wooooo0Ol00001ooooo`0000?o0000ooooooooool0]ooo
ool4o`00o`03oomo0?oooooooooo01Wooooo0_l00?l6ooooo`Coogl0>?ooool1o`00007ooooo0000
0ol0003oooooooooo`2dooooo`?o003o00?ooooooomo0?ooO`000_ooO`0Looooo`03o`00oooooooo
oooo00Cooooo1?ooO`03ooooo`;oogl0<oooool1o`00007ooooo00000ol0003oooooooooo`2boooo
o`;o003o0oooO`02ooooo`;oogl04oooool2oomo00Sooooo00?o003oooooooooool01Oooool2oomo
00?ooooo1?ooO`0booooo`7o00000Oooool00003o`000?oooooooooo0;3ooooo0_l00?l00ooooooo
ogl0oomo0002oomo00Kooooo0_ooO`0>ooooo`Coogl01oooool00ol00?ooooooooooo`0:ooooo`Co
ogl0<_ooool1o`00007ooooo00000ol0003oooooooooo`2^ooooo`;o003o1?ooool2oomo00Kooooo
1?ooO`0=ooooo`Coogl01oooool00ol00?ooooooooooo`0;ooooo`;oogl0<oooool1o`00007ooooo
00000ol0003oooooooooo`2;ooooo`;oogl08?ooool00ol00?ooooooooooo`04ooooo`;oogl01_oo
ool4oomo00kooooo0_ooO`09ooooo`03o`00oooooooooooo03oooooo0Ol00001ooooo`0000?o0000
ooooooooool0R_ooool4oomo01gooooo0_l00?l6ooooo`Coogl01_ooool2oomo01[ooooo00?o003o
ooooooooool0?oooool1o`00007ooooo00000ol0003oooooooooo`2:ooooo`Coogl07?ooool00ol0
0?ooooooooooo`06ooooo`Coogl08_ooool00ol00?ooooooooooo`0oooooo`7o00000Oooool00003
o`000?oooooooooo08_ooooo0_ooO`0Kooooo`;o003o2_ooool2oomo02?ooooo00?o003ooooooooo
ool0?oooool1o`00007ooooo00000ol0003oooooooooo`2Fooooo`;oogl03_ooool2o`00ob[ooooo
0_ooO`05ooooo`03o`00oooooooooooo03oooooo0Ol00001ooooo`0000?o0000ooooooooool0UOoo
ool4oomo00cooooo00Co003oooooooooO`3oogl0:?ooool4oomo00?ooooo00?o003oooooooooool0
@?ooool1o`00007ooooo00000ol0003oooooooooo`2Eooooo`Coogl02_ooool2o`00o`03oooooooo
O`3oogl000;oogl09oooool4oomo00?ooooo00?o003oooooooooool0@?ooool1o`00007ooooo0000
0ol0003oooooooooo`2Fooooo`;oogl02_ooool01?l00?ooooooooooooooool4oomo02Sooooo0_oo
O`04ooooo`03o`00oooooooooooo043ooooo0Ol00001ooooo`0000?o0000ooooooooool0XOooool0
0ol00?ooooooooooo`03ooooo`;oogl0;_ooool00ol00?ooooooooooo`11ooooo`7o00000Oooool0
0003o`000?oooooooooo0:3ooooo00?o003oooooooooool0<oooool00ol00?ooooooooooo`0Boooo
o`;oogl0;_ooool1o`00007ooooo00000ol0003oooooooooo`2Nooooo`;o003o=Oooool00ol00?oo
ooooooooo`0Booooo`Coogl0;Oooool1o`00007ooooo00000ol0003oooooooooo`2Mooooo`03o`00
oooooooooooo01Gooooo1?l00?lLooooo`03o`00ooooO`3oogl001;ooooo1?ooO`0]ooooo`7o0000
0Oooool00003o`000?oooooooooo09cooooo00?o003oooooooooool05Oooool6o`00oa[ooooo00?o
003ooomo0?ooO`000_ooO`0Booooo`;oogl0;_ooool1o`00007ooooo00000ol0003oooooooooo`2K
ooooo`03o`00oooooooooooo01Gooooo2?l00?lHooooo`03o`00ooooooooogl000?oogl0@_ooool1
o`00007ooooo00000ol0003oooooooooo`2Kooooo`03o`00oooooooooooo01Gooooo2?l00?lGoooo
o`04o`00ooooooooooooooooo`;oogl0@oooool1o`00007ooooo00000ol0003oooooooooo`2Joooo
o`03o`00oooooooooooo01Kooooo2?l00?lFooooo`03o`00oooooooooooo04Oooooo0Ol00001oooo
o`0000?o0000ooooooooool0VOooool00ol00?ooooooooooo`0<ooooo`;oogl02?ooool00oooO`3o
003oo`00o`06o`00oaGooooo00?o003oooooooooool00_ooO`16ooooo`7o00000Oooool00003o`00
0?oooooooooo09Wooooo00?o003oooooooooool02_ooool5oomo00Oooooo0_ooO`06o`00oa?ooooo
0_ooO`000ol00?ooooooooooo`04oomo04Gooooo0Ol00001ooooo`0000?o0000ooooooooool0V?oo
ool00ol00?ooooooooooo`0:ooooo`Koogl02?ooool2oomo00Co003o4oooool2oomo00;o003o0_oo
ool4oomo04Gooooo0Ol00001ooooo`0000?o0000ooooooooool0V?ooool00ol00?ooooooooooo`0:
ooooo`Googl08_ooool01?ooO`3o003ooomo0?ooO`03ooooo`;oogl0A_ooool1o`00007ooooo0000
0ol0003oooooooooo`1fooooo`;oogl07oooool00ol00?ooooooooooo`0<ooooo`;oogl09?ooool0
0ol00?ooogl0oomo001<ooooo`7o00000Oooool00003o`000?oooooooooo07Gooooo1?ooO`0Noooo
o`03o`00oooooooooooo037ooooo00?o003oooooooooool0COooool1o`00007ooooo00000ol0003o
ooooooooo`1eooooo`Coogl02_ooool2oomo017ooooo00?o003oooooooooool0<Oooool00ol00?oo
ooooooooo`1>ooooo`7o00000Oooool00003o`000?oooooooooo07Kooooo0_ooO`0:ooooo`Coogl0
3oooool00ol00?ooooooooooo`0Hooooo`;oogl05oooool00ol00?ooooooooooo`1?ooooo`7o0000
0Oooool00003o`000?oooooooooo08;ooooo1?ooO`0?ooooo`03o`00oooooooooooo01Oooooo1?oo
O`0Dooooo`;o003oD_ooool1o`00007ooooo00000ol0003oooooooooo`23ooooo`;oogl03oooool0
0ol00?ooooooooooo`0Booooo`;oogl01?ooool4oomo017ooooo0ol00?mDooooo`7o00000Oooool0
0003o`000?oooooooooo09Cooooo00?o003oooooooooool04Oooool4oomo00Cooooo0_ooO`0@oooo
o`;o003oEoooool1o`00007ooooo00000ol0003oooooooooo`2Dooooo`03o`00oooooooooooo017o
oooo1?ooO`0Eooooo`03o`00oooooooooooo05Oooooo0Ol00001ooooo`0000?o0000ooooooooool0
U?ooool00ol00?ooooooooooo`0Booooo`;oogl05?ooool2o`00oe[ooooo0Ol00001ooooo`0000?o
0000ooooooooool0U?ooool00ol00?ooooooooooo`0Vooooo`;o003oG?ooool1o`00007ooooo0000
0ol0003oooooooooo`2Eooooo`03o`00oooooooooooo02Cooooo00?o003oooooooooool0G?ooool1
o`00007ooooo00000ol0003oooooooooo`2Eooooo`03o`00oooooooooooo02;ooooo0_l00?mOoooo
o`7o00000Oooool00003o`000?oooooooooo09Gooooo00?o003oooooooooool08?ooool2o`00of7o
oooo0Ol00001ooooo`0000?o0000ooooooooool0Q?ooool2oomo00oooooo0_l00?lOooooo`;o003o
Hoooool1o`00007ooooo00000ol0003oooooooooo`23ooooo`Coogl04?ooool2o`00oa[ooooo0ol0
0?mUooooo`7o00000Oooool00003o`000?oooooooooo08?ooooo1?ooO`0Booooo`;o003o5?ooool4
o`00ofSooooo0Ol00001ooooo`0000?o0000ooooooooool0Q?ooool2oomo01Gooooo0ol00?l>oooo
o`?o003o0oooool2oomo06Oooooo0Ol00001ooooo`0000?o0000ooooooooool0W_ooool3o`00o`Go
oooo1_l00?l5ooooo`Coogl0I_ooool1o`00007ooooo00000ol0003oooooooooo`2Qooooo`Go003o
2oooool4oomo06Kooooo0Ol00001ooooo`0000?o0000ooooooooool0/_ooool2oomo06Oooooo0Ol0
0001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo
0?oooooo7?ooool1o`00007ooooo00000ol0003oooooooooo`1kooooo`;oogl0W_ooool1o`00007o
oooo00000ol0003oooooooooo`1jooooo`Coogl0WOooool1o`00007ooooo00000ol0003ooooooooo
o`1jooooo`Coogl08?ooool2oomo07_ooooo0Ol00001ooooo`0000?o0000ooooooooool0Noooool2
oomo023ooooo1?ooO`1jooooo`7o00000Oooool00003o`000?oooooooooo09gooooo1?ooO`1joooo
o`7o00000Oooool00003o`000?oooooooooo093ooooo0_ooO`0<ooooo`;oogl0Noooool1o`00007o
oooo00000ol0003oooooooooo`2?ooooo`Coogl0R?ooool1o`00007ooooo00000ol0003ooooooooo
o`2?ooooo`Coogl0R?ooool1o`00007ooooo00000ol0003oooooooooo`2@ooooo`;oogl08oooool2
oomo06Cooooo0Ol00001ooooo`0000?o0000ooooooooool0]?ooool4oomo06?ooooo0Ol00001oooo
o`0000?o0000ooooooooool0]?ooool4oomo06?ooooo0Ol00001ooooo`0000?o0000ooooooooool0
]Oooool2oomo06Cooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Ooo
ool00003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooo
oacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`00
0?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol0
0001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo
0?oooooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`00
00?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?oo
ool1o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000oooo
ooooool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007o
oooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooo
oolLooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0
003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o
00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003ooooooooo
o`3ooooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool0
0003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooooaco
oooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oo
oooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001
ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo0?oo
oooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o
0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1
o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000oooooooo
ool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo
00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolL
ooooo`7o00000Oooool00003o`000?oooooooooo08kooooo0_ooO`2;ooooo`7o00000Oooool00003
o`000?oooooooooo08gooooo1?ooO`2:ooooo`7o00000Oooool00003o`000?oooooooooo08gooooo
1?ooO`2:ooooo`7o00000Oooool00003o`000?oooooooooo08kooooo0_ooO`2;ooooo`7o00000Ooo
ool00003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooo
oacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`00
0?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol0
0001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo
0?oooooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`00
00?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?oo
ool1o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000oooo
ooooool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007o
oooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooo
oolLooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0
003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o
00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003ooooooooo
o`3ooooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool0
0?oo00008?l00001ooooo`00\
\>"],
  ImageRangeCache->{{{0, 287}, {287, 0}} -> {-1.01089, -1.01089, 0.00704453, \
0.00704453}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.49505 0.5 0.49505 [
[ 0 0 -0.125 0 ]
[ 0 0 -0.125 0 ]
[ 0 1 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
0 0 m
1 0 L
s
0 0 m
0 1 L
s
0 1 m
1 1 L
s
1 0 m
1 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
1 .5 0 r
.015 w
.03175 .1355 Mdot
.03435 .12523 Mdot
.11137 .12765 Mdot
.14107 .18841 Mdot
.16218 .24538 Mdot
.17294 .21053 Mdot
.18267 .18577 Mdot
.18434 .1304 Mdot
.18553 .30956 Mdot
.20401 .239 Mdot
.21247 .27571 Mdot
.21687 .20845 Mdot
.22376 .2799 Mdot
.22832 .27485 Mdot
.29063 .20974 Mdot
.29686 .25079 Mdot
.30487 .22936 Mdot
.30683 .34623 Mdot
.32055 .20902 Mdot
.32574 .21979 Mdot
.34472 .28521 Mdot
.35998 .36393 Mdot
.36335 .24976 Mdot
.3794 .36608 Mdot
.42386 .66992 Mdot
.44391 .74519 Mdot
.45059 .34198 Mdot
.47208 .67586 Mdot
.47436 .71381 Mdot
.49778 .59825 Mdot
.50874 .91643 Mdot
.51516 .76219 Mdot
.53655 .61374 Mdot
.56563 .75219 Mdot
.59189 .65665 Mdot
.59581 .61604 Mdot
.59923 .6556 Mdot
.60292 .68499 Mdot
.62656 .67779 Mdot
.63555 .72451 Mdot
.63919 .652 Mdot
.64169 .6004 Mdot
.64246 .58611 Mdot
.64496 .54267 Mdot
.64608 .77288 Mdot
.65077 .64308 Mdot
.66065 .57816 Mdot
.67474 .59169 Mdot
.69296 .563 Mdot
.72815 .65902 Mdot
.73169 .58879 Mdot
.74669 .61318 Mdot
.74821 .65474 Mdot
.75963 .63781 Mdot
.79673 .57809 Mdot
.80925 .55852 Mdot
.81525 .58444 Mdot
.83417 .62985 Mdot
.83598 .55526 Mdot
.91595 .49319 Mdot
1 0 0 r
.005 w
.16128 .17044 m
.18734 .17269 L
.21339 .17909 L
.2345 .18734 L
.23945 .19126 L
.2655 .20415 L
.27874 .21339 L
.29156 .22295 L
.31204 .23945 L
.31761 .24532 L
.33549 .2655 L
.34367 .28341 L
.34499 .29156 L
.34367 .29798 L
.31761 .3104 L
.29156 .30711 L
.2655 .30014 L
.24507 .29156 L
.23945 .28747 L
.21339 .27402 L
.20155 .2655 L
.18734 .25472 L
.16884 .23945 L
.16128 .2313 L
.14618 .21339 L
.13806 .18734 L
.16128 .17044 L
s
0 0 1 r
.65633 .57701 m
.68239 .56842 L
.70844 .56313 L
.7345 .56168 L
.76055 .5752 L
.76359 .57817 L
.76859 .60422 L
.76055 .62333 L
.75627 .63028 L
.7345 .65485 L
.73298 .65633 L
.70844 .6775 L
.69922 .68239 L
.68239 .69294 L
.65633 .70579 L
.64983 .70844 L
.63028 .71539 L
.60422 .72268 L
.57817 .72651 L
.55211 .7214 L
.53145 .70844 L
.52926 .68239 L
.54239 .65633 L
.55211 .63983 L
.56625 .63028 L
.57817 .6193 L
.60119 .60422 L
.60422 .60227 L
.63028 .58726 L
.65315 .57817 L
.65633 .57701 L
s
1 0 0 r
.03 w
.24141 .24033 Mdot
0 0 1 r
.64872 .64417 Mdot
1 0 0 r
.79703 .00495 m
.79703 .25248 L
.87129 .25248 L
.87129 .00495 L
F
0 0 1 r
.89604 .00495 m
.89604 .00495 L
.9703 .00495 L
.9703 .00495 L
F
1 0 1 r
.04 w
.18267 .18577 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P000182000`400?l00000o`00003ooooooolQ
ooooo`00ool0000Po`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`00
00?o0000ooooooooool0hOoooolEool002Gooooo0Ol00001ooooo`0000?o0000ooooooooool0hOoo
oolEool002Gooooo0Ol00001ooooo`0000?o0000ooooooooool0hOoooolEool002Gooooo0Ol00001
ooooo`0000?o0000ooooooooool0hOoooolEool002Gooooo0Ol00001ooooo`0000?o0000oooooooo
ool0hOoooolEool002Gooooo0Ol00001ooooo`0000?o0000ooooooooool0hOoooolEool002Gooooo
0Ol00001ooooo`0000?o0000ooooooooool0hOoooolEool002Gooooo0Ol00001ooooo`0000?o0000
ooooooooool0hOoooolEool002Gooooo0Ol00001ooooo`0000?o0000ooooooooool0hOoooolEool0
02Gooooo0Ol00001ooooo`0000?o0000ooooooooool0hOoooolEool002Gooooo0Ol00001ooooo`00
00?o0000ooooooooool0hOoooolEool002Gooooo0Ol00001ooooo`0000?o0000ooooooooool0hOoo
oolEool002Gooooo0Ol00001ooooo`0000?o0000ooooooooool0hOoooolEool002Gooooo0Ol00001
ooooo`0000?o0000ooooooooool0hOoooolEool002Gooooo0Ol00001ooooo`0000?o0000oooooooo
ool0hOoooolEool002Gooooo0Ol00001ooooo`0000?o0000ooooooooool0hOoooolEool002Gooooo
0Ol00001ooooo`0000?o0000ooooooooool0hOoooolEool002Gooooo0Ol00001ooooo`0000?o0000
ooooooooool0hOoooolEool002Gooooo0Ol00001ooooo`0000?o0000ooooooooool0hOoooolEool0
02Gooooo0Ol00001ooooo`0000?o0000ooooooooool0hOoooolEool002Gooooo0Ol00001ooooo`00
00?o0000ooooooooool0hOoooolEool002Gooooo0Ol00001ooooo`0000?o0000ooooooooool0hOoo
oolEool002Gooooo0Ol00001ooooo`0000?o0000ooooooooool0hOoooolEool002Gooooo0Ol00001
ooooo`0000?o0000ooooooooool0hOoooolEool002Gooooo0Ol00001ooooo`0000?o0000oooooooo
ool0hOoooolEool002Gooooo0Ol00001ooooo`0000?o0000ooooooooool0hOoooolEool002Gooooo
0Ol00001ooooo`0000?o0000ooooooooool0hOoooolEool002Gooooo0Ol00001ooooo`0000?o0000
ooooooooool0hOoooolEool002Gooooo0Ol00001ooooo`0000?o0000ooooooooool0hOoooolEool0
02Gooooo0Ol00001ooooo`0000?o0000ooooooooool0hOoooolEool002Gooooo0Ol00001ooooo`00
00?o0000ooooooooool0hOoooolEool002Gooooo0Ol00001ooooo`0000?o0000ooooooooool0hOoo
oolEool002Gooooo0Ol00001ooooo`0000?o0000ooooooooool01_ooool2oomo0=Wooooo5Ooo000U
ooooo`7o00000Oooool00003o`000?oooooooooo00Gooooo1?ooO`0Cooooo`;oogl0`ooooolEool0
02Gooooo0Ol00001ooooo`0000?o0000ooooooooool01Oooool4oomo01;ooooo1?ooO`0Booooo`;o
ogl0[_oooolEool002Gooooo0Ol00001ooooo`0000?o0000ooooooooool01Oooool3oomo01?ooooo
1?ooO`0Aooooo`Coogl0[OoooolEool002Gooooo0Ol00001ooooo`0000?o0000ooooooooool01?oo
ool4oomo01Cooooo0_ooO`0Booooo`Coogl0[OoooolEool002Gooooo0Ol00001ooooo`0000?o0000
ooooooooool01?ooool4oomo02Wooooo0_ooO`2^oooooaGoo`009Oooool1o`00007ooooo00000ol0
003oooooooooo`05ooooo`;oogl0f_oooolEool002Gooooo0Ol00001ooooo`0000?o0000oooooooo
ool0hOoooolEool002Gooooo0Ol00001ooooo`0000?o0000ooooooooool0hOoooolEool002Gooooo
0Ol00001ooooo`0000?o0000ooooooooool0hOoooolEool002Gooooo0Ol00001ooooo`0000?o0000
ooooooooool0hOoooolEool002Gooooo0Ol00001ooooo`0000?o0000ooooooooool0hOoooolEool0
02Gooooo0Ol00001ooooo`0000?o0000ooooooooool0hOoooolEool002Gooooo0Ol00001ooooo`00
00?o0000ooooooooool0hOoooolEool002Gooooo0Ol00001ooooo`0000?o0000ooooooooool0:_oo
ool5ool000Goo`3o[OoooolEool002Gooooo0Ol00001ooooo`0000?o0000ooooooooool0:Oooool0
0ooo003oooooooooo`02ooooo`Ooo`3o[?oooolEool002Gooooo0Ol00001ooooo`0000?o0000oooo
ooooool09oooool2ool000Cooooo2Ooo0?l3ool00:Sooooo5Ooo000Uooooo`7o00000Oooool00003
o`000?oooooooooo02Kooooo00?oo`00ooooooooool00oooool;ool0o`;ooooo1?oo002ToooooaGo
o`009Oooool1o`00007ooooo00000ol0003oooooooooo`0Tooooo`03oomo0?oo003ooooo00Gooooo
2ooo0?l6ooooo`?oo`00XOoooolEool002Gooooo0Ol00001ooooo`0000?o0000ooooooooool08ooo
ool01?ooO`3oo`00oomo0?ooO`05ooooo`_oo`3o2Oooool00ooo003oooooooooo`2NoooooaGoo`00
9Oooool1o`00007ooooo00000ol0003oooooooooo`0Sooooo`04oomo0?oo003oogl0oomo00Gooooo
2ooo0?l:ooooo`;oo`00W_oooolEool002Gooooo0Ol00001ooooo`0000?o0000ooooooooool09?oo
ool00oooO`3oo`00ooooo`05ooooo`_oo`3o3?ooool2ool009cooooo5Ooo000Uooooo`7o00000Ooo
ool00003o`000?oooooooooo02Gooooo00?oo`00ooooooooool01Oooool9ool0o`oooooo0_oo002J
oooooaGoo`009Oooool1o`00007ooooo00000ol0003oooooooooo`0Uooooo`03ool00?oooooooooo
00Kooooo1ooo0?lBooooo`;oo`00V?oooolEool002Gooooo0Ol00001ooooo`0000?o0000oooooooo
ool09_ooool00ooo003oooooooooo`06ooooo`Goo`3o1_ooool2oomo00gooooo0_oo0004ooooo`;o
ogl01oooool2oomo08Oooooo5Ooo000Uooooo`7o00000Oooool00003o`000?oooooooooo02Kooooo
00?oo`00ooooooooool01Oooool2oomo00Wooooo1?ooO`0>ooooo`03ool00?oooooooooo00Coogl0
1Oooool4oomo08Kooooo5Ooo000Uooooo`7o00000Oooool00003o`000?oooooooooo02Kooooo00?o
o`00ooooooooool01?ooool4oomo00Sooooo1?ooO`0?ooooo`03ool00?ooooooogl000?oogl01Ooo
ool4oomo08Kooooo5Ooo000Uooooo`7o00000Oooool00003o`000?oooooooooo02Oooooo00?oo`00
ooooooooool00oooool4oomo00Wooooo0_ooO`0Aooooo`04ool00?ooooooogl0oomo00Oooooo0ooo
O`26oooooaGoo`009Oooool1o`00007ooooo00000ol0003oooooooooo`0Wooooo`03ool00?oooooo
oooo00Cooooo0_ooO`0Nooooo`03ool00?oooooooooo00Oooooo1?ooO`25oooooaGoo`009Oooool1
o`00007ooooo00000ol0003oooooooooo`0Xooooo`03ool00?oooooooooo02Cooooo00?oo`00oooo
ooooool01_ooool4oomo08Gooooo5Ooo000Uooooo`7o00000Oooool00003o`000?oooooooooo02Wo
oooo00?oo`00ooooooooool09?ooool2ool00003ooooooooO`3oogl000Cooooo0_ooO`26oooooaGo
o`009Oooool1o`00007ooooo00000ol0003oooooooooo`0Zooooo`03ool00?oooooooooo01?ooooo
1?oo000>ooooo`04ool00?ooO`3oogl0oomo08_ooooo5Ooo000Uooooo`7o00000Oooool00003o`00
0?oooooooooo02_ooooo00?oo`00ooooooooool04Oooool6ool000gooooo00Coogl0ool00?oo003o
ogl0RooooolEool002Gooooo0Ol00001ooooo`0000?o0000ooooooooool0;?ooool00ooo003ooooo
ooooo`08ooooo`;oogl01Oooool8ool000gooooo0_ooO`000ooo003oooooooooo`29oooooaGoo`00
9Oooool1o`00007ooooo00000ol0003oooooooooo`0]ooooo`03ool00?oooooooooo00Kooooo1?oo
O`04ooooo`Soo`004?ooool00ooo003oooooooooo`28oooooaGoo`009Oooool1o`00007ooooo0000
0ol0003oooooooooo`0[ooooo`;oogl000?oooooool00?ooool01_ooool4oomo00Cooooo2?oo000A
ooooo`03ool00?oooooooooo08Oooooo5Ooo000Uooooo`7o00000Oooool00003o`000?oooooooooo
02[ooooo1?ooO`000oooooooo`00ooooo`06ooooo`;oogl01Oooool8ool000_ooooo0_ooO`05oooo
o`03ool00?oooooooooo00Wooooo0_ooO`1koooooaGoo`009Oooool1o`00007ooooo00000ol0003o
ooooooooo`0Zooooo`Coogl00_ooool00ooo003oooooooooo`0<ooooo`Koo`002oooool4oomo00Co
oooo00?oo`00ooooooooool02?ooool4oomo07[ooooo5Ooo000Uooooo`7o00000Oooool00003o`00
0?oooooooooo02_ooooo0_ooO`04ooooo`03ool00?oooooooooo00cooooo1?oo000<ooooo`Coogl0
1Oooool00ooo003oooooooooo`07ooooo`Coogl0N_oooolEool002Gooooo0Ol00001ooooo`0000?o
0000ooooooooool0<_ooool2ool001gooooo0_ooO`07ooooo`03ool00?oooooooooo00Oooooo0_oo
O`2eooooo`7o00000Oooool00003o`000?oooooooooo03Cooooo00?oo`00ooooooooool09?ooool0
0ooo003oooooooooo`2mooooo`7o00000Oooool00003o`000?oooooooooo03Gooooo00?oo`00oooo
ooooool09?ooool00ooo003oooooooooo`2looooo`7o00000Oooool00003o`000?oooooooooo03Ko
oooo0_oo000Uooooo`03ool00?oooooooooo0;_ooooo0Ol00001ooooo`0000?o0000ooooooooool0
>?ooool2ool00003oomo0?oooooooooo00;oogl07_ooool00ooo003oooooooooo`2kooooo`7o0000
0Oooool00003o`000?oooooooooo03Sooooo0_ooO`02ool000Coogl07_ooool00ooo003ooooooooo
o`2jooooo`7o00000Oooool00003o`000?oooooooooo03Sooooo1?ooO`02ool000;oogl07_ooool0
0ooo003oooooooooo`2jooooo`7o00000Oooool00003o`000?oooooooooo03Wooooo1OooO`000ooo
003oooooooooo`0Mooooo`03ool00?ooO`3oogl00;[ooooo0Ol00001ooooo`0000?o0000oooooooo
ool0>oooool4oomo00;oo`007Oooool01?ooO`3oo`00oomo0?ooO`2iooooo`7o00000Oooool00003
o`000?oooooooooo03cooooo0_ooO`03ooooo`;oo`006oooool01?ooO`3oo`00oomo0?ooO`2ioooo
o`7o00000Oooool00003o`000?oooooooooo04?ooooo0_oo000Jooooo`03oomo0?oo003ooooo0;Wo
oooo0Ol00001ooooo`0000?o0000ooooooooool0AOooool2ool001Wooooo00?oo`00ooooooooool0
^?ooool1o`00007ooooo00000ol0003oooooooooo`17ooooo`;oo`005Oooool2ool00;_ooooo0Ol0
0001ooooo`0000?o0000ooooooooool0BOooool3ool0013ooooo0_oo002mooooo`7o00000Oooool0
0003o`000?oooooooooo037ooooo0_ooO`0Iooooo`?oo`003?ooool00ooo003oooooooooo`2moooo
o`7o00000Oooool00003o`000?oooooooooo033ooooo1?ooO`0Kooooo`Koo`001?ooool2ool00<3o
oooo0Ol00001ooooo`0000?o0000ooooooooool0<?ooool4oomo027ooooo1?oo0032ooooo`7o0000
0Oooool00003o`000?oooooooooo037ooooo0_ooO`3Xooooo`7o00000Oooool00003o`000?oooooo
oooo0?oooooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001oooo
o`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo
7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000
ooooooooool0OOooool2oomo09cooooo0Ol00001ooooo`0000?o0000ooooooooool0O?ooool4oomo
09_ooooo0Ol00001ooooo`0000?o0000ooooooooool0E?ooool2oomo02Kooooo1?ooO`2Kooooo`7o
00000Oooool00003o`000?oooooooooo05?ooooo1?ooO`0Vooooo`;oogl0W?ooool1o`00007ooooo
00000ol0003oooooooooo`1Cooooo`Coogl0a?ooool1o`00007ooooo00000ol0003oooooooooo`1D
ooooo`;oogl0aOooool1o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001oooo
o`0000?o0000ooooooooool0Hoooool2oomo00Cooooo0_ooO`2`ooooo`7o00000Oooool00003o`00
0?oooooooooo06;ooooo1?ooO`02ooooo`Coogl0[oooool1o`00007ooooo00000ol0003ooooooooo
o`1Rooooo`Coogl00_ooool4oomo0:oooooo0Ol00001ooooo`0000?o0000ooooooooool0Hoooool2
oomo00Cooooo0_ooO`2`ooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00
007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0
oooooolLooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo0000
0ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLoooo
o`7o00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003ooooo
ooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Ooo
ool00003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooo
oacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`00
0?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol0
0001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo
0?oooooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`00
00?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?oo
ool1o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000oooo
ooooool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007o
oooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooo
oolLooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0
003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o
00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003ooooooooo
o`3ooooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool0
0003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooooaco
oooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oo
oooooooo0?oooooo1?ooool2oomo01Kooooo0Ol00001ooooo`0000?o0000ooooooooool0ooooool3
ooooo`Coogl05Oooool1o`00007ooooo00000ol0003oooooooooo`3oooooo`?ooooo1?ooO`0Eoooo
o`7o00000Oooool00003o`000?oooooooooo0?oooooo1?ooool2oomo01Kooooo0Ol00001ooooo`00
00?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?oo
ool1o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000oooo
ooooool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007o
oooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooo
oolLooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0
003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o
00000Oooool00003o`000?oooooooooo0;Gooooo0_ooO`1Tooooo`7o00000Oooool00003o`000?oo
oooooooo0;Cooooo1?ooO`1Sooooo`7o00000Oooool00003o`000?oooooooooo0;Cooooo1?ooO`1S
ooooo`7o00000Oooool00003o`000?oooooooooo0;Gooooo0_ooO`0eooooo`;oogl0;Oooool1o`00
007ooooo00000ol0003oooooooooo`3Tooooo`;oogl01Oooool4oomo02cooooo0Ol00001ooooo`00
00?o0000ooooooooool0hoooool4oomo00Cooooo1?ooO`0/ooooo`7o00000Oooool00003o`000?oo
oooooooo0<?ooooo0_ooO`0Nooooo`Coogl01Oooool2oomo02gooooo0Ol00001ooooo`0000?o0000
ooooooooool0`_ooool4oomo00_o003o4oooool2oomo03Gooooo0Ol00001ooooo`0000?o0000oooo
ooooool0`_ooool4o`00o`_ooooo0_l00?m8ooooo`7o00000Oooool00003o`000?oooooooooo0;ko
oooo1?l00?l00oooooooogl0oomo000>ooooo`;o003oA_ooool1o`00007ooooo00000ol0003ooooo
ooooo`2iooooo`;oogl00ol00?lGooooo`;o003o2Oooool2oomo03Wooooo0Ol00001ooooo`0000?o
0000ooooooooool0]oooool4o`00o`03oomo0?oooooooooo01Wooooo0_l00?l6ooooo`Coogl0>?oo
ool1o`00007ooooo00000ol0003oooooooooo`2dooooo`?o003o00?ooooooomo0?ooO`000_ooO`0L
ooooo`03o`00oooooooooooo00Cooooo1?ooO`03ooooo`;oogl0<oooool1o`00007ooooo00000ol0
003oooooooooo`2booooo`;o003o0oooO`02ooooo`;oogl04oooool2oomo00Sooooo00?o003ooooo
ooooool01Oooool2oomo00?ooooo1?ooO`0booooo`7o00000Oooool00003o`000?oooooooooo0;3o
oooo0_l00?l00oooooooogl0oomo0002oomo00Kooooo0_ooO`0>ooooo`Coogl01oooool00ol00?oo
ooooooooo`0:ooooo`Coogl0<_ooool1o`00007ooooo00000ol0003oooooooooo`2^ooooo`;o003o
1?ooool2oomo00Kooooo1?ooO`0=ooooo`Coogl01oooool00ol00?ooooooooooo`0;ooooo`;oogl0
<oooool1o`00007ooooo00000ol0003oooooooooo`2;ooooo`;oogl08?ooool00ol00?oooooooooo
o`04ooooo`;oogl01_ooool4oomo00kooooo0_ooO`09ooooo`03o`00oooooooooooo03oooooo0Ol0
0001ooooo`0000?o0000ooooooooool0R_ooool4oomo01gooooo0_l00?l6ooooo`Coogl01_ooool2
oomo01[ooooo00?o003oooooooooool0?oooool1o`00007ooooo00000ol0003oooooooooo`2:oooo
o`Coogl07?ooool00ol00?ooooooooooo`06ooooo`Coogl08_ooool00ol00?ooooooooooo`0ooooo
o`7o00000Oooool00003o`000?oooooooooo08_ooooo0_ooO`0Kooooo`;o003o2_ooool2oomo02?o
oooo00?o003oooooooooool0?oooool1o`00007ooooo00000ol0003oooooooooo`2Fooooo`;oogl0
3_ooool2o`00ob[ooooo0_ooO`05ooooo`03o`00oooooooooooo03oooooo0Ol00001ooooo`0000?o
0000ooooooooool0UOooool4oomo00cooooo00Co003oooooooooO`3oogl0:?ooool4oomo00?ooooo
00?o003oooooooooool0@?ooool1o`00007ooooo00000ol0003oooooooooo`2Eooooo`Coogl02_oo
ool2o`00o`03ooooooooO`3oogl000;oogl09oooool4oomo00?ooooo00?o003oooooooooool0@?oo
ool1o`00007ooooo00000ol0003oooooooooo`2Fooooo`;oogl02_ooool01?l00?oooooooooooooo
ool4oomo02Sooooo0_ooO`04ooooo`03o`00oooooooooooo043ooooo0Ol00001ooooo`0000?o0000
ooooooooool0XOooool00ol00?ooooooooooo`03ooooo`;oogl0;_ooool00ol00?ooooooooooo`11
ooooo`7o00000Oooool00003o`000?oooooooooo0:3ooooo00?o003oooooooooool0<oooool00ol0
0?ooooooooooo`0Booooo`;oogl0;_ooool1o`00007ooooo00000ol0003oooooooooo`2Nooooo`;o
003o=Oooool00ol00?ooooooooooo`0Booooo`Coogl0;Oooool1o`00007ooooo00000ol0003ooooo
ooooo`2Mooooo`03o`00oooooooooooo01Gooooo1?l00?lLooooo`03o`00ooooO`3oogl001;ooooo
1?ooO`0]ooooo`7o00000Oooool00003o`000?oooooooooo09cooooo00?o003oooooooooool05Ooo
ool6o`00oa[ooooo00?o003ooomo0?ooO`000_ooO`0Booooo`;oogl0;_ooool1o`00007ooooo0000
0ol0003oooooooooo`2Kooooo`03o`00oooooooooooo01Gooooo2?l00?lHooooo`03o`00oooooooo
ogl000?oogl0@_ooool1o`00007ooooo00000ol0003oooooooooo`2Kooooo`03o`00oooooooooooo
01Gooooo2?l00?lGooooo`04o`00ooooooooooooooooo`;oogl0@oooool1o`00007ooooo00000ol0
003oooooooooo`2Jooooo`03o`00oooooooooooo01Kooooo2?l00?lFooooo`03o`00oooooooooooo
04Oooooo0Ol00001ooooo`0000?o0000ooooooooool0VOooool00ol00?ooooooooooo`0<ooooo`;o
ogl02?ooool00oooO`3o003oo`00o`06o`00oaGooooo00?o003oooooooooool00_ooO`16ooooo`7o
00000Oooool00003o`000?oooooooooo09Wooooo00?o003oooooooooool02_ooool5oomo00Oooooo
0_ooO`06o`00oa?ooooo0_ooO`000ol00?ooooooooooo`04oomo04Gooooo0Ol00001ooooo`0000?o
0000ooooooooool0V?ooool00ol00?ooooooooooo`0:ooooo`Koogl02?ooool2oomo00Co003o4ooo
ool2oomo00;o003o0_ooool4oomo04Gooooo0Ol00001ooooo`0000?o0000ooooooooool0V?ooool0
0ol00?ooooooooooo`0:ooooo`Googl08_ooool01?ooO`3o003ooomo0?ooO`03ooooo`;oogl0A_oo
ool1o`00007ooooo00000ol0003oooooooooo`1fooooo`;oogl07oooool00ol00?ooooooooooo`0<
ooooo`;oogl09?ooool00ol00?ooogl0oomo001<ooooo`7o00000Oooool00003o`000?oooooooooo
07Gooooo1?ooO`0Nooooo`03o`00oooooooooooo037ooooo00?o003oooooooooool0COooool1o`00
007ooooo00000ol0003oooooooooo`1eooooo`Coogl02_ooool2oomo017ooooo00?o003ooooooooo
ool0<Oooool00ol00?ooooooooooo`1>ooooo`7o00000Oooool00003o`000?oooooooooo07Kooooo
0_ooO`0:ooooo`Coogl03oooool00ol00?ooooooooooo`0Hooooo`;oogl05oooool00ol00?oooooo
ooooo`1?ooooo`7o00000Oooool00003o`000?oooooooooo08;ooooo1?ooO`0?ooooo`03o`00oooo
oooooooo01Oooooo1?ooO`0Dooooo`;o003oD_ooool1o`00007ooooo00000ol0003oooooooooo`23
ooooo`;oogl03oooool00ol00?ooooooooooo`0Booooo`;oogl01?ooool4oomo017ooooo0ol00?mD
ooooo`7o00000Oooool00003o`000?oooooooooo09Cooooo00?o003oooooooooool04Oooool4oomo
00Cooooo0_ooO`0@ooooo`;o003oEoooool1o`00007ooooo00000ol0003oooooooooo`2Dooooo`03
o`00oooooooooooo017ooooo1?ooO`0Eooooo`03o`00oooooooooooo05Oooooo0Ol00001ooooo`00
00?o0000ooooooooool0U?ooool00ol00?ooooooooooo`0Booooo`;oogl05?ooool2o`00oe[ooooo
0Ol00001ooooo`0000?o0000ooooooooool0U?ooool00ol00?ooooooooooo`0Vooooo`;o003oG?oo
ool1o`00007ooooo00000ol0003oooooooooo`2Eooooo`03o`00oooooooooooo02Cooooo00?o003o
ooooooooool0G?ooool1o`00007ooooo00000ol0003oooooooooo`2Eooooo`03o`00oooooooooooo
02;ooooo0_l00?mOooooo`7o00000Oooool00003o`000?oooooooooo09Gooooo00?o003ooooooooo
ool08?ooool2o`00of7ooooo0Ol00001ooooo`0000?o0000ooooooooool0Q?ooool2oomo00oooooo
0_l00?lOooooo`;o003oHoooool1o`00007ooooo00000ol0003oooooooooo`23ooooo`Coogl04?oo
ool2o`00oa[ooooo0ol00?mUooooo`7o00000Oooool00003o`000?oooooooooo08?ooooo1?ooO`0B
ooooo`;o003o5?ooool4o`00ofSooooo0Ol00001ooooo`0000?o0000ooooooooool0Q?ooool2oomo
01Gooooo0ol00?l>ooooo`?o003o0oooool2oomo06Oooooo0Ol00001ooooo`0000?o0000oooooooo
ool0W_ooool3o`00o`Gooooo1_l00?l5ooooo`Coogl0I_ooool1o`00007ooooo00000ol0003ooooo
ooooo`2Qooooo`Go003o2oooool4oomo06Kooooo0Ol00001ooooo`0000?o0000ooooooooool0/_oo
ool2oomo06Oooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool0
0003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003oooooooooo`1kooooo`;o
ogl0W_ooool1o`00007ooooo00000ol0003oooooooooo`1jooooo`Coogl0WOooool1o`00007ooooo
00000ol0003oooooooooo`1jooooo`Coogl08?ooool2oomo07_ooooo0Ol00001ooooo`0000?o0000
ooooooooool0Noooool2oomo023ooooo1?ooO`1jooooo`7o00000Oooool00003o`000?oooooooooo
09gooooo1?ooO`1jooooo`7o00000Oooool00003o`000?oooooooooo093ooooo0_ooO`0<ooooo`;o
ogl0Noooool1o`00007ooooo00000ol0003oooooooooo`2?ooooo`Coogl0R?ooool1o`00007ooooo
00000ol0003oooooooooo`2?ooooo`Coogl0R?ooool1o`00007ooooo00000ol0003oooooooooo`2@
ooooo`;oogl08oooool2oomo06Cooooo0Ol00001ooooo`0000?o0000ooooooooool0]?ooool4oomo
06?ooooo0Ol00001ooooo`0000?o0000ooooooooool0]?ooool4oomo06?ooooo0Ol00001ooooo`00
00?o0000ooooooooool0]Oooool2oomo06Cooooo0Ol00001ooooo`0000?o0000ooooooooool0oooo
oolLooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0
003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o
00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003ooooooooo
o`3ooooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool0
0003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooooaco
oooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oo
oooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001
ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo0?oo
oooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o
0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1
o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000oooooooo
ool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo
00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolL
ooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003o
ooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o0000
0Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3o
oooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003
o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo
0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oooooo
oooo0?oooooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001oooo
o`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo
7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000
ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo08kooooo0_ooO`2;oooo
o`7o00000Oooool00003o`000?oooooooooo08gooooo1?ooO`2:ooooo`7o00000Oooool00003o`00
0?oooooooooo08gooooo1?ooO`2:ooooo`7o00000Oooool00003o`000?oooooooooo08kooooo0_oo
O`2;ooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0
003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o
00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003ooooooooo
o`3ooooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool0
0003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooooaco
oooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oo
oooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001
ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo0?oo
oooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o
0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1
o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000oooooooo
ool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo
00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolL
ooooo`7o00000Oooool00?oo00008?l00001ooooo`00\
\>"],
  ImageRangeCache->{{{0, 287}, {287, 0}} -> {-1.01089, -1.01089, 0.00704453, \
0.00704453}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.49505 0.5 0.49505 [
[ 0 0 -0.125 0 ]
[ 0 0 -0.125 0 ]
[ 0 1 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
0 0 m
1 0 L
s
0 0 m
0 1 L
s
0 1 m
1 1 L
s
1 0 m
1 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
1 .5 0 r
.015 w
.03175 .1355 Mdot
.03435 .12523 Mdot
.11137 .12765 Mdot
.14107 .18841 Mdot
.16218 .24538 Mdot
.17294 .21053 Mdot
.18267 .18577 Mdot
.18434 .1304 Mdot
.18553 .30956 Mdot
.20401 .239 Mdot
.21247 .27571 Mdot
.21687 .20845 Mdot
.22376 .2799 Mdot
.22832 .27485 Mdot
.29063 .20974 Mdot
.29686 .25079 Mdot
.30487 .22936 Mdot
.30683 .34623 Mdot
.32055 .20902 Mdot
.32574 .21979 Mdot
.34472 .28521 Mdot
.35998 .36393 Mdot
.36335 .24976 Mdot
.3794 .36608 Mdot
.42386 .66992 Mdot
.44391 .74519 Mdot
.45059 .34198 Mdot
.47208 .67586 Mdot
.47436 .71381 Mdot
.49778 .59825 Mdot
.50874 .91643 Mdot
.51516 .76219 Mdot
.53655 .61374 Mdot
.56563 .75219 Mdot
.59189 .65665 Mdot
.59581 .61604 Mdot
.59923 .6556 Mdot
.60292 .68499 Mdot
.62656 .67779 Mdot
.63555 .72451 Mdot
.63919 .652 Mdot
.64169 .6004 Mdot
.64246 .58611 Mdot
.64496 .54267 Mdot
.64608 .77288 Mdot
.65077 .64308 Mdot
.66065 .57816 Mdot
.67474 .59169 Mdot
.69296 .563 Mdot
.72815 .65902 Mdot
.73169 .58879 Mdot
.74669 .61318 Mdot
.74821 .65474 Mdot
.75963 .63781 Mdot
.79673 .57809 Mdot
.80925 .55852 Mdot
.81525 .58444 Mdot
.83417 .62985 Mdot
.83598 .55526 Mdot
.91595 .49319 Mdot
1 0 0 r
.005 w
.16128 .17044 m
.18734 .17269 L
.21339 .17909 L
.2345 .18734 L
.23945 .19126 L
.2655 .20415 L
.27874 .21339 L
.29156 .22295 L
.31204 .23945 L
.31761 .24532 L
.33549 .2655 L
.34367 .28341 L
.34499 .29156 L
.34367 .29798 L
.31761 .3104 L
.29156 .30711 L
.2655 .30014 L
.24507 .29156 L
.23945 .28747 L
.21339 .27402 L
.20155 .2655 L
.18734 .25472 L
.16884 .23945 L
.16128 .2313 L
.14618 .21339 L
.13806 .18734 L
.16128 .17044 L
s
0 0 1 r
.65633 .57701 m
.68239 .56842 L
.70844 .56313 L
.7345 .56168 L
.76055 .5752 L
.76359 .57817 L
.76859 .60422 L
.76055 .62333 L
.75627 .63028 L
.7345 .65485 L
.73298 .65633 L
.70844 .6775 L
.69922 .68239 L
.68239 .69294 L
.65633 .70579 L
.64983 .70844 L
.63028 .71539 L
.60422 .72268 L
.57817 .72651 L
.55211 .7214 L
.53145 .70844 L
.52926 .68239 L
.54239 .65633 L
.55211 .63983 L
.56625 .63028 L
.57817 .6193 L
.60119 .60422 L
.60422 .60227 L
.63028 .58726 L
.65315 .57817 L
.65633 .57701 L
s
1 0 0 r
.03 w
.24141 .24033 Mdot
0 0 1 r
.64872 .64417 Mdot
1 0 0 r
.79703 .00495 m
.79703 .25248 L
.87129 .25248 L
.87129 .00495 L
F
0 0 1 r
.89604 .00495 m
.89604 .00495 L
.9703 .00495 L
.9703 .00495 L
F
1 0 1 r
.04 w
.18434 .1304 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P000182000`400?l00000o`00003ooooooolQ
ooooo`00ool0000Po`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`00
00?o0000ooooooooool0hOoooolEool002Gooooo0Ol00001ooooo`0000?o0000ooooooooool0hOoo
oolEool002Gooooo0Ol00001ooooo`0000?o0000ooooooooool0hOoooolEool002Gooooo0Ol00001
ooooo`0000?o0000ooooooooool0hOoooolEool002Gooooo0Ol00001ooooo`0000?o0000oooooooo
ool0hOoooolEool002Gooooo0Ol00001ooooo`0000?o0000ooooooooool0hOoooolEool002Gooooo
0Ol00001ooooo`0000?o0000ooooooooool0hOoooolEool002Gooooo0Ol00001ooooo`0000?o0000
ooooooooool0hOoooolEool002Gooooo0Ol00001ooooo`0000?o0000ooooooooool0hOoooolEool0
02Gooooo0Ol00001ooooo`0000?o0000ooooooooool0hOoooolEool002Gooooo0Ol00001ooooo`00
00?o0000ooooooooool0hOoooolEool002Gooooo0Ol00001ooooo`0000?o0000ooooooooool0hOoo
oolEool002Gooooo0Ol00001ooooo`0000?o0000ooooooooool0hOoooolEool002Gooooo0Ol00001
ooooo`0000?o0000ooooooooool0hOoooolEool002Gooooo0Ol00001ooooo`0000?o0000oooooooo
ool0hOoooolEool002Gooooo0Ol00001ooooo`0000?o0000ooooooooool0hOoooolEool002Gooooo
0Ol00001ooooo`0000?o0000ooooooooool0hOoooolEool002Gooooo0Ol00001ooooo`0000?o0000
ooooooooool0hOoooolEool002Gooooo0Ol00001ooooo`0000?o0000ooooooooool0hOoooolEool0
02Gooooo0Ol00001ooooo`0000?o0000ooooooooool0hOoooolEool002Gooooo0Ol00001ooooo`00
00?o0000ooooooooool0hOoooolEool002Gooooo0Ol00001ooooo`0000?o0000ooooooooool0hOoo
oolEool002Gooooo0Ol00001ooooo`0000?o0000ooooooooool0hOoooolEool002Gooooo0Ol00001
ooooo`0000?o0000ooooooooool0hOoooolEool002Gooooo0Ol00001ooooo`0000?o0000oooooooo
ool0hOoooolEool002Gooooo0Ol00001ooooo`0000?o0000ooooooooool0hOoooolEool002Gooooo
0Ol00001ooooo`0000?o0000ooooooooool0hOoooolEool002Gooooo0Ol00001ooooo`0000?o0000
ooooooooool0hOoooolEool002Gooooo0Ol00001ooooo`0000?o0000ooooooooool0hOoooolEool0
02Gooooo0Ol00001ooooo`0000?o0000ooooooooool0hOoooolEool002Gooooo0Ol00001ooooo`00
00?o0000ooooooooool0;oooool5ool0ojgooooo5Ooo000Uooooo`7o00000Oooool00003o`000?oo
oooooooo02kooooo1ooo0?n/oooooaGoo`009Oooool1o`00007ooooo00000ol0003oooooooooo`06
ooooo`;oogl09Oooool9ool0oj_ooooo5Ooo000Uooooo`7o00000Oooool00003o`000?oooooooooo
00Gooooo1?ooO`0Cooooo`;oogl03_ooool;ool0oj[ooooo5Ooo000Uooooo`7o00000Oooool00003
o`000?oooooooooo00Gooooo1?ooO`0Booooo`Coogl03Oooool;ool0oj[ooooo5Ooo000Uooooo`7o
00000Oooool00003o`000?oooooooooo00Gooooo0oooO`0Cooooo`Coogl03Oooool;ool0oj[ooooo
5Ooo000Uooooo`7o00000Oooool00003o`000?oooooooooo00Cooooo1?ooO`0Dooooo`;oogl03_oo
ool;ool0oj[ooooo5Ooo000Uooooo`7o00000Oooool00003o`000?oooooooooo00Cooooo1?ooO`0T
ooooo`_oo`3oZ_oooolEool002Gooooo0Ol00001ooooo`0000?o0000ooooooooool01Oooool2oomo
02Kooooo2Ooo0?n[oooooaGoo`009Oooool1o`00007ooooo00000ol0003oooooooooo`0^ooooo`Oo
o`3o[?oooolEool002Gooooo0Ol00001ooooo`0000?o0000ooooooooool0;oooool5ool0ojgooooo
5Ooo000Uooooo`7o00000Oooool00003o`000?oooooooooo0>7ooooo5Ooo000Uooooo`7o00000Ooo
ool00003o`000?oooooooooo0>7ooooo5Ooo000Uooooo`7o00000Oooool00003o`000?oooooooooo
0>7ooooo5Ooo000Uooooo`7o00000Oooool00003o`000?oooooooooo0>7ooooo5Ooo000Uooooo`7o
00000Oooool00003o`000?oooooooooo0>7ooooo5Ooo000Uooooo`7o00000Oooool00003o`000?oo
oooooooo02[ooooo1_oo002aoooooaGoo`009Oooool1o`00007ooooo00000ol0003oooooooooo`0Y
ooooo`03ool00?oooooooooo00Cooooo1Ooo002/oooooaGoo`009Oooool1o`00007ooooo00000ol0
003oooooooooo`0Wooooo`;oo`003?ooool4ool00:Sooooo5Ooo000Uooooo`7o00000Oooool00003
o`000?oooooooooo02Kooooo00?oo`00ooooooooool04?ooool4ool00:Cooooo5Ooo000Uooooo`7o
00000Oooool00003o`000?oooooooooo02Cooooo00?oogl0ool00?ooool02Oooool2oomo00_ooooo
0ooo002QoooooaGoo`009Oooool1o`00007ooooo00000ol0003oooooooooo`0Sooooo`04oomo0?oo
003oogl0oomo00Sooooo1?ooO`0=ooooo`03ool00?oooooooooo09kooooo5Ooo000Uooooo`7o0000
0Oooool00003o`000?oooooooooo02?ooooo00Coogl0ool00?ooO`3oogl02?ooool4oomo00kooooo
0_oo002NoooooaGoo`009Oooool1o`00007ooooo00000ol0003oooooooooo`0Tooooo`03oomo0?oo
003ooooo00Wooooo0_ooO`0Aooooo`;oo`00W?oooolEool002Gooooo0Ol00001ooooo`0000?o0000
ooooooooool09Oooool00ooo003oooooooooo`0Mooooo`;oo`00V_oooolEool002Gooooo0Ol00001
ooooo`0000?o0000ooooooooool09Oooool00ooo003oooooooooo`0Oooooo`;oo`00V?oooolEool0
02Gooooo0Ol00001ooooo`0000?o0000ooooooooool09_ooool00ooo003oooooooooo`0Aooooo`;o
ogl03Oooool2ool000Cooooo0_ooO`07ooooo`;oogl0QooooolEool002Gooooo0Ol00001ooooo`00
00?o0000ooooooooool09_ooool00ooo003oooooooooo`05ooooo`;oogl02Oooool4oomo00kooooo
00?oo`00ooooooooool01?ooO`05ooooo`Coogl0Q_oooolEool002Gooooo0Ol00001ooooo`0000?o
0000ooooooooool09_ooool00ooo003oooooooooo`04ooooo`Coogl02?ooool4oomo00oooooo00?o
o`00ooooooooO`000oooO`05ooooo`Coogl0Q_oooolEool002Gooooo0Ol00001ooooo`0000?o0000
ooooooooool09oooool00ooo003oooooooooo`03ooooo`Coogl02Oooool2oomo017ooooo00Coo`00
ooooooooO`3oogl01oooool3oomo08Kooooo5Ooo000Uooooo`7o00000Oooool00003o`000?oooooo
oooo02Oooooo00?oo`00ooooooooool01?ooool2oomo01kooooo00?oo`00ooooooooool01oooool4
oomo08Gooooo5Ooo000Uooooo`7o00000Oooool00003o`000?oooooooooo02Sooooo00?oo`00oooo
ooooool09?ooool00ooo003oooooooooo`06ooooo`Coogl0QOoooolEool002Gooooo0Ol00001oooo
o`0000?o0000ooooooooool0:Oooool00ooo003oooooooooo`0Tooooo`;oo`0000?ooooooomo0?oo
O`001?ooool2oomo08Kooooo5Ooo000Uooooo`7o00000Oooool00003o`000?oooooooooo02[ooooo
00?oo`00ooooooooool04oooool4ool000kooooo00Coo`00oomo0?ooO`3oogl0RooooolEool002Go
oooo0Ol00001ooooo`0000?o0000ooooooooool0:oooool00ooo003oooooooooo`0Aooooo`Koo`00
3Oooool01?ooO`3oo`00ool00?ooO`2;oooooaGoo`009Oooool1o`00007ooooo00000ol0003ooooo
ooooo`0/ooooo`03ool00?oooooooooo00Sooooo0_ooO`05ooooo`Soo`003Oooool2oomo0003ool0
0?oooooooooo08Wooooo5Ooo000Uooooo`7o00000Oooool00003o`000?oooooooooo02gooooo00?o
o`00ooooooooool01_ooool4oomo00Cooooo2?oo000@ooooo`03ool00?oooooooooo08Sooooo5Ooo
000Uooooo`7o00000Oooool00003o`000?oooooooooo02_ooooo0_ooO`000oooooooo`00ooooo`06
ooooo`Coogl01?ooool8ool0017ooooo00?oo`00ooooooooool0QooooolEool002Gooooo0Ol00001
ooooo`0000?o0000ooooooooool0:_ooool4oomo0003oooooooo003ooooo00Kooooo0_ooO`05oooo
o`Soo`002oooool2oomo00Gooooo00?oo`00ooooooooool02Oooool2oomo07_ooooo5Ooo000Uoooo
o`7o00000Oooool00003o`000?oooooooooo02[ooooo1?ooO`02ooooo`03ool00?oooooooooo00co
oooo1_oo000;ooooo`Coogl01?ooool00ooo003oooooooooo`08ooooo`Coogl0N_oooolEool002Go
oooo0Ol00001ooooo`0000?o0000ooooooooool0:oooool2oomo00Cooooo00?oo`00ooooooooool0
3?ooool4ool000cooooo1?ooO`05ooooo`03ool00?oooooooooo00Oooooo1?ooO`1joooooaGoo`00
9Oooool1o`00007ooooo00000ol0003oooooooooo`0booooo`;oo`007Oooool2oomo00Oooooo00?o
o`00ooooooooool01oooool2oomo0;Gooooo0Ol00001ooooo`0000?o0000ooooooooool0=?ooool0
0ooo003oooooooooo`0Tooooo`03ool00?oooooooooo0;gooooo0Ol00001ooooo`0000?o0000oooo
ooooool0=Oooool00ooo003oooooooooo`0Tooooo`03ool00?oooooooooo0;cooooo0Ol00001oooo
o`0000?o0000ooooooooool0=_ooool2ool002Gooooo00?oo`00ooooooooool0^oooool1o`00007o
oooo00000ol0003oooooooooo`0hooooo`;oo`0000?oogl0ooooooooool00_ooO`0Nooooo`03ool0
0?oooooooooo0;_ooooo0Ol00001ooooo`0000?o0000ooooooooool0>?ooool2oomo00;oo`001?oo
O`0Nooooo`03ool00?oooooooooo0;[ooooo0Ol00001ooooo`0000?o0000ooooooooool0>?ooool4
oomo00;oo`000_ooO`0Nooooo`03ool00?oooooooooo0;[ooooo0Ol00001ooooo`0000?o0000oooo
ooooool0>Oooool5oomo0003ool00?oooooooooo01gooooo00?oo`00oomo0?ooO`00^_ooool1o`00
007ooooo00000ol0003oooooooooo`0kooooo`Coogl00_oo000Mooooo`04oomo0?oo003oogl0oomo
0;Wooooo0Ol00001ooooo`0000?o0000ooooooooool0??ooool2oomo00?ooooo0_oo000Kooooo`04
oomo0?oo003oogl0oomo0;Wooooo0Ol00001ooooo`0000?o0000ooooooooool0@oooool2ool001[o
oooo00?oogl0ool00?ooool0^Oooool1o`00007ooooo00000ol0003oooooooooo`15ooooo`;oo`00
6Oooool00ooo003oooooooooo`2hooooo`7o00000Oooool00003o`000?oooooooooo04Oooooo0_oo
000Eooooo`;oo`00^oooool1o`00007ooooo00000ol0003oooooooooo`19ooooo`?oo`004?ooool2
ool00;gooooo0Ol00001ooooo`0000?o0000ooooooooool0<Oooool2oomo01Wooooo0ooo000<oooo
o`03ool00?oooooooooo0;gooooo0Ol00001ooooo`0000?o0000ooooooooool0<?ooool4oomo01_o
oooo1_oo0004ooooo`;oo`00`?ooool1o`00007ooooo00000ol0003oooooooooo`0`ooooo`Coogl0
8Oooool4ool00<;ooooo0Ol00001ooooo`0000?o0000ooooooooool0<Oooool2oomo0>Sooooo0Ol0
0001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo
0?oooooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`00
00?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?oo
ool1o`00007ooooo00000ol0003oooooooooo`1mooooo`;oogl0W?ooool1o`00007ooooo00000ol0
003oooooooooo`1looooo`Coogl0Voooool1o`00007ooooo00000ol0003oooooooooo`1Dooooo`;o
ogl09_ooool4oomo09_ooooo0Ol00001ooooo`0000?o0000ooooooooool0Doooool4oomo02Kooooo
0_ooO`2Looooo`7o00000Oooool00003o`000?oooooooooo05?ooooo1?ooO`34ooooo`7o00000Ooo
ool00003o`000?oooooooooo05Cooooo0_ooO`35ooooo`7o00000Oooool00003o`000?oooooooooo
0?oooooo7?ooool1o`00007ooooo00000ol0003oooooooooo`1Sooooo`;oogl01?ooool2oomo0;3o
oooo0Ol00001ooooo`0000?o0000ooooooooool0H_ooool4oomo00;ooooo1?ooO`2_ooooo`7o0000
0Oooool00003o`000?oooooooooo06;ooooo1?ooO`02ooooo`Coogl0[oooool1o`00007ooooo0000
0ol0003oooooooooo`1Sooooo`;oogl01?ooool2oomo0;3ooooo0Ol00001ooooo`0000?o0000oooo
ooooool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007o
oooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooo
oolLooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0
003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o
00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003ooooooooo
o`3ooooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool0
0003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooooaco
oooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oo
oooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001
ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo0?oo
oooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o
0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1
o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000oooooooo
ool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo
00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolL
ooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003o
ooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o0000
0Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3o
oooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003
o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo
0Ol00001ooooo`0000?o0000ooooooooool0ooooool4ooooo`;oogl05_ooool1o`00007ooooo0000
0ol0003oooooooooo`3oooooo`?ooooo1?ooO`0Eooooo`7o00000Oooool00003o`000?oooooooooo
0?oooooo0oooool4oomo01Gooooo0Ol00001ooooo`0000?o0000ooooooooool0ooooool4ooooo`;o
ogl05_ooool1o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o
0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1
o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000oooooooo
ool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo
00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolL
ooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003o
ooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0]Oooool2oomo06Cooooo
0Ol00001ooooo`0000?o0000ooooooooool0]?ooool4oomo06?ooooo0Ol00001ooooo`0000?o0000
ooooooooool0]?ooool4oomo06?ooooo0Ol00001ooooo`0000?o0000ooooooooool0]Oooool2oomo
03Gooooo0_ooO`0]ooooo`7o00000Oooool00003o`000?oooooooooo0>Cooooo0_ooO`05ooooo`Co
ogl0;?ooool1o`00007ooooo00000ol0003oooooooooo`3Sooooo`Coogl01?ooool4oomo02cooooo
0Ol00001ooooo`0000?o0000ooooooooool0`oooool2oomo01kooooo1?ooO`05ooooo`;oogl0;Ooo
ool1o`00007ooooo00000ol0003oooooooooo`32ooooo`Coogl02ol00?lCooooo`;oogl0=Oooool1
o`00007ooooo00000ol0003oooooooooo`32ooooo`Co003o2oooool2o`00odSooooo0Ol00001oooo
o`0000?o0000ooooooooool0__ooool4o`00o`03ooooooooO`3oogl000kooooo0_l00?m6ooooo`7o
00000Oooool00003o`000?oooooooooo0;Wooooo0_ooO`03o`00oaOooooo0_l00?l9ooooo`;oogl0
>Oooool1o`00007ooooo00000ol0003oooooooooo`2gooooo`Co003o00?oogl0ooooooooool06Ooo
ool2o`00o`Kooooo1?ooO`0hooooo`7o00000Oooool00003o`000?oooooooooo0;Cooooo0ol00?l0
0oooooooogl0oomo0002oomo01cooooo00?o003oooooooooool01?ooool4oomo00?ooooo0_ooO`0c
ooooo`7o00000Oooool00003o`000?oooooooooo0;;ooooo0_l00?l3oomo00;ooooo0_ooO`0Coooo
o`;oogl02?ooool00ol00?ooooooooooo`05ooooo`;oogl00oooool4oomo03;ooooo0Ol00001oooo
o`0000?o0000ooooooooool0/?ooool2o`00o`03ooooooooO`3oogl000;oogl01_ooool2oomo00ko
oooo1?ooO`07ooooo`03o`00oooooooooooo00[ooooo1?ooO`0booooo`7o00000Oooool00003o`00
0?oooooooooo0:kooooo0_l00?l4ooooo`;oogl01_ooool4oomo00gooooo1?ooO`07ooooo`03o`00
oooooooooooo00_ooooo0_ooO`0cooooo`7o00000Oooool00003o`000?oooooooooo08_ooooo0_oo
O`0Pooooo`03o`00oooooooooooo00Cooooo0_ooO`06ooooo`Coogl03_ooool2oomo00Wooooo00?o
003oooooooooool0?oooool1o`00007ooooo00000ol0003oooooooooo`2:ooooo`Coogl07Oooool2
o`00o`Kooooo1?ooO`06ooooo`;oogl06_ooool00ol00?ooooooooooo`0oooooo`7o00000Oooool0
0003o`000?oooooooooo08[ooooo1?ooO`0Looooo`03o`00oooooooooooo00Kooooo1?ooO`0Roooo
o`03o`00oooooooooooo03oooooo0Ol00001ooooo`0000?o0000ooooooooool0Roooool2oomo01_o
oooo0_l00?l:ooooo`;oogl08oooool00ol00?ooooooooooo`0oooooo`7o00000Oooool00003o`00
0?oooooooooo09Kooooo0_ooO`0>ooooo`;o003o:_ooool2oomo00Gooooo00?o003oooooooooool0
?oooool1o`00007ooooo00000ol0003oooooooooo`2Eooooo`Coogl03?ooool01?l00?oooooooomo
0?ooO`0Xooooo`Coogl00oooool00ol00?ooooooooooo`10ooooo`7o00000Oooool00003o`000?oo
oooooooo09Gooooo1?ooO`0:ooooo`;o003o00?ooooooomo0?ooO`000_ooO`0Wooooo`Coogl00ooo
ool00ol00?ooooooooooo`10ooooo`7o00000Oooool00003o`000?oooooooooo09Kooooo0_ooO`0:
ooooo`04o`00ooooooooooooooooo`Coogl0:?ooool2oomo00Cooooo00?o003oooooooooool0@?oo
ool1o`00007ooooo00000ol0003oooooooooo`2Qooooo`03o`00oooooooooooo00?ooooo0_ooO`0^
ooooo`03o`00oooooooooooo047ooooo0Ol00001ooooo`0000?o0000ooooooooool0X?ooool00ol0
0?ooooooooooo`0cooooo`03o`00oooooooooooo01;ooooo0_ooO`0^ooooo`7o00000Oooool00003
o`000?oooooooooo09kooooo0_l00?leooooo`03o`00oooooooooooo01;ooooo1?ooO`0]ooooo`7o
00000Oooool00003o`000?oooooooooo09gooooo00?o003oooooooooool05Oooool4o`00oacooooo
00?o003ooomo0?ooO`004_ooool4oomo02gooooo0Ol00001ooooo`0000?o0000ooooooooool0W?oo
ool00ol00?ooooooooooo`0Eooooo`Ko003o6_ooool00ol00?ooogl0oomo0002oomo01;ooooo0_oo
O`0^ooooo`7o00000Oooool00003o`000?oooooooooo09_ooooo00?o003oooooooooool05Oooool8
o`00oaSooooo00?o003oooooooooO`000oooO`12ooooo`7o00000Oooool00003o`000?oooooooooo
09_ooooo00?o003oooooooooool05Oooool8o`00oaOooooo00Co003ooooooooooooooooo0_ooO`13
ooooo`7o00000Oooool00003o`000?oooooooooo09[ooooo00?o003oooooooooool05_ooool8o`00
oaKooooo00?o003oooooooooool0Aoooool1o`00007ooooo00000ol0003oooooooooo`2Iooooo`03
o`00oooooooooooo00cooooo0_ooO`08ooooo`03oomo0?l00?oo003o00Ko003o5Oooool00ol00?oo
ooooooooo`02oomo04Kooooo0Ol00001ooooo`0000?o0000ooooooooool0VOooool00ol00?oooooo
ooooo`0:ooooo`Googl01oooool2oomo00Ko003o4oooool2oomo0003o`00oooooooooooo00Coogl0
AOooool1o`00007ooooo00000ol0003oooooooooo`2Hooooo`03o`00oooooooooooo00[ooooo1_oo
O`08ooooo`;oogl01?l00?lCooooo`;oogl00_l00?l2ooooo`Coogl0AOooool1o`00007ooooo0000
0ol0003oooooooooo`2Hooooo`03o`00oooooooooooo00[ooooo1OooO`0Rooooo`04oomo0?l00?oo
ogl0oomo00?ooooo0_ooO`16ooooo`7o00000Oooool00003o`000?oooooooooo07Kooooo0_ooO`0O
ooooo`03o`00oooooooooooo00cooooo0_ooO`0Tooooo`03o`00ooooO`3oogl004cooooo0Ol00001
ooooo`0000?o0000ooooooooool0MOooool4oomo01kooooo00?o003oooooooooool0<Oooool00ol0
0?ooooooooooo`1=ooooo`7o00000Oooool00003o`000?oooooooooo07Gooooo1?ooO`0:ooooo`;o
ogl04Oooool00ol00?ooooooooooo`0aooooo`03o`00oooooooooooo04kooooo0Ol00001ooooo`00
00?o0000ooooooooool0M_ooool2oomo00[ooooo1?ooO`0?ooooo`03o`00oooooooooooo01Sooooo
0_ooO`0Gooooo`03o`00oooooooooooo04oooooo0Ol00001ooooo`0000?o0000ooooooooool0P_oo
ool4oomo00oooooo00?o003oooooooooool05oooool4oomo01Cooooo0_l00?mBooooo`7o00000Ooo
ool00003o`000?oooooooooo08?ooooo0_ooO`0?ooooo`03o`00oooooooooooo01;ooooo0_ooO`04
ooooo`Coogl04Oooool3o`00oeCooooo0Ol00001ooooo`0000?o0000ooooooooool0U?ooool00ol0
0?ooooooooooo`0Aooooo`Coogl01?ooool2oomo013ooooo0_l00?mGooooo`7o00000Oooool00003
o`000?oooooooooo09Cooooo00?o003oooooooooool04Oooool4oomo01Gooooo00?o003ooooooooo
ool0Eoooool1o`00007ooooo00000ol0003oooooooooo`2Dooooo`03o`00oooooooooooo01;ooooo
0_ooO`0Dooooo`;o003oF_ooool1o`00007ooooo00000ol0003oooooooooo`2Dooooo`03o`00oooo
oooooooo02Kooooo0_l00?mLooooo`7o00000Oooool00003o`000?oooooooooo09Gooooo00?o003o
ooooooooool09?ooool00ol00?ooooooooooo`1Looooo`7o00000Oooool00003o`000?oooooooooo
09Gooooo00?o003oooooooooool08_ooool2o`00oeoooooo0Ol00001ooooo`0000?o0000oooooooo
ool0UOooool00ol00?ooooooooooo`0Pooooo`;o003oHOooool1o`00007ooooo00000ol0003ooooo
ooooo`24ooooo`;oogl03oooool2o`00oaoooooo0_l00?mSooooo`7o00000Oooool00003o`000?oo
oooooooo08?ooooo1?ooO`0@ooooo`;o003o6_ooool3o`00ofGooooo0Ol00001ooooo`0000?o0000
ooooooooool0Poooool4oomo01;ooooo0_l00?lDooooo`Co003oJ?ooool1o`00007ooooo00000ol0
003oooooooooo`24ooooo`;oogl05Oooool3o`00o`kooooo0ol00?l3ooooo`;oogl0Ioooool1o`00
007ooooo00000ol0003oooooooooo`2Nooooo`?o003o1Oooool6o`00o`Gooooo1?ooO`1Vooooo`7o
00000Oooool00003o`000?oooooooooo0:7ooooo1Ol00?l;ooooo`Coogl0I_ooool1o`00007ooooo
00000ol0003oooooooooo`2booooo`;oogl0Ioooool1o`00007ooooo00000ol0003oooooooooo`3o
oooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003
o`000?oooooooooo07_ooooo0_ooO`2Nooooo`7o00000Oooool00003o`000?oooooooooo07[ooooo
1?ooO`2Mooooo`7o00000Oooool00003o`000?oooooooooo07[ooooo1?ooO`0Pooooo`;oogl0Nooo
ool1o`00007ooooo00000ol0003oooooooooo`1kooooo`;oogl08?ooool4oomo07[ooooo0Ol00001
ooooo`0000?o0000ooooooooool0WOooool4oomo07[ooooo0Ol00001ooooo`0000?o0000oooooooo
ool0T?ooool2oomo00cooooo0_ooO`1kooooo`7o00000Oooool00003o`000?oooooooooo08oooooo
1?ooO`28ooooo`7o00000Oooool00003o`000?oooooooooo08oooooo1?ooO`28ooooo`7o00000Ooo
ool00003o`000?oooooooooo093ooooo0_ooO`0Sooooo`;oogl0I?ooool1o`00007ooooo00000ol0
003oooooooooo`2dooooo`Coogl0Hoooool1o`00007ooooo00000ol0003oooooooooo`2dooooo`Co
ogl0Hoooool1o`00007ooooo00000ol0003oooooooooo`2eooooo`;oogl0I?ooool1o`00007ooooo
00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolL
ooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003o
ooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o0000
0Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3o
oooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003
o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo
0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oooooo
oooo0?oooooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001oooo
o`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo
7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000
ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00
007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0
oooooolLooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo0000
0ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLoooo
o`7o00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003ooooo
ooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Ooo
ool00003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooo
oacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`00
0?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol0
0001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo
0?oooooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`00
00?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?oo
ool1o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000oooo
ooooool0S_ooool2oomo08_ooooo0Ol00001ooooo`0000?o0000ooooooooool0SOooool4oomo08[o
oooo0Ol00001ooooo`0000?o0000ooooooooool0SOooool4oomo08[ooooo0Ol00001ooooo`0000?o
0000ooooooooool0S_ooool2oomo08_ooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolL
ooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003o
ooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o0000
0Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3o
oooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003
o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo
0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oooooo
oooo0?oooooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001oooo
o`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo
7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000
ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00
007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0
oooooolLooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo0000
0ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`00ool0000Po`00007ooooo0000\
\>"],
  ImageRangeCache->{{{0, 287}, {287, 0}} -> {-1.01089, -1.01089, 0.00704453, \
0.00704453}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.49505 0.5 0.49505 [
[ 0 0 -0.125 0 ]
[ 0 0 -0.125 0 ]
[ 0 1 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
0 0 m
1 0 L
s
0 0 m
0 1 L
s
0 1 m
1 1 L
s
1 0 m
1 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
1 .5 0 r
.015 w
.03175 .1355 Mdot
.03435 .12523 Mdot
.11137 .12765 Mdot
.14107 .18841 Mdot
.16218 .24538 Mdot
.17294 .21053 Mdot
.18267 .18577 Mdot
.18434 .1304 Mdot
.18553 .30956 Mdot
.20401 .239 Mdot
.21247 .27571 Mdot
.21687 .20845 Mdot
.22376 .2799 Mdot
.22832 .27485 Mdot
.29063 .20974 Mdot
.29686 .25079 Mdot
.30487 .22936 Mdot
.30683 .34623 Mdot
.32055 .20902 Mdot
.32574 .21979 Mdot
.34472 .28521 Mdot
.35998 .36393 Mdot
.36335 .24976 Mdot
.3794 .36608 Mdot
.42386 .66992 Mdot
.44391 .74519 Mdot
.45059 .34198 Mdot
.47208 .67586 Mdot
.47436 .71381 Mdot
.49778 .59825 Mdot
.50874 .91643 Mdot
.51516 .76219 Mdot
.53655 .61374 Mdot
.56563 .75219 Mdot
.59189 .65665 Mdot
.59581 .61604 Mdot
.59923 .6556 Mdot
.60292 .68499 Mdot
.62656 .67779 Mdot
.63555 .72451 Mdot
.63919 .652 Mdot
.64169 .6004 Mdot
.64246 .58611 Mdot
.64496 .54267 Mdot
.64608 .77288 Mdot
.65077 .64308 Mdot
.66065 .57816 Mdot
.67474 .59169 Mdot
.69296 .563 Mdot
.72815 .65902 Mdot
.73169 .58879 Mdot
.74669 .61318 Mdot
.74821 .65474 Mdot
.75963 .63781 Mdot
.79673 .57809 Mdot
.80925 .55852 Mdot
.81525 .58444 Mdot
.83417 .62985 Mdot
.83598 .55526 Mdot
.91595 .49319 Mdot
1 0 0 r
.005 w
.16128 .17044 m
.18734 .17269 L
.21339 .17909 L
.2345 .18734 L
.23945 .19126 L
.2655 .20415 L
.27874 .21339 L
.29156 .22295 L
.31204 .23945 L
.31761 .24532 L
.33549 .2655 L
.34367 .28341 L
.34499 .29156 L
.34367 .29798 L
.31761 .3104 L
.29156 .30711 L
.2655 .30014 L
.24507 .29156 L
.23945 .28747 L
.21339 .27402 L
.20155 .2655 L
.18734 .25472 L
.16884 .23945 L
.16128 .2313 L
.14618 .21339 L
.13806 .18734 L
.16128 .17044 L
s
0 0 1 r
.65633 .57701 m
.68239 .56842 L
.70844 .56313 L
.7345 .56168 L
.76055 .5752 L
.76359 .57817 L
.76859 .60422 L
.76055 .62333 L
.75627 .63028 L
.7345 .65485 L
.73298 .65633 L
.70844 .6775 L
.69922 .68239 L
.68239 .69294 L
.65633 .70579 L
.64983 .70844 L
.63028 .71539 L
.60422 .72268 L
.57817 .72651 L
.55211 .7214 L
.53145 .70844 L
.52926 .68239 L
.54239 .65633 L
.55211 .63983 L
.56625 .63028 L
.57817 .6193 L
.60119 .60422 L
.60422 .60227 L
.63028 .58726 L
.65315 .57817 L
.65633 .57701 L
s
1 0 0 r
.03 w
.24141 .24033 Mdot
0 0 1 r
.64872 .64417 Mdot
1 0 0 r
.79703 .00495 m
.79703 .25248 L
.87129 .25248 L
.87129 .00495 L
F
0 0 1 r
.89604 .00495 m
.89604 .00495 L
.9703 .00495 L
.9703 .00495 L
F
1 0 1 r
.04 w
.18553 .30956 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P000182000`400?l00000o`00003ooooooolQ
ooooo`00ool0000Po`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`00
00?o0000ooooooooool0hOoooolEool002Gooooo0Ol00001ooooo`0000?o0000ooooooooool0hOoo
oolEool002Gooooo0Ol00001ooooo`0000?o0000ooooooooool0hOoooolEool002Gooooo0Ol00001
ooooo`0000?o0000ooooooooool0hOoooolEool002Gooooo0Ol00001ooooo`0000?o0000oooooooo
ool0hOoooolEool002Gooooo0Ol00001ooooo`0000?o0000ooooooooool0hOoooolEool002Gooooo
0Ol00001ooooo`0000?o0000ooooooooool0hOoooolEool002Gooooo0Ol00001ooooo`0000?o0000
ooooooooool0hOoooolEool002Gooooo0Ol00001ooooo`0000?o0000ooooooooool0hOoooolEool0
02Gooooo0Ol00001ooooo`0000?o0000ooooooooool0hOoooolEool002Gooooo0Ol00001ooooo`00
00?o0000ooooooooool0hOoooolEool002Gooooo0Ol00001ooooo`0000?o0000ooooooooool0hOoo
oolEool002Gooooo0Ol00001ooooo`0000?o0000ooooooooool0hOoooolEool002Gooooo0Ol00001
ooooo`0000?o0000ooooooooool0hOoooolEool002Gooooo0Ol00001ooooo`0000?o0000oooooooo
ool0hOoooolEool002Gooooo0Ol00001ooooo`0000?o0000ooooooooool0hOoooolEool002Gooooo
0Ol00001ooooo`0000?o0000ooooooooool0hOoooolEool002Gooooo0Ol00001ooooo`0000?o0000
ooooooooool0hOoooolEool002Gooooo0Ol00001ooooo`0000?o0000ooooooooool0hOoooolEool0
02Gooooo0Ol00001ooooo`0000?o0000ooooooooool0hOoooolEool002Gooooo0Ol00001ooooo`00
00?o0000ooooooooool0hOoooolEool002Gooooo0Ol00001ooooo`0000?o0000ooooooooool0hOoo
oolEool002Gooooo0Ol00001ooooo`0000?o0000ooooooooool0hOoooolEool002Gooooo0Ol00001
ooooo`0000?o0000ooooooooool0hOoooolEool002Gooooo0Ol00001ooooo`0000?o0000oooooooo
ool0hOoooolEool002Gooooo0Ol00001ooooo`0000?o0000ooooooooool0hOoooolEool002Gooooo
0Ol00001ooooo`0000?o0000ooooooooool0hOoooolEool002Gooooo0Ol00001ooooo`0000?o0000
ooooooooool0hOoooolEool002Gooooo0Ol00001ooooo`0000?o0000ooooooooool0hOoooolEool0
02Gooooo0Ol00001ooooo`0000?o0000ooooooooool0hOoooolEool002Gooooo0Ol00001ooooo`00
00?o0000ooooooooool0hOoooolEool002Gooooo0Ol00001ooooo`0000?o0000ooooooooool0hOoo
oolEool002Gooooo0Ol00001ooooo`0000?o0000ooooooooool01_ooool2oomo0=Wooooo5Ooo000U
ooooo`7o00000Oooool00003o`000?oooooooooo00Gooooo1?ooO`0Cooooo`;oogl0`ooooolEool0
02Gooooo0Ol00001ooooo`0000?o0000ooooooooool01Oooool4oomo01;ooooo1?ooO`0Booooo`;o
ogl0[_oooolEool002Gooooo0Ol00001ooooo`0000?o0000ooooooooool01Oooool3oomo01?ooooo
1?ooO`0Aooooo`Coogl0[OoooolEool002Gooooo0Ol00001ooooo`0000?o0000ooooooooool01?oo
ool4oomo01Cooooo0_ooO`0Booooo`Coogl0[OoooolEool002Gooooo0Ol00001ooooo`0000?o0000
ooooooooool01?ooool4oomo02Wooooo0_ooO`2^oooooaGoo`009Oooool1o`00007ooooo00000ol0
003oooooooooo`05ooooo`;oogl0f_oooolEool002Gooooo0Ol00001ooooo`0000?o0000oooooooo
ool0hOoooolEool002Gooooo0Ol00001ooooo`0000?o0000ooooooooool0hOoooolEool002Gooooo
0Ol00001ooooo`0000?o0000ooooooooool0hOoooolEool002Gooooo0Ol00001ooooo`0000?o0000
ooooooooool0hOoooolEool002Gooooo0Ol00001ooooo`0000?o0000ooooooooool0hOoooolEool0
02Gooooo0Ol00001ooooo`0000?o0000ooooooooool0hOoooolEool002Gooooo0Ol00001ooooo`00
00?o0000ooooooooool0hOoooolEool002Gooooo0Ol00001ooooo`0000?o0000ooooooooool0:_oo
ool6ool00;7ooooo5Ooo000Uooooo`7o00000Oooool00003o`000?oooooooooo02Wooooo00?oo`00
ooooooooool01?ooool5ool00:cooooo5Ooo000Uooooo`7o00000Oooool00003o`000?oooooooooo
02Oooooo0_oo000<ooooo`Coo`00Z?oooolEool002Gooooo0Ol00001ooooo`0000?o0000oooooooo
ool09_ooool00ooo003oooooooooo`0@ooooo`Coo`00Y?oooolEool002Gooooo0Ol00001ooooo`00
00?o0000ooooooooool09?ooool00oooO`3oo`00ooooo`09ooooo`;oogl02oooool3ool00:7ooooo
5Ooo000Uooooo`7o00000Oooool00003o`000?oooooooooo02?ooooo00Coogl0ool00?ooO`3oogl0
2?ooool4oomo00gooooo00?oo`00ooooooooool0W_oooolEool002Gooooo0Ol00001ooooo`0000?o
0000ooooooooool08oooool01?ooO`3oo`00oomo0?ooO`08ooooo`Coogl03_ooool2ool009kooooo
5Ooo000Uooooo`7o00000Oooool00003o`000?oooooooooo02Cooooo00?oogl0ool00?ooool02Ooo
ool2oomo017ooooo0_oo002LoooooaGoo`009Oooool1o`00007ooooo00000ol0003oooooooooo`0U
ooooo`03ool00?oooooooooo01gooooo0_oo002JoooooaGoo`009Oooool1o`00007ooooo00000ol0
003oooooooooo`0Uooooo`03ool00?oooooooooo01oooooo0_oo002HoooooaGoo`009Oooool1o`00
007ooooo00000ol0003oooooooooo`0Vooooo`03ool00?oooooooooo017ooooo0_ooO`0=ooooo`;o
o`001?ooool2oomo00Oooooo0_ooO`27oooooaGoo`009Oooool1o`00007ooooo00000ol0003ooooo
ooooo`0Vooooo`03ool00?oooooooooo00Gooooo0_ooO`09ooooo`Coogl03_ooool00ooo003ooooo
ooooo`04oomo00Gooooo1?ooO`26oooooaGoo`009Oooool1o`00007ooooo00000ol0003ooooooooo
o`0Vooooo`03ool00?oooooooooo00Cooooo1?ooO`08ooooo`Coogl03oooool00ooo003ooooooomo
0003oomo00Gooooo1?ooO`26oooooaGoo`009Oooool1o`00007ooooo00000ol0003oooooooooo`0W
ooooo`03ool00?oooooooooo00?ooooo1?ooO`09ooooo`;oogl04Oooool01?oo003ooooooomo0?oo
O`07ooooo`?oogl0Q_oooolEool002Gooooo0Ol00001ooooo`0000?o0000ooooooooool09oooool0
0ooo003oooooooooo`04ooooo`;oogl07_ooool00ooo003oooooooooo`07ooooo`Coogl0QOoooolE
ool002Gooooo0Ol00001ooooo`0000?o0000ooooooooool0:?ooool00ooo003oooooooooo`0Toooo
o`03ool00?oooooooooo00Kooooo1?ooO`25oooooaGoo`009Oooool1o`00007ooooo00000ol0003o
ooooooooo`0Yooooo`03ool00?oooooooooo02Cooooo0_oo00000oooooooogl0oomo0004ooooo`;o
ogl0Q_oooolEool002Gooooo0Ol00001ooooo`0000?o0000ooooooooool0:_ooool00ooo003ooooo
ooooo`0Cooooo`Coo`003_ooool01?oo003oogl0oomo0?ooO`2;oooooaGoo`009Oooool1o`00007o
oooo00000ol0003oooooooooo`0[ooooo`03ool00?oooooooooo017ooooo1_oo000=ooooo`04oomo
0?oo003oo`00oomo08_ooooo5Ooo000Uooooo`7o00000Oooool00003o`000?oooooooooo02cooooo
00?oo`00ooooooooool02?ooool2oomo00Gooooo2?oo000=ooooo`;oogl000?oo`00ooooooooool0
ROoooolEool002Gooooo0Ol00001ooooo`0000?o0000ooooooooool0;Oooool00ooo003ooooooooo
o`06ooooo`Coogl01?ooool8ool0013ooooo00?oo`00ooooooooool0R?oooolEool002Gooooo0Ol0
0001ooooo`0000?o0000ooooooooool0:oooool2oomo0003oooooooo003ooooo00Kooooo1?ooO`04
ooooo`Soo`004Oooool00ooo003oooooooooo`27oooooaGoo`009Oooool1o`00007ooooo00000ol0
003oooooooooo`0Zooooo`Coogl000?oooooool00?ooool01_ooool2oomo00Gooooo2?oo000;oooo
o`;oogl01Oooool00ooo003oooooooooo`09ooooo`;oogl0NooooolEool002Gooooo0Ol00001oooo
o`0000?o0000ooooooooool0:_ooool4oomo00;ooooo00?oo`00ooooooooool03?ooool6ool000_o
oooo1?ooO`04ooooo`03ool00?oooooooooo00Sooooo1?ooO`1joooooaGoo`009Oooool1o`00007o
oooo00000ol0003oooooooooo`0[ooooo`;oogl01?ooool00ooo003oooooooooo`0<ooooo`Coo`00
3?ooool4oomo00Gooooo00?oo`00ooooooooool01oooool4oomo07[ooooo5Ooo000Uooooo`7o0000
0Oooool00003o`000?oooooooooo03;ooooo0_oo000Mooooo`;oogl01oooool00ooo003ooooooooo
o`07ooooo`;oogl0]Oooool1o`00007ooooo00000ol0003oooooooooo`0dooooo`03ool00?oooooo
oooo02Cooooo00?oo`00ooooooooool0_Oooool1o`00007ooooo00000ol0003oooooooooo`0eoooo
o`03ool00?oooooooooo02Cooooo00?oo`00ooooooooool0_?ooool1o`00007ooooo00000ol0003o
ooooooooo`0fooooo`;oo`009Oooool00ooo003oooooooooo`2kooooo`7o00000Oooool00003o`00
0?oooooooooo03Sooooo0_oo00000oooO`3oooooooooo`02oomo01kooooo00?oo`00ooooooooool0
^oooool1o`00007ooooo00000ol0003oooooooooo`0hooooo`;oogl00_oo0004oomo01kooooo00?o
o`00ooooooooool0^_ooool1o`00007ooooo00000ol0003oooooooooo`0hooooo`Coogl00_oo0002
oomo01kooooo00?oo`00ooooooooool0^_ooool1o`00007ooooo00000ol0003oooooooooo`0ioooo
o`Googl000?oo`00ooooooooool07Oooool00ooo003oogl0oomo002jooooo`7o00000Oooool00003
o`000?oooooooooo03_ooooo1?ooO`02ool001gooooo00Coogl0ool00?ooO`3oogl0^Oooool1o`00
007ooooo00000ol0003oooooooooo`0looooo`;oogl00oooool2ool001_ooooo00Coogl0ool00?oo
O`3oogl0^Oooool1o`00007ooooo00000ol0003oooooooooo`13ooooo`;oo`006_ooool00oooO`3o
o`00ooooo`2iooooo`7o00000Oooool00003o`000?oooooooooo033ooooo1Ooo0?l@ooooo`;oo`00
6Oooool00ooo003oooooooooo`2hooooo`7o00000Oooool00003o`000?oooooooooo02oooooo1ooo
0?lAooooo`;oo`005Oooool2ool00;_ooooo0Ol00001ooooo`0000?o0000ooooooooool0;_ooool9
ool0oa;ooooo0ooo000@ooooo`;oo`00_Oooool1o`00007ooooo00000ol0003oooooooooo`0]oooo
o`_oo`3o5?ooool3ool000cooooo00?oo`00ooooooooool0_Oooool1o`00007ooooo00000ol0003o
ooooooooo`0]ooooo`_oo`3o5oooool6ool000Cooooo0_oo0030ooooo`7o00000Oooool00003o`00
0?oooooooooo02gooooo2ooo0?lMooooo`Coo`00`_ooool1o`00007ooooo00000ol0003ooooooooo
o`0]ooooo`_oo`3ohoooool1o`00007ooooo00000ol0003oooooooooo`0]ooooo`_oo`3ohoooool1
o`00007ooooo00000ol0003oooooooooo`0^ooooo`Woo`3oi?ooool1o`00007ooooo00000ol0003o
ooooooooo`0_ooooo`Ooo`3oiOooool1o`00007ooooo00000ol0003oooooooooo`0`ooooo`Goo`3o
i_ooool1o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000
ooooooooool0OOooool2oomo09cooooo0Ol00001ooooo`0000?o0000ooooooooool0O?ooool4oomo
09_ooooo0Ol00001ooooo`0000?o0000ooooooooool0E?ooool2oomo02Kooooo1?ooO`2Kooooo`7o
00000Oooool00003o`000?oooooooooo05?ooooo1?ooO`0Vooooo`;oogl0W?ooool1o`00007ooooo
00000ol0003oooooooooo`1Cooooo`Coogl0a?ooool1o`00007ooooo00000ol0003oooooooooo`1D
ooooo`;oogl0aOooool1o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001oooo
o`0000?o0000ooooooooool0Hoooool2oomo00Cooooo0_ooO`2`ooooo`7o00000Oooool00003o`00
0?oooooooooo06;ooooo1?ooO`02ooooo`Coogl0[oooool1o`00007ooooo00000ol0003ooooooooo
o`1Rooooo`Coogl00_ooool4oomo0:oooooo0Ol00001ooooo`0000?o0000ooooooooool0Hoooool2
oomo00Cooooo0_ooO`2`ooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00
007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0
oooooolLooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo0000
0ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLoooo
o`7o00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003ooooo
ooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Ooo
ool00003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooo
oacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`00
0?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol0
0001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo
0?oooooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`00
00?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?oo
ool1o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000oooo
ooooool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007o
oooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooo
oolLooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0
003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o
00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003ooooooooo
o`3ooooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool0
0003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooooaco
oooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oo
oooooooo0?oooooo1?ooool2oomo01Kooooo0Ol00001ooooo`0000?o0000ooooooooool0ooooool3
ooooo`Coogl05Oooool1o`00007ooooo00000ol0003oooooooooo`3oooooo`?ooooo1?ooO`0Eoooo
o`7o00000Oooool00003o`000?oooooooooo0?oooooo1?ooool2oomo01Kooooo0Ol00001ooooo`00
00?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?oo
ool1o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000oooo
ooooool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007o
oooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooo
oolLooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0
003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o
00000Oooool00003o`000?oooooooooo0;Gooooo0_ooO`1Tooooo`7o00000Oooool00003o`000?oo
oooooooo0;Cooooo1?ooO`1Sooooo`7o00000Oooool00003o`000?oooooooooo0;Cooooo1?ooO`1S
ooooo`7o00000Oooool00003o`000?oooooooooo0;Gooooo0_ooO`0eooooo`;oogl0;Oooool1o`00
007ooooo00000ol0003oooooooooo`3Tooooo`;oogl01Oooool4oomo02cooooo0Ol00001ooooo`00
00?o0000ooooooooool0hoooool4oomo00Cooooo1?ooO`0/ooooo`7o00000Oooool00003o`000?oo
oooooooo0<?ooooo0_ooO`0Nooooo`Coogl01Oooool2oomo02gooooo0Ol00001ooooo`0000?o0000
ooooooooool0`_ooool4oomo00_o003o4oooool2oomo03Gooooo0Ol00001ooooo`0000?o0000oooo
ooooool0`_ooool4o`00o`_ooooo0_l00?m8ooooo`7o00000Oooool00003o`000?oooooooooo0;ko
oooo1?l00?l00oooooooogl0oomo000>ooooo`;o003oA_ooool1o`00007ooooo00000ol0003ooooo
ooooo`2iooooo`;oogl00ol00?lGooooo`;o003o2Oooool2oomo03Wooooo0Ol00001ooooo`0000?o
0000ooooooooool0]oooool4o`00o`03oomo0?oooooooooo01Wooooo0_l00?l6ooooo`Coogl0>?oo
ool1o`00007ooooo00000ol0003oooooooooo`2dooooo`?o003o00?ooooooomo0?ooO`000_ooO`0L
ooooo`03o`00oooooooooooo00Cooooo1?ooO`03ooooo`;oogl0<oooool1o`00007ooooo00000ol0
003oooooooooo`2booooo`;o003o0oooO`02ooooo`;oogl04oooool2oomo00Sooooo00?o003ooooo
ooooool01Oooool2oomo00?ooooo1?ooO`0booooo`7o00000Oooool00003o`000?oooooooooo0;3o
oooo0_l00?l00oooooooogl0oomo0002oomo00Kooooo0_ooO`0>ooooo`Coogl01oooool00ol00?oo
ooooooooo`0:ooooo`Coogl0<_ooool1o`00007ooooo00000ol0003oooooooooo`2^ooooo`;o003o
1?ooool2oomo00Kooooo1?ooO`0=ooooo`Coogl01oooool00ol00?ooooooooooo`0;ooooo`;oogl0
<oooool1o`00007ooooo00000ol0003oooooooooo`2;ooooo`;oogl08?ooool00ol00?oooooooooo
o`04ooooo`;oogl01_ooool4oomo00kooooo0_ooO`09ooooo`03o`00oooooooooooo03oooooo0Ol0
0001ooooo`0000?o0000ooooooooool0R_ooool4oomo01gooooo0_l00?l6ooooo`Coogl01_ooool2
oomo01[ooooo00?o003oooooooooool0?oooool1o`00007ooooo00000ol0003oooooooooo`2:oooo
o`Coogl07?ooool00ol00?ooooooooooo`06ooooo`Coogl08_ooool00ol00?ooooooooooo`0ooooo
o`7o00000Oooool00003o`000?oooooooooo08_ooooo0_ooO`0Kooooo`;o003o2_ooool2oomo02?o
oooo00?o003oooooooooool0?oooool1o`00007ooooo00000ol0003oooooooooo`2Fooooo`;oogl0
3_ooool2o`00ob[ooooo0_ooO`05ooooo`03o`00oooooooooooo03oooooo0Ol00001ooooo`0000?o
0000ooooooooool0UOooool4oomo00cooooo00Co003oooooooooO`3oogl0:?ooool4oomo00?ooooo
00?o003oooooooooool0@?ooool1o`00007ooooo00000ol0003oooooooooo`2Eooooo`Coogl02_oo
ool2o`00o`03ooooooooO`3oogl000;oogl09oooool4oomo00?ooooo00?o003oooooooooool0@?oo
ool1o`00007ooooo00000ol0003oooooooooo`2Fooooo`;oogl02_ooool01?l00?oooooooooooooo
ool4oomo02Sooooo0_ooO`04ooooo`03o`00oooooooooooo043ooooo0Ol00001ooooo`0000?o0000
ooooooooool0XOooool00ol00?ooooooooooo`03ooooo`;oogl0;_ooool00ol00?ooooooooooo`11
ooooo`7o00000Oooool00003o`000?oooooooooo0:3ooooo00?o003oooooooooool0<oooool00ol0
0?ooooooooooo`0Booooo`;oogl0;_ooool1o`00007ooooo00000ol0003oooooooooo`2Nooooo`;o
003o=Oooool00ol00?ooooooooooo`0Booooo`Coogl0;Oooool1o`00007ooooo00000ol0003ooooo
ooooo`2Mooooo`03o`00oooooooooooo01Gooooo1?l00?lLooooo`03o`00ooooO`3oogl001;ooooo
1?ooO`0]ooooo`7o00000Oooool00003o`000?oooooooooo09cooooo00?o003oooooooooool05Ooo
ool6o`00oa[ooooo00?o003ooomo0?ooO`000_ooO`0Booooo`;oogl0;_ooool1o`00007ooooo0000
0ol0003oooooooooo`2Kooooo`03o`00oooooooooooo01Gooooo2?l00?lHooooo`03o`00oooooooo
ogl000?oogl0@_ooool1o`00007ooooo00000ol0003oooooooooo`2Kooooo`03o`00oooooooooooo
01Gooooo2?l00?lGooooo`04o`00ooooooooooooooooo`;oogl0@oooool1o`00007ooooo00000ol0
003oooooooooo`2Jooooo`03o`00oooooooooooo01Kooooo2?l00?lFooooo`03o`00oooooooooooo
04Oooooo0Ol00001ooooo`0000?o0000ooooooooool0VOooool00ol00?ooooooooooo`0<ooooo`;o
ogl02?ooool00oooO`3o003oo`00o`06o`00oaGooooo00?o003oooooooooool00_ooO`16ooooo`7o
00000Oooool00003o`000?oooooooooo09Wooooo00?o003oooooooooool02_ooool5oomo00Oooooo
0_ooO`06o`00oa?ooooo0_ooO`000ol00?ooooooooooo`04oomo04Gooooo0Ol00001ooooo`0000?o
0000ooooooooool0V?ooool00ol00?ooooooooooo`0:ooooo`Koogl02?ooool2oomo00Co003o4ooo
ool2oomo00;o003o0_ooool4oomo04Gooooo0Ol00001ooooo`0000?o0000ooooooooool0V?ooool0
0ol00?ooooooooooo`0:ooooo`Googl08_ooool01?ooO`3o003ooomo0?ooO`03ooooo`;oogl0A_oo
ool1o`00007ooooo00000ol0003oooooooooo`1fooooo`;oogl07oooool00ol00?ooooooooooo`0<
ooooo`;oogl09?ooool00ol00?ooogl0oomo001<ooooo`7o00000Oooool00003o`000?oooooooooo
07Gooooo1?ooO`0Nooooo`03o`00oooooooooooo037ooooo00?o003oooooooooool0COooool1o`00
007ooooo00000ol0003oooooooooo`1eooooo`Coogl02_ooool2oomo017ooooo00?o003ooooooooo
ool0<Oooool00ol00?ooooooooooo`1>ooooo`7o00000Oooool00003o`000?oooooooooo07Kooooo
0_ooO`0:ooooo`Coogl03oooool00ol00?ooooooooooo`0Hooooo`;oogl05oooool00ol00?oooooo
ooooo`1?ooooo`7o00000Oooool00003o`000?oooooooooo08;ooooo1?ooO`0?ooooo`03o`00oooo
oooooooo01Oooooo1?ooO`0Dooooo`;o003oD_ooool1o`00007ooooo00000ol0003oooooooooo`23
ooooo`;oogl03oooool00ol00?ooooooooooo`0Booooo`;oogl01?ooool4oomo017ooooo0ol00?mD
ooooo`7o00000Oooool00003o`000?oooooooooo09Cooooo00?o003oooooooooool04Oooool4oomo
00Cooooo0_ooO`0@ooooo`;o003oEoooool1o`00007ooooo00000ol0003oooooooooo`2Dooooo`03
o`00oooooooooooo017ooooo1?ooO`0Eooooo`03o`00oooooooooooo05Oooooo0Ol00001ooooo`00
00?o0000ooooooooool0U?ooool00ol00?ooooooooooo`0Booooo`;oogl05?ooool2o`00oe[ooooo
0Ol00001ooooo`0000?o0000ooooooooool0U?ooool00ol00?ooooooooooo`0Vooooo`;o003oG?oo
ool1o`00007ooooo00000ol0003oooooooooo`2Eooooo`03o`00oooooooooooo02Cooooo00?o003o
ooooooooool0G?ooool1o`00007ooooo00000ol0003oooooooooo`2Eooooo`03o`00oooooooooooo
02;ooooo0_l00?mOooooo`7o00000Oooool00003o`000?oooooooooo09Gooooo00?o003ooooooooo
ool08?ooool2o`00of7ooooo0Ol00001ooooo`0000?o0000ooooooooool0Q?ooool2oomo00oooooo
0_l00?lOooooo`;o003oHoooool1o`00007ooooo00000ol0003oooooooooo`23ooooo`Coogl04?oo
ool2o`00oa[ooooo0ol00?mUooooo`7o00000Oooool00003o`000?oooooooooo08?ooooo1?ooO`0B
ooooo`;o003o5?ooool4o`00ofSooooo0Ol00001ooooo`0000?o0000ooooooooool0Q?ooool2oomo
01Gooooo0ol00?l>ooooo`?o003o0oooool2oomo06Oooooo0Ol00001ooooo`0000?o0000oooooooo
ool0W_ooool3o`00o`Gooooo1_l00?l5ooooo`Coogl0I_ooool1o`00007ooooo00000ol0003ooooo
ooooo`2Qooooo`Go003o2oooool4oomo06Kooooo0Ol00001ooooo`0000?o0000ooooooooool0/_oo
ool2oomo06Oooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool0
0003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003oooooooooo`1kooooo`;o
ogl0W_ooool1o`00007ooooo00000ol0003oooooooooo`1jooooo`Coogl0WOooool1o`00007ooooo
00000ol0003oooooooooo`1jooooo`Coogl08?ooool2oomo07_ooooo0Ol00001ooooo`0000?o0000
ooooooooool0Noooool2oomo023ooooo1?ooO`1jooooo`7o00000Oooool00003o`000?oooooooooo
09gooooo1?ooO`1jooooo`7o00000Oooool00003o`000?oooooooooo093ooooo0_ooO`0<ooooo`;o
ogl0Noooool1o`00007ooooo00000ol0003oooooooooo`2?ooooo`Coogl0R?ooool1o`00007ooooo
00000ol0003oooooooooo`2?ooooo`Coogl0R?ooool1o`00007ooooo00000ol0003oooooooooo`2@
ooooo`;oogl08oooool2oomo06Cooooo0Ol00001ooooo`0000?o0000ooooooooool0]?ooool4oomo
06?ooooo0Ol00001ooooo`0000?o0000ooooooooool0]?ooool4oomo06?ooooo0Ol00001ooooo`00
00?o0000ooooooooool0]Oooool2oomo06Cooooo0Ol00001ooooo`0000?o0000ooooooooool0oooo
oolLooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0
003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o
00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003ooooooooo
o`3ooooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool0
0003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooooaco
oooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oo
oooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001
ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo0?oo
oooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o
0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1
o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000oooooooo
ool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo
00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolL
ooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003o
ooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o0000
0Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3o
oooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003
o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo
0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oooooo
oooo0?oooooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001oooo
o`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo
7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000
ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo08kooooo0_ooO`2;oooo
o`7o00000Oooool00003o`000?oooooooooo08gooooo1?ooO`2:ooooo`7o00000Oooool00003o`00
0?oooooooooo08gooooo1?ooO`2:ooooo`7o00000Oooool00003o`000?oooooooooo08kooooo0_oo
O`2;ooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0
003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o
00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003ooooooooo
o`3ooooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool0
0003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooooaco
oooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oo
oooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001
ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo0?oo
oooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o
0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1
o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000oooooooo
ool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo
00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolL
ooooo`7o00000Oooool00?oo00008?l00001ooooo`00\
\>"],
  ImageRangeCache->{{{0, 287}, {287, 0}} -> {-1.01089, -1.01089, 0.00704453, \
0.00704453}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.49505 0.5 0.49505 [
[ 0 0 -0.125 0 ]
[ 0 0 -0.125 0 ]
[ 0 1 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
0 0 m
1 0 L
s
0 0 m
0 1 L
s
0 1 m
1 1 L
s
1 0 m
1 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
1 .5 0 r
.015 w
.03175 .1355 Mdot
.03435 .12523 Mdot
.11137 .12765 Mdot
.14107 .18841 Mdot
.16218 .24538 Mdot
.17294 .21053 Mdot
.18267 .18577 Mdot
.18434 .1304 Mdot
.18553 .30956 Mdot
.20401 .239 Mdot
.21247 .27571 Mdot
.21687 .20845 Mdot
.22376 .2799 Mdot
.22832 .27485 Mdot
.29063 .20974 Mdot
.29686 .25079 Mdot
.30487 .22936 Mdot
.30683 .34623 Mdot
.32055 .20902 Mdot
.32574 .21979 Mdot
.34472 .28521 Mdot
.35998 .36393 Mdot
.36335 .24976 Mdot
.3794 .36608 Mdot
.42386 .66992 Mdot
.44391 .74519 Mdot
.45059 .34198 Mdot
.47208 .67586 Mdot
.47436 .71381 Mdot
.49778 .59825 Mdot
.50874 .91643 Mdot
.51516 .76219 Mdot
.53655 .61374 Mdot
.56563 .75219 Mdot
.59189 .65665 Mdot
.59581 .61604 Mdot
.59923 .6556 Mdot
.60292 .68499 Mdot
.62656 .67779 Mdot
.63555 .72451 Mdot
.63919 .652 Mdot
.64169 .6004 Mdot
.64246 .58611 Mdot
.64496 .54267 Mdot
.64608 .77288 Mdot
.65077 .64308 Mdot
.66065 .57816 Mdot
.67474 .59169 Mdot
.69296 .563 Mdot
.72815 .65902 Mdot
.73169 .58879 Mdot
.74669 .61318 Mdot
.74821 .65474 Mdot
.75963 .63781 Mdot
.79673 .57809 Mdot
.80925 .55852 Mdot
.81525 .58444 Mdot
.83417 .62985 Mdot
.83598 .55526 Mdot
.91595 .49319 Mdot
1 0 0 r
.005 w
.16128 .17044 m
.18734 .17269 L
.21339 .17909 L
.2345 .18734 L
.23945 .19126 L
.2655 .20415 L
.27874 .21339 L
.29156 .22295 L
.31204 .23945 L
.31761 .24532 L
.33549 .2655 L
.34367 .28341 L
.34499 .29156 L
.34367 .29798 L
.31761 .3104 L
.29156 .30711 L
.2655 .30014 L
.24507 .29156 L
.23945 .28747 L
.21339 .27402 L
.20155 .2655 L
.18734 .25472 L
.16884 .23945 L
.16128 .2313 L
.14618 .21339 L
.13806 .18734 L
.16128 .17044 L
s
0 0 1 r
.65633 .57701 m
.68239 .56842 L
.70844 .56313 L
.7345 .56168 L
.76055 .5752 L
.76359 .57817 L
.76859 .60422 L
.76055 .62333 L
.75627 .63028 L
.7345 .65485 L
.73298 .65633 L
.70844 .6775 L
.69922 .68239 L
.68239 .69294 L
.65633 .70579 L
.64983 .70844 L
.63028 .71539 L
.60422 .72268 L
.57817 .72651 L
.55211 .7214 L
.53145 .70844 L
.52926 .68239 L
.54239 .65633 L
.55211 .63983 L
.56625 .63028 L
.57817 .6193 L
.60119 .60422 L
.60422 .60227 L
.63028 .58726 L
.65315 .57817 L
.65633 .57701 L
s
1 0 0 r
.03 w
.24141 .24033 Mdot
0 0 1 r
.64872 .64417 Mdot
1 0 0 r
.79703 .00495 m
.79703 .25248 L
.87129 .25248 L
.87129 .00495 L
F
0 0 1 r
.89604 .00495 m
.89604 .00495 L
.9703 .00495 L
.9703 .00495 L
F
1 0 1 r
.04 w
.20401 .239 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P000182000`400?l00000o`00003ooooooolQ
ooooo`00ool0000Po`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`00
00?o0000ooooooooool0hOoooolEool002Gooooo0Ol00001ooooo`0000?o0000ooooooooool0hOoo
oolEool002Gooooo0Ol00001ooooo`0000?o0000ooooooooool0hOoooolEool002Gooooo0Ol00001
ooooo`0000?o0000ooooooooool0hOoooolEool002Gooooo0Ol00001ooooo`0000?o0000oooooooo
ool0hOoooolEool002Gooooo0Ol00001ooooo`0000?o0000ooooooooool0hOoooolEool002Gooooo
0Ol00001ooooo`0000?o0000ooooooooool0hOoooolEool002Gooooo0Ol00001ooooo`0000?o0000
ooooooooool0hOoooolEool002Gooooo0Ol00001ooooo`0000?o0000ooooooooool0hOoooolEool0
02Gooooo0Ol00001ooooo`0000?o0000ooooooooool0hOoooolEool002Gooooo0Ol00001ooooo`00
00?o0000ooooooooool0hOoooolEool002Gooooo0Ol00001ooooo`0000?o0000ooooooooool0hOoo
oolEool002Gooooo0Ol00001ooooo`0000?o0000ooooooooool0hOoooolEool002Gooooo0Ol00001
ooooo`0000?o0000ooooooooool0hOoooolEool002Gooooo0Ol00001ooooo`0000?o0000oooooooo
ool0hOoooolEool002Gooooo0Ol00001ooooo`0000?o0000ooooooooool0hOoooolEool002Gooooo
0Ol00001ooooo`0000?o0000ooooooooool0hOoooolEool002Gooooo0Ol00001ooooo`0000?o0000
ooooooooool0hOoooolEool002Gooooo0Ol00001ooooo`0000?o0000ooooooooool0hOoooolEool0
02Gooooo0Ol00001ooooo`0000?o0000ooooooooool0hOoooolEool002Gooooo0Ol00001ooooo`00
00?o0000ooooooooool0hOoooolEool002Gooooo0Ol00001ooooo`0000?o0000ooooooooool0hOoo
oolEool002Gooooo0Ol00001ooooo`0000?o0000ooooooooool0hOoooolEool002Gooooo0Ol00001
ooooo`0000?o0000ooooooooool0hOoooolEool002Gooooo0Ol00001ooooo`0000?o0000oooooooo
ool0hOoooolEool002Gooooo0Ol00001ooooo`0000?o0000ooooooooool0hOoooolEool002Gooooo
0Ol00001ooooo`0000?o0000ooooooooool0hOoooolEool002Gooooo0Ol00001ooooo`0000?o0000
ooooooooool0hOoooolEool002Gooooo0Ol00001ooooo`0000?o0000ooooooooool0hOoooolEool0
02Gooooo0Ol00001ooooo`0000?o0000ooooooooool0hOoooolEool002Gooooo0Ol00001ooooo`00
00?o0000ooooooooool0hOoooolEool002Gooooo0Ol00001ooooo`0000?o0000ooooooooool0hOoo
oolEool002Gooooo0Ol00001ooooo`0000?o0000ooooooooool01_ooool2oomo0=Wooooo5Ooo000U
ooooo`7o00000Oooool00003o`000?oooooooooo00Gooooo1?ooO`0Cooooo`;oogl0`ooooolEool0
02Gooooo0Ol00001ooooo`0000?o0000ooooooooool01Oooool4oomo01;ooooo1?ooO`0Booooo`;o
ogl0[_oooolEool002Gooooo0Ol00001ooooo`0000?o0000ooooooooool01Oooool3oomo01?ooooo
1?ooO`0Aooooo`Coogl0[OoooolEool002Gooooo0Ol00001ooooo`0000?o0000ooooooooool01?oo
ool4oomo01Cooooo0_ooO`0Booooo`Coogl0[OoooolEool002Gooooo0Ol00001ooooo`0000?o0000
ooooooooool01?ooool4oomo02Wooooo0_ooO`2^oooooaGoo`009Oooool1o`00007ooooo00000ol0
003oooooooooo`05ooooo`;oogl0f_oooolEool002Gooooo0Ol00001ooooo`0000?o0000oooooooo
ool0hOoooolEool002Gooooo0Ol00001ooooo`0000?o0000ooooooooool0hOoooolEool002Gooooo
0Ol00001ooooo`0000?o0000ooooooooool0hOoooolEool002Gooooo0Ol00001ooooo`0000?o0000
ooooooooool0hOoooolEool002Gooooo0Ol00001ooooo`0000?o0000ooooooooool0hOoooolEool0
02Gooooo0Ol00001ooooo`0000?o0000ooooooooool0hOoooolEool002Gooooo0Ol00001ooooo`00
00?o0000ooooooooool0hOoooolEool002Gooooo0Ol00001ooooo`0000?o0000ooooooooool0:_oo
ool6ool00;7ooooo5Ooo000Uooooo`7o00000Oooool00003o`000?oooooooooo02Wooooo00?oo`00
ooooooooool01?ooool5ool00:cooooo5Ooo000Uooooo`7o00000Oooool00003o`000?oooooooooo
02Oooooo0_oo000<ooooo`Coo`00Z?oooolEool002Gooooo0Ol00001ooooo`0000?o0000oooooooo
ool09_ooool00ooo003oooooooooo`0@ooooo`Coo`00Y?oooolEool002Gooooo0Ol00001ooooo`00
00?o0000ooooooooool09?ooool00oooO`3oo`00ooooo`09ooooo`;oogl02oooool3ool00:7ooooo
5Ooo000Uooooo`7o00000Oooool00003o`000?oooooooooo02?ooooo00Coogl0ool00?ooO`3oogl0
2?ooool4oomo00gooooo00?oo`00ooooooooool0W_oooolEool002Gooooo0Ol00001ooooo`0000?o
0000ooooooooool08oooool01?ooO`3oo`00oomo0?ooO`08ooooo`Coogl03_ooool2ool009kooooo
5Ooo000Uooooo`7o00000Oooool00003o`000?oooooooooo02Cooooo00?oogl0ool00?ooool02Ooo
ool2oomo017ooooo0_oo002LoooooaGoo`009Oooool1o`00007ooooo00000ol0003oooooooooo`0U
ooooo`03ool00?oooooooooo01gooooo0_oo002JoooooaGoo`009Oooool1o`00007ooooo00000ol0
003oooooooooo`0Uooooo`03ool00?oooooooooo01oooooo0_oo002HoooooaGoo`009Oooool1o`00
007ooooo00000ol0003oooooooooo`0Vooooo`03ool00?oooooooooo017ooooo0_ooO`0=ooooo`;o
o`001?ooool2oomo00Oooooo0_ooO`27oooooaGoo`009Oooool1o`00007ooooo00000ol0003ooooo
ooooo`0Vooooo`03ool00?oooooooooo00Gooooo0_ooO`09ooooo`Coogl03_ooool00ooo003ooooo
ooooo`04oomo00Gooooo1?ooO`26oooooaGoo`009Oooool1o`00007ooooo00000ol0003ooooooooo
o`0Vooooo`03ool00?oooooooooo00Cooooo1?ooO`08ooooo`Coogl03oooool00ooo003ooooooomo
0003oomo00Gooooo1?ooO`26oooooaGoo`009Oooool1o`00007ooooo00000ol0003oooooooooo`0W
ooooo`03ool00?oooooooooo00?ooooo1?ooO`09ooooo`;oogl04Oooool01?oo003ooooooomo0?oo
O`07ooooo`?oogl0Q_oooolEool002Gooooo0Ol00001ooooo`0000?o0000ooooooooool09oooool0
0ooo003oooooooooo`04ooooo`;oogl07_ooool00ooo003oooooooooo`07ooooo`Coogl0QOoooolE
ool002Gooooo0Ol00001ooooo`0000?o0000ooooooooool0:?ooool00ooo003oooooooooo`0:oooo
o`Goo`3o5Oooool00ooo003oooooooooo`06ooooo`Coogl0QOoooolEool002Gooooo0Ol00001oooo
o`0000?o0000ooooooooool0:Oooool00ooo003oooooooooo`08ooooo`Ooo`3o5Oooool2ool00003
ooooooooO`3oogl000Cooooo0_ooO`26oooooaGoo`009Oooool1o`00007ooooo00000ol0003ooooo
ooooo`0Zooooo`03ool00?oooooooooo00Kooooo2Ooo0?l4ooooo`Coo`003_ooool01?oo003oogl0
oomo0?ooO`2;oooooaGoo`009Oooool1o`00007ooooo00000ol0003oooooooooo`0[ooooo`03ool0
0?oooooooooo00Cooooo2ooo0?l2ooooo`Koo`003Oooool01?ooO`3oo`00ool00?ooO`2;oooooaGo
o`009Oooool1o`00007ooooo00000ol0003oooooooooo`0/ooooo`03ool00?oooooooooo00?ooooo
2ooo0?l00oooooooo`00ool00006ool000gooooo0_ooO`000ooo003oooooooooo`29oooooaGoo`00
9Oooool1o`00007ooooo00000ol0003oooooooooo`0]ooooo`03ool00?oooooooooo00;ooooo2ooo
0?l00oooooooo`00ool00006ool0013ooooo00?oo`00ooooooooool0R?oooolEool002Gooooo0Ol0
0001ooooo`0000?o0000ooooooooool0:oooool2oomo0003oooooooo003ooooo00;ooooo2ooo0?l0
0oooooooo`00ool00006ool0017ooooo00?oo`00ooooooooool0QooooolEool002Gooooo0Ol00001
ooooo`0000?o0000ooooooooool0:_ooool4oomo0004oooooooo003oooooooooo`_oo`3o00?ooooo
ool00?oo00001_oo000;ooooo`;oogl01Oooool00ooo003oooooooooo`09ooooo`;oogl0NooooolE
ool002Gooooo0Ol00001ooooo`0000?o0000ooooooooool0:_ooool4oomo00;ooooo00?oo`00oooo
ooooool02Ooo0?l3ooooo`Koo`002oooool4oomo00Cooooo00?oo`00ooooooooool02?ooool4oomo
07[ooooo5Ooo000Uooooo`7o00000Oooool00003o`000?oooooooooo02_ooooo0_ooO`04ooooo`03
ool00?oooooooooo00Ooo`3o1Oooool4ool000cooooo1?ooO`05ooooo`03ool00?oooooooooo00Oo
oooo1?ooO`1joooooaGoo`009Oooool1o`00007ooooo00000ol0003oooooooooo`0booooo`;oo`00
00?oooooool0oooo0?l00ooo0?lGooooo`;oogl01oooool00ooo003oooooooooo`07ooooo`;oogl0
]Oooool1o`00007ooooo00000ol0003oooooooooo`0dooooo`03ool00?oooooooooo02Cooooo00?o
o`00ooooooooool0_Oooool1o`00007ooooo00000ol0003oooooooooo`0eooooo`03ool00?oooooo
oooo02Cooooo00?oo`00ooooooooool0_?ooool1o`00007ooooo00000ol0003oooooooooo`0foooo
o`;oo`009Oooool00ooo003oooooooooo`2kooooo`7o00000Oooool00003o`000?oooooooooo03So
oooo0_oo00000oooO`3oooooooooo`02oomo01kooooo00?oo`00ooooooooool0^oooool1o`00007o
oooo00000ol0003oooooooooo`0hooooo`;oogl00_oo0004oomo01kooooo00?oo`00ooooooooool0
^_ooool1o`00007ooooo00000ol0003oooooooooo`0hooooo`Coogl00_oo0002oomo01kooooo00?o
o`00ooooooooool0^_ooool1o`00007ooooo00000ol0003oooooooooo`0iooooo`Googl000?oo`00
ooooooooool07Oooool00ooo003oogl0oomo002jooooo`7o00000Oooool00003o`000?oooooooooo
03_ooooo1?ooO`02ool001gooooo00Coogl0ool00?ooO`3oogl0^Oooool1o`00007ooooo00000ol0
003oooooooooo`0looooo`;oogl00oooool2ool001_ooooo00Coogl0ool00?ooO`3oogl0^Oooool1
o`00007ooooo00000ol0003oooooooooo`13ooooo`;oo`006_ooool00oooO`3oo`00ooooo`2ioooo
o`7o00000Oooool00003o`000?oooooooooo04Gooooo0_oo000Iooooo`03ool00?oooooooooo0;So
oooo0Ol00001ooooo`0000?o0000ooooooooool0Aoooool2ool001Gooooo0_oo002kooooo`7o0000
0Oooool00003o`000?oooooooooo04Wooooo0ooo000@ooooo`;oo`00_Oooool1o`00007ooooo0000
0ol0003oooooooooo`0aooooo`;oogl06Oooool3ool000cooooo00?oo`00ooooooooool0_Oooool1
o`00007ooooo00000ol0003oooooooooo`0`ooooo`Coogl06oooool6ool000Cooooo0_oo0030oooo
o`7o00000Oooool00003o`000?oooooooooo033ooooo1?ooO`0Qooooo`Coo`00`_ooool1o`00007o
oooo00000ol0003oooooooooo`0aooooo`;oogl0j?ooool1o`00007ooooo00000ol0003ooooooooo
o`3ooooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool0
0003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooooaco
oooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oo
oooooooo07gooooo0_ooO`2Looooo`7o00000Oooool00003o`000?oooooooooo07cooooo1?ooO`2K
ooooo`7o00000Oooool00003o`000?oooooooooo05Cooooo0_ooO`0Vooooo`Coogl0Voooool1o`00
007ooooo00000ol0003oooooooooo`1Cooooo`Coogl09_ooool2oomo09cooooo0Ol00001ooooo`00
00?o0000ooooooooool0Doooool4oomo0<Cooooo0Ol00001ooooo`0000?o0000ooooooooool0E?oo
ool2oomo0<Gooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool0
0003o`000?oooooooooo06?ooooo0_ooO`04ooooo`;oogl0/?ooool1o`00007ooooo00000ol0003o
ooooooooo`1Rooooo`Coogl00_ooool4oomo0:oooooo0Ol00001ooooo`0000?o0000ooooooooool0
H_ooool4oomo00;ooooo1?ooO`2_ooooo`7o00000Oooool00003o`000?oooooooooo06?ooooo0_oo
O`04ooooo`;oogl0/?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001
ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo0?oo
oooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o
0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1
o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000oooooooo
ool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo
00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolL
ooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003o
ooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o0000
0Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3o
oooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003
o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo
0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oooooo
oooo0?oooooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001oooo
o`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo
7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000
ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00
007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0
oooooolLooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo0000
0ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLoooo
o`7o00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003ooooo
ooooo`3oooooo`Cooooo0_ooO`0Fooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo0ooo
ool4oomo01Gooooo0Ol00001ooooo`0000?o0000ooooooooool0ooooool3ooooo`Coogl05Oooool1
o`00007ooooo00000ol0003oooooooooo`3oooooo`Cooooo0_ooO`0Fooooo`7o00000Oooool00003
o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo
0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oooooo
oooo0?oooooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001oooo
o`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo
7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000
ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00
007ooooo00000ol0003oooooooooo`2eooooo`;oogl0I?ooool1o`00007ooooo00000ol0003ooooo
ooooo`2dooooo`Coogl0Hoooool1o`00007ooooo00000ol0003oooooooooo`2dooooo`Coogl0Hooo
ool1o`00007ooooo00000ol0003oooooooooo`2eooooo`;oogl0=Oooool2oomo02gooooo0Ol00001
ooooo`0000?o0000ooooooooool0i?ooool2oomo00Gooooo1?ooO`0/ooooo`7o00000Oooool00003
o`000?oooooooooo0>?ooooo1?ooO`04ooooo`Coogl0;?ooool1o`00007ooooo00000ol0003ooooo
ooooo`33ooooo`;oogl07_ooool4oomo00Gooooo0_ooO`0]ooooo`7o00000Oooool00003o`000?oo
oooooooo0<;ooooo1?ooO`0;o`00oa?ooooo0_ooO`0eooooo`7o00000Oooool00003o`000?oooooo
oooo0<;ooooo1?l00?l;ooooo`;o003oB?ooool1o`00007ooooo00000ol0003oooooooooo`2noooo
o`Co003o00?ooooooomo0?ooO`003_ooool2o`00odKooooo0Ol00001ooooo`0000?o0000oooooooo
ool0^Oooool2oomo00?o003o5oooool2o`00o`Wooooo0_ooO`0iooooo`7o00000Oooool00003o`00
0?oooooooooo0;Oooooo1?l00?l00oooO`3oooooooooo`0Iooooo`;o003o1_ooool4oomo03Sooooo
0Ol00001ooooo`0000?o0000ooooooooool0]?ooool3o`00o`03ooooooooO`3oogl000;oogl07?oo
ool00ol00?ooooooooooo`04ooooo`Coogl00oooool2oomo03?ooooo0Ol00001ooooo`0000?o0000
ooooooooool0/_ooool2o`00o`?oogl00_ooool2oomo01?ooooo0_ooO`08ooooo`03o`00oooooooo
oooo00Gooooo0_ooO`03ooooo`Coogl0<_ooool1o`00007ooooo00000ol0003oooooooooo`2`oooo
o`;o003o00?ooooooomo0?ooO`000_ooO`06ooooo`;oogl03_ooool4oomo00Oooooo00?o003ooooo
ooooool02_ooool4oomo03;ooooo0Ol00001ooooo`0000?o0000ooooooooool0[_ooool2o`00o`Co
oooo0_ooO`06ooooo`Coogl03Oooool4oomo00Oooooo00?o003oooooooooool02oooool2oomo03?o
oooo0Ol00001ooooo`0000?o0000ooooooooool0Roooool2oomo023ooooo00?o003oooooooooool0
1?ooool2oomo00Kooooo1?ooO`0>ooooo`;oogl02Oooool00ol00?ooooooooooo`0oooooo`7o0000
0Oooool00003o`000?oooooooooo08[ooooo1?ooO`0Mooooo`;o003o1_ooool4oomo00Kooooo0_oo
O`0Jooooo`03o`00oooooooooooo03oooooo0Ol00001ooooo`0000?o0000ooooooooool0R_ooool4
oomo01cooooo00?o003oooooooooool01_ooool4oomo02;ooooo00?o003oooooooooool0?oooool1
o`00007ooooo00000ol0003oooooooooo`2;ooooo`;oogl06oooool2o`00o`[ooooo0_ooO`0Soooo
o`03o`00oooooooooooo03oooooo0Ol00001ooooo`0000?o0000ooooooooool0U_ooool2oomo00ko
oooo0_l00?lZooooo`;oogl01Oooool00ol00?ooooooooooo`0oooooo`7o00000Oooool00003o`00
0?oooooooooo09Gooooo1?ooO`0<ooooo`04o`00ooooooooogl0oomo02Sooooo1?ooO`03ooooo`03
o`00oooooooooooo043ooooo0Ol00001ooooo`0000?o0000ooooooooool0UOooool4oomo00[ooooo
0_l00?l00oooooooogl0oomo0002oomo02Oooooo1?ooO`03ooooo`03o`00oooooooooooo043ooooo
0Ol00001ooooo`0000?o0000ooooooooool0U_ooool2oomo00[ooooo00Co003ooooooooooooooooo
1?ooO`0Xooooo`;oogl01?ooool00ol00?ooooooooooo`10ooooo`7o00000Oooool00003o`000?oo
oooooooo0:7ooooo00?o003oooooooooool00oooool2oomo02kooooo00?o003oooooooooool0@Ooo
ool1o`00007ooooo00000ol0003oooooooooo`2Pooooo`03o`00oooooooooooo03?ooooo00?o003o
ooooooooool04_ooool2oomo02kooooo0Ol00001ooooo`0000?o0000ooooooooool0W_ooool2o`00
ocGooooo00?o003oooooooooool04_ooool4oomo02gooooo0Ol00001ooooo`0000?o0000oooooooo
ool0WOooool00ol00?ooooooooooo`0Eooooo`Co003o7?ooool00ol00?ooogl0oomo000Booooo`Co
ogl0;Oooool1o`00007ooooo00000ol0003oooooooooo`2Looooo`03o`00oooooooooooo01Gooooo
1_l00?lJooooo`03o`00ooooO`3oogl000;oogl04_ooool2oomo02kooooo0Ol00001ooooo`0000?o
0000ooooooooool0Voooool00ol00?ooooooooooo`0Eooooo`So003o6?ooool00ol00?oooooooomo
0003oomo04;ooooo0Ol00001ooooo`0000?o0000ooooooooool0Voooool00ol00?ooooooooooo`0E
ooooo`So003o5oooool01?l00?ooooooooooooooool2oomo04?ooooo0Ol00001ooooo`0000?o0000
ooooooooool0V_ooool00ol00?ooooooooooo`0Fooooo`So003o5_ooool00ol00?ooooooooooo`17
ooooo`7o00000Oooool00003o`000?oooooooooo09Wooooo00?o003oooooooooool03?ooool2oomo
00Sooooo00?oogl0o`00ool00?l01_l00?lEooooo`03o`00oooooooooooo00;oogl0A_ooool1o`00
007ooooo00000ol0003oooooooooo`2Iooooo`03o`00oooooooooooo00[ooooo1OooO`07ooooo`;o
ogl01_l00?lCooooo`;oogl000?o003oooooooooool01?ooO`15ooooo`7o00000Oooool00003o`00
0?oooooooooo09Sooooo00?o003oooooooooool02_ooool6oomo00Sooooo0_ooO`04o`00oa?ooooo
0_ooO`02o`00o`;ooooo1?ooO`15ooooo`7o00000Oooool00003o`000?oooooooooo09Sooooo00?o
003oooooooooool02_ooool5oomo02;ooooo00Coogl0o`00ooooO`3oogl00oooool2oomo04Kooooo
0Ol00001ooooo`0000?o0000ooooooooool0M_ooool2oomo01oooooo00?o003oooooooooool03?oo
ool2oomo02Cooooo00?o003ooomo0?ooO`00C?ooool1o`00007ooooo00000ol0003oooooooooo`1e
ooooo`Coogl07_ooool00ol00?ooooooooooo`0aooooo`03o`00oooooooooooo04gooooo0Ol00001
ooooo`0000?o0000ooooooooool0MOooool4oomo00[ooooo0_ooO`0Aooooo`03o`00oooooooooooo
037ooooo00?o003oooooooooool0C_ooool1o`00007ooooo00000ol0003oooooooooo`1fooooo`;o
ogl02_ooool4oomo00oooooo00?o003oooooooooool06?ooool2oomo01Oooooo00?o003ooooooooo
ool0Coooool1o`00007ooooo00000ol0003oooooooooo`22ooooo`Coogl03oooool00ol00?oooooo
ooooo`0Gooooo`Coogl05?ooool2o`00oe;ooooo0Ol00001ooooo`0000?o0000ooooooooool0Pooo
ool2oomo00oooooo00?o003oooooooooool04_ooool2oomo00Cooooo1?ooO`0Aooooo`?o003oE?oo
ool1o`00007ooooo00000ol0003oooooooooo`2Dooooo`03o`00oooooooooooo017ooooo1?ooO`04
ooooo`;oogl04?ooool2o`00oeOooooo0Ol00001ooooo`0000?o0000ooooooooool0U?ooool00ol0
0?ooooooooooo`0Aooooo`Coogl05Oooool00ol00?ooooooooooo`1Gooooo`7o00000Oooool00003
o`000?oooooooooo09Cooooo00?o003oooooooooool04_ooool2oomo01Cooooo0_l00?mJooooo`7o
00000Oooool00003o`000?oooooooooo09Cooooo00?o003oooooooooool09_ooool2o`00oecooooo
0Ol00001ooooo`0000?o0000ooooooooool0UOooool00ol00?ooooooooooo`0Tooooo`03o`00oooo
oooooooo05cooooo0Ol00001ooooo`0000?o0000ooooooooool0UOooool00ol00?ooooooooooo`0R
ooooo`;o003oGoooool1o`00007ooooo00000ol0003oooooooooo`2Eooooo`03o`00oooooooooooo
023ooooo0_l00?mQooooo`7o00000Oooool00003o`000?oooooooooo08Cooooo0_ooO`0?ooooo`;o
003o7oooool2o`00of?ooooo0Ol00001ooooo`0000?o0000ooooooooool0Poooool4oomo013ooooo
0_l00?lJooooo`?o003oIOooool1o`00007ooooo00000ol0003oooooooooo`23ooooo`Coogl04_oo
ool2o`00oaCooooo1?l00?mXooooo`7o00000Oooool00003o`000?oooooooooo08Cooooo0_ooO`0E
ooooo`?o003o3_ooool3o`00o`?ooooo0_ooO`1Wooooo`7o00000Oooool00003o`000?oooooooooo
09kooooo0ol00?l5ooooo`Ko003o1Oooool4oomo06Kooooo0Ol00001ooooo`0000?o0000oooooooo
ool0XOooool5o`00o`_ooooo1?ooO`1Vooooo`7o00000Oooool00003o`000?oooooooooo0;;ooooo
0_ooO`1Wooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo0000
0ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0Noooool2oomo
09kooooo0Ol00001ooooo`0000?o0000ooooooooool0N_ooool4oomo09gooooo0Ol00001ooooo`00
00?o0000ooooooooool0N_ooool4oomo023ooooo0_ooO`1kooooo`7o00000Oooool00003o`000?oo
oooooooo07_ooooo0_ooO`0Pooooo`Coogl0N_ooool1o`00007ooooo00000ol0003oooooooooo`2M
ooooo`Coogl0N_ooool1o`00007ooooo00000ol0003oooooooooo`2@ooooo`;oogl03?ooool2oomo
07_ooooo0Ol00001ooooo`0000?o0000ooooooooool0Soooool4oomo08Sooooo0Ol00001ooooo`00
00?o0000ooooooooool0Soooool4oomo08Sooooo0Ol00001ooooo`0000?o0000ooooooooool0T?oo
ool2oomo02?ooooo0_ooO`1Tooooo`7o00000Oooool00003o`000?oooooooooo0;Cooooo1?ooO`1S
ooooo`7o00000Oooool00003o`000?oooooooooo0;Cooooo1?ooO`1Sooooo`7o00000Oooool00003
o`000?oooooooooo0;Gooooo0_ooO`1Tooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo
7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000
ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00
007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0
oooooolLooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo0000
0ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLoooo
o`7o00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003ooooo
ooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Ooo
ool00003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooo
oacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`00
0?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol0
0001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo
0?oooooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`00
00?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?oo
ool1o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000oooo
ooooool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007o
oooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooo
oolLooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0
003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o
00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003ooooooooo
o`3ooooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool0
0003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooooaco
oooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oo
oooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003oooooooooo`2>ooooo`;oogl0Roooool1
o`00007ooooo00000ol0003oooooooooo`2=ooooo`Coogl0R_ooool1o`00007ooooo00000ol0003o
ooooooooo`2=ooooo`Coogl0R_ooool1o`00007ooooo00000ol0003oooooooooo`2>ooooo`;oogl0
Roooool1o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000
ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00
007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0
oooooolLooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo0000
0ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLoooo
o`7o00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003ooooo
ooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Ooo
ool00003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooo
oacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`00
0?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol0
0001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo
0?oooooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`00
00?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?oo
ool1o`00007ooooo003oo`00023o00000Oooool00001\
\>"],
  ImageRangeCache->{{{0, 287}, {287, 0}} -> {-1.01089, -1.01089, 0.00704453, \
0.00704453}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.49505 0.5 0.49505 [
[ 0 0 -0.125 0 ]
[ 0 0 -0.125 0 ]
[ 0 1 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
0 0 m
1 0 L
s
0 0 m
0 1 L
s
0 1 m
1 1 L
s
1 0 m
1 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
1 .5 0 r
.015 w
.03175 .1355 Mdot
.03435 .12523 Mdot
.11137 .12765 Mdot
.14107 .18841 Mdot
.16218 .24538 Mdot
.17294 .21053 Mdot
.18267 .18577 Mdot
.18434 .1304 Mdot
.18553 .30956 Mdot
.20401 .239 Mdot
.21247 .27571 Mdot
.21687 .20845 Mdot
.22376 .2799 Mdot
.22832 .27485 Mdot
.29063 .20974 Mdot
.29686 .25079 Mdot
.30487 .22936 Mdot
.30683 .34623 Mdot
.32055 .20902 Mdot
.32574 .21979 Mdot
.34472 .28521 Mdot
.35998 .36393 Mdot
.36335 .24976 Mdot
.3794 .36608 Mdot
.42386 .66992 Mdot
.44391 .74519 Mdot
.45059 .34198 Mdot
.47208 .67586 Mdot
.47436 .71381 Mdot
.49778 .59825 Mdot
.50874 .91643 Mdot
.51516 .76219 Mdot
.53655 .61374 Mdot
.56563 .75219 Mdot
.59189 .65665 Mdot
.59581 .61604 Mdot
.59923 .6556 Mdot
.60292 .68499 Mdot
.62656 .67779 Mdot
.63555 .72451 Mdot
.63919 .652 Mdot
.64169 .6004 Mdot
.64246 .58611 Mdot
.64496 .54267 Mdot
.64608 .77288 Mdot
.65077 .64308 Mdot
.66065 .57816 Mdot
.67474 .59169 Mdot
.69296 .563 Mdot
.72815 .65902 Mdot
.73169 .58879 Mdot
.74669 .61318 Mdot
.74821 .65474 Mdot
.75963 .63781 Mdot
.79673 .57809 Mdot
.80925 .55852 Mdot
.81525 .58444 Mdot
.83417 .62985 Mdot
.83598 .55526 Mdot
.91595 .49319 Mdot
1 0 0 r
.005 w
.16128 .17044 m
.18734 .17269 L
.21339 .17909 L
.2345 .18734 L
.23945 .19126 L
.2655 .20415 L
.27874 .21339 L
.29156 .22295 L
.31204 .23945 L
.31761 .24532 L
.33549 .2655 L
.34367 .28341 L
.34499 .29156 L
.34367 .29798 L
.31761 .3104 L
.29156 .30711 L
.2655 .30014 L
.24507 .29156 L
.23945 .28747 L
.21339 .27402 L
.20155 .2655 L
.18734 .25472 L
.16884 .23945 L
.16128 .2313 L
.14618 .21339 L
.13806 .18734 L
.16128 .17044 L
s
0 0 1 r
.65633 .57701 m
.68239 .56842 L
.70844 .56313 L
.7345 .56168 L
.76055 .5752 L
.76359 .57817 L
.76859 .60422 L
.76055 .62333 L
.75627 .63028 L
.7345 .65485 L
.73298 .65633 L
.70844 .6775 L
.69922 .68239 L
.68239 .69294 L
.65633 .70579 L
.64983 .70844 L
.63028 .71539 L
.60422 .72268 L
.57817 .72651 L
.55211 .7214 L
.53145 .70844 L
.52926 .68239 L
.54239 .65633 L
.55211 .63983 L
.56625 .63028 L
.57817 .6193 L
.60119 .60422 L
.60422 .60227 L
.63028 .58726 L
.65315 .57817 L
.65633 .57701 L
s
1 0 0 r
.03 w
.24141 .24033 Mdot
0 0 1 r
.64872 .64417 Mdot
1 0 0 r
.79703 .00495 m
.79703 .25248 L
.87129 .25248 L
.87129 .00495 L
F
0 0 1 r
.89604 .00495 m
.89604 .00495 L
.9703 .00495 L
.9703 .00495 L
F
1 0 1 r
.04 w
.21247 .27571 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P000182000`400?l00000o`00003ooooooolQ
ooooo`00ool0000Po`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`00
00?o0000ooooooooool0hOoooolEool002Gooooo0Ol00001ooooo`0000?o0000ooooooooool0hOoo
oolEool002Gooooo0Ol00001ooooo`0000?o0000ooooooooool0hOoooolEool002Gooooo0Ol00001
ooooo`0000?o0000ooooooooool0hOoooolEool002Gooooo0Ol00001ooooo`0000?o0000oooooooo
ool0hOoooolEool002Gooooo0Ol00001ooooo`0000?o0000ooooooooool0hOoooolEool002Gooooo
0Ol00001ooooo`0000?o0000ooooooooool0hOoooolEool002Gooooo0Ol00001ooooo`0000?o0000
ooooooooool0hOoooolEool002Gooooo0Ol00001ooooo`0000?o0000ooooooooool0hOoooolEool0
02Gooooo0Ol00001ooooo`0000?o0000ooooooooool0hOoooolEool002Gooooo0Ol00001ooooo`00
00?o0000ooooooooool0hOoooolEool002Gooooo0Ol00001ooooo`0000?o0000ooooooooool0hOoo
oolEool002Gooooo0Ol00001ooooo`0000?o0000ooooooooool0hOoooolEool002Gooooo0Ol00001
ooooo`0000?o0000ooooooooool0hOoooolEool002Gooooo0Ol00001ooooo`0000?o0000oooooooo
ool0hOoooolEool002Gooooo0Ol00001ooooo`0000?o0000ooooooooool0hOoooolEool002Gooooo
0Ol00001ooooo`0000?o0000ooooooooool0hOoooolEool002Gooooo0Ol00001ooooo`0000?o0000
ooooooooool0hOoooolEool002Gooooo0Ol00001ooooo`0000?o0000ooooooooool0hOoooolEool0
02Gooooo0Ol00001ooooo`0000?o0000ooooooooool0hOoooolEool002Gooooo0Ol00001ooooo`00
00?o0000ooooooooool0hOoooolEool002Gooooo0Ol00001ooooo`0000?o0000ooooooooool0hOoo
oolEool002Gooooo0Ol00001ooooo`0000?o0000ooooooooool0hOoooolEool002Gooooo0Ol00001
ooooo`0000?o0000ooooooooool0hOoooolEool002Gooooo0Ol00001ooooo`0000?o0000oooooooo
ool0hOoooolEool002Gooooo0Ol00001ooooo`0000?o0000ooooooooool0hOoooolEool002Gooooo
0Ol00001ooooo`0000?o0000ooooooooool0hOoooolEool002Gooooo0Ol00001ooooo`0000?o0000
ooooooooool0hOoooolEool002Gooooo0Ol00001ooooo`0000?o0000ooooooooool0hOoooolEool0
02Gooooo0Ol00001ooooo`0000?o0000ooooooooool0hOoooolEool002Gooooo0Ol00001ooooo`00
00?o0000ooooooooool0hOoooolEool002Gooooo0Ol00001ooooo`0000?o0000ooooooooool0hOoo
oolEool002Gooooo0Ol00001ooooo`0000?o0000ooooooooool01_ooool2oomo0=Wooooo5Ooo000U
ooooo`7o00000Oooool00003o`000?oooooooooo00Gooooo1?ooO`0Cooooo`;oogl0`ooooolEool0
02Gooooo0Ol00001ooooo`0000?o0000ooooooooool01Oooool4oomo01;ooooo1?ooO`0Booooo`;o
ogl0[_oooolEool002Gooooo0Ol00001ooooo`0000?o0000ooooooooool01Oooool3oomo01?ooooo
1?ooO`0Aooooo`Coogl0[OoooolEool002Gooooo0Ol00001ooooo`0000?o0000ooooooooool01?oo
ool4oomo01Cooooo0_ooO`0Booooo`Coogl0[OoooolEool002Gooooo0Ol00001ooooo`0000?o0000
ooooooooool01?ooool4oomo02Wooooo0_ooO`2^oooooaGoo`009Oooool1o`00007ooooo00000ol0
003oooooooooo`05ooooo`;oogl0f_oooolEool002Gooooo0Ol00001ooooo`0000?o0000oooooooo
ool0hOoooolEool002Gooooo0Ol00001ooooo`0000?o0000ooooooooool0hOoooolEool002Gooooo
0Ol00001ooooo`0000?o0000ooooooooool0hOoooolEool002Gooooo0Ol00001ooooo`0000?o0000
ooooooooool0hOoooolEool002Gooooo0Ol00001ooooo`0000?o0000ooooooooool0hOoooolEool0
02Gooooo0Ol00001ooooo`0000?o0000ooooooooool0hOoooolEool002Gooooo0Ol00001ooooo`00
00?o0000ooooooooool0hOoooolEool002Gooooo0Ol00001ooooo`0000?o0000ooooooooool0:_oo
ool6ool00;7ooooo5Ooo000Uooooo`7o00000Oooool00003o`000?oooooooooo02Wooooo00?oo`00
ooooooooool01?ooool5ool00:cooooo5Ooo000Uooooo`7o00000Oooool00003o`000?oooooooooo
02Oooooo0_oo000<ooooo`Coo`00Z?oooolEool002Gooooo0Ol00001ooooo`0000?o0000oooooooo
ool09_ooool00ooo003oooooooooo`0@ooooo`Coo`00Y?oooolEool002Gooooo0Ol00001ooooo`00
00?o0000ooooooooool09?ooool00oooO`3oo`00ooooo`09ooooo`;oogl02oooool3ool00:7ooooo
5Ooo000Uooooo`7o00000Oooool00003o`000?oooooooooo02?ooooo00Coogl0ool00?ooO`3oogl0
2?ooool4oomo00gooooo00?oo`00ooooooooool0W_oooolEool002Gooooo0Ol00001ooooo`0000?o
0000ooooooooool08oooool01?ooO`3oo`00oomo0?ooO`08ooooo`Coogl03_ooool2ool009kooooo
5Ooo000Uooooo`7o00000Oooool00003o`000?oooooooooo02Cooooo00?oogl0ool00?ooool02Ooo
ool2oomo017ooooo0_oo002LoooooaGoo`009Oooool1o`00007ooooo00000ol0003oooooooooo`0U
ooooo`03ool00?oooooooooo01gooooo0_oo002JoooooaGoo`009Oooool1o`00007ooooo00000ol0
003oooooooooo`0Uooooo`03ool00?oooooooooo01oooooo0_oo002HoooooaGoo`009Oooool1o`00
007ooooo00000ol0003oooooooooo`0Vooooo`03ool00?oooooooooo017ooooo0_ooO`0=ooooo`;o
o`001?ooool2oomo00Oooooo0_ooO`27oooooaGoo`009Oooool1o`00007ooooo00000ol0003ooooo
ooooo`0Vooooo`03ool00?oooooooooo00Gooooo0_ooO`09ooooo`Coogl03_ooool00ooo003ooooo
ooooo`04oomo00Gooooo1?ooO`26oooooaGoo`009Oooool1o`00007ooooo00000ol0003ooooooooo
o`0Vooooo`03ool00?oooooooooo00Cooooo1?ooO`08ooooo`Coogl03oooool00ooo003ooooooomo
0003oomo00Gooooo1?ooO`26oooooaGoo`009Oooool1o`00007ooooo00000ol0003oooooooooo`0W
ooooo`03ool00?oooooooooo00?ooooo1?ooO`09ooooo`;oogl04Oooool01?oo003ooooooomo0?oo
O`07ooooo`?oogl0Q_oooolEool002Gooooo0Ol00001ooooo`0000?o0000ooooooooool09oooool0
0ooo003oooooooooo`04ooooo`;oogl07_ooool00ooo003oooooooooo`07ooooo`Coogl0QOoooolE
ool002Gooooo0Ol00001ooooo`0000?o0000ooooooooool0:?ooool00ooo003oooooooooo`0Toooo
o`03ool00?oooooooooo00Kooooo1?ooO`25oooooaGoo`009Oooool1o`00007ooooo00000ol0003o
ooooooooo`0Yooooo`03ool00?oooooooooo02Cooooo0_oo00000oooooooogl0oomo0004ooooo`;o
ogl0Q_oooolEool002Gooooo0Ol00001ooooo`0000?o0000ooooooooool0:_ooool00ooo003ooooo
ooooo`0Cooooo`Coo`003_ooool01?oo003oogl0oomo0?ooO`2;oooooaGoo`009Oooool1o`00007o
oooo00000ol0003oooooooooo`0[ooooo`03ool00?oooooooooo017ooooo1_oo000=ooooo`04oomo
0?oo003oo`00oomo08_ooooo5Ooo000Uooooo`7o00000Oooool00003o`000?oooooooooo02cooooo
00?oo`00ooooooooool02?ooool2oomo00Gooooo2?oo000=ooooo`;oogl000?oo`00ooooooooool0
ROoooolEool002Gooooo0Ol00001ooooo`0000?o0000ooooooooool0;Oooool00ooo003ooooooooo
o`06ooooo`Coogl01?ooool8ool0013ooooo00?oo`00ooooooooool0R?oooolEool002Gooooo0Ol0
0001ooooo`0000?o0000ooooooooool0:oooool2oomo0003oooooooo003ooooo00Kooooo1?ooO`04
ooooo`Soo`004Oooool00ooo003oooooooooo`27oooooaGoo`009Oooool1o`00007ooooo00000ol0
003oooooooooo`0Zooooo`Coogl000?oooooool00?ooool01_ooool2oomo00Gooooo2?oo000;oooo
o`;oogl01Oooool00ooo003oooooooooo`09ooooo`;oogl0NooooolEool002Gooooo0Ol00001oooo
o`0000?o0000ooooooooool0:_ooool4oomo00;ooooo00?oo`00ooooooooool03?ooool6ool000_o
oooo1?ooO`04ooooo`03ool00?oooooooooo00Sooooo1?ooO`1joooooaGoo`009Oooool1o`00007o
oooo00000ol0003oooooooooo`0[ooooo`;oogl01?ooool00ooo003oooooooooo`0<ooooo`Coo`00
3?ooool4oomo00Gooooo00?oo`00ooooooooool01oooool4oomo07[ooooo5Ooo000Uooooo`7o0000
0Oooool00003o`000?oooooooooo03;ooooo0_oo000Mooooo`;oogl01oooool00ooo003ooooooooo
o`07ooooo`;oogl0]Oooool1o`00007ooooo00000ol0003oooooooooo`0dooooo`03ool00?oooooo
oooo00Goo`3o7oooool00ooo003oooooooooo`2mooooo`7o00000Oooool00003o`000?oooooooooo
03Gooooo00?oo`00ool0oooo0?l01Ooo0?lOooooo`03ool00?oooooooooo0;cooooo0Ol00001oooo
o`0000?o0000ooooooooool0=Oooool9ool0oaoooooo00?oo`00ooooooooool0^oooool1o`00007o
oooo00000ol0003oooooooooo`0dooooo`_oo`3o7_ooool00ooo003oooooooooo`2kooooo`7o0000
0Oooool00003o`000?oooooooooo03Cooooo2ooo0?l00oooO`3oooooooooo`0Looooo`03ool00?oo
oooooooo0;[ooooo0Ol00001ooooo`0000?o0000ooooooooool0=?ooool;ool0o`03oomo0?oooooo
oooo01cooooo00?oo`00ooooooooool0^_ooool1o`00007ooooo00000ol0003oooooooooo`0doooo
o`_oo`3o7oooool00ooo003oogl0oomo002jooooo`7o00000Oooool00003o`000?oooooooooo03Co
oooo2ooo0?l2ool001gooooo00Coogl0ool00?ooO`3oogl0^Oooool1o`00007ooooo00000ol0003o
ooooooooo`0eooooo`Woo`3o0oooool2ool001_ooooo00Coogl0ool00?ooO`3oogl0^Oooool1o`00
007ooooo00000ol0003oooooooooo`0fooooo`Ooo`3o1_ooool2ool001[ooooo00?oogl0ool00?oo
ool0^Oooool1o`00007ooooo00000ol0003oooooooooo`0gooooo`Goo`3o2Oooool2ool001Wooooo
00?oo`00ooooooooool0^?ooool1o`00007ooooo00000ol0003oooooooooo`17ooooo`;oo`005Ooo
ool2ool00;_ooooo0Ol00001ooooo`0000?o0000ooooooooool0BOooool3ool0013ooooo0_oo002m
ooooo`7o00000Oooool00003o`000?oooooooooo037ooooo0_ooO`0Iooooo`?oo`003?ooool00ooo
003oooooooooo`2mooooo`7o00000Oooool00003o`000?oooooooooo033ooooo1?ooO`0Kooooo`Ko
o`001?ooool2ool00<3ooooo0Ol00001ooooo`0000?o0000ooooooooool0<?ooool4oomo027ooooo
1?oo0032ooooo`7o00000Oooool00003o`000?oooooooooo037ooooo0_ooO`3Xooooo`7o00000Ooo
ool00003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooo
oacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`00
0?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol0
0001ooooo`0000?o0000ooooooooool0OOooool2oomo09cooooo0Ol00001ooooo`0000?o0000oooo
ooooool0O?ooool4oomo09_ooooo0Ol00001ooooo`0000?o0000ooooooooool0E?ooool2oomo02Ko
oooo1?ooO`2Kooooo`7o00000Oooool00003o`000?oooooooooo05?ooooo1?ooO`0Vooooo`;oogl0
W?ooool1o`00007ooooo00000ol0003oooooooooo`1Cooooo`Coogl0a?ooool1o`00007ooooo0000
0ol0003oooooooooo`1Dooooo`;oogl0aOooool1o`00007ooooo00000ol0003oooooooooo`3ooooo
oacooooo0Ol00001ooooo`0000?o0000ooooooooool0Hoooool2oomo00Cooooo0_ooO`2`ooooo`7o
00000Oooool00003o`000?oooooooooo06;ooooo1?ooO`02ooooo`Coogl0[oooool1o`00007ooooo
00000ol0003oooooooooo`1Rooooo`Coogl00_ooool4oomo0:oooooo0Ol00001ooooo`0000?o0000
ooooooooool0Hoooool2oomo00Cooooo0_ooO`2`ooooo`7o00000Oooool00003o`000?oooooooooo
0?oooooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`00
00?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?oo
ool1o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000oooo
ooooool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007o
oooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooo
oolLooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0
003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o
00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003ooooooooo
o`3ooooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool0
0003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooooaco
oooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oo
oooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001
ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo0?oo
oooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o
0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1
o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000oooooooo
ool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo
00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolL
ooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003o
ooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o0000
0Oooool00003o`000?oooooooooo0?oooooo1?ooool2oomo01Kooooo0Ol00001ooooo`0000?o0000
ooooooooool0ooooool3ooooo`Coogl05Oooool1o`00007ooooo00000ol0003oooooooooo`3ooooo
o`?ooooo1?ooO`0Eooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo1?ooool2oomo01Ko
oooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oo
oooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001
ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo0?oo
oooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o
0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1
o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000oooooooo
ool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo0;Gooooo0_ooO`1Tooooo`7o0000
0Oooool00003o`000?oooooooooo0;Cooooo1?ooO`1Sooooo`7o00000Oooool00003o`000?oooooo
oooo0;Cooooo1?ooO`1Sooooo`7o00000Oooool00003o`000?oooooooooo0;Gooooo0_ooO`0eoooo
o`;oogl0;Oooool1o`00007ooooo00000ol0003oooooooooo`3Tooooo`;oogl01Oooool4oomo02co
oooo0Ol00001ooooo`0000?o0000ooooooooool0hoooool4oomo00Cooooo1?ooO`0/ooooo`7o0000
0Oooool00003o`000?oooooooooo0<?ooooo0_ooO`0Nooooo`Coogl01Oooool2oomo02gooooo0Ol0
0001ooooo`0000?o0000ooooooooool0`_ooool4oomo00_o003o4oooool2oomo03Gooooo0Ol00001
ooooo`0000?o0000ooooooooool0`_ooool4o`00o`_ooooo0_l00?m8ooooo`7o00000Oooool00003
o`000?oooooooooo0;kooooo1?l00?l00oooooooogl0oomo000>ooooo`;o003oA_ooool1o`00007o
oooo00000ol0003oooooooooo`2iooooo`;oogl00ol00?lGooooo`;o003o2Oooool2oomo03Wooooo
0Ol00001ooooo`0000?o0000ooooooooool0]oooool4o`00o`03oomo0?oooooooooo01Wooooo0_l0
0?l6ooooo`Coogl0>?ooool1o`00007ooooo00000ol0003oooooooooo`2dooooo`?o003o00?ooooo
oomo0?ooO`000_ooO`0Looooo`03o`00oooooooooooo00Cooooo1?ooO`03ooooo`;oogl0<oooool1
o`00007ooooo00000ol0003oooooooooo`2booooo`;o003o0oooO`02ooooo`;oogl04oooool2oomo
00Sooooo00?o003oooooooooool01Oooool2oomo00?ooooo1?ooO`0booooo`7o00000Oooool00003
o`000?oooooooooo0;3ooooo0_l00?l00oooooooogl0oomo0002oomo00Kooooo0_ooO`0>ooooo`Co
ogl01oooool00ol00?ooooooooooo`0:ooooo`Coogl0<_ooool1o`00007ooooo00000ol0003ooooo
ooooo`2^ooooo`;o003o1?ooool2oomo00Kooooo1?ooO`0=ooooo`Coogl01oooool00ol00?oooooo
ooooo`0;ooooo`;oogl0<oooool1o`00007ooooo00000ol0003oooooooooo`2;ooooo`;oogl08?oo
ool00ol00?ooooooooooo`04ooooo`;oogl01_ooool4oomo00kooooo0_ooO`09ooooo`03o`00oooo
oooooooo03oooooo0Ol00001ooooo`0000?o0000ooooooooool0R_ooool4oomo01gooooo0_l00?l6
ooooo`Coogl01_ooool2oomo01[ooooo00?o003oooooooooool0?oooool1o`00007ooooo00000ol0
003oooooooooo`2:ooooo`Coogl07?ooool00ol00?ooooooooooo`06ooooo`Coogl08_ooool00ol0
0?ooooooooooo`0oooooo`7o00000Oooool00003o`000?oooooooooo08_ooooo0_ooO`0Kooooo`;o
003o2_ooool2oomo02?ooooo00?o003oooooooooool0?oooool1o`00007ooooo00000ol0003ooooo
ooooo`2Fooooo`;oogl03_ooool2o`00ob[ooooo0_ooO`05ooooo`03o`00oooooooooooo03oooooo
0Ol00001ooooo`0000?o0000ooooooooool0UOooool4oomo00cooooo00Co003oooooooooO`3oogl0
:?ooool4oomo00?ooooo00?o003oooooooooool0@?ooool1o`00007ooooo00000ol0003ooooooooo
o`2Eooooo`Coogl02_ooool2o`00o`03ooooooooO`3oogl000;oogl09oooool4oomo00?ooooo00?o
003oooooooooool0@?ooool1o`00007ooooo00000ol0003oooooooooo`2Fooooo`;oogl02_ooool0
1?l00?ooooooooooooooool4oomo02Sooooo0_ooO`04ooooo`03o`00oooooooooooo043ooooo0Ol0
0001ooooo`0000?o0000ooooooooool0XOooool00ol00?ooooooooooo`03ooooo`;oogl0;_ooool0
0ol00?ooooooooooo`11ooooo`7o00000Oooool00003o`000?oooooooooo0:3ooooo00?o003ooooo
ooooool0<oooool00ol00?ooooooooooo`0Booooo`;oogl0;_ooool1o`00007ooooo00000ol0003o
ooooooooo`2Nooooo`;o003o=Oooool00ol00?ooooooooooo`0Booooo`Coogl0;Oooool1o`00007o
oooo00000ol0003oooooooooo`2Mooooo`03o`00oooooooooooo01Gooooo1?l00?lLooooo`03o`00
ooooO`3oogl001;ooooo1?ooO`0]ooooo`7o00000Oooool00003o`000?oooooooooo09cooooo00?o
003oooooooooool05Oooool6o`00oa[ooooo00?o003ooomo0?ooO`000_ooO`0Booooo`;oogl0;_oo
ool1o`00007ooooo00000ol0003oooooooooo`2Kooooo`03o`00oooooooooooo01Gooooo2?l00?lH
ooooo`03o`00ooooooooogl000?oogl0@_ooool1o`00007ooooo00000ol0003oooooooooo`2Koooo
o`03o`00oooooooooooo01Gooooo2?l00?lGooooo`04o`00ooooooooooooooooo`;oogl0@oooool1
o`00007ooooo00000ol0003oooooooooo`2Jooooo`03o`00oooooooooooo01Kooooo2?l00?lFoooo
o`03o`00oooooooooooo04Oooooo0Ol00001ooooo`0000?o0000ooooooooool0VOooool00ol00?oo
ooooooooo`0<ooooo`;oogl02?ooool00oooO`3o003oo`00o`06o`00oaGooooo00?o003ooooooooo
ool00_ooO`16ooooo`7o00000Oooool00003o`000?oooooooooo09Wooooo00?o003oooooooooool0
2_ooool5oomo00Oooooo0_ooO`06o`00oa?ooooo0_ooO`000ol00?ooooooooooo`04oomo04Gooooo
0Ol00001ooooo`0000?o0000ooooooooool0V?ooool00ol00?ooooooooooo`0:ooooo`Koogl02?oo
ool2oomo00Co003o4oooool2oomo00;o003o0_ooool4oomo04Gooooo0Ol00001ooooo`0000?o0000
ooooooooool0V?ooool00ol00?ooooooooooo`0:ooooo`Googl08_ooool01?ooO`3o003ooomo0?oo
O`03ooooo`;oogl0A_ooool1o`00007ooooo00000ol0003oooooooooo`1fooooo`;oogl07oooool0
0ol00?ooooooooooo`0<ooooo`;oogl09?ooool00ol00?ooogl0oomo001<ooooo`7o00000Oooool0
0003o`000?oooooooooo07Gooooo1?ooO`0Nooooo`03o`00oooooooooooo037ooooo00?o003ooooo
ooooool0COooool1o`00007ooooo00000ol0003oooooooooo`1eooooo`Coogl02_ooool2oomo017o
oooo00?o003oooooooooool0<Oooool00ol00?ooooooooooo`1>ooooo`7o00000Oooool00003o`00
0?oooooooooo07Kooooo0_ooO`0:ooooo`Coogl03oooool00ol00?ooooooooooo`0Hooooo`;oogl0
5oooool00ol00?ooooooooooo`1?ooooo`7o00000Oooool00003o`000?oooooooooo08;ooooo1?oo
O`0?ooooo`03o`00oooooooooooo01Oooooo1?ooO`0Dooooo`;o003oD_ooool1o`00007ooooo0000
0ol0003oooooooooo`23ooooo`;oogl03oooool00ol00?ooooooooooo`0Booooo`;oogl01?ooool4
oomo017ooooo0ol00?mDooooo`7o00000Oooool00003o`000?oooooooooo09Cooooo00?o003ooooo
ooooool04Oooool4oomo00Cooooo0_ooO`0@ooooo`;o003oEoooool1o`00007ooooo00000ol0003o
ooooooooo`2Dooooo`03o`00oooooooooooo017ooooo1?ooO`0Eooooo`03o`00oooooooooooo05Oo
oooo0Ol00001ooooo`0000?o0000ooooooooool0U?ooool00ol00?ooooooooooo`0Booooo`;oogl0
5?ooool2o`00oe[ooooo0Ol00001ooooo`0000?o0000ooooooooool0U?ooool00ol00?oooooooooo
o`0Vooooo`;o003oG?ooool1o`00007ooooo00000ol0003oooooooooo`2Eooooo`03o`00oooooooo
oooo02Cooooo00?o003oooooooooool0G?ooool1o`00007ooooo00000ol0003oooooooooo`2Eoooo
o`03o`00oooooooooooo02;ooooo0_l00?mOooooo`7o00000Oooool00003o`000?oooooooooo09Go
oooo00?o003oooooooooool08?ooool2o`00of7ooooo0Ol00001ooooo`0000?o0000ooooooooool0
Q?ooool2oomo00oooooo0_l00?lOooooo`;o003oHoooool1o`00007ooooo00000ol0003ooooooooo
o`23ooooo`Coogl04?ooool2o`00oa[ooooo0ol00?mUooooo`7o00000Oooool00003o`000?oooooo
oooo08?ooooo1?ooO`0Booooo`;o003o5?ooool4o`00ofSooooo0Ol00001ooooo`0000?o0000oooo
ooooool0Q?ooool2oomo01Gooooo0ol00?l>ooooo`?o003o0oooool2oomo06Oooooo0Ol00001oooo
o`0000?o0000ooooooooool0W_ooool3o`00o`Gooooo1_l00?l5ooooo`Coogl0I_ooool1o`00007o
oooo00000ol0003oooooooooo`2Qooooo`Go003o2oooool4oomo06Kooooo0Ol00001ooooo`0000?o
0000ooooooooool0/_ooool2oomo06Oooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolL
ooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003o
ooooooooo`1kooooo`;oogl0W_ooool1o`00007ooooo00000ol0003oooooooooo`1jooooo`Coogl0
WOooool1o`00007ooooo00000ol0003oooooooooo`1jooooo`Coogl08?ooool2oomo07_ooooo0Ol0
0001ooooo`0000?o0000ooooooooool0Noooool2oomo023ooooo1?ooO`1jooooo`7o00000Oooool0
0003o`000?oooooooooo09gooooo1?ooO`1jooooo`7o00000Oooool00003o`000?oooooooooo093o
oooo0_ooO`0<ooooo`;oogl0Noooool1o`00007ooooo00000ol0003oooooooooo`2?ooooo`Coogl0
R?ooool1o`00007ooooo00000ol0003oooooooooo`2?ooooo`Coogl0R?ooool1o`00007ooooo0000
0ol0003oooooooooo`2@ooooo`;oogl08oooool2oomo06Cooooo0Ol00001ooooo`0000?o0000oooo
ooooool0]?ooool4oomo06?ooooo0Ol00001ooooo`0000?o0000ooooooooool0]?ooool4oomo06?o
oooo0Ol00001ooooo`0000?o0000ooooooooool0]Oooool2oomo06Cooooo0Ol00001ooooo`0000?o
0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1
o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000oooooooo
ool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo
00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolL
ooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003o
ooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o0000
0Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3o
oooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003
o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo
0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oooooo
oooo0?oooooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001oooo
o`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo
7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000
ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00
007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0
oooooolLooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo0000
0ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLoooo
o`7o00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003ooooo
ooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Ooo
ool00003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooo
oacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`00
0?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol0
0001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo
08kooooo0_ooO`2;ooooo`7o00000Oooool00003o`000?oooooooooo08gooooo1?ooO`2:ooooo`7o
00000Oooool00003o`000?oooooooooo08gooooo1?ooO`2:ooooo`7o00000Oooool00003o`000?oo
oooooooo08kooooo0_ooO`2;ooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1
o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000oooooooo
ool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo
00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolL
ooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003o
ooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o0000
0Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3o
oooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003
o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo
0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oooooo
oooo0?oooooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001oooo
o`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo
7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000
ooooooooool0oooooolLooooo`7o00000Oooool00?oo00008?l00001ooooo`00\
\>"],
  ImageRangeCache->{{{0, 287}, {287, 0}} -> {-1.01089, -1.01089, 0.00704453, \
0.00704453}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.49505 0.5 0.49505 [
[ 0 0 -0.125 0 ]
[ 0 0 -0.125 0 ]
[ 0 1 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
0 0 m
1 0 L
s
0 0 m
0 1 L
s
0 1 m
1 1 L
s
1 0 m
1 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
1 .5 0 r
.015 w
.03175 .1355 Mdot
.03435 .12523 Mdot
.11137 .12765 Mdot
.14107 .18841 Mdot
.16218 .24538 Mdot
.17294 .21053 Mdot
.18267 .18577 Mdot
.18434 .1304 Mdot
.18553 .30956 Mdot
.20401 .239 Mdot
.21247 .27571 Mdot
.21687 .20845 Mdot
.22376 .2799 Mdot
.22832 .27485 Mdot
.29063 .20974 Mdot
.29686 .25079 Mdot
.30487 .22936 Mdot
.30683 .34623 Mdot
.32055 .20902 Mdot
.32574 .21979 Mdot
.34472 .28521 Mdot
.35998 .36393 Mdot
.36335 .24976 Mdot
.3794 .36608 Mdot
.42386 .66992 Mdot
.44391 .74519 Mdot
.45059 .34198 Mdot
.47208 .67586 Mdot
.47436 .71381 Mdot
.49778 .59825 Mdot
.50874 .91643 Mdot
.51516 .76219 Mdot
.53655 .61374 Mdot
.56563 .75219 Mdot
.59189 .65665 Mdot
.59581 .61604 Mdot
.59923 .6556 Mdot
.60292 .68499 Mdot
.62656 .67779 Mdot
.63555 .72451 Mdot
.63919 .652 Mdot
.64169 .6004 Mdot
.64246 .58611 Mdot
.64496 .54267 Mdot
.64608 .77288 Mdot
.65077 .64308 Mdot
.66065 .57816 Mdot
.67474 .59169 Mdot
.69296 .563 Mdot
.72815 .65902 Mdot
.73169 .58879 Mdot
.74669 .61318 Mdot
.74821 .65474 Mdot
.75963 .63781 Mdot
.79673 .57809 Mdot
.80925 .55852 Mdot
.81525 .58444 Mdot
.83417 .62985 Mdot
.83598 .55526 Mdot
.91595 .49319 Mdot
1 0 0 r
.005 w
.16128 .17044 m
.18734 .17269 L
.21339 .17909 L
.2345 .18734 L
.23945 .19126 L
.2655 .20415 L
.27874 .21339 L
.29156 .22295 L
.31204 .23945 L
.31761 .24532 L
.33549 .2655 L
.34367 .28341 L
.34499 .29156 L
.34367 .29798 L
.31761 .3104 L
.29156 .30711 L
.2655 .30014 L
.24507 .29156 L
.23945 .28747 L
.21339 .27402 L
.20155 .2655 L
.18734 .25472 L
.16884 .23945 L
.16128 .2313 L
.14618 .21339 L
.13806 .18734 L
.16128 .17044 L
s
0 0 1 r
.65633 .57701 m
.68239 .56842 L
.70844 .56313 L
.7345 .56168 L
.76055 .5752 L
.76359 .57817 L
.76859 .60422 L
.76055 .62333 L
.75627 .63028 L
.7345 .65485 L
.73298 .65633 L
.70844 .6775 L
.69922 .68239 L
.68239 .69294 L
.65633 .70579 L
.64983 .70844 L
.63028 .71539 L
.60422 .72268 L
.57817 .72651 L
.55211 .7214 L
.53145 .70844 L
.52926 .68239 L
.54239 .65633 L
.55211 .63983 L
.56625 .63028 L
.57817 .6193 L
.60119 .60422 L
.60422 .60227 L
.63028 .58726 L
.65315 .57817 L
.65633 .57701 L
s
1 0 0 r
.03 w
.24141 .24033 Mdot
0 0 1 r
.64872 .64417 Mdot
1 0 0 r
.79703 .00495 m
.79703 .25248 L
.87129 .25248 L
.87129 .00495 L
F
0 0 1 r
.89604 .00495 m
.89604 .00495 L
.9703 .00495 L
.9703 .00495 L
F
1 0 1 r
.04 w
.21687 .20845 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P000182000`400?l00000o`00003ooooooolQ
ooooo`00ool0000Po`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`00
00?o0000ooooooooool0hOoooolEool002Gooooo0Ol00001ooooo`0000?o0000ooooooooool0hOoo
oolEool002Gooooo0Ol00001ooooo`0000?o0000ooooooooool0hOoooolEool002Gooooo0Ol00001
ooooo`0000?o0000ooooooooool0hOoooolEool002Gooooo0Ol00001ooooo`0000?o0000oooooooo
ool0hOoooolEool002Gooooo0Ol00001ooooo`0000?o0000ooooooooool0hOoooolEool002Gooooo
0Ol00001ooooo`0000?o0000ooooooooool0hOoooolEool002Gooooo0Ol00001ooooo`0000?o0000
ooooooooool0hOoooolEool002Gooooo0Ol00001ooooo`0000?o0000ooooooooool0hOoooolEool0
02Gooooo0Ol00001ooooo`0000?o0000ooooooooool0hOoooolEool002Gooooo0Ol00001ooooo`00
00?o0000ooooooooool0hOoooolEool002Gooooo0Ol00001ooooo`0000?o0000ooooooooool0hOoo
oolEool002Gooooo0Ol00001ooooo`0000?o0000ooooooooool0hOoooolEool002Gooooo0Ol00001
ooooo`0000?o0000ooooooooool0hOoooolEool002Gooooo0Ol00001ooooo`0000?o0000oooooooo
ool0hOoooolEool002Gooooo0Ol00001ooooo`0000?o0000ooooooooool0hOoooolEool002Gooooo
0Ol00001ooooo`0000?o0000ooooooooool0hOoooolEool002Gooooo0Ol00001ooooo`0000?o0000
ooooooooool0hOoooolEool002Gooooo0Ol00001ooooo`0000?o0000ooooooooool0hOoooolEool0
02Gooooo0Ol00001ooooo`0000?o0000ooooooooool0hOoooolEool002Gooooo0Ol00001ooooo`00
00?o0000ooooooooool0hOoooolEool002Gooooo0Ol00001ooooo`0000?o0000ooooooooool0hOoo
oolEool002Gooooo0Ol00001ooooo`0000?o0000ooooooooool0hOoooolEool002Gooooo0Ol00001
ooooo`0000?o0000ooooooooool0hOoooolEool002Gooooo0Ol00001ooooo`0000?o0000oooooooo
ool0hOoooolEool002Gooooo0Ol00001ooooo`0000?o0000ooooooooool0hOoooolEool002Gooooo
0Ol00001ooooo`0000?o0000ooooooooool0hOoooolEool002Gooooo0Ol00001ooooo`0000?o0000
ooooooooool0hOoooolEool002Gooooo0Ol00001ooooo`0000?o0000ooooooooool0hOoooolEool0
02Gooooo0Ol00001ooooo`0000?o0000ooooooooool0hOoooolEool002Gooooo0Ol00001ooooo`00
00?o0000ooooooooool0hOoooolEool002Gooooo0Ol00001ooooo`0000?o0000ooooooooool0hOoo
oolEool002Gooooo0Ol00001ooooo`0000?o0000ooooooooool01_ooool2oomo0=Wooooo5Ooo000U
ooooo`7o00000Oooool00003o`000?oooooooooo00Gooooo1?ooO`0Cooooo`;oogl0`ooooolEool0
02Gooooo0Ol00001ooooo`0000?o0000ooooooooool01Oooool4oomo01;ooooo1?ooO`0Booooo`;o
ogl0[_oooolEool002Gooooo0Ol00001ooooo`0000?o0000ooooooooool01Oooool3oomo01?ooooo
1?ooO`0Aooooo`Coogl0[OoooolEool002Gooooo0Ol00001ooooo`0000?o0000ooooooooool01?oo
ool4oomo01Cooooo0_ooO`0Booooo`Coogl0[OoooolEool002Gooooo0Ol00001ooooo`0000?o0000
ooooooooool01?ooool4oomo02Wooooo0_ooO`2^oooooaGoo`009Oooool1o`00007ooooo00000ol0
003oooooooooo`05ooooo`;oogl0f_oooolEool002Gooooo0Ol00001ooooo`0000?o0000oooooooo
ool0hOoooolEool002Gooooo0Ol00001ooooo`0000?o0000ooooooooool0hOoooolEool002Gooooo
0Ol00001ooooo`0000?o0000ooooooooool0hOoooolEool002Gooooo0Ol00001ooooo`0000?o0000
ooooooooool0hOoooolEool002Gooooo0Ol00001ooooo`0000?o0000ooooooooool0hOoooolEool0
02Gooooo0Ol00001ooooo`0000?o0000ooooooooool0hOoooolEool002Gooooo0Ol00001ooooo`00
00?o0000ooooooooool0hOoooolEool002Gooooo0Ol00001ooooo`0000?o0000ooooooooool0:_oo
ool6ool00;7ooooo5Ooo000Uooooo`7o00000Oooool00003o`000?oooooooooo02Wooooo00?oo`00
ooooooooool01?ooool5ool00:cooooo5Ooo000Uooooo`7o00000Oooool00003o`000?oooooooooo
02Oooooo0_oo000<ooooo`Coo`00Z?oooolEool002Gooooo0Ol00001ooooo`0000?o0000oooooooo
ool09_ooool00ooo003oooooooooo`0@ooooo`Coo`00Y?oooolEool002Gooooo0Ol00001ooooo`00
00?o0000ooooooooool09?ooool00oooO`3oo`00ooooo`09ooooo`;oogl02oooool3ool00:7ooooo
5Ooo000Uooooo`7o00000Oooool00003o`000?oooooooooo02?ooooo00Coogl0ool00?ooO`3oogl0
2?ooool4oomo00gooooo00?oo`00ooooooooool0W_oooolEool002Gooooo0Ol00001ooooo`0000?o
0000ooooooooool08oooool01?ooO`3oo`00oomo0?ooO`08ooooo`Coogl03_ooool2ool009kooooo
5Ooo000Uooooo`7o00000Oooool00003o`000?oooooooooo02Cooooo00?oogl0ool00?ooool02Ooo
ool2oomo00Oooooo1Ooo0?l5ooooo`;oo`00W?oooolEool002Gooooo0Ol00001ooooo`0000?o0000
ooooooooool09Oooool00ooo003oooooooooo`0@ooooo`Ooo`3o1_ooool2ool009[ooooo5Ooo000U
ooooo`7o00000Oooool00003o`000?oooooooooo02Gooooo00?oo`00ooooooooool03oooool9ool0
o`Oooooo0_oo002HoooooaGoo`009Oooool1o`00007ooooo00000ol0003oooooooooo`0Vooooo`03
ool00?oooooooooo00gooooo2ooo0?l8ooooo`;oo`001?ooool2oomo00Oooooo0_ooO`27oooooaGo
o`009Oooool1o`00007ooooo00000ol0003oooooooooo`0Vooooo`03ool00?oooooooooo00Gooooo
0_ooO`06ooooo`_oo`3o2_ooool00ooo003oooooooooo`04oomo00Gooooo1?ooO`26oooooaGoo`00
9Oooool1o`00007ooooo00000ol0003oooooooooo`0Vooooo`03ool00?oooooooooo00Cooooo1?oo
O`05ooooo`_oo`3o2oooool00ooo003ooooooomo0003oomo00Gooooo1?ooO`26oooooaGoo`009Ooo
ool1o`00007ooooo00000ol0003oooooooooo`0Wooooo`03ool00?oooooooooo00?ooooo1?ooO`05
ooooo`_oo`3o3?ooool01?oo003ooooooomo0?ooO`07ooooo`?oogl0Q_oooolEool002Gooooo0Ol0
0001ooooo`0000?o0000ooooooooool09oooool00ooo003oooooooooo`04ooooo`;oogl01_ooool;
ool0o`gooooo00?oo`00ooooooooool01oooool4oomo08Gooooo5Ooo000Uooooo`7o00000Oooool0
0003o`000?oooooooooo02Sooooo00?oo`00ooooooooool03?ooool9ool0o`oooooo00?oo`00oooo
ooooool01_ooool4oomo08Gooooo5Ooo000Uooooo`7o00000Oooool00003o`000?oooooooooo02Wo
oooo00?oo`00ooooooooool03?ooool7ool0oa7ooooo0_oo00000oooooooogl0oomo0004ooooo`;o
ogl0Q_oooolEool002Gooooo0Ol00001ooooo`0000?o0000ooooooooool0:_ooool00ooo003ooooo
ooooo`0<ooooo`Goo`3o0_ooool4ool000kooooo00Coo`00oomo0?ooO`3oogl0RooooolEool002Go
oooo0Ol00001ooooo`0000?o0000ooooooooool0:oooool00ooo003oooooooooo`0Aooooo`Koo`00
3Oooool01?ooO`3oo`00ool00?ooO`2;oooooaGoo`009Oooool1o`00007ooooo00000ol0003ooooo
ooooo`0/ooooo`03ool00?oooooooooo00Sooooo0_ooO`05ooooo`Soo`003Oooool2oomo0003ool0
0?oooooooooo08Wooooo5Ooo000Uooooo`7o00000Oooool00003o`000?oooooooooo02gooooo00?o
o`00ooooooooool01_ooool4oomo00Cooooo2?oo000@ooooo`03ool00?oooooooooo08Sooooo5Ooo
000Uooooo`7o00000Oooool00003o`000?oooooooooo02_ooooo0_ooO`000oooooooo`00ooooo`06
ooooo`Coogl01?ooool8ool0017ooooo00?oo`00ooooooooool0QooooolEool002Gooooo0Ol00001
ooooo`0000?o0000ooooooooool0:_ooool4oomo0003oooooooo003ooooo00Kooooo0_ooO`05oooo
o`Soo`002oooool2oomo00Gooooo00?oo`00ooooooooool02Oooool2oomo07_ooooo5Ooo000Uoooo
o`7o00000Oooool00003o`000?oooooooooo02[ooooo1?ooO`02ooooo`03ool00?oooooooooo00co
oooo1_oo000;ooooo`Coogl01?ooool00ooo003oooooooooo`08ooooo`Coogl0N_oooolEool002Go
oooo0Ol00001ooooo`0000?o0000ooooooooool0:oooool2oomo00Cooooo00?oo`00ooooooooool0
3?ooool4ool000cooooo1?ooO`05ooooo`03ool00?oooooooooo00Oooooo1?ooO`1joooooaGoo`00
9Oooool1o`00007ooooo00000ol0003oooooooooo`0booooo`;oo`007Oooool2oomo00Oooooo00?o
o`00ooooooooool01oooool2oomo0;Gooooo0Ol00001ooooo`0000?o0000ooooooooool0=?ooool0
0ooo003oooooooooo`0Tooooo`03ool00?oooooooooo0;gooooo0Ol00001ooooo`0000?o0000oooo
ooooool0=Oooool00ooo003oooooooooo`0Tooooo`03ool00?oooooooooo0;cooooo0Ol00001oooo
o`0000?o0000ooooooooool0=_ooool2ool002Gooooo00?oo`00ooooooooool0^oooool1o`00007o
oooo00000ol0003oooooooooo`0hooooo`;oo`0000?oogl0ooooooooool00_ooO`0Nooooo`03ool0
0?oooooooooo0;_ooooo0Ol00001ooooo`0000?o0000ooooooooool0>?ooool2oomo00;oo`001?oo
O`0Nooooo`03ool00?oooooooooo0;[ooooo0Ol00001ooooo`0000?o0000ooooooooool0>?ooool4
oomo00;oo`000_ooO`0Nooooo`03ool00?oooooooooo0;[ooooo0Ol00001ooooo`0000?o0000oooo
ooooool0>Oooool5oomo0003ool00?oooooooooo01gooooo00?oo`00oomo0?ooO`00^_ooool1o`00
007ooooo00000ol0003oooooooooo`0kooooo`Coogl00_oo000Mooooo`04oomo0?oo003oogl0oomo
0;Wooooo0Ol00001ooooo`0000?o0000ooooooooool0??ooool2oomo00?ooooo0_oo000Kooooo`04
oomo0?oo003oogl0oomo0;Wooooo0Ol00001ooooo`0000?o0000ooooooooool0@oooool2ool001[o
oooo00?oogl0ool00?ooool0^Oooool1o`00007ooooo00000ol0003oooooooooo`15ooooo`;oo`00
6Oooool00ooo003oooooooooo`2hooooo`7o00000Oooool00003o`000?oooooooooo04Oooooo0_oo
000Eooooo`;oo`00^oooool1o`00007ooooo00000ol0003oooooooooo`19ooooo`?oo`004?ooool2
ool00;gooooo0Ol00001ooooo`0000?o0000ooooooooool0<Oooool2oomo01Wooooo0ooo000<oooo
o`03ool00?oooooooooo0;gooooo0Ol00001ooooo`0000?o0000ooooooooool0<?ooool4oomo01_o
oooo1_oo0004ooooo`;oo`00`?ooool1o`00007ooooo00000ol0003oooooooooo`0`ooooo`Coogl0
8Oooool4ool00<;ooooo0Ol00001ooooo`0000?o0000ooooooooool0<Oooool2oomo0>Sooooo0Ol0
0001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo
0?oooooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`00
00?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?oo
ool1o`00007ooooo00000ol0003oooooooooo`1mooooo`;oogl0W?ooool1o`00007ooooo00000ol0
003oooooooooo`1looooo`Coogl0Voooool1o`00007ooooo00000ol0003oooooooooo`1Dooooo`;o
ogl09_ooool4oomo09_ooooo0Ol00001ooooo`0000?o0000ooooooooool0Doooool4oomo02Kooooo
0_ooO`2Looooo`7o00000Oooool00003o`000?oooooooooo05?ooooo1?ooO`34ooooo`7o00000Ooo
ool00003o`000?oooooooooo05Cooooo0_ooO`35ooooo`7o00000Oooool00003o`000?oooooooooo
0?oooooo7?ooool1o`00007ooooo00000ol0003oooooooooo`1Sooooo`;oogl01?ooool2oomo0;3o
oooo0Ol00001ooooo`0000?o0000ooooooooool0H_ooool4oomo00;ooooo1?ooO`2_ooooo`7o0000
0Oooool00003o`000?oooooooooo06;ooooo1?ooO`02ooooo`Coogl0[oooool1o`00007ooooo0000
0ol0003oooooooooo`1Sooooo`;oogl01?ooool2oomo0;3ooooo0Ol00001ooooo`0000?o0000oooo
ooooool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007o
oooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooo
oolLooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0
003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o
00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003ooooooooo
o`3ooooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool0
0003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooooaco
oooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oo
oooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001
ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo0?oo
oooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o
0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1
o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000oooooooo
ool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo
00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolL
ooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003o
ooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o0000
0Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3o
oooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003
o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo
0Ol00001ooooo`0000?o0000ooooooooool0ooooool4ooooo`;oogl05_ooool1o`00007ooooo0000
0ol0003oooooooooo`3oooooo`?ooooo1?ooO`0Eooooo`7o00000Oooool00003o`000?oooooooooo
0?oooooo0oooool4oomo01Gooooo0Ol00001ooooo`0000?o0000ooooooooool0ooooool4ooooo`;o
ogl05_ooool1o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o
0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1
o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000oooooooo
ool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo
00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolL
ooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003o
ooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0]Oooool2oomo06Cooooo
0Ol00001ooooo`0000?o0000ooooooooool0]?ooool4oomo06?ooooo0Ol00001ooooo`0000?o0000
ooooooooool0]?ooool4oomo06?ooooo0Ol00001ooooo`0000?o0000ooooooooool0]Oooool2oomo
03Gooooo0_ooO`0]ooooo`7o00000Oooool00003o`000?oooooooooo0>Cooooo0_ooO`05ooooo`Co
ogl0;?ooool1o`00007ooooo00000ol0003oooooooooo`3Sooooo`Coogl01?ooool4oomo02cooooo
0Ol00001ooooo`0000?o0000ooooooooool0`oooool2oomo01kooooo1?ooO`05ooooo`;oogl0;Ooo
ool1o`00007ooooo00000ol0003oooooooooo`32ooooo`Coogl02ol00?lCooooo`;oogl0=Oooool1
o`00007ooooo00000ol0003oooooooooo`32ooooo`Co003o2oooool2o`00odSooooo0Ol00001oooo
o`0000?o0000ooooooooool0__ooool4o`00o`03ooooooooO`3oogl000kooooo0_l00?m6ooooo`7o
00000Oooool00003o`000?oooooooooo0;Wooooo0_ooO`03o`00oaOooooo0_l00?l9ooooo`;oogl0
>Oooool1o`00007ooooo00000ol0003oooooooooo`2gooooo`Co003o00?oogl0ooooooooool06Ooo
ool2o`00o`Kooooo1?ooO`0hooooo`7o00000Oooool00003o`000?oooooooooo0;Cooooo0ol00?l0
0oooooooogl0oomo0002oomo01cooooo00?o003oooooooooool01?ooool4oomo00?ooooo0_ooO`0c
ooooo`7o00000Oooool00003o`000?oooooooooo0;;ooooo0_l00?l3oomo00;ooooo0_ooO`0Coooo
o`;oogl02?ooool00ol00?ooooooooooo`05ooooo`;oogl00oooool4oomo03;ooooo0Ol00001oooo
o`0000?o0000ooooooooool0/?ooool2o`00o`03ooooooooO`3oogl000;oogl01_ooool2oomo00ko
oooo1?ooO`07ooooo`03o`00oooooooooooo00[ooooo1?ooO`0booooo`7o00000Oooool00003o`00
0?oooooooooo0:kooooo0_l00?l4ooooo`;oogl01_ooool4oomo00gooooo1?ooO`07ooooo`03o`00
oooooooooooo00_ooooo0_ooO`0cooooo`7o00000Oooool00003o`000?oooooooooo08_ooooo0_oo
O`0Pooooo`03o`00oooooooooooo00Cooooo0_ooO`06ooooo`Coogl03_ooool2oomo00Wooooo00?o
003oooooooooool0?oooool1o`00007ooooo00000ol0003oooooooooo`2:ooooo`Coogl07Oooool2
o`00o`Kooooo1?ooO`06ooooo`;oogl06_ooool00ol00?ooooooooooo`0oooooo`7o00000Oooool0
0003o`000?oooooooooo08[ooooo1?ooO`0Looooo`03o`00oooooooooooo00Kooooo1?ooO`0Roooo
o`03o`00oooooooooooo03oooooo0Ol00001ooooo`0000?o0000ooooooooool0Roooool2oomo01_o
oooo0_l00?l:ooooo`;oogl08oooool00ol00?ooooooooooo`0oooooo`7o00000Oooool00003o`00
0?oooooooooo09Kooooo0_ooO`0>ooooo`;o003o:_ooool2oomo00Gooooo00?o003oooooooooool0
?oooool1o`00007ooooo00000ol0003oooooooooo`2Eooooo`Coogl03?ooool01?l00?oooooooomo
0?ooO`0Xooooo`Coogl00oooool00ol00?ooooooooooo`10ooooo`7o00000Oooool00003o`000?oo
oooooooo09Gooooo1?ooO`0:ooooo`;o003o00?ooooooomo0?ooO`000_ooO`0Wooooo`Coogl00ooo
ool00ol00?ooooooooooo`10ooooo`7o00000Oooool00003o`000?oooooooooo09Kooooo0_ooO`0:
ooooo`04o`00ooooooooooooooooo`Coogl0:?ooool2oomo00Cooooo00?o003oooooooooool0@?oo
ool1o`00007ooooo00000ol0003oooooooooo`2Qooooo`03o`00oooooooooooo00?ooooo0_ooO`0^
ooooo`03o`00oooooooooooo047ooooo0Ol00001ooooo`0000?o0000ooooooooool0X?ooool00ol0
0?ooooooooooo`0cooooo`03o`00oooooooooooo01;ooooo0_ooO`0^ooooo`7o00000Oooool00003
o`000?oooooooooo09kooooo0_l00?leooooo`03o`00oooooooooooo01;ooooo1?ooO`0]ooooo`7o
00000Oooool00003o`000?oooooooooo09gooooo00?o003oooooooooool05Oooool4o`00oacooooo
00?o003ooomo0?ooO`004_ooool4oomo02gooooo0Ol00001ooooo`0000?o0000ooooooooool0W?oo
ool00ol00?ooooooooooo`0Eooooo`Ko003o6_ooool00ol00?ooogl0oomo0002oomo01;ooooo0_oo
O`0^ooooo`7o00000Oooool00003o`000?oooooooooo09_ooooo00?o003oooooooooool05Oooool8
o`00oaSooooo00?o003oooooooooO`000oooO`12ooooo`7o00000Oooool00003o`000?oooooooooo
09_ooooo00?o003oooooooooool05Oooool8o`00oaOooooo00Co003ooooooooooooooooo0_ooO`13
ooooo`7o00000Oooool00003o`000?oooooooooo09[ooooo00?o003oooooooooool05_ooool8o`00
oaKooooo00?o003oooooooooool0Aoooool1o`00007ooooo00000ol0003oooooooooo`2Iooooo`03
o`00oooooooooooo00cooooo0_ooO`08ooooo`03oomo0?l00?oo003o00Ko003o5Oooool00ol00?oo
ooooooooo`02oomo04Kooooo0Ol00001ooooo`0000?o0000ooooooooool0VOooool00ol00?oooooo
ooooo`0:ooooo`Googl01oooool2oomo00Ko003o4oooool2oomo0003o`00oooooooooooo00Coogl0
AOooool1o`00007ooooo00000ol0003oooooooooo`2Hooooo`03o`00oooooooooooo00[ooooo1_oo
O`08ooooo`;oogl01?l00?lCooooo`;oogl00_l00?l2ooooo`Coogl0AOooool1o`00007ooooo0000
0ol0003oooooooooo`2Hooooo`03o`00oooooooooooo00[ooooo1OooO`0Rooooo`04oomo0?l00?oo
ogl0oomo00?ooooo0_ooO`16ooooo`7o00000Oooool00003o`000?oooooooooo07Kooooo0_ooO`0O
ooooo`03o`00oooooooooooo00cooooo0_ooO`0Tooooo`03o`00ooooO`3oogl004cooooo0Ol00001
ooooo`0000?o0000ooooooooool0MOooool4oomo01kooooo00?o003oooooooooool0<Oooool00ol0
0?ooooooooooo`1=ooooo`7o00000Oooool00003o`000?oooooooooo07Gooooo1?ooO`0:ooooo`;o
ogl04Oooool00ol00?ooooooooooo`0aooooo`03o`00oooooooooooo04kooooo0Ol00001ooooo`00
00?o0000ooooooooool0M_ooool2oomo00[ooooo1?ooO`0?ooooo`03o`00oooooooooooo01Sooooo
0_ooO`0Gooooo`03o`00oooooooooooo04oooooo0Ol00001ooooo`0000?o0000ooooooooool0P_oo
ool4oomo00oooooo00?o003oooooooooool05oooool4oomo01Cooooo0_l00?mBooooo`7o00000Ooo
ool00003o`000?oooooooooo08?ooooo0_ooO`0?ooooo`03o`00oooooooooooo01;ooooo0_ooO`04
ooooo`Coogl04Oooool3o`00oeCooooo0Ol00001ooooo`0000?o0000ooooooooool0U?ooool00ol0
0?ooooooooooo`0Aooooo`Coogl01?ooool2oomo013ooooo0_l00?mGooooo`7o00000Oooool00003
o`000?oooooooooo09Cooooo00?o003oooooooooool04Oooool4oomo01Gooooo00?o003ooooooooo
ool0Eoooool1o`00007ooooo00000ol0003oooooooooo`2Dooooo`03o`00oooooooooooo01;ooooo
0_ooO`0Dooooo`;o003oF_ooool1o`00007ooooo00000ol0003oooooooooo`2Dooooo`03o`00oooo
oooooooo02Kooooo0_l00?mLooooo`7o00000Oooool00003o`000?oooooooooo09Gooooo00?o003o
ooooooooool09?ooool00ol00?ooooooooooo`1Looooo`7o00000Oooool00003o`000?oooooooooo
09Gooooo00?o003oooooooooool08_ooool2o`00oeoooooo0Ol00001ooooo`0000?o0000oooooooo
ool0UOooool00ol00?ooooooooooo`0Pooooo`;o003oHOooool1o`00007ooooo00000ol0003ooooo
ooooo`24ooooo`;oogl03oooool2o`00oaoooooo0_l00?mSooooo`7o00000Oooool00003o`000?oo
oooooooo08?ooooo1?ooO`0@ooooo`;o003o6_ooool3o`00ofGooooo0Ol00001ooooo`0000?o0000
ooooooooool0Poooool4oomo01;ooooo0_l00?lDooooo`Co003oJ?ooool1o`00007ooooo00000ol0
003oooooooooo`24ooooo`;oogl05Oooool3o`00o`kooooo0ol00?l3ooooo`;oogl0Ioooool1o`00
007ooooo00000ol0003oooooooooo`2Nooooo`?o003o1Oooool6o`00o`Gooooo1?ooO`1Vooooo`7o
00000Oooool00003o`000?oooooooooo0:7ooooo1Ol00?l;ooooo`Coogl0I_ooool1o`00007ooooo
00000ol0003oooooooooo`2booooo`;oogl0Ioooool1o`00007ooooo00000ol0003oooooooooo`3o
oooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003
o`000?oooooooooo07_ooooo0_ooO`2Nooooo`7o00000Oooool00003o`000?oooooooooo07[ooooo
1?ooO`2Mooooo`7o00000Oooool00003o`000?oooooooooo07[ooooo1?ooO`0Pooooo`;oogl0Nooo
ool1o`00007ooooo00000ol0003oooooooooo`1kooooo`;oogl08?ooool4oomo07[ooooo0Ol00001
ooooo`0000?o0000ooooooooool0WOooool4oomo07[ooooo0Ol00001ooooo`0000?o0000oooooooo
ool0T?ooool2oomo00cooooo0_ooO`1kooooo`7o00000Oooool00003o`000?oooooooooo08oooooo
1?ooO`28ooooo`7o00000Oooool00003o`000?oooooooooo08oooooo1?ooO`28ooooo`7o00000Ooo
ool00003o`000?oooooooooo093ooooo0_ooO`0Sooooo`;oogl0I?ooool1o`00007ooooo00000ol0
003oooooooooo`2dooooo`Coogl0Hoooool1o`00007ooooo00000ol0003oooooooooo`2dooooo`Co
ogl0Hoooool1o`00007ooooo00000ol0003oooooooooo`2eooooo`;oogl0I?ooool1o`00007ooooo
00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolL
ooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003o
ooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o0000
0Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3o
oooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003
o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo
0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oooooo
oooo0?oooooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001oooo
o`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo
7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000
ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00
007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0
oooooolLooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo0000
0ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLoooo
o`7o00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003ooooo
ooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Ooo
ool00003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooo
oacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`00
0?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol0
0001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo
0?oooooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`00
00?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?oo
ool1o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000oooo
ooooool0S_ooool2oomo08_ooooo0Ol00001ooooo`0000?o0000ooooooooool0SOooool4oomo08[o
oooo0Ol00001ooooo`0000?o0000ooooooooool0SOooool4oomo08[ooooo0Ol00001ooooo`0000?o
0000ooooooooool0S_ooool2oomo08_ooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolL
ooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003o
ooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o0000
0Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3o
oooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003
o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo
0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oooooo
oooo0?oooooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001oooo
o`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo
7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000
ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00
007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0
oooooolLooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo0000
0ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`00ool0000Po`00007ooooo0000\
\>"],
  ImageRangeCache->{{{0, 287}, {287, 0}} -> {-1.01089, -1.01089, 0.00704453, \
0.00704453}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.49505 0.5 0.49505 [
[ 0 0 -0.125 0 ]
[ 0 0 -0.125 0 ]
[ 0 1 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
0 0 m
1 0 L
s
0 0 m
0 1 L
s
0 1 m
1 1 L
s
1 0 m
1 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
1 .5 0 r
.015 w
.03175 .1355 Mdot
.03435 .12523 Mdot
.11137 .12765 Mdot
.14107 .18841 Mdot
.16218 .24538 Mdot
.17294 .21053 Mdot
.18267 .18577 Mdot
.18434 .1304 Mdot
.18553 .30956 Mdot
.20401 .239 Mdot
.21247 .27571 Mdot
.21687 .20845 Mdot
.22376 .2799 Mdot
.22832 .27485 Mdot
.29063 .20974 Mdot
.29686 .25079 Mdot
.30487 .22936 Mdot
.30683 .34623 Mdot
.32055 .20902 Mdot
.32574 .21979 Mdot
.34472 .28521 Mdot
.35998 .36393 Mdot
.36335 .24976 Mdot
.3794 .36608 Mdot
.42386 .66992 Mdot
.44391 .74519 Mdot
.45059 .34198 Mdot
.47208 .67586 Mdot
.47436 .71381 Mdot
.49778 .59825 Mdot
.50874 .91643 Mdot
.51516 .76219 Mdot
.53655 .61374 Mdot
.56563 .75219 Mdot
.59189 .65665 Mdot
.59581 .61604 Mdot
.59923 .6556 Mdot
.60292 .68499 Mdot
.62656 .67779 Mdot
.63555 .72451 Mdot
.63919 .652 Mdot
.64169 .6004 Mdot
.64246 .58611 Mdot
.64496 .54267 Mdot
.64608 .77288 Mdot
.65077 .64308 Mdot
.66065 .57816 Mdot
.67474 .59169 Mdot
.69296 .563 Mdot
.72815 .65902 Mdot
.73169 .58879 Mdot
.74669 .61318 Mdot
.74821 .65474 Mdot
.75963 .63781 Mdot
.79673 .57809 Mdot
.80925 .55852 Mdot
.81525 .58444 Mdot
.83417 .62985 Mdot
.83598 .55526 Mdot
.91595 .49319 Mdot
1 0 0 r
.005 w
.16128 .17044 m
.18734 .17269 L
.21339 .17909 L
.2345 .18734 L
.23945 .19126 L
.2655 .20415 L
.27874 .21339 L
.29156 .22295 L
.31204 .23945 L
.31761 .24532 L
.33549 .2655 L
.34367 .28341 L
.34499 .29156 L
.34367 .29798 L
.31761 .3104 L
.29156 .30711 L
.2655 .30014 L
.24507 .29156 L
.23945 .28747 L
.21339 .27402 L
.20155 .2655 L
.18734 .25472 L
.16884 .23945 L
.16128 .2313 L
.14618 .21339 L
.13806 .18734 L
.16128 .17044 L
s
0 0 1 r
.65633 .57701 m
.68239 .56842 L
.70844 .56313 L
.7345 .56168 L
.76055 .5752 L
.76359 .57817 L
.76859 .60422 L
.76055 .62333 L
.75627 .63028 L
.7345 .65485 L
.73298 .65633 L
.70844 .6775 L
.69922 .68239 L
.68239 .69294 L
.65633 .70579 L
.64983 .70844 L
.63028 .71539 L
.60422 .72268 L
.57817 .72651 L
.55211 .7214 L
.53145 .70844 L
.52926 .68239 L
.54239 .65633 L
.55211 .63983 L
.56625 .63028 L
.57817 .6193 L
.60119 .60422 L
.60422 .60227 L
.63028 .58726 L
.65315 .57817 L
.65633 .57701 L
s
1 0 0 r
.03 w
.24141 .24033 Mdot
0 0 1 r
.64872 .64417 Mdot
1 0 0 r
.79703 .00495 m
.79703 .25248 L
.87129 .25248 L
.87129 .00495 L
F
0 0 1 r
.89604 .00495 m
.89604 .00495 L
.9703 .00495 L
.9703 .00495 L
F
1 0 1 r
.04 w
.22376 .2799 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P000182000`400?l00000o`00003ooooooolQ
ooooo`00ool0000Po`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`00
00?o0000ooooooooool0hOoooolEool002Gooooo0Ol00001ooooo`0000?o0000ooooooooool0hOoo
oolEool002Gooooo0Ol00001ooooo`0000?o0000ooooooooool0hOoooolEool002Gooooo0Ol00001
ooooo`0000?o0000ooooooooool0hOoooolEool002Gooooo0Ol00001ooooo`0000?o0000oooooooo
ool0hOoooolEool002Gooooo0Ol00001ooooo`0000?o0000ooooooooool0hOoooolEool002Gooooo
0Ol00001ooooo`0000?o0000ooooooooool0hOoooolEool002Gooooo0Ol00001ooooo`0000?o0000
ooooooooool0hOoooolEool002Gooooo0Ol00001ooooo`0000?o0000ooooooooool0hOoooolEool0
02Gooooo0Ol00001ooooo`0000?o0000ooooooooool0hOoooolEool002Gooooo0Ol00001ooooo`00
00?o0000ooooooooool0hOoooolEool002Gooooo0Ol00001ooooo`0000?o0000ooooooooool0hOoo
oolEool002Gooooo0Ol00001ooooo`0000?o0000ooooooooool0hOoooolEool002Gooooo0Ol00001
ooooo`0000?o0000ooooooooool0hOoooolEool002Gooooo0Ol00001ooooo`0000?o0000oooooooo
ool0hOoooolEool002Gooooo0Ol00001ooooo`0000?o0000ooooooooool0hOoooolEool002Gooooo
0Ol00001ooooo`0000?o0000ooooooooool0hOoooolEool002Gooooo0Ol00001ooooo`0000?o0000
ooooooooool0hOoooolEool002Gooooo0Ol00001ooooo`0000?o0000ooooooooool0hOoooolEool0
02Gooooo0Ol00001ooooo`0000?o0000ooooooooool0hOoooolEool002Gooooo0Ol00001ooooo`00
00?o0000ooooooooool0hOoooolEool002Gooooo0Ol00001ooooo`0000?o0000ooooooooool0hOoo
oolEool002Gooooo0Ol00001ooooo`0000?o0000ooooooooool0hOoooolEool002Gooooo0Ol00001
ooooo`0000?o0000ooooooooool0hOoooolEool002Gooooo0Ol00001ooooo`0000?o0000oooooooo
ool0hOoooolEool002Gooooo0Ol00001ooooo`0000?o0000ooooooooool0hOoooolEool002Gooooo
0Ol00001ooooo`0000?o0000ooooooooool0hOoooolEool002Gooooo0Ol00001ooooo`0000?o0000
ooooooooool0hOoooolEool002Gooooo0Ol00001ooooo`0000?o0000ooooooooool0hOoooolEool0
02Gooooo0Ol00001ooooo`0000?o0000ooooooooool0hOoooolEool002Gooooo0Ol00001ooooo`00
00?o0000ooooooooool0hOoooolEool002Gooooo0Ol00001ooooo`0000?o0000ooooooooool0hOoo
oolEool002Gooooo0Ol00001ooooo`0000?o0000ooooooooool01_ooool2oomo0=Wooooo5Ooo000U
ooooo`7o00000Oooool00003o`000?oooooooooo00Gooooo1?ooO`0Cooooo`;oogl0`ooooolEool0
02Gooooo0Ol00001ooooo`0000?o0000ooooooooool01Oooool4oomo01;ooooo1?ooO`0Booooo`;o
ogl0[_oooolEool002Gooooo0Ol00001ooooo`0000?o0000ooooooooool01Oooool3oomo01?ooooo
1?ooO`0Aooooo`Coogl0[OoooolEool002Gooooo0Ol00001ooooo`0000?o0000ooooooooool01?oo
ool4oomo01Cooooo0_ooO`0Booooo`Coogl0[OoooolEool002Gooooo0Ol00001ooooo`0000?o0000
ooooooooool01?ooool4oomo02Wooooo0_ooO`2^oooooaGoo`009Oooool1o`00007ooooo00000ol0
003oooooooooo`05ooooo`;oogl0f_oooolEool002Gooooo0Ol00001ooooo`0000?o0000oooooooo
ool0hOoooolEool002Gooooo0Ol00001ooooo`0000?o0000ooooooooool0hOoooolEool002Gooooo
0Ol00001ooooo`0000?o0000ooooooooool0hOoooolEool002Gooooo0Ol00001ooooo`0000?o0000
ooooooooool0hOoooolEool002Gooooo0Ol00001ooooo`0000?o0000ooooooooool0hOoooolEool0
02Gooooo0Ol00001ooooo`0000?o0000ooooooooool0hOoooolEool002Gooooo0Ol00001ooooo`00
00?o0000ooooooooool0hOoooolEool002Gooooo0Ol00001ooooo`0000?o0000ooooooooool0:_oo
ool6ool00;7ooooo5Ooo000Uooooo`7o00000Oooool00003o`000?oooooooooo02Wooooo00?oo`00
ooooooooool01?ooool5ool00:cooooo5Ooo000Uooooo`7o00000Oooool00003o`000?oooooooooo
02Oooooo0_oo000<ooooo`Coo`00Z?oooolEool002Gooooo0Ol00001ooooo`0000?o0000oooooooo
ool09_ooool00ooo003oooooooooo`0@ooooo`Coo`00Y?oooolEool002Gooooo0Ol00001ooooo`00
00?o0000ooooooooool09?ooool00oooO`3oo`00ooooo`09ooooo`;oogl02oooool3ool00:7ooooo
5Ooo000Uooooo`7o00000Oooool00003o`000?oooooooooo02?ooooo00Coogl0ool00?ooO`3oogl0
2?ooool4oomo00gooooo00?oo`00ooooooooool0W_oooolEool002Gooooo0Ol00001ooooo`0000?o
0000ooooooooool08oooool01?ooO`3oo`00oomo0?ooO`08ooooo`Coogl03_ooool2ool009kooooo
5Ooo000Uooooo`7o00000Oooool00003o`000?oooooooooo02Cooooo00?oogl0ool00?ooool02Ooo
ool2oomo017ooooo0_oo002LoooooaGoo`009Oooool1o`00007ooooo00000ol0003oooooooooo`0U
ooooo`03ool00?oooooooooo01gooooo0_oo002JoooooaGoo`009Oooool1o`00007ooooo00000ol0
003oooooooooo`0Uooooo`03ool00?oooooooooo01oooooo0_oo002HoooooaGoo`009Oooool1o`00
007ooooo00000ol0003oooooooooo`0Vooooo`03ool00?oooooooooo017ooooo0_ooO`0=ooooo`;o
o`001?ooool2oomo00Oooooo0_ooO`27oooooaGoo`009Oooool1o`00007ooooo00000ol0003ooooo
ooooo`0Vooooo`03ool00?oooooooooo00Gooooo0_ooO`09ooooo`Coogl03_ooool00ooo003ooooo
ooooo`04oomo00Gooooo1?ooO`26oooooaGoo`009Oooool1o`00007ooooo00000ol0003ooooooooo
o`0Vooooo`03ool00?oooooooooo00Cooooo1?ooO`08ooooo`Coogl03oooool00ooo003ooooooomo
0003oomo00Gooooo1?ooO`26oooooaGoo`009Oooool1o`00007ooooo00000ol0003oooooooooo`0W
ooooo`03ool00?oooooooooo00?ooooo1?ooO`09ooooo`;oogl04Oooool01?oo003ooooooomo0?oo
O`07ooooo`?oogl0Q_oooolEool002Gooooo0Ol00001ooooo`0000?o0000ooooooooool09oooool0
0ooo003oooooooooo`04ooooo`;oogl07_ooool00ooo003oooooooooo`07ooooo`Coogl0QOoooolE
ool002Gooooo0Ol00001ooooo`0000?o0000ooooooooool0:?ooool00ooo003oooooooooo`0Toooo
o`03ool00?oooooooooo00Kooooo1?ooO`25oooooaGoo`009Oooool1o`00007ooooo00000ol0003o
ooooooooo`0Yooooo`03ool00?oooooooooo02Cooooo0_oo00000oooooooogl0oomo0004ooooo`;o
ogl0Q_oooolEool002Gooooo0Ol00001ooooo`0000?o0000ooooooooool0:_ooool00ooo003ooooo
ooooo`0Cooooo`Coo`003_ooool01?oo003oogl0oomo0?ooO`2;oooooaGoo`009Oooool1o`00007o
oooo00000ol0003oooooooooo`0[ooooo`03ool00?oooooooooo017ooooo1_oo000=ooooo`04oomo
0?oo003oo`00oomo08_ooooo5Ooo000Uooooo`7o00000Oooool00003o`000?oooooooooo02cooooo
00?oo`00ooooooooool02?ooool2oomo00Gooooo2?oo000=ooooo`;oogl000?oo`00ooooooooool0
ROoooolEool002Gooooo0Ol00001ooooo`0000?o0000ooooooooool0;Oooool00ooo003ooooooooo
o`06ooooo`Coogl01?ooool8ool0013ooooo00?oo`00ooooooooool0R?oooolEool002Gooooo0Ol0
0001ooooo`0000?o0000ooooooooool0:oooool2oomo0003oooooooo003ooooo00Kooooo1?ooO`04
ooooo`Soo`004Oooool00ooo003oooooooooo`27oooooaGoo`009Oooool1o`00007ooooo00000ol0
003oooooooooo`0Zooooo`Coogl000?oooooool00?ooool01_ooool2oomo00Gooooo2?oo000;oooo
o`;oogl01Oooool00ooo003oooooooooo`09ooooo`;oogl0NooooolEool002Gooooo0Ol00001oooo
o`0000?o0000ooooooooool0:_ooool4oomo00;ooooo00?oo`00ooooooooool03?ooool6ool000_o
oooo1?ooO`04ooooo`03ool00?oooooooooo00Sooooo1?ooO`1joooooaGoo`009Oooool1o`00007o
oooo00000ol0003oooooooooo`0[ooooo`;oogl01?ooool00ooo003oooooooooo`0<ooooo`Coo`00
3?ooool4oomo00Gooooo00?oo`00ooooooooool01oooool4oomo07[ooooo5Ooo000Uooooo`7o0000
0Oooool00003o`000?oooooooooo03;ooooo0_oo000Mooooo`;oogl01oooool00ooo003ooooooooo
o`07ooooo`;oogl0]Oooool1o`00007ooooo00000ol0003oooooooooo`0dooooo`03ool00?oooooo
oooo02Cooooo00?oo`00ooooooooool0_Oooool1o`00007ooooo00000ol0003oooooooooo`0eoooo
o`03ool00?oooooooooo00?ooooo1Ooo0?lLooooo`03ool00?oooooooooo0;cooooo0Ol00001oooo
o`0000?o0000ooooooooool0=_ooool2ool000;ooooo1ooo0?lLooooo`03ool00?oooooooooo0;_o
oooo0Ol00001ooooo`0000?o0000ooooooooool0>?ooool00ooo003oo`3oool0o`07ool0oa_ooooo
00?oo`00ooooooooool0^oooool1o`00007ooooo00000ol0003oooooooooo`0hooooo`_oo`3o6ooo
ool00ooo003oooooooooo`2jooooo`7o00000Oooool00003o`000?oooooooooo03Sooooo2ooo0?lK
ooooo`03ool00?oooooooooo0;[ooooo0Ol00001ooooo`0000?o0000ooooooooool0>?ooool;ool0
oa_ooooo00?oo`00oomo0?ooO`00^_ooool1o`00007ooooo00000ol0003oooooooooo`0hooooo`_o
o`3o6oooool01?ooO`3oo`00oomo0?ooO`2iooooo`7o00000Oooool00003o`000?oooooooooo03So
oooo2ooo0?lKooooo`04oomo0?oo003oogl0oomo0;Wooooo0Ol00001ooooo`0000?o0000oooooooo
ool0>Oooool9ool0o`03oooooooo003oo`0001[ooooo00?oogl0ool00?ooool0^Oooool1o`00007o
oooo00000ol0003oooooooooo`0jooooo`Ooo`3o1?ooool2ool001Wooooo00?oo`00ooooooooool0
^?ooool1o`00007ooooo00000ol0003oooooooooo`0kooooo`Goo`3o1oooool2ool001Gooooo0_oo
002kooooo`7o00000Oooool00003o`000?oooooooooo04Wooooo0ooo000@ooooo`;oo`00_Oooool1
o`00007ooooo00000ol0003oooooooooo`0aooooo`;oogl06Oooool3ool000cooooo00?oo`00oooo
ooooool0_Oooool1o`00007ooooo00000ol0003oooooooooo`0`ooooo`Coogl06oooool6ool000Co
oooo0_oo0030ooooo`7o00000Oooool00003o`000?oooooooooo033ooooo1?ooO`0Qooooo`Coo`00
`_ooool1o`00007ooooo00000ol0003oooooooooo`0aooooo`;oogl0j?ooool1o`00007ooooo0000
0ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLoooo
o`7o00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003ooooo
ooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Ooo
ool00003o`000?oooooooooo07gooooo0_ooO`2Looooo`7o00000Oooool00003o`000?oooooooooo
07cooooo1?ooO`2Kooooo`7o00000Oooool00003o`000?oooooooooo05Cooooo0_ooO`0Vooooo`Co
ogl0Voooool1o`00007ooooo00000ol0003oooooooooo`1Cooooo`Coogl09_ooool2oomo09cooooo
0Ol00001ooooo`0000?o0000ooooooooool0Doooool4oomo0<Cooooo0Ol00001ooooo`0000?o0000
ooooooooool0E?ooool2oomo0<Gooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLoooo
o`7o00000Oooool00003o`000?oooooooooo06?ooooo0_ooO`04ooooo`;oogl0/?ooool1o`00007o
oooo00000ol0003oooooooooo`1Rooooo`Coogl00_ooool4oomo0:oooooo0Ol00001ooooo`0000?o
0000ooooooooool0H_ooool4oomo00;ooooo1?ooO`2_ooooo`7o00000Oooool00003o`000?oooooo
oooo06?ooooo0_ooO`04ooooo`;oogl0/?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooo
oacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`00
0?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol0
0001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo
0?oooooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`00
00?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?oo
ool1o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000oooo
ooooool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007o
oooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooo
oolLooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0
003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o
00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003ooooooooo
o`3ooooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool0
0003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooooaco
oooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oo
oooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001
ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo0?oo
oooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o
0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1
o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000oooooooo
ool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo
00000ol0003oooooooooo`3oooooo`Cooooo0_ooO`0Fooooo`7o00000Oooool00003o`000?oooooo
oooo0?oooooo0oooool4oomo01Gooooo0Ol00001ooooo`0000?o0000ooooooooool0ooooool3oooo
o`Coogl05Oooool1o`00007ooooo00000ol0003oooooooooo`3oooooo`Cooooo0_ooO`0Fooooo`7o
00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003ooooooooo
o`3ooooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool0
0003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooooaco
oooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oo
oooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001
ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo0?oo
oooo7?ooool1o`00007ooooo00000ol0003oooooooooo`2eooooo`;oogl0I?ooool1o`00007ooooo
00000ol0003oooooooooo`2dooooo`Coogl0Hoooool1o`00007ooooo00000ol0003oooooooooo`2d
ooooo`Coogl0Hoooool1o`00007ooooo00000ol0003oooooooooo`2eooooo`;oogl0=Oooool2oomo
02gooooo0Ol00001ooooo`0000?o0000ooooooooool0i?ooool2oomo00Gooooo1?ooO`0/ooooo`7o
00000Oooool00003o`000?oooooooooo0>?ooooo1?ooO`04ooooo`Coogl0;?ooool1o`00007ooooo
00000ol0003oooooooooo`33ooooo`;oogl07_ooool4oomo00Gooooo0_ooO`0]ooooo`7o00000Ooo
ool00003o`000?oooooooooo0<;ooooo1?ooO`0;o`00oa?ooooo0_ooO`0eooooo`7o00000Oooool0
0003o`000?oooooooooo0<;ooooo1?l00?l;ooooo`;o003oB?ooool1o`00007ooooo00000ol0003o
ooooooooo`2nooooo`Co003o00?ooooooomo0?ooO`003_ooool2o`00odKooooo0Ol00001ooooo`00
00?o0000ooooooooool0^Oooool2oomo00?o003o5oooool2o`00o`Wooooo0_ooO`0iooooo`7o0000
0Oooool00003o`000?oooooooooo0;Oooooo1?l00?l00oooO`3oooooooooo`0Iooooo`;o003o1_oo
ool4oomo03Sooooo0Ol00001ooooo`0000?o0000ooooooooool0]?ooool3o`00o`03ooooooooO`3o
ogl000;oogl07?ooool00ol00?ooooooooooo`04ooooo`Coogl00oooool2oomo03?ooooo0Ol00001
ooooo`0000?o0000ooooooooool0/_ooool2o`00o`?oogl00_ooool2oomo01?ooooo0_ooO`08oooo
o`03o`00oooooooooooo00Gooooo0_ooO`03ooooo`Coogl0<_ooool1o`00007ooooo00000ol0003o
ooooooooo`2`ooooo`;o003o00?ooooooomo0?ooO`000_ooO`06ooooo`;oogl03_ooool4oomo00Oo
oooo00?o003oooooooooool02_ooool4oomo03;ooooo0Ol00001ooooo`0000?o0000ooooooooool0
[_ooool2o`00o`Cooooo0_ooO`06ooooo`Coogl03Oooool4oomo00Oooooo00?o003oooooooooool0
2oooool2oomo03?ooooo0Ol00001ooooo`0000?o0000ooooooooool0Roooool2oomo023ooooo00?o
003oooooooooool01?ooool2oomo00Kooooo1?ooO`0>ooooo`;oogl02Oooool00ol00?oooooooooo
o`0oooooo`7o00000Oooool00003o`000?oooooooooo08[ooooo1?ooO`0Mooooo`;o003o1_ooool4
oomo00Kooooo0_ooO`0Jooooo`03o`00oooooooooooo03oooooo0Ol00001ooooo`0000?o0000oooo
ooooool0R_ooool4oomo01cooooo00?o003oooooooooool01_ooool4oomo02;ooooo00?o003ooooo
ooooool0?oooool1o`00007ooooo00000ol0003oooooooooo`2;ooooo`;oogl06oooool2o`00o`[o
oooo0_ooO`0Sooooo`03o`00oooooooooooo03oooooo0Ol00001ooooo`0000?o0000ooooooooool0
U_ooool2oomo00kooooo0_l00?lZooooo`;oogl01Oooool00ol00?ooooooooooo`0oooooo`7o0000
0Oooool00003o`000?oooooooooo09Gooooo1?ooO`0<ooooo`04o`00ooooooooogl0oomo02Sooooo
1?ooO`03ooooo`03o`00oooooooooooo043ooooo0Ol00001ooooo`0000?o0000ooooooooool0UOoo
ool4oomo00[ooooo0_l00?l00oooooooogl0oomo0002oomo02Oooooo1?ooO`03ooooo`03o`00oooo
oooooooo043ooooo0Ol00001ooooo`0000?o0000ooooooooool0U_ooool2oomo00[ooooo00Co003o
oooooooooooooooo1?ooO`0Xooooo`;oogl01?ooool00ol00?ooooooooooo`10ooooo`7o00000Ooo
ool00003o`000?oooooooooo0:7ooooo00?o003oooooooooool00oooool2oomo02kooooo00?o003o
ooooooooool0@Oooool1o`00007ooooo00000ol0003oooooooooo`2Pooooo`03o`00oooooooooooo
03?ooooo00?o003oooooooooool04_ooool2oomo02kooooo0Ol00001ooooo`0000?o0000oooooooo
ool0W_ooool2o`00ocGooooo00?o003oooooooooool04_ooool4oomo02gooooo0Ol00001ooooo`00
00?o0000ooooooooool0WOooool00ol00?ooooooooooo`0Eooooo`Co003o7?ooool00ol00?ooogl0
oomo000Booooo`Coogl0;Oooool1o`00007ooooo00000ol0003oooooooooo`2Looooo`03o`00oooo
oooooooo01Gooooo1_l00?lJooooo`03o`00ooooO`3oogl000;oogl04_ooool2oomo02kooooo0Ol0
0001ooooo`0000?o0000ooooooooool0Voooool00ol00?ooooooooooo`0Eooooo`So003o6?ooool0
0ol00?oooooooomo0003oomo04;ooooo0Ol00001ooooo`0000?o0000ooooooooool0Voooool00ol0
0?ooooooooooo`0Eooooo`So003o5oooool01?l00?ooooooooooooooool2oomo04?ooooo0Ol00001
ooooo`0000?o0000ooooooooool0V_ooool00ol00?ooooooooooo`0Fooooo`So003o5_ooool00ol0
0?ooooooooooo`17ooooo`7o00000Oooool00003o`000?oooooooooo09Wooooo00?o003ooooooooo
ool03?ooool2oomo00Sooooo00?oogl0o`00ool00?l01_l00?lEooooo`03o`00oooooooooooo00;o
ogl0A_ooool1o`00007ooooo00000ol0003oooooooooo`2Iooooo`03o`00oooooooooooo00[ooooo
1OooO`07ooooo`;oogl01_l00?lCooooo`;oogl000?o003oooooooooool01?ooO`15ooooo`7o0000
0Oooool00003o`000?oooooooooo09Sooooo00?o003oooooooooool02_ooool6oomo00Sooooo0_oo
O`04o`00oa?ooooo0_ooO`02o`00o`;ooooo1?ooO`15ooooo`7o00000Oooool00003o`000?oooooo
oooo09Sooooo00?o003oooooooooool02_ooool5oomo02;ooooo00Coogl0o`00ooooO`3oogl00ooo
ool2oomo04Kooooo0Ol00001ooooo`0000?o0000ooooooooool0M_ooool2oomo01oooooo00?o003o
ooooooooool03?ooool2oomo02Cooooo00?o003ooomo0?ooO`00C?ooool1o`00007ooooo00000ol0
003oooooooooo`1eooooo`Coogl07_ooool00ol00?ooooooooooo`0aooooo`03o`00oooooooooooo
04gooooo0Ol00001ooooo`0000?o0000ooooooooool0MOooool4oomo00[ooooo0_ooO`0Aooooo`03
o`00oooooooooooo037ooooo00?o003oooooooooool0C_ooool1o`00007ooooo00000ol0003ooooo
ooooo`1fooooo`;oogl02_ooool4oomo00oooooo00?o003oooooooooool06?ooool2oomo01Oooooo
00?o003oooooooooool0Coooool1o`00007ooooo00000ol0003oooooooooo`22ooooo`Coogl03ooo
ool00ol00?ooooooooooo`0Gooooo`Coogl05?ooool2o`00oe;ooooo0Ol00001ooooo`0000?o0000
ooooooooool0Poooool2oomo00oooooo00?o003oooooooooool04_ooool2oomo00Cooooo1?ooO`0A
ooooo`?o003oE?ooool1o`00007ooooo00000ol0003oooooooooo`2Dooooo`03o`00oooooooooooo
017ooooo1?ooO`04ooooo`;oogl04?ooool2o`00oeOooooo0Ol00001ooooo`0000?o0000oooooooo
ool0U?ooool00ol00?ooooooooooo`0Aooooo`Coogl05Oooool00ol00?ooooooooooo`1Gooooo`7o
00000Oooool00003o`000?oooooooooo09Cooooo00?o003oooooooooool04_ooool2oomo01Cooooo
0_l00?mJooooo`7o00000Oooool00003o`000?oooooooooo09Cooooo00?o003oooooooooool09_oo
ool2o`00oecooooo0Ol00001ooooo`0000?o0000ooooooooool0UOooool00ol00?ooooooooooo`0T
ooooo`03o`00oooooooooooo05cooooo0Ol00001ooooo`0000?o0000ooooooooool0UOooool00ol0
0?ooooooooooo`0Rooooo`;o003oGoooool1o`00007ooooo00000ol0003oooooooooo`2Eooooo`03
o`00oooooooooooo023ooooo0_l00?mQooooo`7o00000Oooool00003o`000?oooooooooo08Cooooo
0_ooO`0?ooooo`;o003o7oooool2o`00of?ooooo0Ol00001ooooo`0000?o0000ooooooooool0Pooo
ool4oomo013ooooo0_l00?lJooooo`?o003oIOooool1o`00007ooooo00000ol0003oooooooooo`23
ooooo`Coogl04_ooool2o`00oaCooooo1?l00?mXooooo`7o00000Oooool00003o`000?oooooooooo
08Cooooo0_ooO`0Eooooo`?o003o3_ooool3o`00o`?ooooo0_ooO`1Wooooo`7o00000Oooool00003
o`000?oooooooooo09kooooo0ol00?l5ooooo`Ko003o1Oooool4oomo06Kooooo0Ol00001ooooo`00
00?o0000ooooooooool0XOooool5o`00o`_ooooo1?ooO`1Vooooo`7o00000Oooool00003o`000?oo
oooooooo0;;ooooo0_ooO`1Wooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1
o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000oooooooo
ool0Noooool2oomo09kooooo0Ol00001ooooo`0000?o0000ooooooooool0N_ooool4oomo09gooooo
0Ol00001ooooo`0000?o0000ooooooooool0N_ooool4oomo023ooooo0_ooO`1kooooo`7o00000Ooo
ool00003o`000?oooooooooo07_ooooo0_ooO`0Pooooo`Coogl0N_ooool1o`00007ooooo00000ol0
003oooooooooo`2Mooooo`Coogl0N_ooool1o`00007ooooo00000ol0003oooooooooo`2@ooooo`;o
ogl03?ooool2oomo07_ooooo0Ol00001ooooo`0000?o0000ooooooooool0Soooool4oomo08Sooooo
0Ol00001ooooo`0000?o0000ooooooooool0Soooool4oomo08Sooooo0Ol00001ooooo`0000?o0000
ooooooooool0T?ooool2oomo02?ooooo0_ooO`1Tooooo`7o00000Oooool00003o`000?oooooooooo
0;Cooooo1?ooO`1Sooooo`7o00000Oooool00003o`000?oooooooooo0;Cooooo1?ooO`1Sooooo`7o
00000Oooool00003o`000?oooooooooo0;Gooooo0_ooO`1Tooooo`7o00000Oooool00003o`000?oo
oooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001
ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo0?oo
oooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o
0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1
o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000oooooooo
ool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo
00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolL
ooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003o
ooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o0000
0Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3o
oooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003
o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo
0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oooooo
oooo0?oooooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001oooo
o`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo
7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000
ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00
007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0
oooooolLooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo0000
0ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLoooo
o`7o00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003ooooo
ooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Ooo
ool00003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003oooooooooo`2>oooo
o`;oogl0Roooool1o`00007ooooo00000ol0003oooooooooo`2=ooooo`Coogl0R_ooool1o`00007o
oooo00000ol0003oooooooooo`2=ooooo`Coogl0R_ooool1o`00007ooooo00000ol0003ooooooooo
o`2>ooooo`;oogl0Roooool1o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001
ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo0?oo
oooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o
0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1
o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000oooooooo
ool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo
00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolL
ooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003o
ooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o0000
0Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3o
oooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003
o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo
0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oooooo
oooo0?oooooo7?ooool1o`00007ooooo003oo`00023o00000Oooool00001\
\>"],
  ImageRangeCache->{{{0, 287}, {287, 0}} -> {-1.01089, -1.01089, 0.00704453, \
0.00704453}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.49505 0.5 0.49505 [
[ 0 0 -0.125 0 ]
[ 0 0 -0.125 0 ]
[ 0 1 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
0 0 m
1 0 L
s
0 0 m
0 1 L
s
0 1 m
1 1 L
s
1 0 m
1 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
1 .5 0 r
.015 w
.03175 .1355 Mdot
.03435 .12523 Mdot
.11137 .12765 Mdot
.14107 .18841 Mdot
.16218 .24538 Mdot
.17294 .21053 Mdot
.18267 .18577 Mdot
.18434 .1304 Mdot
.18553 .30956 Mdot
.20401 .239 Mdot
.21247 .27571 Mdot
.21687 .20845 Mdot
.22376 .2799 Mdot
.22832 .27485 Mdot
.29063 .20974 Mdot
.29686 .25079 Mdot
.30487 .22936 Mdot
.30683 .34623 Mdot
.32055 .20902 Mdot
.32574 .21979 Mdot
.34472 .28521 Mdot
.35998 .36393 Mdot
.36335 .24976 Mdot
.3794 .36608 Mdot
.42386 .66992 Mdot
.44391 .74519 Mdot
.45059 .34198 Mdot
.47208 .67586 Mdot
.47436 .71381 Mdot
.49778 .59825 Mdot
.50874 .91643 Mdot
.51516 .76219 Mdot
.53655 .61374 Mdot
.56563 .75219 Mdot
.59189 .65665 Mdot
.59581 .61604 Mdot
.59923 .6556 Mdot
.60292 .68499 Mdot
.62656 .67779 Mdot
.63555 .72451 Mdot
.63919 .652 Mdot
.64169 .6004 Mdot
.64246 .58611 Mdot
.64496 .54267 Mdot
.64608 .77288 Mdot
.65077 .64308 Mdot
.66065 .57816 Mdot
.67474 .59169 Mdot
.69296 .563 Mdot
.72815 .65902 Mdot
.73169 .58879 Mdot
.74669 .61318 Mdot
.74821 .65474 Mdot
.75963 .63781 Mdot
.79673 .57809 Mdot
.80925 .55852 Mdot
.81525 .58444 Mdot
.83417 .62985 Mdot
.83598 .55526 Mdot
.91595 .49319 Mdot
1 0 0 r
.005 w
.16128 .17044 m
.18734 .17269 L
.21339 .17909 L
.2345 .18734 L
.23945 .19126 L
.2655 .20415 L
.27874 .21339 L
.29156 .22295 L
.31204 .23945 L
.31761 .24532 L
.33549 .2655 L
.34367 .28341 L
.34499 .29156 L
.34367 .29798 L
.31761 .3104 L
.29156 .30711 L
.2655 .30014 L
.24507 .29156 L
.23945 .28747 L
.21339 .27402 L
.20155 .2655 L
.18734 .25472 L
.16884 .23945 L
.16128 .2313 L
.14618 .21339 L
.13806 .18734 L
.16128 .17044 L
s
0 0 1 r
.65633 .57701 m
.68239 .56842 L
.70844 .56313 L
.7345 .56168 L
.76055 .5752 L
.76359 .57817 L
.76859 .60422 L
.76055 .62333 L
.75627 .63028 L
.7345 .65485 L
.73298 .65633 L
.70844 .6775 L
.69922 .68239 L
.68239 .69294 L
.65633 .70579 L
.64983 .70844 L
.63028 .71539 L
.60422 .72268 L
.57817 .72651 L
.55211 .7214 L
.53145 .70844 L
.52926 .68239 L
.54239 .65633 L
.55211 .63983 L
.56625 .63028 L
.57817 .6193 L
.60119 .60422 L
.60422 .60227 L
.63028 .58726 L
.65315 .57817 L
.65633 .57701 L
s
1 0 0 r
.03 w
.24141 .24033 Mdot
0 0 1 r
.64872 .64417 Mdot
1 0 0 r
.79703 .00495 m
.79703 .25248 L
.87129 .25248 L
.87129 .00495 L
F
0 0 1 r
.89604 .00495 m
.89604 .00495 L
.9703 .00495 L
.9703 .00495 L
F
1 0 1 r
.04 w
.22832 .27485 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P000182000`400?l00000o`00003ooooooolQ
ooooo`00ool0000Po`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`00
00?o0000ooooooooool0hOoooolEool002Gooooo0Ol00001ooooo`0000?o0000ooooooooool0hOoo
oolEool002Gooooo0Ol00001ooooo`0000?o0000ooooooooool0hOoooolEool002Gooooo0Ol00001
ooooo`0000?o0000ooooooooool0hOoooolEool002Gooooo0Ol00001ooooo`0000?o0000oooooooo
ool0hOoooolEool002Gooooo0Ol00001ooooo`0000?o0000ooooooooool0hOoooolEool002Gooooo
0Ol00001ooooo`0000?o0000ooooooooool0hOoooolEool002Gooooo0Ol00001ooooo`0000?o0000
ooooooooool0hOoooolEool002Gooooo0Ol00001ooooo`0000?o0000ooooooooool0hOoooolEool0
02Gooooo0Ol00001ooooo`0000?o0000ooooooooool0hOoooolEool002Gooooo0Ol00001ooooo`00
00?o0000ooooooooool0hOoooolEool002Gooooo0Ol00001ooooo`0000?o0000ooooooooool0hOoo
oolEool002Gooooo0Ol00001ooooo`0000?o0000ooooooooool0hOoooolEool002Gooooo0Ol00001
ooooo`0000?o0000ooooooooool0hOoooolEool002Gooooo0Ol00001ooooo`0000?o0000oooooooo
ool0hOoooolEool002Gooooo0Ol00001ooooo`0000?o0000ooooooooool0hOoooolEool002Gooooo
0Ol00001ooooo`0000?o0000ooooooooool0hOoooolEool002Gooooo0Ol00001ooooo`0000?o0000
ooooooooool0hOoooolEool002Gooooo0Ol00001ooooo`0000?o0000ooooooooool0hOoooolEool0
02Gooooo0Ol00001ooooo`0000?o0000ooooooooool0hOoooolEool002Gooooo0Ol00001ooooo`00
00?o0000ooooooooool0hOoooolEool002Gooooo0Ol00001ooooo`0000?o0000ooooooooool0hOoo
oolEool002Gooooo0Ol00001ooooo`0000?o0000ooooooooool0hOoooolEool002Gooooo0Ol00001
ooooo`0000?o0000ooooooooool0hOoooolEool002Gooooo0Ol00001ooooo`0000?o0000oooooooo
ool0hOoooolEool002Gooooo0Ol00001ooooo`0000?o0000ooooooooool0hOoooolEool002Gooooo
0Ol00001ooooo`0000?o0000ooooooooool0hOoooolEool002Gooooo0Ol00001ooooo`0000?o0000
ooooooooool0hOoooolEool002Gooooo0Ol00001ooooo`0000?o0000ooooooooool0hOoooolEool0
02Gooooo0Ol00001ooooo`0000?o0000ooooooooool0hOoooolEool002Gooooo0Ol00001ooooo`00
00?o0000ooooooooool0hOoooolEool002Gooooo0Ol00001ooooo`0000?o0000ooooooooool0hOoo
oolEool002Gooooo0Ol00001ooooo`0000?o0000ooooooooool01_ooool2oomo0=Wooooo5Ooo000U
ooooo`7o00000Oooool00003o`000?oooooooooo00Gooooo1?ooO`0Cooooo`;oogl0`ooooolEool0
02Gooooo0Ol00001ooooo`0000?o0000ooooooooool01Oooool4oomo01;ooooo1?ooO`0Booooo`;o
ogl0[_oooolEool002Gooooo0Ol00001ooooo`0000?o0000ooooooooool01Oooool3oomo01?ooooo
1?ooO`0Aooooo`Coogl0[OoooolEool002Gooooo0Ol00001ooooo`0000?o0000ooooooooool01?oo
ool4oomo01Cooooo0_ooO`0Booooo`Coogl0[OoooolEool002Gooooo0Ol00001ooooo`0000?o0000
ooooooooool01?ooool4oomo02Wooooo0_ooO`2^oooooaGoo`009Oooool1o`00007ooooo00000ol0
003oooooooooo`05ooooo`;oogl0f_oooolEool002Gooooo0Ol00001ooooo`0000?o0000oooooooo
ool0hOoooolEool002Gooooo0Ol00001ooooo`0000?o0000ooooooooool0hOoooolEool002Gooooo
0Ol00001ooooo`0000?o0000ooooooooool0hOoooolEool002Gooooo0Ol00001ooooo`0000?o0000
ooooooooool0hOoooolEool002Gooooo0Ol00001ooooo`0000?o0000ooooooooool0hOoooolEool0
02Gooooo0Ol00001ooooo`0000?o0000ooooooooool0hOoooolEool002Gooooo0Ol00001ooooo`00
00?o0000ooooooooool0hOoooolEool002Gooooo0Ol00001ooooo`0000?o0000ooooooooool0:_oo
ool6ool00;7ooooo5Ooo000Uooooo`7o00000Oooool00003o`000?oooooooooo02Wooooo00?oo`00
ooooooooool01?ooool5ool00:cooooo5Ooo000Uooooo`7o00000Oooool00003o`000?oooooooooo
02Oooooo0_oo000<ooooo`Coo`00Z?oooolEool002Gooooo0Ol00001ooooo`0000?o0000oooooooo
ool09_ooool00ooo003oooooooooo`0@ooooo`Coo`00Y?oooolEool002Gooooo0Ol00001ooooo`00
00?o0000ooooooooool09?ooool00oooO`3oo`00ooooo`09ooooo`;oogl02oooool3ool00:7ooooo
5Ooo000Uooooo`7o00000Oooool00003o`000?oooooooooo02?ooooo00Coogl0ool00?ooO`3oogl0
2?ooool4oomo00gooooo00?oo`00ooooooooool0W_oooolEool002Gooooo0Ol00001ooooo`0000?o
0000ooooooooool08oooool01?ooO`3oo`00oomo0?ooO`08ooooo`Coogl03_ooool2ool009kooooo
5Ooo000Uooooo`7o00000Oooool00003o`000?oooooooooo02Cooooo00?oogl0ool00?ooool02Ooo
ool2oomo017ooooo0_oo002LoooooaGoo`009Oooool1o`00007ooooo00000ol0003oooooooooo`0U
ooooo`03ool00?oooooooooo01gooooo0_oo002JoooooaGoo`009Oooool1o`00007ooooo00000ol0
003oooooooooo`0Uooooo`03ool00?oooooooooo01oooooo0_oo002HoooooaGoo`009Oooool1o`00
007ooooo00000ol0003oooooooooo`0Vooooo`03ool00?oooooooooo017ooooo0_ooO`0=ooooo`;o
o`001?ooool2oomo00Oooooo0_ooO`27oooooaGoo`009Oooool1o`00007ooooo00000ol0003ooooo
ooooo`0Vooooo`03ool00?oooooooooo00Gooooo0_ooO`09ooooo`Coogl03_ooool00ooo003ooooo
ooooo`04oomo00Gooooo1?ooO`26oooooaGoo`009Oooool1o`00007ooooo00000ol0003ooooooooo
o`0Vooooo`03ool00?oooooooooo00Cooooo1?ooO`08ooooo`Coogl03oooool00ooo003ooooooomo
0003oomo00Gooooo1?ooO`26oooooaGoo`009Oooool1o`00007ooooo00000ol0003oooooooooo`0W
ooooo`03ool00?oooooooooo00?ooooo1?ooO`09ooooo`;oogl04Oooool01?oo003ooooooomo0?oo
O`07ooooo`?oogl0Q_oooolEool002Gooooo0Ol00001ooooo`0000?o0000ooooooooool09oooool0
0ooo003oooooooooo`04ooooo`;oogl07_ooool00ooo003oooooooooo`07ooooo`Coogl0QOoooolE
ool002Gooooo0Ol00001ooooo`0000?o0000ooooooooool0:?ooool00ooo003oooooooooo`0Toooo
o`03ool00?oooooooooo00Kooooo1?ooO`25oooooaGoo`009Oooool1o`00007ooooo00000ol0003o
ooooooooo`0Yooooo`03ool00?oooooooooo02Cooooo0_oo00000oooooooogl0oomo0004ooooo`;o
ogl0Q_oooolEool002Gooooo0Ol00001ooooo`0000?o0000ooooooooool0:_ooool00ooo003ooooo
ooooo`0Cooooo`Coo`003_ooool01?oo003oogl0oomo0?ooO`2;oooooaGoo`009Oooool1o`00007o
oooo00000ol0003oooooooooo`0[ooooo`03ool00?oooooooooo017ooooo1_oo000=ooooo`04oomo
0?oo003oo`00oomo08_ooooo5Ooo000Uooooo`7o00000Oooool00003o`000?oooooooooo02cooooo
00?oo`00ooooooooool02?ooool2oomo00Gooooo2?oo000=ooooo`;oogl000?oo`00ooooooooool0
ROoooolEool002Gooooo0Ol00001ooooo`0000?o0000ooooooooool0;Oooool00ooo003ooooooooo
o`06ooooo`Coogl01?ooool8ool0013ooooo00?oo`00ooooooooool0R?oooolEool002Gooooo0Ol0
0001ooooo`0000?o0000ooooooooool0:oooool2oomo0003oooooooo003ooooo00Kooooo1?ooO`04
ooooo`Soo`004Oooool00ooo003oooooooooo`27oooooaGoo`009Oooool1o`00007ooooo00000ol0
003oooooooooo`0Zooooo`Coogl000?oooooool00?ooool01_ooool2oomo00Gooooo2?oo000;oooo
o`;oogl01Oooool00ooo003oooooooooo`09ooooo`;oogl0NooooolEool002Gooooo0Ol00001oooo
o`0000?o0000ooooooooool0:_ooool4oomo00;ooooo00?oo`00ooooooooool03?ooool6ool000_o
oooo1?ooO`04ooooo`03ool00?oooooooooo00Sooooo1?ooO`1joooooaGoo`009Oooool1o`00007o
oooo00000ol0003oooooooooo`0[ooooo`;oogl01?ooool00ooo003oooooooooo`0<ooooo`Coo`00
3?ooool4oomo00Gooooo00?oo`00ooooooooool01oooool4oomo07[ooooo5Ooo000Uooooo`7o0000
0Oooool00003o`000?oooooooooo03;ooooo0_oo000Mooooo`;oogl01oooool00ooo003ooooooooo
o`07ooooo`;oogl0]Oooool1o`00007ooooo00000ol0003oooooooooo`0dooooo`03ool00?oooooo
oooo00Gooooo1Ooo0?lJooooo`03ool00?oooooooooo0;gooooo0Ol00001ooooo`0000?o0000oooo
ooooool0=Oooool00ooo003oooooooooo`03ooooo`Ooo`3o6_ooool00ooo003oooooooooo`2loooo
o`7o00000Oooool00003o`000?oooooooooo03Kooooo0_oo0002ooooo`Woo`3o6_ooool00ooo003o
ooooooooo`2kooooo`7o00000Oooool00003o`000?oooooooooo03Sooooo00?oo`00ool0oooo0?l0
2Ooo0?lIooooo`03ool00?oooooooooo0;_ooooo0Ol00001ooooo`0000?o0000ooooooooool0>?oo
ool00oooO`3oo`3oool0o`09ool0oa[ooooo00?oo`00ooooooooool0^_ooool1o`00007ooooo0000
0ol0003oooooooooo`0hooooo`03oomo0?oo0?ooo`3o00Woo`3o6_ooool00ooo003oooooooooo`2j
ooooo`7o00000Oooool00003o`000?oooooooooo03Wooooo2ooo0?lJooooo`03ool00?ooO`3oogl0
0;[ooooo0Ol00001ooooo`0000?o0000ooooooooool0>Oooool;ool0oa[ooooo00Coogl0ool00?oo
O`3oogl0^Oooool1o`00007ooooo00000ol0003oooooooooo`0jooooo`Woo`3o6oooool01?ooO`3o
o`00oomo0?ooO`2iooooo`7o00000Oooool00003o`000?oooooooooo03_ooooo1ooo0?l00ooooooo
o`00ool0000Jooooo`03oomo0?oo003ooooo0;Wooooo0Ol00001ooooo`0000?o0000ooooooooool0
??ooool5ool0o`Cooooo0_oo000Iooooo`03ool00?oooooooooo0;Sooooo0Ol00001ooooo`0000?o
0000ooooooooool0Aoooool2ool001Gooooo0_oo002kooooo`7o00000Oooool00003o`000?oooooo
oooo04Wooooo0ooo000@ooooo`;oo`00_Oooool1o`00007ooooo00000ol0003oooooooooo`0aoooo
o`;oogl06Oooool3ool000cooooo00?oo`00ooooooooool0_Oooool1o`00007ooooo00000ol0003o
ooooooooo`0`ooooo`Coogl06oooool6ool000Cooooo0_oo0030ooooo`7o00000Oooool00003o`00
0?oooooooooo033ooooo1?ooO`0Qooooo`Coo`00`_ooool1o`00007ooooo00000ol0003ooooooooo
o`0aooooo`;oogl0j?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001
ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo0?oo
oooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o
0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo07gooooo0_ooO`2L
ooooo`7o00000Oooool00003o`000?oooooooooo07cooooo1?ooO`2Kooooo`7o00000Oooool00003
o`000?oooooooooo05Cooooo0_ooO`0Vooooo`Coogl0Voooool1o`00007ooooo00000ol0003ooooo
ooooo`1Cooooo`Coogl09_ooool2oomo09cooooo0Ol00001ooooo`0000?o0000ooooooooool0Dooo
ool4oomo0<Cooooo0Ol00001ooooo`0000?o0000ooooooooool0E?ooool2oomo0<Gooooo0Ol00001
ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo06?o
oooo0_ooO`04ooooo`;oogl0/?ooool1o`00007ooooo00000ol0003oooooooooo`1Rooooo`Coogl0
0_ooool4oomo0:oooooo0Ol00001ooooo`0000?o0000ooooooooool0H_ooool4oomo00;ooooo1?oo
O`2_ooooo`7o00000Oooool00003o`000?oooooooooo06?ooooo0_ooO`04ooooo`;oogl0/?ooool1
o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000oooooooo
ool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo
00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolL
ooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003o
ooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o0000
0Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3o
oooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003
o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo
0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oooooo
oooo0?oooooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001oooo
o`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo
7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000
ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00
007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0
oooooolLooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo0000
0ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLoooo
o`7o00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003ooooo
ooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Ooo
ool00003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooo
oacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`00
0?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3oooooo`Cooooo0_oo
O`0Fooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo0oooool4oomo01Gooooo0Ol00001
ooooo`0000?o0000ooooooooool0ooooool3ooooo`Coogl05Oooool1o`00007ooooo00000ol0003o
ooooooooo`3oooooo`Cooooo0_ooO`0Fooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo
7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000
ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00
007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0
oooooolLooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo0000
0ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLoooo
o`7o00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003ooooo
ooooo`2eooooo`;oogl0I?ooool1o`00007ooooo00000ol0003oooooooooo`2dooooo`Coogl0Hooo
ool1o`00007ooooo00000ol0003oooooooooo`2dooooo`Coogl0Hoooool1o`00007ooooo00000ol0
003oooooooooo`2eooooo`;oogl0=Oooool2oomo02gooooo0Ol00001ooooo`0000?o0000oooooooo
ool0i?ooool2oomo00Gooooo1?ooO`0/ooooo`7o00000Oooool00003o`000?oooooooooo0>?ooooo
1?ooO`04ooooo`Coogl0;?ooool1o`00007ooooo00000ol0003oooooooooo`33ooooo`;oogl07_oo
ool4oomo00Gooooo0_ooO`0]ooooo`7o00000Oooool00003o`000?oooooooooo0<;ooooo1?ooO`0;
o`00oa?ooooo0_ooO`0eooooo`7o00000Oooool00003o`000?oooooooooo0<;ooooo1?l00?l;oooo
o`;o003oB?ooool1o`00007ooooo00000ol0003oooooooooo`2nooooo`Co003o00?ooooooomo0?oo
O`003_ooool2o`00odKooooo0Ol00001ooooo`0000?o0000ooooooooool0^Oooool2oomo00?o003o
5oooool2o`00o`Wooooo0_ooO`0iooooo`7o00000Oooool00003o`000?oooooooooo0;Oooooo1?l0
0?l00oooO`3oooooooooo`0Iooooo`;o003o1_ooool4oomo03Sooooo0Ol00001ooooo`0000?o0000
ooooooooool0]?ooool3o`00o`03ooooooooO`3oogl000;oogl07?ooool00ol00?ooooooooooo`04
ooooo`Coogl00oooool2oomo03?ooooo0Ol00001ooooo`0000?o0000ooooooooool0/_ooool2o`00
o`?oogl00_ooool2oomo01?ooooo0_ooO`08ooooo`03o`00oooooooooooo00Gooooo0_ooO`03oooo
o`Coogl0<_ooool1o`00007ooooo00000ol0003oooooooooo`2`ooooo`;o003o00?ooooooomo0?oo
O`000_ooO`06ooooo`;oogl03_ooool4oomo00Oooooo00?o003oooooooooool02_ooool4oomo03;o
oooo0Ol00001ooooo`0000?o0000ooooooooool0[_ooool2o`00o`Cooooo0_ooO`06ooooo`Coogl0
3Oooool4oomo00Oooooo00?o003oooooooooool02oooool2oomo03?ooooo0Ol00001ooooo`0000?o
0000ooooooooool0Roooool2oomo023ooooo00?o003oooooooooool01?ooool2oomo00Kooooo1?oo
O`0>ooooo`;oogl02Oooool00ol00?ooooooooooo`0oooooo`7o00000Oooool00003o`000?oooooo
oooo08[ooooo1?ooO`0Mooooo`;o003o1_ooool4oomo00Kooooo0_ooO`0Jooooo`03o`00oooooooo
oooo03oooooo0Ol00001ooooo`0000?o0000ooooooooool0R_ooool4oomo01cooooo00?o003ooooo
ooooool01_ooool4oomo02;ooooo00?o003oooooooooool0?oooool1o`00007ooooo00000ol0003o
ooooooooo`2;ooooo`;oogl06oooool2o`00o`[ooooo0_ooO`0Sooooo`03o`00oooooooooooo03oo
oooo0Ol00001ooooo`0000?o0000ooooooooool0U_ooool2oomo00kooooo0_l00?lZooooo`;oogl0
1Oooool00ol00?ooooooooooo`0oooooo`7o00000Oooool00003o`000?oooooooooo09Gooooo1?oo
O`0<ooooo`04o`00ooooooooogl0oomo02Sooooo1?ooO`03ooooo`03o`00oooooooooooo043ooooo
0Ol00001ooooo`0000?o0000ooooooooool0UOooool4oomo00[ooooo0_l00?l00oooooooogl0oomo
0002oomo02Oooooo1?ooO`03ooooo`03o`00oooooooooooo043ooooo0Ol00001ooooo`0000?o0000
ooooooooool0U_ooool2oomo00[ooooo00Co003ooooooooooooooooo1?ooO`0Xooooo`;oogl01?oo
ool00ol00?ooooooooooo`10ooooo`7o00000Oooool00003o`000?oooooooooo0:7ooooo00?o003o
ooooooooool00oooool2oomo02kooooo00?o003oooooooooool0@Oooool1o`00007ooooo00000ol0
003oooooooooo`2Pooooo`03o`00oooooooooooo03?ooooo00?o003oooooooooool04_ooool2oomo
02kooooo0Ol00001ooooo`0000?o0000ooooooooool0W_ooool2o`00ocGooooo00?o003ooooooooo
ool04_ooool4oomo02gooooo0Ol00001ooooo`0000?o0000ooooooooool0WOooool00ol00?oooooo
ooooo`0Eooooo`Co003o7?ooool00ol00?ooogl0oomo000Booooo`Coogl0;Oooool1o`00007ooooo
00000ol0003oooooooooo`2Looooo`03o`00oooooooooooo01Gooooo1_l00?lJooooo`03o`00oooo
O`3oogl000;oogl04_ooool2oomo02kooooo0Ol00001ooooo`0000?o0000ooooooooool0Voooool0
0ol00?ooooooooooo`0Eooooo`So003o6?ooool00ol00?oooooooomo0003oomo04;ooooo0Ol00001
ooooo`0000?o0000ooooooooool0Voooool00ol00?ooooooooooo`0Eooooo`So003o5oooool01?l0
0?ooooooooooooooool2oomo04?ooooo0Ol00001ooooo`0000?o0000ooooooooool0V_ooool00ol0
0?ooooooooooo`0Fooooo`So003o5_ooool00ol00?ooooooooooo`17ooooo`7o00000Oooool00003
o`000?oooooooooo09Wooooo00?o003oooooooooool03?ooool2oomo00Sooooo00?oogl0o`00ool0
0?l01_l00?lEooooo`03o`00oooooooooooo00;oogl0A_ooool1o`00007ooooo00000ol0003ooooo
ooooo`2Iooooo`03o`00oooooooooooo00[ooooo1OooO`07ooooo`;oogl01_l00?lCooooo`;oogl0
00?o003oooooooooool01?ooO`15ooooo`7o00000Oooool00003o`000?oooooooooo09Sooooo00?o
003oooooooooool02_ooool6oomo00Sooooo0_ooO`04o`00oa?ooooo0_ooO`02o`00o`;ooooo1?oo
O`15ooooo`7o00000Oooool00003o`000?oooooooooo09Sooooo00?o003oooooooooool02_ooool5
oomo02;ooooo00Coogl0o`00ooooO`3oogl00oooool2oomo04Kooooo0Ol00001ooooo`0000?o0000
ooooooooool0M_ooool2oomo01oooooo00?o003oooooooooool03?ooool2oomo02Cooooo00?o003o
oomo0?ooO`00C?ooool1o`00007ooooo00000ol0003oooooooooo`1eooooo`Coogl07_ooool00ol0
0?ooooooooooo`0aooooo`03o`00oooooooooooo04gooooo0Ol00001ooooo`0000?o0000oooooooo
ool0MOooool4oomo00[ooooo0_ooO`0Aooooo`03o`00oooooooooooo037ooooo00?o003ooooooooo
ool0C_ooool1o`00007ooooo00000ol0003oooooooooo`1fooooo`;oogl02_ooool4oomo00oooooo
00?o003oooooooooool06?ooool2oomo01Oooooo00?o003oooooooooool0Coooool1o`00007ooooo
00000ol0003oooooooooo`22ooooo`Coogl03oooool00ol00?ooooooooooo`0Gooooo`Coogl05?oo
ool2o`00oe;ooooo0Ol00001ooooo`0000?o0000ooooooooool0Poooool2oomo00oooooo00?o003o
ooooooooool04_ooool2oomo00Cooooo1?ooO`0Aooooo`?o003oE?ooool1o`00007ooooo00000ol0
003oooooooooo`2Dooooo`03o`00oooooooooooo017ooooo1?ooO`04ooooo`;oogl04?ooool2o`00
oeOooooo0Ol00001ooooo`0000?o0000ooooooooool0U?ooool00ol00?ooooooooooo`0Aooooo`Co
ogl05Oooool00ol00?ooooooooooo`1Gooooo`7o00000Oooool00003o`000?oooooooooo09Cooooo
00?o003oooooooooool04_ooool2oomo01Cooooo0_l00?mJooooo`7o00000Oooool00003o`000?oo
oooooooo09Cooooo00?o003oooooooooool09_ooool2o`00oecooooo0Ol00001ooooo`0000?o0000
ooooooooool0UOooool00ol00?ooooooooooo`0Tooooo`03o`00oooooooooooo05cooooo0Ol00001
ooooo`0000?o0000ooooooooool0UOooool00ol00?ooooooooooo`0Rooooo`;o003oGoooool1o`00
007ooooo00000ol0003oooooooooo`2Eooooo`03o`00oooooooooooo023ooooo0_l00?mQooooo`7o
00000Oooool00003o`000?oooooooooo08Cooooo0_ooO`0?ooooo`;o003o7oooool2o`00of?ooooo
0Ol00001ooooo`0000?o0000ooooooooool0Poooool4oomo013ooooo0_l00?lJooooo`?o003oIOoo
ool1o`00007ooooo00000ol0003oooooooooo`23ooooo`Coogl04_ooool2o`00oaCooooo1?l00?mX
ooooo`7o00000Oooool00003o`000?oooooooooo08Cooooo0_ooO`0Eooooo`?o003o3_ooool3o`00
o`?ooooo0_ooO`1Wooooo`7o00000Oooool00003o`000?oooooooooo09kooooo0ol00?l5ooooo`Ko
003o1Oooool4oomo06Kooooo0Ol00001ooooo`0000?o0000ooooooooool0XOooool5o`00o`_ooooo
1?ooO`1Vooooo`7o00000Oooool00003o`000?oooooooooo0;;ooooo0_ooO`1Wooooo`7o00000Ooo
ool00003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooo
oacooooo0Ol00001ooooo`0000?o0000ooooooooool0Noooool2oomo09kooooo0Ol00001ooooo`00
00?o0000ooooooooool0N_ooool4oomo09gooooo0Ol00001ooooo`0000?o0000ooooooooool0N_oo
ool4oomo023ooooo0_ooO`1kooooo`7o00000Oooool00003o`000?oooooooooo07_ooooo0_ooO`0P
ooooo`Coogl0N_ooool1o`00007ooooo00000ol0003oooooooooo`2Mooooo`Coogl0N_ooool1o`00
007ooooo00000ol0003oooooooooo`2@ooooo`;oogl03?ooool2oomo07_ooooo0Ol00001ooooo`00
00?o0000ooooooooool0Soooool4oomo08Sooooo0Ol00001ooooo`0000?o0000ooooooooool0Sooo
ool4oomo08Sooooo0Ol00001ooooo`0000?o0000ooooooooool0T?ooool2oomo02?ooooo0_ooO`1T
ooooo`7o00000Oooool00003o`000?oooooooooo0;Cooooo1?ooO`1Sooooo`7o00000Oooool00003
o`000?oooooooooo0;Cooooo1?ooO`1Sooooo`7o00000Oooool00003o`000?oooooooooo0;Gooooo
0_ooO`1Tooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo0000
0ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLoooo
o`7o00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003ooooo
ooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Ooo
ool00003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooo
oacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`00
0?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol0
0001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo
0?oooooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`00
00?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?oo
ool1o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000oooo
ooooool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007o
oooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooo
oolLooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0
003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o
00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003ooooooooo
o`3ooooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool0
0003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooooaco
oooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oo
oooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001
ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo0?oo
oooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o
0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1
o`00007ooooo00000ol0003oooooooooo`2>ooooo`;oogl0Roooool1o`00007ooooo00000ol0003o
ooooooooo`2=ooooo`Coogl0R_ooool1o`00007ooooo00000ol0003oooooooooo`2=ooooo`Coogl0
R_ooool1o`00007ooooo00000ol0003oooooooooo`2>ooooo`;oogl0Roooool1o`00007ooooo0000
0ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLoooo
o`7o00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003ooooo
ooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Ooo
ool00003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooo
oacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`00
0?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol0
0001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo
0?oooooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`00
00?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?oo
ool1o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000oooo
ooooool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007o
oooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooo
oolLooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo003oo`00
023o00000Oooool00001\
\>"],
  ImageRangeCache->{{{0, 287}, {287, 0}} -> {-1.01089, -1.01089, 0.00704453, \
0.00704453}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.49505 0.5 0.49505 [
[ 0 0 -0.125 0 ]
[ 0 0 -0.125 0 ]
[ 0 1 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
0 0 m
1 0 L
s
0 0 m
0 1 L
s
0 1 m
1 1 L
s
1 0 m
1 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
1 .5 0 r
.015 w
.03175 .1355 Mdot
.03435 .12523 Mdot
.11137 .12765 Mdot
.14107 .18841 Mdot
.16218 .24538 Mdot
.17294 .21053 Mdot
.18267 .18577 Mdot
.18434 .1304 Mdot
.18553 .30956 Mdot
.20401 .239 Mdot
.21247 .27571 Mdot
.21687 .20845 Mdot
.22376 .2799 Mdot
.22832 .27485 Mdot
.29063 .20974 Mdot
.29686 .25079 Mdot
.30487 .22936 Mdot
.30683 .34623 Mdot
.32055 .20902 Mdot
.32574 .21979 Mdot
.34472 .28521 Mdot
.35998 .36393 Mdot
.36335 .24976 Mdot
.3794 .36608 Mdot
.42386 .66992 Mdot
.44391 .74519 Mdot
.45059 .34198 Mdot
.47208 .67586 Mdot
.47436 .71381 Mdot
.49778 .59825 Mdot
.50874 .91643 Mdot
.51516 .76219 Mdot
.53655 .61374 Mdot
.56563 .75219 Mdot
.59189 .65665 Mdot
.59581 .61604 Mdot
.59923 .6556 Mdot
.60292 .68499 Mdot
.62656 .67779 Mdot
.63555 .72451 Mdot
.63919 .652 Mdot
.64169 .6004 Mdot
.64246 .58611 Mdot
.64496 .54267 Mdot
.64608 .77288 Mdot
.65077 .64308 Mdot
.66065 .57816 Mdot
.67474 .59169 Mdot
.69296 .563 Mdot
.72815 .65902 Mdot
.73169 .58879 Mdot
.74669 .61318 Mdot
.74821 .65474 Mdot
.75963 .63781 Mdot
.79673 .57809 Mdot
.80925 .55852 Mdot
.81525 .58444 Mdot
.83417 .62985 Mdot
.83598 .55526 Mdot
.91595 .49319 Mdot
1 0 0 r
.005 w
.16128 .17044 m
.18734 .17269 L
.21339 .17909 L
.2345 .18734 L
.23945 .19126 L
.2655 .20415 L
.27874 .21339 L
.29156 .22295 L
.31204 .23945 L
.31761 .24532 L
.33549 .2655 L
.34367 .28341 L
.34499 .29156 L
.34367 .29798 L
.31761 .3104 L
.29156 .30711 L
.2655 .30014 L
.24507 .29156 L
.23945 .28747 L
.21339 .27402 L
.20155 .2655 L
.18734 .25472 L
.16884 .23945 L
.16128 .2313 L
.14618 .21339 L
.13806 .18734 L
.16128 .17044 L
s
0 0 1 r
.65633 .57701 m
.68239 .56842 L
.70844 .56313 L
.7345 .56168 L
.76055 .5752 L
.76359 .57817 L
.76859 .60422 L
.76055 .62333 L
.75627 .63028 L
.7345 .65485 L
.73298 .65633 L
.70844 .6775 L
.69922 .68239 L
.68239 .69294 L
.65633 .70579 L
.64983 .70844 L
.63028 .71539 L
.60422 .72268 L
.57817 .72651 L
.55211 .7214 L
.53145 .70844 L
.52926 .68239 L
.54239 .65633 L
.55211 .63983 L
.56625 .63028 L
.57817 .6193 L
.60119 .60422 L
.60422 .60227 L
.63028 .58726 L
.65315 .57817 L
.65633 .57701 L
s
1 0 0 r
.03 w
.24141 .24033 Mdot
0 0 1 r
.64872 .64417 Mdot
1 0 0 r
.79703 .00495 m
.79703 .25248 L
.87129 .25248 L
.87129 .00495 L
F
0 0 1 r
.89604 .00495 m
.89604 .00495 L
.9703 .00495 L
.9703 .00495 L
F
1 0 1 r
.04 w
.29063 .20974 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P000182000`400?l00000o`00003ooooooolQ
ooooo`00ool0000Po`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`00
00?o0000ooooooooool0hOoooolEool002Gooooo0Ol00001ooooo`0000?o0000ooooooooool0hOoo
oolEool002Gooooo0Ol00001ooooo`0000?o0000ooooooooool0hOoooolEool002Gooooo0Ol00001
ooooo`0000?o0000ooooooooool0hOoooolEool002Gooooo0Ol00001ooooo`0000?o0000oooooooo
ool0hOoooolEool002Gooooo0Ol00001ooooo`0000?o0000ooooooooool0hOoooolEool002Gooooo
0Ol00001ooooo`0000?o0000ooooooooool0hOoooolEool002Gooooo0Ol00001ooooo`0000?o0000
ooooooooool0hOoooolEool002Gooooo0Ol00001ooooo`0000?o0000ooooooooool0hOoooolEool0
02Gooooo0Ol00001ooooo`0000?o0000ooooooooool0hOoooolEool002Gooooo0Ol00001ooooo`00
00?o0000ooooooooool0hOoooolEool002Gooooo0Ol00001ooooo`0000?o0000ooooooooool0hOoo
oolEool002Gooooo0Ol00001ooooo`0000?o0000ooooooooool0hOoooolEool002Gooooo0Ol00001
ooooo`0000?o0000ooooooooool0hOoooolEool002Gooooo0Ol00001ooooo`0000?o0000oooooooo
ool0hOoooolEool002Gooooo0Ol00001ooooo`0000?o0000ooooooooool0hOoooolEool002Gooooo
0Ol00001ooooo`0000?o0000ooooooooool0hOoooolEool002Gooooo0Ol00001ooooo`0000?o0000
ooooooooool0hOoooolEool002Gooooo0Ol00001ooooo`0000?o0000ooooooooool0hOoooolEool0
02Gooooo0Ol00001ooooo`0000?o0000ooooooooool0hOoooolEool002Gooooo0Ol00001ooooo`00
00?o0000ooooooooool0hOoooolEool002Gooooo0Ol00001ooooo`0000?o0000ooooooooool0hOoo
oolEool002Gooooo0Ol00001ooooo`0000?o0000ooooooooool0hOoooolEool002Gooooo0Ol00001
ooooo`0000?o0000ooooooooool0hOoooolEool002Gooooo0Ol00001ooooo`0000?o0000oooooooo
ool0hOoooolEool002Gooooo0Ol00001ooooo`0000?o0000ooooooooool0hOoooolEool002Gooooo
0Ol00001ooooo`0000?o0000ooooooooool0hOoooolEool002Gooooo0Ol00001ooooo`0000?o0000
ooooooooool0hOoooolEool002Gooooo0Ol00001ooooo`0000?o0000ooooooooool0hOoooolEool0
02Gooooo0Ol00001ooooo`0000?o0000ooooooooool0hOoooolEool002Gooooo0Ol00001ooooo`00
00?o0000ooooooooool0hOoooolEool002Gooooo0Ol00001ooooo`0000?o0000ooooooooool0hOoo
oolEool002Gooooo0Ol00001ooooo`0000?o0000ooooooooool01_ooool2oomo0=Wooooo5Ooo000U
ooooo`7o00000Oooool00003o`000?oooooooooo00Gooooo1?ooO`0Cooooo`;oogl0`ooooolEool0
02Gooooo0Ol00001ooooo`0000?o0000ooooooooool01Oooool4oomo01;ooooo1?ooO`0Booooo`;o
ogl0[_oooolEool002Gooooo0Ol00001ooooo`0000?o0000ooooooooool01Oooool3oomo01?ooooo
1?ooO`0Aooooo`Coogl0[OoooolEool002Gooooo0Ol00001ooooo`0000?o0000ooooooooool01?oo
ool4oomo01Cooooo0_ooO`0Booooo`Coogl0[OoooolEool002Gooooo0Ol00001ooooo`0000?o0000
ooooooooool01?ooool4oomo02Wooooo0_ooO`2^oooooaGoo`009Oooool1o`00007ooooo00000ol0
003oooooooooo`05ooooo`;oogl0f_oooolEool002Gooooo0Ol00001ooooo`0000?o0000oooooooo
ool0hOoooolEool002Gooooo0Ol00001ooooo`0000?o0000ooooooooool0hOoooolEool002Gooooo
0Ol00001ooooo`0000?o0000ooooooooool0hOoooolEool002Gooooo0Ol00001ooooo`0000?o0000
ooooooooool0hOoooolEool002Gooooo0Ol00001ooooo`0000?o0000ooooooooool0hOoooolEool0
02Gooooo0Ol00001ooooo`0000?o0000ooooooooool0hOoooolEool002Gooooo0Ol00001ooooo`00
00?o0000ooooooooool0hOoooolEool002Gooooo0Ol00001ooooo`0000?o0000ooooooooool0:_oo
ool6ool00;7ooooo5Ooo000Uooooo`7o00000Oooool00003o`000?oooooooooo02Wooooo00?oo`00
ooooooooool01?ooool5ool00:cooooo5Ooo000Uooooo`7o00000Oooool00003o`000?oooooooooo
02Oooooo0_oo000<ooooo`Coo`00Z?oooolEool002Gooooo0Ol00001ooooo`0000?o0000oooooooo
ool09_ooool00ooo003oooooooooo`0@ooooo`Coo`00Y?oooolEool002Gooooo0Ol00001ooooo`00
00?o0000ooooooooool09?ooool00oooO`3oo`00ooooo`09ooooo`;oogl02oooool3ool00:7ooooo
5Ooo000Uooooo`7o00000Oooool00003o`000?oooooooooo02?ooooo00Coogl0ool00?ooO`3oogl0
2?ooool4oomo00gooooo00?oo`00ooooooooool0W_oooolEool002Gooooo0Ol00001ooooo`0000?o
0000ooooooooool08oooool01?ooO`3oo`00oomo0?ooO`08ooooo`Coogl03_ooool2ool009kooooo
5Ooo000Uooooo`7o00000Oooool00003o`000?oooooooooo02Cooooo00?oogl0ool00?ooool02Ooo
ool2oomo017ooooo0_oo0009ooooo`Goo`3oS_oooolEool002Gooooo0Ol00001ooooo`0000?o0000
ooooooooool09Oooool00ooo003oooooooooo`0Mooooo`;oo`001_ooool7ool0ohgooooo5Ooo000U
ooooo`7o00000Oooool00003o`000?oooooooooo02Gooooo00?oo`00ooooooooool07oooool2ool0
00?ooooo2Ooo0?n<oooooaGoo`009Oooool1o`00007ooooo00000ol0003oooooooooo`0Vooooo`03
ool00?oooooooooo017ooooo0_ooO`0=ooooo`;oo`002ooo0?l2ooooo`;oogl0QooooolEool002Go
oooo0Ol00001ooooo`0000?o0000ooooooooool09_ooool00ooo003oooooooooo`05ooooo`;oogl0
2Oooool4oomo00kooooo2ooo0?l00oooooooogl0oomo0002oomo08Kooooo5Ooo000Uooooo`7o0000
0Oooool00003o`000?oooooooooo02Kooooo00?oo`00ooooooooool01?ooool4oomo00Sooooo1?oo
O`0>ooooo`_oo`3o00?ooooooomo0?ooO`000_ooO`26oooooaGoo`009Oooool1o`00007ooooo0000
0ol0003oooooooooo`0Wooooo`03ool00?oooooooooo00?ooooo1?ooO`09ooooo`;oogl03oooool;
ool0o`;ooooo0oooO`26oooooaGoo`009Oooool1o`00007ooooo00000ol0003oooooooooo`0Woooo
o`03ool00?oooooooooo00Cooooo0_ooO`0Kooooo`_oo`3o0_ooool4oomo08Gooooo5Ooo000Uoooo
o`7o00000Oooool00003o`000?oooooooooo02Sooooo00?oo`00ooooooooool08Oooool9ool0o`?o
oooo1?ooO`25oooooaGoo`009Oooool1o`00007ooooo00000ol0003oooooooooo`0Yooooo`03ool0
0?oooooooooo027ooooo1ooo0?l00oooO`3oooooooooo`02ooooo`;oogl0Q_oooolEool002Gooooo
0Ol00001ooooo`0000?o0000ooooooooool0:_ooool00ooo003oooooooooo`0Cooooo`Coo`002_oo
ool5ool0o`?oogl0RooooolEool002Gooooo0Ol00001ooooo`0000?o0000ooooooooool0:oooool0
0ooo003oooooooooo`0Aooooo`Koo`003Oooool01?ooO`3oo`00ool00?ooO`2;oooooaGoo`009Ooo
ool1o`00007ooooo00000ol0003oooooooooo`0/ooooo`03ool00?oooooooooo00Sooooo0_ooO`05
ooooo`Soo`003Oooool2oomo0003ool00?oooooooooo08Wooooo5Ooo000Uooooo`7o00000Oooool0
0003o`000?oooooooooo02gooooo00?oo`00ooooooooool01_ooool4oomo00Cooooo2?oo000@oooo
o`03ool00?oooooooooo08Sooooo5Ooo000Uooooo`7o00000Oooool00003o`000?oooooooooo02_o
oooo0_ooO`000oooooooo`00ooooo`06ooooo`Coogl01?ooool8ool0017ooooo00?oo`00oooooooo
ool0QooooolEool002Gooooo0Ol00001ooooo`0000?o0000ooooooooool0:_ooool4oomo0003oooo
oooo003ooooo00Kooooo0_ooO`05ooooo`Soo`002oooool2oomo00Gooooo00?oo`00ooooooooool0
2Oooool2oomo07_ooooo5Ooo000Uooooo`7o00000Oooool00003o`000?oooooooooo02[ooooo1?oo
O`02ooooo`03ool00?oooooooooo00cooooo1_oo000;ooooo`Coogl01?ooool00ooo003ooooooooo
o`08ooooo`Coogl0N_oooolEool002Gooooo0Ol00001ooooo`0000?o0000ooooooooool0:oooool2
oomo00Cooooo00?oo`00ooooooooool03?ooool4ool000cooooo1?ooO`05ooooo`03ool00?oooooo
oooo00Oooooo1?ooO`1joooooaGoo`009Oooool1o`00007ooooo00000ol0003oooooooooo`0boooo
o`;oo`007Oooool2oomo00Oooooo00?oo`00ooooooooool01oooool2oomo0;Gooooo0Ol00001oooo
o`0000?o0000ooooooooool0=?ooool00ooo003oooooooooo`0Tooooo`03ool00?oooooooooo0;go
oooo0Ol00001ooooo`0000?o0000ooooooooool0=Oooool00ooo003oooooooooo`0Tooooo`03ool0
0?oooooooooo0;cooooo0Ol00001ooooo`0000?o0000ooooooooool0=_ooool2ool002Gooooo00?o
o`00ooooooooool0^oooool1o`00007ooooo00000ol0003oooooooooo`0hooooo`;oo`0000?oogl0
ooooooooool00_ooO`0Nooooo`03ool00?oooooooooo0;_ooooo0Ol00001ooooo`0000?o0000oooo
ooooool0>?ooool2oomo00;oo`001?ooO`0Nooooo`03ool00?oooooooooo0;[ooooo0Ol00001oooo
o`0000?o0000ooooooooool0>?ooool4oomo00;oo`000_ooO`0Nooooo`03ool00?oooooooooo0;[o
oooo0Ol00001ooooo`0000?o0000ooooooooool0>Oooool5oomo0003ool00?oooooooooo01gooooo
00?oo`00oomo0?ooO`00^_ooool1o`00007ooooo00000ol0003oooooooooo`0kooooo`Coogl00_oo
000Mooooo`04oomo0?oo003oogl0oomo0;Wooooo0Ol00001ooooo`0000?o0000ooooooooool0??oo
ool2oomo00?ooooo0_oo000Kooooo`04oomo0?oo003oogl0oomo0;Wooooo0Ol00001ooooo`0000?o
0000ooooooooool0@oooool2ool001[ooooo00?oogl0ool00?ooool0^Oooool1o`00007ooooo0000
0ol0003oooooooooo`15ooooo`;oo`006Oooool00ooo003oooooooooo`2hooooo`7o00000Oooool0
0003o`000?oooooooooo04Oooooo0_oo000Eooooo`;oo`00^oooool1o`00007ooooo00000ol0003o
ooooooooo`19ooooo`?oo`004?ooool2ool00;gooooo0Ol00001ooooo`0000?o0000ooooooooool0
<Oooool2oomo01Wooooo0ooo000<ooooo`03ool00?oooooooooo0;gooooo0Ol00001ooooo`0000?o
0000ooooooooool0<?ooool4oomo01_ooooo1_oo0004ooooo`;oo`00`?ooool1o`00007ooooo0000
0ol0003oooooooooo`0`ooooo`Coogl08Oooool4ool00<;ooooo0Ol00001ooooo`0000?o0000oooo
ooooool0<Oooool2oomo0>Sooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o
00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003ooooooooo
o`3ooooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool0
0003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003oooooooooo`1mooooo`;o
ogl0W?ooool1o`00007ooooo00000ol0003oooooooooo`1looooo`Coogl0Voooool1o`00007ooooo
00000ol0003oooooooooo`1Dooooo`;oogl09_ooool4oomo09_ooooo0Ol00001ooooo`0000?o0000
ooooooooool0Doooool4oomo02Kooooo0_ooO`2Looooo`7o00000Oooool00003o`000?oooooooooo
05?ooooo1?ooO`34ooooo`7o00000Oooool00003o`000?oooooooooo05Cooooo0_ooO`35ooooo`7o
00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003ooooooooo
o`1Sooooo`;oogl01?ooool2oomo0;3ooooo0Ol00001ooooo`0000?o0000ooooooooool0H_ooool4
oomo00;ooooo1?ooO`2_ooooo`7o00000Oooool00003o`000?oooooooooo06;ooooo1?ooO`02oooo
o`Coogl0[oooool1o`00007ooooo00000ol0003oooooooooo`1Sooooo`;oogl01?ooool2oomo0;3o
oooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oo
oooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001
ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo0?oo
oooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o
0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1
o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000oooooooo
ool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo
00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolL
ooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003o
ooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o0000
0Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3o
oooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003
o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo
0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oooooo
oooo0?oooooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001oooo
o`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo
7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000
ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00
007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0
oooooolLooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo0000
0ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0ooooool4oooo
o`;oogl05_ooool1o`00007ooooo00000ol0003oooooooooo`3oooooo`?ooooo1?ooO`0Eooooo`7o
00000Oooool00003o`000?oooooooooo0?oooooo0oooool4oomo01Gooooo0Ol00001ooooo`0000?o
0000ooooooooool0ooooool4ooooo`;oogl05_ooool1o`00007ooooo00000ol0003oooooooooo`3o
oooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003
o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo
0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oooooo
oooo0?oooooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001oooo
o`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo
7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000
ooooooooool0]Oooool2oomo06Cooooo0Ol00001ooooo`0000?o0000ooooooooool0]?ooool4oomo
06?ooooo0Ol00001ooooo`0000?o0000ooooooooool0]?ooool4oomo06?ooooo0Ol00001ooooo`00
00?o0000ooooooooool0]Oooool2oomo03Gooooo0_ooO`0]ooooo`7o00000Oooool00003o`000?oo
oooooooo0>Cooooo0_ooO`05ooooo`Coogl0;?ooool1o`00007ooooo00000ol0003oooooooooo`3S
ooooo`Coogl01?ooool4oomo02cooooo0Ol00001ooooo`0000?o0000ooooooooool0`oooool2oomo
01kooooo1?ooO`05ooooo`;oogl0;Oooool1o`00007ooooo00000ol0003oooooooooo`32ooooo`Co
ogl02ol00?lCooooo`;oogl0=Oooool1o`00007ooooo00000ol0003oooooooooo`32ooooo`Co003o
2oooool2o`00odSooooo0Ol00001ooooo`0000?o0000ooooooooool0__ooool4o`00o`03oooooooo
O`3oogl000kooooo0_l00?m6ooooo`7o00000Oooool00003o`000?oooooooooo0;Wooooo0_ooO`03
o`00oaOooooo0_l00?l9ooooo`;oogl0>Oooool1o`00007ooooo00000ol0003oooooooooo`2goooo
o`Co003o00?oogl0ooooooooool06Oooool2o`00o`Kooooo1?ooO`0hooooo`7o00000Oooool00003
o`000?oooooooooo0;Cooooo0ol00?l00oooooooogl0oomo0002oomo01cooooo00?o003ooooooooo
ool01?ooool4oomo00?ooooo0_ooO`0cooooo`7o00000Oooool00003o`000?oooooooooo0;;ooooo
0_l00?l3oomo00;ooooo0_ooO`0Cooooo`;oogl02?ooool00ol00?ooooooooooo`05ooooo`;oogl0
0oooool4oomo03;ooooo0Ol00001ooooo`0000?o0000ooooooooool0/?ooool2o`00o`03oooooooo
O`3oogl000;oogl01_ooool2oomo00kooooo1?ooO`07ooooo`03o`00oooooooooooo00[ooooo1?oo
O`0booooo`7o00000Oooool00003o`000?oooooooooo0:kooooo0_l00?l4ooooo`;oogl01_ooool4
oomo00gooooo1?ooO`07ooooo`03o`00oooooooooooo00_ooooo0_ooO`0cooooo`7o00000Oooool0
0003o`000?oooooooooo08_ooooo0_ooO`0Pooooo`03o`00oooooooooooo00Cooooo0_ooO`06oooo
o`Coogl03_ooool2oomo00Wooooo00?o003oooooooooool0?oooool1o`00007ooooo00000ol0003o
ooooooooo`2:ooooo`Coogl07Oooool2o`00o`Kooooo1?ooO`06ooooo`;oogl06_ooool00ol00?oo
ooooooooo`0oooooo`7o00000Oooool00003o`000?oooooooooo08[ooooo1?ooO`0Looooo`03o`00
oooooooooooo00Kooooo1?ooO`0Rooooo`03o`00oooooooooooo03oooooo0Ol00001ooooo`0000?o
0000ooooooooool0Roooool2oomo01_ooooo0_l00?l:ooooo`;oogl08oooool00ol00?oooooooooo
o`0oooooo`7o00000Oooool00003o`000?oooooooooo09Kooooo0_ooO`0>ooooo`;o003o:_ooool2
oomo00Gooooo00?o003oooooooooool0?oooool1o`00007ooooo00000ol0003oooooooooo`2Eoooo
o`Coogl03?ooool01?l00?oooooooomo0?ooO`0Xooooo`Coogl00oooool00ol00?ooooooooooo`10
ooooo`7o00000Oooool00003o`000?oooooooooo09Gooooo1?ooO`0:ooooo`;o003o00?ooooooomo
0?ooO`000_ooO`0Wooooo`Coogl00oooool00ol00?ooooooooooo`10ooooo`7o00000Oooool00003
o`000?oooooooooo09Kooooo0_ooO`0:ooooo`04o`00ooooooooooooooooo`Coogl0:?ooool2oomo
00Cooooo00?o003oooooooooool0@?ooool1o`00007ooooo00000ol0003oooooooooo`2Qooooo`03
o`00oooooooooooo00?ooooo0_ooO`0^ooooo`03o`00oooooooooooo047ooooo0Ol00001ooooo`00
00?o0000ooooooooool0X?ooool00ol00?ooooooooooo`0cooooo`03o`00oooooooooooo01;ooooo
0_ooO`0^ooooo`7o00000Oooool00003o`000?oooooooooo09kooooo0_l00?leooooo`03o`00oooo
oooooooo01;ooooo1?ooO`0]ooooo`7o00000Oooool00003o`000?oooooooooo09gooooo00?o003o
ooooooooool05Oooool4o`00oacooooo00?o003ooomo0?ooO`004_ooool4oomo02gooooo0Ol00001
ooooo`0000?o0000ooooooooool0W?ooool00ol00?ooooooooooo`0Eooooo`Ko003o6_ooool00ol0
0?ooogl0oomo0002oomo01;ooooo0_ooO`0^ooooo`7o00000Oooool00003o`000?oooooooooo09_o
oooo00?o003oooooooooool05Oooool8o`00oaSooooo00?o003oooooooooO`000oooO`12ooooo`7o
00000Oooool00003o`000?oooooooooo09_ooooo00?o003oooooooooool05Oooool8o`00oaOooooo
00Co003ooooooooooooooooo0_ooO`13ooooo`7o00000Oooool00003o`000?oooooooooo09[ooooo
00?o003oooooooooool05_ooool8o`00oaKooooo00?o003oooooooooool0Aoooool1o`00007ooooo
00000ol0003oooooooooo`2Iooooo`03o`00oooooooooooo00cooooo0_ooO`08ooooo`03oomo0?l0
0?oo003o00Ko003o5Oooool00ol00?ooooooooooo`02oomo04Kooooo0Ol00001ooooo`0000?o0000
ooooooooool0VOooool00ol00?ooooooooooo`0:ooooo`Googl01oooool2oomo00Ko003o4oooool2
oomo0003o`00oooooooooooo00Coogl0AOooool1o`00007ooooo00000ol0003oooooooooo`2Hoooo
o`03o`00oooooooooooo00[ooooo1_ooO`08ooooo`;oogl01?l00?lCooooo`;oogl00_l00?l2oooo
o`Coogl0AOooool1o`00007ooooo00000ol0003oooooooooo`2Hooooo`03o`00oooooooooooo00[o
oooo1OooO`0Rooooo`04oomo0?l00?ooogl0oomo00?ooooo0_ooO`16ooooo`7o00000Oooool00003
o`000?oooooooooo07Kooooo0_ooO`0Oooooo`03o`00oooooooooooo00cooooo0_ooO`0Tooooo`03
o`00ooooO`3oogl004cooooo0Ol00001ooooo`0000?o0000ooooooooool0MOooool4oomo01kooooo
00?o003oooooooooool0<Oooool00ol00?ooooooooooo`1=ooooo`7o00000Oooool00003o`000?oo
oooooooo07Gooooo1?ooO`0:ooooo`;oogl04Oooool00ol00?ooooooooooo`0aooooo`03o`00oooo
oooooooo04kooooo0Ol00001ooooo`0000?o0000ooooooooool0M_ooool2oomo00[ooooo1?ooO`0?
ooooo`03o`00oooooooooooo01Sooooo0_ooO`0Gooooo`03o`00oooooooooooo04oooooo0Ol00001
ooooo`0000?o0000ooooooooool0P_ooool4oomo00oooooo00?o003oooooooooool05oooool4oomo
01Cooooo0_l00?mBooooo`7o00000Oooool00003o`000?oooooooooo08?ooooo0_ooO`0?ooooo`03
o`00oooooooooooo01;ooooo0_ooO`04ooooo`Coogl04Oooool3o`00oeCooooo0Ol00001ooooo`00
00?o0000ooooooooool0U?ooool00ol00?ooooooooooo`0Aooooo`Coogl01?ooool2oomo013ooooo
0_l00?mGooooo`7o00000Oooool00003o`000?oooooooooo09Cooooo00?o003oooooooooool04Ooo
ool4oomo01Gooooo00?o003oooooooooool0Eoooool1o`00007ooooo00000ol0003oooooooooo`2D
ooooo`03o`00oooooooooooo01;ooooo0_ooO`0Dooooo`;o003oF_ooool1o`00007ooooo00000ol0
003oooooooooo`2Dooooo`03o`00oooooooooooo02Kooooo0_l00?mLooooo`7o00000Oooool00003
o`000?oooooooooo09Gooooo00?o003oooooooooool09?ooool00ol00?ooooooooooo`1Looooo`7o
00000Oooool00003o`000?oooooooooo09Gooooo00?o003oooooooooool08_ooool2o`00oeoooooo
0Ol00001ooooo`0000?o0000ooooooooool0UOooool00ol00?ooooooooooo`0Pooooo`;o003oHOoo
ool1o`00007ooooo00000ol0003oooooooooo`24ooooo`;oogl03oooool2o`00oaoooooo0_l00?mS
ooooo`7o00000Oooool00003o`000?oooooooooo08?ooooo1?ooO`0@ooooo`;o003o6_ooool3o`00
ofGooooo0Ol00001ooooo`0000?o0000ooooooooool0Poooool4oomo01;ooooo0_l00?lDooooo`Co
003oJ?ooool1o`00007ooooo00000ol0003oooooooooo`24ooooo`;oogl05Oooool3o`00o`kooooo
0ol00?l3ooooo`;oogl0Ioooool1o`00007ooooo00000ol0003oooooooooo`2Nooooo`?o003o1Ooo
ool6o`00o`Gooooo1?ooO`1Vooooo`7o00000Oooool00003o`000?oooooooooo0:7ooooo1Ol00?l;
ooooo`Coogl0I_ooool1o`00007ooooo00000ol0003oooooooooo`2booooo`;oogl0Ioooool1o`00
007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0
oooooolLooooo`7o00000Oooool00003o`000?oooooooooo07_ooooo0_ooO`2Nooooo`7o00000Ooo
ool00003o`000?oooooooooo07[ooooo1?ooO`2Mooooo`7o00000Oooool00003o`000?oooooooooo
07[ooooo1?ooO`0Pooooo`;oogl0Noooool1o`00007ooooo00000ol0003oooooooooo`1kooooo`;o
ogl08?ooool4oomo07[ooooo0Ol00001ooooo`0000?o0000ooooooooool0WOooool4oomo07[ooooo
0Ol00001ooooo`0000?o0000ooooooooool0T?ooool2oomo00cooooo0_ooO`1kooooo`7o00000Ooo
ool00003o`000?oooooooooo08oooooo1?ooO`28ooooo`7o00000Oooool00003o`000?oooooooooo
08oooooo1?ooO`28ooooo`7o00000Oooool00003o`000?oooooooooo093ooooo0_ooO`0Sooooo`;o
ogl0I?ooool1o`00007ooooo00000ol0003oooooooooo`2dooooo`Coogl0Hoooool1o`00007ooooo
00000ol0003oooooooooo`2dooooo`Coogl0Hoooool1o`00007ooooo00000ol0003oooooooooo`2e
ooooo`;oogl0I?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001oooo
o`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo
7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000
ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00
007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0
oooooolLooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo0000
0ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLoooo
o`7o00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003ooooo
ooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Ooo
ool00003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooo
oacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`00
0?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol0
0001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo
0?oooooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`00
00?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?oo
ool1o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000oooo
ooooool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007o
oooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooo
oolLooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0
003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o
00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003ooooooooo
o`3ooooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool0
0003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooooaco
oooo0Ol00001ooooo`0000?o0000ooooooooool0S_ooool2oomo08_ooooo0Ol00001ooooo`0000?o
0000ooooooooool0SOooool4oomo08[ooooo0Ol00001ooooo`0000?o0000ooooooooool0SOooool4
oomo08[ooooo0Ol00001ooooo`0000?o0000ooooooooool0S_ooool2oomo08_ooooo0Ol00001oooo
o`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo
7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000
ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00
007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0
oooooolLooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo0000
0ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLoooo
o`7o00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003ooooo
ooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Ooo
ool00003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooo
oacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`00
0?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol0
0001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo
0?oooooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`00
ool0000Po`00007ooooo0000\
\>"],
  ImageRangeCache->{{{0, 287}, {287, 0}} -> {-1.01089, -1.01089, 0.00704453, \
0.00704453}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.49505 0.5 0.49505 [
[ 0 0 -0.125 0 ]
[ 0 0 -0.125 0 ]
[ 0 1 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
0 0 m
1 0 L
s
0 0 m
0 1 L
s
0 1 m
1 1 L
s
1 0 m
1 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
1 .5 0 r
.015 w
.03175 .1355 Mdot
.03435 .12523 Mdot
.11137 .12765 Mdot
.14107 .18841 Mdot
.16218 .24538 Mdot
.17294 .21053 Mdot
.18267 .18577 Mdot
.18434 .1304 Mdot
.18553 .30956 Mdot
.20401 .239 Mdot
.21247 .27571 Mdot
.21687 .20845 Mdot
.22376 .2799 Mdot
.22832 .27485 Mdot
.29063 .20974 Mdot
.29686 .25079 Mdot
.30487 .22936 Mdot
.30683 .34623 Mdot
.32055 .20902 Mdot
.32574 .21979 Mdot
.34472 .28521 Mdot
.35998 .36393 Mdot
.36335 .24976 Mdot
.3794 .36608 Mdot
.42386 .66992 Mdot
.44391 .74519 Mdot
.45059 .34198 Mdot
.47208 .67586 Mdot
.47436 .71381 Mdot
.49778 .59825 Mdot
.50874 .91643 Mdot
.51516 .76219 Mdot
.53655 .61374 Mdot
.56563 .75219 Mdot
.59189 .65665 Mdot
.59581 .61604 Mdot
.59923 .6556 Mdot
.60292 .68499 Mdot
.62656 .67779 Mdot
.63555 .72451 Mdot
.63919 .652 Mdot
.64169 .6004 Mdot
.64246 .58611 Mdot
.64496 .54267 Mdot
.64608 .77288 Mdot
.65077 .64308 Mdot
.66065 .57816 Mdot
.67474 .59169 Mdot
.69296 .563 Mdot
.72815 .65902 Mdot
.73169 .58879 Mdot
.74669 .61318 Mdot
.74821 .65474 Mdot
.75963 .63781 Mdot
.79673 .57809 Mdot
.80925 .55852 Mdot
.81525 .58444 Mdot
.83417 .62985 Mdot
.83598 .55526 Mdot
.91595 .49319 Mdot
1 0 0 r
.005 w
.16128 .17044 m
.18734 .17269 L
.21339 .17909 L
.2345 .18734 L
.23945 .19126 L
.2655 .20415 L
.27874 .21339 L
.29156 .22295 L
.31204 .23945 L
.31761 .24532 L
.33549 .2655 L
.34367 .28341 L
.34499 .29156 L
.34367 .29798 L
.31761 .3104 L
.29156 .30711 L
.2655 .30014 L
.24507 .29156 L
.23945 .28747 L
.21339 .27402 L
.20155 .2655 L
.18734 .25472 L
.16884 .23945 L
.16128 .2313 L
.14618 .21339 L
.13806 .18734 L
.16128 .17044 L
s
0 0 1 r
.65633 .57701 m
.68239 .56842 L
.70844 .56313 L
.7345 .56168 L
.76055 .5752 L
.76359 .57817 L
.76859 .60422 L
.76055 .62333 L
.75627 .63028 L
.7345 .65485 L
.73298 .65633 L
.70844 .6775 L
.69922 .68239 L
.68239 .69294 L
.65633 .70579 L
.64983 .70844 L
.63028 .71539 L
.60422 .72268 L
.57817 .72651 L
.55211 .7214 L
.53145 .70844 L
.52926 .68239 L
.54239 .65633 L
.55211 .63983 L
.56625 .63028 L
.57817 .6193 L
.60119 .60422 L
.60422 .60227 L
.63028 .58726 L
.65315 .57817 L
.65633 .57701 L
s
1 0 0 r
.03 w
.24141 .24033 Mdot
0 0 1 r
.64872 .64417 Mdot
1 0 0 r
.79703 .00495 m
.79703 .25248 L
.87129 .25248 L
.87129 .00495 L
F
0 0 1 r
.89604 .00495 m
.89604 .00495 L
.9703 .00495 L
.9703 .00495 L
F
1 0 1 r
.04 w
.29686 .25079 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P000182000`400?l00000o`00003ooooooolQ
ooooo`00ool0000Po`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`00
00?o0000ooooooooool0hOoooolEool002Gooooo0Ol00001ooooo`0000?o0000ooooooooool0hOoo
oolEool002Gooooo0Ol00001ooooo`0000?o0000ooooooooool0hOoooolEool002Gooooo0Ol00001
ooooo`0000?o0000ooooooooool0hOoooolEool002Gooooo0Ol00001ooooo`0000?o0000oooooooo
ool0hOoooolEool002Gooooo0Ol00001ooooo`0000?o0000ooooooooool0hOoooolEool002Gooooo
0Ol00001ooooo`0000?o0000ooooooooool0hOoooolEool002Gooooo0Ol00001ooooo`0000?o0000
ooooooooool0hOoooolEool002Gooooo0Ol00001ooooo`0000?o0000ooooooooool0hOoooolEool0
02Gooooo0Ol00001ooooo`0000?o0000ooooooooool0hOoooolEool002Gooooo0Ol00001ooooo`00
00?o0000ooooooooool0hOoooolEool002Gooooo0Ol00001ooooo`0000?o0000ooooooooool0hOoo
oolEool002Gooooo0Ol00001ooooo`0000?o0000ooooooooool0hOoooolEool002Gooooo0Ol00001
ooooo`0000?o0000ooooooooool0hOoooolEool002Gooooo0Ol00001ooooo`0000?o0000oooooooo
ool0hOoooolEool002Gooooo0Ol00001ooooo`0000?o0000ooooooooool0hOoooolEool002Gooooo
0Ol00001ooooo`0000?o0000ooooooooool0hOoooolEool002Gooooo0Ol00001ooooo`0000?o0000
ooooooooool0hOoooolEool002Gooooo0Ol00001ooooo`0000?o0000ooooooooool0hOoooolEool0
02Gooooo0Ol00001ooooo`0000?o0000ooooooooool0hOoooolEool002Gooooo0Ol00001ooooo`00
00?o0000ooooooooool0hOoooolEool002Gooooo0Ol00001ooooo`0000?o0000ooooooooool0hOoo
oolEool002Gooooo0Ol00001ooooo`0000?o0000ooooooooool0hOoooolEool002Gooooo0Ol00001
ooooo`0000?o0000ooooooooool0hOoooolEool002Gooooo0Ol00001ooooo`0000?o0000oooooooo
ool0hOoooolEool002Gooooo0Ol00001ooooo`0000?o0000ooooooooool0hOoooolEool002Gooooo
0Ol00001ooooo`0000?o0000ooooooooool0hOoooolEool002Gooooo0Ol00001ooooo`0000?o0000
ooooooooool0hOoooolEool002Gooooo0Ol00001ooooo`0000?o0000ooooooooool0hOoooolEool0
02Gooooo0Ol00001ooooo`0000?o0000ooooooooool0hOoooolEool002Gooooo0Ol00001ooooo`00
00?o0000ooooooooool0hOoooolEool002Gooooo0Ol00001ooooo`0000?o0000ooooooooool0hOoo
oolEool002Gooooo0Ol00001ooooo`0000?o0000ooooooooool01_ooool2oomo0=Wooooo5Ooo000U
ooooo`7o00000Oooool00003o`000?oooooooooo00Gooooo1?ooO`0Cooooo`;oogl0`ooooolEool0
02Gooooo0Ol00001ooooo`0000?o0000ooooooooool01Oooool4oomo01;ooooo1?ooO`0Booooo`;o
ogl0[_oooolEool002Gooooo0Ol00001ooooo`0000?o0000ooooooooool01Oooool3oomo01?ooooo
1?ooO`0Aooooo`Coogl0[OoooolEool002Gooooo0Ol00001ooooo`0000?o0000ooooooooool01?oo
ool4oomo01Cooooo0_ooO`0Booooo`Coogl0[OoooolEool002Gooooo0Ol00001ooooo`0000?o0000
ooooooooool01?ooool4oomo02Wooooo0_ooO`2^oooooaGoo`009Oooool1o`00007ooooo00000ol0
003oooooooooo`05ooooo`;oogl0f_oooolEool002Gooooo0Ol00001ooooo`0000?o0000oooooooo
ool0hOoooolEool002Gooooo0Ol00001ooooo`0000?o0000ooooooooool0hOoooolEool002Gooooo
0Ol00001ooooo`0000?o0000ooooooooool0hOoooolEool002Gooooo0Ol00001ooooo`0000?o0000
ooooooooool0hOoooolEool002Gooooo0Ol00001ooooo`0000?o0000ooooooooool0hOoooolEool0
02Gooooo0Ol00001ooooo`0000?o0000ooooooooool0hOoooolEool002Gooooo0Ol00001ooooo`00
00?o0000ooooooooool0hOoooolEool002Gooooo0Ol00001ooooo`0000?o0000ooooooooool0:_oo
ool6ool00;7ooooo5Ooo000Uooooo`7o00000Oooool00003o`000?oooooooooo02Wooooo00?oo`00
ooooooooool01?ooool5ool00:cooooo5Ooo000Uooooo`7o00000Oooool00003o`000?oooooooooo
02Oooooo0_oo000<ooooo`Coo`00Z?oooolEool002Gooooo0Ol00001ooooo`0000?o0000oooooooo
ool09_ooool00ooo003oooooooooo`0@ooooo`Coo`00Y?oooolEool002Gooooo0Ol00001ooooo`00
00?o0000ooooooooool09?ooool00oooO`3oo`00ooooo`09ooooo`;oogl02oooool3ool00:7ooooo
5Ooo000Uooooo`7o00000Oooool00003o`000?oooooooooo02?ooooo00Coogl0ool00?ooO`3oogl0
2?ooool4oomo00gooooo00?oo`00ooooooooool0W_oooolEool002Gooooo0Ol00001ooooo`0000?o
0000ooooooooool08oooool01?ooO`3oo`00oomo0?ooO`08ooooo`Coogl03_ooool2ool009kooooo
5Ooo000Uooooo`7o00000Oooool00003o`000?oooooooooo02Cooooo00?oogl0ool00?ooool02Ooo
ool2oomo017ooooo0_oo002LoooooaGoo`009Oooool1o`00007ooooo00000ol0003oooooooooo`0U
ooooo`03ool00?oooooooooo01gooooo0_oo002JoooooaGoo`009Oooool1o`00007ooooo00000ol0
003oooooooooo`0Uooooo`03ool00?oooooooooo01oooooo0_oo002HoooooaGoo`009Oooool1o`00
007ooooo00000ol0003oooooooooo`0Vooooo`03ool00?oooooooooo017ooooo0_ooO`0=ooooo`;o
o`001?ooool2oomo00Oooooo0_ooO`27oooooaGoo`009Oooool1o`00007ooooo00000ol0003ooooo
ooooo`0Vooooo`03ool00?oooooooooo00Gooooo0_ooO`09ooooo`Coogl03_ooool00ooo003ooooo
ooooo`04oomo00Gooooo1?ooO`26oooooaGoo`009Oooool1o`00007ooooo00000ol0003ooooooooo
o`0Vooooo`03ool00?oooooooooo00Cooooo1?ooO`08ooooo`Coogl03oooool00ooo003ooooooomo
0003oomo00Gooooo1?ooO`26oooooaGoo`009Oooool1o`00007ooooo00000ol0003oooooooooo`0W
ooooo`03ool00?oooooooooo00?ooooo1?ooO`09ooooo`;oogl04Oooool01?oo003ooooooomo0?oo
O`07ooooo`?oogl0Q_oooolEool002Gooooo0Ol00001ooooo`0000?o0000ooooooooool09oooool0
0ooo003oooooooooo`04ooooo`;oogl07_ooool00ooo003oooooooooo`07ooooo`Coogl0QOoooolE
ool002Gooooo0Ol00001ooooo`0000?o0000ooooooooool0:?ooool00ooo003oooooooooo`0Toooo
o`03ool00?oooooooooo00Kooooo1?ooO`25oooooaGoo`009Oooool1o`00007ooooo00000ol0003o
ooooooooo`0Yooooo`03ool00?oooooooooo02Cooooo0_oo00000oooooooogl0oomo0004ooooo`;o
ogl0Q_oooolEool002Gooooo0Ol00001ooooo`0000?o0000ooooooooool0:_ooool00ooo003ooooo
ooooo`0Cooooo`Coo`003_ooool01?oo003oogl0oomo0?ooO`2;oooooaGoo`009Oooool1o`00007o
oooo00000ol0003oooooooooo`0[ooooo`03ool00?oooooooooo017ooooo1_oo000=ooooo`04oomo
0?oo003oo`00oomo08_ooooo5Ooo000Uooooo`7o00000Oooool00003o`000?oooooooooo02cooooo
00?oo`00ooooooooool02?ooool2oomo00Gooooo2?oo000:ooooo`Goo`3o00?oo`00ooooooooool0
ROoooolEool002Gooooo0Ol00001ooooo`0000?o0000ooooooooool0;Oooool00ooo003ooooooooo
o`06ooooo`Coogl01?ooool8ool000Wooooo1ooo0?l00ooo003oooooooooo`28oooooaGoo`009Ooo
ool1o`00007ooooo00000ol0003oooooooooo`0[ooooo`;oogl000?oooooool00?ooool01_ooool4
oomo00Cooooo2?oo0008ooooo`Woo`3o00?oo`00ooooooooool0QooooolEool002Gooooo0Ol00001
ooooo`0000?o0000ooooooooool0:_ooool4oomo0003oooooooo003ooooo00Kooooo0_ooO`05oooo
o`Soo`001oooool;ool0o`03ool00?oooooooooo00Wooooo0_ooO`1koooooaGoo`009Oooool1o`00
007ooooo00000ol0003oooooooooo`0Zooooo`Coogl00_ooool00ooo003oooooooooo`0<ooooo`Ko
o`002?ooool;ool0o`03ool00?oooooooooo00Sooooo1?ooO`1joooooaGoo`009Oooool1o`00007o
oooo00000ol0003oooooooooo`0[ooooo`;oogl01?ooool00ooo003oooooooooo`0<ooooo`Coo`00
2Oooool;ool0o`03oooooooo003ooooo00Sooooo1?ooO`1joooooaGoo`009Oooool1o`00007ooooo
00000ol0003oooooooooo`0booooo`;oo`006Oooool;ool0o`;ooooo00?oo`00ooooooooool01ooo
ool2oomo0;Gooooo0Ol00001ooooo`0000?o0000ooooooooool0=?ooool00ooo003oooooooooo`0F
ooooo`_oo`3o0oooool00ooo003oooooooooo`2mooooo`7o00000Oooool00003o`000?oooooooooo
03Gooooo00?oo`00ooooooooool05_ooool9ool0o`Gooooo00?oo`00ooooooooool0_?ooool1o`00
007ooooo00000ol0003oooooooooo`0fooooo`;oo`005oooool7ool0o`Oooooo00?oo`00oooooooo
ool0^oooool1o`00007ooooo00000ol0003oooooooooo`0hooooo`;oo`0000?oogl0ooooooooool0
0_ooO`0Aooooo`Goo`3o2?ooool00ooo003oooooooooo`2kooooo`7o00000Oooool00003o`000?oo
oooooooo03Sooooo0_ooO`02ool000Coogl07_ooool00ooo003oooooooooo`2jooooo`7o00000Ooo
ool00003o`000?oooooooooo03Sooooo1?ooO`02ool000;oogl07_ooool00ooo003oooooooooo`2j
ooooo`7o00000Oooool00003o`000?oooooooooo03Wooooo1OooO`000ooo003oooooooooo`0Moooo
o`03ool00?ooO`3oogl00;[ooooo0Ol00001ooooo`0000?o0000ooooooooool0>oooool4oomo00;o
o`007Oooool01?ooO`3oo`00oomo0?ooO`2iooooo`7o00000Oooool00003o`000?oooooooooo03co
oooo0_ooO`03ooooo`;oo`006oooool01?ooO`3oo`00oomo0?ooO`2iooooo`7o00000Oooool00003
o`000?oooooooooo04?ooooo0_oo000Jooooo`03oomo0?oo003ooooo0;Wooooo0Ol00001ooooo`00
00?o0000ooooooooool0AOooool2ool001Wooooo00?oo`00ooooooooool0^?ooool1o`00007ooooo
00000ol0003oooooooooo`17ooooo`;oo`005Oooool2ool00;_ooooo0Ol00001ooooo`0000?o0000
ooooooooool0BOooool3ool0013ooooo0_oo002mooooo`7o00000Oooool00003o`000?oooooooooo
037ooooo0_ooO`0Iooooo`?oo`003?ooool00ooo003oooooooooo`2mooooo`7o00000Oooool00003
o`000?oooooooooo033ooooo1?ooO`0Kooooo`Koo`001?ooool2ool00<3ooooo0Ol00001ooooo`00
00?o0000ooooooooool0<?ooool4oomo027ooooo1?oo0032ooooo`7o00000Oooool00003o`000?oo
oooooooo037ooooo0_ooO`3Xooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1
o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000oooooooo
ool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo
00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0OOooool2
oomo09cooooo0Ol00001ooooo`0000?o0000ooooooooool0O?ooool4oomo09_ooooo0Ol00001oooo
o`0000?o0000ooooooooool0E?ooool2oomo02Kooooo1?ooO`2Kooooo`7o00000Oooool00003o`00
0?oooooooooo05?ooooo1?ooO`0Vooooo`;oogl0W?ooool1o`00007ooooo00000ol0003ooooooooo
o`1Cooooo`Coogl0a?ooool1o`00007ooooo00000ol0003oooooooooo`1Dooooo`;oogl0aOooool1
o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000oooooooo
ool0Hoooool2oomo00Cooooo0_ooO`2`ooooo`7o00000Oooool00003o`000?oooooooooo06;ooooo
1?ooO`02ooooo`Coogl0[oooool1o`00007ooooo00000ol0003oooooooooo`1Rooooo`Coogl00_oo
ool4oomo0:oooooo0Ol00001ooooo`0000?o0000ooooooooool0Hoooool2oomo00Cooooo0_ooO`2`
ooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003o
ooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o0000
0Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3o
oooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003
o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo
0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oooooo
oooo0?oooooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001oooo
o`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo
7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000
ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00
007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0
oooooolLooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo0000
0ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLoooo
o`7o00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003ooooo
ooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Ooo
ool00003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooo
oacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`00
0?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol0
0001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo
0?oooooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`00
00?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo1?oo
ool2oomo01Kooooo0Ol00001ooooo`0000?o0000ooooooooool0ooooool3ooooo`Coogl05Oooool1
o`00007ooooo00000ol0003oooooooooo`3oooooo`?ooooo1?ooO`0Eooooo`7o00000Oooool00003
o`000?oooooooooo0?oooooo1?ooool2oomo01Kooooo0Ol00001ooooo`0000?o0000ooooooooool0
oooooolLooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo0000
0ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLoooo
o`7o00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003ooooo
ooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Ooo
ool00003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooo
oacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`00
0?oooooooooo0;Gooooo0_ooO`1Tooooo`7o00000Oooool00003o`000?oooooooooo0;Cooooo1?oo
O`1Sooooo`7o00000Oooool00003o`000?oooooooooo0;Cooooo1?ooO`1Sooooo`7o00000Oooool0
0003o`000?oooooooooo0;Gooooo0_ooO`0eooooo`;oogl0;Oooool1o`00007ooooo00000ol0003o
ooooooooo`3Tooooo`;oogl01Oooool4oomo02cooooo0Ol00001ooooo`0000?o0000ooooooooool0
hoooool4oomo00Cooooo1?ooO`0/ooooo`7o00000Oooool00003o`000?oooooooooo0<?ooooo0_oo
O`0Nooooo`Coogl01Oooool2oomo02gooooo0Ol00001ooooo`0000?o0000ooooooooool0`_ooool4
oomo00_o003o4oooool2oomo03Gooooo0Ol00001ooooo`0000?o0000ooooooooool0`_ooool4o`00
o`_ooooo0_l00?m8ooooo`7o00000Oooool00003o`000?oooooooooo0;kooooo1?l00?l00ooooooo
ogl0oomo000>ooooo`;o003oA_ooool1o`00007ooooo00000ol0003oooooooooo`2iooooo`;oogl0
0ol00?lGooooo`;o003o2Oooool2oomo03Wooooo0Ol00001ooooo`0000?o0000ooooooooool0]ooo
ool4o`00o`03oomo0?oooooooooo01Wooooo0_l00?l6ooooo`Coogl0>?ooool1o`00007ooooo0000
0ol0003oooooooooo`2dooooo`?o003o00?ooooooomo0?ooO`000_ooO`0Looooo`03o`00oooooooo
oooo00Cooooo1?ooO`03ooooo`;oogl0<oooool1o`00007ooooo00000ol0003oooooooooo`2boooo
o`;o003o0oooO`02ooooo`;oogl04oooool2oomo00Sooooo00?o003oooooooooool01Oooool2oomo
00?ooooo1?ooO`0booooo`7o00000Oooool00003o`000?oooooooooo0;3ooooo0_l00?l00ooooooo
ogl0oomo0002oomo00Kooooo0_ooO`0>ooooo`Coogl01oooool00ol00?ooooooooooo`0:ooooo`Co
ogl0<_ooool1o`00007ooooo00000ol0003oooooooooo`2^ooooo`;o003o1?ooool2oomo00Kooooo
1?ooO`0=ooooo`Coogl01oooool00ol00?ooooooooooo`0;ooooo`;oogl0<oooool1o`00007ooooo
00000ol0003oooooooooo`2;ooooo`;oogl08?ooool00ol00?ooooooooooo`04ooooo`;oogl01_oo
ool4oomo00kooooo0_ooO`09ooooo`03o`00oooooooooooo03oooooo0Ol00001ooooo`0000?o0000
ooooooooool0R_ooool4oomo01gooooo0_l00?l6ooooo`Coogl01_ooool2oomo01[ooooo00?o003o
ooooooooool0?oooool1o`00007ooooo00000ol0003oooooooooo`2:ooooo`Coogl07?ooool00ol0
0?ooooooooooo`06ooooo`Coogl08_ooool00ol00?ooooooooooo`0oooooo`7o00000Oooool00003
o`000?oooooooooo08_ooooo0_ooO`0Kooooo`;o003o2_ooool2oomo02?ooooo00?o003ooooooooo
ool0?oooool1o`00007ooooo00000ol0003oooooooooo`2Fooooo`;oogl03_ooool2o`00ob[ooooo
0_ooO`05ooooo`03o`00oooooooooooo03oooooo0Ol00001ooooo`0000?o0000ooooooooool0UOoo
ool4oomo00cooooo00Co003oooooooooO`3oogl0:?ooool4oomo00?ooooo00?o003oooooooooool0
@?ooool1o`00007ooooo00000ol0003oooooooooo`2Eooooo`Coogl02_ooool2o`00o`03oooooooo
O`3oogl000;oogl09oooool4oomo00?ooooo00?o003oooooooooool0@?ooool1o`00007ooooo0000
0ol0003oooooooooo`2Fooooo`;oogl02_ooool01?l00?ooooooooooooooool4oomo02Sooooo0_oo
O`04ooooo`03o`00oooooooooooo043ooooo0Ol00001ooooo`0000?o0000ooooooooool0XOooool0
0ol00?ooooooooooo`03ooooo`;oogl0;_ooool00ol00?ooooooooooo`11ooooo`7o00000Oooool0
0003o`000?oooooooooo0:3ooooo00?o003oooooooooool0<oooool00ol00?ooooooooooo`0Boooo
o`;oogl0;_ooool1o`00007ooooo00000ol0003oooooooooo`2Nooooo`;o003o=Oooool00ol00?oo
ooooooooo`0Booooo`Coogl0;Oooool1o`00007ooooo00000ol0003oooooooooo`2Mooooo`03o`00
oooooooooooo01Gooooo1?l00?lLooooo`03o`00ooooO`3oogl001;ooooo1?ooO`0]ooooo`7o0000
0Oooool00003o`000?oooooooooo09cooooo00?o003oooooooooool05Oooool6o`00oa[ooooo00?o
003ooomo0?ooO`000_ooO`0Booooo`;oogl0;_ooool1o`00007ooooo00000ol0003oooooooooo`2K
ooooo`03o`00oooooooooooo01Gooooo2?l00?lHooooo`03o`00ooooooooogl000?oogl0@_ooool1
o`00007ooooo00000ol0003oooooooooo`2Kooooo`03o`00oooooooooooo01Gooooo2?l00?lGoooo
o`04o`00ooooooooooooooooo`;oogl0@oooool1o`00007ooooo00000ol0003oooooooooo`2Joooo
o`03o`00oooooooooooo01Kooooo2?l00?lFooooo`03o`00oooooooooooo04Oooooo0Ol00001oooo
o`0000?o0000ooooooooool0VOooool00ol00?ooooooooooo`0<ooooo`;oogl02?ooool00oooO`3o
003oo`00o`06o`00oaGooooo00?o003oooooooooool00_ooO`16ooooo`7o00000Oooool00003o`00
0?oooooooooo09Wooooo00?o003oooooooooool02_ooool5oomo00Oooooo0_ooO`06o`00oa?ooooo
0_ooO`000ol00?ooooooooooo`04oomo04Gooooo0Ol00001ooooo`0000?o0000ooooooooool0V?oo
ool00ol00?ooooooooooo`0:ooooo`Koogl02?ooool2oomo00Co003o4oooool2oomo00;o003o0_oo
ool4oomo04Gooooo0Ol00001ooooo`0000?o0000ooooooooool0V?ooool00ol00?ooooooooooo`0:
ooooo`Googl08_ooool01?ooO`3o003ooomo0?ooO`03ooooo`;oogl0A_ooool1o`00007ooooo0000
0ol0003oooooooooo`1fooooo`;oogl07oooool00ol00?ooooooooooo`0<ooooo`;oogl09?ooool0
0ol00?ooogl0oomo001<ooooo`7o00000Oooool00003o`000?oooooooooo07Gooooo1?ooO`0Noooo
o`03o`00oooooooooooo037ooooo00?o003oooooooooool0COooool1o`00007ooooo00000ol0003o
ooooooooo`1eooooo`Coogl02_ooool2oomo017ooooo00?o003oooooooooool0<Oooool00ol00?oo
ooooooooo`1>ooooo`7o00000Oooool00003o`000?oooooooooo07Kooooo0_ooO`0:ooooo`Coogl0
3oooool00ol00?ooooooooooo`0Hooooo`;oogl05oooool00ol00?ooooooooooo`1?ooooo`7o0000
0Oooool00003o`000?oooooooooo08;ooooo1?ooO`0?ooooo`03o`00oooooooooooo01Oooooo1?oo
O`0Dooooo`;o003oD_ooool1o`00007ooooo00000ol0003oooooooooo`23ooooo`;oogl03oooool0
0ol00?ooooooooooo`0Booooo`;oogl01?ooool4oomo017ooooo0ol00?mDooooo`7o00000Oooool0
0003o`000?oooooooooo09Cooooo00?o003oooooooooool04Oooool4oomo00Cooooo0_ooO`0@oooo
o`;o003oEoooool1o`00007ooooo00000ol0003oooooooooo`2Dooooo`03o`00oooooooooooo017o
oooo1?ooO`0Eooooo`03o`00oooooooooooo05Oooooo0Ol00001ooooo`0000?o0000ooooooooool0
U?ooool00ol00?ooooooooooo`0Booooo`;oogl05?ooool2o`00oe[ooooo0Ol00001ooooo`0000?o
0000ooooooooool0U?ooool00ol00?ooooooooooo`0Vooooo`;o003oG?ooool1o`00007ooooo0000
0ol0003oooooooooo`2Eooooo`03o`00oooooooooooo02Cooooo00?o003oooooooooool0G?ooool1
o`00007ooooo00000ol0003oooooooooo`2Eooooo`03o`00oooooooooooo02;ooooo0_l00?mOoooo
o`7o00000Oooool00003o`000?oooooooooo09Gooooo00?o003oooooooooool08?ooool2o`00of7o
oooo0Ol00001ooooo`0000?o0000ooooooooool0Q?ooool2oomo00oooooo0_l00?lOooooo`;o003o
Hoooool1o`00007ooooo00000ol0003oooooooooo`23ooooo`Coogl04?ooool2o`00oa[ooooo0ol0
0?mUooooo`7o00000Oooool00003o`000?oooooooooo08?ooooo1?ooO`0Booooo`;o003o5?ooool4
o`00ofSooooo0Ol00001ooooo`0000?o0000ooooooooool0Q?ooool2oomo01Gooooo0ol00?l>oooo
o`?o003o0oooool2oomo06Oooooo0Ol00001ooooo`0000?o0000ooooooooool0W_ooool3o`00o`Go
oooo1_l00?l5ooooo`Coogl0I_ooool1o`00007ooooo00000ol0003oooooooooo`2Qooooo`Go003o
2oooool4oomo06Kooooo0Ol00001ooooo`0000?o0000ooooooooool0/_ooool2oomo06Oooooo0Ol0
0001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo
0?oooooo7?ooool1o`00007ooooo00000ol0003oooooooooo`1kooooo`;oogl0W_ooool1o`00007o
oooo00000ol0003oooooooooo`1jooooo`Coogl0WOooool1o`00007ooooo00000ol0003ooooooooo
o`1jooooo`Coogl08?ooool2oomo07_ooooo0Ol00001ooooo`0000?o0000ooooooooool0Noooool2
oomo023ooooo1?ooO`1jooooo`7o00000Oooool00003o`000?oooooooooo09gooooo1?ooO`1joooo
o`7o00000Oooool00003o`000?oooooooooo093ooooo0_ooO`0<ooooo`;oogl0Noooool1o`00007o
oooo00000ol0003oooooooooo`2?ooooo`Coogl0R?ooool1o`00007ooooo00000ol0003ooooooooo
o`2?ooooo`Coogl0R?ooool1o`00007ooooo00000ol0003oooooooooo`2@ooooo`;oogl08oooool2
oomo06Cooooo0Ol00001ooooo`0000?o0000ooooooooool0]?ooool4oomo06?ooooo0Ol00001oooo
o`0000?o0000ooooooooool0]?ooool4oomo06?ooooo0Ol00001ooooo`0000?o0000ooooooooool0
]Oooool2oomo06Cooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Ooo
ool00003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooo
oacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`00
0?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol0
0001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo
0?oooooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`00
00?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?oo
ool1o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000oooo
ooooool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007o
oooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooo
oolLooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0
003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o
00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003ooooooooo
o`3ooooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool0
0003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooooaco
oooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oo
oooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001
ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo0?oo
oooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o
0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1
o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000oooooooo
ool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo
00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolL
ooooo`7o00000Oooool00003o`000?oooooooooo08kooooo0_ooO`2;ooooo`7o00000Oooool00003
o`000?oooooooooo08gooooo1?ooO`2:ooooo`7o00000Oooool00003o`000?oooooooooo08gooooo
1?ooO`2:ooooo`7o00000Oooool00003o`000?oooooooooo08kooooo0_ooO`2;ooooo`7o00000Ooo
ool00003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooo
oacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`00
0?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol0
0001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo
0?oooooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`00
00?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?oo
ool1o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000oooo
ooooool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007o
oooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooo
oolLooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0
003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o
00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003ooooooooo
o`3ooooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool0
0?oo00008?l00001ooooo`00\
\>"],
  ImageRangeCache->{{{0, 287}, {287, 0}} -> {-1.01089, -1.01089, 0.00704453, \
0.00704453}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.49505 0.5 0.49505 [
[ 0 0 -0.125 0 ]
[ 0 0 -0.125 0 ]
[ 0 1 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
0 0 m
1 0 L
s
0 0 m
0 1 L
s
0 1 m
1 1 L
s
1 0 m
1 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
1 .5 0 r
.015 w
.03175 .1355 Mdot
.03435 .12523 Mdot
.11137 .12765 Mdot
.14107 .18841 Mdot
.16218 .24538 Mdot
.17294 .21053 Mdot
.18267 .18577 Mdot
.18434 .1304 Mdot
.18553 .30956 Mdot
.20401 .239 Mdot
.21247 .27571 Mdot
.21687 .20845 Mdot
.22376 .2799 Mdot
.22832 .27485 Mdot
.29063 .20974 Mdot
.29686 .25079 Mdot
.30487 .22936 Mdot
.30683 .34623 Mdot
.32055 .20902 Mdot
.32574 .21979 Mdot
.34472 .28521 Mdot
.35998 .36393 Mdot
.36335 .24976 Mdot
.3794 .36608 Mdot
.42386 .66992 Mdot
.44391 .74519 Mdot
.45059 .34198 Mdot
.47208 .67586 Mdot
.47436 .71381 Mdot
.49778 .59825 Mdot
.50874 .91643 Mdot
.51516 .76219 Mdot
.53655 .61374 Mdot
.56563 .75219 Mdot
.59189 .65665 Mdot
.59581 .61604 Mdot
.59923 .6556 Mdot
.60292 .68499 Mdot
.62656 .67779 Mdot
.63555 .72451 Mdot
.63919 .652 Mdot
.64169 .6004 Mdot
.64246 .58611 Mdot
.64496 .54267 Mdot
.64608 .77288 Mdot
.65077 .64308 Mdot
.66065 .57816 Mdot
.67474 .59169 Mdot
.69296 .563 Mdot
.72815 .65902 Mdot
.73169 .58879 Mdot
.74669 .61318 Mdot
.74821 .65474 Mdot
.75963 .63781 Mdot
.79673 .57809 Mdot
.80925 .55852 Mdot
.81525 .58444 Mdot
.83417 .62985 Mdot
.83598 .55526 Mdot
.91595 .49319 Mdot
1 0 0 r
.005 w
.16128 .17044 m
.18734 .17269 L
.21339 .17909 L
.2345 .18734 L
.23945 .19126 L
.2655 .20415 L
.27874 .21339 L
.29156 .22295 L
.31204 .23945 L
.31761 .24532 L
.33549 .2655 L
.34367 .28341 L
.34499 .29156 L
.34367 .29798 L
.31761 .3104 L
.29156 .30711 L
.2655 .30014 L
.24507 .29156 L
.23945 .28747 L
.21339 .27402 L
.20155 .2655 L
.18734 .25472 L
.16884 .23945 L
.16128 .2313 L
.14618 .21339 L
.13806 .18734 L
.16128 .17044 L
s
0 0 1 r
.65633 .57701 m
.68239 .56842 L
.70844 .56313 L
.7345 .56168 L
.76055 .5752 L
.76359 .57817 L
.76859 .60422 L
.76055 .62333 L
.75627 .63028 L
.7345 .65485 L
.73298 .65633 L
.70844 .6775 L
.69922 .68239 L
.68239 .69294 L
.65633 .70579 L
.64983 .70844 L
.63028 .71539 L
.60422 .72268 L
.57817 .72651 L
.55211 .7214 L
.53145 .70844 L
.52926 .68239 L
.54239 .65633 L
.55211 .63983 L
.56625 .63028 L
.57817 .6193 L
.60119 .60422 L
.60422 .60227 L
.63028 .58726 L
.65315 .57817 L
.65633 .57701 L
s
1 0 0 r
.03 w
.24141 .24033 Mdot
0 0 1 r
.64872 .64417 Mdot
1 0 0 r
.79703 .00495 m
.79703 .25248 L
.87129 .25248 L
.87129 .00495 L
F
0 0 1 r
.89604 .00495 m
.89604 .00495 L
.9703 .00495 L
.9703 .00495 L
F
1 0 1 r
.04 w
.30487 .22936 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P000182000`400?l00000o`00003ooooooolQ
ooooo`00ool0000Po`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`00
00?o0000ooooooooool0hOoooolEool002Gooooo0Ol00001ooooo`0000?o0000ooooooooool0hOoo
oolEool002Gooooo0Ol00001ooooo`0000?o0000ooooooooool0hOoooolEool002Gooooo0Ol00001
ooooo`0000?o0000ooooooooool0hOoooolEool002Gooooo0Ol00001ooooo`0000?o0000oooooooo
ool0hOoooolEool002Gooooo0Ol00001ooooo`0000?o0000ooooooooool0hOoooolEool002Gooooo
0Ol00001ooooo`0000?o0000ooooooooool0hOoooolEool002Gooooo0Ol00001ooooo`0000?o0000
ooooooooool0hOoooolEool002Gooooo0Ol00001ooooo`0000?o0000ooooooooool0hOoooolEool0
02Gooooo0Ol00001ooooo`0000?o0000ooooooooool0hOoooolEool002Gooooo0Ol00001ooooo`00
00?o0000ooooooooool0hOoooolEool002Gooooo0Ol00001ooooo`0000?o0000ooooooooool0hOoo
oolEool002Gooooo0Ol00001ooooo`0000?o0000ooooooooool0hOoooolEool002Gooooo0Ol00001
ooooo`0000?o0000ooooooooool0hOoooolEool002Gooooo0Ol00001ooooo`0000?o0000oooooooo
ool0hOoooolEool002Gooooo0Ol00001ooooo`0000?o0000ooooooooool0hOoooolEool002Gooooo
0Ol00001ooooo`0000?o0000ooooooooool0hOoooolEool002Gooooo0Ol00001ooooo`0000?o0000
ooooooooool0hOoooolEool002Gooooo0Ol00001ooooo`0000?o0000ooooooooool0hOoooolEool0
02Gooooo0Ol00001ooooo`0000?o0000ooooooooool0hOoooolEool002Gooooo0Ol00001ooooo`00
00?o0000ooooooooool0hOoooolEool002Gooooo0Ol00001ooooo`0000?o0000ooooooooool0hOoo
oolEool002Gooooo0Ol00001ooooo`0000?o0000ooooooooool0hOoooolEool002Gooooo0Ol00001
ooooo`0000?o0000ooooooooool0hOoooolEool002Gooooo0Ol00001ooooo`0000?o0000oooooooo
ool0hOoooolEool002Gooooo0Ol00001ooooo`0000?o0000ooooooooool0hOoooolEool002Gooooo
0Ol00001ooooo`0000?o0000ooooooooool0hOoooolEool002Gooooo0Ol00001ooooo`0000?o0000
ooooooooool0hOoooolEool002Gooooo0Ol00001ooooo`0000?o0000ooooooooool0hOoooolEool0
02Gooooo0Ol00001ooooo`0000?o0000ooooooooool0hOoooolEool002Gooooo0Ol00001ooooo`00
00?o0000ooooooooool0hOoooolEool002Gooooo0Ol00001ooooo`0000?o0000ooooooooool0hOoo
oolEool002Gooooo0Ol00001ooooo`0000?o0000ooooooooool01_ooool2oomo0=Wooooo5Ooo000U
ooooo`7o00000Oooool00003o`000?oooooooooo00Gooooo1?ooO`0Cooooo`;oogl0`ooooolEool0
02Gooooo0Ol00001ooooo`0000?o0000ooooooooool01Oooool4oomo01;ooooo1?ooO`0Booooo`;o
ogl0[_oooolEool002Gooooo0Ol00001ooooo`0000?o0000ooooooooool01Oooool3oomo01?ooooo
1?ooO`0Aooooo`Coogl0[OoooolEool002Gooooo0Ol00001ooooo`0000?o0000ooooooooool01?oo
ool4oomo01Cooooo0_ooO`0Booooo`Coogl0[OoooolEool002Gooooo0Ol00001ooooo`0000?o0000
ooooooooool01?ooool4oomo02Wooooo0_ooO`2^oooooaGoo`009Oooool1o`00007ooooo00000ol0
003oooooooooo`05ooooo`;oogl0f_oooolEool002Gooooo0Ol00001ooooo`0000?o0000oooooooo
ool0hOoooolEool002Gooooo0Ol00001ooooo`0000?o0000ooooooooool0hOoooolEool002Gooooo
0Ol00001ooooo`0000?o0000ooooooooool0hOoooolEool002Gooooo0Ol00001ooooo`0000?o0000
ooooooooool0hOoooolEool002Gooooo0Ol00001ooooo`0000?o0000ooooooooool0hOoooolEool0
02Gooooo0Ol00001ooooo`0000?o0000ooooooooool0hOoooolEool002Gooooo0Ol00001ooooo`00
00?o0000ooooooooool0hOoooolEool002Gooooo0Ol00001ooooo`0000?o0000ooooooooool0:_oo
ool6ool00;7ooooo5Ooo000Uooooo`7o00000Oooool00003o`000?oooooooooo02Wooooo00?oo`00
ooooooooool01?ooool5ool00:cooooo5Ooo000Uooooo`7o00000Oooool00003o`000?oooooooooo
02Oooooo0_oo000<ooooo`Coo`00Z?oooolEool002Gooooo0Ol00001ooooo`0000?o0000oooooooo
ool09_ooool00ooo003oooooooooo`0@ooooo`Coo`00Y?oooolEool002Gooooo0Ol00001ooooo`00
00?o0000ooooooooool09?ooool00oooO`3oo`00ooooo`09ooooo`;oogl02oooool3ool00:7ooooo
5Ooo000Uooooo`7o00000Oooool00003o`000?oooooooooo02?ooooo00Coogl0ool00?ooO`3oogl0
2?ooool4oomo00gooooo00?oo`00ooooooooool0W_oooolEool002Gooooo0Ol00001ooooo`0000?o
0000ooooooooool08oooool01?ooO`3oo`00oomo0?ooO`08ooooo`Coogl03_ooool2ool009kooooo
5Ooo000Uooooo`7o00000Oooool00003o`000?oooooooooo02Cooooo00?oogl0ool00?ooool02Ooo
ool2oomo017ooooo0_oo002LoooooaGoo`009Oooool1o`00007ooooo00000ol0003oooooooooo`0U
ooooo`03ool00?oooooooooo01gooooo0_oo002JoooooaGoo`009Oooool1o`00007ooooo00000ol0
003oooooooooo`0Uooooo`03ool00?oooooooooo01oooooo0_oo002HoooooaGoo`009Oooool1o`00
007ooooo00000ol0003oooooooooo`0Vooooo`03ool00?oooooooooo017ooooo0_ooO`0=ooooo`;o
o`001?ooool2oomo00Oooooo0_ooO`27oooooaGoo`009Oooool1o`00007ooooo00000ol0003ooooo
ooooo`0Vooooo`03ool00?oooooooooo00Gooooo0_ooO`09ooooo`Coogl03_ooool00ooo003ooooo
ooooo`04oomo00Gooooo1?ooO`26oooooaGoo`009Oooool1o`00007ooooo00000ol0003ooooooooo
o`0Vooooo`03ool00?oooooooooo00Cooooo1?ooO`08ooooo`Coogl03oooool00ooo003ooooooomo
0003oomo00Gooooo1?ooO`26oooooaGoo`009Oooool1o`00007ooooo00000ol0003oooooooooo`0W
ooooo`03ool00?oooooooooo00?ooooo1?ooO`09ooooo`;oogl04Oooool01Ooo003ooooooomo0?oo
O`3ooooo00Goo`3o00Cooooooomo0?ooO`3oogl0Q_oooolEool002Gooooo0Ol00001ooooo`0000?o
0000ooooooooool09oooool00ooo003oooooooooo`04ooooo`;oogl07_ooool00ooo003ooooooooo
o`07ool0o`Coogl0QOoooolEool002Gooooo0Ol00001ooooo`0000?o0000ooooooooool0:?ooool0
0ooo003oooooooooo`0Tooooo`03ool00?oo0?ooo`3o00Ooo`3o0oooO`25oooooaGoo`009Oooool1
o`00007ooooo00000ol0003oooooooooo`0Yooooo`03ool00?oooooooooo02?ooooo2ooo0?l00ooo
O`3oooooooooo`24oooooaGoo`009Oooool1o`00007ooooo00000ol0003oooooooooo`0Zooooo`03
ool00?oooooooooo01?ooooo1?oo000;ooooo`_oo`3oQooooolEool002Gooooo0Ol00001ooooo`00
00?o0000ooooooooool0:oooool00ooo003oooooooooo`0Aooooo`Koo`002_ooool;ool0ohOooooo
5Ooo000Uooooo`7o00000Oooool00003o`000?oooooooooo02cooooo00?oo`00ooooooooool02?oo
ool2oomo00Gooooo2?oo0009ooooo`_oo`3oQooooolEool002Gooooo0Ol00001ooooo`0000?o0000
ooooooooool0;Oooool00ooo003oooooooooo`06ooooo`Coogl01?ooool8ool000Wooooo2ooo0?n7
oooooaGoo`009Oooool1o`00007ooooo00000ol0003oooooooooo`0[ooooo`;oogl000?oooooool0
0?ooool01_ooool4oomo00Cooooo2?oo000:ooooo`Woo`3oR?oooolEool002Gooooo0Ol00001oooo
o`0000?o0000ooooooooool0:_ooool4oomo0003oooooooo003ooooo00Kooooo0_ooO`05ooooo`So
o`002oooool7ool0o`03ool00?oooooooooo00Wooooo0_ooO`1koooooaGoo`009Oooool1o`00007o
oooo00000ol0003oooooooooo`0Zooooo`Coogl00_ooool00ooo003oooooooooo`0<ooooo`Koo`00
2oooool2oomo00Goo`3o00?oooooool00?ooool02Oooool4oomo07[ooooo5Ooo000Uooooo`7o0000
0Oooool00003o`000?oooooooooo02_ooooo0_ooO`04ooooo`03ool00?oooooooooo00cooooo1?oo
000<ooooo`Coogl01Oooool00ooo003oooooooooo`07ooooo`Coogl0N_oooolEool002Gooooo0Ol0
0001ooooo`0000?o0000ooooooooool0<_ooool2ool001gooooo0_ooO`07ooooo`03ool00?oooooo
oooo00Oooooo0_ooO`2eooooo`7o00000Oooool00003o`000?oooooooooo03Cooooo00?oo`00oooo
ooooool09?ooool00ooo003oooooooooo`2mooooo`7o00000Oooool00003o`000?oooooooooo03Go
oooo00?oo`00ooooooooool09?ooool00ooo003oooooooooo`2looooo`7o00000Oooool00003o`00
0?oooooooooo03Kooooo0_oo000Uooooo`03ool00?oooooooooo0;_ooooo0Ol00001ooooo`0000?o
0000ooooooooool0>?ooool2ool00003oomo0?oooooooooo00;oogl07_ooool00ooo003ooooooooo
o`2kooooo`7o00000Oooool00003o`000?oooooooooo03Sooooo0_ooO`02ool000Coogl07_ooool0
0ooo003oooooooooo`2jooooo`7o00000Oooool00003o`000?oooooooooo03Sooooo1?ooO`02ool0
00;oogl07_ooool00ooo003oooooooooo`2jooooo`7o00000Oooool00003o`000?oooooooooo03Wo
oooo1OooO`000ooo003oooooooooo`0Mooooo`03ool00?ooO`3oogl00;[ooooo0Ol00001ooooo`00
00?o0000ooooooooool0>oooool4oomo00;oo`007Oooool01?ooO`3oo`00oomo0?ooO`2iooooo`7o
00000Oooool00003o`000?oooooooooo03cooooo0_ooO`03ooooo`;oo`006oooool01?ooO`3oo`00
oomo0?ooO`2iooooo`7o00000Oooool00003o`000?oooooooooo04?ooooo0_oo000Jooooo`03oomo
0?oo003ooooo0;Wooooo0Ol00001ooooo`0000?o0000ooooooooool0AOooool2ool001Wooooo00?o
o`00ooooooooool0^?ooool1o`00007ooooo00000ol0003oooooooooo`17ooooo`;oo`005Oooool2
ool00;_ooooo0Ol00001ooooo`0000?o0000ooooooooool0BOooool3ool0013ooooo0_oo002moooo
o`7o00000Oooool00003o`000?oooooooooo037ooooo0_ooO`0Iooooo`?oo`003?ooool00ooo003o
ooooooooo`2mooooo`7o00000Oooool00003o`000?oooooooooo033ooooo1?ooO`0Kooooo`Koo`00
1?ooool2ool00<3ooooo0Ol00001ooooo`0000?o0000ooooooooool0<?ooool4oomo027ooooo1?oo
0032ooooo`7o00000Oooool00003o`000?oooooooooo037ooooo0_ooO`3Xooooo`7o00000Oooool0
0003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooooaco
oooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oo
oooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001
ooooo`0000?o0000ooooooooool0OOooool2oomo09cooooo0Ol00001ooooo`0000?o0000oooooooo
ool0O?ooool4oomo09_ooooo0Ol00001ooooo`0000?o0000ooooooooool0E?ooool2oomo02Kooooo
1?ooO`2Kooooo`7o00000Oooool00003o`000?oooooooooo05?ooooo1?ooO`0Vooooo`;oogl0W?oo
ool1o`00007ooooo00000ol0003oooooooooo`1Cooooo`Coogl0a?ooool1o`00007ooooo00000ol0
003oooooooooo`1Dooooo`;oogl0aOooool1o`00007ooooo00000ol0003oooooooooo`3ooooooaco
oooo0Ol00001ooooo`0000?o0000ooooooooool0Hoooool2oomo00Cooooo0_ooO`2`ooooo`7o0000
0Oooool00003o`000?oooooooooo06;ooooo1?ooO`02ooooo`Coogl0[oooool1o`00007ooooo0000
0ol0003oooooooooo`1Rooooo`Coogl00_ooool4oomo0:oooooo0Ol00001ooooo`0000?o0000oooo
ooooool0Hoooool2oomo00Cooooo0_ooO`2`ooooo`7o00000Oooool00003o`000?oooooooooo0?oo
oooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o
0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1
o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000oooooooo
ool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo
00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolL
ooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003o
ooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o0000
0Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3o
oooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003
o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo
0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oooooo
oooo0?oooooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001oooo
o`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo
7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000
ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00
007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0
oooooolLooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo0000
0ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLoooo
o`7o00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003ooooo
ooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Ooo
ool00003o`000?oooooooooo0?oooooo1?ooool2oomo01Kooooo0Ol00001ooooo`0000?o0000oooo
ooooool0ooooool3ooooo`Coogl05Oooool1o`00007ooooo00000ol0003oooooooooo`3oooooo`?o
oooo1?ooO`0Eooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo1?ooool2oomo01Kooooo
0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oooooo
oooo0?oooooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001oooo
o`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo
7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000
ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00
007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0
oooooolLooooo`7o00000Oooool00003o`000?oooooooooo0;Gooooo0_ooO`1Tooooo`7o00000Ooo
ool00003o`000?oooooooooo0;Cooooo1?ooO`1Sooooo`7o00000Oooool00003o`000?oooooooooo
0;Cooooo1?ooO`1Sooooo`7o00000Oooool00003o`000?oooooooooo0;Gooooo0_ooO`0eooooo`;o
ogl0;Oooool1o`00007ooooo00000ol0003oooooooooo`3Tooooo`;oogl01Oooool4oomo02cooooo
0Ol00001ooooo`0000?o0000ooooooooool0hoooool4oomo00Cooooo1?ooO`0/ooooo`7o00000Ooo
ool00003o`000?oooooooooo0<?ooooo0_ooO`0Nooooo`Coogl01Oooool2oomo02gooooo0Ol00001
ooooo`0000?o0000ooooooooool0`_ooool4oomo00_o003o4oooool2oomo03Gooooo0Ol00001oooo
o`0000?o0000ooooooooool0`_ooool4o`00o`_ooooo0_l00?m8ooooo`7o00000Oooool00003o`00
0?oooooooooo0;kooooo1?l00?l00oooooooogl0oomo000>ooooo`;o003oA_ooool1o`00007ooooo
00000ol0003oooooooooo`2iooooo`;oogl00ol00?lGooooo`;o003o2Oooool2oomo03Wooooo0Ol0
0001ooooo`0000?o0000ooooooooool0]oooool4o`00o`03oomo0?oooooooooo01Wooooo0_l00?l6
ooooo`Coogl0>?ooool1o`00007ooooo00000ol0003oooooooooo`2dooooo`?o003o00?ooooooomo
0?ooO`000_ooO`0Looooo`03o`00oooooooooooo00Cooooo1?ooO`03ooooo`;oogl0<oooool1o`00
007ooooo00000ol0003oooooooooo`2booooo`;o003o0oooO`02ooooo`;oogl04oooool2oomo00So
oooo00?o003oooooooooool01Oooool2oomo00?ooooo1?ooO`0booooo`7o00000Oooool00003o`00
0?oooooooooo0;3ooooo0_l00?l00oooooooogl0oomo0002oomo00Kooooo0_ooO`0>ooooo`Coogl0
1oooool00ol00?ooooooooooo`0:ooooo`Coogl0<_ooool1o`00007ooooo00000ol0003ooooooooo
o`2^ooooo`;o003o1?ooool2oomo00Kooooo1?ooO`0=ooooo`Coogl01oooool00ol00?oooooooooo
o`0;ooooo`;oogl0<oooool1o`00007ooooo00000ol0003oooooooooo`2;ooooo`;oogl08?ooool0
0ol00?ooooooooooo`04ooooo`;oogl01_ooool4oomo00kooooo0_ooO`09ooooo`03o`00oooooooo
oooo03oooooo0Ol00001ooooo`0000?o0000ooooooooool0R_ooool4oomo01gooooo0_l00?l6oooo
o`Coogl01_ooool2oomo01[ooooo00?o003oooooooooool0?oooool1o`00007ooooo00000ol0003o
ooooooooo`2:ooooo`Coogl07?ooool00ol00?ooooooooooo`06ooooo`Coogl08_ooool00ol00?oo
ooooooooo`0oooooo`7o00000Oooool00003o`000?oooooooooo08_ooooo0_ooO`0Kooooo`;o003o
2_ooool2oomo02?ooooo00?o003oooooooooool0?oooool1o`00007ooooo00000ol0003ooooooooo
o`2Fooooo`;oogl03_ooool2o`00ob[ooooo0_ooO`05ooooo`03o`00oooooooooooo03oooooo0Ol0
0001ooooo`0000?o0000ooooooooool0UOooool4oomo00cooooo00Co003oooooooooO`3oogl0:?oo
ool4oomo00?ooooo00?o003oooooooooool0@?ooool1o`00007ooooo00000ol0003oooooooooo`2E
ooooo`Coogl02_ooool2o`00o`03ooooooooO`3oogl000;oogl09oooool4oomo00?ooooo00?o003o
ooooooooool0@?ooool1o`00007ooooo00000ol0003oooooooooo`2Fooooo`;oogl02_ooool01?l0
0?ooooooooooooooool4oomo02Sooooo0_ooO`04ooooo`03o`00oooooooooooo043ooooo0Ol00001
ooooo`0000?o0000ooooooooool0XOooool00ol00?ooooooooooo`03ooooo`;oogl0;_ooool00ol0
0?ooooooooooo`11ooooo`7o00000Oooool00003o`000?oooooooooo0:3ooooo00?o003ooooooooo
ool0<oooool00ol00?ooooooooooo`0Booooo`;oogl0;_ooool1o`00007ooooo00000ol0003ooooo
ooooo`2Nooooo`;o003o=Oooool00ol00?ooooooooooo`0Booooo`Coogl0;Oooool1o`00007ooooo
00000ol0003oooooooooo`2Mooooo`03o`00oooooooooooo01Gooooo1?l00?lLooooo`03o`00oooo
O`3oogl001;ooooo1?ooO`0]ooooo`7o00000Oooool00003o`000?oooooooooo09cooooo00?o003o
ooooooooool05Oooool6o`00oa[ooooo00?o003ooomo0?ooO`000_ooO`0Booooo`;oogl0;_ooool1
o`00007ooooo00000ol0003oooooooooo`2Kooooo`03o`00oooooooooooo01Gooooo2?l00?lHoooo
o`03o`00ooooooooogl000?oogl0@_ooool1o`00007ooooo00000ol0003oooooooooo`2Kooooo`03
o`00oooooooooooo01Gooooo2?l00?lGooooo`04o`00ooooooooooooooooo`;oogl0@oooool1o`00
007ooooo00000ol0003oooooooooo`2Jooooo`03o`00oooooooooooo01Kooooo2?l00?lFooooo`03
o`00oooooooooooo04Oooooo0Ol00001ooooo`0000?o0000ooooooooool0VOooool00ol00?oooooo
ooooo`0<ooooo`;oogl02?ooool00oooO`3o003oo`00o`06o`00oaGooooo00?o003oooooooooool0
0_ooO`16ooooo`7o00000Oooool00003o`000?oooooooooo09Wooooo00?o003oooooooooool02_oo
ool5oomo00Oooooo0_ooO`06o`00oa?ooooo0_ooO`000ol00?ooooooooooo`04oomo04Gooooo0Ol0
0001ooooo`0000?o0000ooooooooool0V?ooool00ol00?ooooooooooo`0:ooooo`Koogl02?ooool2
oomo00Co003o4oooool2oomo00;o003o0_ooool4oomo04Gooooo0Ol00001ooooo`0000?o0000oooo
ooooool0V?ooool00ol00?ooooooooooo`0:ooooo`Googl08_ooool01?ooO`3o003ooomo0?ooO`03
ooooo`;oogl0A_ooool1o`00007ooooo00000ol0003oooooooooo`1fooooo`;oogl07oooool00ol0
0?ooooooooooo`0<ooooo`;oogl09?ooool00ol00?ooogl0oomo001<ooooo`7o00000Oooool00003
o`000?oooooooooo07Gooooo1?ooO`0Nooooo`03o`00oooooooooooo037ooooo00?o003ooooooooo
ool0COooool1o`00007ooooo00000ol0003oooooooooo`1eooooo`Coogl02_ooool2oomo017ooooo
00?o003oooooooooool0<Oooool00ol00?ooooooooooo`1>ooooo`7o00000Oooool00003o`000?oo
oooooooo07Kooooo0_ooO`0:ooooo`Coogl03oooool00ol00?ooooooooooo`0Hooooo`;oogl05ooo
ool00ol00?ooooooooooo`1?ooooo`7o00000Oooool00003o`000?oooooooooo08;ooooo1?ooO`0?
ooooo`03o`00oooooooooooo01Oooooo1?ooO`0Dooooo`;o003oD_ooool1o`00007ooooo00000ol0
003oooooooooo`23ooooo`;oogl03oooool00ol00?ooooooooooo`0Booooo`;oogl01?ooool4oomo
017ooooo0ol00?mDooooo`7o00000Oooool00003o`000?oooooooooo09Cooooo00?o003ooooooooo
ool04Oooool4oomo00Cooooo0_ooO`0@ooooo`;o003oEoooool1o`00007ooooo00000ol0003ooooo
ooooo`2Dooooo`03o`00oooooooooooo017ooooo1?ooO`0Eooooo`03o`00oooooooooooo05Oooooo
0Ol00001ooooo`0000?o0000ooooooooool0U?ooool00ol00?ooooooooooo`0Booooo`;oogl05?oo
ool2o`00oe[ooooo0Ol00001ooooo`0000?o0000ooooooooool0U?ooool00ol00?ooooooooooo`0V
ooooo`;o003oG?ooool1o`00007ooooo00000ol0003oooooooooo`2Eooooo`03o`00oooooooooooo
02Cooooo00?o003oooooooooool0G?ooool1o`00007ooooo00000ol0003oooooooooo`2Eooooo`03
o`00oooooooooooo02;ooooo0_l00?mOooooo`7o00000Oooool00003o`000?oooooooooo09Gooooo
00?o003oooooooooool08?ooool2o`00of7ooooo0Ol00001ooooo`0000?o0000ooooooooool0Q?oo
ool2oomo00oooooo0_l00?lOooooo`;o003oHoooool1o`00007ooooo00000ol0003oooooooooo`23
ooooo`Coogl04?ooool2o`00oa[ooooo0ol00?mUooooo`7o00000Oooool00003o`000?oooooooooo
08?ooooo1?ooO`0Booooo`;o003o5?ooool4o`00ofSooooo0Ol00001ooooo`0000?o0000oooooooo
ool0Q?ooool2oomo01Gooooo0ol00?l>ooooo`?o003o0oooool2oomo06Oooooo0Ol00001ooooo`00
00?o0000ooooooooool0W_ooool3o`00o`Gooooo1_l00?l5ooooo`Coogl0I_ooool1o`00007ooooo
00000ol0003oooooooooo`2Qooooo`Go003o2oooool4oomo06Kooooo0Ol00001ooooo`0000?o0000
ooooooooool0/_ooool2oomo06Oooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLoooo
o`7o00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003ooooo
ooooo`1kooooo`;oogl0W_ooool1o`00007ooooo00000ol0003oooooooooo`1jooooo`Coogl0WOoo
ool1o`00007ooooo00000ol0003oooooooooo`1jooooo`Coogl08?ooool2oomo07_ooooo0Ol00001
ooooo`0000?o0000ooooooooool0Noooool2oomo023ooooo1?ooO`1jooooo`7o00000Oooool00003
o`000?oooooooooo09gooooo1?ooO`1jooooo`7o00000Oooool00003o`000?oooooooooo093ooooo
0_ooO`0<ooooo`;oogl0Noooool1o`00007ooooo00000ol0003oooooooooo`2?ooooo`Coogl0R?oo
ool1o`00007ooooo00000ol0003oooooooooo`2?ooooo`Coogl0R?ooool1o`00007ooooo00000ol0
003oooooooooo`2@ooooo`;oogl08oooool2oomo06Cooooo0Ol00001ooooo`0000?o0000oooooooo
ool0]?ooool4oomo06?ooooo0Ol00001ooooo`0000?o0000ooooooooool0]?ooool4oomo06?ooooo
0Ol00001ooooo`0000?o0000ooooooooool0]Oooool2oomo06Cooooo0Ol00001ooooo`0000?o0000
ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00
007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0
oooooolLooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo0000
0ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLoooo
o`7o00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003ooooo
ooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Ooo
ool00003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooo
oacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`00
0?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol0
0001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo
0?oooooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`00
00?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?oo
ool1o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000oooo
ooooool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007o
oooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooo
oolLooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0
003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o
00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003ooooooooo
o`3ooooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool0
0003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooooaco
oooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oo
oooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001
ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo08ko
oooo0_ooO`2;ooooo`7o00000Oooool00003o`000?oooooooooo08gooooo1?ooO`2:ooooo`7o0000
0Oooool00003o`000?oooooooooo08gooooo1?ooO`2:ooooo`7o00000Oooool00003o`000?oooooo
oooo08kooooo0_ooO`2;ooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00
007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0
oooooolLooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo0000
0ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLoooo
o`7o00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003ooooo
ooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Ooo
ool00003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooo
oacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`00
0?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol0
0001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo
0?oooooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`00
00?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?oo
ool1o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000oooo
ooooool0oooooolLooooo`7o00000Oooool00?oo00008?l00001ooooo`00\
\>"],
  ImageRangeCache->{{{0, 287}, {287, 0}} -> {-1.01089, -1.01089, 0.00704453, \
0.00704453}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.49505 0.5 0.49505 [
[ 0 0 -0.125 0 ]
[ 0 0 -0.125 0 ]
[ 0 1 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
0 0 m
1 0 L
s
0 0 m
0 1 L
s
0 1 m
1 1 L
s
1 0 m
1 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
1 .5 0 r
.015 w
.03175 .1355 Mdot
.03435 .12523 Mdot
.11137 .12765 Mdot
.14107 .18841 Mdot
.16218 .24538 Mdot
.17294 .21053 Mdot
.18267 .18577 Mdot
.18434 .1304 Mdot
.18553 .30956 Mdot
.20401 .239 Mdot
.21247 .27571 Mdot
.21687 .20845 Mdot
.22376 .2799 Mdot
.22832 .27485 Mdot
.29063 .20974 Mdot
.29686 .25079 Mdot
.30487 .22936 Mdot
.30683 .34623 Mdot
.32055 .20902 Mdot
.32574 .21979 Mdot
.34472 .28521 Mdot
.35998 .36393 Mdot
.36335 .24976 Mdot
.3794 .36608 Mdot
.42386 .66992 Mdot
.44391 .74519 Mdot
.45059 .34198 Mdot
.47208 .67586 Mdot
.47436 .71381 Mdot
.49778 .59825 Mdot
.50874 .91643 Mdot
.51516 .76219 Mdot
.53655 .61374 Mdot
.56563 .75219 Mdot
.59189 .65665 Mdot
.59581 .61604 Mdot
.59923 .6556 Mdot
.60292 .68499 Mdot
.62656 .67779 Mdot
.63555 .72451 Mdot
.63919 .652 Mdot
.64169 .6004 Mdot
.64246 .58611 Mdot
.64496 .54267 Mdot
.64608 .77288 Mdot
.65077 .64308 Mdot
.66065 .57816 Mdot
.67474 .59169 Mdot
.69296 .563 Mdot
.72815 .65902 Mdot
.73169 .58879 Mdot
.74669 .61318 Mdot
.74821 .65474 Mdot
.75963 .63781 Mdot
.79673 .57809 Mdot
.80925 .55852 Mdot
.81525 .58444 Mdot
.83417 .62985 Mdot
.83598 .55526 Mdot
.91595 .49319 Mdot
1 0 0 r
.005 w
.16128 .17044 m
.18734 .17269 L
.21339 .17909 L
.2345 .18734 L
.23945 .19126 L
.2655 .20415 L
.27874 .21339 L
.29156 .22295 L
.31204 .23945 L
.31761 .24532 L
.33549 .2655 L
.34367 .28341 L
.34499 .29156 L
.34367 .29798 L
.31761 .3104 L
.29156 .30711 L
.2655 .30014 L
.24507 .29156 L
.23945 .28747 L
.21339 .27402 L
.20155 .2655 L
.18734 .25472 L
.16884 .23945 L
.16128 .2313 L
.14618 .21339 L
.13806 .18734 L
.16128 .17044 L
s
0 0 1 r
.65633 .57701 m
.68239 .56842 L
.70844 .56313 L
.7345 .56168 L
.76055 .5752 L
.76359 .57817 L
.76859 .60422 L
.76055 .62333 L
.75627 .63028 L
.7345 .65485 L
.73298 .65633 L
.70844 .6775 L
.69922 .68239 L
.68239 .69294 L
.65633 .70579 L
.64983 .70844 L
.63028 .71539 L
.60422 .72268 L
.57817 .72651 L
.55211 .7214 L
.53145 .70844 L
.52926 .68239 L
.54239 .65633 L
.55211 .63983 L
.56625 .63028 L
.57817 .6193 L
.60119 .60422 L
.60422 .60227 L
.63028 .58726 L
.65315 .57817 L
.65633 .57701 L
s
1 0 0 r
.03 w
.24141 .24033 Mdot
0 0 1 r
.64872 .64417 Mdot
1 0 0 r
.79703 .00495 m
.79703 .25248 L
.87129 .25248 L
.87129 .00495 L
F
0 0 1 r
.89604 .00495 m
.89604 .00495 L
.9703 .00495 L
.9703 .00495 L
F
1 0 1 r
.04 w
.30683 .34623 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P000182000`400?l00000o`00003ooooooolQ
ooooo`00ool0000Po`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`00
00?o0000ooooooooool0hOoooolEool002Gooooo0Ol00001ooooo`0000?o0000ooooooooool0hOoo
oolEool002Gooooo0Ol00001ooooo`0000?o0000ooooooooool0hOoooolEool002Gooooo0Ol00001
ooooo`0000?o0000ooooooooool0hOoooolEool002Gooooo0Ol00001ooooo`0000?o0000oooooooo
ool0hOoooolEool002Gooooo0Ol00001ooooo`0000?o0000ooooooooool0hOoooolEool002Gooooo
0Ol00001ooooo`0000?o0000ooooooooool0hOoooolEool002Gooooo0Ol00001ooooo`0000?o0000
ooooooooool0hOoooolEool002Gooooo0Ol00001ooooo`0000?o0000ooooooooool0hOoooolEool0
02Gooooo0Ol00001ooooo`0000?o0000ooooooooool0hOoooolEool002Gooooo0Ol00001ooooo`00
00?o0000ooooooooool0hOoooolEool002Gooooo0Ol00001ooooo`0000?o0000ooooooooool0hOoo
oolEool002Gooooo0Ol00001ooooo`0000?o0000ooooooooool0hOoooolEool002Gooooo0Ol00001
ooooo`0000?o0000ooooooooool0hOoooolEool002Gooooo0Ol00001ooooo`0000?o0000oooooooo
ool0hOoooolEool002Gooooo0Ol00001ooooo`0000?o0000ooooooooool0hOoooolEool002Gooooo
0Ol00001ooooo`0000?o0000ooooooooool0hOoooolEool002Gooooo0Ol00001ooooo`0000?o0000
ooooooooool0hOoooolEool002Gooooo0Ol00001ooooo`0000?o0000ooooooooool0hOoooolEool0
02Gooooo0Ol00001ooooo`0000?o0000ooooooooool0hOoooolEool002Gooooo0Ol00001ooooo`00
00?o0000ooooooooool0hOoooolEool002Gooooo0Ol00001ooooo`0000?o0000ooooooooool0hOoo
oolEool002Gooooo0Ol00001ooooo`0000?o0000ooooooooool0hOoooolEool002Gooooo0Ol00001
ooooo`0000?o0000ooooooooool0hOoooolEool002Gooooo0Ol00001ooooo`0000?o0000oooooooo
ool0hOoooolEool002Gooooo0Ol00001ooooo`0000?o0000ooooooooool0hOoooolEool002Gooooo
0Ol00001ooooo`0000?o0000ooooooooool0hOoooolEool002Gooooo0Ol00001ooooo`0000?o0000
ooooooooool0hOoooolEool002Gooooo0Ol00001ooooo`0000?o0000ooooooooool0hOoooolEool0
02Gooooo0Ol00001ooooo`0000?o0000ooooooooool0hOoooolEool002Gooooo0Ol00001ooooo`00
00?o0000ooooooooool0hOoooolEool002Gooooo0Ol00001ooooo`0000?o0000ooooooooool0hOoo
oolEool002Gooooo0Ol00001ooooo`0000?o0000ooooooooool01_ooool2oomo0=Wooooo5Ooo000U
ooooo`7o00000Oooool00003o`000?oooooooooo00Gooooo1?ooO`0Cooooo`;oogl0`ooooolEool0
02Gooooo0Ol00001ooooo`0000?o0000ooooooooool01Oooool4oomo01;ooooo1?ooO`0Booooo`;o
ogl0[_oooolEool002Gooooo0Ol00001ooooo`0000?o0000ooooooooool01Oooool3oomo01?ooooo
1?ooO`0Aooooo`Coogl0[OoooolEool002Gooooo0Ol00001ooooo`0000?o0000ooooooooool01?oo
ool4oomo01Cooooo0_ooO`0Booooo`Coogl0[OoooolEool002Gooooo0Ol00001ooooo`0000?o0000
ooooooooool01?ooool4oomo02Wooooo0_ooO`2^oooooaGoo`009Oooool1o`00007ooooo00000ol0
003oooooooooo`05ooooo`;oogl0f_oooolEool002Gooooo0Ol00001ooooo`0000?o0000oooooooo
ool0hOoooolEool002Gooooo0Ol00001ooooo`0000?o0000ooooooooool0hOoooolEool002Gooooo
0Ol00001ooooo`0000?o0000ooooooooool0hOoooolEool002Gooooo0Ol00001ooooo`0000?o0000
ooooooooool0hOoooolEool002Gooooo0Ol00001ooooo`0000?o0000ooooooooool0hOoooolEool0
02Gooooo0Ol00001ooooo`0000?o0000ooooooooool0hOoooolEool002Gooooo0Ol00001ooooo`00
00?o0000ooooooooool0hOoooolEool002Gooooo0Ol00001ooooo`0000?o0000ooooooooool0:_oo
ool6ool00;7ooooo5Ooo000Uooooo`7o00000Oooool00003o`000?oooooooooo02Wooooo00?oo`00
ooooooooool01?ooool5ool00:cooooo5Ooo000Uooooo`7o00000Oooool00003o`000?oooooooooo
02Oooooo0_oo000<ooooo`Coo`00Z?oooolEool002Gooooo0Ol00001ooooo`0000?o0000oooooooo
ool09_ooool00ooo003oooooooooo`0@ooooo`Coo`00Y?oooolEool002Gooooo0Ol00001ooooo`00
00?o0000ooooooooool09?ooool00oooO`3oo`00ooooo`09ooooo`;oogl02oooool3ool00:7ooooo
5Ooo000Uooooo`7o00000Oooool00003o`000?oooooooooo02?ooooo00Coogl0ool00?ooO`3oogl0
2?ooool4oomo00gooooo00?oo`00ooooooooool0W_oooolEool002Gooooo0Ol00001ooooo`0000?o
0000ooooooooool08oooool01?ooO`3oo`00oomo0?ooO`08ooooo`Coogl03_ooool2ool009kooooo
5Ooo000Uooooo`7o00000Oooool00003o`000?oooooooooo02Cooooo00?oogl0ool00?ooool02Ooo
ool2oomo017ooooo0_oo002LoooooaGoo`009Oooool1o`00007ooooo00000ol0003oooooooooo`0U
ooooo`03ool00?oooooooooo01gooooo0_oo002JoooooaGoo`009Oooool1o`00007ooooo00000ol0
003oooooooooo`0Uooooo`03ool00?oooooooooo01oooooo0_oo002HoooooaGoo`009Oooool1o`00
007ooooo00000ol0003oooooooooo`0Vooooo`03ool00?oooooooooo017ooooo0_ooO`0=ooooo`;o
o`001?ooool2oomo00Oooooo0_ooO`27oooooaGoo`009Oooool1o`00007ooooo00000ol0003ooooo
ooooo`0Vooooo`03ool00?oooooooooo00Gooooo0_ooO`09ooooo`Coogl03_ooool00ooo003ooooo
ooooo`04oomo00Gooooo1?ooO`26oooooaGoo`009Oooool1o`00007ooooo00000ol0003ooooooooo
o`0Vooooo`03ool00?oooooooooo00Cooooo1?ooO`08ooooo`Coogl03oooool00ooo003ooooooomo
0003oomo00Gooooo1?ooO`26oooooaGoo`009Oooool1o`00007ooooo00000ol0003oooooooooo`0W
ooooo`03ool00?oooooooooo00?ooooo1?ooO`09ooooo`;oogl04Oooool01?oo003ooooooomo0?oo
O`07ooooo`?oogl0Q_oooolEool002Gooooo0Ol00001ooooo`0000?o0000ooooooooool09oooool0
0ooo003oooooooooo`04ooooo`;oogl07_ooool00ooo003oooooooooo`07ooooo`Coogl0QOoooolE
ool002Gooooo0Ol00001ooooo`0000?o0000ooooooooool0:?ooool00ooo003oooooooooo`0Toooo
o`03ool00?oooooooooo00Kooooo1?ooO`25oooooaGoo`009Oooool1o`00007ooooo00000ol0003o
ooooooooo`0Yooooo`03ool00?oooooooooo02Cooooo0_oo00000oooooooogl0oomo0004ooooo`;o
ogl0Q_oooolEool002Gooooo0Ol00001ooooo`0000?o0000ooooooooool0:_ooool00ooo003ooooo
ooooo`0Cooooo`Coo`003_ooool01?oo003oogl0oomo0?ooO`2;oooooaGoo`009Oooool1o`00007o
oooo00000ol0003oooooooooo`0[ooooo`03ool00?oooooooooo017ooooo1_oo000=ooooo`04oomo
0?oo003oo`00oomo08_ooooo5Ooo000Uooooo`7o00000Oooool00003o`000?oooooooooo02cooooo
00?oo`00ooooooooool02?ooool2oomo00Gooooo2?oo000=ooooo`;oogl000?oo`00ooooooooool0
ROoooolEool002Gooooo0Ol00001ooooo`0000?o0000ooooooooool0;Oooool00ooo003ooooooooo
o`06ooooo`Coogl01?ooool8ool0013ooooo00?oo`00ooooooooool0R?oooolEool002Gooooo0Ol0
0001ooooo`0000?o0000ooooooooool0:oooool2oomo0003oooooooo003ooooo00Kooooo1?ooO`04
ooooo`Soo`004Oooool00ooo003oooooooooo`27oooooaGoo`009Oooool1o`00007ooooo00000ol0
003oooooooooo`0Zooooo`Coogl000?oooooool00?ooool01_ooool2oomo00Gooooo2?oo000;oooo
o`;oogl01Oooool00ooo003oooooooooo`09ooooo`;oogl0NooooolEool002Gooooo0Ol00001oooo
o`0000?o0000ooooooooool0:_ooool4oomo00;ooooo00?oo`00ooooooooool03?ooool6ool000_o
oooo1?ooO`04ooooo`03ool00?oooooooooo00Sooooo1?ooO`1joooooaGoo`009Oooool1o`00007o
oooo00000ol0003oooooooooo`0[ooooo`;oogl01?ooool00ooo003oooooooooo`0<ooooo`Coo`00
3?ooool4oomo00Gooooo00?oo`00ooooooooool01oooool4oomo07[ooooo5Ooo000Uooooo`7o0000
0Oooool00003o`000?oooooooooo03;ooooo0_oo000Mooooo`;oogl01oooool00ooo003ooooooooo
o`07ooooo`;oogl0]Oooool1o`00007ooooo00000ol0003oooooooooo`0dooooo`03ool00?oooooo
oooo02Cooooo00?oo`00ooooooooool0_Oooool1o`00007ooooo00000ol0003oooooooooo`0eoooo
o`03ool00?oooooooooo02Cooooo00?oo`00ooooooooool0_?ooool1o`00007ooooo00000ol0003o
ooooooooo`0fooooo`;oo`009Oooool00ooo003oooooooooo`2kooooo`7o00000Oooool00003o`00
0?oooooooooo03Sooooo0_oo00000oooO`3oooooooooo`02oomo01kooooo00?oo`00ooooooooool0
^oooool1o`00007ooooo00000ol0003oooooooooo`0hooooo`;oogl00_oo0004oomo01kooooo00?o
o`00ooooooooool0^_ooool1o`00007ooooo00000ol0003oooooooooo`0hooooo`Coogl00_oo0002
oomo01kooooo00?oo`00ooooooooool0^_ooool1o`00007ooooo00000ol0003oooooooooo`0ioooo
o`Googl000?oo`00ooooooooool07Oooool00ooo003oogl0oomo002jooooo`7o00000Oooool00003
o`000?oooooooooo03_ooooo1?ooO`02ool001gooooo00Coogl0ool00?ooO`3oogl0^Oooool1o`00
007ooooo00000ol0003oooooooooo`0looooo`;oogl00oooool2ool001_ooooo00Coogl0ool00?oo
O`3oogl0^Oooool1o`00007ooooo00000ol0003oooooooooo`13ooooo`;oo`006_ooool00oooO`3o
o`00ooooo`2iooooo`7o00000Oooool00003o`000?oooooooooo04Gooooo0_oo000Iooooo`03ool0
0?oooooooooo0;Sooooo0Ol00001ooooo`0000?o0000ooooooooool0Aoooool2ool001Gooooo0_oo
002kooooo`7o00000Oooool00003o`000?oooooooooo04Wooooo0ooo000@ooooo`;oo`00_Oooool1
o`00007ooooo00000ol0003oooooooooo`0aooooo`;oogl06Oooool3ool000cooooo00?oo`00oooo
ooooool0_Oooool1o`00007ooooo00000ol0003oooooooooo`0`ooooo`Coogl06oooool6ool000Co
oooo0_oo0030ooooo`7o00000Oooool00003o`000?oooooooooo033ooooo1?ooO`0Qooooo`Coo`00
`_ooool1o`00007ooooo00000ol0003oooooooooo`0aooooo`;oogl0j?ooool1o`00007ooooo0000
0ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLoooo
o`7o00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003ooooo
ooooo`1Booooo`Goo`3oa?ooool1o`00007ooooo00000ol0003oooooooooo`1Aooooo`Ooo`3o`ooo
ool1o`00007ooooo00000ol0003oooooooooo`1@ooooo`Woo`3o9?ooool2oomo09cooooo0Ol00001
ooooo`0000?o0000ooooooooool0Coooool;ool0ob;ooooo1?ooO`2Kooooo`7o00000Oooool00003
o`000?oooooooooo04oooooo2ooo0?lRooooo`Coogl0Voooool1o`00007ooooo00000ol0003ooooo
ooooo`1?ooooo`_oo`3o8oooool2oomo09cooooo0Ol00001ooooo`0000?o0000ooooooooool0Cooo
ool;ool0ol7ooooo0Ol00001ooooo`0000?o0000ooooooooool0Coooool;ool0ol7ooooo0Ol00001
ooooo`0000?o0000ooooooooool0D?ooool9ool0ol;ooooo0Ol00001ooooo`0000?o0000oooooooo
ool0DOooool7ool0o`_ooooo0_ooO`04ooooo`;oogl0/?ooool1o`00007ooooo00000ol0003ooooo
ooooo`1Booooo`Goo`3o2oooool4oomo00;ooooo1?ooO`2_ooooo`7o00000Oooool00003o`000?oo
oooooooo06;ooooo1?ooO`02ooooo`Coogl0[oooool1o`00007ooooo00000ol0003oooooooooo`1S
ooooo`;oogl01?ooool2oomo0;3ooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLoooo
o`7o00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003ooooo
ooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Ooo
ool00003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooo
oacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`00
0?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol0
0001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo
0?oooooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`00
00?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?oo
ool1o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000oooo
ooooool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007o
oooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooo
oolLooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0
003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o
00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003ooooooooo
o`3ooooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool0
0003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooooaco
oooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oo
oooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001
ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo0?oo
oooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o
0000ooooooooool0ooooool4ooooo`;oogl05_ooool1o`00007ooooo00000ol0003oooooooooo`3o
ooooo`?ooooo1?ooO`0Eooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo0oooool4oomo
01Gooooo0Ol00001ooooo`0000?o0000ooooooooool0ooooool4ooooo`;oogl05_ooool1o`00007o
oooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooo
oolLooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0
003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o
00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003ooooooooo
o`3ooooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool0
0003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooooaco
oooo0Ol00001ooooo`0000?o0000ooooooooool0]Oooool2oomo06Cooooo0Ol00001ooooo`0000?o
0000ooooooooool0]?ooool4oomo06?ooooo0Ol00001ooooo`0000?o0000ooooooooool0]?ooool4
oomo06?ooooo0Ol00001ooooo`0000?o0000ooooooooool0]Oooool2oomo03Gooooo0_ooO`0]oooo
o`7o00000Oooool00003o`000?oooooooooo0>Cooooo0_ooO`05ooooo`Coogl0;?ooool1o`00007o
oooo00000ol0003oooooooooo`3Sooooo`Coogl01?ooool4oomo02cooooo0Ol00001ooooo`0000?o
0000ooooooooool0`oooool2oomo01kooooo1?ooO`05ooooo`;oogl0;Oooool1o`00007ooooo0000
0ol0003oooooooooo`32ooooo`Coogl02ol00?lCooooo`;oogl0=Oooool1o`00007ooooo00000ol0
003oooooooooo`32ooooo`Co003o2oooool2o`00odSooooo0Ol00001ooooo`0000?o0000oooooooo
ool0__ooool4o`00o`03ooooooooO`3oogl000kooooo0_l00?m6ooooo`7o00000Oooool00003o`00
0?oooooooooo0;Wooooo0_ooO`03o`00oaOooooo0_l00?l9ooooo`;oogl0>Oooool1o`00007ooooo
00000ol0003oooooooooo`2gooooo`Co003o00?oogl0ooooooooool06Oooool2o`00o`Kooooo1?oo
O`0hooooo`7o00000Oooool00003o`000?oooooooooo0;Cooooo0ol00?l00oooooooogl0oomo0002
oomo01cooooo00?o003oooooooooool01?ooool4oomo00?ooooo0_ooO`0cooooo`7o00000Oooool0
0003o`000?oooooooooo0;;ooooo0_l00?l3oomo00;ooooo0_ooO`0Cooooo`;oogl02?ooool00ol0
0?ooooooooooo`05ooooo`;oogl00oooool4oomo03;ooooo0Ol00001ooooo`0000?o0000oooooooo
ool0/?ooool2o`00o`03ooooooooO`3oogl000;oogl01_ooool2oomo00kooooo1?ooO`07ooooo`03
o`00oooooooooooo00[ooooo1?ooO`0booooo`7o00000Oooool00003o`000?oooooooooo0:kooooo
0_l00?l4ooooo`;oogl01_ooool4oomo00gooooo1?ooO`07ooooo`03o`00oooooooooooo00_ooooo
0_ooO`0cooooo`7o00000Oooool00003o`000?oooooooooo08_ooooo0_ooO`0Pooooo`03o`00oooo
oooooooo00Cooooo0_ooO`06ooooo`Coogl03_ooool2oomo00Wooooo00?o003oooooooooool0?ooo
ool1o`00007ooooo00000ol0003oooooooooo`2:ooooo`Coogl07Oooool2o`00o`Kooooo1?ooO`06
ooooo`;oogl06_ooool00ol00?ooooooooooo`0oooooo`7o00000Oooool00003o`000?oooooooooo
08[ooooo1?ooO`0Looooo`03o`00oooooooooooo00Kooooo1?ooO`0Rooooo`03o`00oooooooooooo
03oooooo0Ol00001ooooo`0000?o0000ooooooooool0Roooool2oomo01_ooooo0_l00?l:ooooo`;o
ogl08oooool00ol00?ooooooooooo`0oooooo`7o00000Oooool00003o`000?oooooooooo09Kooooo
0_ooO`0>ooooo`;o003o:_ooool2oomo00Gooooo00?o003oooooooooool0?oooool1o`00007ooooo
00000ol0003oooooooooo`2Eooooo`Coogl03?ooool01?l00?oooooooomo0?ooO`0Xooooo`Coogl0
0oooool00ol00?ooooooooooo`10ooooo`7o00000Oooool00003o`000?oooooooooo09Gooooo1?oo
O`0:ooooo`;o003o00?ooooooomo0?ooO`000_ooO`0Wooooo`Coogl00oooool00ol00?oooooooooo
o`10ooooo`7o00000Oooool00003o`000?oooooooooo09Kooooo0_ooO`0:ooooo`04o`00oooooooo
ooooooooo`Coogl0:?ooool2oomo00Cooooo00?o003oooooooooool0@?ooool1o`00007ooooo0000
0ol0003oooooooooo`2Qooooo`03o`00oooooooooooo00?ooooo0_ooO`0^ooooo`03o`00oooooooo
oooo047ooooo0Ol00001ooooo`0000?o0000ooooooooool0X?ooool00ol00?ooooooooooo`0coooo
o`03o`00oooooooooooo01;ooooo0_ooO`0^ooooo`7o00000Oooool00003o`000?oooooooooo09ko
oooo0_l00?leooooo`03o`00oooooooooooo01;ooooo1?ooO`0]ooooo`7o00000Oooool00003o`00
0?oooooooooo09gooooo00?o003oooooooooool05Oooool4o`00oacooooo00?o003ooomo0?ooO`00
4_ooool4oomo02gooooo0Ol00001ooooo`0000?o0000ooooooooool0W?ooool00ol00?oooooooooo
o`0Eooooo`Ko003o6_ooool00ol00?ooogl0oomo0002oomo01;ooooo0_ooO`0^ooooo`7o00000Ooo
ool00003o`000?oooooooooo09_ooooo00?o003oooooooooool05Oooool8o`00oaSooooo00?o003o
ooooooooO`000oooO`12ooooo`7o00000Oooool00003o`000?oooooooooo09_ooooo00?o003ooooo
ooooool05Oooool8o`00oaOooooo00Co003ooooooooooooooooo0_ooO`13ooooo`7o00000Oooool0
0003o`000?oooooooooo09[ooooo00?o003oooooooooool05_ooool8o`00oaKooooo00?o003ooooo
ooooool0Aoooool1o`00007ooooo00000ol0003oooooooooo`2Iooooo`03o`00oooooooooooo00co
oooo0_ooO`08ooooo`03oomo0?l00?oo003o00Ko003o5Oooool00ol00?ooooooooooo`02oomo04Ko
oooo0Ol00001ooooo`0000?o0000ooooooooool0VOooool00ol00?ooooooooooo`0:ooooo`Googl0
1oooool2oomo00Ko003o4oooool2oomo0003o`00oooooooooooo00Coogl0AOooool1o`00007ooooo
00000ol0003oooooooooo`2Hooooo`03o`00oooooooooooo00[ooooo1_ooO`08ooooo`;oogl01?l0
0?lCooooo`;oogl00_l00?l2ooooo`Coogl0AOooool1o`00007ooooo00000ol0003oooooooooo`2H
ooooo`03o`00oooooooooooo00[ooooo1OooO`0Rooooo`04oomo0?l00?ooogl0oomo00?ooooo0_oo
O`16ooooo`7o00000Oooool00003o`000?oooooooooo07Kooooo0_ooO`0Oooooo`03o`00oooooooo
oooo00cooooo0_ooO`0Tooooo`03o`00ooooO`3oogl004cooooo0Ol00001ooooo`0000?o0000oooo
ooooool0MOooool4oomo01kooooo00?o003oooooooooool0<Oooool00ol00?ooooooooooo`1=oooo
o`7o00000Oooool00003o`000?oooooooooo07Gooooo1?ooO`0:ooooo`;oogl04Oooool00ol00?oo
ooooooooo`0aooooo`03o`00oooooooooooo04kooooo0Ol00001ooooo`0000?o0000ooooooooool0
M_ooool2oomo00[ooooo1?ooO`0?ooooo`03o`00oooooooooooo01Sooooo0_ooO`0Gooooo`03o`00
oooooooooooo04oooooo0Ol00001ooooo`0000?o0000ooooooooool0P_ooool4oomo00oooooo00?o
003oooooooooool05oooool4oomo01Cooooo0_l00?mBooooo`7o00000Oooool00003o`000?oooooo
oooo08?ooooo0_ooO`0?ooooo`03o`00oooooooooooo01;ooooo0_ooO`04ooooo`Coogl04Oooool3
o`00oeCooooo0Ol00001ooooo`0000?o0000ooooooooool0U?ooool00ol00?ooooooooooo`0Aoooo
o`Coogl01?ooool2oomo013ooooo0_l00?mGooooo`7o00000Oooool00003o`000?oooooooooo09Co
oooo00?o003oooooooooool04Oooool4oomo01Gooooo00?o003oooooooooool0Eoooool1o`00007o
oooo00000ol0003oooooooooo`2Dooooo`03o`00oooooooooooo01;ooooo0_ooO`0Dooooo`;o003o
F_ooool1o`00007ooooo00000ol0003oooooooooo`2Dooooo`03o`00oooooooooooo02Kooooo0_l0
0?mLooooo`7o00000Oooool00003o`000?oooooooooo09Gooooo00?o003oooooooooool09?ooool0
0ol00?ooooooooooo`1Looooo`7o00000Oooool00003o`000?oooooooooo09Gooooo00?o003ooooo
ooooool08_ooool2o`00oeoooooo0Ol00001ooooo`0000?o0000ooooooooool0UOooool00ol00?oo
ooooooooo`0Pooooo`;o003oHOooool1o`00007ooooo00000ol0003oooooooooo`24ooooo`;oogl0
3oooool2o`00oaoooooo0_l00?mSooooo`7o00000Oooool00003o`000?oooooooooo08?ooooo1?oo
O`0@ooooo`;o003o6_ooool3o`00ofGooooo0Ol00001ooooo`0000?o0000ooooooooool0Poooool4
oomo01;ooooo0_l00?lDooooo`Co003oJ?ooool1o`00007ooooo00000ol0003oooooooooo`24oooo
o`;oogl05Oooool3o`00o`kooooo0ol00?l3ooooo`;oogl0Ioooool1o`00007ooooo00000ol0003o
ooooooooo`2Nooooo`?o003o1Oooool6o`00o`Gooooo1?ooO`1Vooooo`7o00000Oooool00003o`00
0?oooooooooo0:7ooooo1Ol00?l;ooooo`Coogl0I_ooool1o`00007ooooo00000ol0003ooooooooo
o`2booooo`;oogl0Ioooool1o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001
ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo07_o
oooo0_ooO`2Nooooo`7o00000Oooool00003o`000?oooooooooo07[ooooo1?ooO`2Mooooo`7o0000
0Oooool00003o`000?oooooooooo07[ooooo1?ooO`0Pooooo`;oogl0Noooool1o`00007ooooo0000
0ol0003oooooooooo`1kooooo`;oogl08?ooool4oomo07[ooooo0Ol00001ooooo`0000?o0000oooo
ooooool0WOooool4oomo07[ooooo0Ol00001ooooo`0000?o0000ooooooooool0T?ooool2oomo00co
oooo0_ooO`1kooooo`7o00000Oooool00003o`000?oooooooooo08oooooo1?ooO`28ooooo`7o0000
0Oooool00003o`000?oooooooooo08oooooo1?ooO`28ooooo`7o00000Oooool00003o`000?oooooo
oooo093ooooo0_ooO`0Sooooo`;oogl0I?ooool1o`00007ooooo00000ol0003oooooooooo`2doooo
o`Coogl0Hoooool1o`00007ooooo00000ol0003oooooooooo`2dooooo`Coogl0Hoooool1o`00007o
oooo00000ol0003oooooooooo`2eooooo`;oogl0I?ooool1o`00007ooooo00000ol0003ooooooooo
o`3ooooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool0
0003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooooaco
oooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oo
oooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001
ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo0?oo
oooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o
0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1
o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000oooooooo
ool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo
00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolL
ooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003o
ooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o0000
0Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3o
oooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003
o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo
0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oooooo
oooo0?oooooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001oooo
o`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo
7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000
ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00
007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0
oooooolLooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo0000
0ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0S_ooool2oomo
08_ooooo0Ol00001ooooo`0000?o0000ooooooooool0SOooool4oomo08[ooooo0Ol00001ooooo`00
00?o0000ooooooooool0SOooool4oomo08[ooooo0Ol00001ooooo`0000?o0000ooooooooool0S_oo
ool2oomo08_ooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool0
0003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooooaco
oooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oo
oooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001
ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo0?oo
oooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o
0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1
o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000oooooooo
ool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo
00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolL
ooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003o
ooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o0000
0Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3o
oooooacooooo0Ol00001ooooo`00ool0000Po`00007ooooo0000\
\>"],
  ImageRangeCache->{{{0, 287}, {287, 0}} -> {-1.01089, -1.01089, 0.00704453, \
0.00704453}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.49505 0.5 0.49505 [
[ 0 0 -0.125 0 ]
[ 0 0 -0.125 0 ]
[ 0 1 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
0 0 m
1 0 L
s
0 0 m
0 1 L
s
0 1 m
1 1 L
s
1 0 m
1 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
1 .5 0 r
.015 w
.03175 .1355 Mdot
.03435 .12523 Mdot
.11137 .12765 Mdot
.14107 .18841 Mdot
.16218 .24538 Mdot
.17294 .21053 Mdot
.18267 .18577 Mdot
.18434 .1304 Mdot
.18553 .30956 Mdot
.20401 .239 Mdot
.21247 .27571 Mdot
.21687 .20845 Mdot
.22376 .2799 Mdot
.22832 .27485 Mdot
.29063 .20974 Mdot
.29686 .25079 Mdot
.30487 .22936 Mdot
.30683 .34623 Mdot
.32055 .20902 Mdot
.32574 .21979 Mdot
.34472 .28521 Mdot
.35998 .36393 Mdot
.36335 .24976 Mdot
.3794 .36608 Mdot
.42386 .66992 Mdot
.44391 .74519 Mdot
.45059 .34198 Mdot
.47208 .67586 Mdot
.47436 .71381 Mdot
.49778 .59825 Mdot
.50874 .91643 Mdot
.51516 .76219 Mdot
.53655 .61374 Mdot
.56563 .75219 Mdot
.59189 .65665 Mdot
.59581 .61604 Mdot
.59923 .6556 Mdot
.60292 .68499 Mdot
.62656 .67779 Mdot
.63555 .72451 Mdot
.63919 .652 Mdot
.64169 .6004 Mdot
.64246 .58611 Mdot
.64496 .54267 Mdot
.64608 .77288 Mdot
.65077 .64308 Mdot
.66065 .57816 Mdot
.67474 .59169 Mdot
.69296 .563 Mdot
.72815 .65902 Mdot
.73169 .58879 Mdot
.74669 .61318 Mdot
.74821 .65474 Mdot
.75963 .63781 Mdot
.79673 .57809 Mdot
.80925 .55852 Mdot
.81525 .58444 Mdot
.83417 .62985 Mdot
.83598 .55526 Mdot
.91595 .49319 Mdot
1 0 0 r
.005 w
.16128 .17044 m
.18734 .17269 L
.21339 .17909 L
.2345 .18734 L
.23945 .19126 L
.2655 .20415 L
.27874 .21339 L
.29156 .22295 L
.31204 .23945 L
.31761 .24532 L
.33549 .2655 L
.34367 .28341 L
.34499 .29156 L
.34367 .29798 L
.31761 .3104 L
.29156 .30711 L
.2655 .30014 L
.24507 .29156 L
.23945 .28747 L
.21339 .27402 L
.20155 .2655 L
.18734 .25472 L
.16884 .23945 L
.16128 .2313 L
.14618 .21339 L
.13806 .18734 L
.16128 .17044 L
s
0 0 1 r
.65633 .57701 m
.68239 .56842 L
.70844 .56313 L
.7345 .56168 L
.76055 .5752 L
.76359 .57817 L
.76859 .60422 L
.76055 .62333 L
.75627 .63028 L
.7345 .65485 L
.73298 .65633 L
.70844 .6775 L
.69922 .68239 L
.68239 .69294 L
.65633 .70579 L
.64983 .70844 L
.63028 .71539 L
.60422 .72268 L
.57817 .72651 L
.55211 .7214 L
.53145 .70844 L
.52926 .68239 L
.54239 .65633 L
.55211 .63983 L
.56625 .63028 L
.57817 .6193 L
.60119 .60422 L
.60422 .60227 L
.63028 .58726 L
.65315 .57817 L
.65633 .57701 L
s
1 0 0 r
.03 w
.24141 .24033 Mdot
0 0 1 r
.64872 .64417 Mdot
1 0 0 r
.79703 .00495 m
.79703 .25248 L
.87129 .25248 L
.87129 .00495 L
F
0 0 1 r
.89604 .00495 m
.89604 .00495 L
.9703 .00495 L
.9703 .00495 L
F
1 0 1 r
.04 w
.32055 .20902 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P000182000`400?l00000o`00003ooooooolQ
ooooo`00ool0000Po`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`00
00?o0000ooooooooool0hOoooolEool002Gooooo0Ol00001ooooo`0000?o0000ooooooooool0hOoo
oolEool002Gooooo0Ol00001ooooo`0000?o0000ooooooooool0hOoooolEool002Gooooo0Ol00001
ooooo`0000?o0000ooooooooool0hOoooolEool002Gooooo0Ol00001ooooo`0000?o0000oooooooo
ool0hOoooolEool002Gooooo0Ol00001ooooo`0000?o0000ooooooooool0hOoooolEool002Gooooo
0Ol00001ooooo`0000?o0000ooooooooool0hOoooolEool002Gooooo0Ol00001ooooo`0000?o0000
ooooooooool0hOoooolEool002Gooooo0Ol00001ooooo`0000?o0000ooooooooool0hOoooolEool0
02Gooooo0Ol00001ooooo`0000?o0000ooooooooool0hOoooolEool002Gooooo0Ol00001ooooo`00
00?o0000ooooooooool0hOoooolEool002Gooooo0Ol00001ooooo`0000?o0000ooooooooool0hOoo
oolEool002Gooooo0Ol00001ooooo`0000?o0000ooooooooool0hOoooolEool002Gooooo0Ol00001
ooooo`0000?o0000ooooooooool0hOoooolEool002Gooooo0Ol00001ooooo`0000?o0000oooooooo
ool0hOoooolEool002Gooooo0Ol00001ooooo`0000?o0000ooooooooool0hOoooolEool002Gooooo
0Ol00001ooooo`0000?o0000ooooooooool0hOoooolEool002Gooooo0Ol00001ooooo`0000?o0000
ooooooooool0hOoooolEool002Gooooo0Ol00001ooooo`0000?o0000ooooooooool0hOoooolEool0
02Gooooo0Ol00001ooooo`0000?o0000ooooooooool0hOoooolEool002Gooooo0Ol00001ooooo`00
00?o0000ooooooooool0hOoooolEool002Gooooo0Ol00001ooooo`0000?o0000ooooooooool0hOoo
oolEool002Gooooo0Ol00001ooooo`0000?o0000ooooooooool0hOoooolEool002Gooooo0Ol00001
ooooo`0000?o0000ooooooooool0hOoooolEool002Gooooo0Ol00001ooooo`0000?o0000oooooooo
ool0hOoooolEool002Gooooo0Ol00001ooooo`0000?o0000ooooooooool0hOoooolEool002Gooooo
0Ol00001ooooo`0000?o0000ooooooooool0hOoooolEool002Gooooo0Ol00001ooooo`0000?o0000
ooooooooool0hOoooolEool002Gooooo0Ol00001ooooo`0000?o0000ooooooooool0hOoooolEool0
02Gooooo0Ol00001ooooo`0000?o0000ooooooooool0hOoooolEool002Gooooo0Ol00001ooooo`00
00?o0000ooooooooool0hOoooolEool002Gooooo0Ol00001ooooo`0000?o0000ooooooooool0hOoo
oolEool002Gooooo0Ol00001ooooo`0000?o0000ooooooooool01_ooool2oomo0=Wooooo5Ooo000U
ooooo`7o00000Oooool00003o`000?oooooooooo00Gooooo1?ooO`0Cooooo`;oogl0`ooooolEool0
02Gooooo0Ol00001ooooo`0000?o0000ooooooooool01Oooool4oomo01;ooooo1?ooO`0Booooo`;o
ogl0[_oooolEool002Gooooo0Ol00001ooooo`0000?o0000ooooooooool01Oooool3oomo01?ooooo
1?ooO`0Aooooo`Coogl0[OoooolEool002Gooooo0Ol00001ooooo`0000?o0000ooooooooool01?oo
ool4oomo01Cooooo0_ooO`0Booooo`Coogl0[OoooolEool002Gooooo0Ol00001ooooo`0000?o0000
ooooooooool01?ooool4oomo02Wooooo0_ooO`2^oooooaGoo`009Oooool1o`00007ooooo00000ol0
003oooooooooo`05ooooo`;oogl0f_oooolEool002Gooooo0Ol00001ooooo`0000?o0000oooooooo
ool0hOoooolEool002Gooooo0Ol00001ooooo`0000?o0000ooooooooool0hOoooolEool002Gooooo
0Ol00001ooooo`0000?o0000ooooooooool0hOoooolEool002Gooooo0Ol00001ooooo`0000?o0000
ooooooooool0hOoooolEool002Gooooo0Ol00001ooooo`0000?o0000ooooooooool0hOoooolEool0
02Gooooo0Ol00001ooooo`0000?o0000ooooooooool0hOoooolEool002Gooooo0Ol00001ooooo`00
00?o0000ooooooooool0hOoooolEool002Gooooo0Ol00001ooooo`0000?o0000ooooooooool0:_oo
ool6ool00;7ooooo5Ooo000Uooooo`7o00000Oooool00003o`000?oooooooooo02Wooooo00?oo`00
ooooooooool01?ooool5ool00:cooooo5Ooo000Uooooo`7o00000Oooool00003o`000?oooooooooo
02Oooooo0_oo000<ooooo`Coo`00Z?oooolEool002Gooooo0Ol00001ooooo`0000?o0000oooooooo
ool09_ooool00ooo003oooooooooo`0@ooooo`Coo`00Y?oooolEool002Gooooo0Ol00001ooooo`00
00?o0000ooooooooool09?ooool00oooO`3oo`00ooooo`09ooooo`;oogl02oooool3ool00:7ooooo
5Ooo000Uooooo`7o00000Oooool00003o`000?oooooooooo02?ooooo00Coogl0ool00?ooO`3oogl0
2?ooool4oomo00gooooo00?oo`00ooooooooool0W_oooolEool002Gooooo0Ol00001ooooo`0000?o
0000ooooooooool08oooool01?ooO`3oo`00oomo0?ooO`08ooooo`Coogl03_ooool2ool009kooooo
5Ooo000Uooooo`7o00000Oooool00003o`000?oooooooooo02Cooooo00?oogl0ool00?ooool02Ooo
ool2oomo017ooooo0_oo000Aooooo`Goo`3oQ_oooolEool002Gooooo0Ol00001ooooo`0000?o0000
ooooooooool09Oooool00ooo003oooooooooo`0Mooooo`;oo`003_ooool7ool0ohGooooo5Ooo000U
ooooo`7o00000Oooool00003o`000?oooooooooo02Gooooo00?oo`00ooooooooool07oooool2ool0
00_ooooo2Ooo0?n4oooooaGoo`009Oooool1o`00007ooooo00000ol0003oooooooooo`0Vooooo`03
ool00?oooooooooo017ooooo0_ooO`0=ooooo`;oo`001?ooool2oomo00;ooooo2ooo0?n3oooooaGo
o`009Oooool1o`00007ooooo00000ol0003oooooooooo`0Vooooo`03ool00?oooooooooo00Gooooo
0_ooO`09ooooo`Coogl03_ooool00ooo003oooooooooo`04oomo0003oooooooo0?ooo`3o00Woo`3o
PooooolEool002Gooooo0Ol00001ooooo`0000?o0000ooooooooool09_ooool00ooo003ooooooooo
o`04ooooo`Coogl02?ooool4oomo00oooooo00?oo`00ooooooooO`000oooO`000oooooooo`3oool0
o`09ool0oh?ooooo5Ooo000Uooooo`7o00000Oooool00003o`000?oooooooooo02Oooooo00?oo`00
ooooooooool00oooool4oomo00Wooooo0_ooO`0Aooooo`04ool00?ooooooogl0oomo00;ooooo2ooo
0?n3oooooaGoo`009Oooool1o`00007ooooo00000ol0003oooooooooo`0Wooooo`03ool00?oooooo
oooo00Cooooo0_ooO`0Nooooo`03ool00?oooooooooo00;ooooo2ooo0?n3oooooaGoo`009Oooool1
o`00007ooooo00000ol0003oooooooooo`0Xooooo`03ool00?oooooooooo02Cooooo00?oo`00oooo
ooooool00_ooool9ool0ohCooooo5Ooo000Uooooo`7o00000Oooool00003o`000?oooooooooo02Wo
oooo00?oo`00ooooooooool09?ooool2ool00003ooooooooO`3oogl000Ooo`3oQOoooolEool002Go
oooo0Ol00001ooooo`0000?o0000ooooooooool0:_ooool00ooo003oooooooooo`0Cooooo`Coo`00
3_ooool01?oo003oogl0oomo0?ooO`05ool0ohKooooo5Ooo000Uooooo`7o00000Oooool00003o`00
0?oooooooooo02_ooooo00?oo`00ooooooooool04Oooool6ool000gooooo00Coogl0ool00?oo003o
ogl0RooooolEool002Gooooo0Ol00001ooooo`0000?o0000ooooooooool0;?ooool00ooo003ooooo
ooooo`08ooooo`;oogl01Oooool8ool000gooooo0_ooO`000ooo003oooooooooo`29oooooaGoo`00
9Oooool1o`00007ooooo00000ol0003oooooooooo`0]ooooo`03ool00?oooooooooo00Kooooo1?oo
O`04ooooo`Soo`004?ooool00ooo003oooooooooo`28oooooaGoo`009Oooool1o`00007ooooo0000
0ol0003oooooooooo`0[ooooo`;oogl000?oooooool00?ooool01_ooool4oomo00Cooooo2?oo000A
ooooo`03ool00?oooooooooo08Oooooo5Ooo000Uooooo`7o00000Oooool00003o`000?oooooooooo
02[ooooo1?ooO`000oooooooo`00ooooo`06ooooo`;oogl01Oooool8ool000_ooooo0_ooO`05oooo
o`03ool00?oooooooooo00Wooooo0_ooO`1koooooaGoo`009Oooool1o`00007ooooo00000ol0003o
ooooooooo`0Zooooo`Coogl00_ooool00ooo003oooooooooo`0<ooooo`Koo`002oooool4oomo00Co
oooo00?oo`00ooooooooool02?ooool4oomo07[ooooo5Ooo000Uooooo`7o00000Oooool00003o`00
0?oooooooooo02_ooooo0_ooO`04ooooo`03ool00?oooooooooo00cooooo1?oo000<ooooo`Coogl0
1Oooool00ooo003oooooooooo`07ooooo`Coogl0N_oooolEool002Gooooo0Ol00001ooooo`0000?o
0000ooooooooool0<_ooool2ool001gooooo0_ooO`07ooooo`03ool00?oooooooooo00Oooooo0_oo
O`2eooooo`7o00000Oooool00003o`000?oooooooooo03Cooooo00?oo`00ooooooooool09?ooool0
0ooo003oooooooooo`2mooooo`7o00000Oooool00003o`000?oooooooooo03Gooooo00?oo`00oooo
ooooool09?ooool00ooo003oooooooooo`2looooo`7o00000Oooool00003o`000?oooooooooo03Ko
oooo0_oo000Uooooo`03ool00?oooooooooo0;_ooooo0Ol00001ooooo`0000?o0000ooooooooool0
>?ooool2ool00003oomo0?oooooooooo00;oogl07_ooool00ooo003oooooooooo`2kooooo`7o0000
0Oooool00003o`000?oooooooooo03Sooooo0_ooO`02ool000Coogl07_ooool00ooo003ooooooooo
o`2jooooo`7o00000Oooool00003o`000?oooooooooo03Sooooo1?ooO`02ool000;oogl07_ooool0
0ooo003oooooooooo`2jooooo`7o00000Oooool00003o`000?oooooooooo03Wooooo1OooO`000ooo
003oooooooooo`0Mooooo`03ool00?ooO`3oogl00;[ooooo0Ol00001ooooo`0000?o0000oooooooo
ool0>oooool4oomo00;oo`007Oooool01?ooO`3oo`00oomo0?ooO`2iooooo`7o00000Oooool00003
o`000?oooooooooo03cooooo0_ooO`03ooooo`;oo`006oooool01?ooO`3oo`00oomo0?ooO`2ioooo
o`7o00000Oooool00003o`000?oooooooooo04?ooooo0_oo000Jooooo`03oomo0?oo003ooooo0;Wo
oooo0Ol00001ooooo`0000?o0000ooooooooool0AOooool2ool001Wooooo00?oo`00ooooooooool0
^?ooool1o`00007ooooo00000ol0003oooooooooo`17ooooo`;oo`005Oooool2ool00;_ooooo0Ol0
0001ooooo`0000?o0000ooooooooool0BOooool3ool0013ooooo0_oo002mooooo`7o00000Oooool0
0003o`000?oooooooooo037ooooo0_ooO`0Iooooo`?oo`003?ooool00ooo003oooooooooo`2moooo
o`7o00000Oooool00003o`000?oooooooooo033ooooo1?ooO`0Kooooo`Koo`001?ooool2ool00<3o
oooo0Ol00001ooooo`0000?o0000ooooooooool0<?ooool4oomo027ooooo1?oo0032ooooo`7o0000
0Oooool00003o`000?oooooooooo037ooooo0_ooO`3Xooooo`7o00000Oooool00003o`000?oooooo
oooo0?oooooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001oooo
o`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo
7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000
ooooooooool0OOooool2oomo09cooooo0Ol00001ooooo`0000?o0000ooooooooool0O?ooool4oomo
09_ooooo0Ol00001ooooo`0000?o0000ooooooooool0E?ooool2oomo02Kooooo1?ooO`2Kooooo`7o
00000Oooool00003o`000?oooooooooo05?ooooo1?ooO`0Vooooo`;oogl0W?ooool1o`00007ooooo
00000ol0003oooooooooo`1Cooooo`Coogl0a?ooool1o`00007ooooo00000ol0003oooooooooo`1D
ooooo`;oogl0aOooool1o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001oooo
o`0000?o0000ooooooooool0Hoooool2oomo00Cooooo0_ooO`2`ooooo`7o00000Oooool00003o`00
0?oooooooooo06;ooooo1?ooO`02ooooo`Coogl0[oooool1o`00007ooooo00000ol0003ooooooooo
o`1Rooooo`Coogl00_ooool4oomo0:oooooo0Ol00001ooooo`0000?o0000ooooooooool0Hoooool2
oomo00Cooooo0_ooO`2`ooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00
007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0
oooooolLooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo0000
0ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLoooo
o`7o00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003ooooo
ooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Ooo
ool00003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooo
oacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`00
0?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol0
0001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo
0?oooooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`00
00?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?oo
ool1o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000oooo
ooooool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007o
oooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooo
oolLooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0
003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o
00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003ooooooooo
o`3ooooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool0
0003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooooaco
oooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oo
oooooooo0?oooooo1?ooool2oomo01Kooooo0Ol00001ooooo`0000?o0000ooooooooool0ooooool3
ooooo`Coogl05Oooool1o`00007ooooo00000ol0003oooooooooo`3oooooo`?ooooo1?ooO`0Eoooo
o`7o00000Oooool00003o`000?oooooooooo0?oooooo1?ooool2oomo01Kooooo0Ol00001ooooo`00
00?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?oo
ool1o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000oooo
ooooool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007o
oooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooo
oolLooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0
003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o
00000Oooool00003o`000?oooooooooo0;Gooooo0_ooO`1Tooooo`7o00000Oooool00003o`000?oo
oooooooo0;Cooooo1?ooO`1Sooooo`7o00000Oooool00003o`000?oooooooooo0;Cooooo1?ooO`1S
ooooo`7o00000Oooool00003o`000?oooooooooo0;Gooooo0_ooO`0eooooo`;oogl0;Oooool1o`00
007ooooo00000ol0003oooooooooo`3Tooooo`;oogl01Oooool4oomo02cooooo0Ol00001ooooo`00
00?o0000ooooooooool0hoooool4oomo00Cooooo1?ooO`0/ooooo`7o00000Oooool00003o`000?oo
oooooooo0<?ooooo0_ooO`0Nooooo`Coogl01Oooool2oomo02gooooo0Ol00001ooooo`0000?o0000
ooooooooool0`_ooool4oomo00_o003o4oooool2oomo03Gooooo0Ol00001ooooo`0000?o0000oooo
ooooool0`_ooool4o`00o`_ooooo0_l00?m8ooooo`7o00000Oooool00003o`000?oooooooooo0;ko
oooo1?l00?l00oooooooogl0oomo000>ooooo`;o003oA_ooool1o`00007ooooo00000ol0003ooooo
ooooo`2iooooo`;oogl00ol00?lGooooo`;o003o2Oooool2oomo03Wooooo0Ol00001ooooo`0000?o
0000ooooooooool0]oooool4o`00o`03oomo0?oooooooooo01Wooooo0_l00?l6ooooo`Coogl0>?oo
ool1o`00007ooooo00000ol0003oooooooooo`2dooooo`?o003o00?ooooooomo0?ooO`000_ooO`0L
ooooo`03o`00oooooooooooo00Cooooo1?ooO`03ooooo`;oogl0<oooool1o`00007ooooo00000ol0
003oooooooooo`2booooo`;o003o0oooO`02ooooo`;oogl04oooool2oomo00Sooooo00?o003ooooo
ooooool01Oooool2oomo00?ooooo1?ooO`0booooo`7o00000Oooool00003o`000?oooooooooo0;3o
oooo0_l00?l00oooooooogl0oomo0002oomo00Kooooo0_ooO`0>ooooo`Coogl01oooool00ol00?oo
ooooooooo`0:ooooo`Coogl0<_ooool1o`00007ooooo00000ol0003oooooooooo`2^ooooo`;o003o
1?ooool2oomo00Kooooo1?ooO`0=ooooo`Coogl01oooool00ol00?ooooooooooo`0;ooooo`;oogl0
<oooool1o`00007ooooo00000ol0003oooooooooo`2;ooooo`;oogl08?ooool00ol00?oooooooooo
o`04ooooo`;oogl01_ooool4oomo00kooooo0_ooO`09ooooo`03o`00oooooooooooo03oooooo0Ol0
0001ooooo`0000?o0000ooooooooool0R_ooool4oomo01gooooo0_l00?l6ooooo`Coogl01_ooool2
oomo01[ooooo00?o003oooooooooool0?oooool1o`00007ooooo00000ol0003oooooooooo`2:oooo
o`Coogl07?ooool00ol00?ooooooooooo`06ooooo`Coogl08_ooool00ol00?ooooooooooo`0ooooo
o`7o00000Oooool00003o`000?oooooooooo08_ooooo0_ooO`0Kooooo`;o003o2_ooool2oomo02?o
oooo00?o003oooooooooool0?oooool1o`00007ooooo00000ol0003oooooooooo`2Fooooo`;oogl0
3_ooool2o`00ob[ooooo0_ooO`05ooooo`03o`00oooooooooooo03oooooo0Ol00001ooooo`0000?o
0000ooooooooool0UOooool4oomo00cooooo00Co003oooooooooO`3oogl0:?ooool4oomo00?ooooo
00?o003oooooooooool0@?ooool1o`00007ooooo00000ol0003oooooooooo`2Eooooo`Coogl02_oo
ool2o`00o`03ooooooooO`3oogl000;oogl09oooool4oomo00?ooooo00?o003oooooooooool0@?oo
ool1o`00007ooooo00000ol0003oooooooooo`2Fooooo`;oogl02_ooool01?l00?oooooooooooooo
ool4oomo02Sooooo0_ooO`04ooooo`03o`00oooooooooooo043ooooo0Ol00001ooooo`0000?o0000
ooooooooool0XOooool00ol00?ooooooooooo`03ooooo`;oogl0;_ooool00ol00?ooooooooooo`11
ooooo`7o00000Oooool00003o`000?oooooooooo0:3ooooo00?o003oooooooooool0<oooool00ol0
0?ooooooooooo`0Booooo`;oogl0;_ooool1o`00007ooooo00000ol0003oooooooooo`2Nooooo`;o
003o=Oooool00ol00?ooooooooooo`0Booooo`Coogl0;Oooool1o`00007ooooo00000ol0003ooooo
ooooo`2Mooooo`03o`00oooooooooooo01Gooooo1?l00?lLooooo`03o`00ooooO`3oogl001;ooooo
1?ooO`0]ooooo`7o00000Oooool00003o`000?oooooooooo09cooooo00?o003oooooooooool05Ooo
ool6o`00oa[ooooo00?o003ooomo0?ooO`000_ooO`0Booooo`;oogl0;_ooool1o`00007ooooo0000
0ol0003oooooooooo`2Kooooo`03o`00oooooooooooo01Gooooo2?l00?lHooooo`03o`00oooooooo
ogl000?oogl0@_ooool1o`00007ooooo00000ol0003oooooooooo`2Kooooo`03o`00oooooooooooo
01Gooooo2?l00?lGooooo`04o`00ooooooooooooooooo`;oogl0@oooool1o`00007ooooo00000ol0
003oooooooooo`2Jooooo`03o`00oooooooooooo01Kooooo2?l00?lFooooo`03o`00oooooooooooo
04Oooooo0Ol00001ooooo`0000?o0000ooooooooool0VOooool00ol00?ooooooooooo`0<ooooo`;o
ogl02?ooool00oooO`3o003oo`00o`06o`00oaGooooo00?o003oooooooooool00_ooO`16ooooo`7o
00000Oooool00003o`000?oooooooooo09Wooooo00?o003oooooooooool02_ooool5oomo00Oooooo
0_ooO`06o`00oa?ooooo0_ooO`000ol00?ooooooooooo`04oomo04Gooooo0Ol00001ooooo`0000?o
0000ooooooooool0V?ooool00ol00?ooooooooooo`0:ooooo`Koogl02?ooool2oomo00Co003o4ooo
ool2oomo00;o003o0_ooool4oomo04Gooooo0Ol00001ooooo`0000?o0000ooooooooool0V?ooool0
0ol00?ooooooooooo`0:ooooo`Googl08_ooool01?ooO`3o003ooomo0?ooO`03ooooo`;oogl0A_oo
ool1o`00007ooooo00000ol0003oooooooooo`1fooooo`;oogl07oooool00ol00?ooooooooooo`0<
ooooo`;oogl09?ooool00ol00?ooogl0oomo001<ooooo`7o00000Oooool00003o`000?oooooooooo
07Gooooo1?ooO`0Nooooo`03o`00oooooooooooo037ooooo00?o003oooooooooool0COooool1o`00
007ooooo00000ol0003oooooooooo`1eooooo`Coogl02_ooool2oomo017ooooo00?o003ooooooooo
ool0<Oooool00ol00?ooooooooooo`1>ooooo`7o00000Oooool00003o`000?oooooooooo07Kooooo
0_ooO`0:ooooo`Coogl03oooool00ol00?ooooooooooo`0Hooooo`;oogl05oooool00ol00?oooooo
ooooo`1?ooooo`7o00000Oooool00003o`000?oooooooooo08;ooooo1?ooO`0?ooooo`03o`00oooo
oooooooo01Oooooo1?ooO`0Dooooo`;o003oD_ooool1o`00007ooooo00000ol0003oooooooooo`23
ooooo`;oogl03oooool00ol00?ooooooooooo`0Booooo`;oogl01?ooool4oomo017ooooo0ol00?mD
ooooo`7o00000Oooool00003o`000?oooooooooo09Cooooo00?o003oooooooooool04Oooool4oomo
00Cooooo0_ooO`0@ooooo`;o003oEoooool1o`00007ooooo00000ol0003oooooooooo`2Dooooo`03
o`00oooooooooooo017ooooo1?ooO`0Eooooo`03o`00oooooooooooo05Oooooo0Ol00001ooooo`00
00?o0000ooooooooool0U?ooool00ol00?ooooooooooo`0Booooo`;oogl05?ooool2o`00oe[ooooo
0Ol00001ooooo`0000?o0000ooooooooool0U?ooool00ol00?ooooooooooo`0Vooooo`;o003oG?oo
ool1o`00007ooooo00000ol0003oooooooooo`2Eooooo`03o`00oooooooooooo02Cooooo00?o003o
ooooooooool0G?ooool1o`00007ooooo00000ol0003oooooooooo`2Eooooo`03o`00oooooooooooo
02;ooooo0_l00?mOooooo`7o00000Oooool00003o`000?oooooooooo09Gooooo00?o003ooooooooo
ool08?ooool2o`00of7ooooo0Ol00001ooooo`0000?o0000ooooooooool0Q?ooool2oomo00oooooo
0_l00?lOooooo`;o003oHoooool1o`00007ooooo00000ol0003oooooooooo`23ooooo`Coogl04?oo
ool2o`00oa[ooooo0ol00?mUooooo`7o00000Oooool00003o`000?oooooooooo08?ooooo1?ooO`0B
ooooo`;o003o5?ooool4o`00ofSooooo0Ol00001ooooo`0000?o0000ooooooooool0Q?ooool2oomo
01Gooooo0ol00?l>ooooo`?o003o0oooool2oomo06Oooooo0Ol00001ooooo`0000?o0000oooooooo
ool0W_ooool3o`00o`Gooooo1_l00?l5ooooo`Coogl0I_ooool1o`00007ooooo00000ol0003ooooo
ooooo`2Qooooo`Go003o2oooool4oomo06Kooooo0Ol00001ooooo`0000?o0000ooooooooool0/_oo
ool2oomo06Oooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool0
0003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003oooooooooo`1kooooo`;o
ogl0W_ooool1o`00007ooooo00000ol0003oooooooooo`1jooooo`Coogl0WOooool1o`00007ooooo
00000ol0003oooooooooo`1jooooo`Coogl08?ooool2oomo07_ooooo0Ol00001ooooo`0000?o0000
ooooooooool0Noooool2oomo023ooooo1?ooO`1jooooo`7o00000Oooool00003o`000?oooooooooo
09gooooo1?ooO`1jooooo`7o00000Oooool00003o`000?oooooooooo093ooooo0_ooO`0<ooooo`;o
ogl0Noooool1o`00007ooooo00000ol0003oooooooooo`2?ooooo`Coogl0R?ooool1o`00007ooooo
00000ol0003oooooooooo`2?ooooo`Coogl0R?ooool1o`00007ooooo00000ol0003oooooooooo`2@
ooooo`;oogl08oooool2oomo06Cooooo0Ol00001ooooo`0000?o0000ooooooooool0]?ooool4oomo
06?ooooo0Ol00001ooooo`0000?o0000ooooooooool0]?ooool4oomo06?ooooo0Ol00001ooooo`00
00?o0000ooooooooool0]Oooool2oomo06Cooooo0Ol00001ooooo`0000?o0000ooooooooool0oooo
oolLooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0
003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o
00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003ooooooooo
o`3ooooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool0
0003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooooaco
oooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oo
oooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001
ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo0?oo
oooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o
0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1
o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000oooooooo
ool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo
00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolL
ooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003o
ooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o0000
0Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3o
oooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003
o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo
0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oooooo
oooo0?oooooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001oooo
o`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo
7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000
ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo08kooooo0_ooO`2;oooo
o`7o00000Oooool00003o`000?oooooooooo08gooooo1?ooO`2:ooooo`7o00000Oooool00003o`00
0?oooooooooo08gooooo1?ooO`2:ooooo`7o00000Oooool00003o`000?oooooooooo08kooooo0_oo
O`2;ooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0
003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o
00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003ooooooooo
o`3ooooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool0
0003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooooaco
oooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oo
oooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001
ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo0?oo
oooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o
0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1
o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000oooooooo
ool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo
00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolL
ooooo`7o00000Oooool00?oo00008?l00001ooooo`00\
\>"],
  ImageRangeCache->{{{0, 287}, {287, 0}} -> {-1.01089, -1.01089, 0.00704453, \
0.00704453}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.49505 0.5 0.49505 [
[ 0 0 -0.125 0 ]
[ 0 0 -0.125 0 ]
[ 0 1 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
0 0 m
1 0 L
s
0 0 m
0 1 L
s
0 1 m
1 1 L
s
1 0 m
1 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
1 .5 0 r
.015 w
.03175 .1355 Mdot
.03435 .12523 Mdot
.11137 .12765 Mdot
.14107 .18841 Mdot
.16218 .24538 Mdot
.17294 .21053 Mdot
.18267 .18577 Mdot
.18434 .1304 Mdot
.18553 .30956 Mdot
.20401 .239 Mdot
.21247 .27571 Mdot
.21687 .20845 Mdot
.22376 .2799 Mdot
.22832 .27485 Mdot
.29063 .20974 Mdot
.29686 .25079 Mdot
.30487 .22936 Mdot
.30683 .34623 Mdot
.32055 .20902 Mdot
.32574 .21979 Mdot
.34472 .28521 Mdot
.35998 .36393 Mdot
.36335 .24976 Mdot
.3794 .36608 Mdot
.42386 .66992 Mdot
.44391 .74519 Mdot
.45059 .34198 Mdot
.47208 .67586 Mdot
.47436 .71381 Mdot
.49778 .59825 Mdot
.50874 .91643 Mdot
.51516 .76219 Mdot
.53655 .61374 Mdot
.56563 .75219 Mdot
.59189 .65665 Mdot
.59581 .61604 Mdot
.59923 .6556 Mdot
.60292 .68499 Mdot
.62656 .67779 Mdot
.63555 .72451 Mdot
.63919 .652 Mdot
.64169 .6004 Mdot
.64246 .58611 Mdot
.64496 .54267 Mdot
.64608 .77288 Mdot
.65077 .64308 Mdot
.66065 .57816 Mdot
.67474 .59169 Mdot
.69296 .563 Mdot
.72815 .65902 Mdot
.73169 .58879 Mdot
.74669 .61318 Mdot
.74821 .65474 Mdot
.75963 .63781 Mdot
.79673 .57809 Mdot
.80925 .55852 Mdot
.81525 .58444 Mdot
.83417 .62985 Mdot
.83598 .55526 Mdot
.91595 .49319 Mdot
1 0 0 r
.005 w
.16128 .17044 m
.18734 .17269 L
.21339 .17909 L
.2345 .18734 L
.23945 .19126 L
.2655 .20415 L
.27874 .21339 L
.29156 .22295 L
.31204 .23945 L
.31761 .24532 L
.33549 .2655 L
.34367 .28341 L
.34499 .29156 L
.34367 .29798 L
.31761 .3104 L
.29156 .30711 L
.2655 .30014 L
.24507 .29156 L
.23945 .28747 L
.21339 .27402 L
.20155 .2655 L
.18734 .25472 L
.16884 .23945 L
.16128 .2313 L
.14618 .21339 L
.13806 .18734 L
.16128 .17044 L
s
0 0 1 r
.65633 .57701 m
.68239 .56842 L
.70844 .56313 L
.7345 .56168 L
.76055 .5752 L
.76359 .57817 L
.76859 .60422 L
.76055 .62333 L
.75627 .63028 L
.7345 .65485 L
.73298 .65633 L
.70844 .6775 L
.69922 .68239 L
.68239 .69294 L
.65633 .70579 L
.64983 .70844 L
.63028 .71539 L
.60422 .72268 L
.57817 .72651 L
.55211 .7214 L
.53145 .70844 L
.52926 .68239 L
.54239 .65633 L
.55211 .63983 L
.56625 .63028 L
.57817 .6193 L
.60119 .60422 L
.60422 .60227 L
.63028 .58726 L
.65315 .57817 L
.65633 .57701 L
s
1 0 0 r
.03 w
.24141 .24033 Mdot
0 0 1 r
.64872 .64417 Mdot
1 0 0 r
.79703 .00495 m
.79703 .25248 L
.87129 .25248 L
.87129 .00495 L
F
0 0 1 r
.89604 .00495 m
.89604 .00495 L
.9703 .00495 L
.9703 .00495 L
F
1 0 1 r
.04 w
.32574 .21979 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P000182000`400?l00000o`00003oo`3ooolQ
0?ooo`00ool0000Po`000040oooo00000ol00000oooo0?ooo`3o0?oooa`0oooo0Ol000010?ooo`00
00?o00000?ooo`3oool0h@3ooolEool002D0oooo0Ol000010?ooo`0000?o00000?ooo`3oool0h@3o
oolEool002D0oooo0Ol000010?ooo`0000?o00000?ooo`3oool0h@3ooolEool002D0oooo0Ol00001
0?ooo`0000?o00000?ooo`3oool0h@3ooolEool002D0oooo0Ol000010?ooo`0000?o00000?ooo`3o
ool0h@3ooolEool002D0oooo0Ol000010?ooo`0000?o00000?ooo`3oool0h@3ooolEool002D0oooo
0Ol000010?ooo`0000?o00000?ooo`3oool0h@3ooolEool002D0oooo0Ol000010?ooo`0000?o0000
0?ooo`3oool0h@3ooolEool002D0oooo0Ol000010?ooo`0000?o00000?ooo`3oool0h@3ooolEool0
02D0oooo0Ol000010?ooo`0000?o00000?ooo`3oool0h@3ooolEool002D0oooo0Ol000010?ooo`00
00?o00000?ooo`3oool0h@3ooolEool002D0oooo0Ol000010?ooo`0000?o00000?ooo`3oool0h@3o
oolEool002D0oooo0Ol000010?ooo`0000?o00000?ooo`3oool0h@3ooolEool002D0oooo0Ol00001
0?ooo`0000?o00000?ooo`3oool0h@3ooolEool002D0oooo0Ol000010?ooo`0000?o00000?ooo`3o
ool0h@3ooolEool002D0oooo0Ol000010?ooo`0000?o00000?ooo`3oool0h@3ooolEool002D0oooo
0Ol000010?ooo`0000?o00000?ooo`3oool0h@3ooolEool002D0oooo0Ol000010?ooo`0000?o0000
0?ooo`3oool0h@3ooolEool002D0oooo0Ol000010?ooo`0000?o00000?ooo`3oool0h@3ooolEool0
02D0oooo0Ol000010?ooo`0000?o00000?ooo`3oool0h@3ooolEool002D0oooo0Ol000010?ooo`00
00?o00000?ooo`3oool0h@3ooolEool002D0oooo0Ol000010?ooo`0000?o00000?ooo`3oool0h@3o
oolEool002D0oooo0Ol000010?ooo`0000?o00000?ooo`3oool0h@3ooolEool002D0oooo0Ol00001
0?ooo`0000?o00000?ooo`3oool0h@3ooolEool002D0oooo0Ol000010?ooo`0000?o00000?ooo`3o
ool0h@3ooolEool002D0oooo0Ol000010?ooo`0000?o00000?ooo`3oool0h@3ooolEool002D0oooo
0Ol000010?ooo`0000?o00000?ooo`3oool0h@3ooolEool002D0oooo0Ol000010?ooo`0000?o0000
0?ooo`3oool0h@3ooolEool002D0oooo0Ol000010?ooo`0000?o00000?ooo`3oool0h@3ooolEool0
02D0oooo0Ol000010?ooo`0000?o00000?ooo`3oool0h@3ooolEool002D0oooo0Ol000010?ooo`00
00?o00000?ooo`3oool0h@3ooolEool002D0oooo0Ol000010?ooo`0000?o00000?ooo`3oool0h@3o
oolEool002D0oooo0Ol000010?ooo`0000?o00000?ooo`3oool01P3oool20?mo0=T0oooo5Ooo000U
0?ooo`7o00000@3oool00003o`00003oool0oooo00D0oooo103oO`0C0?ooo`80ogl0``3ooolEool0
02D0oooo0Ol000010?ooo`0000?o00000?ooo`3oool01@3oool40?mo0180oooo103oO`0B0?ooo`80
ogl0[P3ooolEool002D0oooo0Ol000010?ooo`0000?o00000?ooo`3oool01@3oool30?mo01<0oooo
103oO`0A0?ooo`@0ogl0[@3ooolEool002D0oooo0Ol000010?ooo`0000?o00000?ooo`3oool0103o
ool40?mo01@0oooo0P3oO`0B0?ooo`@0ogl0[@3ooolEool002D0oooo0Ol000010?ooo`0000?o0000
0?ooo`3oool0103oool40?mo02T0oooo0P3oO`2^0?oooaGoo`009@3oool1o`000040oooo00000ol0
0000oooo0?ooo`050?ooo`80ogl0fP3ooolEool002D0oooo0Ol000010?ooo`0000?o00000?ooo`3o
ool0h@3ooolEool002D0oooo0Ol000010?ooo`0000?o00000?ooo`3oool0h@3ooolEool002D0oooo
0Ol000010?ooo`0000?o00000?ooo`3oool0h@3ooolEool002D0oooo0Ol000010?ooo`0000?o0000
0?ooo`3oool0h@3ooolEool002D0oooo0Ol000010?ooo`0000?o00000?ooo`3oool0h@3ooolEool0
02D0oooo0Ol000010?ooo`0000?o00000?ooo`3oool0h@3ooolEool002D0oooo0Ol000010?ooo`00
00?o00000?ooo`3oool0h@3ooolEool002D0oooo0Ol000010?ooo`0000?o00000?ooo`3oool0:P3o
ool6ool00;40oooo5Ooo000U0?ooo`7o00000@3oool00003o`00003oool0oooo02T0oooo00?oo`00
0?ooo`3oool0103oool5ool00:`0oooo5Ooo000U0?ooo`7o00000@3oool00003o`00003oool0oooo
02L0oooo0_oo000<0?ooo`Coo`00Z03ooolEool002D0oooo0Ol000010?ooo`0000?o00000?ooo`3o
ool09P3oool00ooo0000oooo0?ooo`0@0?ooo`Coo`00Y03ooolEool002D0oooo0Ol000010?ooo`00
00?o00000?ooo`3oool0903oool00`3oO`3oo`000?ooo`090?ooo`80ogl02`3oool3ool00:40oooo
5Ooo000U0?ooo`7o00000@3oool00003o`00003oool0oooo02<0oooo00@0ogl0ool0003oO`00ogl0
203oool40?mo00d0oooo00?oo`000?ooo`3oool0WP3ooolEool002D0oooo0Ol000010?ooo`0000?o
00000?ooo`3oool08`3oool0103oO`3oo`000?mo003oO`080?ooo`@0ogl03P3oool2ool009h0oooo
5Ooo000U0?ooo`7o00000@3oool00003o`00003oool0oooo02@0oooo00<0ogl0ool0003oool02@3o
ool20?mo0140oooo0_oo002L0?oooaGoo`009@3oool1o`000040oooo00000ol00000oooo0?ooo`0U
0?ooo`03ool0003oool0oooo01d0oooo0_oo002J0?oooaGoo`009@3oool1o`000040oooo00000ol0
0000oooo0?ooo`0U0?ooo`03ool0003oool0oooo01l0oooo0_oo002H0?oooaGoo`009@3oool1o`00
0040oooo00000ol00000oooo0?ooo`0V0?ooo`03ool0003oool0oooo0140oooo0P3oO`0=0?ooo`;o
o`00103oool20?mo00L0oooo1@3o0?n40?oooaGoo`009@3oool1o`000040oooo00000ol00000oooo
0?ooo`0V0?ooo`03ool0003oool0oooo00D0oooo0P3oO`090?ooo`@0ogl03P3oool00ooo0000oooo
0?ooo`040?mo00D0oooo1`3o0?n30?oooaGoo`009@3oool1o`000040oooo00000ol00000oooo0?oo
o`0V0?ooo`03ool0003oool0oooo00@0oooo103oO`080?ooo`@0ogl03`3oool00ooo0000oooo0?mo
00030?mo00@0oooo2@3o0?n20?oooaGoo`009@3oool1o`000040oooo00000ol00000oooo0?ooo`0W
0?ooo`03ool0003oool0oooo00<0oooo103oO`090?ooo`80ogl04@3oool01?oo0000oooo0?mo003o
O`040?ooo`/0o`3oP@3ooolEool002D0oooo0Ol000010?ooo`0000?o00000?ooo`3oool09`3oool0
0ooo0000oooo0?ooo`040?ooo`80ogl07P3oool00ooo0000oooo0?ooo`040?ooo`/0o`3oP@3ooolE
ool002D0oooo0Ol000010?ooo`0000?o00000?ooo`3oool0:03oool00ooo0000oooo0?ooo`0T0?oo
o`03ool0003oool0oooo00<0oooo2`3o0?n10?oooaGoo`009@3oool1o`000040oooo00000ol00000
oooo0?ooo`0Y0?ooo`03ool0003oool0oooo02@0oooo0_oo00000`3oool0ogl00?mo000;0?l0oh40
oooo5Ooo000U0?ooo`7o00000@3oool00003o`00003oool0oooo02X0oooo00?oo`000?ooo`3oool0
4`3oool40?l000h0oooo00?oo`000?mo003oO`002`3o0?n10?oooaGoo`009@3oool1o`000040oooo
00000ol00000oooo0?ooo`0[0?ooo`03ool0003oool0oooo0140oooo1P3o000=0?ooo`040?mo0?oo
003oo`000?mo00T0o`3oPP3ooolEool002D0oooo0Ol000010?ooo`0000?o00000?ooo`3oool0;03o
ool00ooo0000oooo0?ooo`080?ooo`80ogl01@3oool80?l000d0oooo0P3oO`000ooo0000oooo0?l0
o`060?l0oh<0oooo5Ooo000U0?ooo`7o00000@3oool00003o`00003oool0oooo02d0oooo00?oo`00
0?ooo`3oool01P3oool40?mo00@0oooo203o000@0?ooo`03ool0003oool0o`3o00@0o`3oQ03ooolE
ool002D0oooo0Ol000010?ooo`0000?o00000?ooo`3oool0:`3oool20?mo00030?oooooo0000oooo
00H0oooo103oO`040?ooo`P0o`004@3oool00ooo0000oooo0?ooo`270?oooaGoo`009@3oool1o`00
0040oooo00000ol00000oooo0?ooo`0Z0?ooo`@0ogl000<0ooooool0003oool01P3oool20?mo00D0
oooo203o000;0?ooo`80ogl01@3oool00ooo0000oooo0?ooo`090?ooo`80ogl0N`3ooolEool002D0
oooo0Ol000010?ooo`0000?o00000?ooo`3oool0:P3oool40?mo0080oooo00?oo`000?ooo`3oool0
303oool60?l000/0oooo103oO`040?ooo`03ool0003oool0oooo00P0oooo103oO`1j0?oooaGoo`00
9@3oool1o`000040oooo00000ol00000oooo0?ooo`0[0?ooo`80ogl0103oool00ooo0000oooo0?oo
o`0<0?ooo`@0o`00303oool40?mo00D0oooo00?oo`000?ooo`3oool01`3oool40?mo07X0oooo5Ooo
000U0?ooo`7o00000@3oool00003o`00003oool0oooo0380oooo0_oo000M0?ooo`80ogl01`3oool0
0ooo0000oooo0?ooo`070?ooo`80ogl0]@3oool1o`000040oooo00000ol00000oooo0?ooo`0d0?oo
o`03ool0003oool0oooo02@0oooo00?oo`000?ooo`3oool0_@3oool1o`000040oooo00000ol00000
oooo0?ooo`0e0?ooo`03ool0003oool0oooo02@0oooo00?oo`000?ooo`3oool0_03oool1o`000040
oooo00000ol00000oooo0?ooo`0f0?ooo`;oo`009@3oool00ooo0000oooo0?ooo`2k0?ooo`7o0000
0@3oool00003o`00003oool0oooo03P0oooo0_oo00000`3oO`00oooo0?ooo`020?mo01h0oooo00?o
o`000?ooo`3oool0^`3oool1o`000040oooo00000ol00000oooo0?ooo`0h0?ooo`80ogl00_oo0004
0?mo01h0oooo00?oo`000?ooo`3oool0^P3oool1o`000040oooo00000ol00000oooo0?ooo`0h0?oo
o`@0ogl00_oo00020?mo01h0oooo00?oo`000?ooo`3oool0^P3oool1o`000040oooo00000ol00000
oooo0?ooo`0i0?ooo`D0ogl000?oo`000?ooo`3oool07@3oool00ooo0000ogl00?mo002j0?ooo`7o
00000@3oool00003o`00003oool0oooo03/0oooo103oO`02ool001d0oooo00@0ogl0ool0003oO`00
ogl0^@3oool1o`000040oooo00000ol00000oooo0?ooo`0l0?ooo`80ogl00`3oool2ool001/0oooo
00@0ogl0ool0003oO`00ogl0^@3oool1o`000040oooo00000ol00000oooo0?ooo`130?ooo`;oo`00
6P3oool00`3oO`3oo`000?ooo`2i0?ooo`7o00000@3oool00003o`00003oool0oooo04D0oooo0_oo
000I0?ooo`03ool0003oool0oooo0;P0oooo0Ol000010?ooo`0000?o00000?ooo`3oool0A`3oool2
ool001D0oooo0_oo002k0?ooo`7o00000@3oool00003o`00003oool0oooo04T0oooo0ooo000@0?oo
o`;oo`00_@3oool1o`000040oooo00000ol00000oooo0?ooo`0a0?ooo`80ogl06@3oool3ool000`0
oooo00?oo`000?ooo`3oool0_@3oool1o`000040oooo00000ol00000oooo0?ooo`0`0?ooo`@0ogl0
6`3oool6ool000@0oooo0_oo00300?ooo`7o00000@3oool00003o`00003oool0oooo0300oooo103o
O`0Q0?ooo`Coo`00`P3oool1o`000040oooo00000ol00000oooo0?ooo`0a0?ooo`80ogl0j03oool1
o`000040oooo00000ol00000oooo0?ooo`3o0?oooa`0oooo0Ol000010?ooo`0000?o00000?ooo`3o
ool0o`3ooolL0?ooo`7o00000@3oool00003o`00003oool0oooo0?l0oooo703oool1o`000040oooo
00000ol00000oooo0?ooo`3o0?oooa`0oooo0Ol000010?ooo`0000?o00000?ooo`3oool0o`3ooolL
0?ooo`7o00000@3oool00003o`00003oool0oooo07d0oooo0P3oO`2L0?ooo`7o00000@3oool00003
o`00003oool0oooo07`0oooo103oO`2K0?ooo`7o00000@3oool00003o`00003oool0oooo05@0oooo
0P3oO`0V0?ooo`@0ogl0V`3oool1o`000040oooo00000ol00000oooo0?ooo`1C0?ooo`@0ogl09P3o
ool20?mo09`0oooo0Ol000010?ooo`0000?o00000?ooo`3oool0D`3oool40?mo0<@0oooo0Ol00001
0?ooo`0000?o00000?ooo`3oool0E03oool20?mo0<D0oooo0Ol000010?ooo`0000?o00000?ooo`3o
ool0o`3ooolL0?ooo`7o00000@3oool00003o`00003oool0oooo06<0oooo0P3oO`040?ooo`80ogl0
/03oool1o`000040oooo00000ol00000oooo0?ooo`1R0?ooo`@0ogl00P3oool40?mo0:l0oooo0Ol0
00010?ooo`0000?o00000?ooo`3oool0HP3oool40?mo0080oooo103oO`2_0?ooo`7o00000@3oool0
0003o`00003oool0oooo06<0oooo0P3oO`040?ooo`80ogl0/03oool1o`000040oooo00000ol00000
oooo0?ooo`3o0?oooa`0oooo0Ol000010?ooo`0000?o00000?ooo`3oool0o`3ooolL0?ooo`7o0000
0@3oool00003o`00003oool0oooo0?l0oooo703oool1o`000040oooo00000ol00000oooo0?ooo`3o
0?oooa`0oooo0Ol000010?ooo`0000?o00000?ooo`3oool0o`3ooolL0?ooo`7o00000@3oool00003
o`00003oool0oooo0?l0oooo703oool1o`000040oooo00000ol00000oooo0?ooo`3o0?oooa`0oooo
0Ol000010?ooo`0000?o00000?ooo`3oool0o`3ooolL0?ooo`7o00000@3oool00003o`00003oool0
oooo0?l0oooo703oool1o`000040oooo00000ol00000oooo0?ooo`3o0?oooa`0oooo0Ol000010?oo
o`0000?o00000?ooo`3oool0o`3ooolL0?ooo`7o00000@3oool00003o`00003oool0oooo0?l0oooo
703oool1o`000040oooo00000ol00000oooo0?ooo`3o0?oooa`0oooo0Ol000010?ooo`0000?o0000
0?ooo`3oool0o`3ooolL0?ooo`7o00000@3oool00003o`00003oool0oooo0?l0oooo703oool1o`00
0040oooo00000ol00000oooo0?ooo`3o0?oooa`0oooo0Ol000010?ooo`0000?o00000?ooo`3oool0
o`3ooolL0?ooo`7o00000@3oool00003o`00003oool0oooo0?l0oooo703oool1o`000040oooo0000
0ol00000oooo0?ooo`3o0?oooa`0oooo0Ol000010?ooo`0000?o00000?ooo`3oool0o`3ooolL0?oo
o`7o00000@3oool00003o`00003oool0oooo0?l0oooo703oool1o`000040oooo00000ol00000oooo
0?ooo`3o0?oooa`0oooo0Ol000010?ooo`0000?o00000?ooo`3oool0o`3ooolL0?ooo`7o00000@3o
ool00003o`00003oool0oooo0?l0oooo703oool1o`000040oooo00000ol00000oooo0?ooo`3o0?oo
oa`0oooo0Ol000010?ooo`0000?o00000?ooo`3oool0o`3ooolL0?ooo`7o00000@3oool00003o`00
003oool0oooo0?l0oooo703oool1o`000040oooo00000ol00000oooo0?ooo`3o0?oooa`0oooo0Ol0
00010?ooo`0000?o00000?ooo`3oool0o`3ooolL0?ooo`7o00000@3oool00003o`00003oool0oooo
0?l0oooo703oool1o`000040oooo00000ol00000oooo0?ooo`3o0?oooa`0oooo0Ol000010?ooo`00
00?o00000?ooo`3oool0o`3ooolL0?ooo`7o00000@3oool00003o`00003oool0oooo0?l0oooo703o
ool1o`000040oooo00000ol00000oooo0?ooo`3o0?ooo`@0oooo0P3oO`0F0?ooo`7o00000@3oool0
0003o`00003oool0oooo0?l0oooo0`3oool40?mo01D0oooo0Ol000010?ooo`0000?o00000?ooo`3o
ool0o`3oool30?ooo`@0ogl05@3oool1o`000040oooo00000ol00000oooo0?ooo`3o0?ooo`@0oooo
0P3oO`0F0?ooo`7o00000@3oool00003o`00003oool0oooo0?l0oooo703oool1o`000040oooo0000
0ol00000oooo0?ooo`3o0?oooa`0oooo0Ol000010?ooo`0000?o00000?ooo`3oool0o`3ooolL0?oo
o`7o00000@3oool00003o`00003oool0oooo0?l0oooo703oool1o`000040oooo00000ol00000oooo
0?ooo`3o0?oooa`0oooo0Ol000010?ooo`0000?o00000?ooo`3oool0o`3ooolL0?ooo`7o00000@3o
ool00003o`00003oool0oooo0?l0oooo703oool1o`000040oooo00000ol00000oooo0?ooo`3o0?oo
oa`0oooo0Ol000010?ooo`0000?o00000?ooo`3oool0o`3ooolL0?ooo`7o00000@3oool00003o`00
003oool0oooo0?l0oooo703oool1o`000040oooo00000ol00000oooo0?ooo`2e0?ooo`80ogl0I03o
ool1o`000040oooo00000ol00000oooo0?ooo`2d0?ooo`@0ogl0H`3oool1o`000040oooo00000ol0
0000oooo0?ooo`2d0?ooo`@0ogl0H`3oool1o`000040oooo00000ol00000oooo0?ooo`2e0?ooo`80
ogl0=@3oool20?mo02d0oooo0Ol000010?ooo`0000?o00000?ooo`3oool0i03oool20?mo00D0oooo
103oO`0/0?ooo`7o00000@3oool00003o`00003oool0oooo0><0oooo103oO`040?ooo`@0ogl0;03o
ool1o`000040oooo00000ol00000oooo0?ooo`330?ooo`80ogl07P3oool40?mo00D0oooo0P3oO`0]
0?ooo`7o00000@3oool00003o`00003oool0oooo0<80oooo103oO`0;o`00oa<0oooo0P3oO`0e0?oo
o`7o00000@3oool00003o`00003oool0oooo0<80oooo1?l00?l;0?ooo`;o003oB03oool1o`000040
oooo00000ol00000oooo0?ooo`2n0?ooo`Co003o00<0oooo0?mo003oO`003P3oool2o`00odH0oooo
0Ol000010?ooo`0000?o00000?ooo`3oool0^@3oool20?mo00?o003o5`3oool2o`00o`T0oooo0P3o
O`0i0?ooo`7o00000@3oool00003o`00003oool0oooo0;L0oooo1?l00?l00`3oO`00oooo0?ooo`0I
0?ooo`;o003o1P3oool40?mo03P0oooo0Ol000010?ooo`0000?o00000?ooo`3oool0]03oool3o`00
o`030?ooo`3oO`00ogl00080ogl0703oool00ol00?l0oooo0?ooo`040?ooo`@0ogl00`3oool20?mo
03<0oooo0Ol000010?ooo`0000?o00000?ooo`3oool0/P3oool2o`00o`<0ogl00P3oool20?mo01<0
oooo0P3oO`080?ooo`03o`00o`3oool0oooo00D0oooo0P3oO`030?ooo`@0ogl0<P3oool1o`000040
oooo00000ol00000oooo0?ooo`2`0?ooo`;o003o00<0oooo0?mo003oO`000P3oO`060?ooo`80ogl0
3P3oool40?mo00L0oooo00?o003o0?ooo`3oool02P3oool40?mo0380oooo0Ol000010?ooo`0000?o
00000?ooo`3oool0[P3oool2o`00o`@0oooo0P3oO`060?ooo`@0ogl03@3oool40?mo00L0oooo00?o
003o0?ooo`3oool02`3oool20?mo03<0oooo0Ol000010?ooo`0000?o00000?ooo`3oool0R`3oool2
0?mo0200oooo00?o003o0?ooo`3oool0103oool20?mo00H0oooo103oO`0>0?ooo`80ogl02@3oool0
0ol00?l0oooo0?ooo`0o0?ooo`7o00000@3oool00003o`00003oool0oooo08X0oooo103oO`0M0?oo
o`;o003o1P3oool40?mo00H0oooo0P3oO`0J0?ooo`03o`00o`3oool0oooo03l0oooo0Ol000010?oo
o`0000?o00000?ooo`3oool0RP3oool40?mo01`0oooo00?o003o0?ooo`3oool01P3oool40?mo0280
oooo00?o003o0?ooo`3oool0?`3oool1o`000040oooo00000ol00000oooo0?ooo`2;0?ooo`80ogl0
6`3oool2o`00o`X0oooo0P3oO`0S0?ooo`03o`00o`3oool0oooo03l0oooo0Ol000010?ooo`0000?o
00000?ooo`3oool0UP3oool20?mo00h0oooo0_l00?lZ0?ooo`80ogl01@3oool00ol00?l0oooo0?oo
o`0o0?ooo`7o00000@3oool00003o`00003oool0oooo09D0oooo103oO`0<0?ooo`04o`00o`3oool0
ogl00?mo02P0oooo103oO`030?ooo`03o`00o`3oool0oooo0400oooo0Ol000010?ooo`0000?o0000
0?ooo`3oool0U@3oool40?mo00X0oooo0_l00?l00`3oool0ogl00?mo00020?mo02L0oooo103oO`03
0?ooo`03o`00o`3oool0oooo0400oooo0Ol000010?ooo`0000?o00000?ooo`3oool0UP3oool20?mo
00X0oooo00Co003o0?ooo`3oool0oooo103oO`0X0?ooo`80ogl0103oool00ol00?l0oooo0?ooo`10
0?ooo`7o00000@3oool00003o`00003oool0oooo0:40oooo00?o003o0?ooo`3oool00`3oool20?mo
02h0oooo00?o003o0?ooo`3oool0@@3oool1o`000040oooo00000ol00000oooo0?ooo`2P0?ooo`03
o`00o`3oool0oooo03<0oooo00?o003o0?ooo`3oool04P3oool20?mo02h0oooo0Ol000010?ooo`00
00?o00000?ooo`3oool0WP3oool2o`00ocD0oooo00?o003o0?ooo`3oool04P3oool40?mo02d0oooo
0Ol000010?ooo`0000?o00000?ooo`3oool0W@3oool00ol00?l0oooo0?ooo`0E0?ooo`@0003o703o
ool00ol00?l0ogl00?mo000B0?ooo`@0ogl0;@3oool1o`000040oooo00000ol00000oooo0?ooo`2L
0?ooo`03o`00o`3oool0oooo01D0oooo1P000?lJ0?ooo`03o`00o`3oO`00ogl00080ogl04P3oool2
0?mo02h0oooo0Ol000010?ooo`0000?o00000?ooo`3oool0V`3oool00ol00?l0oooo0?ooo`0E0?oo
o`P0003o603oool00ol00?l0oooo0?mo00030?mo0480oooo0Ol000010?ooo`0000?o00000?ooo`3o
ool0V`3oool00ol00?l0oooo0?ooo`0E0?ooo`P0003o5`3oool01?l00?l0oooo0?ooo`3oool20?mo
04<0oooo0Ol000010?ooo`0000?o00000?ooo`3oool0VP3oool00ol00?l0oooo0?ooo`0F0?ooo`P0
003o5P3oool00ol00?l0oooo0?ooo`170?ooo`7o00000@3oool00003o`00003oool0oooo09T0oooo
00?o003o0?ooo`3oool0303oool20?mo00P0oooo00<0ogl00000o`000?l01P000?lE0?ooo`03o`00
o`3oool0oooo0080ogl0AP3oool1o`000040oooo00000ol00000oooo0?ooo`2I0?ooo`03o`00o`3o
ool0oooo00X0oooo1@3oO`070?ooo`80ogl01P000?lC0?ooo`80ogl000?o003o0?ooo`3oool0103o
O`150?ooo`7o00000@3oool00003o`00003oool0oooo09P0oooo00?o003o0?ooo`3oool02P3oool6
0?mo00P0oooo0P3oO`040000oa<0oooo0P3oO`02o`00o`80oooo103oO`150?ooo`7o00000@3oool0
0003o`00003oool0oooo09P0oooo00?o003o0?ooo`3oool02P3oool50?mo0280oooo00@0ogl0o`00
o`3oO`00ogl00`3oool20?mo04H0oooo0Ol000010?ooo`0000?o00000?ooo`3oool0MP3oool20?mo
01l0oooo00?o003o0?ooo`3oool0303oool20?mo02@0oooo00?o003o0?mo003oO`00C03oool1o`00
0040oooo00000ol00000oooo0?ooo`1e0?ooo`@0ogl07P3oool00ol00?l0oooo0?ooo`0a0?ooo`03
o`00o`3oool0oooo04d0oooo0Ol000010?ooo`0000?o00000?ooo`3oool0M@3oool40?mo00X0oooo
0P3oO`0A0?ooo`03o`00o`3oool0oooo0340oooo00?o003o0?ooo`3oool0CP3oool1o`000040oooo
00000ol00000oooo0?ooo`1f0?ooo`80ogl02P3oool40?mo00l0oooo00?o003o0?ooo`3oool0603o
ool20?mo01L0oooo00?o003o0?ooo`3oool0C`3oool1o`000040oooo00000ol00000oooo0?ooo`22
0?ooo`@0ogl03`3oool00ol00?l0oooo0?ooo`0G0?ooo`@0ogl0503oool2o`00oe80oooo0Ol00001
0?ooo`0000?o00000?ooo`3oool0P`3oool20?mo00l0oooo00?o003o0?ooo`3oool04P3oool20?mo
00@0oooo103oO`0A0?ooo`?o003oE03oool1o`000040oooo00000ol00000oooo0?ooo`2D0?ooo`03
o`00o`3oool0oooo0140oooo103oO`040?ooo`80ogl0403oool2o`00oeL0oooo0Ol000010?ooo`00
00?o00000?ooo`3oool0U03oool00ol00?l0oooo0?ooo`0A0?ooo`@0ogl05@3oool00ol00?l0oooo
0?ooo`1G0?ooo`7o00000@3oool00003o`00003oool0oooo09@0oooo00?o003o0?ooo`3oool04P3o
ool20?mo01@0oooo0_l00?mJ0?ooo`7o00000@3oool00003o`00003oool0oooo09@0oooo00?o003o
0?ooo`3oool09P3oool2o`00oe`0oooo0Ol000010?ooo`0000?o00000?ooo`3oool0U@3oool00ol0
0?l0oooo0?ooo`0T0?ooo`03o`00o`3oool0oooo05`0oooo0Ol000010?ooo`0000?o00000?ooo`3o
ool0U@3oool00ol00?l0oooo0?ooo`0R0?ooo`;o003oG`3oool1o`000040oooo00000ol00000oooo
0?ooo`2E0?ooo`03o`00o`3oool0oooo0200oooo0_l00?mQ0?ooo`7o00000@3oool00003o`00003o
ool0oooo08@0oooo0P3oO`0?0?ooo`;o003o7`3oool2o`00of<0oooo0Ol000010?ooo`0000?o0000
0?ooo`3oool0P`3oool40?mo0100oooo0_l00?lJ0?ooo`?o003oI@3oool1o`000040oooo00000ol0
0000oooo0?ooo`230?ooo`@0ogl04P3oool2o`00oa@0oooo1?l00?mX0?ooo`7o00000@3oool00003
o`00003oool0oooo08@0oooo0P3oO`0E0?ooo`?o003o3P3oool3o`00o`<0oooo0P3oO`1W0?ooo`7o
00000@3oool00003o`00003oool0oooo09h0oooo0ol00?l50?ooo`Ko003o1@3oool40?mo06H0oooo
0Ol000010?ooo`0000?o00000?ooo`3oool0X@3oool5o`00o`/0oooo103oO`1V0?ooo`7o00000@3o
ool00003o`00003oool0oooo0;80oooo0P3oO`1W0?ooo`7o00000@3oool00003o`00003oool0oooo
0?l0oooo703oool1o`000040oooo00000ol00000oooo0?ooo`3o0?oooa`0oooo0Ol000010?ooo`00
00?o00000?ooo`3oool0N`3oool20?mo09h0oooo0Ol000010?ooo`0000?o00000?ooo`3oool0NP3o
ool40?mo09d0oooo0Ol000010?ooo`0000?o00000?ooo`3oool0NP3oool40?mo0200oooo0P3oO`1k
0?ooo`7o00000@3oool00003o`00003oool0oooo07/0oooo0P3oO`0P0?ooo`@0ogl0NP3oool1o`00
0040oooo00000ol00000oooo0?ooo`2M0?ooo`@0ogl0NP3oool1o`000040oooo00000ol00000oooo
0?ooo`2@0?ooo`80ogl0303oool20?mo07/0oooo0Ol000010?ooo`0000?o00000?ooo`3oool0S`3o
ool40?mo08P0oooo0Ol000010?ooo`0000?o00000?ooo`3oool0S`3oool40?mo08P0oooo0Ol00001
0?ooo`0000?o00000?ooo`3oool0T03oool20?mo02<0oooo0P3oO`1T0?ooo`7o00000@3oool00003
o`00003oool0oooo0;@0oooo103oO`1S0?ooo`7o00000@3oool00003o`00003oool0oooo0;@0oooo
103oO`1S0?ooo`7o00000@3oool00003o`00003oool0oooo0;D0oooo0P3oO`1T0?ooo`7o00000@3o
ool00003o`00003oool0oooo0?l0oooo703oool1o`000040oooo00000ol00000oooo0?ooo`3o0?oo
oa`0oooo0Ol000010?ooo`0000?o00000?ooo`3oool0o`3ooolL0?ooo`7o00000@3oool00003o`00
003oool0oooo0?l0oooo703oool1o`000040oooo00000ol00000oooo0?ooo`3o0?oooa`0oooo0Ol0
00010?ooo`0000?o00000?ooo`3oool0o`3ooolL0?ooo`7o00000@3oool00003o`00003oool0oooo
0?l0oooo703oool1o`000040oooo00000ol00000oooo0?ooo`3o0?oooa`0oooo0Ol000010?ooo`00
00?o00000?ooo`3oool0o`3ooolL0?ooo`7o00000@3oool00003o`00003oool0oooo0?l0oooo703o
ool1o`000040oooo00000ol00000oooo0?ooo`3o0?oooa`0oooo0Ol000010?ooo`0000?o00000?oo
o`3oool0o`3ooolL0?ooo`7o00000@3oool00003o`00003oool0oooo0?l0oooo703oool1o`000040
oooo00000ol00000oooo0?ooo`3o0?oooa`0oooo0Ol000010?ooo`0000?o00000?ooo`3oool0o`3o
oolL0?ooo`7o00000@3oool00003o`00003oool0oooo0?l0oooo703oool1o`000040oooo00000ol0
0000oooo0?ooo`3o0?oooa`0oooo0Ol000010?ooo`0000?o00000?ooo`3oool0o`3ooolL0?ooo`7o
00000@3oool00003o`00003oool0oooo0?l0oooo703oool1o`000040oooo00000ol00000oooo0?oo
o`3o0?oooa`0oooo0Ol000010?ooo`0000?o00000?ooo`3oool0o`3ooolL0?ooo`7o00000@3oool0
0003o`00003oool0oooo0?l0oooo703oool1o`000040oooo00000ol00000oooo0?ooo`3o0?oooa`0
oooo0Ol000010?ooo`0000?o00000?ooo`3oool0o`3ooolL0?ooo`7o00000@3oool00003o`00003o
ool0oooo0?l0oooo703oool1o`000040oooo00000ol00000oooo0?ooo`3o0?oooa`0oooo0Ol00001
0?ooo`0000?o00000?ooo`3oool0o`3ooolL0?ooo`7o00000@3oool00003o`00003oool0oooo0?l0
oooo703oool1o`000040oooo00000ol00000oooo0?ooo`3o0?oooa`0oooo0Ol000010?ooo`0000?o
00000?ooo`3oool0o`3ooolL0?ooo`7o00000@3oool00003o`00003oool0oooo0?l0oooo703oool1
o`000040oooo00000ol00000oooo0?ooo`3o0?oooa`0oooo0Ol000010?ooo`0000?o00000?ooo`3o
ool0o`3ooolL0?ooo`7o00000@3oool00003o`00003oool0oooo0?l0oooo703oool1o`000040oooo
00000ol00000oooo0?ooo`3o0?oooa`0oooo0Ol000010?ooo`0000?o00000?ooo`3oool0o`3ooolL
0?ooo`7o00000@3oool00003o`00003oool0oooo0?l0oooo703oool1o`000040oooo00000ol00000
oooo0?ooo`2>0?ooo`80ogl0R`3oool1o`000040oooo00000ol00000oooo0?ooo`2=0?ooo`@0ogl0
RP3oool1o`000040oooo00000ol00000oooo0?ooo`2=0?ooo`@0ogl0RP3oool1o`000040oooo0000
0ol00000oooo0?ooo`2>0?ooo`80ogl0R`3oool1o`000040oooo00000ol00000oooo0?ooo`3o0?oo
oa`0oooo0Ol000010?ooo`0000?o00000?ooo`3oool0o`3ooolL0?ooo`7o00000@3oool00003o`00
003oool0oooo0?l0oooo703oool1o`000040oooo00000ol00000oooo0?ooo`3o0?oooa`0oooo0Ol0
00010?ooo`0000?o00000?ooo`3oool0o`3ooolL0?ooo`7o00000@3oool00003o`00003oool0oooo
0?l0oooo703oool1o`000040oooo00000ol00000oooo0?ooo`3o0?oooa`0oooo0Ol000010?ooo`00
00?o00000?ooo`3oool0o`3ooolL0?ooo`7o00000@3oool00003o`00003oool0oooo0?l0oooo703o
ool1o`000040oooo00000ol00000oooo0?ooo`3o0?oooa`0oooo0Ol000010?ooo`0000?o00000?oo
o`3oool0o`3ooolL0?ooo`7o00000@3oool00003o`00003oool0oooo0?l0oooo703oool1o`000040
oooo00000ol00000oooo0?ooo`3o0?oooa`0oooo0Ol000010?ooo`0000?o00000?ooo`3oool0o`3o
oolL0?ooo`7o00000@3oool00003o`00003oool0oooo0?l0oooo703oool1o`000040oooo00000ol0
0000oooo0?ooo`3o0?oooa`0oooo0Ol000010?ooo`0000?o00000?ooo`3oool0o`3ooolL0?ooo`7o
00000@3oool00003o`00003oool0oooo0?l0oooo703oool1o`000040oooo00000ol00000oooo0?oo
o`3o0?oooa`0oooo0Ol000010?ooo`0000?o00000?ooo`3oool0o`3ooolL0?ooo`7o00000@3oool0
0003o`00003oool0oooo0?l0oooo703oool1o`000040oooo003oo`00023o00000@3oool00001\
\>"],
  ImageRangeCache->{{{0, 287}, {287, 0}} -> {-1.01089, -1.01089, 0.00704453, \
0.00704453}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.49505 0.5 0.49505 [
[ 0 0 -0.125 0 ]
[ 0 0 -0.125 0 ]
[ 0 1 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
0 0 m
1 0 L
s
0 0 m
0 1 L
s
0 1 m
1 1 L
s
1 0 m
1 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
1 .5 0 r
.015 w
.03175 .1355 Mdot
.03435 .12523 Mdot
.11137 .12765 Mdot
.14107 .18841 Mdot
.16218 .24538 Mdot
.17294 .21053 Mdot
.18267 .18577 Mdot
.18434 .1304 Mdot
.18553 .30956 Mdot
.20401 .239 Mdot
.21247 .27571 Mdot
.21687 .20845 Mdot
.22376 .2799 Mdot
.22832 .27485 Mdot
.29063 .20974 Mdot
.29686 .25079 Mdot
.30487 .22936 Mdot
.30683 .34623 Mdot
.32055 .20902 Mdot
.32574 .21979 Mdot
.34472 .28521 Mdot
.35998 .36393 Mdot
.36335 .24976 Mdot
.3794 .36608 Mdot
.42386 .66992 Mdot
.44391 .74519 Mdot
.45059 .34198 Mdot
.47208 .67586 Mdot
.47436 .71381 Mdot
.49778 .59825 Mdot
.50874 .91643 Mdot
.51516 .76219 Mdot
.53655 .61374 Mdot
.56563 .75219 Mdot
.59189 .65665 Mdot
.59581 .61604 Mdot
.59923 .6556 Mdot
.60292 .68499 Mdot
.62656 .67779 Mdot
.63555 .72451 Mdot
.63919 .652 Mdot
.64169 .6004 Mdot
.64246 .58611 Mdot
.64496 .54267 Mdot
.64608 .77288 Mdot
.65077 .64308 Mdot
.66065 .57816 Mdot
.67474 .59169 Mdot
.69296 .563 Mdot
.72815 .65902 Mdot
.73169 .58879 Mdot
.74669 .61318 Mdot
.74821 .65474 Mdot
.75963 .63781 Mdot
.79673 .57809 Mdot
.80925 .55852 Mdot
.81525 .58444 Mdot
.83417 .62985 Mdot
.83598 .55526 Mdot
.91595 .49319 Mdot
1 0 0 r
.005 w
.16128 .17044 m
.18734 .17269 L
.21339 .17909 L
.2345 .18734 L
.23945 .19126 L
.2655 .20415 L
.27874 .21339 L
.29156 .22295 L
.31204 .23945 L
.31761 .24532 L
.33549 .2655 L
.34367 .28341 L
.34499 .29156 L
.34367 .29798 L
.31761 .3104 L
.29156 .30711 L
.2655 .30014 L
.24507 .29156 L
.23945 .28747 L
.21339 .27402 L
.20155 .2655 L
.18734 .25472 L
.16884 .23945 L
.16128 .2313 L
.14618 .21339 L
.13806 .18734 L
.16128 .17044 L
s
0 0 1 r
.65633 .57701 m
.68239 .56842 L
.70844 .56313 L
.7345 .56168 L
.76055 .5752 L
.76359 .57817 L
.76859 .60422 L
.76055 .62333 L
.75627 .63028 L
.7345 .65485 L
.73298 .65633 L
.70844 .6775 L
.69922 .68239 L
.68239 .69294 L
.65633 .70579 L
.64983 .70844 L
.63028 .71539 L
.60422 .72268 L
.57817 .72651 L
.55211 .7214 L
.53145 .70844 L
.52926 .68239 L
.54239 .65633 L
.55211 .63983 L
.56625 .63028 L
.57817 .6193 L
.60119 .60422 L
.60422 .60227 L
.63028 .58726 L
.65315 .57817 L
.65633 .57701 L
s
1 0 0 r
.03 w
.24141 .24033 Mdot
0 0 1 r
.64872 .64417 Mdot
1 0 0 r
.79703 .00495 m
.79703 .25248 L
.87129 .25248 L
.87129 .00495 L
F
0 0 1 r
.89604 .00495 m
.89604 .00495 L
.9703 .00495 L
.9703 .00495 L
F
1 0 1 r
.04 w
.34472 .28521 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P000182000`400?l00000o`00003ooooooolQ
ooooo`00ool0000Po`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`00
00?o0000ooooooooool0hOoooolEool002Gooooo0Ol00001ooooo`0000?o0000ooooooooool0hOoo
oolEool002Gooooo0Ol00001ooooo`0000?o0000ooooooooool0hOoooolEool002Gooooo0Ol00001
ooooo`0000?o0000ooooooooool0hOoooolEool002Gooooo0Ol00001ooooo`0000?o0000oooooooo
ool0hOoooolEool002Gooooo0Ol00001ooooo`0000?o0000ooooooooool0hOoooolEool002Gooooo
0Ol00001ooooo`0000?o0000ooooooooool0hOoooolEool002Gooooo0Ol00001ooooo`0000?o0000
ooooooooool0hOoooolEool002Gooooo0Ol00001ooooo`0000?o0000ooooooooool0hOoooolEool0
02Gooooo0Ol00001ooooo`0000?o0000ooooooooool0hOoooolEool002Gooooo0Ol00001ooooo`00
00?o0000ooooooooool0hOoooolEool002Gooooo0Ol00001ooooo`0000?o0000ooooooooool0hOoo
oolEool002Gooooo0Ol00001ooooo`0000?o0000ooooooooool0hOoooolEool002Gooooo0Ol00001
ooooo`0000?o0000ooooooooool0hOoooolEool002Gooooo0Ol00001ooooo`0000?o0000oooooooo
ool0hOoooolEool002Gooooo0Ol00001ooooo`0000?o0000ooooooooool0hOoooolEool002Gooooo
0Ol00001ooooo`0000?o0000ooooooooool0hOoooolEool002Gooooo0Ol00001ooooo`0000?o0000
ooooooooool0hOoooolEool002Gooooo0Ol00001ooooo`0000?o0000ooooooooool0hOoooolEool0
02Gooooo0Ol00001ooooo`0000?o0000ooooooooool0hOoooolEool002Gooooo0Ol00001ooooo`00
00?o0000ooooooooool0hOoooolEool002Gooooo0Ol00001ooooo`0000?o0000ooooooooool0hOoo
oolEool002Gooooo0Ol00001ooooo`0000?o0000ooooooooool0hOoooolEool002Gooooo0Ol00001
ooooo`0000?o0000ooooooooool0hOoooolEool002Gooooo0Ol00001ooooo`0000?o0000oooooooo
ool0hOoooolEool002Gooooo0Ol00001ooooo`0000?o0000ooooooooool0hOoooolEool002Gooooo
0Ol00001ooooo`0000?o0000ooooooooool0hOoooolEool002Gooooo0Ol00001ooooo`0000?o0000
ooooooooool0hOoooolEool002Gooooo0Ol00001ooooo`0000?o0000ooooooooool0hOoooolEool0
02Gooooo0Ol00001ooooo`0000?o0000ooooooooool0hOoooolEool002Gooooo0Ol00001ooooo`00
00?o0000ooooooooool0hOoooolEool002Gooooo0Ol00001ooooo`0000?o0000ooooooooool0hOoo
oolEool002Gooooo0Ol00001ooooo`0000?o0000ooooooooool01_ooool2oomo0=Wooooo5Ooo000U
ooooo`7o00000Oooool00003o`000?oooooooooo00Gooooo1?ooO`0Cooooo`;oogl0`ooooolEool0
02Gooooo0Ol00001ooooo`0000?o0000ooooooooool01Oooool4oomo01;ooooo1?ooO`0Booooo`;o
ogl0[_oooolEool002Gooooo0Ol00001ooooo`0000?o0000ooooooooool01Oooool3oomo01?ooooo
1?ooO`0Aooooo`Coogl0[OoooolEool002Gooooo0Ol00001ooooo`0000?o0000ooooooooool01?oo
ool4oomo01Cooooo0_ooO`0Booooo`Coogl0[OoooolEool002Gooooo0Ol00001ooooo`0000?o0000
ooooooooool01?ooool4oomo02Wooooo0_ooO`2^oooooaGoo`009Oooool1o`00007ooooo00000ol0
003oooooooooo`05ooooo`;oogl0f_oooolEool002Gooooo0Ol00001ooooo`0000?o0000oooooooo
ool0hOoooolEool002Gooooo0Ol00001ooooo`0000?o0000ooooooooool0hOoooolEool002Gooooo
0Ol00001ooooo`0000?o0000ooooooooool0hOoooolEool002Gooooo0Ol00001ooooo`0000?o0000
ooooooooool0hOoooolEool002Gooooo0Ol00001ooooo`0000?o0000ooooooooool0hOoooolEool0
02Gooooo0Ol00001ooooo`0000?o0000ooooooooool0hOoooolEool002Gooooo0Ol00001ooooo`00
00?o0000ooooooooool0hOoooolEool002Gooooo0Ol00001ooooo`0000?o0000ooooooooool0:_oo
ool6ool00;7ooooo5Ooo000Uooooo`7o00000Oooool00003o`000?oooooooooo02Wooooo00?oo`00
ooooooooool01?ooool5ool00:cooooo5Ooo000Uooooo`7o00000Oooool00003o`000?oooooooooo
02Oooooo0_oo000<ooooo`Coo`00Z?oooolEool002Gooooo0Ol00001ooooo`0000?o0000oooooooo
ool09_ooool00ooo003oooooooooo`0@ooooo`Coo`00Y?oooolEool002Gooooo0Ol00001ooooo`00
00?o0000ooooooooool09?ooool00oooO`3oo`00ooooo`09ooooo`;oogl02oooool3ool00:7ooooo
5Ooo000Uooooo`7o00000Oooool00003o`000?oooooooooo02?ooooo00Coogl0ool00?ooO`3oogl0
2?ooool4oomo00gooooo00?oo`00ooooooooool0W_oooolEool002Gooooo0Ol00001ooooo`0000?o
0000ooooooooool08oooool01?ooO`3oo`00oomo0?ooO`08ooooo`Coogl03_ooool2ool009kooooo
5Ooo000Uooooo`7o00000Oooool00003o`000?oooooooooo02Cooooo00?oogl0ool00?ooool02Ooo
ool2oomo017ooooo0_oo002LoooooaGoo`009Oooool1o`00007ooooo00000ol0003oooooooooo`0U
ooooo`03ool00?oooooooooo01gooooo0_oo002JoooooaGoo`009Oooool1o`00007ooooo00000ol0
003oooooooooo`0Uooooo`03ool00?oooooooooo01oooooo0_oo002HoooooaGoo`009Oooool1o`00
007ooooo00000ol0003oooooooooo`0Vooooo`03ool00?oooooooooo017ooooo0_ooO`0=ooooo`;o
o`001?ooool2oomo00Oooooo0_ooO`27oooooaGoo`009Oooool1o`00007ooooo00000ol0003ooooo
ooooo`0Vooooo`03ool00?oooooooooo00Gooooo0_ooO`09ooooo`Coogl03_ooool00ooo003ooooo
ooooo`04oomo00Gooooo1?ooO`26oooooaGoo`009Oooool1o`00007ooooo00000ol0003ooooooooo
o`0Vooooo`03ool00?oooooooooo00Cooooo1?ooO`08ooooo`Coogl03oooool00ooo003ooooooomo
0003oomo00Gooooo1?ooO`26oooooaGoo`009Oooool1o`00007ooooo00000ol0003oooooooooo`0W
ooooo`03ool00?oooooooooo00?ooooo1?ooO`09ooooo`;oogl04Oooool01?oo003ooooooomo0?oo
O`07ooooo`?oogl0Q_oooolEool002Gooooo0Ol00001ooooo`0000?o0000ooooooooool09oooool0
0ooo003oooooooooo`04ooooo`;oogl07_ooool00ooo003oooooooooo`07ooooo`Coogl0QOoooolE
ool002Gooooo0Ol00001ooooo`0000?o0000ooooooooool0:?ooool00ooo003oooooooooo`0Toooo
o`03ool00?oooooooooo00Kooooo1?ooO`25oooooaGoo`009Oooool1o`00007ooooo00000ol0003o
ooooooooo`0Yooooo`03ool00?oooooooooo02Cooooo0_oo00000oooooooogl0oomo0004ooooo`;o
ogl0Q_oooolEool002Gooooo0Ol00001ooooo`0000?o0000ooooooooool0:_ooool00ooo003ooooo
ooooo`0Cooooo`Coo`003_ooool01?oo003oogl0oomo0?ooO`2;oooooaGoo`009Oooool1o`00007o
oooo00000ol0003oooooooooo`0[ooooo`03ool00?oooooooooo017ooooo1_oo000=ooooo`04oomo
0?oo003oo`00oomo08_ooooo5Ooo000Uooooo`7o00000Oooool00003o`000?oooooooooo02cooooo
00?oo`00ooooooooool02?ooool2oomo00Gooooo2?oo000=ooooo`;oogl000?oo`00ooooooooool0
ROoooolEool002Gooooo0Ol00001ooooo`0000?o0000ooooooooool0;Oooool00ooo003ooooooooo
o`06ooooo`Coogl01?ooool8ool0013ooooo00?oo`00ooooooooool0R?oooolEool002Gooooo0Ol0
0001ooooo`0000?o0000ooooooooool0:oooool2oomo0003oooooooo003ooooo00Kooooo1?ooO`04
ooooo`Soo`004Oooool00ooo003oooooooooo`27oooooaGoo`009Oooool1o`00007ooooo00000ol0
003oooooooooo`0Zooooo`Coogl000?oooooool00?ooool01_ooool2oomo00Gooooo2?oo000;oooo
o`;oogl01Oooool00ooo003oooooooooo`09ooooo`;oogl0NooooolEool002Gooooo0Ol00001oooo
o`0000?o0000ooooooooool0:_ooool4oomo00;ooooo00?oo`00ooooooooool03?ooool6ool000_o
oooo1?ooO`04ooooo`03ool00?oooooooooo00Sooooo1?ooO`1joooooaGoo`009Oooool1o`00007o
oooo00000ol0003oooooooooo`0[ooooo`;oogl01?ooool00ooo003oooooooooo`0<ooooo`Coo`00
3?ooool4oomo00Gooooo00?oo`00ooooooooool01oooool4oomo07[ooooo5Ooo000Uooooo`7o0000
0Oooool00003o`000?oooooooooo03;ooooo0_oo000Mooooo`;oogl01oooool00ooo003ooooooooo
o`07ooooo`;oogl0]Oooool1o`00007ooooo00000ol0003oooooooooo`0dooooo`03ool00?oooooo
oooo02Cooooo00?oo`00ooooooooool0_Oooool1o`00007ooooo00000ol0003oooooooooo`0eoooo
o`03ool00?oooooooooo02Cooooo00?oo`00ooooooooool0_?ooool1o`00007ooooo00000ol0003o
ooooooooo`0fooooo`;oo`009Oooool00ooo003oooooooooo`2kooooo`7o00000Oooool00003o`00
0?oooooooooo03Sooooo0_oo00000oooO`3oooooooooo`02oomo01kooooo1Ooo0?niooooo`7o0000
0Oooool00003o`000?oooooooooo03Sooooo0_ooO`02ool000Coogl07?ooool7ool0okSooooo0Ol0
0001ooooo`0000?o0000ooooooooool0>?ooool4oomo00;oo`000_ooO`0Kooooo`Woo`3o]oooool1
o`00007ooooo00000ol0003oooooooooo`0iooooo`Googl000?oo`00ooooooooool06Oooool;ool0
okKooooo0Ol00001ooooo`0000?o0000ooooooooool0>oooool4oomo00;oo`006Oooool;ool0okKo
oooo0Ol00001ooooo`0000?o0000ooooooooool0??ooool2oomo00?ooooo0_oo000Gooooo`_oo`3o
]_ooool1o`00007ooooo00000ol0003oooooooooo`13ooooo`;oo`005Oooool;ool0okKooooo0Ol0
0001ooooo`0000?o0000ooooooooool0AOooool2ool001?ooooo2ooo0?nfooooo`7o00000Oooool0
0003o`000?oooooooooo04Oooooo0_oo000Booooo`Woo`3o]oooool1o`00007ooooo00000ol0003o
ooooooooo`19ooooo`?oo`004?ooool7ool0okSooooo0Ol00001ooooo`0000?o0000ooooooooool0
<Oooool2oomo01Wooooo0ooo000<ooooo`03ool00?ooooooo`3o00Coo`3o^Oooool1o`00007ooooo
00000ol0003oooooooooo`0`ooooo`Coogl06oooool6ool000Cooooo0_oo0030ooooo`7o00000Ooo
ool00003o`000?oooooooooo033ooooo1?ooO`0Qooooo`Coo`00`_ooool1o`00007ooooo00000ol0
003oooooooooo`0aooooo`;oogl0j?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooooaco
oooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oo
oooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001
ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo07go
oooo0_ooO`2Looooo`7o00000Oooool00003o`000?oooooooooo07cooooo1?ooO`2Kooooo`7o0000
0Oooool00003o`000?oooooooooo05Cooooo0_ooO`0Vooooo`Coogl0Voooool1o`00007ooooo0000
0ol0003oooooooooo`1Cooooo`Coogl09_ooool2oomo09cooooo0Ol00001ooooo`0000?o0000oooo
ooooool0Doooool4oomo0<Cooooo0Ol00001ooooo`0000?o0000ooooooooool0E?ooool2oomo0<Go
oooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oo
oooooooo06?ooooo0_ooO`04ooooo`;oogl0/?ooool1o`00007ooooo00000ol0003oooooooooo`1R
ooooo`Coogl00_ooool4oomo0:oooooo0Ol00001ooooo`0000?o0000ooooooooool0H_ooool4oomo
00;ooooo1?ooO`2_ooooo`7o00000Oooool00003o`000?oooooooooo06?ooooo0_ooO`04ooooo`;o
ogl0/?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o
0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1
o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000oooooooo
ool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo
00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolL
ooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003o
ooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o0000
0Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3o
oooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003
o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo
0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oooooo
oooo0?oooooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001oooo
o`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo
7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000
ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00
007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0
oooooolLooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo0000
0ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLoooo
o`7o00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003ooooo
ooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Ooo
ool00003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooo
o`Cooooo0_ooO`0Fooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo0oooool4oomo01Go
oooo0Ol00001ooooo`0000?o0000ooooooooool0ooooool3ooooo`Coogl05Oooool1o`00007ooooo
00000ol0003oooooooooo`3oooooo`Cooooo0_ooO`0Fooooo`7o00000Oooool00003o`000?oooooo
oooo0?oooooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001oooo
o`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo
7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000
ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00
007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0
oooooolLooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo0000
0ol0003oooooooooo`2eooooo`;oogl0I?ooool1o`00007ooooo00000ol0003oooooooooo`2doooo
o`Coogl0Hoooool1o`00007ooooo00000ol0003oooooooooo`2dooooo`Coogl0Hoooool1o`00007o
oooo00000ol0003oooooooooo`2eooooo`;oogl0=Oooool2oomo02gooooo0Ol00001ooooo`0000?o
0000ooooooooool0i?ooool2oomo00Gooooo1?ooO`0/ooooo`7o00000Oooool00003o`000?oooooo
oooo0>?ooooo1?ooO`04ooooo`Coogl0;?ooool1o`00007ooooo00000ol0003oooooooooo`33oooo
o`;oogl07_ooool4oomo00Gooooo0_ooO`0]ooooo`7o00000Oooool00003o`000?oooooooooo0<;o
oooo1?ooO`0;o`00oa?ooooo0_ooO`0eooooo`7o00000Oooool00003o`000?oooooooooo0<;ooooo
1?l00?l;ooooo`;o003oB?ooool1o`00007ooooo00000ol0003oooooooooo`2nooooo`Co003o00?o
oooooomo0?ooO`003_ooool2o`00odKooooo0Ol00001ooooo`0000?o0000ooooooooool0^Oooool2
oomo00?o003o5oooool2o`00o`Wooooo0_ooO`0iooooo`7o00000Oooool00003o`000?oooooooooo
0;Oooooo1?l00?l00oooO`3oooooooooo`0Iooooo`;o003o1_ooool4oomo03Sooooo0Ol00001oooo
o`0000?o0000ooooooooool0]?ooool3o`00o`03ooooooooO`3oogl000;oogl07?ooool00ol00?oo
ooooooooo`04ooooo`Coogl00oooool2oomo03?ooooo0Ol00001ooooo`0000?o0000ooooooooool0
/_ooool2o`00o`?oogl00_ooool2oomo01?ooooo0_ooO`08ooooo`03o`00oooooooooooo00Gooooo
0_ooO`03ooooo`Coogl0<_ooool1o`00007ooooo00000ol0003oooooooooo`2`ooooo`;o003o00?o
oooooomo0?ooO`000_ooO`06ooooo`;oogl03_ooool4oomo00Oooooo00?o003oooooooooool02_oo
ool4oomo03;ooooo0Ol00001ooooo`0000?o0000ooooooooool0[_ooool2o`00o`Cooooo0_ooO`06
ooooo`Coogl03Oooool4oomo00Oooooo00?o003oooooooooool02oooool2oomo03?ooooo0Ol00001
ooooo`0000?o0000ooooooooool0Roooool2oomo023ooooo00?o003oooooooooool01?ooool2oomo
00Kooooo1?ooO`0>ooooo`;oogl02Oooool00ol00?ooooooooooo`0oooooo`7o00000Oooool00003
o`000?oooooooooo08[ooooo1?ooO`0Mooooo`;o003o1_ooool4oomo00Kooooo0_ooO`0Jooooo`03
o`00oooooooooooo03oooooo0Ol00001ooooo`0000?o0000ooooooooool0R_ooool4oomo01cooooo
00?o003oooooooooool01_ooool4oomo02;ooooo00?o003oooooooooool0?oooool1o`00007ooooo
00000ol0003oooooooooo`2;ooooo`;oogl06oooool2o`00o`[ooooo0_ooO`0Sooooo`03o`00oooo
oooooooo03oooooo0Ol00001ooooo`0000?o0000ooooooooool0U_ooool2oomo00kooooo0_l00?lZ
ooooo`;oogl01Oooool00ol00?ooooooooooo`0oooooo`7o00000Oooool00003o`000?oooooooooo
09Gooooo1?ooO`0<ooooo`04o`00ooooooooogl0oomo02Sooooo1?ooO`03ooooo`03o`00oooooooo
oooo043ooooo0Ol00001ooooo`0000?o0000ooooooooool0UOooool4oomo00[ooooo0_l00?l00ooo
ooooogl0oomo0002oomo02Oooooo1?ooO`03ooooo`03o`00oooooooooooo043ooooo0Ol00001oooo
o`0000?o0000ooooooooool0U_ooool2oomo00[ooooo00Co003ooooooooooooooooo1?ooO`0Xoooo
o`;oogl01?ooool00ol00?ooooooooooo`10ooooo`7o00000Oooool00003o`000?oooooooooo0:7o
oooo00?o003oooooooooool00oooool2oomo02kooooo00?o003oooooooooool0@Oooool1o`00007o
oooo00000ol0003oooooooooo`2Pooooo`03o`00oooooooooooo03?ooooo00?o003oooooooooool0
4_ooool2oomo02kooooo0Ol00001ooooo`0000?o0000ooooooooool0W_ooool2o`00ocGooooo00?o
003oooooooooool04_ooool4oomo02gooooo0Ol00001ooooo`0000?o0000ooooooooool0WOooool0
0ol00?ooooooooooo`0Eooooo`Co003o7?ooool00ol00?ooogl0oomo000Booooo`Coogl0;Oooool1
o`00007ooooo00000ol0003oooooooooo`2Looooo`03o`00oooooooooooo01Gooooo1_l00?lJoooo
o`03o`00ooooO`3oogl000;oogl04_ooool2oomo02kooooo0Ol00001ooooo`0000?o0000oooooooo
ool0Voooool00ol00?ooooooooooo`0Eooooo`So003o6?ooool00ol00?oooooooomo0003oomo04;o
oooo0Ol00001ooooo`0000?o0000ooooooooool0Voooool00ol00?ooooooooooo`0Eooooo`So003o
5oooool01?l00?ooooooooooooooool2oomo04?ooooo0Ol00001ooooo`0000?o0000ooooooooool0
V_ooool00ol00?ooooooooooo`0Fooooo`So003o5_ooool00ol00?ooooooooooo`17ooooo`7o0000
0Oooool00003o`000?oooooooooo09Wooooo00?o003oooooooooool03?ooool2oomo00Sooooo00?o
ogl0o`00ool00?l01_l00?lEooooo`03o`00oooooooooooo00;oogl0A_ooool1o`00007ooooo0000
0ol0003oooooooooo`2Iooooo`03o`00oooooooooooo00[ooooo1OooO`07ooooo`;oogl01_l00?lC
ooooo`;oogl000?o003oooooooooool01?ooO`15ooooo`7o00000Oooool00003o`000?oooooooooo
09Sooooo00?o003oooooooooool02_ooool6oomo00Sooooo0_ooO`04o`00oa?ooooo0_ooO`02o`00
o`;ooooo1?ooO`15ooooo`7o00000Oooool00003o`000?oooooooooo09Sooooo00?o003ooooooooo
ool02_ooool5oomo02;ooooo00Coogl0o`00ooooO`3oogl00oooool2oomo04Kooooo0Ol00001oooo
o`0000?o0000ooooooooool0M_ooool2oomo01oooooo00?o003oooooooooool03?ooool2oomo02Co
oooo00?o003ooomo0?ooO`00C?ooool1o`00007ooooo00000ol0003oooooooooo`1eooooo`Coogl0
7_ooool00ol00?ooooooooooo`0aooooo`03o`00oooooooooooo04gooooo0Ol00001ooooo`0000?o
0000ooooooooool0MOooool4oomo00[ooooo0_ooO`0Aooooo`03o`00oooooooooooo037ooooo00?o
003oooooooooool0C_ooool1o`00007ooooo00000ol0003oooooooooo`1fooooo`;oogl02_ooool4
oomo00oooooo00?o003oooooooooool06?ooool2oomo01Oooooo00?o003oooooooooool0Coooool1
o`00007ooooo00000ol0003oooooooooo`22ooooo`Coogl03oooool00ol00?ooooooooooo`0Goooo
o`Coogl05?ooool2o`00oe;ooooo0Ol00001ooooo`0000?o0000ooooooooool0Poooool2oomo00oo
oooo00?o003oooooooooool04_ooool2oomo00Cooooo1?ooO`0Aooooo`?o003oE?ooool1o`00007o
oooo00000ol0003oooooooooo`2Dooooo`03o`00oooooooooooo017ooooo1?ooO`04ooooo`;oogl0
4?ooool2o`00oeOooooo0Ol00001ooooo`0000?o0000ooooooooool0U?ooool00ol00?oooooooooo
o`0Aooooo`Coogl05Oooool00ol00?ooooooooooo`1Gooooo`7o00000Oooool00003o`000?oooooo
oooo09Cooooo00?o003oooooooooool04_ooool2oomo01Cooooo0_l00?mJooooo`7o00000Oooool0
0003o`000?oooooooooo09Cooooo00?o003oooooooooool09_ooool2o`00oecooooo0Ol00001oooo
o`0000?o0000ooooooooool0UOooool00ol00?ooooooooooo`0Tooooo`03o`00oooooooooooo05co
oooo0Ol00001ooooo`0000?o0000ooooooooool0UOooool00ol00?ooooooooooo`0Rooooo`;o003o
Goooool1o`00007ooooo00000ol0003oooooooooo`2Eooooo`03o`00oooooooooooo023ooooo0_l0
0?mQooooo`7o00000Oooool00003o`000?oooooooooo08Cooooo0_ooO`0?ooooo`;o003o7oooool2
o`00of?ooooo0Ol00001ooooo`0000?o0000ooooooooool0Poooool4oomo013ooooo0_l00?lJoooo
o`?o003oIOooool1o`00007ooooo00000ol0003oooooooooo`23ooooo`Coogl04_ooool2o`00oaCo
oooo1?l00?mXooooo`7o00000Oooool00003o`000?oooooooooo08Cooooo0_ooO`0Eooooo`?o003o
3_ooool3o`00o`?ooooo0_ooO`1Wooooo`7o00000Oooool00003o`000?oooooooooo09kooooo0ol0
0?l5ooooo`Ko003o1Oooool4oomo06Kooooo0Ol00001ooooo`0000?o0000ooooooooool0XOooool5
o`00o`_ooooo1?ooO`1Vooooo`7o00000Oooool00003o`000?oooooooooo0;;ooooo0_ooO`1Woooo
o`7o00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003ooooo
ooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0Noooool2oomo09kooooo0Ol0
0001ooooo`0000?o0000ooooooooool0N_ooool4oomo09gooooo0Ol00001ooooo`0000?o0000oooo
ooooool0N_ooool4oomo023ooooo0_ooO`1kooooo`7o00000Oooool00003o`000?oooooooooo07_o
oooo0_ooO`0Pooooo`Coogl0N_ooool1o`00007ooooo00000ol0003oooooooooo`2Mooooo`Coogl0
N_ooool1o`00007ooooo00000ol0003oooooooooo`2@ooooo`;oogl03?ooool2oomo07_ooooo0Ol0
0001ooooo`0000?o0000ooooooooool0Soooool4oomo08Sooooo0Ol00001ooooo`0000?o0000oooo
ooooool0Soooool4oomo08Sooooo0Ol00001ooooo`0000?o0000ooooooooool0T?ooool2oomo02?o
oooo0_ooO`1Tooooo`7o00000Oooool00003o`000?oooooooooo0;Cooooo1?ooO`1Sooooo`7o0000
0Oooool00003o`000?oooooooooo0;Cooooo1?ooO`1Sooooo`7o00000Oooool00003o`000?oooooo
oooo0;Gooooo0_ooO`1Tooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00
007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0
oooooolLooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo0000
0ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLoooo
o`7o00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003ooooo
ooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Ooo
ool00003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooo
oacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`00
0?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol0
0001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo
0?oooooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`00
00?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?oo
ool1o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000oooo
ooooool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007o
oooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooo
oolLooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0
003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o
00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003ooooooooo
o`3ooooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool0
0003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooooaco
oooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oo
oooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001
ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo0?oo
oooo7?ooool1o`00007ooooo00000ol0003oooooooooo`2>ooooo`;oogl0Roooool1o`00007ooooo
00000ol0003oooooooooo`2=ooooo`Coogl0R_ooool1o`00007ooooo00000ol0003oooooooooo`2=
ooooo`Coogl0R_ooool1o`00007ooooo00000ol0003oooooooooo`2>ooooo`;oogl0Roooool1o`00
007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0
oooooolLooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo0000
0ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLoooo
o`7o00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003ooooo
ooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Ooo
ool00003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooo
oacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`00
0?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol0
0001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo
0?oooooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`00
00?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?oo
ool1o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000oooo
ooooool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007o
oooo003oo`00023o00000Oooool00001\
\>"],
  ImageRangeCache->{{{0, 287}, {287, 0}} -> {-1.01089, -1.01089, 0.00704453, \
0.00704453}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.49505 0.5 0.49505 [
[ 0 0 -0.125 0 ]
[ 0 0 -0.125 0 ]
[ 0 1 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
0 0 m
1 0 L
s
0 0 m
0 1 L
s
0 1 m
1 1 L
s
1 0 m
1 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
1 .5 0 r
.015 w
.03175 .1355 Mdot
.03435 .12523 Mdot
.11137 .12765 Mdot
.14107 .18841 Mdot
.16218 .24538 Mdot
.17294 .21053 Mdot
.18267 .18577 Mdot
.18434 .1304 Mdot
.18553 .30956 Mdot
.20401 .239 Mdot
.21247 .27571 Mdot
.21687 .20845 Mdot
.22376 .2799 Mdot
.22832 .27485 Mdot
.29063 .20974 Mdot
.29686 .25079 Mdot
.30487 .22936 Mdot
.30683 .34623 Mdot
.32055 .20902 Mdot
.32574 .21979 Mdot
.34472 .28521 Mdot
.35998 .36393 Mdot
.36335 .24976 Mdot
.3794 .36608 Mdot
.42386 .66992 Mdot
.44391 .74519 Mdot
.45059 .34198 Mdot
.47208 .67586 Mdot
.47436 .71381 Mdot
.49778 .59825 Mdot
.50874 .91643 Mdot
.51516 .76219 Mdot
.53655 .61374 Mdot
.56563 .75219 Mdot
.59189 .65665 Mdot
.59581 .61604 Mdot
.59923 .6556 Mdot
.60292 .68499 Mdot
.62656 .67779 Mdot
.63555 .72451 Mdot
.63919 .652 Mdot
.64169 .6004 Mdot
.64246 .58611 Mdot
.64496 .54267 Mdot
.64608 .77288 Mdot
.65077 .64308 Mdot
.66065 .57816 Mdot
.67474 .59169 Mdot
.69296 .563 Mdot
.72815 .65902 Mdot
.73169 .58879 Mdot
.74669 .61318 Mdot
.74821 .65474 Mdot
.75963 .63781 Mdot
.79673 .57809 Mdot
.80925 .55852 Mdot
.81525 .58444 Mdot
.83417 .62985 Mdot
.83598 .55526 Mdot
.91595 .49319 Mdot
1 0 0 r
.005 w
.16128 .17044 m
.18734 .17269 L
.21339 .17909 L
.2345 .18734 L
.23945 .19126 L
.2655 .20415 L
.27874 .21339 L
.29156 .22295 L
.31204 .23945 L
.31761 .24532 L
.33549 .2655 L
.34367 .28341 L
.34499 .29156 L
.34367 .29798 L
.31761 .3104 L
.29156 .30711 L
.2655 .30014 L
.24507 .29156 L
.23945 .28747 L
.21339 .27402 L
.20155 .2655 L
.18734 .25472 L
.16884 .23945 L
.16128 .2313 L
.14618 .21339 L
.13806 .18734 L
.16128 .17044 L
s
0 0 1 r
.65633 .57701 m
.68239 .56842 L
.70844 .56313 L
.7345 .56168 L
.76055 .5752 L
.76359 .57817 L
.76859 .60422 L
.76055 .62333 L
.75627 .63028 L
.7345 .65485 L
.73298 .65633 L
.70844 .6775 L
.69922 .68239 L
.68239 .69294 L
.65633 .70579 L
.64983 .70844 L
.63028 .71539 L
.60422 .72268 L
.57817 .72651 L
.55211 .7214 L
.53145 .70844 L
.52926 .68239 L
.54239 .65633 L
.55211 .63983 L
.56625 .63028 L
.57817 .6193 L
.60119 .60422 L
.60422 .60227 L
.63028 .58726 L
.65315 .57817 L
.65633 .57701 L
s
1 0 0 r
.03 w
.24141 .24033 Mdot
0 0 1 r
.64872 .64417 Mdot
1 0 0 r
.79703 .00495 m
.79703 .25248 L
.87129 .25248 L
.87129 .00495 L
F
0 0 1 r
.89604 .00495 m
.89604 .00495 L
.9703 .00495 L
.9703 .00495 L
F
1 0 1 r
.04 w
.35998 .36393 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P000182000`400?l00000o`00003ooooooolQ
ooooo`00o`00000P0000007ooooo00000`00003oooooooooo`3ooooooacooooo0@000001ooooo`00
00<00000ooooooooool0hOoooolE0?l002Gooooo0@000001ooooo`0000<00000ooooooooool0hOoo
oolE0?l002Gooooo0@000001ooooo`0000<00000ooooooooool0hOoooolE0?l002Gooooo0@000001
ooooo`0000<00000ooooooooool0hOoooolE0?l002Gooooo0@000001ooooo`0000<00000oooooooo
ool0hOoooolE0?l002Gooooo0@000001ooooo`0000<00000ooooooooool0hOoooolE0?l002Gooooo
0@000001ooooo`0000<00000ooooooooool0hOoooolE0?l002Gooooo0@000001ooooo`0000<00000
ooooooooool0hOoooolE0?l002Gooooo0@000001ooooo`0000<00000ooooooooool0hOoooolE0?l0
02Gooooo0@000001ooooo`0000<00000ooooooooool0hOoooolE0?l002Gooooo0@000001ooooo`00
00<00000ooooooooool0hOoooolE0?l002Gooooo0@000001ooooo`0000<00000ooooooooool0hOoo
oolE0?l002Gooooo0@000001ooooo`0000<00000ooooooooool0hOoooolE0?l002Gooooo0@000001
ooooo`0000<00000ooooooooool0hOoooolE0?l002Gooooo0@000001ooooo`0000<00000oooooooo
ool0hOoooolE0?l002Gooooo0@000001ooooo`0000<00000ooooooooool0hOoooolE0?l002Gooooo
0@000001ooooo`0000<00000ooooooooool0hOoooolE0?l002Gooooo0@000001ooooo`0000<00000
ooooooooool0hOoooolE0?l002Gooooo0@000001ooooo`0000<00000ooooooooool0hOoooolE0?l0
02Gooooo0@000001ooooo`0000<00000ooooooooool0hOoooolE0?l002Gooooo0@000001ooooo`00
00<00000ooooooooool0hOoooolE0?l002Gooooo0@000001ooooo`0000<00000ooooooooool0hOoo
oolE0?l002Gooooo0@000001ooooo`0000<00000ooooooooool0hOoooolE0?l002Gooooo0@000001
ooooo`0000<00000ooooooooool0hOoooolE0?l002Gooooo0@000001ooooo`0000<00000oooooooo
ool0hOoooolE0?l002Gooooo0@000001ooooo`0000<00000ooooooooool0hOoooolE0?l002Gooooo
0@000001ooooo`0000<00000ooooooooool0hOoooolE0?l002Gooooo0@000001ooooo`0000<00000
ooooooooool0hOoooolE0?l002Gooooo0@000001ooooo`0000<00000ooooooooool0hOoooolE0?l0
02Gooooo0@000001ooooo`0000<00000ooooooooool0hOoooolE0?l002Gooooo0@000001ooooo`00
00<00000ooooooooool0hOoooolE0?l002Gooooo0@000001ooooo`0000<00000ooooooooool0hOoo
oolE0?l002Gooooo0@000001ooooo`0000<00000ooooooooool01_ooool2oomo0=Wooooo5@3o000U
ooooo`4000000Oooool0000300000?oooooooooo00Gooooo1?ooO`0Cooooo`;oogl0`ooooolE0?l0
02Gooooo0@000001ooooo`0000<00000ooooooooool01Oooool4oomo01;ooooo1?ooO`0Booooo`;o
ogl0[_oooolE0?l002Gooooo0@000001ooooo`0000<00000ooooooooool01Oooool3oomo01?ooooo
1?ooO`0Aooooo`Coogl0[OoooolE0?l002Gooooo0@000001ooooo`0000<00000ooooooooool01?oo
ool4oomo01Cooooo0_ooO`0Booooo`Coogl0[OoooolE0?l002Gooooo0@000001ooooo`0000<00000
ooooooooool01?ooool4oomo02Wooooo0_ooO`2^oooooaD0o`009Oooool10000007ooooo00000`00
003oooooooooo`05ooooo`;oogl0f_oooolE0?l002Gooooo0@000001ooooo`0000<00000oooooooo
ool0hOoooolE0?l002Gooooo0@000001ooooo`0000<00000ooooooooool0hOoooolE0?l002Gooooo
0@000001ooooo`0000<00000ooooooooool0hOoooolE0?l002Gooooo0@000001ooooo`0000<00000
ooooooooool0hOoooolE0?l002Gooooo0@000001ooooo`0000<00000ooooooooool0hOoooolE0?l0
02Gooooo0@000001ooooo`0000<00000ooooooooool0hOoooolE0?l002Gooooo0@000001ooooo`00
00<00000ooooooooool0hOoooolE0?l002Gooooo0@000001ooooo`0000<00000ooooooooool0:_oo
ool60?l00;7ooooo5@3o000Uooooo`4000000Oooool0000300000?oooooooooo02Wooooo00<0o`00
ooooooooool01?ooool50?l00:cooooo5@3o000Uooooo`4000000Oooool0000300000?oooooooooo
02Oooooo0P3o000<ooooo`@0o`00Z?oooolE0?l002Gooooo0@000001ooooo`0000<00000oooooooo
ool09_ooool00`3o003oooooooooo`0@ooooo`@0o`00Y?oooolE0?l002Gooooo0@000001ooooo`00
00<00000ooooooooool09?ooool00oooO`00o`00ooooo`09ooooo`;oogl02oooool30?l00:7ooooo
5@3o000Uooooo`4000000Oooool0000300000?oooooooooo02?ooooo00Coogl00?l00?ooO`3oogl0
2?ooool4oomo00gooooo00?oo`00ooooooooool0W_oooolE0?l002Gooooo0@000001ooooo`0000<0
0000ooooooooool08oooool01?ooO`00o`00oomo0?ooO`08ooooo`Coogl03_ooool20?l009kooooo
5@3o000Uooooo`4000000Oooool0000300000?oooooooooo02Cooooo00?oogl00?l00?ooool02Ooo
ool2oomo017ooooo0P3o002LoooooaD0o`009Oooool10000007ooooo00000`00003oooooooooo`0U
ooooo`030?l00?oooooooooo01gooooo0P3o002JoooooaD0o`009Oooool10000007ooooo00000`00
003oooooooooo`0Uooooo`030?l00?oooooooooo01oooooo0P3o002HoooooaD0o`009Oooool10000
007ooooo00000`00003oooooooooo`0Vooooo`030?l00?oooooooooo017ooooo0_ooO`0=ooooo`80
o`001?ooool2oomo00Oooooo0_ooO`27oooooaD0o`009Oooool10000007ooooo00000`00003ooooo
ooooo`0Vooooo`030?l00?oooooooooo00Gooooo0_ooO`09ooooo`Coogl03_ooool00`3o003ooooo
ooooo`04oomo00Gooooo1?ooO`26oooooaD0o`009Oooool10000007ooooo00000`00003ooooooooo
o`0Vooooo`030?l00?oooooooooo00Cooooo1?ooO`08ooooo`Coogl03oooool00`3o003ooooooomo
0003oomo00Gooooo1?ooO`26oooooaD0o`009Oooool10000007ooooo00000`00003oooooooooo`0W
ooooo`030?l00?oooooooooo00?ooooo1?ooO`09ooooo`;oogl04Oooool0103o003ooooooomo0?oo
O`07ooooo`?oogl0Q_oooolE0?l002Gooooo0@000001ooooo`0000<00000ooooooooool09oooool0
0`3o003oooooooooo`04ooooo`;oogl07_ooool00`3o003oooooooooo`07ooooo`Coogl0QOoooolE
0?l002Gooooo0@000001ooooo`0000<00000ooooooooool0:?ooool00`3o003oooooooooo`0Toooo
o`030?l00?oooooooooo00Kooooo1?ooO`25oooooaD0o`009Oooool10000007ooooo00000`00003o
ooooooooo`0Yooooo`030?l00?oooooooooo02Cooooo0P3o00000oooooooogl0oomo0004ooooo`;o
ogl0Q_oooolE0?l002Gooooo0@000001ooooo`0000<00000ooooooooool0:_ooool00`3o003ooooo
ooooo`0Cooooo`Coo`003_ooool0103o003oogl0oomo0?ooO`2;oooooaD0o`009Oooool10000007o
oooo00000`00003oooooooooo`0[ooooo`030?l00?oooooooooo017ooooo1_oo000=ooooo`04oomo
003o0000o`00oomo08_ooooo5@3o000Uooooo`4000000Oooool0000300000?oooooooooo02cooooo
00<0o`00ooooooooool02?ooool2oomo00Gooooo2?oo000=ooooo`;oogl000<0o`00ooooooooool0
ROoooolE0?l002Gooooo0@000001ooooo`0000<00000ooooooooool0;Oooool00`3o003ooooooooo
o`06ooooo`Coogl01?ooool8ool0013ooooo00<0o`00ooooooooool0R?oooolE0?l002Gooooo0@00
0001ooooo`0000<00000ooooooooool0:oooool2oomo0003ooooo`3o003ooooo00Kooooo1?ooO`04
ooooo`Soo`004Oooool00`3o003oooooooooo`27oooooaD0o`009Oooool10000007ooooo00000`00
003oooooooooo`0Zooooo`Coogl000?ooooo0?l00?ooool01_ooool2oomo00Gooooo2?oo000;oooo
o`;oogl01Oooool00`3o003oooooooooo`09ooooo`;oogl0NooooolE0?l002Gooooo0@000001oooo
o`0000<00000ooooooooool0:_ooool4oomo00;ooooo00<0o`00ooooooooool03?ooool6ool000_o
oooo1?ooO`04ooooo`030?l00?oooooooooo00Sooooo1?ooO`1joooooaD0o`009Oooool10000007o
oooo00000`00003oooooooooo`0[ooooo`;oogl01?ooool00`3o003oooooooooo`0<ooooo`Coo`00
3?ooool4oomo00Gooooo00<0o`00ooooooooool01oooool4oomo07[ooooo5@3o000Uooooo`400000
0Oooool0000300000?oooooooooo03;ooooo0P3o000Mooooo`;oogl01oooool00`3o003ooooooooo
o`07ooooo`;oogl0]Oooool10000007ooooo00000`00003oooooooooo`0dooooo`030?l00?oooooo
oooo02Cooooo00<0o`00ooooooooool0_Oooool10000007ooooo00000`00003oooooooooo`0eoooo
o`030?l00?oooooooooo02Cooooo00<0o`00ooooooooool0_?ooool10000007ooooo00000`00003o
ooooooooo`0fooooo`80o`009Oooool00`3o003oooooooooo`2kooooo`4000000Oooool000030000
0?oooooooooo03Sooooo0P3o00000oooO`3oooooooooo`02oomo01kooooo00<0o`00ooooooooool0
^oooool10000007ooooo00000`00003oooooooooo`0hooooo`;oogl00P3o0004oomo01kooooo00<0
o`00ooooooooool0^_ooool10000007ooooo00000`00003oooooooooo`0hooooo`Coogl00P3o0002
oomo01kooooo00<0o`00ooooooooool0^_ooool10000007ooooo00000`00003oooooooooo`0ioooo
o`Googl000<0o`00ooooooooool07Oooool00`3o003oogl0oomo002jooooo`4000000Oooool00003
00000?oooooooooo03_ooooo1?ooO`020?l001gooooo00Coogl00?l00?ooO`3oogl0^Oooool10000
007ooooo00000`00003oooooooooo`0looooo`;oogl00oooool20?l001_ooooo00Coogl00?l00?oo
O`3oogl0^Oooool10000007ooooo00000`00003oooooooooo`13ooooo`80o`006_ooool00oooO`00
o`00ooooo`2iooooo`4000000Oooool0000300000?oooooooooo04Gooooo0P3o000Iooooo`030?l0
0?oooooooooo0;Sooooo0@000001ooooo`0000<00000ooooooooool0Aoooool20?l001Gooooo0P3o
002kooooo`4000000Oooool0000300000?oooooooooo04Wooooo0`3o000@ooooo`80o`00_Oooool1
0000007ooooo00000`00003oooooooooo`0aooooo`;oogl06Oooool30?l000cooooo00<0o`00oooo
ooooool0_Oooool10000007ooooo00000`00003oooooooooo`0`ooooo`Coogl06oooool60?l000Co
oooo0P3o0030ooooo`4000000Oooool0000300000?oooooooooo033ooooo1?ooO`0Qooooo`@0o`00
`_ooool10000007ooooo00000`00003oooooooooo`0aooooo`;oogl0j?ooool10000007ooooo0000
0`00003oooooooooo`3ooooooacooooo0@000001ooooo`0000<00000ooooooooool0oooooolLoooo
o`4000000Oooool0000300000?oooooooooo0?oooooo7?ooool10000007ooooo00000`00003ooooo
ooooo`3ooooooacooooo0@000001ooooo`0000<00000ooooooooool0oooooolLooooo`4000000Ooo
ool0000300000?oooooooooo07gooooo0_ooO`2Looooo`4000000Oooool0000300000?oooooooooo
07cooooo1?ooO`2Kooooo`4000000Oooool0000300000?oooooooooo05Cooooo0_ooO`0Vooooo`Co
ogl0Voooool10000007ooooo00000`00003oooooooooo`1Cooooo`Coogl02oooool5ool0oaKooooo
0_ooO`2Looooo`4000000Oooool0000300000?oooooooooo05?ooooo1?ooO`0:ooooo`Ooo`3o/ooo
ool10000007ooooo00000`00003oooooooooo`1Dooooo`;oogl02_ooool9ool0ok;ooooo0@000001
ooooo`0000<00000ooooooooool0Goooool;ool0ok7ooooo0@000001ooooo`0000<00000oooooooo
ool0Goooool;ool0o`03oomo0?oooooooooo0:kooooo0@000001ooooo`0000<00000ooooooooool0
Goooool;ool0o`;oogl0[oooool10000007ooooo00000`00003oooooooooo`1Oooooo`_oo`3o0_oo
O`2_ooooo`4000000Oooool0000300000?oooooooooo05oooooo2ooo0?l00oooO`3oooooooooo`2^
ooooo`4000000Oooool0000300000?oooooooooo063ooooo2Ooo0?nbooooo`4000000Oooool00003
00000?oooooooooo067ooooo1ooo0?ncooooo`4000000Oooool0000300000?oooooooooo06;ooooo
1Ooo0?ndooooo`4000000Oooool0000300000?oooooooooo0?oooooo7?ooool10000007ooooo0000
0`00003oooooooooo`3ooooooacooooo0@000001ooooo`0000<00000ooooooooool0oooooolLoooo
o`4000000Oooool0000300000?oooooooooo0?oooooo7?ooool10000007ooooo00000`00003ooooo
ooooo`3ooooooacooooo0@000001ooooo`0000<00000ooooooooool0oooooolLooooo`4000000Ooo
ool0000300000?oooooooooo0?oooooo7?ooool10000007ooooo00000`00003oooooooooo`3ooooo
oacooooo0@000001ooooo`0000<00000ooooooooool0oooooolLooooo`4000000Oooool000030000
0?oooooooooo0?oooooo7?ooool10000007ooooo00000`00003oooooooooo`3ooooooacooooo0@00
0001ooooo`0000<00000ooooooooool0oooooolLooooo`4000000Oooool0000300000?oooooooooo
0?oooooo7?ooool10000007ooooo00000`00003oooooooooo`3ooooooacooooo0@000001ooooo`00
00<00000ooooooooool0oooooolLooooo`4000000Oooool0000300000?oooooooooo0?oooooo7?oo
ool10000007ooooo00000`00003oooooooooo`3ooooooacooooo0@000001ooooo`0000<00000oooo
ooooool0oooooolLooooo`4000000Oooool0000300000?oooooooooo0?oooooo7?ooool10000007o
oooo00000`00003oooooooooo`3ooooooacooooo0@000001ooooo`0000<00000ooooooooool0oooo
oolLooooo`4000000Oooool0000300000?oooooooooo0?oooooo7?ooool10000007ooooo00000`00
003oooooooooo`3ooooooacooooo0@000001ooooo`0000<00000ooooooooool0oooooolLooooo`40
00000Oooool0000300000?oooooooooo0?oooooo7?ooool10000007ooooo00000`00003ooooooooo
o`3ooooooacooooo0@000001ooooo`0000<00000ooooooooool0oooooolLooooo`4000000Oooool0
000300000?oooooooooo0?oooooo7?ooool10000007ooooo00000`00003oooooooooo`3ooooooaco
oooo0@000001ooooo`0000<00000ooooooooool0oooooolLooooo`4000000Oooool0000300000?oo
oooooooo0?oooooo1?ooool2oomo01Kooooo0@000001ooooo`0000<00000ooooooooool0ooooool3
ooooo`Coogl05Oooool10000007ooooo00000`00003oooooooooo`3oooooo`?ooooo1?ooO`0Eoooo
o`4000000Oooool0000300000?oooooooooo0?oooooo1?ooool2oomo01Kooooo0@000001ooooo`00
00<00000ooooooooool0oooooolLooooo`4000000Oooool0000300000?oooooooooo0?oooooo7?oo
ool10000007ooooo00000`00003oooooooooo`3ooooooacooooo0@000001ooooo`0000<00000oooo
ooooool0oooooolLooooo`4000000Oooool0000300000?oooooooooo0?oooooo7?ooool10000007o
oooo00000`00003oooooooooo`3ooooooacooooo0@000001ooooo`0000<00000ooooooooool0oooo
oolLooooo`4000000Oooool0000300000?oooooooooo0?oooooo7?ooool10000007ooooo00000`00
003oooooooooo`3ooooooacooooo0@000001ooooo`0000<00000ooooooooool0oooooolLooooo`40
00000Oooool0000300000?oooooooooo0;Gooooo0_ooO`1Tooooo`4000000Oooool0000300000?oo
oooooooo0;Cooooo1?ooO`1Sooooo`4000000Oooool0000300000?oooooooooo0;Cooooo1?ooO`1S
ooooo`4000000Oooool0000300000?oooooooooo0;Gooooo0_ooO`0eooooo`;oogl0;Oooool10000
007ooooo00000`00003oooooooooo`3Tooooo`;oogl01Oooool4oomo02cooooo0@000001ooooo`00
00<00000ooooooooool0hoooool4oomo00Cooooo1?ooO`0/ooooo`4000000Oooool0000300000?oo
oooooooo0<?ooooo0_ooO`0Nooooo`Coogl01Oooool2oomo02gooooo0@000001ooooo`0000<00000
ooooooooool0`_ooool4oomo00/0003o4oooool2oomo03Gooooo0@000001ooooo`0000<00000oooo
ooooool0`_ooool40000o`_ooooo0P000?m8ooooo`4000000Oooool0000300000?oooooooooo0;ko
oooo10000?l00oooooooogl0oomo000>ooooo`80003oA_ooool10000007ooooo00000`00003ooooo
ooooo`2iooooo`;oogl00`000?lGooooo`80003o2Oooool2oomo03Wooooo0@000001ooooo`0000<0
0000ooooooooool0]oooool01@000?oo003oo`00o`000?ooogl001_ooooo00?o003o0000ooooool0
1Oooool4oomo03Sooooo0@000001ooooo`0000<00000ooooooooool0]?ooool30000o`03oooooooo
O`3oogl000;oogl07?ooool00`000?ooooooooooo`04ooooo`Coogl00oooool2oomo03?ooooo0@00
0001ooooo`0000<00000ooooooooool0/_ooool20000o`?oogl00_ooool2oomo01?ooooo0_ooO`08
ooooo`030000oooooooooooo00Gooooo0_ooO`03ooooo`Coogl0<_ooool10000007ooooo00000`00
003oooooooooo`2`ooooo`80003o00?ooooooomo0?ooO`000_ooO`06ooooo`;oogl03_ooool4oomo
00Oooooo00<0003oooooooooool02_ooool4oomo03;ooooo0@000001ooooo`0000<00000oooooooo
ool0[_ooool20000o`Cooooo0_ooO`06ooooo`Coogl03Oooool4oomo00Oooooo00<0003ooooooooo
ool02oooool2oomo03?ooooo0@000001ooooo`0000<00000ooooooooool0Roooool2oomo023ooooo
00<0003oooooooooool01?ooool2oomo00Kooooo1?ooO`0>ooooo`;oogl02Oooool00`000?oooooo
ooooo`0oooooo`4000000Oooool0000300000?oooooooooo08[ooooo1?ooO`0Mooooo`80003o1_oo
ool4oomo00Kooooo0_ooO`0Jooooo`030000oooooooooooo03oooooo0@000001ooooo`0000<00000
ooooooooool0R_ooool4oomo01cooooo00<0003oooooooooool01_ooool4oomo02;ooooo00<0003o
ooooooooool0?oooool10000007ooooo00000`00003oooooooooo`2;ooooo`;oogl06oooool00`00
0?oo003oooooo`09ooooo`;oogl08oooool00`000?ooooooooooo`0oooooo`4000000Oooool00003
00000?oooooooooo09Kooooo0_ooO`0>ooooo`80003o:_ooool2oomo00Gooooo00<0003ooooooooo
ool0?oooool10000007ooooo00000`00003oooooooooo`2Eooooo`Coogl03?ooool010000?oooooo
oomo0?ooO`0Xooooo`Coogl00oooool00`000?ooooooooooo`10ooooo`4000000Oooool000030000
0?oooooooooo09Gooooo1?ooO`0:ooooo`80003o00?ooooooomo0?ooO`000_ooO`0Wooooo`Coogl0
0oooool00`000?ooooooooooo`10ooooo`4000000Oooool0000300000?oooooooooo09Kooooo0_oo
O`0:ooooo`040000ooooooooooooooooo`Coogl0:?ooool2oomo00Cooooo00<0003oooooooooool0
@?ooool10000007ooooo00000`00003oooooooooo`2Qooooo`030000oooooooooooo00?ooooo0_oo
O`0^ooooo`030000oooooooooooo047ooooo0@000001ooooo`0000<00000ooooooooool0X?ooool0
0`000?ooooooooooo`0cooooo`030000oooooooooooo01;ooooo0_ooO`0^ooooo`4000000Oooool0
000300000?oooooooooo09kooooo0P000?leooooo`030000oooooooooooo01;ooooo1?ooO`0]oooo
o`4000000Oooool0000300000?oooooooooo09gooooo00<0003oooooooooool05Oooool4o`00oaco
oooo00<0003ooomo0?ooO`004_ooool4oomo02gooooo0@000001ooooo`0000<00000ooooooooool0
W?ooool00`000?ooooooooooo`0Eooooo`Ko003o6_ooool00`000?ooogl0oomo0002oomo01;ooooo
0_ooO`0^ooooo`4000000Oooool0000300000?oooooooooo09_ooooo00<0003oooooooooool05Ooo
ool8o`00oaSooooo00<0003oooooooooO`000oooO`12ooooo`4000000Oooool0000300000?oooooo
oooo09_ooooo00<0003oooooooooool05Oooool8o`00oaOooooo00@0003ooooooooooooooooo0_oo
O`13ooooo`4000000Oooool0000300000?oooooooooo09[ooooo00<0003oooooooooool05_ooool8
o`00oaKooooo00<0003oooooooooool0Aoooool10000007ooooo00000`00003oooooooooo`2Ioooo
o`030000oooooooooooo00cooooo0_ooO`08ooooo`03oomo0?l00?oo003o00Ko003o5Oooool00`00
0?ooooooooooo`02oomo04Kooooo0@000001ooooo`0000<00000ooooooooool0VOooool00`000?oo
ooooooooo`0:ooooo`Googl01oooool2oomo00Ko003o4oooool2oomo0003o`00oooooooooooo00Co
ogl0AOooool10000007ooooo00000`00003oooooooooo`2Hooooo`030000oooooooooooo00[ooooo
1_ooO`08ooooo`;oogl01?l00?lCooooo`;oogl00P000?l2ooooo`Coogl0AOooool10000007ooooo
00000`00003oooooooooo`2Hooooo`030000oooooooooooo00[ooooo1OooO`0Rooooo`04oomo0000
0?ooogl0oomo00?ooooo0_ooO`16ooooo`4000000Oooool0000300000?oooooooooo07Kooooo0_oo
O`0Oooooo`030000oooooooooooo00cooooo0_ooO`0Tooooo`030000ooooO`3oogl004cooooo0@00
0001ooooo`0000<00000ooooooooool0MOooool4oomo01kooooo00<0003oooooooooool0<Oooool0
0`000?ooooooooooo`1=ooooo`4000000Oooool0000300000?oooooooooo07Gooooo1?ooO`0:oooo
o`;oogl04Oooool00`000?ooooooooooo`0aooooo`030000oooooooooooo04kooooo0@000001oooo
o`0000<00000ooooooooool0M_ooool2oomo00[ooooo1?ooO`0?ooooo`030000oooooooooooo01So
oooo0_ooO`0Gooooo`030000oooooooooooo04oooooo0@000001ooooo`0000<00000ooooooooool0
P_ooool4oomo00oooooo00<0003oooooooooool05oooool4oomo01Cooooo0P000?mBooooo`400000
0Oooool0000300000?oooooooooo08?ooooo0_ooO`0?ooooo`030000oooooooooooo01;ooooo0_oo
O`04ooooo`Coogl04Oooool30000oeCooooo0@000001ooooo`0000<00000ooooooooool0U?ooool0
0`000?ooooooooooo`0Aooooo`Coogl01?ooool2oomo013ooooo0P000?mGooooo`4000000Oooool0
000300000?oooooooooo09Cooooo00<0003oooooooooool04Oooool4oomo01Gooooo00<0003ooooo
ooooool0Eoooool10000007ooooo00000`00003oooooooooo`2Dooooo`030000oooooooooooo01;o
oooo0_ooO`0Dooooo`80003oF_ooool10000007ooooo00000`00003oooooooooo`2Dooooo`030000
oooooooooooo02Kooooo0P000?mLooooo`4000000Oooool0000300000?oooooooooo09Gooooo00<0
003oooooooooool09?ooool00`000?ooooooooooo`1Looooo`4000000Oooool0000300000?oooooo
oooo09Gooooo00<0003oooooooooool08_ooool20000oeoooooo0@000001ooooo`0000<00000oooo
ooooool0UOooool00`000?ooooooooooo`0Pooooo`80003oHOooool10000007ooooo00000`00003o
ooooooooo`24ooooo`;oogl03oooool20000oaoooooo0P000?mSooooo`4000000Oooool000030000
0?oooooooooo08?ooooo1?ooO`0@ooooo`80003o6_ooool30000ofGooooo0@000001ooooo`0000<0
0000ooooooooool0Poooool4oomo01;ooooo0P000?lDooooo`@0003oJ?ooool10000007ooooo0000
0`00003oooooooooo`24ooooo`;oogl05Oooool30000o`kooooo0`000?l3ooooo`;oogl0Ioooool1
0000007ooooo00000`00003oooooooooo`2Nooooo`<0003o1Oooool60000o`Gooooo1?ooO`1Voooo
o`4000000Oooool0000300000?oooooooooo0:7ooooo1@000?l;ooooo`Coogl0I_ooool10000007o
oooo00000`00003oooooooooo`2booooo`;oogl0Ioooool10000007ooooo00000`00003ooooooooo
o`3ooooooacooooo0@000001ooooo`0000<00000ooooooooool0oooooolLooooo`4000000Oooool0
000300000?oooooooooo07_ooooo0_ooO`2Nooooo`4000000Oooool0000300000?oooooooooo07[o
oooo1?ooO`2Mooooo`4000000Oooool0000300000?oooooooooo07[ooooo1?ooO`0Pooooo`;oogl0
Noooool10000007ooooo00000`00003oooooooooo`1kooooo`;oogl08?ooool4oomo07[ooooo0@00
0001ooooo`0000<00000ooooooooool0WOooool4oomo07[ooooo0@000001ooooo`0000<00000oooo
ooooool0T?ooool2oomo00cooooo0_ooO`1kooooo`4000000Oooool0000300000?oooooooooo08oo
oooo1?ooO`28ooooo`4000000Oooool0000300000?oooooooooo08oooooo1?ooO`28ooooo`400000
0Oooool0000300000?oooooooooo093ooooo0_ooO`0Sooooo`;oogl0I?ooool10000007ooooo0000
0`00003oooooooooo`2dooooo`Coogl0Hoooool10000007ooooo00000`00003oooooooooo`2doooo
o`Coogl0Hoooool10000007ooooo00000`00003oooooooooo`2eooooo`;oogl0I?ooool10000007o
oooo00000`00003oooooooooo`3ooooooacooooo0@000001ooooo`0000<00000ooooooooool0oooo
oolLooooo`4000000Oooool0000300000?oooooooooo0?oooooo7?ooool10000007ooooo00000`00
003oooooooooo`3ooooooacooooo0@000001ooooo`0000<00000ooooooooool0oooooolLooooo`40
00000Oooool0000300000?oooooooooo0?oooooo7?ooool10000007ooooo00000`00003ooooooooo
o`3ooooooacooooo0@000001ooooo`0000<00000ooooooooool0oooooolLooooo`4000000Oooool0
000300000?oooooooooo0?oooooo7?ooool10000007ooooo00000`00003oooooooooo`3ooooooaco
oooo0@000001ooooo`0000<00000ooooooooool0oooooolLooooo`4000000Oooool0000300000?oo
oooooooo0?oooooo7?ooool10000007ooooo00000`00003oooooooooo`3ooooooacooooo0@000001
ooooo`0000<00000ooooooooool0oooooolLooooo`4000000Oooool0000300000?oooooooooo0?oo
oooo7?ooool10000007ooooo00000`00003oooooooooo`3ooooooacooooo0@000001ooooo`0000<0
0000ooooooooool0oooooolLooooo`4000000Oooool0000300000?oooooooooo0?oooooo7?ooool1
0000007ooooo00000`00003oooooooooo`3ooooooacooooo0@000001ooooo`0000<00000oooooooo
ool0oooooolLooooo`4000000Oooool0000300000?oooooooooo0?oooooo7?ooool10000007ooooo
00000`00003oooooooooo`3ooooooacooooo0@000001ooooo`0000<00000ooooooooool0oooooolL
ooooo`4000000Oooool0000300000?oooooooooo0?oooooo7?ooool10000007ooooo00000`00003o
ooooooooo`3ooooooacooooo0@000001ooooo`0000<00000ooooooooool0oooooolLooooo`400000
0Oooool0000300000?oooooooooo0?oooooo7?ooool10000007ooooo00000`00003oooooooooo`3o
oooooacooooo0@000001ooooo`0000<00000ooooooooool0oooooolLooooo`4000000Oooool00003
00000?oooooooooo0?oooooo7?ooool10000007ooooo00000`00003oooooooooo`3ooooooacooooo
0@000001ooooo`0000<00000ooooooooool0oooooolLooooo`4000000Oooool0000300000?oooooo
oooo0?oooooo7?ooool10000007ooooo00000`00003oooooooooo`3ooooooacooooo0@000001oooo
o`0000<00000ooooooooool0oooooolLooooo`4000000Oooool0000300000?oooooooooo0?oooooo
7?ooool10000007ooooo00000`00003oooooooooo`3ooooooacooooo0@000001ooooo`0000<00000
ooooooooool0S_ooool2oomo08_ooooo0@000001ooooo`0000<00000ooooooooool0SOooool4oomo
08[ooooo0@000001ooooo`0000<00000ooooooooool0SOooool4oomo08[ooooo0@000001ooooo`00
00<00000ooooooooool0S_ooool2oomo08_ooooo0@000001ooooo`0000<00000ooooooooool0oooo
oolLooooo`4000000Oooool0000300000?oooooooooo0?oooooo7?ooool10000007ooooo00000`00
003oooooooooo`3ooooooacooooo0@000001ooooo`0000<00000ooooooooool0oooooolLooooo`40
00000Oooool0000300000?oooooooooo0?oooooo7?ooool10000007ooooo00000`00003ooooooooo
o`3ooooooacooooo0@000001ooooo`0000<00000ooooooooool0oooooolLooooo`4000000Oooool0
000300000?oooooooooo0?oooooo7?ooool10000007ooooo00000`00003oooooooooo`3ooooooaco
oooo0@000001ooooo`0000<00000ooooooooool0oooooolLooooo`4000000Oooool0000300000?oo
oooooooo0?oooooo7?ooool10000007ooooo00000`00003oooooooooo`3ooooooacooooo0@000001
ooooo`0000<00000ooooooooool0oooooolLooooo`4000000Oooool0000300000?oooooooooo0?oo
oooo7?ooool10000007ooooo00000`00003oooooooooo`3ooooooacooooo0@000001ooooo`0000<0
0000ooooooooool0oooooolLooooo`4000000Oooool0000300000?oooooooooo0?oooooo7?ooool1
0000007ooooo00000`00003oooooooooo`3ooooooacooooo0@000001ooooo`0000<00000oooooooo
ool0oooooolLooooo`4000000Oooool0000300000?oooooooooo0?oooooo7?ooool10000007ooooo
00000`00003oooooooooo`3ooooooacooooo0@000001ooooo`00o`00000P0000007ooooo0000\
\>"],
  ImageRangeCache->{{{0, 287}, {287, 0}} -> {-1.01089, -1.01089, 0.00704453, \
0.00704453}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.49505 0.5 0.49505 [
[ 0 0 -0.125 0 ]
[ 0 0 -0.125 0 ]
[ 0 1 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
0 0 m
1 0 L
s
0 0 m
0 1 L
s
0 1 m
1 1 L
s
1 0 m
1 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
1 .5 0 r
.015 w
.03175 .1355 Mdot
.03435 .12523 Mdot
.11137 .12765 Mdot
.14107 .18841 Mdot
.16218 .24538 Mdot
.17294 .21053 Mdot
.18267 .18577 Mdot
.18434 .1304 Mdot
.18553 .30956 Mdot
.20401 .239 Mdot
.21247 .27571 Mdot
.21687 .20845 Mdot
.22376 .2799 Mdot
.22832 .27485 Mdot
.29063 .20974 Mdot
.29686 .25079 Mdot
.30487 .22936 Mdot
.30683 .34623 Mdot
.32055 .20902 Mdot
.32574 .21979 Mdot
.34472 .28521 Mdot
.35998 .36393 Mdot
.36335 .24976 Mdot
.3794 .36608 Mdot
.42386 .66992 Mdot
.44391 .74519 Mdot
.45059 .34198 Mdot
.47208 .67586 Mdot
.47436 .71381 Mdot
.49778 .59825 Mdot
.50874 .91643 Mdot
.51516 .76219 Mdot
.53655 .61374 Mdot
.56563 .75219 Mdot
.59189 .65665 Mdot
.59581 .61604 Mdot
.59923 .6556 Mdot
.60292 .68499 Mdot
.62656 .67779 Mdot
.63555 .72451 Mdot
.63919 .652 Mdot
.64169 .6004 Mdot
.64246 .58611 Mdot
.64496 .54267 Mdot
.64608 .77288 Mdot
.65077 .64308 Mdot
.66065 .57816 Mdot
.67474 .59169 Mdot
.69296 .563 Mdot
.72815 .65902 Mdot
.73169 .58879 Mdot
.74669 .61318 Mdot
.74821 .65474 Mdot
.75963 .63781 Mdot
.79673 .57809 Mdot
.80925 .55852 Mdot
.81525 .58444 Mdot
.83417 .62985 Mdot
.83598 .55526 Mdot
.91595 .49319 Mdot
1 0 0 r
.005 w
.16128 .17044 m
.18734 .17269 L
.21339 .17909 L
.2345 .18734 L
.23945 .19126 L
.2655 .20415 L
.27874 .21339 L
.29156 .22295 L
.31204 .23945 L
.31761 .24532 L
.33549 .2655 L
.34367 .28341 L
.34499 .29156 L
.34367 .29798 L
.31761 .3104 L
.29156 .30711 L
.2655 .30014 L
.24507 .29156 L
.23945 .28747 L
.21339 .27402 L
.20155 .2655 L
.18734 .25472 L
.16884 .23945 L
.16128 .2313 L
.14618 .21339 L
.13806 .18734 L
.16128 .17044 L
s
0 0 1 r
.65633 .57701 m
.68239 .56842 L
.70844 .56313 L
.7345 .56168 L
.76055 .5752 L
.76359 .57817 L
.76859 .60422 L
.76055 .62333 L
.75627 .63028 L
.7345 .65485 L
.73298 .65633 L
.70844 .6775 L
.69922 .68239 L
.68239 .69294 L
.65633 .70579 L
.64983 .70844 L
.63028 .71539 L
.60422 .72268 L
.57817 .72651 L
.55211 .7214 L
.53145 .70844 L
.52926 .68239 L
.54239 .65633 L
.55211 .63983 L
.56625 .63028 L
.57817 .6193 L
.60119 .60422 L
.60422 .60227 L
.63028 .58726 L
.65315 .57817 L
.65633 .57701 L
s
1 0 0 r
.03 w
.24141 .24033 Mdot
0 0 1 r
.64872 .64417 Mdot
1 0 0 r
.79703 .00495 m
.79703 .25248 L
.87129 .25248 L
.87129 .00495 L
F
0 0 1 r
.89604 .00495 m
.89604 .00495 L
.9703 .00495 L
.9703 .00495 L
F
1 0 1 r
.04 w
.36335 .24976 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P000182000`400?l00000o`00003ooooooolQ
ooooo`00ool0000Po`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`00
00?o0000ooooooooool0hOoooolEool002Gooooo0Ol00001ooooo`0000?o0000ooooooooool0hOoo
oolEool002Gooooo0Ol00001ooooo`0000?o0000ooooooooool0hOoooolEool002Gooooo0Ol00001
ooooo`0000?o0000ooooooooool0hOoooolEool002Gooooo0Ol00001ooooo`0000?o0000oooooooo
ool0hOoooolEool002Gooooo0Ol00001ooooo`0000?o0000ooooooooool0hOoooolEool002Gooooo
0Ol00001ooooo`0000?o0000ooooooooool0hOoooolEool002Gooooo0Ol00001ooooo`0000?o0000
ooooooooool0hOoooolEool002Gooooo0Ol00001ooooo`0000?o0000ooooooooool0hOoooolEool0
02Gooooo0Ol00001ooooo`0000?o0000ooooooooool0hOoooolEool002Gooooo0Ol00001ooooo`00
00?o0000ooooooooool0hOoooolEool002Gooooo0Ol00001ooooo`0000?o0000ooooooooool0hOoo
oolEool002Gooooo0Ol00001ooooo`0000?o0000ooooooooool0hOoooolEool002Gooooo0Ol00001
ooooo`0000?o0000ooooooooool0hOoooolEool002Gooooo0Ol00001ooooo`0000?o0000oooooooo
ool0hOoooolEool002Gooooo0Ol00001ooooo`0000?o0000ooooooooool0hOoooolEool002Gooooo
0Ol00001ooooo`0000?o0000ooooooooool0hOoooolEool002Gooooo0Ol00001ooooo`0000?o0000
ooooooooool0hOoooolEool002Gooooo0Ol00001ooooo`0000?o0000ooooooooool0hOoooolEool0
02Gooooo0Ol00001ooooo`0000?o0000ooooooooool0hOoooolEool002Gooooo0Ol00001ooooo`00
00?o0000ooooooooool0hOoooolEool002Gooooo0Ol00001ooooo`0000?o0000ooooooooool0hOoo
oolEool002Gooooo0Ol00001ooooo`0000?o0000ooooooooool0hOoooolEool002Gooooo0Ol00001
ooooo`0000?o0000ooooooooool0hOoooolEool002Gooooo0Ol00001ooooo`0000?o0000oooooooo
ool0hOoooolEool002Gooooo0Ol00001ooooo`0000?o0000ooooooooool0hOoooolEool002Gooooo
0Ol00001ooooo`0000?o0000ooooooooool0hOoooolEool002Gooooo0Ol00001ooooo`0000?o0000
ooooooooool0hOoooolEool002Gooooo0Ol00001ooooo`0000?o0000ooooooooool0hOoooolEool0
02Gooooo0Ol00001ooooo`0000?o0000ooooooooool0hOoooolEool002Gooooo0Ol00001ooooo`00
00?o0000ooooooooool0hOoooolEool002Gooooo0Ol00001ooooo`0000?o0000ooooooooool0hOoo
oolEool002Gooooo0Ol00001ooooo`0000?o0000ooooooooool01_ooool2oomo0=Wooooo5Ooo000U
ooooo`7o00000Oooool00003o`000?oooooooooo00Gooooo1?ooO`0Cooooo`;oogl0`ooooolEool0
02Gooooo0Ol00001ooooo`0000?o0000ooooooooool01Oooool4oomo01;ooooo1?ooO`0Booooo`;o
ogl0[_oooolEool002Gooooo0Ol00001ooooo`0000?o0000ooooooooool01Oooool3oomo01?ooooo
1?ooO`0Aooooo`Coogl0[OoooolEool002Gooooo0Ol00001ooooo`0000?o0000ooooooooool01?oo
ool4oomo01Cooooo0_ooO`0Booooo`Coogl0[OoooolEool002Gooooo0Ol00001ooooo`0000?o0000
ooooooooool01?ooool4oomo02Wooooo0_ooO`2^oooooaGoo`009Oooool1o`00007ooooo00000ol0
003oooooooooo`05ooooo`;oogl0f_oooolEool002Gooooo0Ol00001ooooo`0000?o0000oooooooo
ool0hOoooolEool002Gooooo0Ol00001ooooo`0000?o0000ooooooooool0hOoooolEool002Gooooo
0Ol00001ooooo`0000?o0000ooooooooool0hOoooolEool002Gooooo0Ol00001ooooo`0000?o0000
ooooooooool0hOoooolEool002Gooooo0Ol00001ooooo`0000?o0000ooooooooool0hOoooolEool0
02Gooooo0Ol00001ooooo`0000?o0000ooooooooool0hOoooolEool002Gooooo0Ol00001ooooo`00
00?o0000ooooooooool0hOoooolEool002Gooooo0Ol00001ooooo`0000?o0000ooooooooool0:_oo
ool6ool00;7ooooo5Ooo000Uooooo`7o00000Oooool00003o`000?oooooooooo02Wooooo00?oo`00
ooooooooool01?ooool5ool00:cooooo5Ooo000Uooooo`7o00000Oooool00003o`000?oooooooooo
02Oooooo0_oo000<ooooo`Coo`00Z?oooolEool002Gooooo0Ol00001ooooo`0000?o0000oooooooo
ool09_ooool00ooo003oooooooooo`0@ooooo`Coo`00Y?oooolEool002Gooooo0Ol00001ooooo`00
00?o0000ooooooooool09?ooool00oooO`3oo`00ooooo`09ooooo`;oogl02oooool3ool00:7ooooo
5Ooo000Uooooo`7o00000Oooool00003o`000?oooooooooo02?ooooo00Coogl0ool00?ooO`3oogl0
2?ooool4oomo00gooooo00?oo`00ooooooooool0W_oooolEool002Gooooo0Ol00001ooooo`0000?o
0000ooooooooool08oooool01?ooO`3oo`00oomo0?ooO`08ooooo`Coogl03_ooool2ool009kooooo
5Ooo000Uooooo`7o00000Oooool00003o`000?oooooooooo02Cooooo00?oogl0ool00?ooool02Ooo
ool2oomo017ooooo0_oo002LoooooaGoo`009Oooool1o`00007ooooo00000ol0003oooooooooo`0U
ooooo`03ool00?oooooooooo01gooooo0_oo002JoooooaGoo`009Oooool1o`00007ooooo00000ol0
003oooooooooo`0Uooooo`03ool00?oooooooooo01oooooo0_oo002HoooooaGoo`009Oooool1o`00
007ooooo00000ol0003oooooooooo`0Vooooo`03ool00?oooooooooo017ooooo0_ooO`0=ooooo`;o
o`001?ooool2oomo00Oooooo0_ooO`27oooooaGoo`009Oooool1o`00007ooooo00000ol0003ooooo
ooooo`0Vooooo`03ool00?oooooooooo00Gooooo0_ooO`09ooooo`Coogl03_ooool00ooo003ooooo
ooooo`04oomo00Gooooo1?ooO`26oooooaGoo`009Oooool1o`00007ooooo00000ol0003ooooooooo
o`0Vooooo`03ool00?oooooooooo00Cooooo1?ooO`08ooooo`Coogl03oooool00ooo003ooooooomo
0003oomo00Gooooo1?ooO`26oooooaGoo`009Oooool1o`00007ooooo00000ol0003oooooooooo`0W
ooooo`03ool00?oooooooooo00?ooooo1?ooO`09ooooo`;oogl04Oooool01?oo003ooooooomo0?oo
O`07ooooo`?oogl0Q_oooolEool002Gooooo0Ol00001ooooo`0000?o0000ooooooooool09oooool0
0ooo003oooooooooo`04ooooo`;oogl07_ooool00ooo003oooooooooo`07ooooo`Coogl0QOoooolE
ool002Gooooo0Ol00001ooooo`0000?o0000ooooooooool0:?ooool00ooo003oooooooooo`0Toooo
o`03ool00?oooooooooo00Kooooo1?ooO`25oooooaGoo`009Oooool1o`00007ooooo00000ol0003o
ooooooooo`0Yooooo`03ool00?oooooooooo02Cooooo0_oo00000oooooooogl0oomo0004ooooo`;o
ogl0Q_oooolEool002Gooooo0Ol00001ooooo`0000?o0000ooooooooool0:_ooool00ooo003ooooo
ooooo`0Cooooo`Coo`003_ooool01?oo003oogl0oomo0?ooO`2;oooooaGoo`009Oooool1o`00007o
oooo00000ol0003oooooooooo`0[ooooo`03ool00?oooooooooo017ooooo1_oo000=ooooo`04oomo
0?oo003oo`00oomo00gooooo1Ooo0?mioooooaGoo`009Oooool1o`00007ooooo00000ol0003ooooo
ooooo`0/ooooo`03ool00?oooooooooo00Sooooo0_ooO`05ooooo`Soo`003Oooool2oomo0003ool0
0?oooooooooo00[ooooo1ooo0?mhoooooaGoo`009Oooool1o`00007ooooo00000ol0003ooooooooo
o`0]ooooo`03ool00?oooooooooo00Kooooo1?ooO`04ooooo`Soo`004?ooool00ooo003ooooooooo
o`08ooooo`Woo`3oMooooolEool002Gooooo0Ol00001ooooo`0000?o0000ooooooooool0:oooool2
oomo0003oooooooo003ooooo00Kooooo1?ooO`04ooooo`Soo`004Oooool00ooo003oooooooooo`06
ooooo`_oo`3oM_oooolEool002Gooooo0Ol00001ooooo`0000?o0000ooooooooool0:_ooool4oomo
0003oooooooo003ooooo00Kooooo0_ooO`05ooooo`Soo`002oooool2oomo00Gooooo00?oo`00oooo
ooooool01Oooool;ool0ogKooooo5Ooo000Uooooo`7o00000Oooool00003o`000?oooooooooo02[o
oooo1?ooO`02ooooo`03ool00?oooooooooo00cooooo1_oo000;ooooo`Coogl01?ooool00ooo003o
ooooooooo`05ooooo`_oo`3oM_oooolEool002Gooooo0Ol00001ooooo`0000?o0000ooooooooool0
:oooool2oomo00Cooooo00?oo`00ooooooooool03?ooool4ool000cooooo1?ooO`05ooooo`03ool0
0?oooooooooo00Cooooo2ooo0?mfoooooaGoo`009Oooool1o`00007ooooo00000ol0003ooooooooo
o`0booooo`;oo`007Oooool2oomo00Oooooo00?oo`00ooooooooool00oooool;ool0ok3ooooo0Ol0
0001ooooo`0000?o0000ooooooooool0=?ooool00ooo003oooooooooo`0Tooooo`03ool00?oooooo
oooo00?ooooo2Ooo0?naooooo`7o00000Oooool00003o`000?oooooooooo03Gooooo00?oo`00oooo
ooooool09?ooool00ooo003oooooooooo`03ooooo`Ooo`3o/_ooool1o`00007ooooo00000ol0003o
ooooooooo`0fooooo`;oo`009Oooool00ooo003oooooooooo`03ooooo`Goo`3o/oooool1o`00007o
oooo00000ol0003oooooooooo`0hooooo`;oo`0000?oogl0ooooooooool00_ooO`0Nooooo`03ool0
0?oooooooooo0;_ooooo0Ol00001ooooo`0000?o0000ooooooooool0>?ooool2oomo00;oo`001?oo
O`0Nooooo`03ool00?oooooooooo0;[ooooo0Ol00001ooooo`0000?o0000ooooooooool0>?ooool4
oomo00;oo`000_ooO`0Nooooo`03ool00?oooooooooo0;[ooooo0Ol00001ooooo`0000?o0000oooo
ooooool0>Oooool5oomo0003ool00?oooooooooo01gooooo00?oo`00oomo0?ooO`00^_ooool1o`00
007ooooo00000ol0003oooooooooo`0kooooo`Coogl00_oo000Mooooo`04oomo0?oo003oogl0oomo
0;Wooooo0Ol00001ooooo`0000?o0000ooooooooool0??ooool2oomo00?ooooo0_oo000Kooooo`04
oomo0?oo003oogl0oomo0;Wooooo0Ol00001ooooo`0000?o0000ooooooooool0@oooool2ool001[o
oooo00?oogl0ool00?ooool0^Oooool1o`00007ooooo00000ol0003oooooooooo`15ooooo`;oo`00
6Oooool00ooo003oooooooooo`2hooooo`7o00000Oooool00003o`000?oooooooooo04Oooooo0_oo
000Eooooo`;oo`00^oooool1o`00007ooooo00000ol0003oooooooooo`19ooooo`?oo`004?ooool2
ool00;gooooo0Ol00001ooooo`0000?o0000ooooooooool0<Oooool2oomo01Wooooo0ooo000<oooo
o`03ool00?oooooooooo0;gooooo0Ol00001ooooo`0000?o0000ooooooooool0<?ooool4oomo01_o
oooo1_oo0004ooooo`;oo`00`?ooool1o`00007ooooo00000ol0003oooooooooo`0`ooooo`Coogl0
8Oooool4ool00<;ooooo0Ol00001ooooo`0000?o0000ooooooooool0<Oooool2oomo0>Sooooo0Ol0
0001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo
0?oooooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`00
00?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?oo
ool1o`00007ooooo00000ol0003oooooooooo`1mooooo`;oogl0W?ooool1o`00007ooooo00000ol0
003oooooooooo`1looooo`Coogl0Voooool1o`00007ooooo00000ol0003oooooooooo`1Dooooo`;o
ogl09_ooool4oomo09_ooooo0Ol00001ooooo`0000?o0000ooooooooool0Doooool4oomo02Kooooo
0_ooO`2Looooo`7o00000Oooool00003o`000?oooooooooo05?ooooo1?ooO`34ooooo`7o00000Ooo
ool00003o`000?oooooooooo05Cooooo0_ooO`35ooooo`7o00000Oooool00003o`000?oooooooooo
0?oooooo7?ooool1o`00007ooooo00000ol0003oooooooooo`1Sooooo`;oogl01?ooool2oomo0;3o
oooo0Ol00001ooooo`0000?o0000ooooooooool0H_ooool4oomo00;ooooo1?ooO`2_ooooo`7o0000
0Oooool00003o`000?oooooooooo06;ooooo1?ooO`02ooooo`Coogl0[oooool1o`00007ooooo0000
0ol0003oooooooooo`1Sooooo`;oogl01?ooool2oomo0;3ooooo0Ol00001ooooo`0000?o0000oooo
ooooool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007o
oooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooo
oolLooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0
003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o
00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003ooooooooo
o`3ooooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool0
0003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooooaco
oooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oo
oooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001
ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo0?oo
oooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o
0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1
o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000oooooooo
ool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo
00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolL
ooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003o
ooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o0000
0Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3o
oooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003
o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo
0Ol00001ooooo`0000?o0000ooooooooool0ooooool4ooooo`;oogl05_ooool1o`00007ooooo0000
0ol0003oooooooooo`3oooooo`?ooooo1?ooO`0Eooooo`7o00000Oooool00003o`000?oooooooooo
0?oooooo0oooool4oomo01Gooooo0Ol00001ooooo`0000?o0000ooooooooool0ooooool4ooooo`;o
ogl05_ooool1o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o
0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1
o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000oooooooo
ool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo
00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolL
ooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003o
ooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0]Oooool2oomo06Cooooo
0Ol00001ooooo`0000?o0000ooooooooool0]?ooool4oomo06?ooooo0Ol00001ooooo`0000?o0000
ooooooooool0]?ooool4oomo06?ooooo0Ol00001ooooo`0000?o0000ooooooooool0]Oooool2oomo
03Gooooo0_ooO`0]ooooo`7o00000Oooool00003o`000?oooooooooo0>Cooooo0_ooO`05ooooo`Co
ogl0;?ooool1o`00007ooooo00000ol0003oooooooooo`3Sooooo`Coogl01?ooool4oomo02cooooo
0Ol00001ooooo`0000?o0000ooooooooool0`oooool2oomo01kooooo1?ooO`05ooooo`;oogl0;Ooo
ool1o`00007ooooo00000ol0003oooooooooo`32ooooo`Coogl02ol00?lCooooo`;oogl0=Oooool1
o`00007ooooo00000ol0003oooooooooo`32ooooo`Co003o2oooool2o`00odSooooo0Ol00001oooo
o`0000?o0000ooooooooool0__ooool4o`00o`03ooooooooO`3oogl000kooooo0_l00?m6ooooo`7o
00000Oooool00003o`000?oooooooooo0;Wooooo0_ooO`03o`00oaOooooo0_l00?l9ooooo`;oogl0
>Oooool1o`00007ooooo00000ol0003oooooooooo`2gooooo`Co003o00?oogl0ooooooooool06Ooo
ool2o`00o`Kooooo1?ooO`0hooooo`7o00000Oooool00003o`000?oooooooooo0;Cooooo0ol00?l0
0oooooooogl0oomo0002oomo01cooooo00?o003oooooooooool01?ooool4oomo00?ooooo0_ooO`0c
ooooo`7o00000Oooool00003o`000?oooooooooo0;;ooooo0_l00?l3oomo00;ooooo0_ooO`0Coooo
o`;oogl02?ooool00ol00?ooooooooooo`05ooooo`;oogl00oooool4oomo03;ooooo0Ol00001oooo
o`0000?o0000ooooooooool0/?ooool2o`00o`03ooooooooO`3oogl000;oogl01_ooool2oomo00ko
oooo1?ooO`07ooooo`03o`00oooooooooooo00[ooooo1?ooO`0booooo`7o00000Oooool00003o`00
0?oooooooooo0:kooooo0_l00?l4ooooo`;oogl01_ooool4oomo00gooooo1?ooO`07ooooo`03o`00
oooooooooooo00_ooooo0_ooO`0cooooo`7o00000Oooool00003o`000?oooooooooo08_ooooo0_oo
O`0Pooooo`03o`00oooooooooooo00Cooooo0_ooO`06ooooo`Coogl03_ooool2oomo00Wooooo00?o
003oooooooooool0?oooool1o`00007ooooo00000ol0003oooooooooo`2:ooooo`Coogl07Oooool2
o`00o`Kooooo1?ooO`06ooooo`;oogl06_ooool00ol00?ooooooooooo`0oooooo`7o00000Oooool0
0003o`000?oooooooooo08[ooooo1?ooO`0Looooo`03o`00oooooooooooo00Kooooo1?ooO`0Roooo
o`03o`00oooooooooooo03oooooo0Ol00001ooooo`0000?o0000ooooooooool0Roooool2oomo01_o
oooo0_l00?l:ooooo`;oogl08oooool00ol00?ooooooooooo`0oooooo`7o00000Oooool00003o`00
0?oooooooooo09Kooooo0_ooO`0>ooooo`;o003o:_ooool2oomo00Gooooo00?o003oooooooooool0
?oooool1o`00007ooooo00000ol0003oooooooooo`2Eooooo`Coogl03?ooool01?l00?oooooooomo
0?ooO`0Xooooo`Coogl00oooool00ol00?ooooooooooo`10ooooo`7o00000Oooool00003o`000?oo
oooooooo09Gooooo1?ooO`0:ooooo`;o003o00?ooooooomo0?ooO`000_ooO`0Wooooo`Coogl00ooo
ool00ol00?ooooooooooo`10ooooo`7o00000Oooool00003o`000?oooooooooo09Kooooo0_ooO`0:
ooooo`04o`00ooooooooooooooooo`Coogl0:?ooool2oomo00Cooooo00?o003oooooooooool0@?oo
ool1o`00007ooooo00000ol0003oooooooooo`2Qooooo`03o`00oooooooooooo00?ooooo0_ooO`0^
ooooo`03o`00oooooooooooo047ooooo0Ol00001ooooo`0000?o0000ooooooooool0X?ooool00ol0
0?ooooooooooo`0cooooo`03o`00oooooooooooo01;ooooo0_ooO`0^ooooo`7o00000Oooool00003
o`000?oooooooooo09kooooo0_l00?leooooo`03o`00oooooooooooo01;ooooo1?ooO`0]ooooo`7o
00000Oooool00003o`000?oooooooooo09gooooo00?o003oooooooooool05Oooool4o`00oacooooo
00?o003ooomo0?ooO`004_ooool4oomo02gooooo0Ol00001ooooo`0000?o0000ooooooooool0W?oo
ool00ol00?ooooooooooo`0Eooooo`Ko003o6_ooool00ol00?ooogl0oomo0002oomo01;ooooo0_oo
O`0^ooooo`7o00000Oooool00003o`000?oooooooooo09_ooooo00?o003oooooooooool05Oooool8
o`00oaSooooo00?o003oooooooooO`000oooO`12ooooo`7o00000Oooool00003o`000?oooooooooo
09_ooooo00?o003oooooooooool05Oooool8o`00oaOooooo00Co003ooooooooooooooooo0_ooO`13
ooooo`7o00000Oooool00003o`000?oooooooooo09[ooooo00?o003oooooooooool05_ooool8o`00
oaKooooo00?o003oooooooooool0Aoooool1o`00007ooooo00000ol0003oooooooooo`2Iooooo`03
o`00oooooooooooo00cooooo0_ooO`08ooooo`03oomo0?l00?oo003o00Ko003o5Oooool00ol00?oo
ooooooooo`02oomo04Kooooo0Ol00001ooooo`0000?o0000ooooooooool0VOooool00ol00?oooooo
ooooo`0:ooooo`Googl01oooool2oomo00Ko003o4oooool2oomo0003o`00oooooooooooo00Coogl0
AOooool1o`00007ooooo00000ol0003oooooooooo`2Hooooo`03o`00oooooooooooo00[ooooo1_oo
O`08ooooo`;oogl01?l00?lCooooo`;oogl00_l00?l2ooooo`Coogl0AOooool1o`00007ooooo0000
0ol0003oooooooooo`2Hooooo`03o`00oooooooooooo00[ooooo1OooO`0Rooooo`04oomo0?l00?oo
ogl0oomo00?ooooo0_ooO`16ooooo`7o00000Oooool00003o`000?oooooooooo07Kooooo0_ooO`0O
ooooo`03o`00oooooooooooo00cooooo0_ooO`0Tooooo`03o`00ooooO`3oogl004cooooo0Ol00001
ooooo`0000?o0000ooooooooool0MOooool4oomo01kooooo00?o003oooooooooool0<Oooool00ol0
0?ooooooooooo`1=ooooo`7o00000Oooool00003o`000?oooooooooo07Gooooo1?ooO`0:ooooo`;o
ogl04Oooool00ol00?ooooooooooo`0aooooo`03o`00oooooooooooo04kooooo0Ol00001ooooo`00
00?o0000ooooooooool0M_ooool2oomo00[ooooo1?ooO`0?ooooo`03o`00oooooooooooo01Sooooo
0_ooO`0Gooooo`03o`00oooooooooooo04oooooo0Ol00001ooooo`0000?o0000ooooooooool0P_oo
ool4oomo00oooooo00?o003oooooooooool05oooool4oomo01Cooooo0_l00?mBooooo`7o00000Ooo
ool00003o`000?oooooooooo08?ooooo0_ooO`0?ooooo`03o`00oooooooooooo01;ooooo0_ooO`04
ooooo`Coogl04Oooool3o`00oeCooooo0Ol00001ooooo`0000?o0000ooooooooool0U?ooool00ol0
0?ooooooooooo`0Aooooo`Coogl01?ooool2oomo013ooooo0_l00?mGooooo`7o00000Oooool00003
o`000?oooooooooo09Cooooo00?o003oooooooooool04Oooool4oomo01Gooooo00?o003ooooooooo
ool0Eoooool1o`00007ooooo00000ol0003oooooooooo`2Dooooo`03o`00oooooooooooo01;ooooo
0_ooO`0Dooooo`;o003oF_ooool1o`00007ooooo00000ol0003oooooooooo`2Dooooo`03o`00oooo
oooooooo02Kooooo0_l00?mLooooo`7o00000Oooool00003o`000?oooooooooo09Gooooo00?o003o
ooooooooool09?ooool00ol00?ooooooooooo`1Looooo`7o00000Oooool00003o`000?oooooooooo
09Gooooo00?o003oooooooooool08_ooool2o`00oeoooooo0Ol00001ooooo`0000?o0000oooooooo
ool0UOooool00ol00?ooooooooooo`0Pooooo`;o003oHOooool1o`00007ooooo00000ol0003ooooo
ooooo`24ooooo`;oogl03oooool2o`00oaoooooo0_l00?mSooooo`7o00000Oooool00003o`000?oo
oooooooo08?ooooo1?ooO`0@ooooo`;o003o6_ooool3o`00ofGooooo0Ol00001ooooo`0000?o0000
ooooooooool0Poooool4oomo01;ooooo0_l00?lDooooo`Co003oJ?ooool1o`00007ooooo00000ol0
003oooooooooo`24ooooo`;oogl05Oooool3o`00o`kooooo0ol00?l3ooooo`;oogl0Ioooool1o`00
007ooooo00000ol0003oooooooooo`2Nooooo`?o003o1Oooool6o`00o`Gooooo1?ooO`1Vooooo`7o
00000Oooool00003o`000?oooooooooo0:7ooooo1Ol00?l;ooooo`Coogl0I_ooool1o`00007ooooo
00000ol0003oooooooooo`2booooo`;oogl0Ioooool1o`00007ooooo00000ol0003oooooooooo`3o
oooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003
o`000?oooooooooo07_ooooo0_ooO`2Nooooo`7o00000Oooool00003o`000?oooooooooo07[ooooo
1?ooO`2Mooooo`7o00000Oooool00003o`000?oooooooooo07[ooooo1?ooO`0Pooooo`;oogl0Nooo
ool1o`00007ooooo00000ol0003oooooooooo`1kooooo`;oogl08?ooool4oomo07[ooooo0Ol00001
ooooo`0000?o0000ooooooooool0WOooool4oomo07[ooooo0Ol00001ooooo`0000?o0000oooooooo
ool0T?ooool2oomo00cooooo0_ooO`1kooooo`7o00000Oooool00003o`000?oooooooooo08oooooo
1?ooO`28ooooo`7o00000Oooool00003o`000?oooooooooo08oooooo1?ooO`28ooooo`7o00000Ooo
ool00003o`000?oooooooooo093ooooo0_ooO`0Sooooo`;oogl0I?ooool1o`00007ooooo00000ol0
003oooooooooo`2dooooo`Coogl0Hoooool1o`00007ooooo00000ol0003oooooooooo`2dooooo`Co
ogl0Hoooool1o`00007ooooo00000ol0003oooooooooo`2eooooo`;oogl0I?ooool1o`00007ooooo
00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolL
ooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003o
ooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o0000
0Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3o
oooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003
o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo
0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oooooo
oooo0?oooooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001oooo
o`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo
7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000
ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00
007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0
oooooolLooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo0000
0ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLoooo
o`7o00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003ooooo
ooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Ooo
ool00003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooo
oacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`00
0?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol0
0001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo
0?oooooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`00
00?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?oo
ool1o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000oooo
ooooool0S_ooool2oomo08_ooooo0Ol00001ooooo`0000?o0000ooooooooool0SOooool4oomo08[o
oooo0Ol00001ooooo`0000?o0000ooooooooool0SOooool4oomo08[ooooo0Ol00001ooooo`0000?o
0000ooooooooool0S_ooool2oomo08_ooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolL
ooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003o
ooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o0000
0Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3o
oooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003
o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo
0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oooooo
oooo0?oooooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001oooo
o`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo
7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000
ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00
007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0
oooooolLooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo0000
0ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`00ool0000Po`00007ooooo0000\
\>"],
  ImageRangeCache->{{{0, 287}, {287, 0}} -> {-1.01089, -1.01089, 0.00704453, \
0.00704453}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.49505 0.5 0.49505 [
[ 0 0 -0.125 0 ]
[ 0 0 -0.125 0 ]
[ 0 1 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
0 0 m
1 0 L
s
0 0 m
0 1 L
s
0 1 m
1 1 L
s
1 0 m
1 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
1 .5 0 r
.015 w
.03175 .1355 Mdot
.03435 .12523 Mdot
.11137 .12765 Mdot
.14107 .18841 Mdot
.16218 .24538 Mdot
.17294 .21053 Mdot
.18267 .18577 Mdot
.18434 .1304 Mdot
.18553 .30956 Mdot
.20401 .239 Mdot
.21247 .27571 Mdot
.21687 .20845 Mdot
.22376 .2799 Mdot
.22832 .27485 Mdot
.29063 .20974 Mdot
.29686 .25079 Mdot
.30487 .22936 Mdot
.30683 .34623 Mdot
.32055 .20902 Mdot
.32574 .21979 Mdot
.34472 .28521 Mdot
.35998 .36393 Mdot
.36335 .24976 Mdot
.3794 .36608 Mdot
.42386 .66992 Mdot
.44391 .74519 Mdot
.45059 .34198 Mdot
.47208 .67586 Mdot
.47436 .71381 Mdot
.49778 .59825 Mdot
.50874 .91643 Mdot
.51516 .76219 Mdot
.53655 .61374 Mdot
.56563 .75219 Mdot
.59189 .65665 Mdot
.59581 .61604 Mdot
.59923 .6556 Mdot
.60292 .68499 Mdot
.62656 .67779 Mdot
.63555 .72451 Mdot
.63919 .652 Mdot
.64169 .6004 Mdot
.64246 .58611 Mdot
.64496 .54267 Mdot
.64608 .77288 Mdot
.65077 .64308 Mdot
.66065 .57816 Mdot
.67474 .59169 Mdot
.69296 .563 Mdot
.72815 .65902 Mdot
.73169 .58879 Mdot
.74669 .61318 Mdot
.74821 .65474 Mdot
.75963 .63781 Mdot
.79673 .57809 Mdot
.80925 .55852 Mdot
.81525 .58444 Mdot
.83417 .62985 Mdot
.83598 .55526 Mdot
.91595 .49319 Mdot
1 0 0 r
.005 w
.16128 .17044 m
.18734 .17269 L
.21339 .17909 L
.2345 .18734 L
.23945 .19126 L
.2655 .20415 L
.27874 .21339 L
.29156 .22295 L
.31204 .23945 L
.31761 .24532 L
.33549 .2655 L
.34367 .28341 L
.34499 .29156 L
.34367 .29798 L
.31761 .3104 L
.29156 .30711 L
.2655 .30014 L
.24507 .29156 L
.23945 .28747 L
.21339 .27402 L
.20155 .2655 L
.18734 .25472 L
.16884 .23945 L
.16128 .2313 L
.14618 .21339 L
.13806 .18734 L
.16128 .17044 L
s
0 0 1 r
.65633 .57701 m
.68239 .56842 L
.70844 .56313 L
.7345 .56168 L
.76055 .5752 L
.76359 .57817 L
.76859 .60422 L
.76055 .62333 L
.75627 .63028 L
.7345 .65485 L
.73298 .65633 L
.70844 .6775 L
.69922 .68239 L
.68239 .69294 L
.65633 .70579 L
.64983 .70844 L
.63028 .71539 L
.60422 .72268 L
.57817 .72651 L
.55211 .7214 L
.53145 .70844 L
.52926 .68239 L
.54239 .65633 L
.55211 .63983 L
.56625 .63028 L
.57817 .6193 L
.60119 .60422 L
.60422 .60227 L
.63028 .58726 L
.65315 .57817 L
.65633 .57701 L
s
1 0 0 r
.03 w
.24141 .24033 Mdot
0 0 1 r
.64872 .64417 Mdot
1 0 0 r
.79703 .00495 m
.79703 .25248 L
.87129 .25248 L
.87129 .00495 L
F
0 0 1 r
.89604 .00495 m
.89604 .00495 L
.9703 .00495 L
.9703 .00495 L
F
1 0 1 r
.04 w
.3794 .36608 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P000182000`400?l00000o`00003ooooooolQ
ooooo`00ool0000Po`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`00
00?o0000ooooooooool0hOoooolEool002Gooooo0Ol00001ooooo`0000?o0000ooooooooool0hOoo
oolEool002Gooooo0Ol00001ooooo`0000?o0000ooooooooool0hOoooolEool002Gooooo0Ol00001
ooooo`0000?o0000ooooooooool0hOoooolEool002Gooooo0Ol00001ooooo`0000?o0000oooooooo
ool0hOoooolEool002Gooooo0Ol00001ooooo`0000?o0000ooooooooool0hOoooolEool002Gooooo
0Ol00001ooooo`0000?o0000ooooooooool0hOoooolEool002Gooooo0Ol00001ooooo`0000?o0000
ooooooooool0hOoooolEool002Gooooo0Ol00001ooooo`0000?o0000ooooooooool0hOoooolEool0
02Gooooo0Ol00001ooooo`0000?o0000ooooooooool0hOoooolEool002Gooooo0Ol00001ooooo`00
00?o0000ooooooooool0hOoooolEool002Gooooo0Ol00001ooooo`0000?o0000ooooooooool0hOoo
oolEool002Gooooo0Ol00001ooooo`0000?o0000ooooooooool0hOoooolEool002Gooooo0Ol00001
ooooo`0000?o0000ooooooooool0hOoooolEool002Gooooo0Ol00001ooooo`0000?o0000oooooooo
ool0hOoooolEool002Gooooo0Ol00001ooooo`0000?o0000ooooooooool0hOoooolEool002Gooooo
0Ol00001ooooo`0000?o0000ooooooooool0hOoooolEool002Gooooo0Ol00001ooooo`0000?o0000
ooooooooool0hOoooolEool002Gooooo0Ol00001ooooo`0000?o0000ooooooooool0hOoooolEool0
02Gooooo0Ol00001ooooo`0000?o0000ooooooooool0hOoooolEool002Gooooo0Ol00001ooooo`00
00?o0000ooooooooool0hOoooolEool002Gooooo0Ol00001ooooo`0000?o0000ooooooooool0hOoo
oolEool002Gooooo0Ol00001ooooo`0000?o0000ooooooooool0hOoooolEool002Gooooo0Ol00001
ooooo`0000?o0000ooooooooool0hOoooolEool002Gooooo0Ol00001ooooo`0000?o0000oooooooo
ool0hOoooolEool002Gooooo0Ol00001ooooo`0000?o0000ooooooooool0hOoooolEool002Gooooo
0Ol00001ooooo`0000?o0000ooooooooool0hOoooolEool002Gooooo0Ol00001ooooo`0000?o0000
ooooooooool0hOoooolEool002Gooooo0Ol00001ooooo`0000?o0000ooooooooool0hOoooolEool0
02Gooooo0Ol00001ooooo`0000?o0000ooooooooool0hOoooolEool002Gooooo0Ol00001ooooo`00
00?o0000ooooooooool0hOoooolEool002Gooooo0Ol00001ooooo`0000?o0000ooooooooool0hOoo
oolEool002Gooooo0Ol00001ooooo`0000?o0000ooooooooool01_ooool2oomo0=Wooooo5Ooo000U
ooooo`7o00000Oooool00003o`000?oooooooooo00Gooooo1?ooO`0Cooooo`;oogl0`ooooolEool0
02Gooooo0Ol00001ooooo`0000?o0000ooooooooool01Oooool4oomo01;ooooo1?ooO`0Booooo`;o
ogl0[_oooolEool002Gooooo0Ol00001ooooo`0000?o0000ooooooooool01Oooool3oomo01?ooooo
1?ooO`0Aooooo`Coogl0[OoooolEool002Gooooo0Ol00001ooooo`0000?o0000ooooooooool01?oo
ool4oomo01Cooooo0_ooO`0Booooo`Coogl0[OoooolEool002Gooooo0Ol00001ooooo`0000?o0000
ooooooooool01?ooool4oomo02Wooooo0_ooO`2^oooooaGoo`009Oooool1o`00007ooooo00000ol0
003oooooooooo`05ooooo`;oogl0f_oooolEool002Gooooo0Ol00001ooooo`0000?o0000oooooooo
ool0hOoooolEool002Gooooo0Ol00001ooooo`0000?o0000ooooooooool0hOoooolEool002Gooooo
0Ol00001ooooo`0000?o0000ooooooooool0hOoooolEool002Gooooo0Ol00001ooooo`0000?o0000
ooooooooool0hOoooolEool002Gooooo0Ol00001ooooo`0000?o0000ooooooooool0hOoooolEool0
02Gooooo0Ol00001ooooo`0000?o0000ooooooooool0hOoooolEool002Gooooo0Ol00001ooooo`00
00?o0000ooooooooool0hOoooolEool002Gooooo0Ol00001ooooo`0000?o0000ooooooooool0:_oo
ool6ool00;7ooooo5Ooo000Uooooo`7o00000Oooool00003o`000?oooooooooo02Wooooo00?oo`00
ooooooooool01?ooool5ool00:cooooo5Ooo000Uooooo`7o00000Oooool00003o`000?oooooooooo
02Oooooo0_oo000<ooooo`Coo`00Z?oooolEool002Gooooo0Ol00001ooooo`0000?o0000oooooooo
ool09_ooool00ooo003oooooooooo`0@ooooo`Coo`00Y?oooolEool002Gooooo0Ol00001ooooo`00
00?o0000ooooooooool09?ooool00oooO`3oo`00ooooo`09ooooo`;oogl02oooool3ool00:7ooooo
5Ooo000Uooooo`7o00000Oooool00003o`000?oooooooooo02?ooooo00Coogl0ool00?ooO`3oogl0
2?ooool4oomo00gooooo00?oo`00ooooooooool0W_oooolEool002Gooooo0Ol00001ooooo`0000?o
0000ooooooooool08oooool01?ooO`3oo`00oomo0?ooO`08ooooo`Coogl03_ooool2ool009kooooo
5Ooo000Uooooo`7o00000Oooool00003o`000?oooooooooo02Cooooo00?oogl0ool00?ooool02Ooo
ool2oomo017ooooo0_oo002LoooooaGoo`009Oooool1o`00007ooooo00000ol0003oooooooooo`0U
ooooo`03ool00?oooooooooo01gooooo0_oo002JoooooaGoo`009Oooool1o`00007ooooo00000ol0
003oooooooooo`0Uooooo`03ool00?oooooooooo01oooooo0_oo002HoooooaGoo`009Oooool1o`00
007ooooo00000ol0003oooooooooo`0Vooooo`03ool00?oooooooooo017ooooo0_ooO`0=ooooo`;o
o`001?ooool2oomo00Oooooo0_ooO`27oooooaGoo`009Oooool1o`00007ooooo00000ol0003ooooo
ooooo`0Vooooo`03ool00?oooooooooo00Gooooo0_ooO`09ooooo`Coogl03_ooool00ooo003ooooo
ooooo`04oomo00Gooooo1?ooO`26oooooaGoo`009Oooool1o`00007ooooo00000ol0003ooooooooo
o`0Vooooo`03ool00?oooooooooo00Cooooo1?ooO`08ooooo`Coogl03oooool00ooo003ooooooomo
0003oomo00Gooooo1?ooO`26oooooaGoo`009Oooool1o`00007ooooo00000ol0003oooooooooo`0W
ooooo`03ool00?oooooooooo00?ooooo1?ooO`09ooooo`;oogl04Oooool01?oo003ooooooomo0?oo
O`07ooooo`?oogl0Q_oooolEool002Gooooo0Ol00001ooooo`0000?o0000ooooooooool09oooool0
0ooo003oooooooooo`04ooooo`;oogl07_ooool00ooo003oooooooooo`07ooooo`Coogl0QOoooolE
ool002Gooooo0Ol00001ooooo`0000?o0000ooooooooool0:?ooool00ooo003oooooooooo`0Toooo
o`03ool00?oooooooooo00Kooooo1?ooO`25oooooaGoo`009Oooool1o`00007ooooo00000ol0003o
ooooooooo`0Yooooo`03ool00?oooooooooo02Cooooo0_oo00000oooooooogl0oomo0004ooooo`;o
ogl0Q_oooolEool002Gooooo0Ol00001ooooo`0000?o0000ooooooooool0:_ooool00ooo003ooooo
ooooo`0Cooooo`Coo`003_ooool01?oo003oogl0oomo0?ooO`2;oooooaGoo`009Oooool1o`00007o
oooo00000ol0003oooooooooo`0[ooooo`03ool00?oooooooooo017ooooo1_oo000=ooooo`04oomo
0?oo003oo`00oomo08_ooooo5Ooo000Uooooo`7o00000Oooool00003o`000?oooooooooo02cooooo
00?oo`00ooooooooool02?ooool2oomo00Gooooo2?oo000=ooooo`;oogl000?oo`00ooooooooool0
ROoooolEool002Gooooo0Ol00001ooooo`0000?o0000ooooooooool0;Oooool00ooo003ooooooooo
o`06ooooo`Coogl01?ooool8ool0013ooooo00?oo`00ooooooooool0R?oooolEool002Gooooo0Ol0
0001ooooo`0000?o0000ooooooooool0:oooool2oomo0003oooooooo003ooooo00Kooooo1?ooO`04
ooooo`Soo`004Oooool00ooo003oooooooooo`27oooooaGoo`009Oooool1o`00007ooooo00000ol0
003oooooooooo`0Zooooo`Coogl000?oooooool00?ooool01_ooool2oomo00Gooooo2?oo000;oooo
o`;oogl01Oooool00ooo003oooooooooo`09ooooo`;oogl0NooooolEool002Gooooo0Ol00001oooo
o`0000?o0000ooooooooool0:_ooool4oomo00;ooooo00?oo`00ooooooooool03?ooool6ool000_o
oooo1?ooO`04ooooo`03ool00?oooooooooo00Sooooo1?ooO`1joooooaGoo`009Oooool1o`00007o
oooo00000ol0003oooooooooo`0[ooooo`;oogl01?ooool00ooo003oooooooooo`0<ooooo`Coo`00
3?ooool4oomo00Gooooo00?oo`00ooooooooool01oooool4oomo07[ooooo5Ooo000Uooooo`7o0000
0Oooool00003o`000?oooooooooo03;ooooo0_oo000Mooooo`;oogl01oooool00ooo003ooooooooo
o`07ooooo`;oogl0]Oooool1o`00007ooooo00000ol0003oooooooooo`0dooooo`03ool00?oooooo
oooo02Cooooo00?oo`00ooooooooool0_Oooool1o`00007ooooo00000ol0003oooooooooo`0eoooo
o`03ool00?oooooooooo02Cooooo00?oo`00ooooooooool0_?ooool1o`00007ooooo00000ol0003o
ooooooooo`0fooooo`;oo`009Oooool00ooo003oooooooooo`2kooooo`7o00000Oooool00003o`00
0?oooooooooo03Sooooo0_oo00000oooO`3oooooooooo`02oomo01kooooo00?oo`00ooooooooool0
^oooool1o`00007ooooo00000ol0003oooooooooo`0hooooo`;oogl00_oo0004oomo01kooooo00?o
o`00ooooooooool0^_ooool1o`00007ooooo00000ol0003oooooooooo`0hooooo`Coogl00_oo0002
oomo01kooooo00?oo`00ooooooooool0^_ooool1o`00007ooooo00000ol0003oooooooooo`0ioooo
o`Googl000?oo`00ooooooooool07Oooool00ooo003oogl0oomo002jooooo`7o00000Oooool00003
o`000?oooooooooo03_ooooo1?ooO`02ool001gooooo00Coogl0ool00?ooO`3oogl0^Oooool1o`00
007ooooo00000ol0003oooooooooo`0looooo`;oogl00oooool2ool001_ooooo00Coogl0ool00?oo
O`3oogl0^Oooool1o`00007ooooo00000ol0003oooooooooo`13ooooo`;oo`006_ooool00oooO`3o
o`00ooooo`2iooooo`7o00000Oooool00003o`000?oooooooooo04Gooooo0_oo000Iooooo`03ool0
0?oooooooooo0;Sooooo0Ol00001ooooo`0000?o0000ooooooooool0Aoooool2ool001Gooooo0_oo
002kooooo`7o00000Oooool00003o`000?oooooooooo04Wooooo0ooo000@ooooo`;oo`00_Oooool1
o`00007ooooo00000ol0003oooooooooo`0aooooo`;oogl06Oooool3ool000cooooo00?oo`00oooo
ooooool0_Oooool1o`00007ooooo00000ol0003oooooooooo`0`ooooo`Coogl06oooool6ool000Co
oooo0_oo0030ooooo`7o00000Oooool00003o`000?oooooooooo033ooooo1?ooO`0Qooooo`Coo`00
`_ooool1o`00007ooooo00000ol0003oooooooooo`0aooooo`;oogl0j?ooool1o`00007ooooo0000
0ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLoooo
o`7o00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003ooooo
ooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Ooo
ool00003o`000?oooooooooo07gooooo0_ooO`2Looooo`7o00000Oooool00003o`000?oooooooooo
07cooooo1?ooO`2Kooooo`7o00000Oooool00003o`000?oooooooooo05Cooooo0_ooO`0Vooooo`Co
ogl0Voooool1o`00007ooooo00000ol0003oooooooooo`1Cooooo`Coogl09_ooool2oomo09cooooo
0Ol00001ooooo`0000?o0000ooooooooool0Doooool4oomo013ooooo1Ooo0?n_ooooo`7o00000Ooo
ool00003o`000?oooooooooo05Cooooo0_ooO`0@ooooo`Ooo`3o[_ooool1o`00007ooooo00000ol0
003oooooooooo`1Uooooo`Woo`3o[Oooool1o`00007ooooo00000ol0003oooooooooo`1Sooooo`03
oomo0?oo0?ooo`3o00Woo`3o[?ooool1o`00007ooooo00000ol0003oooooooooo`1Rooooo`;oogl0
2ooo0?n/ooooo`7o00000Oooool00003o`000?oooooooooo06;ooooo0_ooO`0;ool0ojcooooo0Ol0
0001ooooo`0000?o0000ooooooooool0Hoooool00oooO`3oo`3oool0o`09ool0ojcooooo0Ol00001
ooooo`0000?o0000ooooooooool0I?ooool;ool0ojcooooo0Ol00001ooooo`0000?o0000oooooooo
ool0IOooool9ool0ojgooooo0Ol00001ooooo`0000?o0000ooooooooool0I_ooool7ool0ojkooooo
0Ol00001ooooo`0000?o0000ooooooooool0Ioooool5ool0ojoooooo0Ol00001ooooo`0000?o0000
ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00
007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0
oooooolLooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo0000
0ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLoooo
o`7o00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003ooooo
ooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Ooo
ool00003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooo
oacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`00
0?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol0
0001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo
0?oooooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`00
00?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?oo
ool1o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000oooo
ooooool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007o
oooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooo
oolLooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0
003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o
00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003ooooooooo
o`3oooooo`Cooooo0_ooO`0Fooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo0oooool4
oomo01Gooooo0Ol00001ooooo`0000?o0000ooooooooool0ooooool3ooooo`Coogl05Oooool1o`00
007ooooo00000ol0003oooooooooo`3oooooo`Cooooo0_ooO`0Fooooo`7o00000Oooool00003o`00
0?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol0
0001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo
0?oooooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`00
00?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?oo
ool1o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000oooo
ooooool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007o
oooo00000ol0003oooooooooo`2eooooo`;oogl0I?ooool1o`00007ooooo00000ol0003ooooooooo
o`2dooooo`Coogl0Hoooool1o`00007ooooo00000ol0003oooooooooo`2dooooo`Coogl0Hoooool1
o`00007ooooo00000ol0003oooooooooo`2eooooo`;oogl0=Oooool2oomo02gooooo0Ol00001oooo
o`0000?o0000ooooooooool0i?ooool2oomo00Gooooo1?ooO`0/ooooo`7o00000Oooool00003o`00
0?oooooooooo0>?ooooo1?ooO`04ooooo`Coogl0;?ooool1o`00007ooooo00000ol0003ooooooooo
o`33ooooo`;oogl07_ooool4oomo00Gooooo0_ooO`0]ooooo`7o00000Oooool00003o`000?oooooo
oooo0<;ooooo1?ooO`0;o`00oa?ooooo0_ooO`0eooooo`7o00000Oooool00003o`000?oooooooooo
0<;ooooo1?l00?l;ooooo`;o003oB?ooool1o`00007ooooo00000ol0003oooooooooo`2nooooo`Co
003o00?ooooooomo0?ooO`003_ooool2o`00odKooooo0Ol00001ooooo`0000?o0000ooooooooool0
^Oooool2oomo00?o003o5oooool2o`00o`Wooooo0_ooO`0iooooo`7o00000Oooool00003o`000?oo
oooooooo0;Oooooo1?l00?l00oooO`3oooooooooo`0Iooooo`;o003o1_ooool4oomo03Sooooo0Ol0
0001ooooo`0000?o0000ooooooooool0]?ooool3o`00o`03ooooooooO`3oogl000;oogl07?ooool0
0ol00?ooooooooooo`04ooooo`Coogl00oooool2oomo03?ooooo0Ol00001ooooo`0000?o0000oooo
ooooool0/_ooool2o`00o`?oogl00_ooool2oomo01?ooooo0_ooO`08ooooo`03o`00oooooooooooo
00Gooooo0_ooO`03ooooo`Coogl0<_ooool1o`00007ooooo00000ol0003oooooooooo`2`ooooo`;o
003o00?ooooooomo0?ooO`000_ooO`06ooooo`;oogl03_ooool4oomo00Oooooo00?o003ooooooooo
ool02_ooool4oomo03;ooooo0Ol00001ooooo`0000?o0000ooooooooool0[_ooool2o`00o`Cooooo
0_ooO`06ooooo`Coogl03Oooool4oomo00Oooooo00?o003oooooooooool02oooool2oomo03?ooooo
0Ol00001ooooo`0000?o0000ooooooooool0Roooool2oomo023ooooo00?o003oooooooooool01?oo
ool2oomo00Kooooo1?ooO`0>ooooo`;oogl02Oooool00ol00?ooooooooooo`0oooooo`7o00000Ooo
ool00003o`000?oooooooooo08[ooooo1?ooO`0Mooooo`;o003o1_ooool4oomo00Kooooo0_ooO`0J
ooooo`03o`00oooooooooooo03oooooo0Ol00001ooooo`0000?o0000ooooooooool0R_ooool4oomo
01cooooo00?o003oooooooooool01_ooool4oomo02;ooooo00?o003oooooooooool0?oooool1o`00
007ooooo00000ol0003oooooooooo`2;ooooo`;oogl06oooool2o`00o`[ooooo0_ooO`0Sooooo`03
o`00oooooooooooo03oooooo0Ol00001ooooo`0000?o0000ooooooooool0U_ooool2oomo00kooooo
0_l00?lZooooo`;oogl01Oooool00ol00?ooooooooooo`0oooooo`7o00000Oooool00003o`000?oo
oooooooo09Gooooo1?ooO`0<ooooo`04o`00ooooooooogl0oomo02Sooooo1?ooO`03ooooo`03o`00
oooooooooooo043ooooo0Ol00001ooooo`0000?o0000ooooooooool0UOooool4oomo00[ooooo0_l0
0?l00oooooooogl0oomo0002oomo02Oooooo1?ooO`03ooooo`03o`00oooooooooooo043ooooo0Ol0
0001ooooo`0000?o0000ooooooooool0U_ooool2oomo00[ooooo00Co003ooooooooooooooooo1?oo
O`0Xooooo`;oogl01?ooool00ol00?ooooooooooo`10ooooo`7o00000Oooool00003o`000?oooooo
oooo0:7ooooo00?o003oooooooooool00oooool2oomo02kooooo00?o003oooooooooool0@Oooool1
o`00007ooooo00000ol0003oooooooooo`2Pooooo`03o`00oooooooooooo03?ooooo00?o003ooooo
ooooool04_ooool2oomo02kooooo0Ol00001ooooo`0000?o0000ooooooooool0W_ooool2o`00ocGo
oooo00?o003oooooooooool04_ooool4oomo02gooooo0Ol00001ooooo`0000?o0000ooooooooool0
WOooool00ol00?ooooooooooo`0Eooooo`Co003o7?ooool00ol00?ooogl0oomo000Booooo`Coogl0
;Oooool1o`00007ooooo00000ol0003oooooooooo`2Looooo`03o`00oooooooooooo01Gooooo1_l0
0?lJooooo`03o`00ooooO`3oogl000;oogl04_ooool2oomo02kooooo0Ol00001ooooo`0000?o0000
ooooooooool0Voooool00ol00?ooooooooooo`0Eooooo`So003o6?ooool00ol00?oooooooomo0003
oomo04;ooooo0Ol00001ooooo`0000?o0000ooooooooool0Voooool00ol00?ooooooooooo`0Eoooo
o`So003o5oooool01?l00?ooooooooooooooool2oomo04?ooooo0Ol00001ooooo`0000?o0000oooo
ooooool0V_ooool00ol00?ooooooooooo`0Fooooo`So003o5_ooool00ol00?ooooooooooo`17oooo
o`7o00000Oooool00003o`000?oooooooooo09Wooooo00?o003oooooooooool03?ooool2oomo00So
oooo00?oogl0o`00ool00?l01_l00?lEooooo`03o`00oooooooooooo00;oogl0A_ooool1o`00007o
oooo00000ol0003oooooooooo`2Iooooo`03o`00oooooooooooo00[ooooo1OooO`07ooooo`;oogl0
1_l00?lCooooo`;oogl000?o003oooooooooool01?ooO`15ooooo`7o00000Oooool00003o`000?oo
oooooooo09Sooooo00?o003oooooooooool02_ooool6oomo00Sooooo0_ooO`04o`00oa?ooooo0_oo
O`02o`00o`;ooooo1?ooO`15ooooo`7o00000Oooool00003o`000?oooooooooo09Sooooo00?o003o
ooooooooool02_ooool5oomo02;ooooo00Coogl0o`00ooooO`3oogl00oooool2oomo04Kooooo0Ol0
0001ooooo`0000?o0000ooooooooool0M_ooool2oomo01oooooo00?o003oooooooooool03?ooool2
oomo02Cooooo00?o003ooomo0?ooO`00C?ooool1o`00007ooooo00000ol0003oooooooooo`1eoooo
o`Coogl07_ooool00ol00?ooooooooooo`0aooooo`03o`00oooooooooooo04gooooo0Ol00001oooo
o`0000?o0000ooooooooool0MOooool4oomo00[ooooo0_ooO`0Aooooo`03o`00oooooooooooo037o
oooo00?o003oooooooooool0C_ooool1o`00007ooooo00000ol0003oooooooooo`1fooooo`;oogl0
2_ooool4oomo00oooooo00?o003oooooooooool06?ooool2oomo01Oooooo00?o003oooooooooool0
Coooool1o`00007ooooo00000ol0003oooooooooo`22ooooo`Coogl03oooool00ol00?oooooooooo
o`0Gooooo`Coogl05?ooool2o`00oe;ooooo0Ol00001ooooo`0000?o0000ooooooooool0Poooool2
oomo00oooooo00?o003oooooooooool04_ooool2oomo00Cooooo1?ooO`0Aooooo`?o003oE?ooool1
o`00007ooooo00000ol0003oooooooooo`2Dooooo`03o`00oooooooooooo017ooooo1?ooO`04oooo
o`;oogl04?ooool2o`00oeOooooo0Ol00001ooooo`0000?o0000ooooooooool0U?ooool00ol00?oo
ooooooooo`0Aooooo`Coogl05Oooool00ol00?ooooooooooo`1Gooooo`7o00000Oooool00003o`00
0?oooooooooo09Cooooo00?o003oooooooooool04_ooool2oomo01Cooooo0_l00?mJooooo`7o0000
0Oooool00003o`000?oooooooooo09Cooooo00?o003oooooooooool09_ooool2o`00oecooooo0Ol0
0001ooooo`0000?o0000ooooooooool0UOooool00ol00?ooooooooooo`0Tooooo`03o`00oooooooo
oooo05cooooo0Ol00001ooooo`0000?o0000ooooooooool0UOooool00ol00?ooooooooooo`0Roooo
o`;o003oGoooool1o`00007ooooo00000ol0003oooooooooo`2Eooooo`03o`00oooooooooooo023o
oooo0_l00?mQooooo`7o00000Oooool00003o`000?oooooooooo08Cooooo0_ooO`0?ooooo`;o003o
7oooool2o`00of?ooooo0Ol00001ooooo`0000?o0000ooooooooool0Poooool4oomo013ooooo0_l0
0?lJooooo`?o003oIOooool1o`00007ooooo00000ol0003oooooooooo`23ooooo`Coogl04_ooool2
o`00oaCooooo1?l00?mXooooo`7o00000Oooool00003o`000?oooooooooo08Cooooo0_ooO`0Eoooo
o`?o003o3_ooool3o`00o`?ooooo0_ooO`1Wooooo`7o00000Oooool00003o`000?oooooooooo09ko
oooo0ol00?l5ooooo`Ko003o1Oooool4oomo06Kooooo0Ol00001ooooo`0000?o0000ooooooooool0
XOooool5o`00o`_ooooo1?ooO`1Vooooo`7o00000Oooool00003o`000?oooooooooo0;;ooooo0_oo
O`1Wooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0
003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0Noooool2oomo09ko
oooo0Ol00001ooooo`0000?o0000ooooooooool0N_ooool4oomo09gooooo0Ol00001ooooo`0000?o
0000ooooooooool0N_ooool4oomo023ooooo0_ooO`1kooooo`7o00000Oooool00003o`000?oooooo
oooo07_ooooo0_ooO`0Pooooo`Coogl0N_ooool1o`00007ooooo00000ol0003oooooooooo`2Moooo
o`Coogl0N_ooool1o`00007ooooo00000ol0003oooooooooo`2@ooooo`;oogl03?ooool2oomo07_o
oooo0Ol00001ooooo`0000?o0000ooooooooool0Soooool4oomo08Sooooo0Ol00001ooooo`0000?o
0000ooooooooool0Soooool4oomo08Sooooo0Ol00001ooooo`0000?o0000ooooooooool0T?ooool2
oomo02?ooooo0_ooO`1Tooooo`7o00000Oooool00003o`000?oooooooooo0;Cooooo1?ooO`1Soooo
o`7o00000Oooool00003o`000?oooooooooo0;Cooooo1?ooO`1Sooooo`7o00000Oooool00003o`00
0?oooooooooo0;Gooooo0_ooO`1Tooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?oo
ool1o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000oooo
ooooool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007o
oooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooo
oolLooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0
003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o
00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003ooooooooo
o`3ooooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool0
0003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooooaco
oooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oo
oooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001
ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo0?oo
oooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o
0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1
o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000oooooooo
ool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo
00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolL
ooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003o
ooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o0000
0Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3o
oooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003
o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo
0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oooooo
oooo0?oooooo7?ooool1o`00007ooooo00000ol0003oooooooooo`2>ooooo`;oogl0Roooool1o`00
007ooooo00000ol0003oooooooooo`2=ooooo`Coogl0R_ooool1o`00007ooooo00000ol0003ooooo
ooooo`2=ooooo`Coogl0R_ooool1o`00007ooooo00000ol0003oooooooooo`2>ooooo`;oogl0Rooo
ool1o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000oooo
ooooool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007o
oooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooo
oolLooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0
003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o
00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003ooooooooo
o`3ooooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool0
0003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooooaco
oooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oo
oooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001
ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo0?oo
oooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o
0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1
o`00007ooooo003oo`00023o00000Oooool00001\
\>"],
  ImageRangeCache->{{{0, 287}, {287, 0}} -> {-1.01089, -1.01089, 0.00704453, \
0.00704453}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.49505 0.5 0.49505 [
[ 0 0 -0.125 0 ]
[ 0 0 -0.125 0 ]
[ 0 1 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
0 0 m
1 0 L
s
0 0 m
0 1 L
s
0 1 m
1 1 L
s
1 0 m
1 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
1 .5 0 r
.015 w
.03175 .1355 Mdot
.03435 .12523 Mdot
.11137 .12765 Mdot
.14107 .18841 Mdot
.16218 .24538 Mdot
.17294 .21053 Mdot
.18267 .18577 Mdot
.18434 .1304 Mdot
.18553 .30956 Mdot
.20401 .239 Mdot
.21247 .27571 Mdot
.21687 .20845 Mdot
.22376 .2799 Mdot
.22832 .27485 Mdot
.29063 .20974 Mdot
.29686 .25079 Mdot
.30487 .22936 Mdot
.30683 .34623 Mdot
.32055 .20902 Mdot
.32574 .21979 Mdot
.34472 .28521 Mdot
.35998 .36393 Mdot
.36335 .24976 Mdot
.3794 .36608 Mdot
.42386 .66992 Mdot
.44391 .74519 Mdot
.45059 .34198 Mdot
.47208 .67586 Mdot
.47436 .71381 Mdot
.49778 .59825 Mdot
.50874 .91643 Mdot
.51516 .76219 Mdot
.53655 .61374 Mdot
.56563 .75219 Mdot
.59189 .65665 Mdot
.59581 .61604 Mdot
.59923 .6556 Mdot
.60292 .68499 Mdot
.62656 .67779 Mdot
.63555 .72451 Mdot
.63919 .652 Mdot
.64169 .6004 Mdot
.64246 .58611 Mdot
.64496 .54267 Mdot
.64608 .77288 Mdot
.65077 .64308 Mdot
.66065 .57816 Mdot
.67474 .59169 Mdot
.69296 .563 Mdot
.72815 .65902 Mdot
.73169 .58879 Mdot
.74669 .61318 Mdot
.74821 .65474 Mdot
.75963 .63781 Mdot
.79673 .57809 Mdot
.80925 .55852 Mdot
.81525 .58444 Mdot
.83417 .62985 Mdot
.83598 .55526 Mdot
.91595 .49319 Mdot
1 0 0 r
.005 w
.16128 .17044 m
.18734 .17269 L
.21339 .17909 L
.2345 .18734 L
.23945 .19126 L
.2655 .20415 L
.27874 .21339 L
.29156 .22295 L
.31204 .23945 L
.31761 .24532 L
.33549 .2655 L
.34367 .28341 L
.34499 .29156 L
.34367 .29798 L
.31761 .3104 L
.29156 .30711 L
.2655 .30014 L
.24507 .29156 L
.23945 .28747 L
.21339 .27402 L
.20155 .2655 L
.18734 .25472 L
.16884 .23945 L
.16128 .2313 L
.14618 .21339 L
.13806 .18734 L
.16128 .17044 L
s
0 0 1 r
.65633 .57701 m
.68239 .56842 L
.70844 .56313 L
.7345 .56168 L
.76055 .5752 L
.76359 .57817 L
.76859 .60422 L
.76055 .62333 L
.75627 .63028 L
.7345 .65485 L
.73298 .65633 L
.70844 .6775 L
.69922 .68239 L
.68239 .69294 L
.65633 .70579 L
.64983 .70844 L
.63028 .71539 L
.60422 .72268 L
.57817 .72651 L
.55211 .7214 L
.53145 .70844 L
.52926 .68239 L
.54239 .65633 L
.55211 .63983 L
.56625 .63028 L
.57817 .6193 L
.60119 .60422 L
.60422 .60227 L
.63028 .58726 L
.65315 .57817 L
.65633 .57701 L
s
1 0 0 r
.03 w
.24141 .24033 Mdot
0 0 1 r
.64872 .64417 Mdot
1 0 0 r
.79703 .00495 m
.79703 .00495 L
.87129 .00495 L
.87129 .00495 L
F
0 0 1 r
.89604 .00495 m
.89604 .25248 L
.9703 .25248 L
.9703 .00495 L
F
1 0 1 r
.04 w
.42386 .66992 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P000182000`400?l00000o`00003ooooooolQ
ooooo`00ool0000Po`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`00
00?o0000ooooooooool0o_oooolEo`00o`Sooooo0Ol00001ooooo`0000?o0000ooooooooool0o_oo
oolEo`00o`Sooooo0Ol00001ooooo`0000?o0000ooooooooool0o_oooolEo`00o`Sooooo0Ol00001
ooooo`0000?o0000ooooooooool0o_oooolEo`00o`Sooooo0Ol00001ooooo`0000?o0000oooooooo
ool0o_oooolEo`00o`Sooooo0Ol00001ooooo`0000?o0000ooooooooool0o_oooolEo`00o`Sooooo
0Ol00001ooooo`0000?o0000ooooooooool0o_oooolEo`00o`Sooooo0Ol00001ooooo`0000?o0000
ooooooooool0o_oooolEo`00o`Sooooo0Ol00001ooooo`0000?o0000ooooooooool0o_oooolEo`00
o`Sooooo0Ol00001ooooo`0000?o0000ooooooooool0o_oooolEo`00o`Sooooo0Ol00001ooooo`00
00?o0000ooooooooool0o_oooolEo`00o`Sooooo0Ol00001ooooo`0000?o0000ooooooooool0o_oo
oolEo`00o`Sooooo0Ol00001ooooo`0000?o0000ooooooooool0o_oooolEo`00o`Sooooo0Ol00001
ooooo`0000?o0000ooooooooool0o_oooolEo`00o`Sooooo0Ol00001ooooo`0000?o0000oooooooo
ool0o_oooolEo`00o`Sooooo0Ol00001ooooo`0000?o0000ooooooooool0o_oooolEo`00o`Sooooo
0Ol00001ooooo`0000?o0000ooooooooool0o_oooolEo`00o`Sooooo0Ol00001ooooo`0000?o0000
ooooooooool0o_oooolEo`00o`Sooooo0Ol00001ooooo`0000?o0000ooooooooool0o_oooolEo`00
o`Sooooo0Ol00001ooooo`0000?o0000ooooooooool0o_oooolEo`00o`Sooooo0Ol00001ooooo`00
00?o0000ooooooooool0o_oooolEo`00o`Sooooo0Ol00001ooooo`0000?o0000ooooooooool0o_oo
oolEo`00o`Sooooo0Ol00001ooooo`0000?o0000ooooooooool0o_oooolEo`00o`Sooooo0Ol00001
ooooo`0000?o0000ooooooooool0o_oooolEo`00o`Sooooo0Ol00001ooooo`0000?o0000oooooooo
ool0o_oooolEo`00o`Sooooo0Ol00001ooooo`0000?o0000ooooooooool0o_oooolEo`00o`Sooooo
0Ol00001ooooo`0000?o0000ooooooooool0o_oooolEo`00o`Sooooo0Ol00001ooooo`0000?o0000
ooooooooool0o_oooolEo`00o`Sooooo0Ol00001ooooo`0000?o0000ooooooooool0o_oooolEo`00
o`Sooooo0Ol00001ooooo`0000?o0000ooooooooool0o_oooolEo`00o`Sooooo0Ol00001ooooo`00
00?o0000ooooooooool0o_oooolEo`00o`Sooooo0Ol00001ooooo`0000?o0000ooooooooool0o_oo
oolEo`00o`Sooooo0Ol00001ooooo`0000?o0000ooooooooool01_ooool2oomo0?Kooooo5Ol00?l8
ooooo`7o00000Oooool00003o`000?oooooooooo00Gooooo1?ooO`0Cooooo`;oogl0h?oooolEo`00
o`Sooooo0Ol00001ooooo`0000?o0000ooooooooool01Oooool4oomo01;ooooo1?ooO`0Booooo`;o
ogl0booooolEo`00o`Sooooo0Ol00001ooooo`0000?o0000ooooooooool01Oooool3oomo01?ooooo
1?ooO`0Aooooo`Coogl0b_oooolEo`00o`Sooooo0Ol00001ooooo`0000?o0000ooooooooool01?oo
ool4oomo01Cooooo0_ooO`0Booooo`Coogl0b_oooolEo`00o`Sooooo0Ol00001ooooo`0000?o0000
ooooooooool01?ooool4oomo02Wooooo0_ooO`3;oooooaGo003o2?ooool1o`00007ooooo00000ol0
003oooooooooo`05ooooo`;oogl0mooooolEo`00o`Sooooo0Ol00001ooooo`0000?o0000oooooooo
ool0o_oooolEo`00o`Sooooo0Ol00001ooooo`0000?o0000ooooooooool0o_oooolEo`00o`Sooooo
0Ol00001ooooo`0000?o0000ooooooooool0o_oooolEo`00o`Sooooo0Ol00001ooooo`0000?o0000
ooooooooool0o_oooolEo`00o`Sooooo0Ol00001ooooo`0000?o0000ooooooooool0o_oooolEo`00
o`Sooooo0Ol00001ooooo`0000?o0000ooooooooool0o_oooolEo`00o`Sooooo0Ol00001ooooo`00
00?o0000ooooooooool0o_oooolEo`00o`Sooooo0Ol00001ooooo`0000?o0000ooooooooool0:_oo
ool6ool00<kooooo5Ol00?l8ooooo`7o00000Oooool00003o`000?oooooooooo02Wooooo00?oo`00
ooooooooool01?ooool5ool00<Wooooo5Ol00?l8ooooo`7o00000Oooool00003o`000?oooooooooo
02Oooooo0_oo000<ooooo`Coo`00aOoooolEo`00o`Sooooo0Ol00001ooooo`0000?o0000oooooooo
ool09_ooool00ooo003oooooooooo`0@ooooo`Coo`00`OoooolEo`00o`Sooooo0Ol00001ooooo`00
00?o0000ooooooooool09?ooool00oooO`3oo`00ooooo`09ooooo`;oogl02oooool3ool00;kooooo
5Ol00?l8ooooo`7o00000Oooool00003o`000?oooooooooo02?ooooo00Coogl0ool00?ooO`3oogl0
2?ooool4oomo00gooooo00?oo`00ooooooooool0^ooooolEo`00o`Sooooo0Ol00001ooooo`0000?o
0000ooooooooool08oooool01?ooO`3oo`00oomo0?ooO`08ooooo`Coogl03_ooool2ool00;_ooooo
5Ol00?l8ooooo`7o00000Oooool00003o`000?oooooooooo02Cooooo00?oogl0ool00?ooool02Ooo
ool2oomo017ooooo0_oo002ioooooaGo003o2?ooool1o`00007ooooo00000ol0003oooooooooo`0U
ooooo`03ool00?oooooooooo01gooooo0_oo002goooooaGo003o2?ooool1o`00007ooooo00000ol0
003oooooooooo`0Uooooo`03ool00?oooooooooo01oooooo0_oo002eoooooaGo003o2?ooool1o`00
007ooooo00000ol0003oooooooooo`0Vooooo`03ool00?oooooooooo017ooooo0_ooO`0=ooooo`;o
o`001?ooool2oomo00Oooooo0_ooO`2ToooooaGo003o2?ooool1o`00007ooooo00000ol0003ooooo
ooooo`0Vooooo`03ool00?oooooooooo00Gooooo0_ooO`09ooooo`Coogl03_ooool00ooo003ooooo
ooooo`04oomo00Gooooo1?ooO`2SoooooaGo003o2?ooool1o`00007ooooo00000ol0003ooooooooo
o`0Vooooo`03ool00?oooooooooo00Cooooo1?ooO`08ooooo`Coogl03oooool00ooo003ooooooomo
0003oomo00Gooooo1?ooO`2SoooooaGo003o2?ooool1o`00007ooooo00000ol0003oooooooooo`0W
ooooo`03ool00?oooooooooo00?ooooo1?ooO`09ooooo`;oogl04Oooool01?oo003ooooooomo0?oo
O`07ooooo`?oogl0XooooolEo`00o`Sooooo0Ol00001ooooo`0000?o0000ooooooooool09oooool0
0ooo003oooooooooo`04ooooo`;oogl07_ooool00ooo003oooooooooo`07ooooo`Coogl0X_oooolE
o`00o`Sooooo0Ol00001ooooo`0000?o0000ooooooooool0:?ooool00ooo003oooooooooo`0Toooo
o`03ool00?oooooooooo00Kooooo1?ooO`2RoooooaGo003o2?ooool1o`00007ooooo00000ol0003o
ooooooooo`0Yooooo`03ool00?oooooooooo02Cooooo0_oo00000oooooooogl0oomo0004ooooo`;o
ogl0XooooolEo`00o`Sooooo0Ol00001ooooo`0000?o0000ooooooooool0:_ooool00ooo003ooooo
ooooo`0Cooooo`Coo`003_ooool01?oo003oogl0oomo0?ooO`2XoooooaGo003o2?ooool1o`00007o
oooo00000ol0003oooooooooo`0[ooooo`03ool00?oooooooooo017ooooo1_oo000=ooooo`04oomo
0?oo003oo`00oomo0:Sooooo5Ol00?l8ooooo`7o00000Oooool00003o`000?oooooooooo02cooooo
00?oo`00ooooooooool02?ooool2oomo00Gooooo2?oo000=ooooo`;oogl000?oo`00ooooooooool0
Y_oooolEo`00o`Sooooo0Ol00001ooooo`0000?o0000ooooooooool0;Oooool00ooo003ooooooooo
o`06ooooo`Coogl01?ooool8ool0013ooooo00?oo`00ooooooooool0YOoooolEo`00o`Sooooo0Ol0
0001ooooo`0000?o0000ooooooooool0:oooool2oomo0003oooooooo003ooooo00Kooooo1?ooO`04
ooooo`Soo`004Oooool00ooo003oooooooooo`2ToooooaGo003o2?ooool1o`00007ooooo00000ol0
003oooooooooo`0Zooooo`Coogl000?oooooool00?ooool01_ooool2oomo00Gooooo2?oo000;oooo
o`;oogl01Oooool00ooo003oooooooooo`09ooooo`;oogl0V?oooolEo`00o`Sooooo0Ol00001oooo
o`0000?o0000ooooooooool0:_ooool4oomo00;ooooo00?oo`00ooooooooool03?ooool6ool000_o
oooo1?ooO`04ooooo`03ool00?oooooooooo00Sooooo1?ooO`2GoooooaGo003o2?ooool1o`00007o
oooo00000ol0003oooooooooo`0[ooooo`;oogl01?ooool00ooo003oooooooooo`0<ooooo`Coo`00
3?ooool4oomo00Gooooo00?oo`00ooooooooool01oooool4oomo09Oooooo5Ol00?l8ooooo`7o0000
0Oooool00003o`000?oooooooooo03;ooooo0_oo000Mooooo`;oogl01oooool00ooo003ooooooooo
o`07ooooo`;oogl0]Oooool1o`00007ooooo00000ol0003oooooooooo`0dooooo`03ool00?oooooo
oooo02Cooooo00?oo`00ooooooooool0_Oooool1o`00007ooooo00000ol0003oooooooooo`0eoooo
o`03ool00?oooooooooo02Cooooo00?oo`00ooooooooool0_?ooool1o`00007ooooo00000ol0003o
ooooooooo`0fooooo`;oo`009Oooool00ooo003oooooooooo`2kooooo`7o00000Oooool00003o`00
0?oooooooooo03Sooooo0_oo00000oooO`3oooooooooo`02oomo01kooooo00?oo`00ooooooooool0
^oooool1o`00007ooooo00000ol0003oooooooooo`0hooooo`;oogl00_oo0004oomo01kooooo00?o
o`00ooooooooool0^_ooool1o`00007ooooo00000ol0003oooooooooo`0hooooo`Coogl00_oo0002
oomo01kooooo00?oo`00ooooooooool0^_ooool1o`00007ooooo00000ol0003oooooooooo`0ioooo
o`Googl000?oo`00ooooooooool07Oooool00ooo003oogl0oomo002jooooo`7o00000Oooool00003
o`000?oooooooooo03_ooooo1?ooO`02ool001gooooo00Coogl0ool00?ooO`3oogl0^Oooool1o`00
007ooooo00000ol0003oooooooooo`0looooo`;oogl00oooool2ool001_ooooo00Coogl0ool00?oo
O`3oogl0^Oooool1o`00007ooooo00000ol0003oooooooooo`13ooooo`;oo`006_ooool00oooO`3o
o`00ooooo`2iooooo`7o00000Oooool00003o`000?oooooooooo04Gooooo0_oo000Iooooo`03ool0
0?oooooooooo0;Sooooo0Ol00001ooooo`0000?o0000ooooooooool0Aoooool2ool001Gooooo0_oo
002kooooo`7o00000Oooool00003o`000?oooooooooo04Wooooo0ooo000@ooooo`;oo`00_Oooool1
o`00007ooooo00000ol0003oooooooooo`0aooooo`;oogl06Oooool3ool000cooooo00?oo`00oooo
ooooool0_Oooool1o`00007ooooo00000ol0003oooooooooo`0`ooooo`Coogl06oooool6ool000Co
oooo0_oo0030ooooo`7o00000Oooool00003o`000?oooooooooo033ooooo1?ooO`0Qooooo`Coo`00
`_ooool1o`00007ooooo00000ol0003oooooooooo`0aooooo`;oogl0j?ooool1o`00007ooooo0000
0ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLoooo
o`7o00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003ooooo
ooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Ooo
ool00003o`000?oooooooooo07gooooo0_ooO`2Looooo`7o00000Oooool00003o`000?oooooooooo
07cooooo1?ooO`2Kooooo`7o00000Oooool00003o`000?oooooooooo05Cooooo0_ooO`0Vooooo`Co
ogl0Voooool1o`00007ooooo00000ol0003oooooooooo`1Cooooo`Coogl09_ooool2oomo09cooooo
0Ol00001ooooo`0000?o0000ooooooooool0Doooool4oomo0<Cooooo0Ol00001ooooo`0000?o0000
ooooooooool0E?ooool2oomo0<Gooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLoooo
o`7o00000Oooool00003o`000?oooooooooo06?ooooo0_ooO`04ooooo`;oogl0/?ooool1o`00007o
oooo00000ol0003oooooooooo`1Rooooo`Coogl00_ooool4oomo0:oooooo0Ol00001ooooo`0000?o
0000ooooooooool0H_ooool4oomo00;ooooo1?ooO`2_ooooo`7o00000Oooool00003o`000?oooooo
oooo06?ooooo0_ooO`04ooooo`;oogl0/?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooo
oacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`00
0?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol0
0001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo
0?oooooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`00
00?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?oo
ool1o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000oooo
ooooool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007o
oooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooo
oolLooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0
003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o
00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003ooooooooo
o`3ooooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool0
0003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooooaco
oooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oo
oooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001
ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo0?oo
oooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o
0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1
o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000oooooooo
ool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo
00000ol0003oooooooooo`3oooooo`Cooooo0_ooO`0Fooooo`7o00000Oooool00003o`000?oooooo
oooo0?oooooo0oooool4oomo01Gooooo0Ol00001ooooo`0000?o0000ooooooooool0ooooool3oooo
o`Coogl05Oooool1o`00007ooooo00000ol0003oooooooooo`3oooooo`Cooooo0_ooO`0Fooooo`7o
00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003ooooooooo
o`3ooooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool0
0003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooooaco
oooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oo
oooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001
ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo0?oo
oooo7?ooool1o`00007ooooo00000ol0003oooooooooo`2eooooo`;oogl0I?ooool1o`00007ooooo
00000ol0003oooooooooo`2dooooo`Coogl0Hoooool1o`00007ooooo00000ol0003oooooooooo`2d
ooooo`Coogl0Hoooool1o`00007ooooo00000ol0003oooooooooo`2eooooo`;oogl0=Oooool2oomo
02gooooo0Ol00001ooooo`0000?o0000ooooooooool0i?ooool2oomo00Gooooo1?ooO`0/ooooo`7o
00000Oooool00003o`000?oooooooooo0>?ooooo1?ooO`04ooooo`Coogl0;?ooool1o`00007ooooo
00000ol0003oooooooooo`33ooooo`;oogl07_ooool4oomo00Gooooo0_ooO`0]ooooo`7o00000Ooo
ool00003o`000?oooooooooo0<;ooooo1?ooO`0;o`00oa?ooooo0_ooO`0eooooo`7o00000Oooool0
0003o`000?oooooooooo0<;ooooo1?l00?l;ooooo`;o003oB?ooool1o`00007ooooo00000ol0003o
ooooooooo`2nooooo`Co003o00?ooooooomo0?ooO`003_ooool2o`00odKooooo0Ol00001ooooo`00
00?o0000ooooooooool0^Oooool2oomo00?o003o5oooool2o`00o`Wooooo0_ooO`0iooooo`7o0000
0Oooool00003o`000?oooooooooo0;Oooooo1?l00?l00oooO`3oooooooooo`0Iooooo`;o003o1_oo
ool4oomo03Sooooo0Ol00001ooooo`0000?o0000ooooooooool0]?ooool3o`00o`03ooooooooO`3o
ogl000;oogl07?ooool00ol00?ooooooooooo`04ooooo`Coogl00oooool2oomo03?ooooo0Ol00001
ooooo`0000?o0000ooooooooool0/_ooool2o`00o`?oogl00_ooool2oomo01?ooooo0_ooO`08oooo
o`03o`00oooooooooooo00Gooooo0_ooO`03ooooo`Coogl0<_ooool1o`00007ooooo00000ol0003o
ooooooooo`2`ooooo`;o003o00?ooooooomo0?ooO`000_ooO`06ooooo`;oogl03_ooool4oomo00Oo
oooo00?o003oooooooooool02_ooool4oomo03;ooooo0Ol00001ooooo`0000?o0000ooooooooool0
[_ooool2o`00o`Cooooo0_ooO`06ooooo`Coogl03Oooool4oomo00Oooooo00?o003oooooooooool0
2oooool2oomo03?ooooo0Ol00001ooooo`0000?o0000ooooooooool0Roooool2oomo023ooooo00?o
003oooooooooool01?ooool2oomo00Kooooo1?ooO`0>ooooo`;oogl02Oooool00ol00?oooooooooo
o`0oooooo`7o00000Oooool00003o`000?oooooooooo08[ooooo1?ooO`0Mooooo`;o003o1_ooool4
oomo00Kooooo0_ooO`0Jooooo`03o`00oooooooooooo03oooooo0Ol00001ooooo`0000?o0000oooo
ooooool0R_ooool4oomo01cooooo00?o003oooooooooool01_ooool4oomo02;ooooo00?o003ooooo
ooooool0?oooool1o`00007ooooo00000ol0003oooooooooo`2;ooooo`;oogl06oooool2o`00o`[o
oooo0_ooO`0Sooooo`03o`00oooooooooooo03oooooo0Ol00001ooooo`0000?o0000ooooooooool0
U_ooool2oomo00kooooo0_l00?lZooooo`;oogl01Oooool00ol00?ooooooooooo`0oooooo`7o0000
0Oooool00003o`000?oooooooooo09Gooooo1?ooO`0<ooooo`04o`00ooooooooogl0oomo02Sooooo
1?ooO`03ooooo`03o`00oooooooooooo043ooooo0Ol00001ooooo`0000?o0000ooooooooool0UOoo
ool4oomo00[ooooo0_l00?l00oooooooogl0oomo0002oomo02Oooooo1?ooO`03ooooo`03o`00oooo
oooooooo043ooooo0Ol00001ooooo`0000?o0000ooooooooool0U_ooool2oomo00[ooooo00Co003o
oooooooooooooooo1?ooO`0Xooooo`;oogl01?ooool00ol00?ooooooooooo`10ooooo`7o00000Ooo
ool00003o`000?oooooooooo0:7ooooo00?o003oooooooooool00oooool2oomo02kooooo00?o003o
ooooooooool0@Oooool1o`00007ooooo00000ol0003oooooooooo`2Pooooo`03o`00oooooooooooo
03?ooooo00?o003oooooooooool04_ooool2oomo02kooooo0Ol00001ooooo`0000?o0000oooooooo
ool0W_ooool2o`00ocGooooo00?o003oooooooooool04_ooool4oomo02gooooo0Ol00001ooooo`00
00?o0000ooooooooool0WOooool00ol00?ooooooooooo`0Eooooo`Co003o7?ooool00ol00?ooogl0
oomo000Booooo`Coogl0;Oooool1o`00007ooooo00000ol0003oooooooooo`2Looooo`03o`00oooo
oooooooo01Gooooo1_l00?lJooooo`03o`00ooooO`3oogl000;oogl04_ooool2oomo02kooooo0Ol0
0001ooooo`0000?o0000ooooooooool0Voooool00ol00?ooooooooooo`0Eooooo`So003o6?ooool0
0ol00?oooooooomo0003oomo04;ooooo0Ol00001ooooo`0000?o0000ooooooooool0Voooool00ol0
0?ooooooooooo`0Eooooo`So003o5oooool01?l00?ooooooooooooooool2oomo04?ooooo0Ol00001
ooooo`0000?o0000ooooooooool0V_ooool00ol00?ooooooooooo`0Fooooo`So003o5_ooool00ol0
0?ooooooooooo`17ooooo`7o00000Oooool00003o`000?oooooooooo09Wooooo00?o003ooooooooo
ool03?ooool2oomo00Sooooo00?oogl0o`00ool00?l01_l00?lEooooo`03o`00oooooooooooo00;o
ogl0A_ooool1o`00007ooooo00000ol0003oooooooooo`1dooooo`Goo`3o8?ooool00ol00?oooooo
ooooo`0:ooooo`Googl01oooool2oomo00Ko003o4oooool2oomo0003o`00oooooooooooo00Coogl0
AOooool1o`00007ooooo00000ol0003oooooooooo`1cooooo`Ooo`3o7_ooool00ol00?oooooooooo
o`0:ooooo`Koogl02?ooool2oomo00Co003o4oooool2oomo00;o003o0_ooool4oomo04Gooooo0Ol0
0001ooooo`0000?o0000ooooooooool0L_ooool9ool0oagooooo00?o003oooooooooool02_ooool5
oomo02;ooooo00Coogl0o`00ooooO`3oogl00oooool2oomo04Kooooo0Ol00001ooooo`0000?o0000
ooooooooool0LOooool;ool0oa_ooooo00?o003oooooooooool03?ooool2oomo02Cooooo00?o003o
oomo0?ooO`00C?ooool1o`00007ooooo00000ol0003oooooooooo`1aooooo`_oo`3o6oooool00ol0
0?ooooooooooo`0aooooo`03o`00oooooooooooo04gooooo0Ol00001ooooo`0000?o0000oooooooo
ool0LOooool;ool0o`Oooooo0_ooO`0Aooooo`03o`00oooooooooooo037ooooo00?o003ooooooooo
ool0C_ooool1o`00007ooooo00000ol0003oooooooooo`1aooooo`_oo`3o1_ooool4oomo00oooooo
00?o003oooooooooool06?ooool2oomo01Oooooo00?o003oooooooooool0Coooool1o`00007ooooo
00000ol0003oooooooooo`1aooooo`_oo`3o1_ooool4oomo00oooooo00?o003oooooooooool05ooo
ool4oomo01Cooooo0_l00?mBooooo`7o00000Oooool00003o`000?oooooooooo07;ooooo2Ooo0?l8
ooooo`;oogl03oooool00ol00?ooooooooooo`0Booooo`;oogl01?ooool4oomo017ooooo0ol00?mD
ooooo`7o00000Oooool00003o`000?oooooooooo07?ooooo1ooo0?lJooooo`03o`00oooooooooooo
017ooooo1?ooO`04ooooo`;oogl04?ooool2o`00oeOooooo0Ol00001ooooo`0000?o0000oooooooo
ool0M?ooool5ool0oa_ooooo00?o003oooooooooool04Oooool4oomo01Gooooo00?o003ooooooooo
ool0Eoooool1o`00007ooooo00000ol0003oooooooooo`2Dooooo`03o`00oooooooooooo01;ooooo
0_ooO`0Dooooo`;o003oF_ooool1o`00007ooooo00000ol0003oooooooooo`2Dooooo`03o`00oooo
oooooooo02Kooooo0_l00?mLooooo`7o00000Oooool00003o`000?oooooooooo09Gooooo00?o003o
ooooooooool09?ooool00ol00?ooooooooooo`1Looooo`7o00000Oooool00003o`000?oooooooooo
09Gooooo00?o003oooooooooool08_ooool2o`00oeoooooo0Ol00001ooooo`0000?o0000oooooooo
ool0UOooool00ol00?ooooooooooo`0Pooooo`;o003oHOooool1o`00007ooooo00000ol0003ooooo
ooooo`24ooooo`;oogl03oooool2o`00oaoooooo0_l00?mSooooo`7o00000Oooool00003o`000?oo
oooooooo08?ooooo1?ooO`0@ooooo`;o003o6_ooool3o`00ofGooooo0Ol00001ooooo`0000?o0000
ooooooooool0Poooool4oomo01;ooooo0_l00?lDooooo`Co003oJ?ooool1o`00007ooooo00000ol0
003oooooooooo`24ooooo`;oogl05Oooool3o`00o`kooooo0ol00?l3ooooo`;oogl0Ioooool1o`00
007ooooo00000ol0003oooooooooo`2Nooooo`?o003o1Oooool6o`00o`Gooooo1?ooO`1Vooooo`7o
00000Oooool00003o`000?oooooooooo0:7ooooo1Ol00?l;ooooo`Coogl0I_ooool1o`00007ooooo
00000ol0003oooooooooo`2booooo`;oogl0Ioooool1o`00007ooooo00000ol0003oooooooooo`3o
oooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003
o`000?oooooooooo07_ooooo0_ooO`2Nooooo`7o00000Oooool00003o`000?oooooooooo07[ooooo
1?ooO`2Mooooo`7o00000Oooool00003o`000?oooooooooo07[ooooo1?ooO`0Pooooo`;oogl0Nooo
ool1o`00007ooooo00000ol0003oooooooooo`1kooooo`;oogl08?ooool4oomo07[ooooo0Ol00001
ooooo`0000?o0000ooooooooool0WOooool4oomo07[ooooo0Ol00001ooooo`0000?o0000oooooooo
ool0T?ooool2oomo00cooooo0_ooO`1kooooo`7o00000Oooool00003o`000?oooooooooo08oooooo
1?ooO`28ooooo`7o00000Oooool00003o`000?oooooooooo08oooooo1?ooO`28ooooo`7o00000Ooo
ool00003o`000?oooooooooo093ooooo0_ooO`0Sooooo`;oogl0I?ooool1o`00007ooooo00000ol0
003oooooooooo`2dooooo`Coogl0Hoooool1o`00007ooooo00000ol0003oooooooooo`2dooooo`Co
ogl0Hoooool1o`00007ooooo00000ol0003oooooooooo`2eooooo`;oogl0I?ooool1o`00007ooooo
00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolL
ooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003o
ooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o0000
0Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3o
oooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003
o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo
0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oooooo
oooo0?oooooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001oooo
o`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo
7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000
ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00
007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0
oooooolLooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo0000
0ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLoooo
o`7o00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003ooooo
ooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Ooo
ool00003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooo
oacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`00
0?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol0
0001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo
0?oooooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`00
00?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?oo
ool1o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000oooo
ooooool0S_ooool2oomo08_ooooo0Ol00001ooooo`0000?o0000ooooooooool0SOooool4oomo08[o
oooo0Ol00001ooooo`0000?o0000ooooooooool0SOooool4oomo08[ooooo0Ol00001ooooo`0000?o
0000ooooooooool0S_ooool2oomo08_ooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolL
ooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003o
ooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o0000
0Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3o
oooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003
o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo
0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oooooo
oooo0?oooooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001oooo
o`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo
7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000
ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00
007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0
oooooolLooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo0000
0ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`00ool0000Po`00007ooooo0000\
\>"],
  ImageRangeCache->{{{0, 287}, {287, 0}} -> {-1.01089, -1.01089, 0.00704453, \
0.00704453}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.49505 0.5 0.49505 [
[ 0 0 -0.125 0 ]
[ 0 0 -0.125 0 ]
[ 0 1 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
0 0 m
1 0 L
s
0 0 m
0 1 L
s
0 1 m
1 1 L
s
1 0 m
1 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
1 .5 0 r
.015 w
.03175 .1355 Mdot
.03435 .12523 Mdot
.11137 .12765 Mdot
.14107 .18841 Mdot
.16218 .24538 Mdot
.17294 .21053 Mdot
.18267 .18577 Mdot
.18434 .1304 Mdot
.18553 .30956 Mdot
.20401 .239 Mdot
.21247 .27571 Mdot
.21687 .20845 Mdot
.22376 .2799 Mdot
.22832 .27485 Mdot
.29063 .20974 Mdot
.29686 .25079 Mdot
.30487 .22936 Mdot
.30683 .34623 Mdot
.32055 .20902 Mdot
.32574 .21979 Mdot
.34472 .28521 Mdot
.35998 .36393 Mdot
.36335 .24976 Mdot
.3794 .36608 Mdot
.42386 .66992 Mdot
.44391 .74519 Mdot
.45059 .34198 Mdot
.47208 .67586 Mdot
.47436 .71381 Mdot
.49778 .59825 Mdot
.50874 .91643 Mdot
.51516 .76219 Mdot
.53655 .61374 Mdot
.56563 .75219 Mdot
.59189 .65665 Mdot
.59581 .61604 Mdot
.59923 .6556 Mdot
.60292 .68499 Mdot
.62656 .67779 Mdot
.63555 .72451 Mdot
.63919 .652 Mdot
.64169 .6004 Mdot
.64246 .58611 Mdot
.64496 .54267 Mdot
.64608 .77288 Mdot
.65077 .64308 Mdot
.66065 .57816 Mdot
.67474 .59169 Mdot
.69296 .563 Mdot
.72815 .65902 Mdot
.73169 .58879 Mdot
.74669 .61318 Mdot
.74821 .65474 Mdot
.75963 .63781 Mdot
.79673 .57809 Mdot
.80925 .55852 Mdot
.81525 .58444 Mdot
.83417 .62985 Mdot
.83598 .55526 Mdot
.91595 .49319 Mdot
1 0 0 r
.005 w
.16128 .17044 m
.18734 .17269 L
.21339 .17909 L
.2345 .18734 L
.23945 .19126 L
.2655 .20415 L
.27874 .21339 L
.29156 .22295 L
.31204 .23945 L
.31761 .24532 L
.33549 .2655 L
.34367 .28341 L
.34499 .29156 L
.34367 .29798 L
.31761 .3104 L
.29156 .30711 L
.2655 .30014 L
.24507 .29156 L
.23945 .28747 L
.21339 .27402 L
.20155 .2655 L
.18734 .25472 L
.16884 .23945 L
.16128 .2313 L
.14618 .21339 L
.13806 .18734 L
.16128 .17044 L
s
0 0 1 r
.65633 .57701 m
.68239 .56842 L
.70844 .56313 L
.7345 .56168 L
.76055 .5752 L
.76359 .57817 L
.76859 .60422 L
.76055 .62333 L
.75627 .63028 L
.7345 .65485 L
.73298 .65633 L
.70844 .6775 L
.69922 .68239 L
.68239 .69294 L
.65633 .70579 L
.64983 .70844 L
.63028 .71539 L
.60422 .72268 L
.57817 .72651 L
.55211 .7214 L
.53145 .70844 L
.52926 .68239 L
.54239 .65633 L
.55211 .63983 L
.56625 .63028 L
.57817 .6193 L
.60119 .60422 L
.60422 .60227 L
.63028 .58726 L
.65315 .57817 L
.65633 .57701 L
s
1 0 0 r
.03 w
.24141 .24033 Mdot
0 0 1 r
.64872 .64417 Mdot
1 0 0 r
.79703 .00495 m
.79703 .00495 L
.87129 .00495 L
.87129 .00495 L
F
0 0 1 r
.89604 .00495 m
.89604 .25248 L
.9703 .25248 L
.9703 .00495 L
F
1 0 1 r
.04 w
.44391 .74519 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P000182000`400?l00000o`00003ooooooolQ
ooooo`00ool0000Po`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`00
00?o0000ooooooooool0o_oooolEo`00o`Sooooo0Ol00001ooooo`0000?o0000ooooooooool0o_oo
oolEo`00o`Sooooo0Ol00001ooooo`0000?o0000ooooooooool0o_oooolEo`00o`Sooooo0Ol00001
ooooo`0000?o0000ooooooooool0o_oooolEo`00o`Sooooo0Ol00001ooooo`0000?o0000oooooooo
ool0o_oooolEo`00o`Sooooo0Ol00001ooooo`0000?o0000ooooooooool0o_oooolEo`00o`Sooooo
0Ol00001ooooo`0000?o0000ooooooooool0o_oooolEo`00o`Sooooo0Ol00001ooooo`0000?o0000
ooooooooool0o_oooolEo`00o`Sooooo0Ol00001ooooo`0000?o0000ooooooooool0o_oooolEo`00
o`Sooooo0Ol00001ooooo`0000?o0000ooooooooool0o_oooolEo`00o`Sooooo0Ol00001ooooo`00
00?o0000ooooooooool0o_oooolEo`00o`Sooooo0Ol00001ooooo`0000?o0000ooooooooool0o_oo
oolEo`00o`Sooooo0Ol00001ooooo`0000?o0000ooooooooool0o_oooolEo`00o`Sooooo0Ol00001
ooooo`0000?o0000ooooooooool0o_oooolEo`00o`Sooooo0Ol00001ooooo`0000?o0000oooooooo
ool0o_oooolEo`00o`Sooooo0Ol00001ooooo`0000?o0000ooooooooool0o_oooolEo`00o`Sooooo
0Ol00001ooooo`0000?o0000ooooooooool0o_oooolEo`00o`Sooooo0Ol00001ooooo`0000?o0000
ooooooooool0o_oooolEo`00o`Sooooo0Ol00001ooooo`0000?o0000ooooooooool0o_oooolEo`00
o`Sooooo0Ol00001ooooo`0000?o0000ooooooooool0o_oooolEo`00o`Sooooo0Ol00001ooooo`00
00?o0000ooooooooool0o_oooolEo`00o`Sooooo0Ol00001ooooo`0000?o0000ooooooooool0o_oo
oolEo`00o`Sooooo0Ol00001ooooo`0000?o0000ooooooooool0o_oooolEo`00o`Sooooo0Ol00001
ooooo`0000?o0000ooooooooool0o_oooolEo`00o`Sooooo0Ol00001ooooo`0000?o0000oooooooo
ool0o_oooolEo`00o`Sooooo0Ol00001ooooo`0000?o0000ooooooooool0o_oooolEo`00o`Sooooo
0Ol00001ooooo`0000?o0000ooooooooool0o_oooolEo`00o`Sooooo0Ol00001ooooo`0000?o0000
ooooooooool0o_oooolEo`00o`Sooooo0Ol00001ooooo`0000?o0000ooooooooool0o_oooolEo`00
o`Sooooo0Ol00001ooooo`0000?o0000ooooooooool0o_oooolEo`00o`Sooooo0Ol00001ooooo`00
00?o0000ooooooooool0o_oooolEo`00o`Sooooo0Ol00001ooooo`0000?o0000ooooooooool0o_oo
oolEo`00o`Sooooo0Ol00001ooooo`0000?o0000ooooooooool01_ooool2oomo0?Kooooo5Ol00?l8
ooooo`7o00000Oooool00003o`000?oooooooooo00Gooooo1?ooO`0Cooooo`;oogl0h?oooolEo`00
o`Sooooo0Ol00001ooooo`0000?o0000ooooooooool01Oooool4oomo01;ooooo1?ooO`0Booooo`;o
ogl0booooolEo`00o`Sooooo0Ol00001ooooo`0000?o0000ooooooooool01Oooool3oomo01?ooooo
1?ooO`0Aooooo`Coogl0b_oooolEo`00o`Sooooo0Ol00001ooooo`0000?o0000ooooooooool01?oo
ool4oomo01Cooooo0_ooO`0Booooo`Coogl0b_oooolEo`00o`Sooooo0Ol00001ooooo`0000?o0000
ooooooooool01?ooool4oomo02Wooooo0_ooO`3;oooooaGo003o2?ooool1o`00007ooooo00000ol0
003oooooooooo`05ooooo`;oogl0mooooolEo`00o`Sooooo0Ol00001ooooo`0000?o0000oooooooo
ool0o_oooolEo`00o`Sooooo0Ol00001ooooo`0000?o0000ooooooooool0o_oooolEo`00o`Sooooo
0Ol00001ooooo`0000?o0000ooooooooool0o_oooolEo`00o`Sooooo0Ol00001ooooo`0000?o0000
ooooooooool0o_oooolEo`00o`Sooooo0Ol00001ooooo`0000?o0000ooooooooool0o_oooolEo`00
o`Sooooo0Ol00001ooooo`0000?o0000ooooooooool0o_oooolEo`00o`Sooooo0Ol00001ooooo`00
00?o0000ooooooooool0o_oooolEo`00o`Sooooo0Ol00001ooooo`0000?o0000ooooooooool0:_oo
ool6ool00<kooooo5Ol00?l8ooooo`7o00000Oooool00003o`000?oooooooooo02Wooooo00?oo`00
ooooooooool01?ooool5ool00<Wooooo5Ol00?l8ooooo`7o00000Oooool00003o`000?oooooooooo
02Oooooo0_oo000<ooooo`Coo`00aOoooolEo`00o`Sooooo0Ol00001ooooo`0000?o0000oooooooo
ool09_ooool00ooo003oooooooooo`0@ooooo`Coo`00`OoooolEo`00o`Sooooo0Ol00001ooooo`00
00?o0000ooooooooool09?ooool00oooO`3oo`00ooooo`09ooooo`;oogl02oooool3ool00;kooooo
5Ol00?l8ooooo`7o00000Oooool00003o`000?oooooooooo02?ooooo00Coogl0ool00?ooO`3oogl0
2?ooool4oomo00gooooo00?oo`00ooooooooool0^ooooolEo`00o`Sooooo0Ol00001ooooo`0000?o
0000ooooooooool08oooool01?ooO`3oo`00oomo0?ooO`08ooooo`Coogl03_ooool2ool00;_ooooo
5Ol00?l8ooooo`7o00000Oooool00003o`000?oooooooooo02Cooooo00?oogl0ool00?ooool02Ooo
ool2oomo017ooooo0_oo002ioooooaGo003o2?ooool1o`00007ooooo00000ol0003oooooooooo`0U
ooooo`03ool00?oooooooooo01gooooo0_oo002goooooaGo003o2?ooool1o`00007ooooo00000ol0
003oooooooooo`0Uooooo`03ool00?oooooooooo01oooooo0_oo002eoooooaGo003o2?ooool1o`00
007ooooo00000ol0003oooooooooo`0Vooooo`03ool00?oooooooooo017ooooo0_ooO`0=ooooo`;o
o`001?ooool2oomo00Oooooo0_ooO`2ToooooaGo003o2?ooool1o`00007ooooo00000ol0003ooooo
ooooo`0Vooooo`03ool00?oooooooooo00Gooooo0_ooO`09ooooo`Coogl03_ooool00ooo003ooooo
ooooo`04oomo00Gooooo1?ooO`2SoooooaGo003o2?ooool1o`00007ooooo00000ol0003ooooooooo
o`0Vooooo`03ool00?oooooooooo00Cooooo1?ooO`08ooooo`Coogl03oooool00ooo003ooooooomo
0003oomo00Gooooo1?ooO`2SoooooaGo003o2?ooool1o`00007ooooo00000ol0003oooooooooo`0W
ooooo`03ool00?oooooooooo00?ooooo1?ooO`09ooooo`;oogl04Oooool01?oo003ooooooomo0?oo
O`07ooooo`?oogl0XooooolEo`00o`Sooooo0Ol00001ooooo`0000?o0000ooooooooool09oooool0
0ooo003oooooooooo`04ooooo`;oogl07_ooool00ooo003oooooooooo`07ooooo`Coogl0X_oooolE
o`00o`Sooooo0Ol00001ooooo`0000?o0000ooooooooool0:?ooool00ooo003oooooooooo`0Toooo
o`03ool00?oooooooooo00Kooooo1?ooO`2RoooooaGo003o2?ooool1o`00007ooooo00000ol0003o
ooooooooo`0Yooooo`03ool00?oooooooooo02Cooooo0_oo00000oooooooogl0oomo0004ooooo`;o
ogl0XooooolEo`00o`Sooooo0Ol00001ooooo`0000?o0000ooooooooool0:_ooool00ooo003ooooo
ooooo`0Cooooo`Coo`003_ooool01?oo003oogl0oomo0?ooO`2XoooooaGo003o2?ooool1o`00007o
oooo00000ol0003oooooooooo`0[ooooo`03ool00?oooooooooo017ooooo1_oo000=ooooo`04oomo
0?oo003oo`00oomo0:Sooooo5Ol00?l8ooooo`7o00000Oooool00003o`000?oooooooooo02cooooo
00?oo`00ooooooooool02?ooool2oomo00Gooooo2?oo000=ooooo`;oogl000?oo`00ooooooooool0
Y_oooolEo`00o`Sooooo0Ol00001ooooo`0000?o0000ooooooooool0;Oooool00ooo003ooooooooo
o`06ooooo`Coogl01?ooool8ool0013ooooo00?oo`00ooooooooool0YOoooolEo`00o`Sooooo0Ol0
0001ooooo`0000?o0000ooooooooool0:oooool2oomo0003oooooooo003ooooo00Kooooo1?ooO`04
ooooo`Soo`004Oooool00ooo003oooooooooo`2ToooooaGo003o2?ooool1o`00007ooooo00000ol0
003oooooooooo`0Zooooo`Coogl000?oooooool00?ooool01_ooool2oomo00Gooooo2?oo000;oooo
o`;oogl01Oooool00ooo003oooooooooo`09ooooo`;oogl0V?oooolEo`00o`Sooooo0Ol00001oooo
o`0000?o0000ooooooooool0:_ooool4oomo00;ooooo00?oo`00ooooooooool03?ooool6ool000_o
oooo1?ooO`04ooooo`03ool00?oooooooooo00Sooooo1?ooO`2GoooooaGo003o2?ooool1o`00007o
oooo00000ol0003oooooooooo`0[ooooo`;oogl01?ooool00ooo003oooooooooo`0<ooooo`Coo`00
3?ooool4oomo00Gooooo00?oo`00ooooooooool01oooool4oomo09Oooooo5Ol00?l8ooooo`7o0000
0Oooool00003o`000?oooooooooo03;ooooo0_oo000Mooooo`;oogl01oooool00ooo003ooooooooo
o`07ooooo`;oogl0]Oooool1o`00007ooooo00000ol0003oooooooooo`0dooooo`03ool00?oooooo
oooo02Cooooo00?oo`00ooooooooool0_Oooool1o`00007ooooo00000ol0003oooooooooo`0eoooo
o`03ool00?oooooooooo02Cooooo00?oo`00ooooooooool0_?ooool1o`00007ooooo00000ol0003o
ooooooooo`0fooooo`;oo`009Oooool00ooo003oooooooooo`2kooooo`7o00000Oooool00003o`00
0?oooooooooo03Sooooo0_oo00000oooO`3oooooooooo`02oomo01kooooo00?oo`00ooooooooool0
^oooool1o`00007ooooo00000ol0003oooooooooo`0hooooo`;oogl00_oo0004oomo01kooooo00?o
o`00ooooooooool0^_ooool1o`00007ooooo00000ol0003oooooooooo`0hooooo`Coogl00_oo0002
oomo01kooooo00?oo`00ooooooooool0^_ooool1o`00007ooooo00000ol0003oooooooooo`0ioooo
o`Googl000?oo`00ooooooooool07Oooool00ooo003oogl0oomo002jooooo`7o00000Oooool00003
o`000?oooooooooo03_ooooo1?ooO`02ool001gooooo00Coogl0ool00?ooO`3oogl0^Oooool1o`00
007ooooo00000ol0003oooooooooo`0looooo`;oogl00oooool2ool001_ooooo00Coogl0ool00?oo
O`3oogl0^Oooool1o`00007ooooo00000ol0003oooooooooo`13ooooo`;oo`006_ooool00oooO`3o
o`00ooooo`2iooooo`7o00000Oooool00003o`000?oooooooooo04Gooooo0_oo000Iooooo`03ool0
0?oooooooooo0;Sooooo0Ol00001ooooo`0000?o0000ooooooooool0Aoooool2ool001Gooooo0_oo
002kooooo`7o00000Oooool00003o`000?oooooooooo04Wooooo0ooo000@ooooo`;oo`00_Oooool1
o`00007ooooo00000ol0003oooooooooo`0aooooo`;oogl06Oooool3ool000cooooo00?oo`00oooo
ooooool0_Oooool1o`00007ooooo00000ol0003oooooooooo`0`ooooo`Coogl06oooool6ool000Co
oooo0_oo0030ooooo`7o00000Oooool00003o`000?oooooooooo033ooooo1?ooO`0Qooooo`Coo`00
`_ooool1o`00007ooooo00000ol0003oooooooooo`0aooooo`;oogl0j?ooool1o`00007ooooo0000
0ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLoooo
o`7o00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003ooooo
ooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Ooo
ool00003o`000?oooooooooo07gooooo0_ooO`2Looooo`7o00000Oooool00003o`000?oooooooooo
07cooooo1?ooO`2Kooooo`7o00000Oooool00003o`000?oooooooooo05Cooooo0_ooO`0Vooooo`Co
ogl0Voooool1o`00007ooooo00000ol0003oooooooooo`1Cooooo`Coogl09_ooool2oomo09cooooo
0Ol00001ooooo`0000?o0000ooooooooool0Doooool4oomo0<Cooooo0Ol00001ooooo`0000?o0000
ooooooooool0E?ooool2oomo0<Gooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLoooo
o`7o00000Oooool00003o`000?oooooooooo06?ooooo0_ooO`04ooooo`;oogl0/?ooool1o`00007o
oooo00000ol0003oooooooooo`1Rooooo`Coogl00_ooool4oomo0:oooooo0Ol00001ooooo`0000?o
0000ooooooooool0H_ooool4oomo00;ooooo1?ooO`2_ooooo`7o00000Oooool00003o`000?oooooo
oooo06?ooooo0_ooO`04ooooo`;oogl0/?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooo
oacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`00
0?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol0
0001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo
0?oooooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`00
00?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?oo
ool1o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000oooo
ooooool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007o
oooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooo
oolLooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0
003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o
00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003ooooooooo
o`3ooooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool0
0003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooooaco
oooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oo
oooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001
ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo0?oo
oooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o
0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1
o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000oooooooo
ool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo
00000ol0003oooooooooo`3oooooo`Cooooo0_ooO`0Fooooo`7o00000Oooool00003o`000?oooooo
oooo0?oooooo0oooool4oomo01Gooooo0Ol00001ooooo`0000?o0000ooooooooool0ooooool3oooo
o`Coogl05Oooool1o`00007ooooo00000ol0003oooooooooo`3oooooo`Cooooo0_ooO`0Fooooo`7o
00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003ooooooooo
o`3ooooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool0
0003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooooaco
oooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oo
oooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001
ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo0?oo
oooo7?ooool1o`00007ooooo00000ol0003oooooooooo`2eooooo`;oogl0I?ooool1o`00007ooooo
00000ol0003oooooooooo`2dooooo`Coogl0Hoooool1o`00007ooooo00000ol0003oooooooooo`2d
ooooo`Coogl0Hoooool1o`00007ooooo00000ol0003oooooooooo`2eooooo`;oogl0=Oooool2oomo
02gooooo0Ol00001ooooo`0000?o0000ooooooooool0i?ooool2oomo00Gooooo1?ooO`0/ooooo`7o
00000Oooool00003o`000?oooooooooo0>?ooooo1?ooO`04ooooo`Coogl0;?ooool1o`00007ooooo
00000ol0003oooooooooo`33ooooo`;oogl07_ooool4oomo00Gooooo0_ooO`0]ooooo`7o00000Ooo
ool00003o`000?oooooooooo0<;ooooo1?ooO`0;o`00oa?ooooo0_ooO`0eooooo`7o00000Oooool0
0003o`000?oooooooooo0<;ooooo1?l00?l;ooooo`;o003oB?ooool1o`00007ooooo00000ol0003o
ooooooooo`2nooooo`Co003o00?ooooooomo0?ooO`003_ooool2o`00odKooooo0Ol00001ooooo`00
00?o0000ooooooooool0^Oooool2oomo00?o003o5oooool2o`00o`Wooooo0_ooO`0iooooo`7o0000
0Oooool00003o`000?oooooooooo0;Oooooo1?l00?l00oooO`3oooooooooo`0Iooooo`;o003o1_oo
ool4oomo03Sooooo0Ol00001ooooo`0000?o0000ooooooooool0]?ooool3o`00o`03ooooooooO`3o
ogl000;oogl07?ooool00ol00?ooooooooooo`04ooooo`Coogl00oooool2oomo03?ooooo0Ol00001
ooooo`0000?o0000ooooooooool0/_ooool2o`00o`?oogl00_ooool2oomo01?ooooo0_ooO`08oooo
o`03o`00oooooooooooo00Gooooo0_ooO`03ooooo`Coogl0<_ooool1o`00007ooooo00000ol0003o
ooooooooo`2`ooooo`;o003o00?ooooooomo0?ooO`000_ooO`06ooooo`;oogl03_ooool4oomo00Oo
oooo00?o003oooooooooool02_ooool4oomo03;ooooo0Ol00001ooooo`0000?o0000ooooooooool0
[_ooool2o`00o`Cooooo0_ooO`06ooooo`Coogl03Oooool4oomo00Oooooo00?o003oooooooooool0
2oooool2oomo03?ooooo0Ol00001ooooo`0000?o0000ooooooooool0Roooool2oomo023ooooo00?o
003oooooooooool01?ooool2oomo00Kooooo1?ooO`0>ooooo`;oogl02Oooool00ol00?oooooooooo
o`0oooooo`7o00000Oooool00003o`000?oooooooooo08[ooooo1?ooO`0Mooooo`;o003o1_ooool4
oomo00Kooooo0_ooO`0Jooooo`03o`00oooooooooooo03oooooo0Ol00001ooooo`0000?o0000oooo
ooooool0R_ooool4oomo01cooooo00?o003oooooooooool01_ooool4oomo02;ooooo00?o003ooooo
ooooool0?oooool1o`00007ooooo00000ol0003oooooooooo`2;ooooo`;oogl06oooool2o`00o`[o
oooo0_ooO`0Sooooo`03o`00oooooooooooo03oooooo0Ol00001ooooo`0000?o0000ooooooooool0
U_ooool2oomo00kooooo0_l00?lZooooo`;oogl01Oooool00ol00?ooooooooooo`0oooooo`7o0000
0Oooool00003o`000?oooooooooo09Gooooo1?ooO`0<ooooo`04o`00ooooooooogl0oomo02Sooooo
1?ooO`03ooooo`03o`00oooooooooooo043ooooo0Ol00001ooooo`0000?o0000ooooooooool0UOoo
ool4oomo00[ooooo0_l00?l00oooooooogl0oomo0002oomo02Oooooo1?ooO`03ooooo`03o`00oooo
oooooooo043ooooo0Ol00001ooooo`0000?o0000ooooooooool0U_ooool2oomo00[ooooo00Co003o
oooooooooooooooo1?ooO`0Xooooo`;oogl01?ooool00ol00?ooooooooooo`10ooooo`7o00000Ooo
ool00003o`000?oooooooooo0:7ooooo00?o003oooooooooool00oooool2oomo02kooooo00?o003o
ooooooooool0@Oooool1o`00007ooooo00000ol0003oooooooooo`2Pooooo`03o`00oooooooooooo
03?ooooo00?o003oooooooooool04_ooool2oomo02kooooo0Ol00001ooooo`0000?o0000oooooooo
ool0W_ooool2o`00ocGooooo00?o003oooooooooool04_ooool4oomo02gooooo0Ol00001ooooo`00
00?o0000ooooooooool0WOooool00ol00?ooooooooooo`0Eooooo`Co003o7?ooool00ol00?ooogl0
oomo000Booooo`Coogl0;Oooool1o`00007ooooo00000ol0003oooooooooo`2Looooo`03o`00oooo
oooooooo01Gooooo1_l00?lJooooo`03o`00ooooO`3oogl000;oogl04_ooool2oomo02kooooo0Ol0
0001ooooo`0000?o0000ooooooooool0Voooool00ol00?ooooooooooo`0Eooooo`So003o6?ooool0
0ol00?oooooooomo0003oomo04;ooooo0Ol00001ooooo`0000?o0000ooooooooool0Voooool00ol0
0?ooooooooooo`0Eooooo`So003o5oooool01?l00?ooooooooooooooool2oomo04?ooooo0Ol00001
ooooo`0000?o0000ooooooooool0V_ooool00ol00?ooooooooooo`0Fooooo`So003o5_ooool00ol0
0?ooooooooooo`17ooooo`7o00000Oooool00003o`000?oooooooooo09Wooooo00?o003ooooooooo
ool03?ooool2oomo00Sooooo00?oogl0o`00ool00?l01_l00?lEooooo`03o`00oooooooooooo00;o
ogl0A_ooool1o`00007ooooo00000ol0003oooooooooo`2Iooooo`03o`00oooooooooooo00[ooooo
1OooO`07ooooo`;oogl01_l00?lCooooo`;oogl000?o003oooooooooool01?ooO`15ooooo`7o0000
0Oooool00003o`000?oooooooooo09Sooooo00?o003oooooooooool02_ooool6oomo00Sooooo0_oo
O`04o`00oa?ooooo0_ooO`02o`00o`;ooooo1?ooO`15ooooo`7o00000Oooool00003o`000?oooooo
oooo09Sooooo00?o003oooooooooool02_ooool5oomo02;ooooo00Coogl0o`00ooooO`3oogl00ooo
ool2oomo04Kooooo0Ol00001ooooo`0000?o0000ooooooooool0M_ooool2oomo01oooooo00?o003o
ooooooooool03?ooool2oomo02Cooooo00?o003ooomo0?ooO`00C?ooool1o`00007ooooo00000ol0
003oooooooooo`1eooooo`Coogl07_ooool00ol00?ooooooooooo`0aooooo`03o`00oooooooooooo
04gooooo0Ol00001ooooo`0000?o0000ooooooooool0MOooool4oomo00[ooooo0_ooO`0Aooooo`03
o`00oooooooooooo037ooooo00?o003oooooooooool0C_ooool1o`00007ooooo00000ol0003ooooo
ooooo`1fooooo`;oogl02_ooool4oomo00oooooo00?o003oooooooooool06?ooool2oomo01Oooooo
00?o003oooooooooool0Coooool1o`00007ooooo00000ol0003oooooooooo`22ooooo`Coogl03ooo
ool00ol00?ooooooooooo`0Gooooo`Coogl05?ooool2o`00oe;ooooo0Ol00001ooooo`0000?o0000
ooooooooool0Poooool2oomo00oooooo00?o003oooooooooool04_ooool2oomo00Cooooo1?ooO`0A
ooooo`?o003oE?ooool1o`00007ooooo00000ol0003oooooooooo`2Dooooo`03o`00oooooooooooo
017ooooo1?ooO`04ooooo`;oogl04?ooool2o`00oeOooooo0Ol00001ooooo`0000?o0000oooooooo
ool0U?ooool00ol00?ooooooooooo`0Aooooo`Coogl05Oooool00ol00?ooooooooooo`1Gooooo`7o
00000Oooool00003o`000?oooooooooo09Cooooo00?o003oooooooooool04_ooool2oomo01Cooooo
0_l00?mJooooo`7o00000Oooool00003o`000?oooooooooo09Cooooo00?o003oooooooooool09_oo
ool2o`00oecooooo0Ol00001ooooo`0000?o0000ooooooooool0UOooool00ol00?ooooooooooo`0T
ooooo`03o`00oooooooooooo05cooooo0Ol00001ooooo`0000?o0000ooooooooool0UOooool00ol0
0?ooooooooooo`0Rooooo`;o003oGoooool1o`00007ooooo00000ol0003oooooooooo`2Eooooo`03
o`00oooooooooooo023ooooo0_l00?mQooooo`7o00000Oooool00003o`000?oooooooooo08Cooooo
0_ooO`0?ooooo`;o003o7oooool2o`00of?ooooo0Ol00001ooooo`0000?o0000ooooooooool0Pooo
ool4oomo013ooooo0_l00?lJooooo`?o003oIOooool1o`00007ooooo00000ol0003oooooooooo`23
ooooo`Coogl04_ooool2o`00oaCooooo1?l00?mXooooo`7o00000Oooool00003o`000?oooooooooo
08Cooooo0_ooO`0Eooooo`?o003o3_ooool3o`00o`?ooooo0_ooO`1Wooooo`7o00000Oooool00003
o`000?oooooooooo09kooooo0ol00?l5ooooo`Ko003o1Oooool4oomo06Kooooo0Ol00001ooooo`00
00?o0000ooooooooool0N_ooool5ool0ob;ooooo1Ol00?l;ooooo`Coogl0I_ooool1o`00007ooooo
00000ol0003oooooooooo`1iooooo`Ooo`3o<_ooool2oomo06Oooooo0Ol00001ooooo`0000?o0000
ooooooooool0N?ooool9ool0oi[ooooo0Ol00001ooooo`0000?o0000ooooooooool0Moooool;ool0
oiWooooo0Ol00001ooooo`0000?o0000ooooooooool0Moooool;ool0oiWooooo0Ol00001ooooo`00
00?o0000ooooooooool0Moooool;ool0oiWooooo0Ol00001ooooo`0000?o0000ooooooooool0Mooo
ool;ool0oacooooo0_ooO`1kooooo`7o00000Oooool00003o`000?oooooooooo07Oooooo2ooo0?lK
ooooo`Coogl0N_ooool1o`00007ooooo00000ol0003oooooooooo`1hooooo`Woo`3o7?ooool4oomo
07[ooooo0Ol00001ooooo`0000?o0000ooooooooool0NOooool7ool0oa3ooooo0_ooO`0<ooooo`;o
ogl0Noooool1o`00007ooooo00000ol0003oooooooooo`1jooooo`Goo`3o4?ooool4oomo08Sooooo
0Ol00001ooooo`0000?o0000ooooooooool0Soooool4oomo08Sooooo0Ol00001ooooo`0000?o0000
ooooooooool0T?ooool2oomo02?ooooo0_ooO`1Tooooo`7o00000Oooool00003o`000?oooooooooo
0;Cooooo1?ooO`1Sooooo`7o00000Oooool00003o`000?oooooooooo0;Cooooo1?ooO`1Sooooo`7o
00000Oooool00003o`000?oooooooooo0;Gooooo0_ooO`1Tooooo`7o00000Oooool00003o`000?oo
oooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001
ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo0?oo
oooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o
0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1
o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000oooooooo
ool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo
00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolL
ooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003o
ooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o0000
0Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3o
oooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003
o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo
0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oooooo
oooo0?oooooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001oooo
o`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo
7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000
ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00
007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0
oooooolLooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo0000
0ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLoooo
o`7o00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003ooooo
ooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Ooo
ool00003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003oooooooooo`2>oooo
o`;oogl0Roooool1o`00007ooooo00000ol0003oooooooooo`2=ooooo`Coogl0R_ooool1o`00007o
oooo00000ol0003oooooooooo`2=ooooo`Coogl0R_ooool1o`00007ooooo00000ol0003ooooooooo
o`2>ooooo`;oogl0Roooool1o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001
ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo0?oo
oooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o
0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1
o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000oooooooo
ool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo
00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolL
ooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003o
ooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o0000
0Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3o
oooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003
o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo
0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oooooo
oooo0?oooooo7?ooool1o`00007ooooo003oo`00023o00000Oooool00001\
\>"],
  ImageRangeCache->{{{0, 287}, {287, 0}} -> {-1.01089, -1.01089, 0.00704453, \
0.00704453}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.49505 0.5 0.49505 [
[ 0 0 -0.125 0 ]
[ 0 0 -0.125 0 ]
[ 0 1 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
0 0 m
1 0 L
s
0 0 m
0 1 L
s
0 1 m
1 1 L
s
1 0 m
1 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
1 .5 0 r
.015 w
.03175 .1355 Mdot
.03435 .12523 Mdot
.11137 .12765 Mdot
.14107 .18841 Mdot
.16218 .24538 Mdot
.17294 .21053 Mdot
.18267 .18577 Mdot
.18434 .1304 Mdot
.18553 .30956 Mdot
.20401 .239 Mdot
.21247 .27571 Mdot
.21687 .20845 Mdot
.22376 .2799 Mdot
.22832 .27485 Mdot
.29063 .20974 Mdot
.29686 .25079 Mdot
.30487 .22936 Mdot
.30683 .34623 Mdot
.32055 .20902 Mdot
.32574 .21979 Mdot
.34472 .28521 Mdot
.35998 .36393 Mdot
.36335 .24976 Mdot
.3794 .36608 Mdot
.42386 .66992 Mdot
.44391 .74519 Mdot
.45059 .34198 Mdot
.47208 .67586 Mdot
.47436 .71381 Mdot
.49778 .59825 Mdot
.50874 .91643 Mdot
.51516 .76219 Mdot
.53655 .61374 Mdot
.56563 .75219 Mdot
.59189 .65665 Mdot
.59581 .61604 Mdot
.59923 .6556 Mdot
.60292 .68499 Mdot
.62656 .67779 Mdot
.63555 .72451 Mdot
.63919 .652 Mdot
.64169 .6004 Mdot
.64246 .58611 Mdot
.64496 .54267 Mdot
.64608 .77288 Mdot
.65077 .64308 Mdot
.66065 .57816 Mdot
.67474 .59169 Mdot
.69296 .563 Mdot
.72815 .65902 Mdot
.73169 .58879 Mdot
.74669 .61318 Mdot
.74821 .65474 Mdot
.75963 .63781 Mdot
.79673 .57809 Mdot
.80925 .55852 Mdot
.81525 .58444 Mdot
.83417 .62985 Mdot
.83598 .55526 Mdot
.91595 .49319 Mdot
1 0 0 r
.005 w
.16128 .17044 m
.18734 .17269 L
.21339 .17909 L
.2345 .18734 L
.23945 .19126 L
.2655 .20415 L
.27874 .21339 L
.29156 .22295 L
.31204 .23945 L
.31761 .24532 L
.33549 .2655 L
.34367 .28341 L
.34499 .29156 L
.34367 .29798 L
.31761 .3104 L
.29156 .30711 L
.2655 .30014 L
.24507 .29156 L
.23945 .28747 L
.21339 .27402 L
.20155 .2655 L
.18734 .25472 L
.16884 .23945 L
.16128 .2313 L
.14618 .21339 L
.13806 .18734 L
.16128 .17044 L
s
0 0 1 r
.65633 .57701 m
.68239 .56842 L
.70844 .56313 L
.7345 .56168 L
.76055 .5752 L
.76359 .57817 L
.76859 .60422 L
.76055 .62333 L
.75627 .63028 L
.7345 .65485 L
.73298 .65633 L
.70844 .6775 L
.69922 .68239 L
.68239 .69294 L
.65633 .70579 L
.64983 .70844 L
.63028 .71539 L
.60422 .72268 L
.57817 .72651 L
.55211 .7214 L
.53145 .70844 L
.52926 .68239 L
.54239 .65633 L
.55211 .63983 L
.56625 .63028 L
.57817 .6193 L
.60119 .60422 L
.60422 .60227 L
.63028 .58726 L
.65315 .57817 L
.65633 .57701 L
s
1 0 0 r
.03 w
.24141 .24033 Mdot
0 0 1 r
.64872 .64417 Mdot
1 0 0 r
.79703 .00495 m
.79703 .25248 L
.87129 .25248 L
.87129 .00495 L
F
0 0 1 r
.89604 .00495 m
.89604 .00495 L
.9703 .00495 L
.9703 .00495 L
F
1 0 1 r
.04 w
.45059 .34198 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P000182000`400?l00000o`00003ooooooolQ
ooooo`00ool0000Po`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`00
00?o0000ooooooooool0hOoooolEool002Gooooo0Ol00001ooooo`0000?o0000ooooooooool0hOoo
oolEool002Gooooo0Ol00001ooooo`0000?o0000ooooooooool0hOoooolEool002Gooooo0Ol00001
ooooo`0000?o0000ooooooooool0hOoooolEool002Gooooo0Ol00001ooooo`0000?o0000oooooooo
ool0hOoooolEool002Gooooo0Ol00001ooooo`0000?o0000ooooooooool0hOoooolEool002Gooooo
0Ol00001ooooo`0000?o0000ooooooooool0hOoooolEool002Gooooo0Ol00001ooooo`0000?o0000
ooooooooool0hOoooolEool002Gooooo0Ol00001ooooo`0000?o0000ooooooooool0hOoooolEool0
02Gooooo0Ol00001ooooo`0000?o0000ooooooooool0hOoooolEool002Gooooo0Ol00001ooooo`00
00?o0000ooooooooool0hOoooolEool002Gooooo0Ol00001ooooo`0000?o0000ooooooooool0hOoo
oolEool002Gooooo0Ol00001ooooo`0000?o0000ooooooooool0hOoooolEool002Gooooo0Ol00001
ooooo`0000?o0000ooooooooool0hOoooolEool002Gooooo0Ol00001ooooo`0000?o0000oooooooo
ool0hOoooolEool002Gooooo0Ol00001ooooo`0000?o0000ooooooooool0hOoooolEool002Gooooo
0Ol00001ooooo`0000?o0000ooooooooool0hOoooolEool002Gooooo0Ol00001ooooo`0000?o0000
ooooooooool0hOoooolEool002Gooooo0Ol00001ooooo`0000?o0000ooooooooool0hOoooolEool0
02Gooooo0Ol00001ooooo`0000?o0000ooooooooool0hOoooolEool002Gooooo0Ol00001ooooo`00
00?o0000ooooooooool0hOoooolEool002Gooooo0Ol00001ooooo`0000?o0000ooooooooool0hOoo
oolEool002Gooooo0Ol00001ooooo`0000?o0000ooooooooool0hOoooolEool002Gooooo0Ol00001
ooooo`0000?o0000ooooooooool0hOoooolEool002Gooooo0Ol00001ooooo`0000?o0000oooooooo
ool0hOoooolEool002Gooooo0Ol00001ooooo`0000?o0000ooooooooool0hOoooolEool002Gooooo
0Ol00001ooooo`0000?o0000ooooooooool0hOoooolEool002Gooooo0Ol00001ooooo`0000?o0000
ooooooooool0hOoooolEool002Gooooo0Ol00001ooooo`0000?o0000ooooooooool0hOoooolEool0
02Gooooo0Ol00001ooooo`0000?o0000ooooooooool0hOoooolEool002Gooooo0Ol00001ooooo`00
00?o0000ooooooooool0hOoooolEool002Gooooo0Ol00001ooooo`0000?o0000ooooooooool0hOoo
oolEool002Gooooo0Ol00001ooooo`0000?o0000ooooooooool01_ooool2oomo0=Wooooo5Ooo000U
ooooo`7o00000Oooool00003o`000?oooooooooo00Gooooo1?ooO`0Cooooo`;oogl0`ooooolEool0
02Gooooo0Ol00001ooooo`0000?o0000ooooooooool01Oooool4oomo01;ooooo1?ooO`0Booooo`;o
ogl0[_oooolEool002Gooooo0Ol00001ooooo`0000?o0000ooooooooool01Oooool3oomo01?ooooo
1?ooO`0Aooooo`Coogl0[OoooolEool002Gooooo0Ol00001ooooo`0000?o0000ooooooooool01?oo
ool4oomo01Cooooo0_ooO`0Booooo`Coogl0[OoooolEool002Gooooo0Ol00001ooooo`0000?o0000
ooooooooool01?ooool4oomo02Wooooo0_ooO`2^oooooaGoo`009Oooool1o`00007ooooo00000ol0
003oooooooooo`05ooooo`;oogl0f_oooolEool002Gooooo0Ol00001ooooo`0000?o0000oooooooo
ool0hOoooolEool002Gooooo0Ol00001ooooo`0000?o0000ooooooooool0hOoooolEool002Gooooo
0Ol00001ooooo`0000?o0000ooooooooool0hOoooolEool002Gooooo0Ol00001ooooo`0000?o0000
ooooooooool0hOoooolEool002Gooooo0Ol00001ooooo`0000?o0000ooooooooool0hOoooolEool0
02Gooooo0Ol00001ooooo`0000?o0000ooooooooool0hOoooolEool002Gooooo0Ol00001ooooo`00
00?o0000ooooooooool0hOoooolEool002Gooooo0Ol00001ooooo`0000?o0000ooooooooool0:_oo
ool6ool00;7ooooo5Ooo000Uooooo`7o00000Oooool00003o`000?oooooooooo02Wooooo00?oo`00
ooooooooool01?ooool5ool00:cooooo5Ooo000Uooooo`7o00000Oooool00003o`000?oooooooooo
02Oooooo0_oo000<ooooo`Coo`00Z?oooolEool002Gooooo0Ol00001ooooo`0000?o0000oooooooo
ool09_ooool00ooo003oooooooooo`0@ooooo`Coo`00Y?oooolEool002Gooooo0Ol00001ooooo`00
00?o0000ooooooooool09?ooool00oooO`3oo`00ooooo`09ooooo`;oogl02oooool3ool00:7ooooo
5Ooo000Uooooo`7o00000Oooool00003o`000?oooooooooo02?ooooo00Coogl0ool00?ooO`3oogl0
2?ooool4oomo00gooooo00?oo`00ooooooooool0W_oooolEool002Gooooo0Ol00001ooooo`0000?o
0000ooooooooool08oooool01?ooO`3oo`00oomo0?ooO`08ooooo`Coogl03_ooool2ool009kooooo
5Ooo000Uooooo`7o00000Oooool00003o`000?oooooooooo02Cooooo00?oogl0ool00?ooool02Ooo
ool2oomo017ooooo0_oo002LoooooaGoo`009Oooool1o`00007ooooo00000ol0003oooooooooo`0U
ooooo`03ool00?oooooooooo01gooooo0_oo002JoooooaGoo`009Oooool1o`00007ooooo00000ol0
003oooooooooo`0Uooooo`03ool00?oooooooooo01oooooo0_oo002HoooooaGoo`009Oooool1o`00
007ooooo00000ol0003oooooooooo`0Vooooo`03ool00?oooooooooo017ooooo0_ooO`0=ooooo`;o
o`001?ooool2oomo00Oooooo0_ooO`27oooooaGoo`009Oooool1o`00007ooooo00000ol0003ooooo
ooooo`0Vooooo`03ool00?oooooooooo00Gooooo0_ooO`09ooooo`Coogl03_ooool00ooo003ooooo
ooooo`04oomo00Gooooo1?ooO`26oooooaGoo`009Oooool1o`00007ooooo00000ol0003ooooooooo
o`0Vooooo`03ool00?oooooooooo00Cooooo1?ooO`08ooooo`Coogl03oooool00ooo003ooooooomo
0003oomo00Gooooo1?ooO`26oooooaGoo`009Oooool1o`00007ooooo00000ol0003oooooooooo`0W
ooooo`03ool00?oooooooooo00?ooooo1?ooO`09ooooo`;oogl04Oooool01?oo003ooooooomo0?oo
O`07ooooo`?oogl0Q_oooolEool002Gooooo0Ol00001ooooo`0000?o0000ooooooooool09oooool0
0ooo003oooooooooo`04ooooo`;oogl07_ooool00ooo003oooooooooo`07ooooo`Coogl0QOoooolE
ool002Gooooo0Ol00001ooooo`0000?o0000ooooooooool0:?ooool00ooo003oooooooooo`0Toooo
o`03ool00?oooooooooo00Kooooo1?ooO`25oooooaGoo`009Oooool1o`00007ooooo00000ol0003o
ooooooooo`0Yooooo`03ool00?oooooooooo02Cooooo0_oo00000oooooooogl0oomo0004ooooo`;o
ogl0Q_oooolEool002Gooooo0Ol00001ooooo`0000?o0000ooooooooool0:_ooool00ooo003ooooo
ooooo`0Cooooo`Coo`003_ooool01?oo003oogl0oomo0?ooO`2;oooooaGoo`009Oooool1o`00007o
oooo00000ol0003oooooooooo`0[ooooo`03ool00?oooooooooo017ooooo1_oo000=ooooo`04oomo
0?oo003oo`00oomo08_ooooo5Ooo000Uooooo`7o00000Oooool00003o`000?oooooooooo02cooooo
00?oo`00ooooooooool02?ooool2oomo00Gooooo2?oo000=ooooo`;oogl000?oo`00ooooooooool0
ROoooolEool002Gooooo0Ol00001ooooo`0000?o0000ooooooooool0;Oooool00ooo003ooooooooo
o`06ooooo`Coogl01?ooool8ool0013ooooo00?oo`00ooooooooool0R?oooolEool002Gooooo0Ol0
0001ooooo`0000?o0000ooooooooool0:oooool2oomo0003oooooooo003ooooo00Kooooo1?ooO`04
ooooo`Soo`004Oooool00ooo003oooooooooo`27oooooaGoo`009Oooool1o`00007ooooo00000ol0
003oooooooooo`0Zooooo`Coogl000?oooooool00?ooool01_ooool2oomo00Gooooo2?oo000;oooo
o`;oogl01Oooool00ooo003oooooooooo`09ooooo`;oogl0NooooolEool002Gooooo0Ol00001oooo
o`0000?o0000ooooooooool0:_ooool4oomo00;ooooo00?oo`00ooooooooool03?ooool6ool000_o
oooo1?ooO`04ooooo`03ool00?oooooooooo00Sooooo1?ooO`1joooooaGoo`009Oooool1o`00007o
oooo00000ol0003oooooooooo`0[ooooo`;oogl01?ooool00ooo003oooooooooo`0<ooooo`Coo`00
3?ooool4oomo00Gooooo00?oo`00ooooooooool01oooool4oomo07[ooooo5Ooo000Uooooo`7o0000
0Oooool00003o`000?oooooooooo03;ooooo0_oo000Mooooo`;oogl01oooool00ooo003ooooooooo
o`07ooooo`;oogl0]Oooool1o`00007ooooo00000ol0003oooooooooo`0dooooo`03ool00?oooooo
oooo02Cooooo00?oo`00ooooooooool0_Oooool1o`00007ooooo00000ol0003oooooooooo`0eoooo
o`03ool00?oooooooooo02Cooooo00?oo`00ooooooooool0_?ooool1o`00007ooooo00000ol0003o
ooooooooo`0fooooo`;oo`009Oooool00ooo003oooooooooo`2kooooo`7o00000Oooool00003o`00
0?oooooooooo03Sooooo0_oo00000oooO`3oooooooooo`02oomo01kooooo00?oo`00ooooooooool0
^oooool1o`00007ooooo00000ol0003oooooooooo`0hooooo`;oogl00_oo0004oomo01kooooo00?o
o`00ooooooooool0^_ooool1o`00007ooooo00000ol0003oooooooooo`0hooooo`Coogl00_oo0002
oomo01kooooo00?oo`00ooooooooool0^_ooool1o`00007ooooo00000ol0003oooooooooo`0ioooo
o`Googl000?oo`00ooooooooool07Oooool00ooo003oogl0oomo002jooooo`7o00000Oooool00003
o`000?oooooooooo03_ooooo1?ooO`02ool001gooooo00Coogl0ool00?ooO`3oogl0^Oooool1o`00
007ooooo00000ol0003oooooooooo`0looooo`;oogl00oooool2ool001_ooooo00Coogl0ool00?oo
O`3oogl0^Oooool1o`00007ooooo00000ol0003oooooooooo`13ooooo`;oo`006_ooool00oooO`3o
o`00ooooo`2iooooo`7o00000Oooool00003o`000?oooooooooo04Gooooo0_oo000Iooooo`03ool0
0?oooooooooo0;Sooooo0Ol00001ooooo`0000?o0000ooooooooool0Aoooool2ool001Gooooo0_oo
002kooooo`7o00000Oooool00003o`000?oooooooooo04Wooooo0ooo000@ooooo`;oo`00_Oooool1
o`00007ooooo00000ol0003oooooooooo`0aooooo`;oogl06Oooool3ool000cooooo00?oo`00oooo
ooooool0_Oooool1o`00007ooooo00000ol0003oooooooooo`0`ooooo`Coogl06oooool6ool000Co
oooo0_oo0030ooooo`7o00000Oooool00003o`000?oooooooooo033ooooo1?ooO`0Qooooo`Coo`00
`_ooool1o`00007ooooo00000ol0003oooooooooo`0aooooo`;oogl0j?ooool1o`00007ooooo0000
0ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLoooo
o`7o00000Oooool00003o`000?oooooooooo07cooooo1Ooo0?nJooooo`7o00000Oooool00003o`00
0?oooooooooo07_ooooo1ooo0?nIooooo`7o00000Oooool00003o`000?oooooooooo07[ooooo2Ooo
0?nHooooo`7o00000Oooool00003o`000?oooooooooo07Wooooo2ooo0?nGooooo`7o00000Oooool0
0003o`000?oooooooooo07Wooooo2ooo0?nGooooo`7o00000Oooool00003o`000?oooooooooo05Co
oooo0_ooO`0Sooooo`_oo`3oUoooool1o`00007ooooo00000ol0003oooooooooo`1Cooooo`Coogl0
8_ooool;ool0oiOooooo0Ol00001ooooo`0000?o0000ooooooooool0Doooool4oomo02;ooooo2ooo
0?nGooooo`7o00000Oooool00003o`000?oooooooooo05Cooooo0_ooO`0Tooooo`Woo`3oV?ooool1
o`00007ooooo00000ol0003oooooooooo`1kooooo`Ooo`3oVOooool1o`00007ooooo00000ol0003o
ooooooooo`1Sooooo`;oogl01?ooool2oomo017ooooo1Ooo0?nJooooo`7o00000Oooool00003o`00
0?oooooooooo06;ooooo1?ooO`02ooooo`Coogl0[oooool1o`00007ooooo00000ol0003ooooooooo
o`1Rooooo`Coogl00_ooool4oomo0:oooooo0Ol00001ooooo`0000?o0000ooooooooool0Hoooool2
oomo00Cooooo0_ooO`2`ooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00
007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0
oooooolLooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo0000
0ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLoooo
o`7o00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003ooooo
ooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Ooo
ool00003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooo
oacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`00
0?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol0
0001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo
0?oooooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`00
00?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?oo
ool1o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000oooo
ooooool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007o
oooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooo
oolLooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0
003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o
00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003ooooooooo
o`3ooooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool0
0003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooooaco
oooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oo
oooooooo0?oooooo1?ooool2oomo01Kooooo0Ol00001ooooo`0000?o0000ooooooooool0ooooool3
ooooo`Coogl05Oooool1o`00007ooooo00000ol0003oooooooooo`3oooooo`?ooooo1?ooO`0Eoooo
o`7o00000Oooool00003o`000?oooooooooo0?oooooo1?ooool2oomo01Kooooo0Ol00001ooooo`00
00?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?oo
ool1o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000oooo
ooooool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007o
oooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooo
oolLooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0
003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o
00000Oooool00003o`000?oooooooooo0;Gooooo0_ooO`1Tooooo`7o00000Oooool00003o`000?oo
oooooooo0;Cooooo1?ooO`1Sooooo`7o00000Oooool00003o`000?oooooooooo0;Cooooo1?ooO`1S
ooooo`7o00000Oooool00003o`000?oooooooooo0;Gooooo0_ooO`0eooooo`;oogl0;Oooool1o`00
007ooooo00000ol0003oooooooooo`3Tooooo`;oogl01Oooool4oomo02cooooo0Ol00001ooooo`00
00?o0000ooooooooool0hoooool4oomo00Cooooo1?ooO`0/ooooo`7o00000Oooool00003o`000?oo
oooooooo0<?ooooo0_ooO`0Nooooo`Coogl01Oooool2oomo02gooooo0Ol00001ooooo`0000?o0000
ooooooooool0`_ooool4oomo00_o003o4oooool2oomo03Gooooo0Ol00001ooooo`0000?o0000oooo
ooooool0`_ooool4o`00o`_ooooo0_l00?m8ooooo`7o00000Oooool00003o`000?oooooooooo0;ko
oooo1?l00?l00oooooooogl0oomo000>ooooo`;o003oA_ooool1o`00007ooooo00000ol0003ooooo
ooooo`2iooooo`;oogl00ol00?lGooooo`;o003o2Oooool2oomo03Wooooo0Ol00001ooooo`0000?o
0000ooooooooool0]oooool4o`00o`03oomo0?oooooooooo01Wooooo0_l00?l6ooooo`Coogl0>?oo
ool1o`00007ooooo00000ol0003oooooooooo`2dooooo`?o003o00?ooooooomo0?ooO`000_ooO`0L
ooooo`03o`00oooooooooooo00Cooooo1?ooO`03ooooo`;oogl0<oooool1o`00007ooooo00000ol0
003oooooooooo`2booooo`;o003o0oooO`02ooooo`;oogl04oooool2oomo00Sooooo00?o003ooooo
ooooool01Oooool2oomo00?ooooo1?ooO`0booooo`7o00000Oooool00003o`000?oooooooooo0;3o
oooo0_l00?l00oooooooogl0oomo0002oomo00Kooooo0_ooO`0>ooooo`Coogl01oooool00ol00?oo
ooooooooo`0:ooooo`Coogl0<_ooool1o`00007ooooo00000ol0003oooooooooo`2^ooooo`;o003o
1?ooool2oomo00Kooooo1?ooO`0=ooooo`Coogl01oooool00ol00?ooooooooooo`0;ooooo`;oogl0
<oooool1o`00007ooooo00000ol0003oooooooooo`2;ooooo`;oogl08?ooool00ol00?oooooooooo
o`04ooooo`;oogl01_ooool4oomo00kooooo0_ooO`09ooooo`03o`00oooooooooooo03oooooo0Ol0
0001ooooo`0000?o0000ooooooooool0R_ooool4oomo01gooooo0_l00?l6ooooo`Coogl01_ooool2
oomo01[ooooo00?o003oooooooooool0?oooool1o`00007ooooo00000ol0003oooooooooo`2:oooo
o`Coogl07?ooool00ol00?ooooooooooo`06ooooo`Coogl08_ooool00ol00?ooooooooooo`0ooooo
o`7o00000Oooool00003o`000?oooooooooo08_ooooo0_ooO`0Kooooo`;o003o2_ooool2oomo02?o
oooo00?o003oooooooooool0?oooool1o`00007ooooo00000ol0003oooooooooo`2Fooooo`;oogl0
3_ooool2o`00ob[ooooo0_ooO`05ooooo`03o`00oooooooooooo03oooooo0Ol00001ooooo`0000?o
0000ooooooooool0UOooool4oomo00cooooo00Co003oooooooooO`3oogl0:?ooool4oomo00?ooooo
00?o003oooooooooool0@?ooool1o`00007ooooo00000ol0003oooooooooo`2Eooooo`Coogl02_oo
ool2o`00o`03ooooooooO`3oogl000;oogl09oooool4oomo00?ooooo00?o003oooooooooool0@?oo
ool1o`00007ooooo00000ol0003oooooooooo`2Fooooo`;oogl02_ooool01?l00?oooooooooooooo
ool4oomo02Sooooo0_ooO`04ooooo`03o`00oooooooooooo043ooooo0Ol00001ooooo`0000?o0000
ooooooooool0XOooool00ol00?ooooooooooo`03ooooo`;oogl0;_ooool00ol00?ooooooooooo`11
ooooo`7o00000Oooool00003o`000?oooooooooo0:3ooooo00?o003oooooooooool0<oooool00ol0
0?ooooooooooo`0Booooo`;oogl0;_ooool1o`00007ooooo00000ol0003oooooooooo`2Nooooo`;o
003o=Oooool00ol00?ooooooooooo`0Booooo`Coogl0;Oooool1o`00007ooooo00000ol0003ooooo
ooooo`2Mooooo`03o`00oooooooooooo01Gooooo1?l00?lLooooo`03o`00ooooO`3oogl001;ooooo
1?ooO`0]ooooo`7o00000Oooool00003o`000?oooooooooo09cooooo00?o003oooooooooool05Ooo
ool6o`00oa[ooooo00?o003ooomo0?ooO`000_ooO`0Booooo`;oogl0;_ooool1o`00007ooooo0000
0ol0003oooooooooo`2Kooooo`03o`00oooooooooooo01Gooooo2?l00?lHooooo`03o`00oooooooo
ogl000?oogl0@_ooool1o`00007ooooo00000ol0003oooooooooo`2Kooooo`03o`00oooooooooooo
01Gooooo2?l00?lGooooo`04o`00ooooooooooooooooo`;oogl0@oooool1o`00007ooooo00000ol0
003oooooooooo`2Jooooo`03o`00oooooooooooo01Kooooo2?l00?lFooooo`03o`00oooooooooooo
04Oooooo0Ol00001ooooo`0000?o0000ooooooooool0VOooool00ol00?ooooooooooo`0<ooooo`;o
ogl02?ooool00oooO`3o003oo`00o`06o`00oaGooooo00?o003oooooooooool00_ooO`16ooooo`7o
00000Oooool00003o`000?oooooooooo09Wooooo00?o003oooooooooool02_ooool5oomo00Oooooo
0_ooO`06o`00oa?ooooo0_ooO`000ol00?ooooooooooo`04oomo04Gooooo0Ol00001ooooo`0000?o
0000ooooooooool0V?ooool00ol00?ooooooooooo`0:ooooo`Koogl02?ooool2oomo00Co003o4ooo
ool2oomo00;o003o0_ooool4oomo04Gooooo0Ol00001ooooo`0000?o0000ooooooooool0V?ooool0
0ol00?ooooooooooo`0:ooooo`Googl08_ooool01?ooO`3o003ooomo0?ooO`03ooooo`;oogl0A_oo
ool1o`00007ooooo00000ol0003oooooooooo`1fooooo`;oogl07oooool00ol00?ooooooooooo`0<
ooooo`;oogl09?ooool00ol00?ooogl0oomo001<ooooo`7o00000Oooool00003o`000?oooooooooo
07Gooooo1?ooO`0Nooooo`03o`00oooooooooooo037ooooo00?o003oooooooooool0COooool1o`00
007ooooo00000ol0003oooooooooo`1eooooo`Coogl02_ooool2oomo017ooooo00?o003ooooooooo
ool0<Oooool00ol00?ooooooooooo`1>ooooo`7o00000Oooool00003o`000?oooooooooo07Kooooo
0_ooO`0:ooooo`Coogl03oooool00ol00?ooooooooooo`0Hooooo`;oogl05oooool00ol00?oooooo
ooooo`1?ooooo`7o00000Oooool00003o`000?oooooooooo08;ooooo1?ooO`0?ooooo`03o`00oooo
oooooooo01Oooooo1?ooO`0Dooooo`;o003oD_ooool1o`00007ooooo00000ol0003oooooooooo`23
ooooo`;oogl03oooool00ol00?ooooooooooo`0Booooo`;oogl01?ooool4oomo017ooooo0ol00?mD
ooooo`7o00000Oooool00003o`000?oooooooooo09Cooooo00?o003oooooooooool04Oooool4oomo
00Cooooo0_ooO`0@ooooo`;o003oEoooool1o`00007ooooo00000ol0003oooooooooo`2Dooooo`03
o`00oooooooooooo017ooooo1?ooO`0Eooooo`03o`00oooooooooooo05Oooooo0Ol00001ooooo`00
00?o0000ooooooooool0U?ooool00ol00?ooooooooooo`0Booooo`;oogl05?ooool2o`00oe[ooooo
0Ol00001ooooo`0000?o0000ooooooooool0U?ooool00ol00?ooooooooooo`0Vooooo`;o003oG?oo
ool1o`00007ooooo00000ol0003oooooooooo`2Eooooo`03o`00oooooooooooo02Cooooo00?o003o
ooooooooool0G?ooool1o`00007ooooo00000ol0003oooooooooo`2Eooooo`03o`00oooooooooooo
02;ooooo0_l00?mOooooo`7o00000Oooool00003o`000?oooooooooo09Gooooo00?o003ooooooooo
ool08?ooool2o`00of7ooooo0Ol00001ooooo`0000?o0000ooooooooool0Q?ooool2oomo00oooooo
0_l00?lOooooo`;o003oHoooool1o`00007ooooo00000ol0003oooooooooo`23ooooo`Coogl04?oo
ool2o`00oa[ooooo0ol00?mUooooo`7o00000Oooool00003o`000?oooooooooo08?ooooo1?ooO`0B
ooooo`;o003o5?ooool4o`00ofSooooo0Ol00001ooooo`0000?o0000ooooooooool0Q?ooool2oomo
01Gooooo0ol00?l>ooooo`?o003o0oooool2oomo06Oooooo0Ol00001ooooo`0000?o0000oooooooo
ool0W_ooool3o`00o`Gooooo1_l00?l5ooooo`Coogl0I_ooool1o`00007ooooo00000ol0003ooooo
ooooo`2Qooooo`Go003o2oooool4oomo06Kooooo0Ol00001ooooo`0000?o0000ooooooooool0/_oo
ool2oomo06Oooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool0
0003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003oooooooooo`1kooooo`;o
ogl0W_ooool1o`00007ooooo00000ol0003oooooooooo`1jooooo`Coogl0WOooool1o`00007ooooo
00000ol0003oooooooooo`1jooooo`Coogl08?ooool2oomo07_ooooo0Ol00001ooooo`0000?o0000
ooooooooool0Noooool2oomo023ooooo1?ooO`1jooooo`7o00000Oooool00003o`000?oooooooooo
09gooooo1?ooO`1jooooo`7o00000Oooool00003o`000?oooooooooo093ooooo0_ooO`0<ooooo`;o
ogl0Noooool1o`00007ooooo00000ol0003oooooooooo`2?ooooo`Coogl0R?ooool1o`00007ooooo
00000ol0003oooooooooo`2?ooooo`Coogl0R?ooool1o`00007ooooo00000ol0003oooooooooo`2@
ooooo`;oogl08oooool2oomo06Cooooo0Ol00001ooooo`0000?o0000ooooooooool0]?ooool4oomo
06?ooooo0Ol00001ooooo`0000?o0000ooooooooool0]?ooool4oomo06?ooooo0Ol00001ooooo`00
00?o0000ooooooooool0]Oooool2oomo06Cooooo0Ol00001ooooo`0000?o0000ooooooooool0oooo
oolLooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0
003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o
00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003ooooooooo
o`3ooooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool0
0003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooooaco
oooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oo
oooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001
ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo0?oo
oooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o
0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1
o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000oooooooo
ool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo
00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolL
ooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003o
ooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o0000
0Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3o
oooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003
o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo
0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oooooo
oooo0?oooooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001oooo
o`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo
7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000
ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo08kooooo0_ooO`2;oooo
o`7o00000Oooool00003o`000?oooooooooo08gooooo1?ooO`2:ooooo`7o00000Oooool00003o`00
0?oooooooooo08gooooo1?ooO`2:ooooo`7o00000Oooool00003o`000?oooooooooo08kooooo0_oo
O`2;ooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0
003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o
00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003ooooooooo
o`3ooooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool0
0003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooooaco
oooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oo
oooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001
ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo0?oo
oooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o
0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1
o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000oooooooo
ool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo
00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolL
ooooo`7o00000Oooool00?oo00008?l00001ooooo`00\
\>"],
  ImageRangeCache->{{{0, 287}, {287, 0}} -> {-1.01089, -1.01089, 0.00704453, \
0.00704453}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.49505 0.5 0.49505 [
[ 0 0 -0.125 0 ]
[ 0 0 -0.125 0 ]
[ 0 1 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
0 0 m
1 0 L
s
0 0 m
0 1 L
s
0 1 m
1 1 L
s
1 0 m
1 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
1 .5 0 r
.015 w
.03175 .1355 Mdot
.03435 .12523 Mdot
.11137 .12765 Mdot
.14107 .18841 Mdot
.16218 .24538 Mdot
.17294 .21053 Mdot
.18267 .18577 Mdot
.18434 .1304 Mdot
.18553 .30956 Mdot
.20401 .239 Mdot
.21247 .27571 Mdot
.21687 .20845 Mdot
.22376 .2799 Mdot
.22832 .27485 Mdot
.29063 .20974 Mdot
.29686 .25079 Mdot
.30487 .22936 Mdot
.30683 .34623 Mdot
.32055 .20902 Mdot
.32574 .21979 Mdot
.34472 .28521 Mdot
.35998 .36393 Mdot
.36335 .24976 Mdot
.3794 .36608 Mdot
.42386 .66992 Mdot
.44391 .74519 Mdot
.45059 .34198 Mdot
.47208 .67586 Mdot
.47436 .71381 Mdot
.49778 .59825 Mdot
.50874 .91643 Mdot
.51516 .76219 Mdot
.53655 .61374 Mdot
.56563 .75219 Mdot
.59189 .65665 Mdot
.59581 .61604 Mdot
.59923 .6556 Mdot
.60292 .68499 Mdot
.62656 .67779 Mdot
.63555 .72451 Mdot
.63919 .652 Mdot
.64169 .6004 Mdot
.64246 .58611 Mdot
.64496 .54267 Mdot
.64608 .77288 Mdot
.65077 .64308 Mdot
.66065 .57816 Mdot
.67474 .59169 Mdot
.69296 .563 Mdot
.72815 .65902 Mdot
.73169 .58879 Mdot
.74669 .61318 Mdot
.74821 .65474 Mdot
.75963 .63781 Mdot
.79673 .57809 Mdot
.80925 .55852 Mdot
.81525 .58444 Mdot
.83417 .62985 Mdot
.83598 .55526 Mdot
.91595 .49319 Mdot
1 0 0 r
.005 w
.16128 .17044 m
.18734 .17269 L
.21339 .17909 L
.2345 .18734 L
.23945 .19126 L
.2655 .20415 L
.27874 .21339 L
.29156 .22295 L
.31204 .23945 L
.31761 .24532 L
.33549 .2655 L
.34367 .28341 L
.34499 .29156 L
.34367 .29798 L
.31761 .3104 L
.29156 .30711 L
.2655 .30014 L
.24507 .29156 L
.23945 .28747 L
.21339 .27402 L
.20155 .2655 L
.18734 .25472 L
.16884 .23945 L
.16128 .2313 L
.14618 .21339 L
.13806 .18734 L
.16128 .17044 L
s
0 0 1 r
.65633 .57701 m
.68239 .56842 L
.70844 .56313 L
.7345 .56168 L
.76055 .5752 L
.76359 .57817 L
.76859 .60422 L
.76055 .62333 L
.75627 .63028 L
.7345 .65485 L
.73298 .65633 L
.70844 .6775 L
.69922 .68239 L
.68239 .69294 L
.65633 .70579 L
.64983 .70844 L
.63028 .71539 L
.60422 .72268 L
.57817 .72651 L
.55211 .7214 L
.53145 .70844 L
.52926 .68239 L
.54239 .65633 L
.55211 .63983 L
.56625 .63028 L
.57817 .6193 L
.60119 .60422 L
.60422 .60227 L
.63028 .58726 L
.65315 .57817 L
.65633 .57701 L
s
1 0 0 r
.03 w
.24141 .24033 Mdot
0 0 1 r
.64872 .64417 Mdot
1 0 0 r
.79703 .00495 m
.79703 .00495 L
.87129 .00495 L
.87129 .00495 L
F
0 0 1 r
.89604 .00495 m
.89604 .25248 L
.9703 .25248 L
.9703 .00495 L
F
1 0 1 r
.04 w
.47208 .67586 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P000182000`400?l00000o`00003ooooooolQ
ooooo`00ool0000Po`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`00
00?o0000ooooooooool0o_oooolEo`00o`Sooooo0Ol00001ooooo`0000?o0000ooooooooool0o_oo
oolEo`00o`Sooooo0Ol00001ooooo`0000?o0000ooooooooool0o_oooolEo`00o`Sooooo0Ol00001
ooooo`0000?o0000ooooooooool0o_oooolEo`00o`Sooooo0Ol00001ooooo`0000?o0000oooooooo
ool0o_oooolEo`00o`Sooooo0Ol00001ooooo`0000?o0000ooooooooool0o_oooolEo`00o`Sooooo
0Ol00001ooooo`0000?o0000ooooooooool0o_oooolEo`00o`Sooooo0Ol00001ooooo`0000?o0000
ooooooooool0o_oooolEo`00o`Sooooo0Ol00001ooooo`0000?o0000ooooooooool0o_oooolEo`00
o`Sooooo0Ol00001ooooo`0000?o0000ooooooooool0o_oooolEo`00o`Sooooo0Ol00001ooooo`00
00?o0000ooooooooool0o_oooolEo`00o`Sooooo0Ol00001ooooo`0000?o0000ooooooooool0o_oo
oolEo`00o`Sooooo0Ol00001ooooo`0000?o0000ooooooooool0o_oooolEo`00o`Sooooo0Ol00001
ooooo`0000?o0000ooooooooool0o_oooolEo`00o`Sooooo0Ol00001ooooo`0000?o0000oooooooo
ool0o_oooolEo`00o`Sooooo0Ol00001ooooo`0000?o0000ooooooooool0o_oooolEo`00o`Sooooo
0Ol00001ooooo`0000?o0000ooooooooool0o_oooolEo`00o`Sooooo0Ol00001ooooo`0000?o0000
ooooooooool0o_oooolEo`00o`Sooooo0Ol00001ooooo`0000?o0000ooooooooool0o_oooolEo`00
o`Sooooo0Ol00001ooooo`0000?o0000ooooooooool0o_oooolEo`00o`Sooooo0Ol00001ooooo`00
00?o0000ooooooooool0o_oooolEo`00o`Sooooo0Ol00001ooooo`0000?o0000ooooooooool0o_oo
oolEo`00o`Sooooo0Ol00001ooooo`0000?o0000ooooooooool0o_oooolEo`00o`Sooooo0Ol00001
ooooo`0000?o0000ooooooooool0o_oooolEo`00o`Sooooo0Ol00001ooooo`0000?o0000oooooooo
ool0o_oooolEo`00o`Sooooo0Ol00001ooooo`0000?o0000ooooooooool0o_oooolEo`00o`Sooooo
0Ol00001ooooo`0000?o0000ooooooooool0o_oooolEo`00o`Sooooo0Ol00001ooooo`0000?o0000
ooooooooool0o_oooolEo`00o`Sooooo0Ol00001ooooo`0000?o0000ooooooooool0o_oooolEo`00
o`Sooooo0Ol00001ooooo`0000?o0000ooooooooool0o_oooolEo`00o`Sooooo0Ol00001ooooo`00
00?o0000ooooooooool0o_oooolEo`00o`Sooooo0Ol00001ooooo`0000?o0000ooooooooool0o_oo
oolEo`00o`Sooooo0Ol00001ooooo`0000?o0000ooooooooool01_ooool2oomo0?Kooooo5Ol00?l8
ooooo`7o00000Oooool00003o`000?oooooooooo00Gooooo1?ooO`0Cooooo`;oogl0h?oooolEo`00
o`Sooooo0Ol00001ooooo`0000?o0000ooooooooool01Oooool4oomo01;ooooo1?ooO`0Booooo`;o
ogl0booooolEo`00o`Sooooo0Ol00001ooooo`0000?o0000ooooooooool01Oooool3oomo01?ooooo
1?ooO`0Aooooo`Coogl0b_oooolEo`00o`Sooooo0Ol00001ooooo`0000?o0000ooooooooool01?oo
ool4oomo01Cooooo0_ooO`0Booooo`Coogl0b_oooolEo`00o`Sooooo0Ol00001ooooo`0000?o0000
ooooooooool01?ooool4oomo02Wooooo0_ooO`3;oooooaGo003o2?ooool1o`00007ooooo00000ol0
003oooooooooo`05ooooo`;oogl0mooooolEo`00o`Sooooo0Ol00001ooooo`0000?o0000oooooooo
ool0o_oooolEo`00o`Sooooo0Ol00001ooooo`0000?o0000ooooooooool0o_oooolEo`00o`Sooooo
0Ol00001ooooo`0000?o0000ooooooooool0o_oooolEo`00o`Sooooo0Ol00001ooooo`0000?o0000
ooooooooool0o_oooolEo`00o`Sooooo0Ol00001ooooo`0000?o0000ooooooooool0o_oooolEo`00
o`Sooooo0Ol00001ooooo`0000?o0000ooooooooool0o_oooolEo`00o`Sooooo0Ol00001ooooo`00
00?o0000ooooooooool0o_oooolEo`00o`Sooooo0Ol00001ooooo`0000?o0000ooooooooool0:_oo
ool6ool00<kooooo5Ol00?l8ooooo`7o00000Oooool00003o`000?oooooooooo02Wooooo00?oo`00
ooooooooool01?ooool5ool00<Wooooo5Ol00?l8ooooo`7o00000Oooool00003o`000?oooooooooo
02Oooooo0_oo000<ooooo`Coo`00aOoooolEo`00o`Sooooo0Ol00001ooooo`0000?o0000oooooooo
ool09_ooool00ooo003oooooooooo`0@ooooo`Coo`00`OoooolEo`00o`Sooooo0Ol00001ooooo`00
00?o0000ooooooooool09?ooool00oooO`3oo`00ooooo`09ooooo`;oogl02oooool3ool00;kooooo
5Ol00?l8ooooo`7o00000Oooool00003o`000?oooooooooo02?ooooo00Coogl0ool00?ooO`3oogl0
2?ooool4oomo00gooooo00?oo`00ooooooooool0^ooooolEo`00o`Sooooo0Ol00001ooooo`0000?o
0000ooooooooool08oooool01?ooO`3oo`00oomo0?ooO`08ooooo`Coogl03_ooool2ool00;_ooooo
5Ol00?l8ooooo`7o00000Oooool00003o`000?oooooooooo02Cooooo00?oogl0ool00?ooool02Ooo
ool2oomo017ooooo0_oo002ioooooaGo003o2?ooool1o`00007ooooo00000ol0003oooooooooo`0U
ooooo`03ool00?oooooooooo01gooooo0_oo002goooooaGo003o2?ooool1o`00007ooooo00000ol0
003oooooooooo`0Uooooo`03ool00?oooooooooo01oooooo0_oo002eoooooaGo003o2?ooool1o`00
007ooooo00000ol0003oooooooooo`0Vooooo`03ool00?oooooooooo017ooooo0_ooO`0=ooooo`;o
o`001?ooool2oomo00Oooooo0_ooO`2ToooooaGo003o2?ooool1o`00007ooooo00000ol0003ooooo
ooooo`0Vooooo`03ool00?oooooooooo00Gooooo0_ooO`09ooooo`Coogl03_ooool00ooo003ooooo
ooooo`04oomo00Gooooo1?ooO`2SoooooaGo003o2?ooool1o`00007ooooo00000ol0003ooooooooo
o`0Vooooo`03ool00?oooooooooo00Cooooo1?ooO`08ooooo`Coogl03oooool00ooo003ooooooomo
0003oomo00Gooooo1?ooO`2SoooooaGo003o2?ooool1o`00007ooooo00000ol0003oooooooooo`0W
ooooo`03ool00?oooooooooo00?ooooo1?ooO`09ooooo`;oogl04Oooool01?oo003ooooooomo0?oo
O`07ooooo`?oogl0XooooolEo`00o`Sooooo0Ol00001ooooo`0000?o0000ooooooooool09oooool0
0ooo003oooooooooo`04ooooo`;oogl07_ooool00ooo003oooooooooo`07ooooo`Coogl0X_oooolE
o`00o`Sooooo0Ol00001ooooo`0000?o0000ooooooooool0:?ooool00ooo003oooooooooo`0Toooo
o`03ool00?oooooooooo00Kooooo1?ooO`2RoooooaGo003o2?ooool1o`00007ooooo00000ol0003o
ooooooooo`0Yooooo`03ool00?oooooooooo02Cooooo0_oo00000oooooooogl0oomo0004ooooo`;o
ogl0XooooolEo`00o`Sooooo0Ol00001ooooo`0000?o0000ooooooooool0:_ooool00ooo003ooooo
ooooo`0Cooooo`Coo`003_ooool01?oo003oogl0oomo0?ooO`2XoooooaGo003o2?ooool1o`00007o
oooo00000ol0003oooooooooo`0[ooooo`03ool00?oooooooooo017ooooo1_oo000=ooooo`04oomo
0?oo003oo`00oomo0:Sooooo5Ol00?l8ooooo`7o00000Oooool00003o`000?oooooooooo02cooooo
00?oo`00ooooooooool02?ooool2oomo00Gooooo2?oo000=ooooo`;oogl000?oo`00ooooooooool0
Y_oooolEo`00o`Sooooo0Ol00001ooooo`0000?o0000ooooooooool0;Oooool00ooo003ooooooooo
o`06ooooo`Coogl01?ooool8ool0013ooooo00?oo`00ooooooooool0YOoooolEo`00o`Sooooo0Ol0
0001ooooo`0000?o0000ooooooooool0:oooool2oomo0003oooooooo003ooooo00Kooooo1?ooO`04
ooooo`Soo`004Oooool00ooo003oooooooooo`2ToooooaGo003o2?ooool1o`00007ooooo00000ol0
003oooooooooo`0Zooooo`Coogl000?oooooool00?ooool01_ooool2oomo00Gooooo2?oo000;oooo
o`;oogl01Oooool00ooo003oooooooooo`09ooooo`;oogl0V?oooolEo`00o`Sooooo0Ol00001oooo
o`0000?o0000ooooooooool0:_ooool4oomo00;ooooo00?oo`00ooooooooool03?ooool6ool000_o
oooo1?ooO`04ooooo`03ool00?oooooooooo00Sooooo1?ooO`2GoooooaGo003o2?ooool1o`00007o
oooo00000ol0003oooooooooo`0[ooooo`;oogl01?ooool00ooo003oooooooooo`0<ooooo`Coo`00
3?ooool4oomo00Gooooo00?oo`00ooooooooool01oooool4oomo09Oooooo5Ol00?l8ooooo`7o0000
0Oooool00003o`000?oooooooooo03;ooooo0_oo000Mooooo`;oogl01oooool00ooo003ooooooooo
o`07ooooo`;oogl0]Oooool1o`00007ooooo00000ol0003oooooooooo`0dooooo`03ool00?oooooo
oooo02Cooooo00?oo`00ooooooooool0_Oooool1o`00007ooooo00000ol0003oooooooooo`0eoooo
o`03ool00?oooooooooo02Cooooo00?oo`00ooooooooool0_?ooool1o`00007ooooo00000ol0003o
ooooooooo`0fooooo`;oo`009Oooool00ooo003oooooooooo`2kooooo`7o00000Oooool00003o`00
0?oooooooooo03Sooooo0_oo00000oooO`3oooooooooo`02oomo01kooooo00?oo`00ooooooooool0
^oooool1o`00007ooooo00000ol0003oooooooooo`0hooooo`;oogl00_oo0004oomo01kooooo00?o
o`00ooooooooool0^_ooool1o`00007ooooo00000ol0003oooooooooo`0hooooo`Coogl00_oo0002
oomo01kooooo00?oo`00ooooooooool0^_ooool1o`00007ooooo00000ol0003oooooooooo`0ioooo
o`Googl000?oo`00ooooooooool07Oooool00ooo003oogl0oomo002jooooo`7o00000Oooool00003
o`000?oooooooooo03_ooooo1?ooO`02ool001gooooo00Coogl0ool00?ooO`3oogl0^Oooool1o`00
007ooooo00000ol0003oooooooooo`0looooo`;oogl00oooool2ool001_ooooo00Coogl0ool00?oo
O`3oogl0^Oooool1o`00007ooooo00000ol0003oooooooooo`13ooooo`;oo`006_ooool00oooO`3o
o`00ooooo`2iooooo`7o00000Oooool00003o`000?oooooooooo04Gooooo0_oo000Iooooo`03ool0
0?oooooooooo0;Sooooo0Ol00001ooooo`0000?o0000ooooooooool0Aoooool2ool001Gooooo0_oo
002kooooo`7o00000Oooool00003o`000?oooooooooo04Wooooo0ooo000@ooooo`;oo`00_Oooool1
o`00007ooooo00000ol0003oooooooooo`0aooooo`;oogl06Oooool3ool000cooooo00?oo`00oooo
ooooool0_Oooool1o`00007ooooo00000ol0003oooooooooo`0`ooooo`Coogl06oooool6ool000Co
oooo0_oo0030ooooo`7o00000Oooool00003o`000?oooooooooo033ooooo1?ooO`0Qooooo`Coo`00
`_ooool1o`00007ooooo00000ol0003oooooooooo`0aooooo`;oogl0j?ooool1o`00007ooooo0000
0ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLoooo
o`7o00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003ooooo
ooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Ooo
ool00003o`000?oooooooooo07gooooo0_ooO`2Looooo`7o00000Oooool00003o`000?oooooooooo
07cooooo1?ooO`2Kooooo`7o00000Oooool00003o`000?oooooooooo05Cooooo0_ooO`0Vooooo`Co
ogl0Voooool1o`00007ooooo00000ol0003oooooooooo`1Cooooo`Coogl09_ooool2oomo09cooooo
0Ol00001ooooo`0000?o0000ooooooooool0Doooool4oomo0<Cooooo0Ol00001ooooo`0000?o0000
ooooooooool0E?ooool2oomo0<Gooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLoooo
o`7o00000Oooool00003o`000?oooooooooo06?ooooo0_ooO`04ooooo`;oogl0/?ooool1o`00007o
oooo00000ol0003oooooooooo`1Rooooo`Coogl00_ooool4oomo0:oooooo0Ol00001ooooo`0000?o
0000ooooooooool0H_ooool4oomo00;ooooo1?ooO`2_ooooo`7o00000Oooool00003o`000?oooooo
oooo06?ooooo0_ooO`04ooooo`;oogl0/?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooo
oacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`00
0?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol0
0001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo
0?oooooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`00
00?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?oo
ool1o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000oooo
ooooool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007o
oooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooo
oolLooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0
003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o
00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003ooooooooo
o`3ooooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool0
0003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooooaco
oooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oo
oooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001
ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo0?oo
oooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o
0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1
o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000oooooooo
ool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo
00000ol0003oooooooooo`3oooooo`Cooooo0_ooO`0Fooooo`7o00000Oooool00003o`000?oooooo
oooo0?oooooo0oooool4oomo01Gooooo0Ol00001ooooo`0000?o0000ooooooooool0ooooool3oooo
o`Coogl05Oooool1o`00007ooooo00000ol0003oooooooooo`3oooooo`Cooooo0_ooO`0Fooooo`7o
00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003ooooooooo
o`3ooooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool0
0003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooooaco
oooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oo
oooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001
ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo0?oo
oooo7?ooool1o`00007ooooo00000ol0003oooooooooo`2eooooo`;oogl0I?ooool1o`00007ooooo
00000ol0003oooooooooo`2dooooo`Coogl0Hoooool1o`00007ooooo00000ol0003oooooooooo`2d
ooooo`Coogl0Hoooool1o`00007ooooo00000ol0003oooooooooo`2eooooo`;oogl0=Oooool2oomo
02gooooo0Ol00001ooooo`0000?o0000ooooooooool0i?ooool2oomo00Gooooo1?ooO`0/ooooo`7o
00000Oooool00003o`000?oooooooooo0>?ooooo1?ooO`04ooooo`Coogl0;?ooool1o`00007ooooo
00000ol0003oooooooooo`33ooooo`;oogl07_ooool4oomo00Gooooo0_ooO`0]ooooo`7o00000Ooo
ool00003o`000?oooooooooo0<;ooooo1?ooO`0;o`00oa?ooooo0_ooO`0eooooo`7o00000Oooool0
0003o`000?oooooooooo0<;ooooo1?l00?l;ooooo`;o003oB?ooool1o`00007ooooo00000ol0003o
ooooooooo`2nooooo`Co003o00?ooooooomo0?ooO`003_ooool2o`00odKooooo0Ol00001ooooo`00
00?o0000ooooooooool0^Oooool2oomo00?o003o5oooool2o`00o`Wooooo0_ooO`0iooooo`7o0000
0Oooool00003o`000?oooooooooo0;Oooooo1?l00?l00oooO`3oooooooooo`0Iooooo`;o003o1_oo
ool4oomo03Sooooo0Ol00001ooooo`0000?o0000ooooooooool0]?ooool3o`00o`03ooooooooO`3o
ogl000;oogl07?ooool00ol00?ooooooooooo`04ooooo`Coogl00oooool2oomo03?ooooo0Ol00001
ooooo`0000?o0000ooooooooool0/_ooool2o`00o`?oogl00_ooool2oomo01?ooooo0_ooO`08oooo
o`03o`00oooooooooooo00Gooooo0_ooO`03ooooo`Coogl0<_ooool1o`00007ooooo00000ol0003o
ooooooooo`2`ooooo`;o003o00?ooooooomo0?ooO`000_ooO`06ooooo`;oogl03_ooool4oomo00Oo
oooo00?o003oooooooooool02_ooool4oomo03;ooooo0Ol00001ooooo`0000?o0000ooooooooool0
[_ooool2o`00o`Cooooo0_ooO`06ooooo`Coogl03Oooool4oomo00Oooooo00?o003oooooooooool0
2oooool2oomo03?ooooo0Ol00001ooooo`0000?o0000ooooooooool0Roooool2oomo023ooooo00?o
003oooooooooool01?ooool2oomo00Kooooo1?ooO`0>ooooo`;oogl02Oooool00ol00?oooooooooo
o`0oooooo`7o00000Oooool00003o`000?oooooooooo08[ooooo1?ooO`0Mooooo`;o003o1_ooool4
oomo00Kooooo0_ooO`0Jooooo`03o`00oooooooooooo03oooooo0Ol00001ooooo`0000?o0000oooo
ooooool0R_ooool4oomo01cooooo00?o003oooooooooool01_ooool4oomo02;ooooo00?o003ooooo
ooooool0?oooool1o`00007ooooo00000ol0003oooooooooo`2;ooooo`;oogl06oooool2o`00o`[o
oooo0_ooO`0Sooooo`03o`00oooooooooooo03oooooo0Ol00001ooooo`0000?o0000ooooooooool0
U_ooool2oomo00kooooo0_l00?lZooooo`;oogl01Oooool00ol00?ooooooooooo`0oooooo`7o0000
0Oooool00003o`000?oooooooooo09Gooooo1?ooO`0<ooooo`04o`00ooooooooogl0oomo02Sooooo
1?ooO`03ooooo`03o`00oooooooooooo043ooooo0Ol00001ooooo`0000?o0000ooooooooool0UOoo
ool4oomo00[ooooo0_l00?l00oooooooogl0oomo0002oomo02Oooooo1?ooO`03ooooo`03o`00oooo
oooooooo043ooooo0Ol00001ooooo`0000?o0000ooooooooool0U_ooool2oomo00[ooooo00Co003o
oooooooooooooooo1?ooO`0Xooooo`;oogl01?ooool00ol00?ooooooooooo`10ooooo`7o00000Ooo
ool00003o`000?oooooooooo0:7ooooo00?o003oooooooooool00oooool2oomo02kooooo00?o003o
ooooooooool0@Oooool1o`00007ooooo00000ol0003oooooooooo`2Pooooo`03o`00oooooooooooo
03?ooooo00?o003oooooooooool04_ooool2oomo02kooooo0Ol00001ooooo`0000?o0000oooooooo
ool0W_ooool2o`00ocGooooo00?o003oooooooooool04_ooool4oomo02gooooo0Ol00001ooooo`00
00?o0000ooooooooool0WOooool00ol00?ooooooooooo`0Eooooo`Co003o7?ooool00ol00?ooogl0
oomo000Booooo`Coogl0;Oooool1o`00007ooooo00000ol0003oooooooooo`2Looooo`03o`00oooo
oooooooo01Gooooo1_l00?lJooooo`03o`00ooooO`3oogl000;oogl04_ooool2oomo02kooooo0Ol0
0001ooooo`0000?o0000ooooooooool0Voooool00ol00?ooooooooooo`0Eooooo`So003o6?ooool0
0ol00?oooooooomo0003oomo04;ooooo0Ol00001ooooo`0000?o0000ooooooooool0Voooool00ol0
0?ooooooooooo`0Eooooo`So003o5oooool01?l00?ooooooooooooooool2oomo04?ooooo0Ol00001
ooooo`0000?o0000ooooooooool0V_ooool00ol00?ooooooooooo`0Fooooo`So003o5_ooool00ol0
0?ooooooooooo`17ooooo`7o00000Oooool00003o`000?oooooooooo09Wooooo00?o003ooooooooo
ool03?ooool2oomo00Sooooo00?oogl0o`00ool00?l01_l00?lEooooo`03o`00oooooooooooo00;o
ogl0A_ooool1o`00007ooooo00000ol0003oooooooooo`2Iooooo`03o`00oooooooooooo00[ooooo
1OooO`07ooooo`;oogl01_l00?lCooooo`;oogl000?o003oooooooooool01?ooO`15ooooo`7o0000
0Oooool00003o`000?oooooooooo09Sooooo00?o003oooooooooool02_ooool6oomo00Sooooo0_oo
O`04o`00oa?ooooo0_ooO`02o`00o`;ooooo1?ooO`15ooooo`7o00000Oooool00003o`000?oooooo
oooo08;ooooo1Ooo0?lAooooo`03o`00oooooooooooo00[ooooo1OooO`0Rooooo`04oomo0?l00?oo
ogl0oomo00?ooooo0_ooO`16ooooo`7o00000Oooool00003o`000?oooooooooo07Kooooo0_ooO`09
ooooo`Ooo`3o3oooool00ol00?ooooooooooo`0<ooooo`;oogl09?ooool00ol00?ooogl0oomo001<
ooooo`7o00000Oooool00003o`000?oooooooooo07Gooooo1?ooO`07ooooo`Woo`3o3_ooool00ol0
0?ooooooooooo`0aooooo`03o`00oooooooooooo04gooooo0Ol00001ooooo`0000?o0000oooooooo
ool0MOooool4oomo00Kooooo2ooo0?l<ooooo`03o`00oooooooooooo037ooooo00?o003ooooooooo
ool0C_ooool1o`00007ooooo00000ol0003oooooooooo`1fooooo`;oogl01oooool;ool0o`_ooooo
00?o003oooooooooool06?ooool2oomo01Oooooo00?o003oooooooooool0Coooool1o`00007ooooo
00000ol0003oooooooooo`1oooooo`_oo`3o2oooool00ol00?ooooooooooo`0Gooooo`Coogl05?oo
ool2o`00oe;ooooo0Ol00001ooooo`0000?o0000ooooooooool0Ooooool;ool0o`[ooooo00?o003o
ooooooooool04_ooool2oomo00Cooooo1?ooO`0Aooooo`?o003oE?ooool1o`00007ooooo00000ol0
003oooooooooo`1oooooo`_oo`3o2_ooool00ol00?ooooooooooo`0Aooooo`Coogl01?ooool2oomo
013ooooo0_l00?mGooooo`7o00000Oooool00003o`000?oooooooooo083ooooo2Ooo0?l;ooooo`03
o`00oooooooooooo017ooooo1?ooO`0Eooooo`03o`00oooooooooooo05Oooooo0Ol00001ooooo`00
00?o0000ooooooooool0POooool7ool0o`cooooo00?o003oooooooooool04_ooool2oomo01Cooooo
0_l00?mJooooo`7o00000Oooool00003o`000?oooooooooo08;ooooo1Ooo0?l=ooooo`03o`00oooo
oooooooo02Kooooo0_l00?mLooooo`7o00000Oooool00003o`000?oooooooooo09Gooooo00?o003o
ooooooooool09?ooool00ol00?ooooooooooo`1Looooo`7o00000Oooool00003o`000?oooooooooo
09Gooooo00?o003oooooooooool08_ooool2o`00oeoooooo0Ol00001ooooo`0000?o0000oooooooo
ool0UOooool00ol00?ooooooooooo`0Pooooo`;o003oHOooool1o`00007ooooo00000ol0003ooooo
ooooo`24ooooo`;oogl03oooool2o`00oaoooooo0_l00?mSooooo`7o00000Oooool00003o`000?oo
oooooooo08?ooooo1?ooO`0@ooooo`;o003o6_ooool3o`00ofGooooo0Ol00001ooooo`0000?o0000
ooooooooool0Poooool4oomo01;ooooo0_l00?lDooooo`Co003oJ?ooool1o`00007ooooo00000ol0
003oooooooooo`24ooooo`;oogl05Oooool3o`00o`kooooo0ol00?l3ooooo`;oogl0Ioooool1o`00
007ooooo00000ol0003oooooooooo`2Nooooo`?o003o1Oooool6o`00o`Gooooo1?ooO`1Vooooo`7o
00000Oooool00003o`000?oooooooooo0:7ooooo1Ol00?l;ooooo`Coogl0I_ooool1o`00007ooooo
00000ol0003oooooooooo`2booooo`;oogl0Ioooool1o`00007ooooo00000ol0003oooooooooo`3o
oooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003
o`000?oooooooooo07_ooooo0_ooO`2Nooooo`7o00000Oooool00003o`000?oooooooooo07[ooooo
1?ooO`2Mooooo`7o00000Oooool00003o`000?oooooooooo07[ooooo1?ooO`0Pooooo`;oogl0Nooo
ool1o`00007ooooo00000ol0003oooooooooo`1kooooo`;oogl08?ooool4oomo07[ooooo0Ol00001
ooooo`0000?o0000ooooooooool0WOooool4oomo07[ooooo0Ol00001ooooo`0000?o0000oooooooo
ool0T?ooool2oomo00cooooo0_ooO`1kooooo`7o00000Oooool00003o`000?oooooooooo08oooooo
1?ooO`28ooooo`7o00000Oooool00003o`000?oooooooooo08oooooo1?ooO`28ooooo`7o00000Ooo
ool00003o`000?oooooooooo093ooooo0_ooO`0Sooooo`;oogl0I?ooool1o`00007ooooo00000ol0
003oooooooooo`2dooooo`Coogl0Hoooool1o`00007ooooo00000ol0003oooooooooo`2dooooo`Co
ogl0Hoooool1o`00007ooooo00000ol0003oooooooooo`2eooooo`;oogl0I?ooool1o`00007ooooo
00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolL
ooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003o
ooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o0000
0Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3o
oooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003
o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo
0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oooooo
oooo0?oooooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001oooo
o`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo
7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000
ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00
007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0
oooooolLooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo0000
0ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLoooo
o`7o00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003ooooo
ooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Ooo
ool00003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooo
oacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`00
0?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol0
0001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo
0?oooooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`00
00?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?oo
ool1o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000oooo
ooooool0S_ooool2oomo08_ooooo0Ol00001ooooo`0000?o0000ooooooooool0SOooool4oomo08[o
oooo0Ol00001ooooo`0000?o0000ooooooooool0SOooool4oomo08[ooooo0Ol00001ooooo`0000?o
0000ooooooooool0S_ooool2oomo08_ooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolL
ooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003o
ooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o0000
0Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3o
oooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003
o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo
0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oooooo
oooo0?oooooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001oooo
o`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo
7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000
ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00
007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0
oooooolLooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo0000
0ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`00ool0000Po`00007ooooo0000\
\>"],
  ImageRangeCache->{{{0, 287}, {287, 0}} -> {-1.01089, -1.01089, 0.00704453, \
0.00704453}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.49505 0.5 0.49505 [
[ 0 0 -0.125 0 ]
[ 0 0 -0.125 0 ]
[ 0 1 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
0 0 m
1 0 L
s
0 0 m
0 1 L
s
0 1 m
1 1 L
s
1 0 m
1 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
1 .5 0 r
.015 w
.03175 .1355 Mdot
.03435 .12523 Mdot
.11137 .12765 Mdot
.14107 .18841 Mdot
.16218 .24538 Mdot
.17294 .21053 Mdot
.18267 .18577 Mdot
.18434 .1304 Mdot
.18553 .30956 Mdot
.20401 .239 Mdot
.21247 .27571 Mdot
.21687 .20845 Mdot
.22376 .2799 Mdot
.22832 .27485 Mdot
.29063 .20974 Mdot
.29686 .25079 Mdot
.30487 .22936 Mdot
.30683 .34623 Mdot
.32055 .20902 Mdot
.32574 .21979 Mdot
.34472 .28521 Mdot
.35998 .36393 Mdot
.36335 .24976 Mdot
.3794 .36608 Mdot
.42386 .66992 Mdot
.44391 .74519 Mdot
.45059 .34198 Mdot
.47208 .67586 Mdot
.47436 .71381 Mdot
.49778 .59825 Mdot
.50874 .91643 Mdot
.51516 .76219 Mdot
.53655 .61374 Mdot
.56563 .75219 Mdot
.59189 .65665 Mdot
.59581 .61604 Mdot
.59923 .6556 Mdot
.60292 .68499 Mdot
.62656 .67779 Mdot
.63555 .72451 Mdot
.63919 .652 Mdot
.64169 .6004 Mdot
.64246 .58611 Mdot
.64496 .54267 Mdot
.64608 .77288 Mdot
.65077 .64308 Mdot
.66065 .57816 Mdot
.67474 .59169 Mdot
.69296 .563 Mdot
.72815 .65902 Mdot
.73169 .58879 Mdot
.74669 .61318 Mdot
.74821 .65474 Mdot
.75963 .63781 Mdot
.79673 .57809 Mdot
.80925 .55852 Mdot
.81525 .58444 Mdot
.83417 .62985 Mdot
.83598 .55526 Mdot
.91595 .49319 Mdot
1 0 0 r
.005 w
.16128 .17044 m
.18734 .17269 L
.21339 .17909 L
.2345 .18734 L
.23945 .19126 L
.2655 .20415 L
.27874 .21339 L
.29156 .22295 L
.31204 .23945 L
.31761 .24532 L
.33549 .2655 L
.34367 .28341 L
.34499 .29156 L
.34367 .29798 L
.31761 .3104 L
.29156 .30711 L
.2655 .30014 L
.24507 .29156 L
.23945 .28747 L
.21339 .27402 L
.20155 .2655 L
.18734 .25472 L
.16884 .23945 L
.16128 .2313 L
.14618 .21339 L
.13806 .18734 L
.16128 .17044 L
s
0 0 1 r
.65633 .57701 m
.68239 .56842 L
.70844 .56313 L
.7345 .56168 L
.76055 .5752 L
.76359 .57817 L
.76859 .60422 L
.76055 .62333 L
.75627 .63028 L
.7345 .65485 L
.73298 .65633 L
.70844 .6775 L
.69922 .68239 L
.68239 .69294 L
.65633 .70579 L
.64983 .70844 L
.63028 .71539 L
.60422 .72268 L
.57817 .72651 L
.55211 .7214 L
.53145 .70844 L
.52926 .68239 L
.54239 .65633 L
.55211 .63983 L
.56625 .63028 L
.57817 .6193 L
.60119 .60422 L
.60422 .60227 L
.63028 .58726 L
.65315 .57817 L
.65633 .57701 L
s
1 0 0 r
.03 w
.24141 .24033 Mdot
0 0 1 r
.64872 .64417 Mdot
1 0 0 r
.79703 .00495 m
.79703 .00495 L
.87129 .00495 L
.87129 .00495 L
F
0 0 1 r
.89604 .00495 m
.89604 .25248 L
.9703 .25248 L
.9703 .00495 L
F
1 0 1 r
.04 w
.47436 .71381 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P000182000`400?l00000o`00003ooooooolQ
ooooo`00ool0000Po`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`00
00?o0000ooooooooool0o_oooolEo`00o`Sooooo0Ol00001ooooo`0000?o0000ooooooooool0o_oo
oolEo`00o`Sooooo0Ol00001ooooo`0000?o0000ooooooooool0o_oooolEo`00o`Sooooo0Ol00001
ooooo`0000?o0000ooooooooool0o_oooolEo`00o`Sooooo0Ol00001ooooo`0000?o0000oooooooo
ool0o_oooolEo`00o`Sooooo0Ol00001ooooo`0000?o0000ooooooooool0o_oooolEo`00o`Sooooo
0Ol00001ooooo`0000?o0000ooooooooool0o_oooolEo`00o`Sooooo0Ol00001ooooo`0000?o0000
ooooooooool0o_oooolEo`00o`Sooooo0Ol00001ooooo`0000?o0000ooooooooool0o_oooolEo`00
o`Sooooo0Ol00001ooooo`0000?o0000ooooooooool0o_oooolEo`00o`Sooooo0Ol00001ooooo`00
00?o0000ooooooooool0o_oooolEo`00o`Sooooo0Ol00001ooooo`0000?o0000ooooooooool0o_oo
oolEo`00o`Sooooo0Ol00001ooooo`0000?o0000ooooooooool0o_oooolEo`00o`Sooooo0Ol00001
ooooo`0000?o0000ooooooooool0o_oooolEo`00o`Sooooo0Ol00001ooooo`0000?o0000oooooooo
ool0o_oooolEo`00o`Sooooo0Ol00001ooooo`0000?o0000ooooooooool0o_oooolEo`00o`Sooooo
0Ol00001ooooo`0000?o0000ooooooooool0o_oooolEo`00o`Sooooo0Ol00001ooooo`0000?o0000
ooooooooool0o_oooolEo`00o`Sooooo0Ol00001ooooo`0000?o0000ooooooooool0o_oooolEo`00
o`Sooooo0Ol00001ooooo`0000?o0000ooooooooool0o_oooolEo`00o`Sooooo0Ol00001ooooo`00
00?o0000ooooooooool0o_oooolEo`00o`Sooooo0Ol00001ooooo`0000?o0000ooooooooool0o_oo
oolEo`00o`Sooooo0Ol00001ooooo`0000?o0000ooooooooool0o_oooolEo`00o`Sooooo0Ol00001
ooooo`0000?o0000ooooooooool0o_oooolEo`00o`Sooooo0Ol00001ooooo`0000?o0000oooooooo
ool0o_oooolEo`00o`Sooooo0Ol00001ooooo`0000?o0000ooooooooool0o_oooolEo`00o`Sooooo
0Ol00001ooooo`0000?o0000ooooooooool0o_oooolEo`00o`Sooooo0Ol00001ooooo`0000?o0000
ooooooooool0o_oooolEo`00o`Sooooo0Ol00001ooooo`0000?o0000ooooooooool0o_oooolEo`00
o`Sooooo0Ol00001ooooo`0000?o0000ooooooooool0o_oooolEo`00o`Sooooo0Ol00001ooooo`00
00?o0000ooooooooool0o_oooolEo`00o`Sooooo0Ol00001ooooo`0000?o0000ooooooooool0o_oo
oolEo`00o`Sooooo0Ol00001ooooo`0000?o0000ooooooooool01_ooool2oomo0?Kooooo5Ol00?l8
ooooo`7o00000Oooool00003o`000?oooooooooo00Gooooo1?ooO`0Cooooo`;oogl0h?oooolEo`00
o`Sooooo0Ol00001ooooo`0000?o0000ooooooooool01Oooool4oomo01;ooooo1?ooO`0Booooo`;o
ogl0booooolEo`00o`Sooooo0Ol00001ooooo`0000?o0000ooooooooool01Oooool3oomo01?ooooo
1?ooO`0Aooooo`Coogl0b_oooolEo`00o`Sooooo0Ol00001ooooo`0000?o0000ooooooooool01?oo
ool4oomo01Cooooo0_ooO`0Booooo`Coogl0b_oooolEo`00o`Sooooo0Ol00001ooooo`0000?o0000
ooooooooool01?ooool4oomo02Wooooo0_ooO`3;oooooaGo003o2?ooool1o`00007ooooo00000ol0
003oooooooooo`05ooooo`;oogl0mooooolEo`00o`Sooooo0Ol00001ooooo`0000?o0000oooooooo
ool0o_oooolEo`00o`Sooooo0Ol00001ooooo`0000?o0000ooooooooool0o_oooolEo`00o`Sooooo
0Ol00001ooooo`0000?o0000ooooooooool0o_oooolEo`00o`Sooooo0Ol00001ooooo`0000?o0000
ooooooooool0o_oooolEo`00o`Sooooo0Ol00001ooooo`0000?o0000ooooooooool0o_oooolEo`00
o`Sooooo0Ol00001ooooo`0000?o0000ooooooooool0o_oooolEo`00o`Sooooo0Ol00001ooooo`00
00?o0000ooooooooool0o_oooolEo`00o`Sooooo0Ol00001ooooo`0000?o0000ooooooooool0:_oo
ool6ool00<kooooo5Ol00?l8ooooo`7o00000Oooool00003o`000?oooooooooo02Wooooo00?oo`00
ooooooooool01?ooool5ool00<Wooooo5Ol00?l8ooooo`7o00000Oooool00003o`000?oooooooooo
02Oooooo0_oo000<ooooo`Coo`00aOoooolEo`00o`Sooooo0Ol00001ooooo`0000?o0000oooooooo
ool09_ooool00ooo003oooooooooo`0@ooooo`Coo`00`OoooolEo`00o`Sooooo0Ol00001ooooo`00
00?o0000ooooooooool09?ooool00oooO`3oo`00ooooo`09ooooo`;oogl02oooool3ool00;kooooo
5Ol00?l8ooooo`7o00000Oooool00003o`000?oooooooooo02?ooooo00Coogl0ool00?ooO`3oogl0
2?ooool4oomo00gooooo00?oo`00ooooooooool0^ooooolEo`00o`Sooooo0Ol00001ooooo`0000?o
0000ooooooooool08oooool01?ooO`3oo`00oomo0?ooO`08ooooo`Coogl03_ooool2ool00;_ooooo
5Ol00?l8ooooo`7o00000Oooool00003o`000?oooooooooo02Cooooo00?oogl0ool00?ooool02Ooo
ool2oomo017ooooo0_oo002ioooooaGo003o2?ooool1o`00007ooooo00000ol0003oooooooooo`0U
ooooo`03ool00?oooooooooo01gooooo0_oo002goooooaGo003o2?ooool1o`00007ooooo00000ol0
003oooooooooo`0Uooooo`03ool00?oooooooooo01oooooo0_oo002eoooooaGo003o2?ooool1o`00
007ooooo00000ol0003oooooooooo`0Vooooo`03ool00?oooooooooo017ooooo0_ooO`0=ooooo`;o
o`001?ooool2oomo00Oooooo0_ooO`2ToooooaGo003o2?ooool1o`00007ooooo00000ol0003ooooo
ooooo`0Vooooo`03ool00?oooooooooo00Gooooo0_ooO`09ooooo`Coogl03_ooool00ooo003ooooo
ooooo`04oomo00Gooooo1?ooO`2SoooooaGo003o2?ooool1o`00007ooooo00000ol0003ooooooooo
o`0Vooooo`03ool00?oooooooooo00Cooooo1?ooO`08ooooo`Coogl03oooool00ooo003ooooooomo
0003oomo00Gooooo1?ooO`2SoooooaGo003o2?ooool1o`00007ooooo00000ol0003oooooooooo`0W
ooooo`03ool00?oooooooooo00?ooooo1?ooO`09ooooo`;oogl04Oooool01?oo003ooooooomo0?oo
O`07ooooo`?oogl0XooooolEo`00o`Sooooo0Ol00001ooooo`0000?o0000ooooooooool09oooool0
0ooo003oooooooooo`04ooooo`;oogl07_ooool00ooo003oooooooooo`07ooooo`Coogl0X_oooolE
o`00o`Sooooo0Ol00001ooooo`0000?o0000ooooooooool0:?ooool00ooo003oooooooooo`0Toooo
o`03ool00?oooooooooo00Kooooo1?ooO`2RoooooaGo003o2?ooool1o`00007ooooo00000ol0003o
ooooooooo`0Yooooo`03ool00?oooooooooo02Cooooo0_oo00000oooooooogl0oomo0004ooooo`;o
ogl0XooooolEo`00o`Sooooo0Ol00001ooooo`0000?o0000ooooooooool0:_ooool00ooo003ooooo
ooooo`0Cooooo`Coo`003_ooool01?oo003oogl0oomo0?ooO`2XoooooaGo003o2?ooool1o`00007o
oooo00000ol0003oooooooooo`0[ooooo`03ool00?oooooooooo017ooooo1_oo000=ooooo`04oomo
0?oo003oo`00oomo0:Sooooo5Ol00?l8ooooo`7o00000Oooool00003o`000?oooooooooo02cooooo
00?oo`00ooooooooool02?ooool2oomo00Gooooo2?oo000=ooooo`;oogl000?oo`00ooooooooool0
Y_oooolEo`00o`Sooooo0Ol00001ooooo`0000?o0000ooooooooool0;Oooool00ooo003ooooooooo
o`06ooooo`Coogl01?ooool8ool0013ooooo00?oo`00ooooooooool0YOoooolEo`00o`Sooooo0Ol0
0001ooooo`0000?o0000ooooooooool0:oooool2oomo0003oooooooo003ooooo00Kooooo1?ooO`04
ooooo`Soo`004Oooool00ooo003oooooooooo`2ToooooaGo003o2?ooool1o`00007ooooo00000ol0
003oooooooooo`0Zooooo`Coogl000?oooooool00?ooool01_ooool2oomo00Gooooo2?oo000;oooo
o`;oogl01Oooool00ooo003oooooooooo`09ooooo`;oogl0V?oooolEo`00o`Sooooo0Ol00001oooo
o`0000?o0000ooooooooool0:_ooool4oomo00;ooooo00?oo`00ooooooooool03?ooool6ool000_o
oooo1?ooO`04ooooo`03ool00?oooooooooo00Sooooo1?ooO`2GoooooaGo003o2?ooool1o`00007o
oooo00000ol0003oooooooooo`0[ooooo`;oogl01?ooool00ooo003oooooooooo`0<ooooo`Coo`00
3?ooool4oomo00Gooooo00?oo`00ooooooooool01oooool4oomo09Oooooo5Ol00?l8ooooo`7o0000
0Oooool00003o`000?oooooooooo03;ooooo0_oo000Mooooo`;oogl01oooool00ooo003ooooooooo
o`07ooooo`;oogl0]Oooool1o`00007ooooo00000ol0003oooooooooo`0dooooo`03ool00?oooooo
oooo02Cooooo00?oo`00ooooooooool0_Oooool1o`00007ooooo00000ol0003oooooooooo`0eoooo
o`03ool00?oooooooooo02Cooooo00?oo`00ooooooooool0_?ooool1o`00007ooooo00000ol0003o
ooooooooo`0fooooo`;oo`009Oooool00ooo003oooooooooo`2kooooo`7o00000Oooool00003o`00
0?oooooooooo03Sooooo0_oo00000oooO`3oooooooooo`02oomo01kooooo00?oo`00ooooooooool0
^oooool1o`00007ooooo00000ol0003oooooooooo`0hooooo`;oogl00_oo0004oomo01kooooo00?o
o`00ooooooooool0^_ooool1o`00007ooooo00000ol0003oooooooooo`0hooooo`Coogl00_oo0002
oomo01kooooo00?oo`00ooooooooool0^_ooool1o`00007ooooo00000ol0003oooooooooo`0ioooo
o`Googl000?oo`00ooooooooool07Oooool00ooo003oogl0oomo002jooooo`7o00000Oooool00003
o`000?oooooooooo03_ooooo1?ooO`02ool001gooooo00Coogl0ool00?ooO`3oogl0^Oooool1o`00
007ooooo00000ol0003oooooooooo`0looooo`;oogl00oooool2ool001_ooooo00Coogl0ool00?oo
O`3oogl0^Oooool1o`00007ooooo00000ol0003oooooooooo`13ooooo`;oo`006_ooool00oooO`3o
o`00ooooo`2iooooo`7o00000Oooool00003o`000?oooooooooo04Gooooo0_oo000Iooooo`03ool0
0?oooooooooo0;Sooooo0Ol00001ooooo`0000?o0000ooooooooool0Aoooool2ool001Gooooo0_oo
002kooooo`7o00000Oooool00003o`000?oooooooooo04Wooooo0ooo000@ooooo`;oo`00_Oooool1
o`00007ooooo00000ol0003oooooooooo`0aooooo`;oogl06Oooool3ool000cooooo00?oo`00oooo
ooooool0_Oooool1o`00007ooooo00000ol0003oooooooooo`0`ooooo`Coogl06oooool6ool000Co
oooo0_oo0030ooooo`7o00000Oooool00003o`000?oooooooooo033ooooo1?ooO`0Qooooo`Coo`00
`_ooool1o`00007ooooo00000ol0003oooooooooo`0aooooo`;oogl0j?ooool1o`00007ooooo0000
0ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLoooo
o`7o00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003ooooo
ooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Ooo
ool00003o`000?oooooooooo07gooooo0_ooO`2Looooo`7o00000Oooool00003o`000?oooooooooo
07cooooo1?ooO`2Kooooo`7o00000Oooool00003o`000?oooooooooo05Cooooo0_ooO`0Vooooo`Co
ogl0Voooool1o`00007ooooo00000ol0003oooooooooo`1Cooooo`Coogl09_ooool2oomo09cooooo
0Ol00001ooooo`0000?o0000ooooooooool0Doooool4oomo0<Cooooo0Ol00001ooooo`0000?o0000
ooooooooool0E?ooool2oomo0<Gooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLoooo
o`7o00000Oooool00003o`000?oooooooooo06?ooooo0_ooO`04ooooo`;oogl0/?ooool1o`00007o
oooo00000ol0003oooooooooo`1Rooooo`Coogl00_ooool4oomo0:oooooo0Ol00001ooooo`0000?o
0000ooooooooool0H_ooool4oomo00;ooooo1?ooO`2_ooooo`7o00000Oooool00003o`000?oooooo
oooo06?ooooo0_ooO`04ooooo`;oogl0/?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooo
oacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`00
0?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol0
0001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo
0?oooooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`00
00?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?oo
ool1o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000oooo
ooooool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007o
oooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooo
oolLooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0
003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o
00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003ooooooooo
o`3ooooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool0
0003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooooaco
oooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oo
oooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001
ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo0?oo
oooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o
0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1
o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000oooooooo
ool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo
00000ol0003oooooooooo`3oooooo`Cooooo0_ooO`0Fooooo`7o00000Oooool00003o`000?oooooo
oooo0?oooooo0oooool4oomo01Gooooo0Ol00001ooooo`0000?o0000ooooooooool0ooooool3oooo
o`Coogl05Oooool1o`00007ooooo00000ol0003oooooooooo`3oooooo`Cooooo0_ooO`0Fooooo`7o
00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003ooooooooo
o`3ooooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool0
0003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooooaco
oooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oo
oooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001
ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo0?oo
oooo7?ooool1o`00007ooooo00000ol0003oooooooooo`2eooooo`;oogl0I?ooool1o`00007ooooo
00000ol0003oooooooooo`2dooooo`Coogl0Hoooool1o`00007ooooo00000ol0003oooooooooo`2d
ooooo`Coogl0Hoooool1o`00007ooooo00000ol0003oooooooooo`2eooooo`;oogl0=Oooool2oomo
02gooooo0Ol00001ooooo`0000?o0000ooooooooool0i?ooool2oomo00Gooooo1?ooO`0/ooooo`7o
00000Oooool00003o`000?oooooooooo0>?ooooo1?ooO`04ooooo`Coogl0;?ooool1o`00007ooooo
00000ol0003oooooooooo`33ooooo`;oogl07_ooool4oomo00Gooooo0_ooO`0]ooooo`7o00000Ooo
ool00003o`000?oooooooooo0<;ooooo1?ooO`0;o`00oa?ooooo0_ooO`0eooooo`7o00000Oooool0
0003o`000?oooooooooo0<;ooooo1?l00?l;ooooo`;o003oB?ooool1o`00007ooooo00000ol0003o
ooooooooo`2nooooo`Co003o00?ooooooomo0?ooO`003_ooool2o`00odKooooo0Ol00001ooooo`00
00?o0000ooooooooool0^Oooool2oomo00?o003o5oooool2o`00o`Wooooo0_ooO`0iooooo`7o0000
0Oooool00003o`000?oooooooooo0;Oooooo1?l00?l00oooO`3oooooooooo`0Iooooo`;o003o1_oo
ool4oomo03Sooooo0Ol00001ooooo`0000?o0000ooooooooool0]?ooool3o`00o`03ooooooooO`3o
ogl000;oogl07?ooool00ol00?ooooooooooo`04ooooo`Coogl00oooool2oomo03?ooooo0Ol00001
ooooo`0000?o0000ooooooooool0/_ooool2o`00o`?oogl00_ooool2oomo01?ooooo0_ooO`08oooo
o`03o`00oooooooooooo00Gooooo0_ooO`03ooooo`Coogl0<_ooool1o`00007ooooo00000ol0003o
ooooooooo`2`ooooo`;o003o00?ooooooomo0?ooO`000_ooO`06ooooo`;oogl03_ooool4oomo00Oo
oooo00?o003oooooooooool02_ooool4oomo03;ooooo0Ol00001ooooo`0000?o0000ooooooooool0
[_ooool2o`00o`Cooooo0_ooO`06ooooo`Coogl03Oooool4oomo00Oooooo00?o003oooooooooool0
2oooool2oomo03?ooooo0Ol00001ooooo`0000?o0000ooooooooool0Roooool2oomo023ooooo00?o
003oooooooooool01?ooool2oomo00Kooooo1?ooO`0>ooooo`;oogl02Oooool00ol00?oooooooooo
o`0oooooo`7o00000Oooool00003o`000?oooooooooo08[ooooo1?ooO`0Mooooo`;o003o1_ooool4
oomo00Kooooo0_ooO`0Jooooo`03o`00oooooooooooo03oooooo0Ol00001ooooo`0000?o0000oooo
ooooool0R_ooool4oomo01cooooo00?o003oooooooooool01_ooool4oomo02;ooooo00?o003ooooo
ooooool0?oooool1o`00007ooooo00000ol0003oooooooooo`2;ooooo`;oogl06oooool2o`00o`[o
oooo0_ooO`0Sooooo`03o`00oooooooooooo03oooooo0Ol00001ooooo`0000?o0000ooooooooool0
U_ooool2oomo00kooooo0_l00?lZooooo`;oogl01Oooool00ol00?ooooooooooo`0oooooo`7o0000
0Oooool00003o`000?oooooooooo09Gooooo1?ooO`0<ooooo`04o`00ooooooooogl0oomo02Sooooo
1?ooO`03ooooo`03o`00oooooooooooo043ooooo0Ol00001ooooo`0000?o0000ooooooooool0UOoo
ool4oomo00[ooooo0_l00?l00oooooooogl0oomo0002oomo02Oooooo1?ooO`03ooooo`03o`00oooo
oooooooo043ooooo0Ol00001ooooo`0000?o0000ooooooooool0U_ooool2oomo00[ooooo00Co003o
oooooooooooooooo1?ooO`0Xooooo`;oogl01?ooool00ol00?ooooooooooo`10ooooo`7o00000Ooo
ool00003o`000?oooooooooo0:7ooooo00?o003oooooooooool00oooool2oomo02kooooo00?o003o
ooooooooool0@Oooool1o`00007ooooo00000ol0003oooooooooo`2Pooooo`03o`00oooooooooooo
03?ooooo00?o003oooooooooool04_ooool2oomo02kooooo0Ol00001ooooo`0000?o0000oooooooo
ool0W_ooool2o`00ocGooooo00?o003oooooooooool04_ooool4oomo02gooooo0Ol00001ooooo`00
00?o0000ooooooooool0WOooool00ol00?ooooooooooo`0Eooooo`Co003o7?ooool00ol00?ooogl0
oomo000Booooo`Coogl0;Oooool1o`00007ooooo00000ol0003oooooooooo`2Looooo`03o`00oooo
oooooooo01Gooooo1_l00?lJooooo`03o`00ooooO`3oogl000;oogl04_ooool2oomo02kooooo0Ol0
0001ooooo`0000?o0000ooooooooool0Voooool00ol00?ooooooooooo`0Eooooo`So003o6?ooool0
0ol00?oooooooomo0003oomo04;ooooo0Ol00001ooooo`0000?o0000ooooooooool0Voooool00ol0
0?ooooooooooo`0Eooooo`So003o5oooool01?l00?ooooooooooooooool2oomo04?ooooo0Ol00001
ooooo`0000?o0000ooooooooool0V_ooool00ol00?ooooooooooo`0Fooooo`So003o5_ooool00ol0
0?ooooooooooo`17ooooo`7o00000Oooool00003o`000?oooooooooo09Wooooo00?o003ooooooooo
ool03?ooool2oomo00Sooooo00?oogl0o`00ool00?l01_l00?lEooooo`03o`00oooooooooooo00;o
ogl0A_ooool1o`00007ooooo00000ol0003oooooooooo`2Iooooo`03o`00oooooooooooo00[ooooo
1OooO`07ooooo`;oogl01_l00?lCooooo`;oogl000?o003oooooooooool01?ooO`15ooooo`7o0000
0Oooool00003o`000?oooooooooo09Sooooo00?o003oooooooooool02_ooool6oomo00Sooooo0_oo
O`04o`00oa?ooooo0_ooO`02o`00o`;ooooo1?ooO`15ooooo`7o00000Oooool00003o`000?oooooo
oooo09Sooooo00?o003oooooooooool02_ooool5oomo02;ooooo00Coogl0o`00ooooO`3oogl00ooo
ool2oomo04Kooooo0Ol00001ooooo`0000?o0000ooooooooool0M_ooool2oomo01oooooo00?o003o
ooooooooool03?ooool2oomo02Cooooo00?o003ooomo0?ooO`00C?ooool1o`00007ooooo00000ol0
003oooooooooo`1eooooo`Coogl07_ooool00ol00?ooooooooooo`0aooooo`03o`00oooooooooooo
04gooooo0Ol00001ooooo`0000?o0000ooooooooool0MOooool4oomo00[ooooo0_ooO`0Aooooo`03
o`00oooooooooooo037ooooo00?o003oooooooooool0C_ooool1o`00007ooooo00000ol0003ooooo
ooooo`1fooooo`;oogl02_ooool4oomo00oooooo00?o003oooooooooool06?ooool2oomo01Oooooo
00?o003oooooooooool0Coooool1o`00007ooooo00000ol0003oooooooooo`22ooooo`Coogl03ooo
ool00ol00?ooooooooooo`0Gooooo`Coogl05?ooool2o`00oe;ooooo0Ol00001ooooo`0000?o0000
ooooooooool0Poooool2oomo00oooooo00?o003oooooooooool04_ooool2oomo00Cooooo1?ooO`0A
ooooo`?o003oE?ooool1o`00007ooooo00000ol0003oooooooooo`2Dooooo`03o`00oooooooooooo
017ooooo1?ooO`04ooooo`;oogl04?ooool2o`00oeOooooo0Ol00001ooooo`0000?o0000oooooooo
ool0U?ooool00ol00?ooooooooooo`0Aooooo`Coogl05Oooool00ol00?ooooooooooo`1Gooooo`7o
00000Oooool00003o`000?oooooooooo09Cooooo00?o003oooooooooool04_ooool2oomo01Cooooo
0_l00?mJooooo`7o00000Oooool00003o`000?oooooooooo08;ooooo1Ooo0?l=ooooo`03o`00oooo
oooooooo02Kooooo0_l00?mLooooo`7o00000Oooool00003o`000?oooooooooo087ooooo1ooo0?l=
ooooo`03o`00oooooooooooo02Cooooo00?o003oooooooooool0G?ooool1o`00007ooooo00000ol0
003oooooooooo`20ooooo`Woo`3o3?ooool00ol00?ooooooooooo`0Rooooo`;o003oGoooool1o`00
007ooooo00000ol0003oooooooooo`1oooooo`_oo`3o2oooool00ol00?ooooooooooo`0Pooooo`;o
003oHOooool1o`00007ooooo00000ol0003oooooooooo`1oooooo`_oo`3o2oooool2o`00oaoooooo
0_l00?mSooooo`7o00000Oooool00003o`000?oooooooooo07oooooo2ooo0?l=ooooo`;o003o6_oo
ool3o`00ofGooooo0Ol00001ooooo`0000?o0000ooooooooool0Ooooool;ool0o`oooooo0_l00?lD
ooooo`Co003oJ?ooool1o`00007ooooo00000ol0003oooooooooo`1oooooo`_oo`3o4Oooool3o`00
o`kooooo0ol00?l3ooooo`;oogl0Ioooool1o`00007ooooo00000ol0003oooooooooo`20ooooo`Wo
o`3o5Oooool3o`00o`Gooooo1_l00?l5ooooo`Coogl0I_ooool1o`00007ooooo00000ol0003ooooo
ooooo`21ooooo`Ooo`3o6Oooool5o`00o`_ooooo1?ooO`1Vooooo`7o00000Oooool00003o`000?oo
oooooooo08;ooooo1Ooo0?l[ooooo`;oogl0Ioooool1o`00007ooooo00000ol0003oooooooooo`3o
oooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003
o`000?oooooooooo07_ooooo0_ooO`2Nooooo`7o00000Oooool00003o`000?oooooooooo07[ooooo
1?ooO`2Mooooo`7o00000Oooool00003o`000?oooooooooo07[ooooo1?ooO`0Pooooo`;oogl0Nooo
ool1o`00007ooooo00000ol0003oooooooooo`1kooooo`;oogl08?ooool4oomo07[ooooo0Ol00001
ooooo`0000?o0000ooooooooool0WOooool4oomo07[ooooo0Ol00001ooooo`0000?o0000oooooooo
ool0T?ooool2oomo00cooooo0_ooO`1kooooo`7o00000Oooool00003o`000?oooooooooo08oooooo
1?ooO`28ooooo`7o00000Oooool00003o`000?oooooooooo08oooooo1?ooO`28ooooo`7o00000Ooo
ool00003o`000?oooooooooo093ooooo0_ooO`0Sooooo`;oogl0I?ooool1o`00007ooooo00000ol0
003oooooooooo`2dooooo`Coogl0Hoooool1o`00007ooooo00000ol0003oooooooooo`2dooooo`Co
ogl0Hoooool1o`00007ooooo00000ol0003oooooooooo`2eooooo`;oogl0I?ooool1o`00007ooooo
00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolL
ooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003o
ooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o0000
0Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3o
oooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003
o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo
0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oooooo
oooo0?oooooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001oooo
o`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo
7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000
ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00
007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0
oooooolLooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo0000
0ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLoooo
o`7o00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003ooooo
ooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Ooo
ool00003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooo
oacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`00
0?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol0
0001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo
0?oooooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`00
00?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?oo
ool1o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000oooo
ooooool0S_ooool2oomo08_ooooo0Ol00001ooooo`0000?o0000ooooooooool0SOooool4oomo08[o
oooo0Ol00001ooooo`0000?o0000ooooooooool0SOooool4oomo08[ooooo0Ol00001ooooo`0000?o
0000ooooooooool0S_ooool2oomo08_ooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolL
ooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003o
ooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o0000
0Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3o
oooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003
o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo
0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oooooo
oooo0?oooooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001oooo
o`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo
7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000
ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00
007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0
oooooolLooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo0000
0ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`00ool0000Po`00007ooooo0000\
\>"],
  ImageRangeCache->{{{0, 287}, {287, 0}} -> {-1.01089, -1.01089, 0.00704453, \
0.00704453}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.49505 0.5 0.49505 [
[ 0 0 -0.125 0 ]
[ 0 0 -0.125 0 ]
[ 0 1 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
0 0 m
1 0 L
s
0 0 m
0 1 L
s
0 1 m
1 1 L
s
1 0 m
1 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
1 .5 0 r
.015 w
.03175 .1355 Mdot
.03435 .12523 Mdot
.11137 .12765 Mdot
.14107 .18841 Mdot
.16218 .24538 Mdot
.17294 .21053 Mdot
.18267 .18577 Mdot
.18434 .1304 Mdot
.18553 .30956 Mdot
.20401 .239 Mdot
.21247 .27571 Mdot
.21687 .20845 Mdot
.22376 .2799 Mdot
.22832 .27485 Mdot
.29063 .20974 Mdot
.29686 .25079 Mdot
.30487 .22936 Mdot
.30683 .34623 Mdot
.32055 .20902 Mdot
.32574 .21979 Mdot
.34472 .28521 Mdot
.35998 .36393 Mdot
.36335 .24976 Mdot
.3794 .36608 Mdot
.42386 .66992 Mdot
.44391 .74519 Mdot
.45059 .34198 Mdot
.47208 .67586 Mdot
.47436 .71381 Mdot
.49778 .59825 Mdot
.50874 .91643 Mdot
.51516 .76219 Mdot
.53655 .61374 Mdot
.56563 .75219 Mdot
.59189 .65665 Mdot
.59581 .61604 Mdot
.59923 .6556 Mdot
.60292 .68499 Mdot
.62656 .67779 Mdot
.63555 .72451 Mdot
.63919 .652 Mdot
.64169 .6004 Mdot
.64246 .58611 Mdot
.64496 .54267 Mdot
.64608 .77288 Mdot
.65077 .64308 Mdot
.66065 .57816 Mdot
.67474 .59169 Mdot
.69296 .563 Mdot
.72815 .65902 Mdot
.73169 .58879 Mdot
.74669 .61318 Mdot
.74821 .65474 Mdot
.75963 .63781 Mdot
.79673 .57809 Mdot
.80925 .55852 Mdot
.81525 .58444 Mdot
.83417 .62985 Mdot
.83598 .55526 Mdot
.91595 .49319 Mdot
1 0 0 r
.005 w
.16128 .17044 m
.18734 .17269 L
.21339 .17909 L
.2345 .18734 L
.23945 .19126 L
.2655 .20415 L
.27874 .21339 L
.29156 .22295 L
.31204 .23945 L
.31761 .24532 L
.33549 .2655 L
.34367 .28341 L
.34499 .29156 L
.34367 .29798 L
.31761 .3104 L
.29156 .30711 L
.2655 .30014 L
.24507 .29156 L
.23945 .28747 L
.21339 .27402 L
.20155 .2655 L
.18734 .25472 L
.16884 .23945 L
.16128 .2313 L
.14618 .21339 L
.13806 .18734 L
.16128 .17044 L
s
0 0 1 r
.65633 .57701 m
.68239 .56842 L
.70844 .56313 L
.7345 .56168 L
.76055 .5752 L
.76359 .57817 L
.76859 .60422 L
.76055 .62333 L
.75627 .63028 L
.7345 .65485 L
.73298 .65633 L
.70844 .6775 L
.69922 .68239 L
.68239 .69294 L
.65633 .70579 L
.64983 .70844 L
.63028 .71539 L
.60422 .72268 L
.57817 .72651 L
.55211 .7214 L
.53145 .70844 L
.52926 .68239 L
.54239 .65633 L
.55211 .63983 L
.56625 .63028 L
.57817 .6193 L
.60119 .60422 L
.60422 .60227 L
.63028 .58726 L
.65315 .57817 L
.65633 .57701 L
s
1 0 0 r
.03 w
.24141 .24033 Mdot
0 0 1 r
.64872 .64417 Mdot
1 0 0 r
.79703 .00495 m
.79703 .00495 L
.87129 .00495 L
.87129 .00495 L
F
0 0 1 r
.89604 .00495 m
.89604 .25247 L
.9703 .25247 L
.9703 .00495 L
F
1 0 1 r
.04 w
.49778 .59825 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P000182000`400?l00000o`00003ooooooolQ
ooooo`00ool0000Po`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`00
00?o0000ooooooooool0o_oooolEo`00o`Sooooo0Ol00001ooooo`0000?o0000ooooooooool0o_oo
oolEo`00o`Sooooo0Ol00001ooooo`0000?o0000ooooooooool0o_oooolEo`00o`Sooooo0Ol00001
ooooo`0000?o0000ooooooooool0o_oooolEo`00o`Sooooo0Ol00001ooooo`0000?o0000oooooooo
ool0o_oooolEo`00o`Sooooo0Ol00001ooooo`0000?o0000ooooooooool0o_oooolEo`00o`Sooooo
0Ol00001ooooo`0000?o0000ooooooooool0o_oooolEo`00o`Sooooo0Ol00001ooooo`0000?o0000
ooooooooool0o_oooolEo`00o`Sooooo0Ol00001ooooo`0000?o0000ooooooooool0o_oooolEo`00
o`Sooooo0Ol00001ooooo`0000?o0000ooooooooool0o_oooolEo`00o`Sooooo0Ol00001ooooo`00
00?o0000ooooooooool0o_oooolEo`00o`Sooooo0Ol00001ooooo`0000?o0000ooooooooool0o_oo
oolEo`00o`Sooooo0Ol00001ooooo`0000?o0000ooooooooool0o_oooolEo`00o`Sooooo0Ol00001
ooooo`0000?o0000ooooooooool0o_oooolEo`00o`Sooooo0Ol00001ooooo`0000?o0000oooooooo
ool0o_oooolEo`00o`Sooooo0Ol00001ooooo`0000?o0000ooooooooool0o_oooolEo`00o`Sooooo
0Ol00001ooooo`0000?o0000ooooooooool0o_oooolEo`00o`Sooooo0Ol00001ooooo`0000?o0000
ooooooooool0o_oooolEo`00o`Sooooo0Ol00001ooooo`0000?o0000ooooooooool0o_oooolEo`00
o`Sooooo0Ol00001ooooo`0000?o0000ooooooooool0o_oooolEo`00o`Sooooo0Ol00001ooooo`00
00?o0000ooooooooool0o_oooolEo`00o`Sooooo0Ol00001ooooo`0000?o0000ooooooooool0o_oo
oolEo`00o`Sooooo0Ol00001ooooo`0000?o0000ooooooooool0o_oooolEo`00o`Sooooo0Ol00001
ooooo`0000?o0000ooooooooool0o_oooolEo`00o`Sooooo0Ol00001ooooo`0000?o0000oooooooo
ool0o_oooolEo`00o`Sooooo0Ol00001ooooo`0000?o0000ooooooooool0o_oooolEo`00o`Sooooo
0Ol00001ooooo`0000?o0000ooooooooool0o_oooolEo`00o`Sooooo0Ol00001ooooo`0000?o0000
ooooooooool0o_oooolEo`00o`Sooooo0Ol00001ooooo`0000?o0000ooooooooool0o_oooolEo`00
o`Sooooo0Ol00001ooooo`0000?o0000ooooooooool0o_oooolEo`00o`Sooooo0Ol00001ooooo`00
00?o0000ooooooooool0o_oooolEo`00o`Sooooo0Ol00001ooooo`0000?o0000ooooooooool0o_oo
oolEo`00o`Sooooo0Ol00001ooooo`0000?o0000ooooooooool01_ooool2oomo0?Kooooo5Ol00?l8
ooooo`7o00000Oooool00003o`000?oooooooooo00Gooooo1?ooO`0Cooooo`;oogl0h?oooolEo`00
o`Sooooo0Ol00001ooooo`0000?o0000ooooooooool01Oooool4oomo01;ooooo1?ooO`0Booooo`;o
ogl0booooolEo`00o`Sooooo0Ol00001ooooo`0000?o0000ooooooooool01Oooool3oomo01?ooooo
1?ooO`0Aooooo`Coogl0b_oooolEo`00o`Sooooo0Ol00001ooooo`0000?o0000ooooooooool01?oo
ool4oomo01Cooooo0_ooO`0Booooo`Coogl0b_oooolEo`00o`Sooooo0Ol00001ooooo`0000?o0000
ooooooooool01?ooool4oomo02Wooooo0_ooO`3;oooooaGo003o2?ooool1o`00007ooooo00000ol0
003oooooooooo`05ooooo`;oogl0mooooolEo`00o`Sooooo0Ol00001ooooo`0000?o0000oooooooo
ool0o_oooolEo`00o`Sooooo0Ol00001ooooo`0000?o0000ooooooooool0o_oooolEo`00o`Sooooo
0Ol00001ooooo`0000?o0000ooooooooool0o_oooolEo`00o`Sooooo0Ol00001ooooo`0000?o0000
ooooooooool0o_oooolEo`00o`Sooooo0Ol00001ooooo`0000?o0000ooooooooool0o_oooolEo`00
o`Sooooo0Ol00001ooooo`0000?o0000ooooooooool0o_oooolEo`00o`Sooooo0Ol00001ooooo`00
00?o0000ooooooooool0o_oooolEo`00o`Sooooo0Ol00001ooooo`0000?o0000ooooooooool0:_oo
ool6ool00<kooooo5Ol00?l8ooooo`7o00000Oooool00003o`000?oooooooooo02Wooooo00?oo`00
ooooooooool01?ooool5ool00<Wooooo5Ol00?l8ooooo`7o00000Oooool00003o`000?oooooooooo
02Oooooo0_oo000<ooooo`Coo`00aOoooolEo`00o`Sooooo0Ol00001ooooo`0000?o0000oooooooo
ool09_ooool00ooo003oooooooooo`0@ooooo`Coo`00`OoooolEo`00o`Sooooo0Ol00001ooooo`00
00?o0000ooooooooool09?ooool00oooO`3oo`00ooooo`09ooooo`;oogl02oooool3ool00;kooooo
5Ol00?l8ooooo`7o00000Oooool00003o`000?oooooooooo02?ooooo00Coogl0ool00?ooO`3oogl0
2?ooool4oomo00gooooo00?oo`00ooooooooool0^ooooolEo`00o`Sooooo0Ol00001ooooo`0000?o
0000ooooooooool08oooool01?ooO`3oo`00oomo0?ooO`08ooooo`Coogl03_ooool2ool00;_ooooo
5Ol00?l8ooooo`7o00000Oooool00003o`000?oooooooooo02Cooooo00?oogl0ool00?ooool02Ooo
ool2oomo017ooooo0_oo002ioooooaGo003o2?ooool1o`00007ooooo00000ol0003oooooooooo`0U
ooooo`03ool00?oooooooooo01gooooo0_oo002goooooaGo003o2?ooool1o`00007ooooo00000ol0
003oooooooooo`0Uooooo`03ool00?oooooooooo01oooooo0_oo002eoooooaGo003o2?ooool1o`00
007ooooo00000ol0003oooooooooo`0Vooooo`03ool00?oooooooooo017ooooo0_ooO`0=ooooo`;o
o`001?ooool2oomo00Oooooo0_ooO`2ToooooaGo003o2?ooool1o`00007ooooo00000ol0003ooooo
ooooo`0Vooooo`03ool00?oooooooooo00Gooooo0_ooO`09ooooo`Coogl03_ooool00ooo003ooooo
ooooo`04oomo00Gooooo1?ooO`2SoooooaGo003o2?ooool1o`00007ooooo00000ol0003ooooooooo
o`0Vooooo`03ool00?oooooooooo00Cooooo1?ooO`08ooooo`Coogl03oooool00ooo003ooooooomo
0003oomo00Gooooo1?ooO`2SoooooaGo003o2?ooool1o`00007ooooo00000ol0003oooooooooo`0W
ooooo`03ool00?oooooooooo00?ooooo1?ooO`09ooooo`;oogl04Oooool01?oo003ooooooomo0?oo
O`07ooooo`?oogl0XooooolEo`00o`Sooooo0Ol00001ooooo`0000?o0000ooooooooool09oooool0
0ooo003oooooooooo`04ooooo`;oogl07_ooool00ooo003oooooooooo`07ooooo`Coogl0X_oooolE
o`00o`Sooooo0Ol00001ooooo`0000?o0000ooooooooool0:?ooool00ooo003oooooooooo`0Toooo
o`03ool00?oooooooooo00Kooooo1?ooO`2RoooooaGo003o2?ooool1o`00007ooooo00000ol0003o
ooooooooo`0Yooooo`03ool00?oooooooooo02Cooooo0_oo00000oooooooogl0oomo0004ooooo`;o
ogl0XooooolEo`00o`Sooooo0Ol00001ooooo`0000?o0000ooooooooool0:_ooool00ooo003ooooo
ooooo`0Cooooo`Coo`003_ooool01?oo003oogl0oomo0?ooO`2XoooooaGo003o2?ooool1o`00007o
oooo00000ol0003oooooooooo`0[ooooo`03ool00?oooooooooo017ooooo1_oo000=ooooo`04oomo
0?oo003oo`00oomo0:Sooooo5Ol00?l8ooooo`7o00000Oooool00003o`000?oooooooooo02cooooo
00?oo`00ooooooooool02?ooool2oomo00Gooooo2?oo000=ooooo`;oogl000?oo`00ooooooooool0
Y_oooolEo`00o`Sooooo0Ol00001ooooo`0000?o0000ooooooooool0;Oooool00ooo003ooooooooo
o`06ooooo`Coogl01?ooool8ool0013ooooo00?oo`00ooooooooool0YOoooolEo`00o`Sooooo0Ol0
0001ooooo`0000?o0000ooooooooool0:oooool2oomo0003oooooooo003ooooo00Kooooo1?ooO`04
ooooo`Soo`004Oooool00ooo003oooooooooo`2ToooooaGo003o2?ooool1o`00007ooooo00000ol0
003oooooooooo`0Zooooo`Coogl000?oooooool00?ooool01_ooool2oomo00Gooooo2?oo000;oooo
o`;oogl01Oooool00ooo003oooooooooo`09ooooo`;oogl0V?oooolEo`00o`Sooooo0Ol00001oooo
o`0000?o0000ooooooooool0:_ooool4oomo00;ooooo00?oo`00ooooooooool03?ooool6ool000_o
oooo1?ooO`04ooooo`03ool00?oooooooooo00Sooooo1?ooO`2GoooooaGo003o2?ooool1o`00007o
oooo00000ol0003oooooooooo`0[ooooo`;oogl01?ooool00ooo003oooooooooo`0<ooooo`Coo`00
3?ooool4oomo00Gooooo00?oo`00ooooooooool01oooool4oomo09Oooooo5Ol00?l8ooooo`7o0000
0Oooool00003o`000?oooooooooo03;ooooo0_oo000Mooooo`;oogl01oooool00ooo003ooooooooo
o`07ooooo`;oogl0]Oooool1o`00007ooooo00000ol0003oooooooooo`0dooooo`03ool00?oooooo
oooo02Cooooo00?oo`00ooooooooool0_Oooool1o`00007ooooo00000ol0003oooooooooo`0eoooo
o`03ool00?oooooooooo02Cooooo00?oo`00ooooooooool0_?ooool1o`00007ooooo00000ol0003o
ooooooooo`0fooooo`;oo`009Oooool00ooo003oooooooooo`2kooooo`7o00000Oooool00003o`00
0?oooooooooo03Sooooo0_oo00000oooO`3oooooooooo`02oomo01kooooo00?oo`00ooooooooool0
^oooool1o`00007ooooo00000ol0003oooooooooo`0hooooo`;oogl00_oo0004oomo01kooooo00?o
o`00ooooooooool0^_ooool1o`00007ooooo00000ol0003oooooooooo`0hooooo`Coogl00_oo0002
oomo01kooooo00?oo`00ooooooooool0^_ooool1o`00007ooooo00000ol0003oooooooooo`0ioooo
o`Googl000?oo`00ooooooooool07Oooool00ooo003oogl0oomo002jooooo`7o00000Oooool00003
o`000?oooooooooo03_ooooo1?ooO`02ool001gooooo00Coogl0ool00?ooO`3oogl0^Oooool1o`00
007ooooo00000ol0003oooooooooo`0looooo`;oogl00oooool2ool001_ooooo00Coogl0ool00?oo
O`3oogl0^Oooool1o`00007ooooo00000ol0003oooooooooo`13ooooo`;oo`006_ooool00oooO`3o
o`00ooooo`2iooooo`7o00000Oooool00003o`000?oooooooooo04Gooooo0_oo000Iooooo`03ool0
0?oooooooooo0;Sooooo0Ol00001ooooo`0000?o0000ooooooooool0Aoooool2ool001Gooooo0_oo
002kooooo`7o00000Oooool00003o`000?oooooooooo04Wooooo0ooo000@ooooo`;oo`00_Oooool1
o`00007ooooo00000ol0003oooooooooo`0aooooo`;oogl06Oooool3ool000cooooo00?oo`00oooo
ooooool0_Oooool1o`00007ooooo00000ol0003oooooooooo`0`ooooo`Coogl06oooool6ool000Co
oooo0_oo0030ooooo`7o00000Oooool00003o`000?oooooooooo033ooooo1?ooO`0Qooooo`Coo`00
`_ooool1o`00007ooooo00000ol0003oooooooooo`0aooooo`;oogl0j?ooool1o`00007ooooo0000
0ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLoooo
o`7o00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003ooooo
ooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Ooo
ool00003o`000?oooooooooo07gooooo0_ooO`2Looooo`7o00000Oooool00003o`000?oooooooooo
07cooooo1?ooO`2Kooooo`7o00000Oooool00003o`000?oooooooooo05Cooooo0_ooO`0Vooooo`Co
ogl0Voooool1o`00007ooooo00000ol0003oooooooooo`1Cooooo`Coogl09_ooool2oomo09cooooo
0Ol00001ooooo`0000?o0000ooooooooool0Doooool4oomo0<Cooooo0Ol00001ooooo`0000?o0000
ooooooooool0E?ooool2oomo0<Gooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLoooo
o`7o00000Oooool00003o`000?oooooooooo06?ooooo0_ooO`04ooooo`;oogl0/?ooool1o`00007o
oooo00000ol0003oooooooooo`1Rooooo`Coogl00_ooool4oomo0:oooooo0Ol00001ooooo`0000?o
0000ooooooooool0H_ooool4oomo00;ooooo1?ooO`2_ooooo`7o00000Oooool00003o`000?oooooo
oooo06?ooooo0_ooO`04ooooo`;oogl0/?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooo
oacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`00
0?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol0
0001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo
0?oooooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`00
00?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?oo
ool1o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000oooo
ooooool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007o
oooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooo
oolLooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0
003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o
00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003ooooooooo
o`3ooooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool0
0003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooooaco
oooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oo
oooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001
ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo0?oo
oooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o
0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1
o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000oooooooo
ool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo
00000ol0003oooooooooo`3oooooo`Cooooo0_ooO`0Fooooo`7o00000Oooool00003o`000?oooooo
oooo0?oooooo0oooool4oomo01Gooooo0Ol00001ooooo`0000?o0000ooooooooool0ooooool3oooo
o`Coogl05Oooool1o`00007ooooo00000ol0003oooooooooo`3oooooo`Cooooo0_ooO`0Fooooo`7o
00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003ooooooooo
o`3ooooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool0
0003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooooaco
oooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oo
oooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001
ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo0?oo
oooo7?ooool1o`00007ooooo00000ol0003oooooooooo`2eooooo`;oogl0I?ooool1o`00007ooooo
00000ol0003oooooooooo`2dooooo`Coogl0Hoooool1o`00007ooooo00000ol0003oooooooooo`2d
ooooo`Coogl0Hoooool1o`00007ooooo00000ol0003oooooooooo`2eooooo`;oogl0=Oooool2oomo
02gooooo0Ol00001ooooo`0000?o0000ooooooooool0i?ooool2oomo00Gooooo1?ooO`0/ooooo`7o
00000Oooool00003o`000?oooooooooo0>?ooooo1?ooO`04ooooo`Coogl0;?ooool1o`00007ooooo
00000ol0003oooooooooo`33ooooo`;oogl07_ooool4oomo00Gooooo0_ooO`0]ooooo`7o00000Ooo
ool00003o`000?oooooooooo0<;ooooo1?ooO`0;o`00oa?ooooo0_ooO`0eooooo`7o00000Oooool0
0003o`000?oooooooooo0<;ooooo1?l00?l;ooooo`;o003oB?ooool1o`00007ooooo00000ol0003o
ooooooooo`2nooooo`Co003o00?ooooooomo0?ooO`003_ooool2o`00odKooooo0Ol00001ooooo`00
00?o0000ooooooooool0^Oooool2oomo00?o003o5oooool2o`00o`Wooooo0_ooO`0iooooo`7o0000
0Oooool00003o`000?oooooooooo0;Oooooo1?l00?l00oooO`3oooooooooo`0Iooooo`;o003o1_oo
ool4oomo03Sooooo0Ol00001ooooo`0000?o0000ooooooooool0ROooool5ool0obKooooo0ol00?l0
0oooooooogl0oomo0002oomo01cooooo00?o003oooooooooool01?ooool4oomo00?ooooo0_ooO`0c
ooooo`7o00000Oooool00003o`000?oooooooooo08Sooooo1ooo0?lSooooo`;o003o0oooO`02oooo
o`;oogl04oooool2oomo00Sooooo00?o003oooooooooool01Oooool2oomo00?ooooo1?ooO`0boooo
o`7o00000Oooool00003o`000?oooooooooo08Oooooo2Ooo0?lPooooo`;o003o00?ooooooomo0?oo
O`000_ooO`06ooooo`;oogl03_ooool4oomo00Oooooo00?o003oooooooooool02_ooool4oomo03;o
oooo0Ol00001ooooo`0000?o0000ooooooooool0Q_ooool;ool0oagooooo0_l00?l4ooooo`;oogl0
1_ooool4oomo00gooooo1?ooO`07ooooo`03o`00oooooooooooo00_ooooo0_ooO`0cooooo`7o0000
0Oooool00003o`000?oooooooooo08Kooooo2ooo0?lLooooo`03o`00oooooooooooo00Cooooo0_oo
O`06ooooo`Coogl03_ooool2oomo00Wooooo00?o003oooooooooool0?oooool1o`00007ooooo0000
0ol0003oooooooooo`26ooooo`_oo`3o6_ooool2o`00o`Kooooo1?ooO`06ooooo`;oogl06_ooool0
0ol00?ooooooooooo`0oooooo`7o00000Oooool00003o`000?oooooooooo08Kooooo2ooo0?lIoooo
o`03o`00oooooooooooo00Kooooo1?ooO`0Rooooo`03o`00oooooooooooo03oooooo0Ol00001oooo
o`0000?o0000ooooooooool0Q_ooool;ool0oaOooooo0_l00?l:ooooo`;oogl08oooool00ol00?oo
ooooooooo`0oooooo`7o00000Oooool00003o`000?oooooooooo08Oooooo2Ooo0?l6ooooo`;oogl0
3_ooool2o`00ob[ooooo0_ooO`05ooooo`03o`00oooooooooooo03oooooo0Ol00001ooooo`0000?o
0000ooooooooool0R?ooool7ool0o`Kooooo1?ooO`0<ooooo`04o`00ooooooooogl0oomo02Sooooo
1?ooO`03ooooo`03o`00oooooooooooo043ooooo0Ol00001ooooo`0000?o0000ooooooooool0ROoo
ool5ool0o`Oooooo1?ooO`0:ooooo`;o003o00?ooooooomo0?ooO`000_ooO`0Wooooo`Coogl00ooo
ool00ol00?ooooooooooo`10ooooo`7o00000Oooool00003o`000?oooooooooo09Kooooo0_ooO`0:
ooooo`04o`00ooooooooooooooooo`Coogl0:?ooool2oomo00Cooooo00?o003oooooooooool0@?oo
ool1o`00007ooooo00000ol0003oooooooooo`2Qooooo`03o`00oooooooooooo00?ooooo0_ooO`0^
ooooo`03o`00oooooooooooo047ooooo0Ol00001ooooo`0000?o0000ooooooooool0X?ooool00ol0
0?ooooooooooo`0cooooo`03o`00oooooooooooo01;ooooo0_ooO`0^ooooo`7o00000Oooool00003
o`000?oooooooooo09kooooo0_l00?leooooo`03o`00oooooooooooo01;ooooo1?ooO`0]ooooo`7o
00000Oooool00003o`000?oooooooooo09gooooo00?o003oooooooooool05Oooool4o`00oacooooo
00?o003ooomo0?ooO`004_ooool4oomo02gooooo0Ol00001ooooo`0000?o0000ooooooooool0W?oo
ool00ol00?ooooooooooo`0Eooooo`Ko003o6_ooool00ol00?ooogl0oomo0002oomo01;ooooo0_oo
O`0^ooooo`7o00000Oooool00003o`000?oooooooooo09_ooooo00?o003oooooooooool05Oooool8
o`00oaSooooo00?o003oooooooooO`000oooO`12ooooo`7o00000Oooool00003o`000?oooooooooo
09_ooooo00?o003oooooooooool05Oooool8o`00oaOooooo00Co003ooooooooooooooooo0_ooO`13
ooooo`7o00000Oooool00003o`000?oooooooooo09[ooooo00?o003oooooooooool05_ooool8o`00
oaKooooo00?o003oooooooooool0Aoooool1o`00007ooooo00000ol0003oooooooooo`2Iooooo`03
o`00oooooooooooo00cooooo0_ooO`08ooooo`03oomo0?l00?oo003o00Ko003o5Oooool00ol00?oo
ooooooooo`02oomo04Kooooo0Ol00001ooooo`0000?o0000ooooooooool0VOooool00ol00?oooooo
ooooo`0:ooooo`Googl01oooool2oomo00Ko003o4oooool2oomo0003o`00oooooooooooo00Coogl0
AOooool1o`00007ooooo00000ol0003oooooooooo`2Hooooo`03o`00oooooooooooo00[ooooo1_oo
O`08ooooo`;oogl01?l00?lCooooo`;oogl00_l00?l2ooooo`Coogl0AOooool1o`00007ooooo0000
0ol0003oooooooooo`2Hooooo`03o`00oooooooooooo00[ooooo1OooO`0Rooooo`04oomo0?l00?oo
ogl0oomo00?ooooo0_ooO`16ooooo`7o00000Oooool00003o`000?oooooooooo07Kooooo0_ooO`0O
ooooo`03o`00oooooooooooo00cooooo0_ooO`0Tooooo`03o`00ooooO`3oogl004cooooo0Ol00001
ooooo`0000?o0000ooooooooool0MOooool4oomo01kooooo00?o003oooooooooool0<Oooool00ol0
0?ooooooooooo`1=ooooo`7o00000Oooool00003o`000?oooooooooo07Gooooo1?ooO`0:ooooo`;o
ogl04Oooool00ol00?ooooooooooo`0aooooo`03o`00oooooooooooo04kooooo0Ol00001ooooo`00
00?o0000ooooooooool0M_ooool2oomo00[ooooo1?ooO`0?ooooo`03o`00oooooooooooo01Sooooo
0_ooO`0Gooooo`03o`00oooooooooooo04oooooo0Ol00001ooooo`0000?o0000ooooooooool0P_oo
ool4oomo00oooooo00?o003oooooooooool05oooool4oomo01Cooooo0_l00?mBooooo`7o00000Ooo
ool00003o`000?oooooooooo08?ooooo0_ooO`0?ooooo`03o`00oooooooooooo01;ooooo0_ooO`04
ooooo`Coogl04Oooool3o`00oeCooooo0Ol00001ooooo`0000?o0000ooooooooool0U?ooool00ol0
0?ooooooooooo`0Aooooo`Coogl01?ooool2oomo013ooooo0_l00?mGooooo`7o00000Oooool00003
o`000?oooooooooo09Cooooo00?o003oooooooooool04Oooool4oomo01Gooooo00?o003ooooooooo
ool0Eoooool1o`00007ooooo00000ol0003oooooooooo`2Dooooo`03o`00oooooooooooo01;ooooo
0_ooO`0Dooooo`;o003oF_ooool1o`00007ooooo00000ol0003oooooooooo`2Dooooo`03o`00oooo
oooooooo02Kooooo0_l00?mLooooo`7o00000Oooool00003o`000?oooooooooo09Gooooo00?o003o
ooooooooool09?ooool00ol00?ooooooooooo`1Looooo`7o00000Oooool00003o`000?oooooooooo
09Gooooo00?o003oooooooooool08_ooool2o`00oeoooooo0Ol00001ooooo`0000?o0000oooooooo
ool0UOooool00ol00?ooooooooooo`0Pooooo`;o003oHOooool1o`00007ooooo00000ol0003ooooo
ooooo`24ooooo`;oogl03oooool2o`00oaoooooo0_l00?mSooooo`7o00000Oooool00003o`000?oo
oooooooo08?ooooo1?ooO`0@ooooo`;o003o6_ooool3o`00ofGooooo0Ol00001ooooo`0000?o0000
ooooooooool0Poooool4oomo01;ooooo0_l00?lDooooo`Co003oJ?ooool1o`00007ooooo00000ol0
003oooooooooo`24ooooo`;oogl05Oooool3o`00o`kooooo0ol00?l3ooooo`;oogl0Ioooool1o`00
007ooooo00000ol0003oooooooooo`2Nooooo`?o003o1Oooool6o`00o`Gooooo1?ooO`1Vooooo`7o
00000Oooool00003o`000?oooooooooo0:7ooooo1Ol00?l;ooooo`Coogl0I_ooool1o`00007ooooo
00000ol0003oooooooooo`2booooo`;oogl0Ioooool1o`00007ooooo00000ol0003oooooooooo`3o
oooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003
o`000?oooooooooo07_ooooo0_ooO`2Nooooo`7o00000Oooool00003o`000?oooooooooo07[ooooo
1?ooO`2Mooooo`7o00000Oooool00003o`000?oooooooooo07[ooooo1?ooO`0Pooooo`;oogl0Nooo
ool1o`00007ooooo00000ol0003oooooooooo`1kooooo`;oogl08?ooool4oomo07[ooooo0Ol00001
ooooo`0000?o0000ooooooooool0WOooool4oomo07[ooooo0Ol00001ooooo`0000?o0000oooooooo
ool0T?ooool2oomo00cooooo0_ooO`1kooooo`7o00000Oooool00003o`000?oooooooooo08oooooo
1?ooO`28ooooo`7o00000Oooool00003o`000?oooooooooo08oooooo1?ooO`28ooooo`7o00000Ooo
ool00003o`000?oooooooooo093ooooo0_ooO`0Sooooo`;oogl0I?ooool1o`00007ooooo00000ol0
003oooooooooo`2dooooo`Coogl0Hoooool1o`00007ooooo00000ol0003oooooooooo`2dooooo`Co
ogl0Hoooool1o`00007ooooo00000ol0003oooooooooo`2eooooo`;oogl0I?ooool1o`00007ooooo
00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolL
ooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003o
ooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o0000
0Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3o
oooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003
o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo
0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oooooo
oooo0?oooooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001oooo
o`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo
7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000
ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00
007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0
oooooolLooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo0000
0ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLoooo
o`7o00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003ooooo
ooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Ooo
ool00003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooo
oacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`00
0?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol0
0001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo
0?oooooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`00
00?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?oo
ool1o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000oooo
ooooool0S_ooool2oomo08_ooooo0Ol00001ooooo`0000?o0000ooooooooool0SOooool4oomo08[o
oooo0Ol00001ooooo`0000?o0000ooooooooool0SOooool4oomo08[ooooo0Ol00001ooooo`0000?o
0000ooooooooool0S_ooool2oomo08_ooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolL
ooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003o
ooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o0000
0Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3o
oooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003
o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo
0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oooooo
oooo0?oooooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001oooo
o`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo
7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000
ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00
007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0
oooooolLooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo0000
0ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`00ool0000Po`00007ooooo0000\
\>"],
  ImageRangeCache->{{{0, 287}, {287, 0}} -> {-1.01089, -1.01089, 0.00704453, \
0.00704453}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.49505 0.5 0.49505 [
[ 0 0 -0.125 0 ]
[ 0 0 -0.125 0 ]
[ 0 1 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
0 0 m
1 0 L
s
0 0 m
0 1 L
s
0 1 m
1 1 L
s
1 0 m
1 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
1 .5 0 r
.015 w
.03175 .1355 Mdot
.03435 .12523 Mdot
.11137 .12765 Mdot
.14107 .18841 Mdot
.16218 .24538 Mdot
.17294 .21053 Mdot
.18267 .18577 Mdot
.18434 .1304 Mdot
.18553 .30956 Mdot
.20401 .239 Mdot
.21247 .27571 Mdot
.21687 .20845 Mdot
.22376 .2799 Mdot
.22832 .27485 Mdot
.29063 .20974 Mdot
.29686 .25079 Mdot
.30487 .22936 Mdot
.30683 .34623 Mdot
.32055 .20902 Mdot
.32574 .21979 Mdot
.34472 .28521 Mdot
.35998 .36393 Mdot
.36335 .24976 Mdot
.3794 .36608 Mdot
.42386 .66992 Mdot
.44391 .74519 Mdot
.45059 .34198 Mdot
.47208 .67586 Mdot
.47436 .71381 Mdot
.49778 .59825 Mdot
.50874 .91643 Mdot
.51516 .76219 Mdot
.53655 .61374 Mdot
.56563 .75219 Mdot
.59189 .65665 Mdot
.59581 .61604 Mdot
.59923 .6556 Mdot
.60292 .68499 Mdot
.62656 .67779 Mdot
.63555 .72451 Mdot
.63919 .652 Mdot
.64169 .6004 Mdot
.64246 .58611 Mdot
.64496 .54267 Mdot
.64608 .77288 Mdot
.65077 .64308 Mdot
.66065 .57816 Mdot
.67474 .59169 Mdot
.69296 .563 Mdot
.72815 .65902 Mdot
.73169 .58879 Mdot
.74669 .61318 Mdot
.74821 .65474 Mdot
.75963 .63781 Mdot
.79673 .57809 Mdot
.80925 .55852 Mdot
.81525 .58444 Mdot
.83417 .62985 Mdot
.83598 .55526 Mdot
.91595 .49319 Mdot
1 0 0 r
.005 w
.16128 .17044 m
.18734 .17269 L
.21339 .17909 L
.2345 .18734 L
.23945 .19126 L
.2655 .20415 L
.27874 .21339 L
.29156 .22295 L
.31204 .23945 L
.31761 .24532 L
.33549 .2655 L
.34367 .28341 L
.34499 .29156 L
.34367 .29798 L
.31761 .3104 L
.29156 .30711 L
.2655 .30014 L
.24507 .29156 L
.23945 .28747 L
.21339 .27402 L
.20155 .2655 L
.18734 .25472 L
.16884 .23945 L
.16128 .2313 L
.14618 .21339 L
.13806 .18734 L
.16128 .17044 L
s
0 0 1 r
.65633 .57701 m
.68239 .56842 L
.70844 .56313 L
.7345 .56168 L
.76055 .5752 L
.76359 .57817 L
.76859 .60422 L
.76055 .62333 L
.75627 .63028 L
.7345 .65485 L
.73298 .65633 L
.70844 .6775 L
.69922 .68239 L
.68239 .69294 L
.65633 .70579 L
.64983 .70844 L
.63028 .71539 L
.60422 .72268 L
.57817 .72651 L
.55211 .7214 L
.53145 .70844 L
.52926 .68239 L
.54239 .65633 L
.55211 .63983 L
.56625 .63028 L
.57817 .6193 L
.60119 .60422 L
.60422 .60227 L
.63028 .58726 L
.65315 .57817 L
.65633 .57701 L
s
1 0 0 r
.03 w
.24141 .24033 Mdot
0 0 1 r
.64872 .64417 Mdot
1 0 0 r
.79703 .00495 m
.79703 .00495 L
.87129 .00495 L
.87129 .00495 L
F
0 0 1 r
.89604 .00495 m
.89604 .25248 L
.9703 .25248 L
.9703 .00495 L
F
1 0 1 r
.04 w
.50874 .91643 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P000182000`400?l00000o`00003ooooooolQ
ooooo`00ool0000Po`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`00
00?o0000ooooooooool0o_oooolEo`00o`Sooooo0Ol00001ooooo`0000?o0000ooooooooool0o_oo
oolEo`00o`Sooooo0Ol00001ooooo`0000?o0000ooooooooool0o_oooolEo`00o`Sooooo0Ol00001
ooooo`0000?o0000ooooooooool0o_oooolEo`00o`Sooooo0Ol00001ooooo`0000?o0000oooooooo
ool0o_oooolEo`00o`Sooooo0Ol00001ooooo`0000?o0000ooooooooool0o_oooolEo`00o`Sooooo
0Ol00001ooooo`0000?o0000ooooooooool0o_oooolEo`00o`Sooooo0Ol00001ooooo`0000?o0000
ooooooooool0o_oooolEo`00o`Sooooo0Ol00001ooooo`0000?o0000ooooooooool0o_oooolEo`00
o`Sooooo0Ol00001ooooo`0000?o0000ooooooooool0o_oooolEo`00o`Sooooo0Ol00001ooooo`00
00?o0000ooooooooool0o_oooolEo`00o`Sooooo0Ol00001ooooo`0000?o0000ooooooooool0o_oo
oolEo`00o`Sooooo0Ol00001ooooo`0000?o0000ooooooooool0o_oooolEo`00o`Sooooo0Ol00001
ooooo`0000?o0000ooooooooool0o_oooolEo`00o`Sooooo0Ol00001ooooo`0000?o0000oooooooo
ool0o_oooolEo`00o`Sooooo0Ol00001ooooo`0000?o0000ooooooooool0o_oooolEo`00o`Sooooo
0Ol00001ooooo`0000?o0000ooooooooool0o_oooolEo`00o`Sooooo0Ol00001ooooo`0000?o0000
ooooooooool0o_oooolEo`00o`Sooooo0Ol00001ooooo`0000?o0000ooooooooool0o_oooolEo`00
o`Sooooo0Ol00001ooooo`0000?o0000ooooooooool0o_oooolEo`00o`Sooooo0Ol00001ooooo`00
00?o0000ooooooooool0o_oooolEo`00o`Sooooo0Ol00001ooooo`0000?o0000ooooooooool0o_oo
oolEo`00o`Sooooo0Ol00001ooooo`0000?o0000ooooooooool0o_oooolEo`00o`Sooooo0Ol00001
ooooo`0000?o0000ooooooooool0o_oooolEo`00o`Sooooo0Ol00001ooooo`0000?o0000oooooooo
ool0o_oooolEo`00o`Sooooo0Ol00001ooooo`0000?o0000ooooooooool0o_oooolEo`00o`Sooooo
0Ol00001ooooo`0000?o0000ooooooooool0o_oooolEo`00o`Sooooo0Ol00001ooooo`0000?o0000
ooooooooool0o_oooolEo`00o`Sooooo0Ol00001ooooo`0000?o0000ooooooooool0o_oooolEo`00
o`Sooooo0Ol00001ooooo`0000?o0000ooooooooool0o_oooolEo`00o`Sooooo0Ol00001ooooo`00
00?o0000ooooooooool0o_oooolEo`00o`Sooooo0Ol00001ooooo`0000?o0000ooooooooool0o_oo
oolEo`00o`Sooooo0Ol00001ooooo`0000?o0000ooooooooool01_ooool2oomo0?Kooooo5Ol00?l8
ooooo`7o00000Oooool00003o`000?oooooooooo00Gooooo1?ooO`0Cooooo`;oogl0h?oooolEo`00
o`Sooooo0Ol00001ooooo`0000?o0000ooooooooool01Oooool4oomo01;ooooo1?ooO`0Booooo`;o
ogl0booooolEo`00o`Sooooo0Ol00001ooooo`0000?o0000ooooooooool01Oooool3oomo01?ooooo
1?ooO`0Aooooo`Coogl0b_oooolEo`00o`Sooooo0Ol00001ooooo`0000?o0000ooooooooool01?oo
ool4oomo01Cooooo0_ooO`0Booooo`Coogl0b_oooolEo`00o`Sooooo0Ol00001ooooo`0000?o0000
ooooooooool01?ooool4oomo02Wooooo0_ooO`3;oooooaGo003o2?ooool1o`00007ooooo00000ol0
003oooooooooo`05ooooo`;oogl0mooooolEo`00o`Sooooo0Ol00001ooooo`0000?o0000oooooooo
ool0o_oooolEo`00o`Sooooo0Ol00001ooooo`0000?o0000ooooooooool0o_oooolEo`00o`Sooooo
0Ol00001ooooo`0000?o0000ooooooooool0o_oooolEo`00o`Sooooo0Ol00001ooooo`0000?o0000
ooooooooool0o_oooolEo`00o`Sooooo0Ol00001ooooo`0000?o0000ooooooooool0o_oooolEo`00
o`Sooooo0Ol00001ooooo`0000?o0000ooooooooool0o_oooolEo`00o`Sooooo0Ol00001ooooo`00
00?o0000ooooooooool0o_oooolEo`00o`Sooooo0Ol00001ooooo`0000?o0000ooooooooool0:_oo
ool6ool00<kooooo5Ol00?l8ooooo`7o00000Oooool00003o`000?oooooooooo02Wooooo00?oo`00
ooooooooool01?ooool5ool00<Wooooo5Ol00?l8ooooo`7o00000Oooool00003o`000?oooooooooo
02Oooooo0_oo000<ooooo`Coo`00aOoooolEo`00o`Sooooo0Ol00001ooooo`0000?o0000oooooooo
ool09_ooool00ooo003oooooooooo`0@ooooo`Coo`00`OoooolEo`00o`Sooooo0Ol00001ooooo`00
00?o0000ooooooooool09?ooool00oooO`3oo`00ooooo`09ooooo`;oogl02oooool3ool00;kooooo
5Ol00?l8ooooo`7o00000Oooool00003o`000?oooooooooo02?ooooo00Coogl0ool00?ooO`3oogl0
2?ooool4oomo00gooooo00?oo`00ooooooooool0^ooooolEo`00o`Sooooo0Ol00001ooooo`0000?o
0000ooooooooool08oooool01?ooO`3oo`00oomo0?ooO`08ooooo`Coogl03_ooool2ool00;_ooooo
5Ol00?l8ooooo`7o00000Oooool00003o`000?oooooooooo02Cooooo00?oogl0ool00?ooool02Ooo
ool2oomo017ooooo0_oo002ioooooaGo003o2?ooool1o`00007ooooo00000ol0003oooooooooo`0U
ooooo`03ool00?oooooooooo01gooooo0_oo002goooooaGo003o2?ooool1o`00007ooooo00000ol0
003oooooooooo`0Uooooo`03ool00?oooooooooo01oooooo0_oo002eoooooaGo003o2?ooool1o`00
007ooooo00000ol0003oooooooooo`0Vooooo`03ool00?oooooooooo017ooooo0_ooO`0=ooooo`;o
o`001?ooool2oomo00Oooooo0_ooO`2ToooooaGo003o2?ooool1o`00007ooooo00000ol0003ooooo
ooooo`0Vooooo`03ool00?oooooooooo00Gooooo0_ooO`09ooooo`Coogl03_ooool00ooo003ooooo
ooooo`04oomo00Gooooo1?ooO`2SoooooaGo003o2?ooool1o`00007ooooo00000ol0003ooooooooo
o`0Vooooo`03ool00?oooooooooo00Cooooo1?ooO`08ooooo`Coogl03oooool00ooo003ooooooomo
0003oomo00Gooooo1?ooO`2SoooooaGo003o2?ooool1o`00007ooooo00000ol0003oooooooooo`0W
ooooo`03ool00?oooooooooo00?ooooo1?ooO`09ooooo`;oogl04Oooool01?oo003ooooooomo0?oo
O`07ooooo`?oogl0XooooolEo`00o`Sooooo0Ol00001ooooo`0000?o0000ooooooooool09oooool0
0ooo003oooooooooo`04ooooo`;oogl07_ooool00ooo003oooooooooo`07ooooo`Coogl0X_oooolE
o`00o`Sooooo0Ol00001ooooo`0000?o0000ooooooooool0:?ooool00ooo003oooooooooo`0Toooo
o`03ool00?oooooooooo00Kooooo1?ooO`2RoooooaGo003o2?ooool1o`00007ooooo00000ol0003o
ooooooooo`0Yooooo`03ool00?oooooooooo02Cooooo0_oo00000oooooooogl0oomo0004ooooo`;o
ogl0XooooolEo`00o`Sooooo0Ol00001ooooo`0000?o0000ooooooooool0:_ooool00ooo003ooooo
ooooo`0Cooooo`Coo`003_ooool01?oo003oogl0oomo0?ooO`2XoooooaGo003o2?ooool1o`00007o
oooo00000ol0003oooooooooo`0[ooooo`03ool00?oooooooooo017ooooo1_oo000=ooooo`04oomo
0?oo003oo`00oomo0:Sooooo5Ol00?l8ooooo`7o00000Oooool00003o`000?oooooooooo02cooooo
00?oo`00ooooooooool02?ooool2oomo00Gooooo2?oo000=ooooo`;oogl000?oo`00ooooooooool0
Y_oooolEo`00o`Sooooo0Ol00001ooooo`0000?o0000ooooooooool0;Oooool00ooo003ooooooooo
o`06ooooo`Coogl01?ooool8ool0013ooooo00?oo`00ooooooooool0YOoooolEo`00o`Sooooo0Ol0
0001ooooo`0000?o0000ooooooooool0:oooool2oomo0003oooooooo003ooooo00Kooooo1?ooO`04
ooooo`Soo`004Oooool00ooo003oooooooooo`2ToooooaGo003o2?ooool1o`00007ooooo00000ol0
003oooooooooo`0Zooooo`Coogl000?oooooool00?ooool01_ooool2oomo00Gooooo2?oo000;oooo
o`;oogl01Oooool00ooo003oooooooooo`09ooooo`;oogl0V?oooolEo`00o`Sooooo0Ol00001oooo
o`0000?o0000ooooooooool0:_ooool4oomo00;ooooo00?oo`00ooooooooool03?ooool6ool000_o
oooo1?ooO`04ooooo`03ool00?oooooooooo00Sooooo1?ooO`2GoooooaGo003o2?ooool1o`00007o
oooo00000ol0003oooooooooo`0[ooooo`;oogl01?ooool00ooo003oooooooooo`0<ooooo`Coo`00
3?ooool4oomo00Gooooo00?oo`00ooooooooool01oooool4oomo09Oooooo5Ol00?l8ooooo`7o0000
0Oooool00003o`000?oooooooooo03;ooooo0_oo000Mooooo`;oogl01oooool00ooo003ooooooooo
o`07ooooo`;oogl0]Oooool1o`00007ooooo00000ol0003oooooooooo`0dooooo`03ool00?oooooo
oooo02Cooooo00?oo`00ooooooooool0_Oooool1o`00007ooooo00000ol0003oooooooooo`0eoooo
o`03ool00?oooooooooo02Cooooo00?oo`00ooooooooool0_?ooool1o`00007ooooo00000ol0003o
ooooooooo`0fooooo`;oo`009Oooool00ooo003oooooooooo`2kooooo`7o00000Oooool00003o`00
0?oooooooooo03Sooooo0_oo00000oooO`3oooooooooo`02oomo01kooooo00?oo`00ooooooooool0
^oooool1o`00007ooooo00000ol0003oooooooooo`0hooooo`;oogl00_oo0004oomo01kooooo00?o
o`00ooooooooool0^_ooool1o`00007ooooo00000ol0003oooooooooo`0hooooo`Coogl00_oo0002
oomo01kooooo00?oo`00ooooooooool0^_ooool1o`00007ooooo00000ol0003oooooooooo`0ioooo
o`Googl000?oo`00ooooooooool07Oooool00ooo003oogl0oomo002jooooo`7o00000Oooool00003
o`000?oooooooooo03_ooooo1?ooO`02ool001gooooo00Coogl0ool00?ooO`3oogl0^Oooool1o`00
007ooooo00000ol0003oooooooooo`0looooo`;oogl00oooool2ool001_ooooo00Coogl0ool00?oo
O`3oogl0^Oooool1o`00007ooooo00000ol0003oooooooooo`13ooooo`;oo`006_ooool00oooO`3o
o`00ooooo`2iooooo`7o00000Oooool00003o`000?oooooooooo04Gooooo0_oo000Iooooo`03ool0
0?oooooooooo0;Sooooo0Ol00001ooooo`0000?o0000ooooooooool0Aoooool2ool001Gooooo0_oo
002kooooo`7o00000Oooool00003o`000?oooooooooo04Wooooo0ooo000@ooooo`;oo`00_Oooool1
o`00007ooooo00000ol0003oooooooooo`0aooooo`;oogl06Oooool3ool000cooooo00?oo`00oooo
ooooool0_Oooool1o`00007ooooo00000ol0003oooooooooo`0`ooooo`Coogl06oooool6ool000Co
oooo0_oo0030ooooo`7o00000Oooool00003o`000?oooooooooo033ooooo1?ooO`0Qooooo`Coo`00
`_ooool1o`00007ooooo00000ol0003oooooooooo`0aooooo`;oogl0j?ooool1o`00007ooooo0000
0ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLoooo
o`7o00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003ooooo
ooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Ooo
ool00003o`000?oooooooooo07gooooo0_ooO`2Looooo`7o00000Oooool00003o`000?oooooooooo
07cooooo1?ooO`2Kooooo`7o00000Oooool00003o`000?oooooooooo05Cooooo0_ooO`0Vooooo`Co
ogl0Voooool1o`00007ooooo00000ol0003oooooooooo`1Cooooo`Coogl09_ooool2oomo09cooooo
0Ol00001ooooo`0000?o0000ooooooooool0Doooool4oomo0<Cooooo0Ol00001ooooo`0000?o0000
ooooooooool0E?ooool2oomo0<Gooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLoooo
o`7o00000Oooool00003o`000?oooooooooo06?ooooo0_ooO`04ooooo`;oogl0/?ooool1o`00007o
oooo00000ol0003oooooooooo`1Rooooo`Coogl00_ooool4oomo0:oooooo0Ol00001ooooo`0000?o
0000ooooooooool0H_ooool4oomo00;ooooo1?ooO`2_ooooo`7o00000Oooool00003o`000?oooooo
oooo06?ooooo0_ooO`04ooooo`;oogl0/?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooo
oacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`00
0?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol0
0001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo
0?oooooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`00
00?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?oo
ool1o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000oooo
ooooool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007o
oooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooo
oolLooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0
003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o
00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003ooooooooo
o`3ooooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool0
0003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooooaco
oooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oo
oooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001
ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo0?oo
oooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o
0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1
o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000oooooooo
ool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo
00000ol0003oooooooooo`3oooooo`Cooooo0_ooO`0Fooooo`7o00000Oooool00003o`000?oooooo
oooo0?oooooo0oooool4oomo01Gooooo0Ol00001ooooo`0000?o0000ooooooooool0ooooool3oooo
o`Coogl05Oooool1o`00007ooooo00000ol0003oooooooooo`3oooooo`Cooooo0_ooO`0Fooooo`7o
00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003ooooooooo
o`3ooooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool0
0003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooooaco
oooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oo
oooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001
ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo0?oo
oooo7?ooool1o`00007ooooo00000ol0003oooooooooo`2eooooo`;oogl0I?ooool1o`00007ooooo
00000ol0003oooooooooo`2dooooo`Coogl0Hoooool1o`00007ooooo00000ol0003oooooooooo`2d
ooooo`Coogl0Hoooool1o`00007ooooo00000ol0003oooooooooo`2eooooo`;oogl0=Oooool2oomo
02gooooo0Ol00001ooooo`0000?o0000ooooooooool0i?ooool2oomo00Gooooo1?ooO`0/ooooo`7o
00000Oooool00003o`000?oooooooooo0>?ooooo1?ooO`04ooooo`Coogl0;?ooool1o`00007ooooo
00000ol0003oooooooooo`33ooooo`;oogl07_ooool4oomo00Gooooo0_ooO`0]ooooo`7o00000Ooo
ool00003o`000?oooooooooo0<;ooooo1?ooO`0;o`00oa?ooooo0_ooO`0eooooo`7o00000Oooool0
0003o`000?oooooooooo0<;ooooo1?l00?l;ooooo`;o003oB?ooool1o`00007ooooo00000ol0003o
ooooooooo`2nooooo`Co003o00?ooooooomo0?ooO`003_ooool2o`00odKooooo0Ol00001ooooo`00
00?o0000ooooooooool0^Oooool2oomo00?o003o5oooool2o`00o`Wooooo0_ooO`0iooooo`7o0000
0Oooool00003o`000?oooooooooo0;Oooooo1?l00?l00oooO`3oooooooooo`0Iooooo`;o003o1_oo
ool4oomo03Sooooo0Ol00001ooooo`0000?o0000ooooooooool0]?ooool3o`00o`03ooooooooO`3o
ogl000;oogl07?ooool00ol00?ooooooooooo`04ooooo`Coogl00oooool2oomo03?ooooo0Ol00001
ooooo`0000?o0000ooooooooool0/_ooool2o`00o`?oogl00_ooool2oomo01?ooooo0_ooO`08oooo
o`03o`00oooooooooooo00Gooooo0_ooO`03ooooo`Coogl0<_ooool1o`00007ooooo00000ol0003o
ooooooooo`2`ooooo`;o003o00?ooooooomo0?ooO`000_ooO`06ooooo`;oogl03_ooool4oomo00Oo
oooo00?o003oooooooooool02_ooool4oomo03;ooooo0Ol00001ooooo`0000?o0000ooooooooool0
[_ooool2o`00o`Cooooo0_ooO`06ooooo`Coogl03Oooool4oomo00Oooooo00?o003oooooooooool0
2oooool2oomo03?ooooo0Ol00001ooooo`0000?o0000ooooooooool0Roooool2oomo023ooooo00?o
003oooooooooool01?ooool2oomo00Kooooo1?ooO`0>ooooo`;oogl02Oooool00ol00?oooooooooo
o`0oooooo`7o00000Oooool00003o`000?oooooooooo08[ooooo1?ooO`0Mooooo`;o003o1_ooool4
oomo00Kooooo0_ooO`0Jooooo`03o`00oooooooooooo03oooooo0Ol00001ooooo`0000?o0000oooo
ooooool0R_ooool4oomo01cooooo00?o003oooooooooool01_ooool4oomo02;ooooo00?o003ooooo
ooooool0?oooool1o`00007ooooo00000ol0003oooooooooo`2;ooooo`;oogl06oooool2o`00o`[o
oooo0_ooO`0Sooooo`03o`00oooooooooooo03oooooo0Ol00001ooooo`0000?o0000ooooooooool0
U_ooool2oomo00kooooo0_l00?lZooooo`;oogl01Oooool00ol00?ooooooooooo`0oooooo`7o0000
0Oooool00003o`000?oooooooooo09Gooooo1?ooO`0<ooooo`04o`00ooooooooogl0oomo02Sooooo
1?ooO`03ooooo`03o`00oooooooooooo043ooooo0Ol00001ooooo`0000?o0000ooooooooool0UOoo
ool4oomo00[ooooo0_l00?l00oooooooogl0oomo0002oomo02Oooooo1?ooO`03ooooo`03o`00oooo
oooooooo043ooooo0Ol00001ooooo`0000?o0000ooooooooool0U_ooool2oomo00[ooooo00Co003o
oooooooooooooooo1?ooO`0Xooooo`;oogl01?ooool00ol00?ooooooooooo`10ooooo`7o00000Ooo
ool00003o`000?oooooooooo0:7ooooo00?o003oooooooooool00oooool2oomo02kooooo00?o003o
ooooooooool0@Oooool1o`00007ooooo00000ol0003oooooooooo`2Pooooo`03o`00oooooooooooo
03?ooooo00?o003oooooooooool04_ooool2oomo02kooooo0Ol00001ooooo`0000?o0000oooooooo
ool0W_ooool2o`00ocGooooo00?o003oooooooooool04_ooool4oomo02gooooo0Ol00001ooooo`00
00?o0000ooooooooool0WOooool00ol00?ooooooooooo`0Eooooo`Co003o7?ooool00ol00?ooogl0
oomo000Booooo`Coogl0;Oooool1o`00007ooooo00000ol0003oooooooooo`2Looooo`03o`00oooo
oooooooo01Gooooo1_l00?lJooooo`03o`00ooooO`3oogl000;oogl04_ooool2oomo02kooooo0Ol0
0001ooooo`0000?o0000ooooooooool0Voooool00ol00?ooooooooooo`0Eooooo`So003o6?ooool0
0ol00?oooooooomo0003oomo04;ooooo0Ol00001ooooo`0000?o0000ooooooooool0Voooool00ol0
0?ooooooooooo`0Eooooo`So003o5oooool01?l00?ooooooooooooooool2oomo04?ooooo0Ol00001
ooooo`0000?o0000ooooooooool0V_ooool00ol00?ooooooooooo`0Fooooo`So003o5_ooool00ol0
0?ooooooooooo`17ooooo`7o00000Oooool00003o`000?oooooooooo09Wooooo00?o003ooooooooo
ool03?ooool2oomo00Sooooo00?oogl0o`00ool00?l01_l00?lEooooo`03o`00oooooooooooo00;o
ogl0A_ooool1o`00007ooooo00000ol0003oooooooooo`2Iooooo`03o`00oooooooooooo00[ooooo
1OooO`07ooooo`;oogl01_l00?lCooooo`;oogl000?o003oooooooooool01?ooO`15ooooo`7o0000
0Oooool00003o`000?oooooooooo09Sooooo00?o003oooooooooool02_ooool6oomo00Sooooo0_oo
O`04o`00oa?ooooo0_ooO`02o`00o`;ooooo1?ooO`15ooooo`7o00000Oooool00003o`000?oooooo
oooo09Sooooo00?o003oooooooooool02_ooool5oomo02;ooooo00Coogl0o`00ooooO`3oogl00ooo
ool2oomo04Kooooo0Ol00001ooooo`0000?o0000ooooooooool0M_ooool2oomo01oooooo00?o003o
ooooooooool03?ooool2oomo02Cooooo00?o003ooomo0?ooO`00C?ooool1o`00007ooooo00000ol0
003oooooooooo`1eooooo`Coogl07_ooool00ol00?ooooooooooo`0aooooo`03o`00oooooooooooo
04gooooo0Ol00001ooooo`0000?o0000ooooooooool0MOooool4oomo00[ooooo0_ooO`0Aooooo`03
o`00oooooooooooo037ooooo00?o003oooooooooool0C_ooool1o`00007ooooo00000ol0003ooooo
ooooo`1fooooo`;oogl02_ooool4oomo00oooooo00?o003oooooooooool06?ooool2oomo01Oooooo
00?o003oooooooooool0Coooool1o`00007ooooo00000ol0003oooooooooo`22ooooo`Coogl03ooo
ool00ol00?ooooooooooo`0Gooooo`Coogl05?ooool2o`00oe;ooooo0Ol00001ooooo`0000?o0000
ooooooooool0Poooool2oomo00oooooo00?o003oooooooooool04_ooool2oomo00Cooooo1?ooO`0A
ooooo`?o003oE?ooool1o`00007ooooo00000ol0003oooooooooo`2Dooooo`03o`00oooooooooooo
017ooooo1?ooO`04ooooo`;oogl04?ooool2o`00oeOooooo0Ol00001ooooo`0000?o0000oooooooo
ool0U?ooool00ol00?ooooooooooo`0Aooooo`Coogl05Oooool00ol00?ooooooooooo`1Gooooo`7o
00000Oooool00003o`000?oooooooooo09Cooooo00?o003oooooooooool04_ooool2oomo01Cooooo
0_l00?mJooooo`7o00000Oooool00003o`000?oooooooooo09Cooooo00?o003oooooooooool09_oo
ool2o`00oecooooo0Ol00001ooooo`0000?o0000ooooooooool0UOooool00ol00?ooooooooooo`0T
ooooo`03o`00oooooooooooo05cooooo0Ol00001ooooo`0000?o0000ooooooooool0UOooool00ol0
0?ooooooooooo`0Rooooo`;o003oGoooool1o`00007ooooo00000ol0003oooooooooo`2Eooooo`03
o`00oooooooooooo023ooooo0_l00?mQooooo`7o00000Oooool00003o`000?oooooooooo08Cooooo
0_ooO`0?ooooo`;o003o7oooool2o`00of?ooooo0Ol00001ooooo`0000?o0000ooooooooool0Pooo
ool4oomo013ooooo0_l00?lJooooo`?o003oIOooool1o`00007ooooo00000ol0003oooooooooo`23
ooooo`Coogl04_ooool2o`00oaCooooo1?l00?mXooooo`7o00000Oooool00003o`000?oooooooooo
08Cooooo0_ooO`0Eooooo`?o003o3_ooool3o`00o`?ooooo0_ooO`1Wooooo`7o00000Oooool00003
o`000?oooooooooo09kooooo0ol00?l5ooooo`Ko003o1Oooool4oomo06Kooooo0Ol00001ooooo`00
00?o0000ooooooooool0XOooool5o`00o`_ooooo1?ooO`1Vooooo`7o00000Oooool00003o`000?oo
oooooooo0;;ooooo0_ooO`1Wooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1
o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000oooooooo
ool0Noooool2oomo09kooooo0Ol00001ooooo`0000?o0000ooooooooool0N_ooool4oomo09gooooo
0Ol00001ooooo`0000?o0000ooooooooool0N_ooool4oomo023ooooo0_ooO`1kooooo`7o00000Ooo
ool00003o`000?oooooooooo07_ooooo0_ooO`0Pooooo`Coogl0N_ooool1o`00007ooooo00000ol0
003oooooooooo`2Mooooo`Coogl0N_ooool1o`00007ooooo00000ol0003oooooooooo`2@ooooo`;o
ogl03?ooool2oomo07_ooooo0Ol00001ooooo`0000?o0000ooooooooool0Soooool4oomo08Sooooo
0Ol00001ooooo`0000?o0000ooooooooool0Soooool4oomo08Sooooo0Ol00001ooooo`0000?o0000
ooooooooool0T?ooool2oomo02?ooooo0_ooO`1Tooooo`7o00000Oooool00003o`000?oooooooooo
0;Cooooo1?ooO`1Sooooo`7o00000Oooool00003o`000?oooooooooo0;Cooooo1?ooO`1Sooooo`7o
00000Oooool00003o`000?oooooooooo0;Gooooo0_ooO`1Tooooo`7o00000Oooool00003o`000?oo
oooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001
ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo0?oo
oooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o
0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1
o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000oooooooo
ool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo
00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolL
ooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003o
ooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o0000
0Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3o
oooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003
o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo
0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oooooo
oooo0?oooooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001oooo
o`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo
7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000
ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00
007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0
oooooolLooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo0000
0ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLoooo
o`7o00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003ooooo
ooooo`2<ooooo`Goo`3oR_ooool1o`00007ooooo00000ol0003oooooooooo`2;ooooo`Ooo`3oROoo
ool1o`00007ooooo00000ol0003oooooooooo`2:ooooo`Woo`3oR?ooool1o`00007ooooo00000ol0
003oooooooooo`29ooooo`_oo`3oQoooool1o`00007ooooo00000ol0003oooooooooo`29ooooo`_o
o`3oQoooool1o`00007ooooo00000ol0003oooooooooo`29ooooo`_oo`3oQoooool1o`00007ooooo
00000ol0003oooooooooo`29ooooo`_oo`3oQoooool1o`00007ooooo00000ol0003oooooooooo`29
ooooo`_oo`3oQoooool1o`00007ooooo00000ol0003oooooooooo`2:ooooo`Woo`3oR?ooool1o`00
007ooooo00000ol0003oooooooooo`2;ooooo`Ooo`3oROooool1o`00007ooooo00000ol0003ooooo
ooooo`2<ooooo`Goo`3oR_ooool1o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol0
0001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo
0?oooooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`00
00?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?oo
ool1o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000oooo
ooooool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007o
oooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooo
oolLooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0
003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o
00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003ooooooooo
o`3ooooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool0
0?oo00008?l00001ooooo`00\
\>"],
  ImageRangeCache->{{{0, 287}, {287, 0}} -> {-1.01089, -1.01089, 0.00704453, \
0.00704453}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.49505 0.5 0.49505 [
[ 0 0 -0.125 0 ]
[ 0 0 -0.125 0 ]
[ 0 1 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
0 0 m
1 0 L
s
0 0 m
0 1 L
s
0 1 m
1 1 L
s
1 0 m
1 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
1 .5 0 r
.015 w
.03175 .1355 Mdot
.03435 .12523 Mdot
.11137 .12765 Mdot
.14107 .18841 Mdot
.16218 .24538 Mdot
.17294 .21053 Mdot
.18267 .18577 Mdot
.18434 .1304 Mdot
.18553 .30956 Mdot
.20401 .239 Mdot
.21247 .27571 Mdot
.21687 .20845 Mdot
.22376 .2799 Mdot
.22832 .27485 Mdot
.29063 .20974 Mdot
.29686 .25079 Mdot
.30487 .22936 Mdot
.30683 .34623 Mdot
.32055 .20902 Mdot
.32574 .21979 Mdot
.34472 .28521 Mdot
.35998 .36393 Mdot
.36335 .24976 Mdot
.3794 .36608 Mdot
.42386 .66992 Mdot
.44391 .74519 Mdot
.45059 .34198 Mdot
.47208 .67586 Mdot
.47436 .71381 Mdot
.49778 .59825 Mdot
.50874 .91643 Mdot
.51516 .76219 Mdot
.53655 .61374 Mdot
.56563 .75219 Mdot
.59189 .65665 Mdot
.59581 .61604 Mdot
.59923 .6556 Mdot
.60292 .68499 Mdot
.62656 .67779 Mdot
.63555 .72451 Mdot
.63919 .652 Mdot
.64169 .6004 Mdot
.64246 .58611 Mdot
.64496 .54267 Mdot
.64608 .77288 Mdot
.65077 .64308 Mdot
.66065 .57816 Mdot
.67474 .59169 Mdot
.69296 .563 Mdot
.72815 .65902 Mdot
.73169 .58879 Mdot
.74669 .61318 Mdot
.74821 .65474 Mdot
.75963 .63781 Mdot
.79673 .57809 Mdot
.80925 .55852 Mdot
.81525 .58444 Mdot
.83417 .62985 Mdot
.83598 .55526 Mdot
.91595 .49319 Mdot
1 0 0 r
.005 w
.16128 .17044 m
.18734 .17269 L
.21339 .17909 L
.2345 .18734 L
.23945 .19126 L
.2655 .20415 L
.27874 .21339 L
.29156 .22295 L
.31204 .23945 L
.31761 .24532 L
.33549 .2655 L
.34367 .28341 L
.34499 .29156 L
.34367 .29798 L
.31761 .3104 L
.29156 .30711 L
.2655 .30014 L
.24507 .29156 L
.23945 .28747 L
.21339 .27402 L
.20155 .2655 L
.18734 .25472 L
.16884 .23945 L
.16128 .2313 L
.14618 .21339 L
.13806 .18734 L
.16128 .17044 L
s
0 0 1 r
.65633 .57701 m
.68239 .56842 L
.70844 .56313 L
.7345 .56168 L
.76055 .5752 L
.76359 .57817 L
.76859 .60422 L
.76055 .62333 L
.75627 .63028 L
.7345 .65485 L
.73298 .65633 L
.70844 .6775 L
.69922 .68239 L
.68239 .69294 L
.65633 .70579 L
.64983 .70844 L
.63028 .71539 L
.60422 .72268 L
.57817 .72651 L
.55211 .7214 L
.53145 .70844 L
.52926 .68239 L
.54239 .65633 L
.55211 .63983 L
.56625 .63028 L
.57817 .6193 L
.60119 .60422 L
.60422 .60227 L
.63028 .58726 L
.65315 .57817 L
.65633 .57701 L
s
1 0 0 r
.03 w
.24141 .24033 Mdot
0 0 1 r
.64872 .64417 Mdot
1 0 0 r
.79703 .00495 m
.79703 .00495 L
.87129 .00495 L
.87129 .00495 L
F
0 0 1 r
.89604 .00495 m
.89604 .25248 L
.9703 .25248 L
.9703 .00495 L
F
1 0 1 r
.04 w
.51516 .76219 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P000182000`400?l00000o`00003ooooooolQ
ooooo`00ool0000Po`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`00
00?o0000ooooooooool0o_oooolEo`00o`Sooooo0Ol00001ooooo`0000?o0000ooooooooool0o_oo
oolEo`00o`Sooooo0Ol00001ooooo`0000?o0000ooooooooool0o_oooolEo`00o`Sooooo0Ol00001
ooooo`0000?o0000ooooooooool0o_oooolEo`00o`Sooooo0Ol00001ooooo`0000?o0000oooooooo
ool0o_oooolEo`00o`Sooooo0Ol00001ooooo`0000?o0000ooooooooool0o_oooolEo`00o`Sooooo
0Ol00001ooooo`0000?o0000ooooooooool0o_oooolEo`00o`Sooooo0Ol00001ooooo`0000?o0000
ooooooooool0o_oooolEo`00o`Sooooo0Ol00001ooooo`0000?o0000ooooooooool0o_oooolEo`00
o`Sooooo0Ol00001ooooo`0000?o0000ooooooooool0o_oooolEo`00o`Sooooo0Ol00001ooooo`00
00?o0000ooooooooool0o_oooolEo`00o`Sooooo0Ol00001ooooo`0000?o0000ooooooooool0o_oo
oolEo`00o`Sooooo0Ol00001ooooo`0000?o0000ooooooooool0o_oooolEo`00o`Sooooo0Ol00001
ooooo`0000?o0000ooooooooool0o_oooolEo`00o`Sooooo0Ol00001ooooo`0000?o0000oooooooo
ool0o_oooolEo`00o`Sooooo0Ol00001ooooo`0000?o0000ooooooooool0o_oooolEo`00o`Sooooo
0Ol00001ooooo`0000?o0000ooooooooool0o_oooolEo`00o`Sooooo0Ol00001ooooo`0000?o0000
ooooooooool0o_oooolEo`00o`Sooooo0Ol00001ooooo`0000?o0000ooooooooool0o_oooolEo`00
o`Sooooo0Ol00001ooooo`0000?o0000ooooooooool0o_oooolEo`00o`Sooooo0Ol00001ooooo`00
00?o0000ooooooooool0o_oooolEo`00o`Sooooo0Ol00001ooooo`0000?o0000ooooooooool0o_oo
oolEo`00o`Sooooo0Ol00001ooooo`0000?o0000ooooooooool0o_oooolEo`00o`Sooooo0Ol00001
ooooo`0000?o0000ooooooooool0o_oooolEo`00o`Sooooo0Ol00001ooooo`0000?o0000oooooooo
ool0o_oooolEo`00o`Sooooo0Ol00001ooooo`0000?o0000ooooooooool0o_oooolEo`00o`Sooooo
0Ol00001ooooo`0000?o0000ooooooooool0o_oooolEo`00o`Sooooo0Ol00001ooooo`0000?o0000
ooooooooool0o_oooolEo`00o`Sooooo0Ol00001ooooo`0000?o0000ooooooooool0o_oooolEo`00
o`Sooooo0Ol00001ooooo`0000?o0000ooooooooool0o_oooolEo`00o`Sooooo0Ol00001ooooo`00
00?o0000ooooooooool0o_oooolEo`00o`Sooooo0Ol00001ooooo`0000?o0000ooooooooool0o_oo
oolEo`00o`Sooooo0Ol00001ooooo`0000?o0000ooooooooool01_ooool2oomo0?Kooooo5Ol00?l8
ooooo`7o00000Oooool00003o`000?oooooooooo00Gooooo1?ooO`0Cooooo`;oogl0h?oooolEo`00
o`Sooooo0Ol00001ooooo`0000?o0000ooooooooool01Oooool4oomo01;ooooo1?ooO`0Booooo`;o
ogl0booooolEo`00o`Sooooo0Ol00001ooooo`0000?o0000ooooooooool01Oooool3oomo01?ooooo
1?ooO`0Aooooo`Coogl0b_oooolEo`00o`Sooooo0Ol00001ooooo`0000?o0000ooooooooool01?oo
ool4oomo01Cooooo0_ooO`0Booooo`Coogl0b_oooolEo`00o`Sooooo0Ol00001ooooo`0000?o0000
ooooooooool01?ooool4oomo02Wooooo0_ooO`3;oooooaGo003o2?ooool1o`00007ooooo00000ol0
003oooooooooo`05ooooo`;oogl0mooooolEo`00o`Sooooo0Ol00001ooooo`0000?o0000oooooooo
ool0o_oooolEo`00o`Sooooo0Ol00001ooooo`0000?o0000ooooooooool0o_oooolEo`00o`Sooooo
0Ol00001ooooo`0000?o0000ooooooooool0o_oooolEo`00o`Sooooo0Ol00001ooooo`0000?o0000
ooooooooool0o_oooolEo`00o`Sooooo0Ol00001ooooo`0000?o0000ooooooooool0o_oooolEo`00
o`Sooooo0Ol00001ooooo`0000?o0000ooooooooool0o_oooolEo`00o`Sooooo0Ol00001ooooo`00
00?o0000ooooooooool0o_oooolEo`00o`Sooooo0Ol00001ooooo`0000?o0000ooooooooool0:_oo
ool6ool00<kooooo5Ol00?l8ooooo`7o00000Oooool00003o`000?oooooooooo02Wooooo00?oo`00
ooooooooool01?ooool5ool00<Wooooo5Ol00?l8ooooo`7o00000Oooool00003o`000?oooooooooo
02Oooooo0_oo000<ooooo`Coo`00aOoooolEo`00o`Sooooo0Ol00001ooooo`0000?o0000oooooooo
ool09_ooool00ooo003oooooooooo`0@ooooo`Coo`00`OoooolEo`00o`Sooooo0Ol00001ooooo`00
00?o0000ooooooooool09?ooool00oooO`3oo`00ooooo`09ooooo`;oogl02oooool3ool00;kooooo
5Ol00?l8ooooo`7o00000Oooool00003o`000?oooooooooo02?ooooo00Coogl0ool00?ooO`3oogl0
2?ooool4oomo00gooooo00?oo`00ooooooooool0^ooooolEo`00o`Sooooo0Ol00001ooooo`0000?o
0000ooooooooool08oooool01?ooO`3oo`00oomo0?ooO`08ooooo`Coogl03_ooool2ool00;_ooooo
5Ol00?l8ooooo`7o00000Oooool00003o`000?oooooooooo02Cooooo00?oogl0ool00?ooool02Ooo
ool2oomo017ooooo0_oo002ioooooaGo003o2?ooool1o`00007ooooo00000ol0003oooooooooo`0U
ooooo`03ool00?oooooooooo01gooooo0_oo002goooooaGo003o2?ooool1o`00007ooooo00000ol0
003oooooooooo`0Uooooo`03ool00?oooooooooo01oooooo0_oo002eoooooaGo003o2?ooool1o`00
007ooooo00000ol0003oooooooooo`0Vooooo`03ool00?oooooooooo017ooooo0_ooO`0=ooooo`;o
o`001?ooool2oomo00Oooooo0_ooO`2ToooooaGo003o2?ooool1o`00007ooooo00000ol0003ooooo
ooooo`0Vooooo`03ool00?oooooooooo00Gooooo0_ooO`09ooooo`Coogl03_ooool00ooo003ooooo
ooooo`04oomo00Gooooo1?ooO`2SoooooaGo003o2?ooool1o`00007ooooo00000ol0003ooooooooo
o`0Vooooo`03ool00?oooooooooo00Cooooo1?ooO`08ooooo`Coogl03oooool00ooo003ooooooomo
0003oomo00Gooooo1?ooO`2SoooooaGo003o2?ooool1o`00007ooooo00000ol0003oooooooooo`0W
ooooo`03ool00?oooooooooo00?ooooo1?ooO`09ooooo`;oogl04Oooool01?oo003ooooooomo0?oo
O`07ooooo`?oogl0XooooolEo`00o`Sooooo0Ol00001ooooo`0000?o0000ooooooooool09oooool0
0ooo003oooooooooo`04ooooo`;oogl07_ooool00ooo003oooooooooo`07ooooo`Coogl0X_oooolE
o`00o`Sooooo0Ol00001ooooo`0000?o0000ooooooooool0:?ooool00ooo003oooooooooo`0Toooo
o`03ool00?oooooooooo00Kooooo1?ooO`2RoooooaGo003o2?ooool1o`00007ooooo00000ol0003o
ooooooooo`0Yooooo`03ool00?oooooooooo02Cooooo0_oo00000oooooooogl0oomo0004ooooo`;o
ogl0XooooolEo`00o`Sooooo0Ol00001ooooo`0000?o0000ooooooooool0:_ooool00ooo003ooooo
ooooo`0Cooooo`Coo`003_ooool01?oo003oogl0oomo0?ooO`2XoooooaGo003o2?ooool1o`00007o
oooo00000ol0003oooooooooo`0[ooooo`03ool00?oooooooooo017ooooo1_oo000=ooooo`04oomo
0?oo003oo`00oomo0:Sooooo5Ol00?l8ooooo`7o00000Oooool00003o`000?oooooooooo02cooooo
00?oo`00ooooooooool02?ooool2oomo00Gooooo2?oo000=ooooo`;oogl000?oo`00ooooooooool0
Y_oooolEo`00o`Sooooo0Ol00001ooooo`0000?o0000ooooooooool0;Oooool00ooo003ooooooooo
o`06ooooo`Coogl01?ooool8ool0013ooooo00?oo`00ooooooooool0YOoooolEo`00o`Sooooo0Ol0
0001ooooo`0000?o0000ooooooooool0:oooool2oomo0003oooooooo003ooooo00Kooooo1?ooO`04
ooooo`Soo`004Oooool00ooo003oooooooooo`2ToooooaGo003o2?ooool1o`00007ooooo00000ol0
003oooooooooo`0Zooooo`Coogl000?oooooool00?ooool01_ooool2oomo00Gooooo2?oo000;oooo
o`;oogl01Oooool00ooo003oooooooooo`09ooooo`;oogl0V?oooolEo`00o`Sooooo0Ol00001oooo
o`0000?o0000ooooooooool0:_ooool4oomo00;ooooo00?oo`00ooooooooool03?ooool6ool000_o
oooo1?ooO`04ooooo`03ool00?oooooooooo00Sooooo1?ooO`2GoooooaGo003o2?ooool1o`00007o
oooo00000ol0003oooooooooo`0[ooooo`;oogl01?ooool00ooo003oooooooooo`0<ooooo`Coo`00
3?ooool4oomo00Gooooo00?oo`00ooooooooool01oooool4oomo09Oooooo5Ol00?l8ooooo`7o0000
0Oooool00003o`000?oooooooooo03;ooooo0_oo000Mooooo`;oogl01oooool00ooo003ooooooooo
o`07ooooo`;oogl0]Oooool1o`00007ooooo00000ol0003oooooooooo`0dooooo`03ool00?oooooo
oooo02Cooooo00?oo`00ooooooooool0_Oooool1o`00007ooooo00000ol0003oooooooooo`0eoooo
o`03ool00?oooooooooo02Cooooo00?oo`00ooooooooool0_?ooool1o`00007ooooo00000ol0003o
ooooooooo`0fooooo`;oo`009Oooool00ooo003oooooooooo`2kooooo`7o00000Oooool00003o`00
0?oooooooooo03Sooooo0_oo00000oooO`3oooooooooo`02oomo01kooooo00?oo`00ooooooooool0
^oooool1o`00007ooooo00000ol0003oooooooooo`0hooooo`;oogl00_oo0004oomo01kooooo00?o
o`00ooooooooool0^_ooool1o`00007ooooo00000ol0003oooooooooo`0hooooo`Coogl00_oo0002
oomo01kooooo00?oo`00ooooooooool0^_ooool1o`00007ooooo00000ol0003oooooooooo`0ioooo
o`Googl000?oo`00ooooooooool07Oooool00ooo003oogl0oomo002jooooo`7o00000Oooool00003
o`000?oooooooooo03_ooooo1?ooO`02ool001gooooo00Coogl0ool00?ooO`3oogl0^Oooool1o`00
007ooooo00000ol0003oooooooooo`0looooo`;oogl00oooool2ool001_ooooo00Coogl0ool00?oo
O`3oogl0^Oooool1o`00007ooooo00000ol0003oooooooooo`13ooooo`;oo`006_ooool00oooO`3o
o`00ooooo`2iooooo`7o00000Oooool00003o`000?oooooooooo04Gooooo0_oo000Iooooo`03ool0
0?oooooooooo0;Sooooo0Ol00001ooooo`0000?o0000ooooooooool0Aoooool2ool001Gooooo0_oo
002kooooo`7o00000Oooool00003o`000?oooooooooo04Wooooo0ooo000@ooooo`;oo`00_Oooool1
o`00007ooooo00000ol0003oooooooooo`0aooooo`;oogl06Oooool3ool000cooooo00?oo`00oooo
ooooool0_Oooool1o`00007ooooo00000ol0003oooooooooo`0`ooooo`Coogl06oooool6ool000Co
oooo0_oo0030ooooo`7o00000Oooool00003o`000?oooooooooo033ooooo1?ooO`0Qooooo`Coo`00
`_ooool1o`00007ooooo00000ol0003oooooooooo`0aooooo`;oogl0j?ooool1o`00007ooooo0000
0ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLoooo
o`7o00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003ooooo
ooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Ooo
ool00003o`000?oooooooooo07gooooo0_ooO`2Looooo`7o00000Oooool00003o`000?oooooooooo
07cooooo1?ooO`2Kooooo`7o00000Oooool00003o`000?oooooooooo05Cooooo0_ooO`0Vooooo`Co
ogl0Voooool1o`00007ooooo00000ol0003oooooooooo`1Cooooo`Coogl09_ooool2oomo09cooooo
0Ol00001ooooo`0000?o0000ooooooooool0Doooool4oomo0<Cooooo0Ol00001ooooo`0000?o0000
ooooooooool0E?ooool2oomo0<Gooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLoooo
o`7o00000Oooool00003o`000?oooooooooo06?ooooo0_ooO`04ooooo`;oogl0/?ooool1o`00007o
oooo00000ol0003oooooooooo`1Rooooo`Coogl00_ooool4oomo0:oooooo0Ol00001ooooo`0000?o
0000ooooooooool0H_ooool4oomo00;ooooo1?ooO`2_ooooo`7o00000Oooool00003o`000?oooooo
oooo06?ooooo0_ooO`04ooooo`;oogl0/?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooo
oacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`00
0?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol0
0001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo
0?oooooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`00
00?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?oo
ool1o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000oooo
ooooool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007o
oooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooo
oolLooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0
003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o
00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003ooooooooo
o`3ooooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool0
0003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooooaco
oooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oo
oooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001
ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo0?oo
oooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o
0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1
o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000oooooooo
ool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo
00000ol0003oooooooooo`3oooooo`Cooooo0_ooO`0Fooooo`7o00000Oooool00003o`000?oooooo
oooo0?oooooo0oooool4oomo01Gooooo0Ol00001ooooo`0000?o0000ooooooooool0ooooool3oooo
o`Coogl05Oooool1o`00007ooooo00000ol0003oooooooooo`3oooooo`Cooooo0_ooO`0Fooooo`7o
00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003ooooooooo
o`3ooooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool0
0003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooooaco
oooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oo
oooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001
ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo0?oo
oooo7?ooool1o`00007ooooo00000ol0003oooooooooo`2eooooo`;oogl0I?ooool1o`00007ooooo
00000ol0003oooooooooo`2dooooo`Coogl0Hoooool1o`00007ooooo00000ol0003oooooooooo`2d
ooooo`Coogl0Hoooool1o`00007ooooo00000ol0003oooooooooo`2eooooo`;oogl0=Oooool2oomo
02gooooo0Ol00001ooooo`0000?o0000ooooooooool0i?ooool2oomo00Gooooo1?ooO`0/ooooo`7o
00000Oooool00003o`000?oooooooooo0>?ooooo1?ooO`04ooooo`Coogl0;?ooool1o`00007ooooo
00000ol0003oooooooooo`33ooooo`;oogl07_ooool4oomo00Gooooo0_ooO`0]ooooo`7o00000Ooo
ool00003o`000?oooooooooo0<;ooooo1?ooO`0;o`00oa?ooooo0_ooO`0eooooo`7o00000Oooool0
0003o`000?oooooooooo0<;ooooo1?l00?l;ooooo`;o003oB?ooool1o`00007ooooo00000ol0003o
ooooooooo`2nooooo`Co003o00?ooooooomo0?ooO`003_ooool2o`00odKooooo0Ol00001ooooo`00
00?o0000ooooooooool0^Oooool2oomo00?o003o5oooool2o`00o`Wooooo0_ooO`0iooooo`7o0000
0Oooool00003o`000?oooooooooo0;Oooooo1?l00?l00oooO`3oooooooooo`0Iooooo`;o003o1_oo
ool4oomo03Sooooo0Ol00001ooooo`0000?o0000ooooooooool0]?ooool3o`00o`03ooooooooO`3o
ogl000;oogl07?ooool00ol00?ooooooooooo`04ooooo`Coogl00oooool2oomo03?ooooo0Ol00001
ooooo`0000?o0000ooooooooool0/_ooool2o`00o`?oogl00_ooool2oomo01?ooooo0_ooO`08oooo
o`03o`00oooooooooooo00Gooooo0_ooO`03ooooo`Coogl0<_ooool1o`00007ooooo00000ol0003o
ooooooooo`2`ooooo`;o003o00?ooooooomo0?ooO`000_ooO`06ooooo`;oogl03_ooool4oomo00Oo
oooo00?o003oooooooooool02_ooool4oomo03;ooooo0Ol00001ooooo`0000?o0000ooooooooool0
[_ooool2o`00o`Cooooo0_ooO`06ooooo`Coogl03Oooool4oomo00Oooooo00?o003oooooooooool0
2oooool2oomo03?ooooo0Ol00001ooooo`0000?o0000ooooooooool0Roooool2oomo023ooooo00?o
003oooooooooool01?ooool2oomo00Kooooo1?ooO`0>ooooo`;oogl02Oooool00ol00?oooooooooo
o`0oooooo`7o00000Oooool00003o`000?oooooooooo08[ooooo1?ooO`0Mooooo`;o003o1_ooool4
oomo00Kooooo0_ooO`0Jooooo`03o`00oooooooooooo03oooooo0Ol00001ooooo`0000?o0000oooo
ooooool0R_ooool4oomo01cooooo00?o003oooooooooool01_ooool4oomo02;ooooo00?o003ooooo
ooooool0?oooool1o`00007ooooo00000ol0003oooooooooo`2;ooooo`;oogl06oooool2o`00o`[o
oooo0_ooO`0Sooooo`03o`00oooooooooooo03oooooo0Ol00001ooooo`0000?o0000ooooooooool0
U_ooool2oomo00kooooo0_l00?lZooooo`;oogl01Oooool00ol00?ooooooooooo`0oooooo`7o0000
0Oooool00003o`000?oooooooooo09Gooooo1?ooO`0<ooooo`04o`00ooooooooogl0oomo02Sooooo
1?ooO`03ooooo`03o`00oooooooooooo043ooooo0Ol00001ooooo`0000?o0000ooooooooool0UOoo
ool4oomo00[ooooo0_l00?l00oooooooogl0oomo0002oomo02Oooooo1?ooO`03ooooo`03o`00oooo
oooooooo043ooooo0Ol00001ooooo`0000?o0000ooooooooool0U_ooool2oomo00[ooooo00Co003o
oooooooooooooooo1?ooO`0Xooooo`;oogl01?ooool00ol00?ooooooooooo`10ooooo`7o00000Ooo
ool00003o`000?oooooooooo0:7ooooo00?o003oooooooooool00oooool2oomo02kooooo00?o003o
ooooooooool0@Oooool1o`00007ooooo00000ol0003oooooooooo`2Pooooo`03o`00oooooooooooo
03?ooooo00?o003oooooooooool04_ooool2oomo02kooooo0Ol00001ooooo`0000?o0000oooooooo
ool0W_ooool2o`00ocGooooo00?o003oooooooooool04_ooool4oomo02gooooo0Ol00001ooooo`00
00?o0000ooooooooool0WOooool00ol00?ooooooooooo`0Eooooo`Co003o7?ooool00ol00?ooogl0
oomo000Booooo`Coogl0;Oooool1o`00007ooooo00000ol0003oooooooooo`2Looooo`03o`00oooo
oooooooo01Gooooo1_l00?lJooooo`03o`00ooooO`3oogl000;oogl04_ooool2oomo02kooooo0Ol0
0001ooooo`0000?o0000ooooooooool0Voooool00ol00?ooooooooooo`0Eooooo`So003o6?ooool0
0ol00?oooooooomo0003oomo04;ooooo0Ol00001ooooo`0000?o0000ooooooooool0Voooool00ol0
0?ooooooooooo`0Eooooo`So003o5oooool01?l00?ooooooooooooooool2oomo04?ooooo0Ol00001
ooooo`0000?o0000ooooooooool0V_ooool00ol00?ooooooooooo`0Fooooo`So003o5_ooool00ol0
0?ooooooooooo`17ooooo`7o00000Oooool00003o`000?oooooooooo09Wooooo00?o003ooooooooo
ool03?ooool2oomo00Sooooo00?oogl0o`00ool00?l01_l00?lEooooo`03o`00oooooooooooo00;o
ogl0A_ooool1o`00007ooooo00000ol0003oooooooooo`2Iooooo`03o`00oooooooooooo00[ooooo
1OooO`07ooooo`;oogl01_l00?lCooooo`;oogl000?o003oooooooooool01?ooO`15ooooo`7o0000
0Oooool00003o`000?oooooooooo09Sooooo00?o003oooooooooool02_ooool6oomo00Sooooo0_oo
O`04o`00oa?ooooo0_ooO`02o`00o`;ooooo1?ooO`15ooooo`7o00000Oooool00003o`000?oooooo
oooo09Sooooo00?o003oooooooooool02_ooool5oomo02;ooooo00Coogl0o`00ooooO`3oogl00ooo
ool2oomo04Kooooo0Ol00001ooooo`0000?o0000ooooooooool0M_ooool2oomo01oooooo00?o003o
ooooooooool03?ooool2oomo02Cooooo00?o003ooomo0?ooO`00C?ooool1o`00007ooooo00000ol0
003oooooooooo`1eooooo`Coogl07_ooool00ol00?ooooooooooo`0aooooo`03o`00oooooooooooo
04gooooo0Ol00001ooooo`0000?o0000ooooooooool0MOooool4oomo00[ooooo0_ooO`0Aooooo`03
o`00oooooooooooo037ooooo00?o003oooooooooool0C_ooool1o`00007ooooo00000ol0003ooooo
ooooo`1fooooo`;oogl02_ooool4oomo00oooooo00?o003oooooooooool06?ooool2oomo01Oooooo
00?o003oooooooooool0Coooool1o`00007ooooo00000ol0003oooooooooo`22ooooo`Coogl03ooo
ool00ol00?ooooooooooo`0Gooooo`Coogl05?ooool2o`00oe;ooooo0Ol00001ooooo`0000?o0000
ooooooooool0Poooool2oomo00oooooo00?o003oooooooooool04_ooool2oomo00Cooooo1?ooO`0A
ooooo`?o003oE?ooool1o`00007ooooo00000ol0003oooooooooo`2Dooooo`03o`00oooooooooooo
017ooooo1?ooO`04ooooo`;oogl04?ooool2o`00oeOooooo0Ol00001ooooo`0000?o0000oooooooo
ool0U?ooool00ol00?ooooooooooo`0Aooooo`Coogl05Oooool00ol00?ooooooooooo`1Gooooo`7o
00000Oooool00003o`000?oooooooooo09Cooooo00?o003oooooooooool04_ooool2oomo01Cooooo
0_l00?mJooooo`7o00000Oooool00003o`000?oooooooooo09Cooooo00?o003oooooooooool09_oo
ool2o`00oecooooo0Ol00001ooooo`0000?o0000ooooooooool0UOooool00ol00?ooooooooooo`0T
ooooo`03o`00oooooooooooo05cooooo0Ol00001ooooo`0000?o0000ooooooooool0UOooool00ol0
0?ooooooooooo`0Rooooo`;o003oGoooool1o`00007ooooo00000ol0003oooooooooo`2Eooooo`03
o`00oooooooooooo023ooooo0_l00?mQooooo`7o00000Oooool00003o`000?oooooooooo08Cooooo
0_ooO`0?ooooo`;o003o7oooool2o`00of?ooooo0Ol00001ooooo`0000?o0000ooooooooool0Pooo
ool4oomo013ooooo0_l00?lJooooo`?o003oIOooool1o`00007ooooo00000ol0003oooooooooo`23
ooooo`Coogl04_ooool2o`00oaCooooo1?l00?mXooooo`7o00000Oooool00003o`000?oooooooooo
08Cooooo0_ooO`0Eooooo`?o003o3_ooool3o`00o`?ooooo0_ooO`1Wooooo`7o00000Oooool00003
o`000?oooooooooo09kooooo0ol00?l5ooooo`Ko003o1Oooool4oomo06Kooooo0Ol00001ooooo`00
00?o0000ooooooooool0XOooool5o`00o`_ooooo1?ooO`1Vooooo`7o00000Oooool00003o`000?oo
oooooooo0;;ooooo0_ooO`1Wooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1
o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000oooooooo
ool0Noooool2oomo09kooooo0Ol00001ooooo`0000?o0000ooooooooool0N_ooool4oomo013ooooo
1Ooo0?n8ooooo`7o00000Oooool00003o`000?oooooooooo07[ooooo1?ooO`0?ooooo`Ooo`3o2_oo
ool2oomo07_ooooo0Ol00001ooooo`0000?o0000ooooooooool0Noooool2oomo00oooooo2Ooo0?l8
ooooo`Coogl0N_ooool1o`00007ooooo00000ol0003oooooooooo`2;ooooo`_oo`3o1oooool4oomo
07[ooooo0Ol00001ooooo`0000?o0000ooooooooool0Roooool;ool0o`Sooooo0_ooO`1kooooo`7o
00000Oooool00003o`000?oooooooooo08_ooooo2ooo0?n5ooooo`7o00000Oooool00003o`000?oo
oooooooo08_ooooo2ooo0?n5ooooo`7o00000Oooool00003o`000?oooooooooo08_ooooo2ooo0?lO
ooooo`;oogl0I?ooool1o`00007ooooo00000ol0003oooooooooo`2<ooooo`Woo`3o7oooool4oomo
06?ooooo0Ol00001ooooo`0000?o0000ooooooooool0SOooool7ool0ob3ooooo1?ooO`1Sooooo`7o
00000Oooool00003o`000?oooooooooo08kooooo1Ooo0?lRooooo`;oogl0I?ooool1o`00007ooooo
00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolL
ooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003o
ooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o0000
0Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3o
oooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003
o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo
0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oooooo
oooo0?oooooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001oooo
o`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo
7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000
ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00
007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0
oooooolLooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo0000
0ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLoooo
o`7o00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003ooooo
ooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Ooo
ool00003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooo
oacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`00
0?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol0
0001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo
0?oooooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`00
00?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?oo
ool1o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000oooo
ooooool0S_ooool2oomo08_ooooo0Ol00001ooooo`0000?o0000ooooooooool0SOooool4oomo08[o
oooo0Ol00001ooooo`0000?o0000ooooooooool0SOooool4oomo08[ooooo0Ol00001ooooo`0000?o
0000ooooooooool0S_ooool2oomo08_ooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolL
ooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003o
ooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o0000
0Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3o
oooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003
o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo
0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oooooo
oooo0?oooooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001oooo
o`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo
7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000
ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00
007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0
oooooolLooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo0000
0ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`00ool0000Po`00007ooooo0000\
\>"],
  ImageRangeCache->{{{0, 287}, {287, 0}} -> {-1.01089, -1.01089, 0.00704453, \
0.00704453}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.49505 0.5 0.49505 [
[ 0 0 -0.125 0 ]
[ 0 0 -0.125 0 ]
[ 0 1 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
0 0 m
1 0 L
s
0 0 m
0 1 L
s
0 1 m
1 1 L
s
1 0 m
1 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
1 .5 0 r
.015 w
.03175 .1355 Mdot
.03435 .12523 Mdot
.11137 .12765 Mdot
.14107 .18841 Mdot
.16218 .24538 Mdot
.17294 .21053 Mdot
.18267 .18577 Mdot
.18434 .1304 Mdot
.18553 .30956 Mdot
.20401 .239 Mdot
.21247 .27571 Mdot
.21687 .20845 Mdot
.22376 .2799 Mdot
.22832 .27485 Mdot
.29063 .20974 Mdot
.29686 .25079 Mdot
.30487 .22936 Mdot
.30683 .34623 Mdot
.32055 .20902 Mdot
.32574 .21979 Mdot
.34472 .28521 Mdot
.35998 .36393 Mdot
.36335 .24976 Mdot
.3794 .36608 Mdot
.42386 .66992 Mdot
.44391 .74519 Mdot
.45059 .34198 Mdot
.47208 .67586 Mdot
.47436 .71381 Mdot
.49778 .59825 Mdot
.50874 .91643 Mdot
.51516 .76219 Mdot
.53655 .61374 Mdot
.56563 .75219 Mdot
.59189 .65665 Mdot
.59581 .61604 Mdot
.59923 .6556 Mdot
.60292 .68499 Mdot
.62656 .67779 Mdot
.63555 .72451 Mdot
.63919 .652 Mdot
.64169 .6004 Mdot
.64246 .58611 Mdot
.64496 .54267 Mdot
.64608 .77288 Mdot
.65077 .64308 Mdot
.66065 .57816 Mdot
.67474 .59169 Mdot
.69296 .563 Mdot
.72815 .65902 Mdot
.73169 .58879 Mdot
.74669 .61318 Mdot
.74821 .65474 Mdot
.75963 .63781 Mdot
.79673 .57809 Mdot
.80925 .55852 Mdot
.81525 .58444 Mdot
.83417 .62985 Mdot
.83598 .55526 Mdot
.91595 .49319 Mdot
1 0 0 r
.005 w
.16128 .17044 m
.18734 .17269 L
.21339 .17909 L
.2345 .18734 L
.23945 .19126 L
.2655 .20415 L
.27874 .21339 L
.29156 .22295 L
.31204 .23945 L
.31761 .24532 L
.33549 .2655 L
.34367 .28341 L
.34499 .29156 L
.34367 .29798 L
.31761 .3104 L
.29156 .30711 L
.2655 .30014 L
.24507 .29156 L
.23945 .28747 L
.21339 .27402 L
.20155 .2655 L
.18734 .25472 L
.16884 .23945 L
.16128 .2313 L
.14618 .21339 L
.13806 .18734 L
.16128 .17044 L
s
0 0 1 r
.65633 .57701 m
.68239 .56842 L
.70844 .56313 L
.7345 .56168 L
.76055 .5752 L
.76359 .57817 L
.76859 .60422 L
.76055 .62333 L
.75627 .63028 L
.7345 .65485 L
.73298 .65633 L
.70844 .6775 L
.69922 .68239 L
.68239 .69294 L
.65633 .70579 L
.64983 .70844 L
.63028 .71539 L
.60422 .72268 L
.57817 .72651 L
.55211 .7214 L
.53145 .70844 L
.52926 .68239 L
.54239 .65633 L
.55211 .63983 L
.56625 .63028 L
.57817 .6193 L
.60119 .60422 L
.60422 .60227 L
.63028 .58726 L
.65315 .57817 L
.65633 .57701 L
s
1 0 0 r
.03 w
.24141 .24033 Mdot
0 0 1 r
.64872 .64417 Mdot
1 0 0 r
.79703 .00495 m
.79703 .00495 L
.87129 .00495 L
.87129 .00495 L
F
0 0 1 r
.89604 .00495 m
.89604 .25248 L
.9703 .25248 L
.9703 .00495 L
F
1 0 1 r
.04 w
.53655 .61374 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P000182000`400?l00000o`00003ooooooolQ
ooooo`00ool0000Po`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`00
00?o0000ooooooooool0o_oooolEo`00o`Sooooo0Ol00001ooooo`0000?o0000ooooooooool0o_oo
oolEo`00o`Sooooo0Ol00001ooooo`0000?o0000ooooooooool0o_oooolEo`00o`Sooooo0Ol00001
ooooo`0000?o0000ooooooooool0o_oooolEo`00o`Sooooo0Ol00001ooooo`0000?o0000oooooooo
ool0o_oooolEo`00o`Sooooo0Ol00001ooooo`0000?o0000ooooooooool0o_oooolEo`00o`Sooooo
0Ol00001ooooo`0000?o0000ooooooooool0o_oooolEo`00o`Sooooo0Ol00001ooooo`0000?o0000
ooooooooool0o_oooolEo`00o`Sooooo0Ol00001ooooo`0000?o0000ooooooooool0o_oooolEo`00
o`Sooooo0Ol00001ooooo`0000?o0000ooooooooool0o_oooolEo`00o`Sooooo0Ol00001ooooo`00
00?o0000ooooooooool0o_oooolEo`00o`Sooooo0Ol00001ooooo`0000?o0000ooooooooool0o_oo
oolEo`00o`Sooooo0Ol00001ooooo`0000?o0000ooooooooool0o_oooolEo`00o`Sooooo0Ol00001
ooooo`0000?o0000ooooooooool0o_oooolEo`00o`Sooooo0Ol00001ooooo`0000?o0000oooooooo
ool0o_oooolEo`00o`Sooooo0Ol00001ooooo`0000?o0000ooooooooool0o_oooolEo`00o`Sooooo
0Ol00001ooooo`0000?o0000ooooooooool0o_oooolEo`00o`Sooooo0Ol00001ooooo`0000?o0000
ooooooooool0o_oooolEo`00o`Sooooo0Ol00001ooooo`0000?o0000ooooooooool0o_oooolEo`00
o`Sooooo0Ol00001ooooo`0000?o0000ooooooooool0o_oooolEo`00o`Sooooo0Ol00001ooooo`00
00?o0000ooooooooool0o_oooolEo`00o`Sooooo0Ol00001ooooo`0000?o0000ooooooooool0o_oo
oolEo`00o`Sooooo0Ol00001ooooo`0000?o0000ooooooooool0o_oooolEo`00o`Sooooo0Ol00001
ooooo`0000?o0000ooooooooool0o_oooolEo`00o`Sooooo0Ol00001ooooo`0000?o0000oooooooo
ool0o_oooolEo`00o`Sooooo0Ol00001ooooo`0000?o0000ooooooooool0o_oooolEo`00o`Sooooo
0Ol00001ooooo`0000?o0000ooooooooool0o_oooolEo`00o`Sooooo0Ol00001ooooo`0000?o0000
ooooooooool0o_oooolEo`00o`Sooooo0Ol00001ooooo`0000?o0000ooooooooool0o_oooolEo`00
o`Sooooo0Ol00001ooooo`0000?o0000ooooooooool0o_oooolEo`00o`Sooooo0Ol00001ooooo`00
00?o0000ooooooooool0o_oooolEo`00o`Sooooo0Ol00001ooooo`0000?o0000ooooooooool0o_oo
oolEo`00o`Sooooo0Ol00001ooooo`0000?o0000ooooooooool01_ooool2oomo0?Kooooo5Ol00?l8
ooooo`7o00000Oooool00003o`000?oooooooooo00Gooooo1?ooO`0Cooooo`;oogl0h?oooolEo`00
o`Sooooo0Ol00001ooooo`0000?o0000ooooooooool01Oooool4oomo01;ooooo1?ooO`0Booooo`;o
ogl0booooolEo`00o`Sooooo0Ol00001ooooo`0000?o0000ooooooooool01Oooool3oomo01?ooooo
1?ooO`0Aooooo`Coogl0b_oooolEo`00o`Sooooo0Ol00001ooooo`0000?o0000ooooooooool01?oo
ool4oomo01Cooooo0_ooO`0Booooo`Coogl0b_oooolEo`00o`Sooooo0Ol00001ooooo`0000?o0000
ooooooooool01?ooool4oomo02Wooooo0_ooO`3;oooooaGo003o2?ooool1o`00007ooooo00000ol0
003oooooooooo`05ooooo`;oogl0mooooolEo`00o`Sooooo0Ol00001ooooo`0000?o0000oooooooo
ool0o_oooolEo`00o`Sooooo0Ol00001ooooo`0000?o0000ooooooooool0o_oooolEo`00o`Sooooo
0Ol00001ooooo`0000?o0000ooooooooool0o_oooolEo`00o`Sooooo0Ol00001ooooo`0000?o0000
ooooooooool0o_oooolEo`00o`Sooooo0Ol00001ooooo`0000?o0000ooooooooool0o_oooolEo`00
o`Sooooo0Ol00001ooooo`0000?o0000ooooooooool0o_oooolEo`00o`Sooooo0Ol00001ooooo`00
00?o0000ooooooooool0o_oooolEo`00o`Sooooo0Ol00001ooooo`0000?o0000ooooooooool0:_oo
ool6ool00<kooooo5Ol00?l8ooooo`7o00000Oooool00003o`000?oooooooooo02Wooooo00?oo`00
ooooooooool01?ooool5ool00<Wooooo5Ol00?l8ooooo`7o00000Oooool00003o`000?oooooooooo
02Oooooo0_oo000<ooooo`Coo`00aOoooolEo`00o`Sooooo0Ol00001ooooo`0000?o0000oooooooo
ool09_ooool00ooo003oooooooooo`0@ooooo`Coo`00`OoooolEo`00o`Sooooo0Ol00001ooooo`00
00?o0000ooooooooool09?ooool00oooO`3oo`00ooooo`09ooooo`;oogl02oooool3ool00;kooooo
5Ol00?l8ooooo`7o00000Oooool00003o`000?oooooooooo02?ooooo00Coogl0ool00?ooO`3oogl0
2?ooool4oomo00gooooo00?oo`00ooooooooool0^ooooolEo`00o`Sooooo0Ol00001ooooo`0000?o
0000ooooooooool08oooool01?ooO`3oo`00oomo0?ooO`08ooooo`Coogl03_ooool2ool00;_ooooo
5Ol00?l8ooooo`7o00000Oooool00003o`000?oooooooooo02Cooooo00?oogl0ool00?ooool02Ooo
ool2oomo017ooooo0_oo002ioooooaGo003o2?ooool1o`00007ooooo00000ol0003oooooooooo`0U
ooooo`03ool00?oooooooooo01gooooo0_oo002goooooaGo003o2?ooool1o`00007ooooo00000ol0
003oooooooooo`0Uooooo`03ool00?oooooooooo01oooooo0_oo002eoooooaGo003o2?ooool1o`00
007ooooo00000ol0003oooooooooo`0Vooooo`03ool00?oooooooooo017ooooo0_ooO`0=ooooo`;o
o`001?ooool2oomo00Oooooo0_ooO`2ToooooaGo003o2?ooool1o`00007ooooo00000ol0003ooooo
ooooo`0Vooooo`03ool00?oooooooooo00Gooooo0_ooO`09ooooo`Coogl03_ooool00ooo003ooooo
ooooo`04oomo00Gooooo1?ooO`2SoooooaGo003o2?ooool1o`00007ooooo00000ol0003ooooooooo
o`0Vooooo`03ool00?oooooooooo00Cooooo1?ooO`08ooooo`Coogl03oooool00ooo003ooooooomo
0003oomo00Gooooo1?ooO`2SoooooaGo003o2?ooool1o`00007ooooo00000ol0003oooooooooo`0W
ooooo`03ool00?oooooooooo00?ooooo1?ooO`09ooooo`;oogl04Oooool01?oo003ooooooomo0?oo
O`07ooooo`?oogl0XooooolEo`00o`Sooooo0Ol00001ooooo`0000?o0000ooooooooool09oooool0
0ooo003oooooooooo`04ooooo`;oogl07_ooool00ooo003oooooooooo`07ooooo`Coogl0X_oooolE
o`00o`Sooooo0Ol00001ooooo`0000?o0000ooooooooool0:?ooool00ooo003oooooooooo`0Toooo
o`03ool00?oooooooooo00Kooooo1?ooO`2RoooooaGo003o2?ooool1o`00007ooooo00000ol0003o
ooooooooo`0Yooooo`03ool00?oooooooooo02Cooooo0_oo00000oooooooogl0oomo0004ooooo`;o
ogl0XooooolEo`00o`Sooooo0Ol00001ooooo`0000?o0000ooooooooool0:_ooool00ooo003ooooo
ooooo`0Cooooo`Coo`003_ooool01?oo003oogl0oomo0?ooO`2XoooooaGo003o2?ooool1o`00007o
oooo00000ol0003oooooooooo`0[ooooo`03ool00?oooooooooo017ooooo1_oo000=ooooo`04oomo
0?oo003oo`00oomo0:Sooooo5Ol00?l8ooooo`7o00000Oooool00003o`000?oooooooooo02cooooo
00?oo`00ooooooooool02?ooool2oomo00Gooooo2?oo000=ooooo`;oogl000?oo`00ooooooooool0
Y_oooolEo`00o`Sooooo0Ol00001ooooo`0000?o0000ooooooooool0;Oooool00ooo003ooooooooo
o`06ooooo`Coogl01?ooool8ool0013ooooo00?oo`00ooooooooool0YOoooolEo`00o`Sooooo0Ol0
0001ooooo`0000?o0000ooooooooool0:oooool2oomo0003oooooooo003ooooo00Kooooo1?ooO`04
ooooo`Soo`004Oooool00ooo003oooooooooo`2ToooooaGo003o2?ooool1o`00007ooooo00000ol0
003oooooooooo`0Zooooo`Coogl000?oooooool00?ooool01_ooool2oomo00Gooooo2?oo000;oooo
o`;oogl01Oooool00ooo003oooooooooo`09ooooo`;oogl0V?oooolEo`00o`Sooooo0Ol00001oooo
o`0000?o0000ooooooooool0:_ooool4oomo00;ooooo00?oo`00ooooooooool03?ooool6ool000_o
oooo1?ooO`04ooooo`03ool00?oooooooooo00Sooooo1?ooO`2GoooooaGo003o2?ooool1o`00007o
oooo00000ol0003oooooooooo`0[ooooo`;oogl01?ooool00ooo003oooooooooo`0<ooooo`Coo`00
3?ooool4oomo00Gooooo00?oo`00ooooooooool01oooool4oomo09Oooooo5Ol00?l8ooooo`7o0000
0Oooool00003o`000?oooooooooo03;ooooo0_oo000Mooooo`;oogl01oooool00ooo003ooooooooo
o`07ooooo`;oogl0]Oooool1o`00007ooooo00000ol0003oooooooooo`0dooooo`03ool00?oooooo
oooo02Cooooo00?oo`00ooooooooool0_Oooool1o`00007ooooo00000ol0003oooooooooo`0eoooo
o`03ool00?oooooooooo02Cooooo00?oo`00ooooooooool0_?ooool1o`00007ooooo00000ol0003o
ooooooooo`0fooooo`;oo`009Oooool00ooo003oooooooooo`2kooooo`7o00000Oooool00003o`00
0?oooooooooo03Sooooo0_oo00000oooO`3oooooooooo`02oomo01kooooo00?oo`00ooooooooool0
^oooool1o`00007ooooo00000ol0003oooooooooo`0hooooo`;oogl00_oo0004oomo01kooooo00?o
o`00ooooooooool0^_ooool1o`00007ooooo00000ol0003oooooooooo`0hooooo`Coogl00_oo0002
oomo01kooooo00?oo`00ooooooooool0^_ooool1o`00007ooooo00000ol0003oooooooooo`0ioooo
o`Googl000?oo`00ooooooooool07Oooool00ooo003oogl0oomo002jooooo`7o00000Oooool00003
o`000?oooooooooo03_ooooo1?ooO`02ool001gooooo00Coogl0ool00?ooO`3oogl0^Oooool1o`00
007ooooo00000ol0003oooooooooo`0looooo`;oogl00oooool2ool001_ooooo00Coogl0ool00?oo
O`3oogl0^Oooool1o`00007ooooo00000ol0003oooooooooo`13ooooo`;oo`006_ooool00oooO`3o
o`00ooooo`2iooooo`7o00000Oooool00003o`000?oooooooooo04Gooooo0_oo000Iooooo`03ool0
0?oooooooooo0;Sooooo0Ol00001ooooo`0000?o0000ooooooooool0Aoooool2ool001Gooooo0_oo
002kooooo`7o00000Oooool00003o`000?oooooooooo04Wooooo0ooo000@ooooo`;oo`00_Oooool1
o`00007ooooo00000ol0003oooooooooo`0aooooo`;oogl06Oooool3ool000cooooo00?oo`00oooo
ooooool0_Oooool1o`00007ooooo00000ol0003oooooooooo`0`ooooo`Coogl06oooool6ool000Co
oooo0_oo0030ooooo`7o00000Oooool00003o`000?oooooooooo033ooooo1?ooO`0Qooooo`Coo`00
`_ooool1o`00007ooooo00000ol0003oooooooooo`0aooooo`;oogl0j?ooool1o`00007ooooo0000
0ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLoooo
o`7o00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003ooooo
ooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Ooo
ool00003o`000?oooooooooo07gooooo0_ooO`2Looooo`7o00000Oooool00003o`000?oooooooooo
07cooooo1?ooO`2Kooooo`7o00000Oooool00003o`000?oooooooooo05Cooooo0_ooO`0Vooooo`Co
ogl0Voooool1o`00007ooooo00000ol0003oooooooooo`1Cooooo`Coogl09_ooool2oomo09cooooo
0Ol00001ooooo`0000?o0000ooooooooool0Doooool4oomo0<Cooooo0Ol00001ooooo`0000?o0000
ooooooooool0E?ooool2oomo0<Gooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLoooo
o`7o00000Oooool00003o`000?oooooooooo06?ooooo0_ooO`04ooooo`;oogl0/?ooool1o`00007o
oooo00000ol0003oooooooooo`1Rooooo`Coogl00_ooool4oomo0:oooooo0Ol00001ooooo`0000?o
0000ooooooooool0H_ooool4oomo00;ooooo1?ooO`2_ooooo`7o00000Oooool00003o`000?oooooo
oooo06?ooooo0_ooO`04ooooo`;oogl0/?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooo
oacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`00
0?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol0
0001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo
0?oooooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`00
00?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?oo
ool1o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000oooo
ooooool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007o
oooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooo
oolLooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0
003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o
00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003ooooooooo
o`3ooooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool0
0003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooooaco
oooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oo
oooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001
ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo0?oo
oooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o
0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1
o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000oooooooo
ool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo
00000ol0003oooooooooo`3oooooo`Cooooo0_ooO`0Fooooo`7o00000Oooool00003o`000?oooooo
oooo0?oooooo0oooool4oomo01Gooooo0Ol00001ooooo`0000?o0000ooooooooool0ooooool3oooo
o`Coogl05Oooool1o`00007ooooo00000ol0003oooooooooo`3oooooo`Cooooo0_ooO`0Fooooo`7o
00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003ooooooooo
o`3ooooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool0
0003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooooaco
oooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oo
oooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001
ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo0?oo
oooo7?ooool1o`00007ooooo00000ol0003oooooooooo`2eooooo`;oogl0I?ooool1o`00007ooooo
00000ol0003oooooooooo`2dooooo`Coogl0Hoooool1o`00007ooooo00000ol0003oooooooooo`2d
ooooo`Coogl0Hoooool1o`00007ooooo00000ol0003oooooooooo`2eooooo`;oogl0=Oooool2oomo
02gooooo0Ol00001ooooo`0000?o0000ooooooooool0i?ooool2oomo00Gooooo1?ooO`0/ooooo`7o
00000Oooool00003o`000?oooooooooo0>?ooooo1?ooO`04ooooo`Coogl0;?ooool1o`00007ooooo
00000ol0003oooooooooo`33ooooo`;oogl07_ooool4oomo00Gooooo0_ooO`0]ooooo`7o00000Ooo
ool00003o`000?oooooooooo0<;ooooo1?ooO`0;o`00oa?ooooo0_ooO`0eooooo`7o00000Oooool0
0003o`000?oooooooooo0<;ooooo1?l00?l;ooooo`;o003oB?ooool1o`00007ooooo00000ol0003o
ooooooooo`2nooooo`Co003o00?ooooooomo0?ooO`003_ooool2o`00odKooooo0Ol00001ooooo`00
00?o0000ooooooooool0^Oooool2oomo00?o003o5oooool2o`00o`Wooooo0_ooO`0iooooo`7o0000
0Oooool00003o`000?oooooooooo0;Oooooo1?l00?l00oooO`3oooooooooo`0Iooooo`;o003o1_oo
ool4oomo03Sooooo0Ol00001ooooo`0000?o0000ooooooooool0]?ooool3o`00o`03ooooooooO`3o
ogl000;oogl07?ooool00ol00?ooooooooooo`04ooooo`Coogl00oooool2oomo03?ooooo0Ol00001
ooooo`0000?o0000ooooooooool0/_ooool2o`00o`?oogl00_ooool2oomo01?ooooo0_ooO`08oooo
o`03o`00oooooooooooo00Gooooo0_ooO`03ooooo`Coogl0<_ooool1o`00007ooooo00000ol0003o
ooooooooo`2`ooooo`;o003o00?ooooooomo0?ooO`000_ooO`06ooooo`;oogl03_ooool4oomo00Oo
oooo00?o003oooooooooool02_ooool4oomo03;ooooo0Ol00001ooooo`0000?o0000ooooooooool0
[_ooool2o`00o`Cooooo0_ooO`06ooooo`Coogl03Oooool4oomo00Oooooo00?o003oooooooooool0
2oooool2oomo03?ooooo0Ol00001ooooo`0000?o0000ooooooooool0Roooool2oomo023ooooo00?o
003oooooooooool01?ooool2oomo00Kooooo1?ooO`0>ooooo`;oogl02Oooool00ol00?oooooooooo
o`0oooooo`7o00000Oooool00003o`000?oooooooooo08[ooooo1?ooO`06ooooo`Goo`3o4_ooool2
o`00o`Kooooo1?ooO`06ooooo`;oogl06_ooool00ol00?ooooooooooo`0oooooo`7o00000Oooool0
0003o`000?oooooooooo08[ooooo1?ooO`05ooooo`Ooo`3o4?ooool00ol00?ooooooooooo`06oooo
o`Coogl08_ooool00ol00?ooooooooooo`0oooooo`7o00000Oooool00003o`000?oooooooooo08_o
oooo0_ooO`05ooooo`Woo`3o3Oooool2o`00o`[ooooo0_ooO`0Sooooo`03o`00oooooooooooo03oo
oooo0Ol00001ooooo`0000?o0000ooooooooool0TOooool;ool0o`[ooooo0_l00?lZooooo`;oogl0
1Oooool00ol00?ooooooooooo`0oooooo`7o00000Oooool00003o`000?oooooooooo097ooooo2ooo
0?l9ooooo`04o`00ooooooooogl0oomo02Sooooo1?ooO`03ooooo`03o`00oooooooooooo043ooooo
0Ol00001ooooo`0000?o0000ooooooooool0TOooool;ool0o`Oooooo0_l00?l00oooooooogl0oomo
0002oomo02Oooooo1?ooO`03ooooo`03o`00oooooooooooo043ooooo0Ol00001ooooo`0000?o0000
ooooooooool0TOooool;ool0o`Kooooo00Co003ooooooooooooooooo1?ooO`0Xooooo`;oogl01?oo
ool00ol00?ooooooooooo`10ooooo`7o00000Oooool00003o`000?oooooooooo097ooooo2ooo0?l5
ooooo`03o`00oooooooooooo00?ooooo0_ooO`0^ooooo`03o`00oooooooooooo047ooooo0Ol00001
ooooo`0000?o0000ooooooooool0T_ooool9ool0o`Gooooo00?o003oooooooooool0<oooool00ol0
0?ooooooooooo`0Booooo`;oogl0;_ooool1o`00007ooooo00000ol0003oooooooooo`2Cooooo`Oo
o`3o1?ooool2o`00ocGooooo00?o003oooooooooool04_ooool4oomo02gooooo0Ol00001ooooo`00
00?o0000ooooooooool0U?ooool5ool0o`Cooooo00?o003oooooooooool05Oooool4o`00oacooooo
00?o003ooomo0?ooO`004_ooool4oomo02gooooo0Ol00001ooooo`0000?o0000ooooooooool0W?oo
ool00ol00?ooooooooooo`0Eooooo`Ko003o6_ooool00ol00?ooogl0oomo0002oomo01;ooooo0_oo
O`0^ooooo`7o00000Oooool00003o`000?oooooooooo09_ooooo00?o003oooooooooool05Oooool8
o`00oaSooooo00?o003oooooooooO`000oooO`12ooooo`7o00000Oooool00003o`000?oooooooooo
09_ooooo00?o003oooooooooool05Oooool8o`00oaOooooo00Co003ooooooooooooooooo0_ooO`13
ooooo`7o00000Oooool00003o`000?oooooooooo09[ooooo00?o003oooooooooool05_ooool8o`00
oaKooooo00?o003oooooooooool0Aoooool1o`00007ooooo00000ol0003oooooooooo`2Iooooo`03
o`00oooooooooooo00cooooo0_ooO`08ooooo`03oomo0?l00?oo003o00Ko003o5Oooool00ol00?oo
ooooooooo`02oomo04Kooooo0Ol00001ooooo`0000?o0000ooooooooool0VOooool00ol00?oooooo
ooooo`0:ooooo`Googl01oooool2oomo00Ko003o4oooool2oomo0003o`00oooooooooooo00Coogl0
AOooool1o`00007ooooo00000ol0003oooooooooo`2Hooooo`03o`00oooooooooooo00[ooooo1_oo
O`08ooooo`;oogl01?l00?lCooooo`;oogl00_l00?l2ooooo`Coogl0AOooool1o`00007ooooo0000
0ol0003oooooooooo`2Hooooo`03o`00oooooooooooo00[ooooo1OooO`0Rooooo`04oomo0?l00?oo
ogl0oomo00?ooooo0_ooO`16ooooo`7o00000Oooool00003o`000?oooooooooo07Kooooo0_ooO`0O
ooooo`03o`00oooooooooooo00cooooo0_ooO`0Tooooo`03o`00ooooO`3oogl004cooooo0Ol00001
ooooo`0000?o0000ooooooooool0MOooool4oomo01kooooo00?o003oooooooooool0<Oooool00ol0
0?ooooooooooo`1=ooooo`7o00000Oooool00003o`000?oooooooooo07Gooooo1?ooO`0:ooooo`;o
ogl04Oooool00ol00?ooooooooooo`0aooooo`03o`00oooooooooooo04kooooo0Ol00001ooooo`00
00?o0000ooooooooool0M_ooool2oomo00[ooooo1?ooO`0?ooooo`03o`00oooooooooooo01Sooooo
0_ooO`0Gooooo`03o`00oooooooooooo04oooooo0Ol00001ooooo`0000?o0000ooooooooool0P_oo
ool4oomo00oooooo00?o003oooooooooool05oooool4oomo01Cooooo0_l00?mBooooo`7o00000Ooo
ool00003o`000?oooooooooo08?ooooo0_ooO`0?ooooo`03o`00oooooooooooo01;ooooo0_ooO`04
ooooo`Coogl04Oooool3o`00oeCooooo0Ol00001ooooo`0000?o0000ooooooooool0U?ooool00ol0
0?ooooooooooo`0Aooooo`Coogl01?ooool2oomo013ooooo0_l00?mGooooo`7o00000Oooool00003
o`000?oooooooooo09Cooooo00?o003oooooooooool04Oooool4oomo01Gooooo00?o003ooooooooo
ool0Eoooool1o`00007ooooo00000ol0003oooooooooo`2Dooooo`03o`00oooooooooooo01;ooooo
0_ooO`0Dooooo`;o003oF_ooool1o`00007ooooo00000ol0003oooooooooo`2Dooooo`03o`00oooo
oooooooo02Kooooo0_l00?mLooooo`7o00000Oooool00003o`000?oooooooooo09Gooooo00?o003o
ooooooooool09?ooool00ol00?ooooooooooo`1Looooo`7o00000Oooool00003o`000?oooooooooo
09Gooooo00?o003oooooooooool08_ooool2o`00oeoooooo0Ol00001ooooo`0000?o0000oooooooo
ool0UOooool00ol00?ooooooooooo`0Pooooo`;o003oHOooool1o`00007ooooo00000ol0003ooooo
ooooo`24ooooo`;oogl03oooool2o`00oaoooooo0_l00?mSooooo`7o00000Oooool00003o`000?oo
oooooooo08?ooooo1?ooO`0@ooooo`;o003o6_ooool3o`00ofGooooo0Ol00001ooooo`0000?o0000
ooooooooool0Poooool4oomo01;ooooo0_l00?lDooooo`Co003oJ?ooool1o`00007ooooo00000ol0
003oooooooooo`24ooooo`;oogl05Oooool3o`00o`kooooo0ol00?l3ooooo`;oogl0Ioooool1o`00
007ooooo00000ol0003oooooooooo`2Nooooo`?o003o1Oooool6o`00o`Gooooo1?ooO`1Vooooo`7o
00000Oooool00003o`000?oooooooooo0:7ooooo1Ol00?l;ooooo`Coogl0I_ooool1o`00007ooooo
00000ol0003oooooooooo`2booooo`;oogl0Ioooool1o`00007ooooo00000ol0003oooooooooo`3o
oooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003
o`000?oooooooooo07_ooooo0_ooO`2Nooooo`7o00000Oooool00003o`000?oooooooooo07[ooooo
1?ooO`2Mooooo`7o00000Oooool00003o`000?oooooooooo07[ooooo1?ooO`0Pooooo`;oogl0Nooo
ool1o`00007ooooo00000ol0003oooooooooo`1kooooo`;oogl08?ooool4oomo07[ooooo0Ol00001
ooooo`0000?o0000ooooooooool0WOooool4oomo07[ooooo0Ol00001ooooo`0000?o0000oooooooo
ool0T?ooool2oomo00cooooo0_ooO`1kooooo`7o00000Oooool00003o`000?oooooooooo08oooooo
1?ooO`28ooooo`7o00000Oooool00003o`000?oooooooooo08oooooo1?ooO`28ooooo`7o00000Ooo
ool00003o`000?oooooooooo093ooooo0_ooO`0Sooooo`;oogl0I?ooool1o`00007ooooo00000ol0
003oooooooooo`2dooooo`Coogl0Hoooool1o`00007ooooo00000ol0003oooooooooo`2dooooo`Co
ogl0Hoooool1o`00007ooooo00000ol0003oooooooooo`2eooooo`;oogl0I?ooool1o`00007ooooo
00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolL
ooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003o
ooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o0000
0Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3o
oooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003
o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo
0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oooooo
oooo0?oooooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001oooo
o`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo
7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000
ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00
007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0
oooooolLooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo0000
0ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLoooo
o`7o00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003ooooo
ooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Ooo
ool00003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooo
oacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`00
0?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol0
0001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo
0?oooooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`00
00?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?oo
ool1o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000oooo
ooooool0S_ooool2oomo08_ooooo0Ol00001ooooo`0000?o0000ooooooooool0SOooool4oomo08[o
oooo0Ol00001ooooo`0000?o0000ooooooooool0SOooool4oomo08[ooooo0Ol00001ooooo`0000?o
0000ooooooooool0S_ooool2oomo08_ooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolL
ooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003o
ooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o0000
0Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3o
oooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003
o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo
0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oooooo
oooo0?oooooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001oooo
o`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo
7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000
ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00
007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0
oooooolLooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo0000
0ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`00ool0000Po`00007ooooo0000\
\>"],
  ImageRangeCache->{{{0, 287}, {287, 0}} -> {-1.01089, -1.01089, 0.00704453, \
0.00704453}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.49505 0.5 0.49505 [
[ 0 0 -0.125 0 ]
[ 0 0 -0.125 0 ]
[ 0 1 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
0 0 m
1 0 L
s
0 0 m
0 1 L
s
0 1 m
1 1 L
s
1 0 m
1 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
1 .5 0 r
.015 w
.03175 .1355 Mdot
.03435 .12523 Mdot
.11137 .12765 Mdot
.14107 .18841 Mdot
.16218 .24538 Mdot
.17294 .21053 Mdot
.18267 .18577 Mdot
.18434 .1304 Mdot
.18553 .30956 Mdot
.20401 .239 Mdot
.21247 .27571 Mdot
.21687 .20845 Mdot
.22376 .2799 Mdot
.22832 .27485 Mdot
.29063 .20974 Mdot
.29686 .25079 Mdot
.30487 .22936 Mdot
.30683 .34623 Mdot
.32055 .20902 Mdot
.32574 .21979 Mdot
.34472 .28521 Mdot
.35998 .36393 Mdot
.36335 .24976 Mdot
.3794 .36608 Mdot
.42386 .66992 Mdot
.44391 .74519 Mdot
.45059 .34198 Mdot
.47208 .67586 Mdot
.47436 .71381 Mdot
.49778 .59825 Mdot
.50874 .91643 Mdot
.51516 .76219 Mdot
.53655 .61374 Mdot
.56563 .75219 Mdot
.59189 .65665 Mdot
.59581 .61604 Mdot
.59923 .6556 Mdot
.60292 .68499 Mdot
.62656 .67779 Mdot
.63555 .72451 Mdot
.63919 .652 Mdot
.64169 .6004 Mdot
.64246 .58611 Mdot
.64496 .54267 Mdot
.64608 .77288 Mdot
.65077 .64308 Mdot
.66065 .57816 Mdot
.67474 .59169 Mdot
.69296 .563 Mdot
.72815 .65902 Mdot
.73169 .58879 Mdot
.74669 .61318 Mdot
.74821 .65474 Mdot
.75963 .63781 Mdot
.79673 .57809 Mdot
.80925 .55852 Mdot
.81525 .58444 Mdot
.83417 .62985 Mdot
.83598 .55526 Mdot
.91595 .49319 Mdot
1 0 0 r
.005 w
.16128 .17044 m
.18734 .17269 L
.21339 .17909 L
.2345 .18734 L
.23945 .19126 L
.2655 .20415 L
.27874 .21339 L
.29156 .22295 L
.31204 .23945 L
.31761 .24532 L
.33549 .2655 L
.34367 .28341 L
.34499 .29156 L
.34367 .29798 L
.31761 .3104 L
.29156 .30711 L
.2655 .30014 L
.24507 .29156 L
.23945 .28747 L
.21339 .27402 L
.20155 .2655 L
.18734 .25472 L
.16884 .23945 L
.16128 .2313 L
.14618 .21339 L
.13806 .18734 L
.16128 .17044 L
s
0 0 1 r
.65633 .57701 m
.68239 .56842 L
.70844 .56313 L
.7345 .56168 L
.76055 .5752 L
.76359 .57817 L
.76859 .60422 L
.76055 .62333 L
.75627 .63028 L
.7345 .65485 L
.73298 .65633 L
.70844 .6775 L
.69922 .68239 L
.68239 .69294 L
.65633 .70579 L
.64983 .70844 L
.63028 .71539 L
.60422 .72268 L
.57817 .72651 L
.55211 .7214 L
.53145 .70844 L
.52926 .68239 L
.54239 .65633 L
.55211 .63983 L
.56625 .63028 L
.57817 .6193 L
.60119 .60422 L
.60422 .60227 L
.63028 .58726 L
.65315 .57817 L
.65633 .57701 L
s
1 0 0 r
.03 w
.24141 .24033 Mdot
0 0 1 r
.64872 .64417 Mdot
1 0 0 r
.79703 .00495 m
.79703 .00495 L
.87129 .00495 L
.87129 .00495 L
F
0 0 1 r
.89604 .00495 m
.89604 .25248 L
.9703 .25248 L
.9703 .00495 L
F
1 0 1 r
.04 w
.56563 .75219 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P000182000`400?l00000o`00003ooooooolQ
ooooo`00ool0000Po`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`00
00?o0000ooooooooool0o_oooolEo`00o`Sooooo0Ol00001ooooo`0000?o0000ooooooooool0o_oo
oolEo`00o`Sooooo0Ol00001ooooo`0000?o0000ooooooooool0o_oooolEo`00o`Sooooo0Ol00001
ooooo`0000?o0000ooooooooool0o_oooolEo`00o`Sooooo0Ol00001ooooo`0000?o0000oooooooo
ool0o_oooolEo`00o`Sooooo0Ol00001ooooo`0000?o0000ooooooooool0o_oooolEo`00o`Sooooo
0Ol00001ooooo`0000?o0000ooooooooool0o_oooolEo`00o`Sooooo0Ol00001ooooo`0000?o0000
ooooooooool0o_oooolEo`00o`Sooooo0Ol00001ooooo`0000?o0000ooooooooool0o_oooolEo`00
o`Sooooo0Ol00001ooooo`0000?o0000ooooooooool0o_oooolEo`00o`Sooooo0Ol00001ooooo`00
00?o0000ooooooooool0o_oooolEo`00o`Sooooo0Ol00001ooooo`0000?o0000ooooooooool0o_oo
oolEo`00o`Sooooo0Ol00001ooooo`0000?o0000ooooooooool0o_oooolEo`00o`Sooooo0Ol00001
ooooo`0000?o0000ooooooooool0o_oooolEo`00o`Sooooo0Ol00001ooooo`0000?o0000oooooooo
ool0o_oooolEo`00o`Sooooo0Ol00001ooooo`0000?o0000ooooooooool0o_oooolEo`00o`Sooooo
0Ol00001ooooo`0000?o0000ooooooooool0o_oooolEo`00o`Sooooo0Ol00001ooooo`0000?o0000
ooooooooool0o_oooolEo`00o`Sooooo0Ol00001ooooo`0000?o0000ooooooooool0o_oooolEo`00
o`Sooooo0Ol00001ooooo`0000?o0000ooooooooool0o_oooolEo`00o`Sooooo0Ol00001ooooo`00
00?o0000ooooooooool0o_oooolEo`00o`Sooooo0Ol00001ooooo`0000?o0000ooooooooool0o_oo
oolEo`00o`Sooooo0Ol00001ooooo`0000?o0000ooooooooool0o_oooolEo`00o`Sooooo0Ol00001
ooooo`0000?o0000ooooooooool0o_oooolEo`00o`Sooooo0Ol00001ooooo`0000?o0000oooooooo
ool0o_oooolEo`00o`Sooooo0Ol00001ooooo`0000?o0000ooooooooool0o_oooolEo`00o`Sooooo
0Ol00001ooooo`0000?o0000ooooooooool0o_oooolEo`00o`Sooooo0Ol00001ooooo`0000?o0000
ooooooooool0o_oooolEo`00o`Sooooo0Ol00001ooooo`0000?o0000ooooooooool0o_oooolEo`00
o`Sooooo0Ol00001ooooo`0000?o0000ooooooooool0o_oooolEo`00o`Sooooo0Ol00001ooooo`00
00?o0000ooooooooool0o_oooolEo`00o`Sooooo0Ol00001ooooo`0000?o0000ooooooooool0o_oo
oolEo`00o`Sooooo0Ol00001ooooo`0000?o0000ooooooooool01_ooool2oomo0?Kooooo5Ol00?l8
ooooo`7o00000Oooool00003o`000?oooooooooo00Gooooo1?ooO`0Cooooo`;oogl0h?oooolEo`00
o`Sooooo0Ol00001ooooo`0000?o0000ooooooooool01Oooool4oomo01;ooooo1?ooO`0Booooo`;o
ogl0booooolEo`00o`Sooooo0Ol00001ooooo`0000?o0000ooooooooool01Oooool3oomo01?ooooo
1?ooO`0Aooooo`Coogl0b_oooolEo`00o`Sooooo0Ol00001ooooo`0000?o0000ooooooooool01?oo
ool4oomo01Cooooo0_ooO`0Booooo`Coogl0b_oooolEo`00o`Sooooo0Ol00001ooooo`0000?o0000
ooooooooool01?ooool4oomo02Wooooo0_ooO`3;oooooaGo003o2?ooool1o`00007ooooo00000ol0
003oooooooooo`05ooooo`;oogl0mooooolEo`00o`Sooooo0Ol00001ooooo`0000?o0000oooooooo
ool0o_oooolEo`00o`Sooooo0Ol00001ooooo`0000?o0000ooooooooool0o_oooolEo`00o`Sooooo
0Ol00001ooooo`0000?o0000ooooooooool0o_oooolEo`00o`Sooooo0Ol00001ooooo`0000?o0000
ooooooooool0o_oooolEo`00o`Sooooo0Ol00001ooooo`0000?o0000ooooooooool0o_oooolEo`00
o`Sooooo0Ol00001ooooo`0000?o0000ooooooooool0o_oooolEo`00o`Sooooo0Ol00001ooooo`00
00?o0000ooooooooool0o_oooolEo`00o`Sooooo0Ol00001ooooo`0000?o0000ooooooooool0:_oo
ool6ool00<kooooo5Ol00?l8ooooo`7o00000Oooool00003o`000?oooooooooo02Wooooo00?oo`00
ooooooooool01?ooool5ool00<Wooooo5Ol00?l8ooooo`7o00000Oooool00003o`000?oooooooooo
02Oooooo0_oo000<ooooo`Coo`00aOoooolEo`00o`Sooooo0Ol00001ooooo`0000?o0000oooooooo
ool09_ooool00ooo003oooooooooo`0@ooooo`Coo`00`OoooolEo`00o`Sooooo0Ol00001ooooo`00
00?o0000ooooooooool09?ooool00oooO`3oo`00ooooo`09ooooo`;oogl02oooool3ool00;kooooo
5Ol00?l8ooooo`7o00000Oooool00003o`000?oooooooooo02?ooooo00Coogl0ool00?ooO`3oogl0
2?ooool4oomo00gooooo00?oo`00ooooooooool0^ooooolEo`00o`Sooooo0Ol00001ooooo`0000?o
0000ooooooooool08oooool01?ooO`3oo`00oomo0?ooO`08ooooo`Coogl03_ooool2ool00;_ooooo
5Ol00?l8ooooo`7o00000Oooool00003o`000?oooooooooo02Cooooo00?oogl0ool00?ooool02Ooo
ool2oomo017ooooo0_oo002ioooooaGo003o2?ooool1o`00007ooooo00000ol0003oooooooooo`0U
ooooo`03ool00?oooooooooo01gooooo0_oo002goooooaGo003o2?ooool1o`00007ooooo00000ol0
003oooooooooo`0Uooooo`03ool00?oooooooooo01oooooo0_oo002eoooooaGo003o2?ooool1o`00
007ooooo00000ol0003oooooooooo`0Vooooo`03ool00?oooooooooo017ooooo0_ooO`0=ooooo`;o
o`001?ooool2oomo00Oooooo0_ooO`2ToooooaGo003o2?ooool1o`00007ooooo00000ol0003ooooo
ooooo`0Vooooo`03ool00?oooooooooo00Gooooo0_ooO`09ooooo`Coogl03_ooool00ooo003ooooo
ooooo`04oomo00Gooooo1?ooO`2SoooooaGo003o2?ooool1o`00007ooooo00000ol0003ooooooooo
o`0Vooooo`03ool00?oooooooooo00Cooooo1?ooO`08ooooo`Coogl03oooool00ooo003ooooooomo
0003oomo00Gooooo1?ooO`2SoooooaGo003o2?ooool1o`00007ooooo00000ol0003oooooooooo`0W
ooooo`03ool00?oooooooooo00?ooooo1?ooO`09ooooo`;oogl04Oooool01?oo003ooooooomo0?oo
O`07ooooo`?oogl0XooooolEo`00o`Sooooo0Ol00001ooooo`0000?o0000ooooooooool09oooool0
0ooo003oooooooooo`04ooooo`;oogl07_ooool00ooo003oooooooooo`07ooooo`Coogl0X_oooolE
o`00o`Sooooo0Ol00001ooooo`0000?o0000ooooooooool0:?ooool00ooo003oooooooooo`0Toooo
o`03ool00?oooooooooo00Kooooo1?ooO`2RoooooaGo003o2?ooool1o`00007ooooo00000ol0003o
ooooooooo`0Yooooo`03ool00?oooooooooo02Cooooo0_oo00000oooooooogl0oomo0004ooooo`;o
ogl0XooooolEo`00o`Sooooo0Ol00001ooooo`0000?o0000ooooooooool0:_ooool00ooo003ooooo
ooooo`0Cooooo`Coo`003_ooool01?oo003oogl0oomo0?ooO`2XoooooaGo003o2?ooool1o`00007o
oooo00000ol0003oooooooooo`0[ooooo`03ool00?oooooooooo017ooooo1_oo000=ooooo`04oomo
0?oo003oo`00oomo0:Sooooo5Ol00?l8ooooo`7o00000Oooool00003o`000?oooooooooo02cooooo
00?oo`00ooooooooool02?ooool2oomo00Gooooo2?oo000=ooooo`;oogl000?oo`00ooooooooool0
Y_oooolEo`00o`Sooooo0Ol00001ooooo`0000?o0000ooooooooool0;Oooool00ooo003ooooooooo
o`06ooooo`Coogl01?ooool8ool0013ooooo00?oo`00ooooooooool0YOoooolEo`00o`Sooooo0Ol0
0001ooooo`0000?o0000ooooooooool0:oooool2oomo0003oooooooo003ooooo00Kooooo1?ooO`04
ooooo`Soo`004Oooool00ooo003oooooooooo`2ToooooaGo003o2?ooool1o`00007ooooo00000ol0
003oooooooooo`0Zooooo`Coogl000?oooooool00?ooool01_ooool2oomo00Gooooo2?oo000;oooo
o`;oogl01Oooool00ooo003oooooooooo`09ooooo`;oogl0V?oooolEo`00o`Sooooo0Ol00001oooo
o`0000?o0000ooooooooool0:_ooool4oomo00;ooooo00?oo`00ooooooooool03?ooool6ool000_o
oooo1?ooO`04ooooo`03ool00?oooooooooo00Sooooo1?ooO`2GoooooaGo003o2?ooool1o`00007o
oooo00000ol0003oooooooooo`0[ooooo`;oogl01?ooool00ooo003oooooooooo`0<ooooo`Coo`00
3?ooool4oomo00Gooooo00?oo`00ooooooooool01oooool4oomo09Oooooo5Ol00?l8ooooo`7o0000
0Oooool00003o`000?oooooooooo03;ooooo0_oo000Mooooo`;oogl01oooool00ooo003ooooooooo
o`07ooooo`;oogl0]Oooool1o`00007ooooo00000ol0003oooooooooo`0dooooo`03ool00?oooooo
oooo02Cooooo00?oo`00ooooooooool0_Oooool1o`00007ooooo00000ol0003oooooooooo`0eoooo
o`03ool00?oooooooooo02Cooooo00?oo`00ooooooooool0_?ooool1o`00007ooooo00000ol0003o
ooooooooo`0fooooo`;oo`009Oooool00ooo003oooooooooo`2kooooo`7o00000Oooool00003o`00
0?oooooooooo03Sooooo0_oo00000oooO`3oooooooooo`02oomo01kooooo00?oo`00ooooooooool0
^oooool1o`00007ooooo00000ol0003oooooooooo`0hooooo`;oogl00_oo0004oomo01kooooo00?o
o`00ooooooooool0^_ooool1o`00007ooooo00000ol0003oooooooooo`0hooooo`Coogl00_oo0002
oomo01kooooo00?oo`00ooooooooool0^_ooool1o`00007ooooo00000ol0003oooooooooo`0ioooo
o`Googl000?oo`00ooooooooool07Oooool00ooo003oogl0oomo002jooooo`7o00000Oooool00003
o`000?oooooooooo03_ooooo1?ooO`02ool001gooooo00Coogl0ool00?ooO`3oogl0^Oooool1o`00
007ooooo00000ol0003oooooooooo`0looooo`;oogl00oooool2ool001_ooooo00Coogl0ool00?oo
O`3oogl0^Oooool1o`00007ooooo00000ol0003oooooooooo`13ooooo`;oo`006_ooool00oooO`3o
o`00ooooo`2iooooo`7o00000Oooool00003o`000?oooooooooo04Gooooo0_oo000Iooooo`03ool0
0?oooooooooo0;Sooooo0Ol00001ooooo`0000?o0000ooooooooool0Aoooool2ool001Gooooo0_oo
002kooooo`7o00000Oooool00003o`000?oooooooooo04Wooooo0ooo000@ooooo`;oo`00_Oooool1
o`00007ooooo00000ol0003oooooooooo`0aooooo`;oogl06Oooool3ool000cooooo00?oo`00oooo
ooooool0_Oooool1o`00007ooooo00000ol0003oooooooooo`0`ooooo`Coogl06oooool6ool000Co
oooo0_oo0030ooooo`7o00000Oooool00003o`000?oooooooooo033ooooo1?ooO`0Qooooo`Coo`00
`_ooool1o`00007ooooo00000ol0003oooooooooo`0aooooo`;oogl0j?ooool1o`00007ooooo0000
0ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLoooo
o`7o00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003ooooo
ooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Ooo
ool00003o`000?oooooooooo07gooooo0_ooO`2Looooo`7o00000Oooool00003o`000?oooooooooo
07cooooo1?ooO`2Kooooo`7o00000Oooool00003o`000?oooooooooo05Cooooo0_ooO`0Vooooo`Co
ogl0Voooool1o`00007ooooo00000ol0003oooooooooo`1Cooooo`Coogl09_ooool2oomo09cooooo
0Ol00001ooooo`0000?o0000ooooooooool0Doooool4oomo0<Cooooo0Ol00001ooooo`0000?o0000
ooooooooool0E?ooool2oomo0<Gooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLoooo
o`7o00000Oooool00003o`000?oooooooooo06?ooooo0_ooO`04ooooo`;oogl0/?ooool1o`00007o
oooo00000ol0003oooooooooo`1Rooooo`Coogl00_ooool4oomo0:oooooo0Ol00001ooooo`0000?o
0000ooooooooool0H_ooool4oomo00;ooooo1?ooO`2_ooooo`7o00000Oooool00003o`000?oooooo
oooo06?ooooo0_ooO`04ooooo`;oogl0/?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooo
oacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`00
0?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol0
0001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo
0?oooooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`00
00?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?oo
ool1o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000oooo
ooooool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007o
oooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooo
oolLooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0
003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o
00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003ooooooooo
o`3ooooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool0
0003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooooaco
oooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oo
oooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001
ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo0?oo
oooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o
0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1
o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000oooooooo
ool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo
00000ol0003oooooooooo`3oooooo`Cooooo0_ooO`0Fooooo`7o00000Oooool00003o`000?oooooo
oooo0?oooooo0oooool4oomo01Gooooo0Ol00001ooooo`0000?o0000ooooooooool0ooooool3oooo
o`Coogl05Oooool1o`00007ooooo00000ol0003oooooooooo`3oooooo`Cooooo0_ooO`0Fooooo`7o
00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003ooooooooo
o`3ooooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool0
0003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooooaco
oooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oo
oooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001
ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo0?oo
oooo7?ooool1o`00007ooooo00000ol0003oooooooooo`2eooooo`;oogl0I?ooool1o`00007ooooo
00000ol0003oooooooooo`2dooooo`Coogl0Hoooool1o`00007ooooo00000ol0003oooooooooo`2d
ooooo`Coogl0Hoooool1o`00007ooooo00000ol0003oooooooooo`2eooooo`;oogl0=Oooool2oomo
02gooooo0Ol00001ooooo`0000?o0000ooooooooool0i?ooool2oomo00Gooooo1?ooO`0/ooooo`7o
00000Oooool00003o`000?oooooooooo0>?ooooo1?ooO`04ooooo`Coogl0;?ooool1o`00007ooooo
00000ol0003oooooooooo`33ooooo`;oogl07_ooool4oomo00Gooooo0_ooO`0]ooooo`7o00000Ooo
ool00003o`000?oooooooooo0<;ooooo1?ooO`0;o`00oa?ooooo0_ooO`0eooooo`7o00000Oooool0
0003o`000?oooooooooo0<;ooooo1?l00?l;ooooo`;o003oB?ooool1o`00007ooooo00000ol0003o
ooooooooo`2nooooo`Co003o00?ooooooomo0?ooO`003_ooool2o`00odKooooo0Ol00001ooooo`00
00?o0000ooooooooool0^Oooool2oomo00?o003o5oooool2o`00o`Wooooo0_ooO`0iooooo`7o0000
0Oooool00003o`000?oooooooooo0;Oooooo1?l00?l00oooO`3oooooooooo`0Iooooo`;o003o1_oo
ool4oomo03Sooooo0Ol00001ooooo`0000?o0000ooooooooool0]?ooool3o`00o`03ooooooooO`3o
ogl000;oogl07?ooool00ol00?ooooooooooo`04ooooo`Coogl00oooool2oomo03?ooooo0Ol00001
ooooo`0000?o0000ooooooooool0/_ooool2o`00o`?oogl00_ooool2oomo01?ooooo0_ooO`08oooo
o`03o`00oooooooooooo00Gooooo0_ooO`03ooooo`Coogl0<_ooool1o`00007ooooo00000ol0003o
ooooooooo`2`ooooo`;o003o00?ooooooomo0?ooO`000_ooO`06ooooo`;oogl03_ooool4oomo00Oo
oooo00?o003oooooooooool02_ooool4oomo03;ooooo0Ol00001ooooo`0000?o0000ooooooooool0
[_ooool2o`00o`Cooooo0_ooO`06ooooo`Coogl03Oooool4oomo00Oooooo00?o003oooooooooool0
2oooool2oomo03?ooooo0Ol00001ooooo`0000?o0000ooooooooool0Roooool2oomo023ooooo00?o
003oooooooooool01?ooool2oomo00Kooooo1?ooO`0>ooooo`;oogl02Oooool00ol00?oooooooooo
o`0oooooo`7o00000Oooool00003o`000?oooooooooo08[ooooo1?ooO`0Mooooo`;o003o1_ooool4
oomo00Kooooo0_ooO`0Jooooo`03o`00oooooooooooo03oooooo0Ol00001ooooo`0000?o0000oooo
ooooool0R_ooool4oomo01cooooo00?o003oooooooooool01_ooool4oomo02;ooooo00?o003ooooo
ooooool0?oooool1o`00007ooooo00000ol0003oooooooooo`2;ooooo`;oogl06oooool2o`00o`[o
oooo0_ooO`0Sooooo`03o`00oooooooooooo03oooooo0Ol00001ooooo`0000?o0000ooooooooool0
U_ooool2oomo00kooooo0_l00?lZooooo`;oogl01Oooool00ol00?ooooooooooo`0oooooo`7o0000
0Oooool00003o`000?oooooooooo09Gooooo1?ooO`0<ooooo`04o`00ooooooooogl0oomo02Sooooo
1?ooO`03ooooo`03o`00oooooooooooo043ooooo0Ol00001ooooo`0000?o0000ooooooooool0UOoo
ool4oomo00[ooooo0_l00?l00oooooooogl0oomo0002oomo02Oooooo1?ooO`03ooooo`03o`00oooo
oooooooo043ooooo0Ol00001ooooo`0000?o0000ooooooooool0U_ooool2oomo00[ooooo00Co003o
oooooooooooooooo1?ooO`0Xooooo`;oogl01?ooool00ol00?ooooooooooo`10ooooo`7o00000Ooo
ool00003o`000?oooooooooo0:7ooooo00?o003oooooooooool00oooool2oomo02kooooo00?o003o
ooooooooool0@Oooool1o`00007ooooo00000ol0003oooooooooo`2Pooooo`03o`00oooooooooooo
03?ooooo00?o003oooooooooool04_ooool2oomo02kooooo0Ol00001ooooo`0000?o0000oooooooo
ool0W_ooool2o`00ocGooooo00?o003oooooooooool04_ooool4oomo02gooooo0Ol00001ooooo`00
00?o0000ooooooooool0WOooool00ol00?ooooooooooo`0Eooooo`Co003o7?ooool00ol00?ooogl0
oomo000Booooo`Coogl0;Oooool1o`00007ooooo00000ol0003oooooooooo`2Looooo`03o`00oooo
oooooooo01Gooooo1_l00?lJooooo`03o`00ooooO`3oogl000;oogl04_ooool2oomo02kooooo0Ol0
0001ooooo`0000?o0000ooooooooool0Voooool00ol00?ooooooooooo`0Eooooo`So003o6?ooool0
0ol00?oooooooomo0003oomo04;ooooo0Ol00001ooooo`0000?o0000ooooooooool0Voooool00ol0
0?ooooooooooo`0Eooooo`So003o5oooool01?l00?ooooooooooooooool2oomo04?ooooo0Ol00001
ooooo`0000?o0000ooooooooool0V_ooool00ol00?ooooooooooo`0Fooooo`So003o5_ooool00ol0
0?ooooooooooo`17ooooo`7o00000Oooool00003o`000?oooooooooo09Wooooo00?o003ooooooooo
ool03?ooool2oomo00Sooooo00?oogl0o`00ool00?l01_l00?lEooooo`03o`00oooooooooooo00;o
ogl0A_ooool1o`00007ooooo00000ol0003oooooooooo`2Iooooo`03o`00oooooooooooo00[ooooo
1OooO`07ooooo`;oogl01_l00?lCooooo`;oogl000?o003oooooooooool01?ooO`15ooooo`7o0000
0Oooool00003o`000?oooooooooo09Sooooo00?o003oooooooooool02_ooool6oomo00Sooooo0_oo
O`04o`00oa?ooooo0_ooO`02o`00o`;ooooo1?ooO`15ooooo`7o00000Oooool00003o`000?oooooo
oooo09Sooooo00?o003oooooooooool02_ooool5oomo02;ooooo00Coogl0o`00ooooO`3oogl00ooo
ool2oomo04Kooooo0Ol00001ooooo`0000?o0000ooooooooool0M_ooool2oomo01oooooo00?o003o
ooooooooool03?ooool2oomo02Cooooo00?o003ooomo0?ooO`00C?ooool1o`00007ooooo00000ol0
003oooooooooo`1eooooo`Coogl07_ooool00ol00?ooooooooooo`0aooooo`03o`00oooooooooooo
04gooooo0Ol00001ooooo`0000?o0000ooooooooool0MOooool4oomo00[ooooo0_ooO`0Aooooo`03
o`00oooooooooooo037ooooo00?o003oooooooooool0C_ooool1o`00007ooooo00000ol0003ooooo
ooooo`1fooooo`;oogl02_ooool4oomo00oooooo00?o003oooooooooool06?ooool2oomo01Oooooo
00?o003oooooooooool0Coooool1o`00007ooooo00000ol0003oooooooooo`22ooooo`Coogl03ooo
ool00ol00?ooooooooooo`0Gooooo`Coogl05?ooool2o`00oe;ooooo0Ol00001ooooo`0000?o0000
ooooooooool0Poooool2oomo00oooooo00?o003oooooooooool04_ooool2oomo00Cooooo1?ooO`0A
ooooo`?o003oE?ooool1o`00007ooooo00000ol0003oooooooooo`2Dooooo`03o`00oooooooooooo
017ooooo1?ooO`04ooooo`;oogl04?ooool2o`00oeOooooo0Ol00001ooooo`0000?o0000oooooooo
ool0U?ooool00ol00?ooooooooooo`0Aooooo`Coogl05Oooool00ol00?ooooooooooo`1Gooooo`7o
00000Oooool00003o`000?oooooooooo09Cooooo00?o003oooooooooool04_ooool2oomo01Cooooo
0_l00?mJooooo`7o00000Oooool00003o`000?oooooooooo09Cooooo00?o003oooooooooool09_oo
ool2o`00oecooooo0Ol00001ooooo`0000?o0000ooooooooool0UOooool00ol00?ooooooooooo`0T
ooooo`03o`00oooooooooooo05cooooo0Ol00001ooooo`0000?o0000ooooooooool0UOooool00ol0
0?ooooooooooo`0Rooooo`;o003oGoooool1o`00007ooooo00000ol0003oooooooooo`2Eooooo`03
o`00oooooooooooo023ooooo0_l00?mQooooo`7o00000Oooool00003o`000?oooooooooo08Cooooo
0_ooO`0?ooooo`;o003o7oooool2o`00of?ooooo0Ol00001ooooo`0000?o0000ooooooooool0Pooo
ool4oomo013ooooo0_l00?lJooooo`?o003oIOooool1o`00007ooooo00000ol0003oooooooooo`23
ooooo`Coogl04_ooool2o`00oaCooooo1?l00?mXooooo`7o00000Oooool00003o`000?oooooooooo
08Cooooo0_ooO`0Eooooo`?o003o3_ooool3o`00o`?ooooo0_ooO`1Wooooo`7o00000Oooool00003
o`000?oooooooooo09kooooo0ol00?l5ooooo`Ko003o1Oooool4oomo06Kooooo0Ol00001ooooo`00
00?o0000ooooooooool0XOooool5o`00o`_ooooo1?ooO`1Vooooo`7o00000Oooool00003o`000?oo
oooooooo0;;ooooo0_ooO`1Wooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1
o`00007ooooo00000ol0003oooooooooo`2Mooooo`Goo`3oNOooool1o`00007ooooo00000ol0003o
ooooooooo`1kooooo`;oogl07oooool7ool0ogSooooo0Ol00001ooooo`0000?o0000ooooooooool0
N_ooool4oomo01gooooo2Ooo0?mgooooo`7o00000Oooool00003o`000?oooooooooo07[ooooo1?oo
O`0Looooo`_oo`3oM_ooool1o`00007ooooo00000ol0003oooooooooo`1kooooo`;oogl07Oooool;
ool0ogKooooo0Ol00001ooooo`0000?o0000ooooooooool0V_ooool;ool0ogKooooo0Ol00001oooo
o`0000?o0000ooooooooool0T?ooool2oomo00Sooooo2ooo0?mfooooo`7o00000Oooool00003o`00
0?oooooooooo08oooooo1?ooO`07ooooo`_oo`3oM_ooool1o`00007ooooo00000ol0003ooooooooo
o`2?ooooo`Coogl02?ooool9ool0ogOooooo0Ol00001ooooo`0000?o0000ooooooooool0T?ooool2
oomo00[ooooo1ooo0?lBooooo`;oogl0I?ooool1o`00007ooooo00000ol0003oooooooooo`2Moooo
o`Goo`3o4_ooool4oomo06?ooooo0Ol00001ooooo`0000?o0000ooooooooool0]?ooool4oomo06?o
oooo0Ol00001ooooo`0000?o0000ooooooooool0]Oooool2oomo06Cooooo0Ol00001ooooo`0000?o
0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1
o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000oooooooo
ool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo
00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolL
ooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003o
ooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o0000
0Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3o
oooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003
o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo
0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oooooo
oooo0?oooooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001oooo
o`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo
7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000
ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00
007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0
oooooolLooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo0000
0ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLoooo
o`7o00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003ooooo
ooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Ooo
ool00003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooo
oacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`00
0?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol0
0001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo
08kooooo0_ooO`2;ooooo`7o00000Oooool00003o`000?oooooooooo08gooooo1?ooO`2:ooooo`7o
00000Oooool00003o`000?oooooooooo08gooooo1?ooO`2:ooooo`7o00000Oooool00003o`000?oo
oooooooo08kooooo0_ooO`2;ooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1
o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000oooooooo
ool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo
00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolL
ooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003o
ooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o0000
0Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3o
oooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003
o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo
0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oooooo
oooo0?oooooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001oooo
o`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo
7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000
ooooooooool0oooooolLooooo`7o00000Oooool00?oo00008?l00001ooooo`00\
\>"],
  ImageRangeCache->{{{0, 287}, {287, 0}} -> {-1.01089, -1.01089, 0.00704453, \
0.00704453}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.49505 0.5 0.49505 [
[ 0 0 -0.125 0 ]
[ 0 0 -0.125 0 ]
[ 0 1 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
0 0 m
1 0 L
s
0 0 m
0 1 L
s
0 1 m
1 1 L
s
1 0 m
1 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
1 .5 0 r
.015 w
.03175 .1355 Mdot
.03435 .12523 Mdot
.11137 .12765 Mdot
.14107 .18841 Mdot
.16218 .24538 Mdot
.17294 .21053 Mdot
.18267 .18577 Mdot
.18434 .1304 Mdot
.18553 .30956 Mdot
.20401 .239 Mdot
.21247 .27571 Mdot
.21687 .20845 Mdot
.22376 .2799 Mdot
.22832 .27485 Mdot
.29063 .20974 Mdot
.29686 .25079 Mdot
.30487 .22936 Mdot
.30683 .34623 Mdot
.32055 .20902 Mdot
.32574 .21979 Mdot
.34472 .28521 Mdot
.35998 .36393 Mdot
.36335 .24976 Mdot
.3794 .36608 Mdot
.42386 .66992 Mdot
.44391 .74519 Mdot
.45059 .34198 Mdot
.47208 .67586 Mdot
.47436 .71381 Mdot
.49778 .59825 Mdot
.50874 .91643 Mdot
.51516 .76219 Mdot
.53655 .61374 Mdot
.56563 .75219 Mdot
.59189 .65665 Mdot
.59581 .61604 Mdot
.59923 .6556 Mdot
.60292 .68499 Mdot
.62656 .67779 Mdot
.63555 .72451 Mdot
.63919 .652 Mdot
.64169 .6004 Mdot
.64246 .58611 Mdot
.64496 .54267 Mdot
.64608 .77288 Mdot
.65077 .64308 Mdot
.66065 .57816 Mdot
.67474 .59169 Mdot
.69296 .563 Mdot
.72815 .65902 Mdot
.73169 .58879 Mdot
.74669 .61318 Mdot
.74821 .65474 Mdot
.75963 .63781 Mdot
.79673 .57809 Mdot
.80925 .55852 Mdot
.81525 .58444 Mdot
.83417 .62985 Mdot
.83598 .55526 Mdot
.91595 .49319 Mdot
1 0 0 r
.005 w
.16128 .17044 m
.18734 .17269 L
.21339 .17909 L
.2345 .18734 L
.23945 .19126 L
.2655 .20415 L
.27874 .21339 L
.29156 .22295 L
.31204 .23945 L
.31761 .24532 L
.33549 .2655 L
.34367 .28341 L
.34499 .29156 L
.34367 .29798 L
.31761 .3104 L
.29156 .30711 L
.2655 .30014 L
.24507 .29156 L
.23945 .28747 L
.21339 .27402 L
.20155 .2655 L
.18734 .25472 L
.16884 .23945 L
.16128 .2313 L
.14618 .21339 L
.13806 .18734 L
.16128 .17044 L
s
0 0 1 r
.65633 .57701 m
.68239 .56842 L
.70844 .56313 L
.7345 .56168 L
.76055 .5752 L
.76359 .57817 L
.76859 .60422 L
.76055 .62333 L
.75627 .63028 L
.7345 .65485 L
.73298 .65633 L
.70844 .6775 L
.69922 .68239 L
.68239 .69294 L
.65633 .70579 L
.64983 .70844 L
.63028 .71539 L
.60422 .72268 L
.57817 .72651 L
.55211 .7214 L
.53145 .70844 L
.52926 .68239 L
.54239 .65633 L
.55211 .63983 L
.56625 .63028 L
.57817 .6193 L
.60119 .60422 L
.60422 .60227 L
.63028 .58726 L
.65315 .57817 L
.65633 .57701 L
s
1 0 0 r
.03 w
.24141 .24033 Mdot
0 0 1 r
.64872 .64417 Mdot
1 0 0 r
.79703 .00495 m
.79703 .00495 L
.87129 .00495 L
.87129 .00495 L
F
0 0 1 r
.89604 .00495 m
.89604 .25248 L
.9703 .25248 L
.9703 .00495 L
F
1 0 1 r
.04 w
.59189 .65665 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P000182000`400?l00000o`00003ooooooolQ
ooooo`00ool0000Po`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`00
00?o0000ooooooooool0o_oooolEo`00o`Sooooo0Ol00001ooooo`0000?o0000ooooooooool0o_oo
oolEo`00o`Sooooo0Ol00001ooooo`0000?o0000ooooooooool0o_oooolEo`00o`Sooooo0Ol00001
ooooo`0000?o0000ooooooooool0o_oooolEo`00o`Sooooo0Ol00001ooooo`0000?o0000oooooooo
ool0o_oooolEo`00o`Sooooo0Ol00001ooooo`0000?o0000ooooooooool0o_oooolEo`00o`Sooooo
0Ol00001ooooo`0000?o0000ooooooooool0o_oooolEo`00o`Sooooo0Ol00001ooooo`0000?o0000
ooooooooool0o_oooolEo`00o`Sooooo0Ol00001ooooo`0000?o0000ooooooooool0o_oooolEo`00
o`Sooooo0Ol00001ooooo`0000?o0000ooooooooool0o_oooolEo`00o`Sooooo0Ol00001ooooo`00
00?o0000ooooooooool0o_oooolEo`00o`Sooooo0Ol00001ooooo`0000?o0000ooooooooool0o_oo
oolEo`00o`Sooooo0Ol00001ooooo`0000?o0000ooooooooool0o_oooolEo`00o`Sooooo0Ol00001
ooooo`0000?o0000ooooooooool0o_oooolEo`00o`Sooooo0Ol00001ooooo`0000?o0000oooooooo
ool0o_oooolEo`00o`Sooooo0Ol00001ooooo`0000?o0000ooooooooool0o_oooolEo`00o`Sooooo
0Ol00001ooooo`0000?o0000ooooooooool0o_oooolEo`00o`Sooooo0Ol00001ooooo`0000?o0000
ooooooooool0o_oooolEo`00o`Sooooo0Ol00001ooooo`0000?o0000ooooooooool0o_oooolEo`00
o`Sooooo0Ol00001ooooo`0000?o0000ooooooooool0o_oooolEo`00o`Sooooo0Ol00001ooooo`00
00?o0000ooooooooool0o_oooolEo`00o`Sooooo0Ol00001ooooo`0000?o0000ooooooooool0o_oo
oolEo`00o`Sooooo0Ol00001ooooo`0000?o0000ooooooooool0o_oooolEo`00o`Sooooo0Ol00001
ooooo`0000?o0000ooooooooool0o_oooolEo`00o`Sooooo0Ol00001ooooo`0000?o0000oooooooo
ool0o_oooolEo`00o`Sooooo0Ol00001ooooo`0000?o0000ooooooooool0o_oooolEo`00o`Sooooo
0Ol00001ooooo`0000?o0000ooooooooool0o_oooolEo`00o`Sooooo0Ol00001ooooo`0000?o0000
ooooooooool0o_oooolEo`00o`Sooooo0Ol00001ooooo`0000?o0000ooooooooool0o_oooolEo`00
o`Sooooo0Ol00001ooooo`0000?o0000ooooooooool0o_oooolEo`00o`Sooooo0Ol00001ooooo`00
00?o0000ooooooooool0o_oooolEo`00o`Sooooo0Ol00001ooooo`0000?o0000ooooooooool0o_oo
oolEo`00o`Sooooo0Ol00001ooooo`0000?o0000ooooooooool01_ooool2oomo0?Kooooo5Ol00?l8
ooooo`7o00000Oooool00003o`000?oooooooooo00Gooooo1?ooO`0Cooooo`;oogl0h?oooolEo`00
o`Sooooo0Ol00001ooooo`0000?o0000ooooooooool01Oooool4oomo01;ooooo1?ooO`0Booooo`;o
ogl0booooolEo`00o`Sooooo0Ol00001ooooo`0000?o0000ooooooooool01Oooool3oomo01?ooooo
1?ooO`0Aooooo`Coogl0b_oooolEo`00o`Sooooo0Ol00001ooooo`0000?o0000ooooooooool01?oo
ool4oomo01Cooooo0_ooO`0Booooo`Coogl0b_oooolEo`00o`Sooooo0Ol00001ooooo`0000?o0000
ooooooooool01?ooool4oomo02Wooooo0_ooO`3;oooooaGo003o2?ooool1o`00007ooooo00000ol0
003oooooooooo`05ooooo`;oogl0mooooolEo`00o`Sooooo0Ol00001ooooo`0000?o0000oooooooo
ool0o_oooolEo`00o`Sooooo0Ol00001ooooo`0000?o0000ooooooooool0o_oooolEo`00o`Sooooo
0Ol00001ooooo`0000?o0000ooooooooool0o_oooolEo`00o`Sooooo0Ol00001ooooo`0000?o0000
ooooooooool0o_oooolEo`00o`Sooooo0Ol00001ooooo`0000?o0000ooooooooool0o_oooolEo`00
o`Sooooo0Ol00001ooooo`0000?o0000ooooooooool0o_oooolEo`00o`Sooooo0Ol00001ooooo`00
00?o0000ooooooooool0o_oooolEo`00o`Sooooo0Ol00001ooooo`0000?o0000ooooooooool0:_oo
ool6ool00<kooooo5Ol00?l8ooooo`7o00000Oooool00003o`000?oooooooooo02Wooooo00?oo`00
ooooooooool01?ooool5ool00<Wooooo5Ol00?l8ooooo`7o00000Oooool00003o`000?oooooooooo
02Oooooo0_oo000<ooooo`Coo`00aOoooolEo`00o`Sooooo0Ol00001ooooo`0000?o0000oooooooo
ool09_ooool00ooo003oooooooooo`0@ooooo`Coo`00`OoooolEo`00o`Sooooo0Ol00001ooooo`00
00?o0000ooooooooool09?ooool00oooO`3oo`00ooooo`09ooooo`;oogl02oooool3ool00;kooooo
5Ol00?l8ooooo`7o00000Oooool00003o`000?oooooooooo02?ooooo00Coogl0ool00?ooO`3oogl0
2?ooool4oomo00gooooo00?oo`00ooooooooool0^ooooolEo`00o`Sooooo0Ol00001ooooo`0000?o
0000ooooooooool08oooool01?ooO`3oo`00oomo0?ooO`08ooooo`Coogl03_ooool2ool00;_ooooo
5Ol00?l8ooooo`7o00000Oooool00003o`000?oooooooooo02Cooooo00?oogl0ool00?ooool02Ooo
ool2oomo017ooooo0_oo002ioooooaGo003o2?ooool1o`00007ooooo00000ol0003oooooooooo`0U
ooooo`03ool00?oooooooooo01gooooo0_oo002goooooaGo003o2?ooool1o`00007ooooo00000ol0
003oooooooooo`0Uooooo`03ool00?oooooooooo01oooooo0_oo002eoooooaGo003o2?ooool1o`00
007ooooo00000ol0003oooooooooo`0Vooooo`03ool00?oooooooooo017ooooo0_ooO`0=ooooo`;o
o`001?ooool2oomo00Oooooo0_ooO`2ToooooaGo003o2?ooool1o`00007ooooo00000ol0003ooooo
ooooo`0Vooooo`03ool00?oooooooooo00Gooooo0_ooO`09ooooo`Coogl03_ooool00ooo003ooooo
ooooo`04oomo00Gooooo1?ooO`2SoooooaGo003o2?ooool1o`00007ooooo00000ol0003ooooooooo
o`0Vooooo`03ool00?oooooooooo00Cooooo1?ooO`08ooooo`Coogl03oooool00ooo003ooooooomo
0003oomo00Gooooo1?ooO`2SoooooaGo003o2?ooool1o`00007ooooo00000ol0003oooooooooo`0W
ooooo`03ool00?oooooooooo00?ooooo1?ooO`09ooooo`;oogl04Oooool01?oo003ooooooomo0?oo
O`07ooooo`?oogl0XooooolEo`00o`Sooooo0Ol00001ooooo`0000?o0000ooooooooool09oooool0
0ooo003oooooooooo`04ooooo`;oogl07_ooool00ooo003oooooooooo`07ooooo`Coogl0X_oooolE
o`00o`Sooooo0Ol00001ooooo`0000?o0000ooooooooool0:?ooool00ooo003oooooooooo`0Toooo
o`03ool00?oooooooooo00Kooooo1?ooO`2RoooooaGo003o2?ooool1o`00007ooooo00000ol0003o
ooooooooo`0Yooooo`03ool00?oooooooooo02Cooooo0_oo00000oooooooogl0oomo0004ooooo`;o
ogl0XooooolEo`00o`Sooooo0Ol00001ooooo`0000?o0000ooooooooool0:_ooool00ooo003ooooo
ooooo`0Cooooo`Coo`003_ooool01?oo003oogl0oomo0?ooO`2XoooooaGo003o2?ooool1o`00007o
oooo00000ol0003oooooooooo`0[ooooo`03ool00?oooooooooo017ooooo1_oo000=ooooo`04oomo
0?oo003oo`00oomo0:Sooooo5Ol00?l8ooooo`7o00000Oooool00003o`000?oooooooooo02cooooo
00?oo`00ooooooooool02?ooool2oomo00Gooooo2?oo000=ooooo`;oogl000?oo`00ooooooooool0
Y_oooolEo`00o`Sooooo0Ol00001ooooo`0000?o0000ooooooooool0;Oooool00ooo003ooooooooo
o`06ooooo`Coogl01?ooool8ool0013ooooo00?oo`00ooooooooool0YOoooolEo`00o`Sooooo0Ol0
0001ooooo`0000?o0000ooooooooool0:oooool2oomo0003oooooooo003ooooo00Kooooo1?ooO`04
ooooo`Soo`004Oooool00ooo003oooooooooo`2ToooooaGo003o2?ooool1o`00007ooooo00000ol0
003oooooooooo`0Zooooo`Coogl000?oooooool00?ooool01_ooool2oomo00Gooooo2?oo000;oooo
o`;oogl01Oooool00ooo003oooooooooo`09ooooo`;oogl0V?oooolEo`00o`Sooooo0Ol00001oooo
o`0000?o0000ooooooooool0:_ooool4oomo00;ooooo00?oo`00ooooooooool03?ooool6ool000_o
oooo1?ooO`04ooooo`03ool00?oooooooooo00Sooooo1?ooO`2GoooooaGo003o2?ooool1o`00007o
oooo00000ol0003oooooooooo`0[ooooo`;oogl01?ooool00ooo003oooooooooo`0<ooooo`Coo`00
3?ooool4oomo00Gooooo00?oo`00ooooooooool01oooool4oomo09Oooooo5Ol00?l8ooooo`7o0000
0Oooool00003o`000?oooooooooo03;ooooo0_oo000Mooooo`;oogl01oooool00ooo003ooooooooo
o`07ooooo`;oogl0]Oooool1o`00007ooooo00000ol0003oooooooooo`0dooooo`03ool00?oooooo
oooo02Cooooo00?oo`00ooooooooool0_Oooool1o`00007ooooo00000ol0003oooooooooo`0eoooo
o`03ool00?oooooooooo02Cooooo00?oo`00ooooooooool0_?ooool1o`00007ooooo00000ol0003o
ooooooooo`0fooooo`;oo`009Oooool00ooo003oooooooooo`2kooooo`7o00000Oooool00003o`00
0?oooooooooo03Sooooo0_oo00000oooO`3oooooooooo`02oomo01kooooo00?oo`00ooooooooool0
^oooool1o`00007ooooo00000ol0003oooooooooo`0hooooo`;oogl00_oo0004oomo01kooooo00?o
o`00ooooooooool0^_ooool1o`00007ooooo00000ol0003oooooooooo`0hooooo`Coogl00_oo0002
oomo01kooooo00?oo`00ooooooooool0^_ooool1o`00007ooooo00000ol0003oooooooooo`0ioooo
o`Googl000?oo`00ooooooooool07Oooool00ooo003oogl0oomo002jooooo`7o00000Oooool00003
o`000?oooooooooo03_ooooo1?ooO`02ool001gooooo00Coogl0ool00?ooO`3oogl0^Oooool1o`00
007ooooo00000ol0003oooooooooo`0looooo`;oogl00oooool2ool001_ooooo00Coogl0ool00?oo
O`3oogl0^Oooool1o`00007ooooo00000ol0003oooooooooo`13ooooo`;oo`006_ooool00oooO`3o
o`00ooooo`2iooooo`7o00000Oooool00003o`000?oooooooooo04Gooooo0_oo000Iooooo`03ool0
0?oooooooooo0;Sooooo0Ol00001ooooo`0000?o0000ooooooooool0Aoooool2ool001Gooooo0_oo
002kooooo`7o00000Oooool00003o`000?oooooooooo04Wooooo0ooo000@ooooo`;oo`00_Oooool1
o`00007ooooo00000ol0003oooooooooo`0aooooo`;oogl06Oooool3ool000cooooo00?oo`00oooo
ooooool0_Oooool1o`00007ooooo00000ol0003oooooooooo`0`ooooo`Coogl06oooool6ool000Co
oooo0_oo0030ooooo`7o00000Oooool00003o`000?oooooooooo033ooooo1?ooO`0Qooooo`Coo`00
`_ooool1o`00007ooooo00000ol0003oooooooooo`0aooooo`;oogl0j?ooool1o`00007ooooo0000
0ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLoooo
o`7o00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003ooooo
ooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Ooo
ool00003o`000?oooooooooo07gooooo0_ooO`2Looooo`7o00000Oooool00003o`000?oooooooooo
07cooooo1?ooO`2Kooooo`7o00000Oooool00003o`000?oooooooooo05Cooooo0_ooO`0Vooooo`Co
ogl0Voooool1o`00007ooooo00000ol0003oooooooooo`1Cooooo`Coogl09_ooool2oomo09cooooo
0Ol00001ooooo`0000?o0000ooooooooool0Doooool4oomo0<Cooooo0Ol00001ooooo`0000?o0000
ooooooooool0E?ooool2oomo0<Gooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLoooo
o`7o00000Oooool00003o`000?oooooooooo06?ooooo0_ooO`04ooooo`;oogl0/?ooool1o`00007o
oooo00000ol0003oooooooooo`1Rooooo`Coogl00_ooool4oomo0:oooooo0Ol00001ooooo`0000?o
0000ooooooooool0H_ooool4oomo00;ooooo1?ooO`2_ooooo`7o00000Oooool00003o`000?oooooo
oooo06?ooooo0_ooO`04ooooo`;oogl0/?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooo
oacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`00
0?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol0
0001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo
0?oooooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`00
00?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?oo
ool1o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000oooo
ooooool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007o
oooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooo
oolLooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0
003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o
00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003ooooooooo
o`3ooooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool0
0003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooooaco
oooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oo
oooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001
ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo0?oo
oooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o
0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1
o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000oooooooo
ool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo
00000ol0003oooooooooo`3oooooo`Cooooo0_ooO`0Fooooo`7o00000Oooool00003o`000?oooooo
oooo0?oooooo0oooool4oomo01Gooooo0Ol00001ooooo`0000?o0000ooooooooool0ooooool3oooo
o`Coogl05Oooool1o`00007ooooo00000ol0003oooooooooo`3oooooo`Cooooo0_ooO`0Fooooo`7o
00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003ooooooooo
o`3ooooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool0
0003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooooaco
oooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oo
oooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001
ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo0?oo
oooo7?ooool1o`00007ooooo00000ol0003oooooooooo`2eooooo`;oogl0I?ooool1o`00007ooooo
00000ol0003oooooooooo`2dooooo`Coogl0Hoooool1o`00007ooooo00000ol0003oooooooooo`2d
ooooo`Coogl0Hoooool1o`00007ooooo00000ol0003oooooooooo`2eooooo`;oogl0=Oooool2oomo
02gooooo0Ol00001ooooo`0000?o0000ooooooooool0i?ooool2oomo00Gooooo1?ooO`0/ooooo`7o
00000Oooool00003o`000?oooooooooo0>?ooooo1?ooO`04ooooo`Coogl0;?ooool1o`00007ooooo
00000ol0003oooooooooo`33ooooo`;oogl07_ooool4oomo00Gooooo0_ooO`0]ooooo`7o00000Ooo
ool00003o`000?oooooooooo0<;ooooo1?ooO`0;o`00oa?ooooo0_ooO`0eooooo`7o00000Oooool0
0003o`000?oooooooooo0<;ooooo1?l00?l;ooooo`;o003oB?ooool1o`00007ooooo00000ol0003o
ooooooooo`2nooooo`Co003o00?ooooooomo0?ooO`003_ooool2o`00odKooooo0Ol00001ooooo`00
00?o0000ooooooooool0^Oooool2oomo00?o003o5oooool2o`00o`Wooooo0_ooO`0iooooo`7o0000
0Oooool00003o`000?oooooooooo0;Oooooo1?l00?l00oooO`3oooooooooo`0Iooooo`;o003o1_oo
ool4oomo03Sooooo0Ol00001ooooo`0000?o0000ooooooooool0]?ooool3o`00o`03ooooooooO`3o
ogl000;oogl07?ooool00ol00?ooooooooooo`04ooooo`Coogl00oooool2oomo03?ooooo0Ol00001
ooooo`0000?o0000ooooooooool0/_ooool2o`00o`?oogl00_ooool2oomo01?ooooo0_ooO`08oooo
o`03o`00oooooooooooo00Gooooo0_ooO`03ooooo`Coogl0<_ooool1o`00007ooooo00000ol0003o
ooooooooo`2`ooooo`;o003o00?ooooooomo0?ooO`000_ooO`06ooooo`;oogl03_ooool4oomo00Oo
oooo00?o003oooooooooool02_ooool4oomo03;ooooo0Ol00001ooooo`0000?o0000ooooooooool0
[_ooool2o`00o`Cooooo0_ooO`06ooooo`Coogl03Oooool4oomo00Oooooo00?o003oooooooooool0
2oooool2oomo03?ooooo0Ol00001ooooo`0000?o0000ooooooooool0Roooool2oomo023ooooo00?o
003oooooooooool01?ooool2oomo00Kooooo1?ooO`0>ooooo`;oogl02Oooool00ol00?oooooooooo
o`0oooooo`7o00000Oooool00003o`000?oooooooooo08[ooooo1?ooO`0Mooooo`;o003o1_ooool4
oomo00Kooooo0_ooO`0Jooooo`03o`00oooooooooooo03oooooo0Ol00001ooooo`0000?o0000oooo
ooooool0R_ooool4oomo01cooooo00?o003oooooooooool01_ooool4oomo02;ooooo00?o003ooooo
ooooool0?oooool1o`00007ooooo00000ol0003oooooooooo`2;ooooo`;oogl06oooool2o`00o`[o
oooo0_ooO`0Sooooo`03o`00oooooooooooo03oooooo0Ol00001ooooo`0000?o0000ooooooooool0
U_ooool2oomo00kooooo0_l00?lZooooo`;oogl01Oooool00ol00?ooooooooooo`0oooooo`7o0000
0Oooool00003o`000?oooooooooo09Gooooo1?ooO`0<ooooo`04o`00ooooooooogl0oomo02Sooooo
1?ooO`03ooooo`03o`00oooooooooooo043ooooo0Ol00001ooooo`0000?o0000ooooooooool0UOoo
ool4oomo00[ooooo0_l00?l00oooooooogl0oomo0002oomo02Oooooo1?ooO`03ooooo`03o`00oooo
oooooooo043ooooo0Ol00001ooooo`0000?o0000ooooooooool0U_ooool2oomo00[ooooo00Co003o
oooooooooooooooo1?ooO`0Xooooo`;oogl01?ooool00ol00?ooooooooooo`10ooooo`7o00000Ooo
ool00003o`000?oooooooooo0:7ooooo00?o003oooooooooool00oooool2oomo02kooooo00?o003o
ooooooooool0@Oooool1o`00007ooooo00000ol0003oooooooooo`2Pooooo`03o`00oooooooooooo
03?ooooo00?o003oooooooooool04_ooool2oomo02kooooo0Ol00001ooooo`0000?o0000oooooooo
ool0W_ooool2o`00ocGooooo00?o003oooooooooool04_ooool4oomo02gooooo0Ol00001ooooo`00
00?o0000ooooooooool0WOooool00ol00?ooooooooooo`0Eooooo`Co003o7?ooool00ol00?ooogl0
oomo000Booooo`Coogl0;Oooool1o`00007ooooo00000ol0003oooooooooo`2Looooo`03o`00oooo
oooooooo01Gooooo1_l00?lJooooo`03o`00ooooO`3oogl000;oogl04_ooool2oomo02kooooo0Ol0
0001ooooo`0000?o0000ooooooooool0Voooool00ol00?ooooooooooo`06ooooo`Goo`3o2_ooool8
o`00oaSooooo00?o003oooooooooO`000oooO`12ooooo`7o00000Oooool00003o`000?oooooooooo
09_ooooo00?o003oooooooooool01Oooool7ool0o`Wooooo2?l00?lGooooo`04o`00oooooooooooo
ooooo`;oogl0@oooool1o`00007ooooo00000ol0003oooooooooo`2Jooooo`03o`00oooooooooooo
00Gooooo2Ooo0?l8ooooo`So003o5_ooool00ol00?ooooooooooo`17ooooo`7o00000Oooool00003
o`000?oooooooooo09Wooooo00?o003oooooooooool01Oooool;ool0o`Kooooo00?oogl0o`00ool0
0?l01_l00?lEooooo`03o`00oooooooooooo00;oogl0A_ooool1o`00007ooooo00000ol0003ooooo
ooooo`2Iooooo`03o`00oooooooooooo00Gooooo2ooo0?l6ooooo`;oogl01_l00?lCooooo`;oogl0
00?o003oooooooooool01?ooO`15ooooo`7o00000Oooool00003o`000?oooooooooo09Sooooo00?o
003oooooooooool01_ooool;ool0o`Oooooo0_ooO`04o`00oa?ooooo0_ooO`02o`00o`;ooooo1?oo
O`15ooooo`7o00000Oooool00003o`000?oooooooooo09Sooooo00?o003oooooooooool01_ooool;
ool0ob3ooooo00Coogl0o`00ooooO`3oogl00oooool2oomo04Kooooo0Ol00001ooooo`0000?o0000
ooooooooool0M_ooool2oomo01oooooo00?o003oooooooooool01oooool;ool0ob3ooooo00?o003o
oomo0?ooO`00C?ooool1o`00007ooooo00000ol0003oooooooooo`1eooooo`Coogl07_ooool00ol0
0?ooooooooooo`08ooooo`Woo`3o8?ooool00ol00?ooooooooooo`1=ooooo`7o00000Oooool00003
o`000?oooooooooo07Gooooo1?ooO`0:ooooo`;oogl04Oooool00ol00?ooooooooooo`0:ooooo`Oo
o`3o8?ooool00ol00?ooooooooooo`1>ooooo`7o00000Oooool00003o`000?oooooooooo07Kooooo
0_ooO`0:ooooo`Coogl03oooool00ol00?ooooooooooo`0<ooooo`Goo`3o1oooool2oomo01Oooooo
00?o003oooooooooool0Coooool1o`00007ooooo00000ol0003oooooooooo`22ooooo`Coogl03ooo
ool00ol00?ooooooooooo`0Gooooo`Coogl05?ooool2o`00oe;ooooo0Ol00001ooooo`0000?o0000
ooooooooool0Poooool2oomo00oooooo00?o003oooooooooool04_ooool2oomo00Cooooo1?ooO`0A
ooooo`?o003oE?ooool1o`00007ooooo00000ol0003oooooooooo`2Dooooo`03o`00oooooooooooo
017ooooo1?ooO`04ooooo`;oogl04?ooool2o`00oeOooooo0Ol00001ooooo`0000?o0000oooooooo
ool0U?ooool00ol00?ooooooooooo`0Aooooo`Coogl05Oooool00ol00?ooooooooooo`1Gooooo`7o
00000Oooool00003o`000?oooooooooo09Cooooo00?o003oooooooooool04_ooool2oomo01Cooooo
0_l00?mJooooo`7o00000Oooool00003o`000?oooooooooo09Cooooo00?o003oooooooooool09_oo
ool2o`00oecooooo0Ol00001ooooo`0000?o0000ooooooooool0UOooool00ol00?ooooooooooo`0T
ooooo`03o`00oooooooooooo05cooooo0Ol00001ooooo`0000?o0000ooooooooool0UOooool00ol0
0?ooooooooooo`0Rooooo`;o003oGoooool1o`00007ooooo00000ol0003oooooooooo`2Eooooo`03
o`00oooooooooooo023ooooo0_l00?mQooooo`7o00000Oooool00003o`000?oooooooooo08Cooooo
0_ooO`0?ooooo`;o003o7oooool2o`00of?ooooo0Ol00001ooooo`0000?o0000ooooooooool0Pooo
ool4oomo013ooooo0_l00?lJooooo`?o003oIOooool1o`00007ooooo00000ol0003oooooooooo`23
ooooo`Coogl04_ooool2o`00oaCooooo1?l00?mXooooo`7o00000Oooool00003o`000?oooooooooo
08Cooooo0_ooO`0Eooooo`?o003o3_ooool3o`00o`?ooooo0_ooO`1Wooooo`7o00000Oooool00003
o`000?oooooooooo09kooooo0ol00?l5ooooo`Ko003o1Oooool4oomo06Kooooo0Ol00001ooooo`00
00?o0000ooooooooool0XOooool5o`00o`_ooooo1?ooO`1Vooooo`7o00000Oooool00003o`000?oo
oooooooo0;;ooooo0_ooO`1Wooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1
o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000oooooooo
ool0Noooool2oomo09kooooo0Ol00001ooooo`0000?o0000ooooooooool0N_ooool4oomo09gooooo
0Ol00001ooooo`0000?o0000ooooooooool0N_ooool4oomo023ooooo0_ooO`1kooooo`7o00000Ooo
ool00003o`000?oooooooooo07_ooooo0_ooO`0Pooooo`Coogl0N_ooool1o`00007ooooo00000ol0
003oooooooooo`2Mooooo`Coogl0N_ooool1o`00007ooooo00000ol0003oooooooooo`2@ooooo`;o
ogl03?ooool2oomo07_ooooo0Ol00001ooooo`0000?o0000ooooooooool0Soooool4oomo08Sooooo
0Ol00001ooooo`0000?o0000ooooooooool0Soooool4oomo08Sooooo0Ol00001ooooo`0000?o0000
ooooooooool0T?ooool2oomo02?ooooo0_ooO`1Tooooo`7o00000Oooool00003o`000?oooooooooo
0;Cooooo1?ooO`1Sooooo`7o00000Oooool00003o`000?oooooooooo0;Cooooo1?ooO`1Sooooo`7o
00000Oooool00003o`000?oooooooooo0;Gooooo0_ooO`1Tooooo`7o00000Oooool00003o`000?oo
oooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001
ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo0?oo
oooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o
0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1
o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000oooooooo
ool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo
00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolL
ooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003o
ooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o0000
0Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3o
oooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003
o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo
0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oooooo
oooo0?oooooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001oooo
o`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo
7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000
ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00
007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0
oooooolLooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo0000
0ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLoooo
o`7o00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003ooooo
ooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Ooo
ool00003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003oooooooooo`2>oooo
o`;oogl0Roooool1o`00007ooooo00000ol0003oooooooooo`2=ooooo`Coogl0R_ooool1o`00007o
oooo00000ol0003oooooooooo`2=ooooo`Coogl0R_ooool1o`00007ooooo00000ol0003ooooooooo
o`2>ooooo`;oogl0Roooool1o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001
ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo0?oo
oooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o
0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1
o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000oooooooo
ool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo
00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolL
ooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003o
ooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o0000
0Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3o
oooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003
o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo
0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oooooo
oooo0?oooooo7?ooool1o`00007ooooo003oo`00023o00000Oooool00001\
\>"],
  ImageRangeCache->{{{0, 287}, {287, 0}} -> {-1.01089, -1.01089, 0.00704453, \
0.00704453}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.49505 0.5 0.49505 [
[ 0 0 -0.125 0 ]
[ 0 0 -0.125 0 ]
[ 0 1 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
0 0 m
1 0 L
s
0 0 m
0 1 L
s
0 1 m
1 1 L
s
1 0 m
1 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
1 .5 0 r
.015 w
.03175 .1355 Mdot
.03435 .12523 Mdot
.11137 .12765 Mdot
.14107 .18841 Mdot
.16218 .24538 Mdot
.17294 .21053 Mdot
.18267 .18577 Mdot
.18434 .1304 Mdot
.18553 .30956 Mdot
.20401 .239 Mdot
.21247 .27571 Mdot
.21687 .20845 Mdot
.22376 .2799 Mdot
.22832 .27485 Mdot
.29063 .20974 Mdot
.29686 .25079 Mdot
.30487 .22936 Mdot
.30683 .34623 Mdot
.32055 .20902 Mdot
.32574 .21979 Mdot
.34472 .28521 Mdot
.35998 .36393 Mdot
.36335 .24976 Mdot
.3794 .36608 Mdot
.42386 .66992 Mdot
.44391 .74519 Mdot
.45059 .34198 Mdot
.47208 .67586 Mdot
.47436 .71381 Mdot
.49778 .59825 Mdot
.50874 .91643 Mdot
.51516 .76219 Mdot
.53655 .61374 Mdot
.56563 .75219 Mdot
.59189 .65665 Mdot
.59581 .61604 Mdot
.59923 .6556 Mdot
.60292 .68499 Mdot
.62656 .67779 Mdot
.63555 .72451 Mdot
.63919 .652 Mdot
.64169 .6004 Mdot
.64246 .58611 Mdot
.64496 .54267 Mdot
.64608 .77288 Mdot
.65077 .64308 Mdot
.66065 .57816 Mdot
.67474 .59169 Mdot
.69296 .563 Mdot
.72815 .65902 Mdot
.73169 .58879 Mdot
.74669 .61318 Mdot
.74821 .65474 Mdot
.75963 .63781 Mdot
.79673 .57809 Mdot
.80925 .55852 Mdot
.81525 .58444 Mdot
.83417 .62985 Mdot
.83598 .55526 Mdot
.91595 .49319 Mdot
1 0 0 r
.005 w
.16128 .17044 m
.18734 .17269 L
.21339 .17909 L
.2345 .18734 L
.23945 .19126 L
.2655 .20415 L
.27874 .21339 L
.29156 .22295 L
.31204 .23945 L
.31761 .24532 L
.33549 .2655 L
.34367 .28341 L
.34499 .29156 L
.34367 .29798 L
.31761 .3104 L
.29156 .30711 L
.2655 .30014 L
.24507 .29156 L
.23945 .28747 L
.21339 .27402 L
.20155 .2655 L
.18734 .25472 L
.16884 .23945 L
.16128 .2313 L
.14618 .21339 L
.13806 .18734 L
.16128 .17044 L
s
0 0 1 r
.65633 .57701 m
.68239 .56842 L
.70844 .56313 L
.7345 .56168 L
.76055 .5752 L
.76359 .57817 L
.76859 .60422 L
.76055 .62333 L
.75627 .63028 L
.7345 .65485 L
.73298 .65633 L
.70844 .6775 L
.69922 .68239 L
.68239 .69294 L
.65633 .70579 L
.64983 .70844 L
.63028 .71539 L
.60422 .72268 L
.57817 .72651 L
.55211 .7214 L
.53145 .70844 L
.52926 .68239 L
.54239 .65633 L
.55211 .63983 L
.56625 .63028 L
.57817 .6193 L
.60119 .60422 L
.60422 .60227 L
.63028 .58726 L
.65315 .57817 L
.65633 .57701 L
s
1 0 0 r
.03 w
.24141 .24033 Mdot
0 0 1 r
.64872 .64417 Mdot
1 0 0 r
.79703 .00495 m
.79703 .00495 L
.87129 .00495 L
.87129 .00495 L
F
0 0 1 r
.89604 .00495 m
.89604 .25248 L
.9703 .25248 L
.9703 .00495 L
F
1 0 1 r
.04 w
.59581 .61604 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P000182000`400?l00000o`00003ooooooolQ
ooooo`00ool0000Po`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`00
00?o0000ooooooooool0o_oooolEo`00o`Sooooo0Ol00001ooooo`0000?o0000ooooooooool0o_oo
oolEo`00o`Sooooo0Ol00001ooooo`0000?o0000ooooooooool0o_oooolEo`00o`Sooooo0Ol00001
ooooo`0000?o0000ooooooooool0o_oooolEo`00o`Sooooo0Ol00001ooooo`0000?o0000oooooooo
ool0o_oooolEo`00o`Sooooo0Ol00001ooooo`0000?o0000ooooooooool0o_oooolEo`00o`Sooooo
0Ol00001ooooo`0000?o0000ooooooooool0o_oooolEo`00o`Sooooo0Ol00001ooooo`0000?o0000
ooooooooool0o_oooolEo`00o`Sooooo0Ol00001ooooo`0000?o0000ooooooooool0o_oooolEo`00
o`Sooooo0Ol00001ooooo`0000?o0000ooooooooool0o_oooolEo`00o`Sooooo0Ol00001ooooo`00
00?o0000ooooooooool0o_oooolEo`00o`Sooooo0Ol00001ooooo`0000?o0000ooooooooool0o_oo
oolEo`00o`Sooooo0Ol00001ooooo`0000?o0000ooooooooool0o_oooolEo`00o`Sooooo0Ol00001
ooooo`0000?o0000ooooooooool0o_oooolEo`00o`Sooooo0Ol00001ooooo`0000?o0000oooooooo
ool0o_oooolEo`00o`Sooooo0Ol00001ooooo`0000?o0000ooooooooool0o_oooolEo`00o`Sooooo
0Ol00001ooooo`0000?o0000ooooooooool0o_oooolEo`00o`Sooooo0Ol00001ooooo`0000?o0000
ooooooooool0o_oooolEo`00o`Sooooo0Ol00001ooooo`0000?o0000ooooooooool0o_oooolEo`00
o`Sooooo0Ol00001ooooo`0000?o0000ooooooooool0o_oooolEo`00o`Sooooo0Ol00001ooooo`00
00?o0000ooooooooool0o_oooolEo`00o`Sooooo0Ol00001ooooo`0000?o0000ooooooooool0o_oo
oolEo`00o`Sooooo0Ol00001ooooo`0000?o0000ooooooooool0o_oooolEo`00o`Sooooo0Ol00001
ooooo`0000?o0000ooooooooool0o_oooolEo`00o`Sooooo0Ol00001ooooo`0000?o0000oooooooo
ool0o_oooolEo`00o`Sooooo0Ol00001ooooo`0000?o0000ooooooooool0o_oooolEo`00o`Sooooo
0Ol00001ooooo`0000?o0000ooooooooool0o_oooolEo`00o`Sooooo0Ol00001ooooo`0000?o0000
ooooooooool0o_oooolEo`00o`Sooooo0Ol00001ooooo`0000?o0000ooooooooool0o_oooolEo`00
o`Sooooo0Ol00001ooooo`0000?o0000ooooooooool0o_oooolEo`00o`Sooooo0Ol00001ooooo`00
00?o0000ooooooooool0o_oooolEo`00o`Sooooo0Ol00001ooooo`0000?o0000ooooooooool0o_oo
oolEo`00o`Sooooo0Ol00001ooooo`0000?o0000ooooooooool01_ooool2oomo0?Kooooo5Ol00?l8
ooooo`7o00000Oooool00003o`000?oooooooooo00Gooooo1?ooO`0Cooooo`;oogl0h?oooolEo`00
o`Sooooo0Ol00001ooooo`0000?o0000ooooooooool01Oooool4oomo01;ooooo1?ooO`0Booooo`;o
ogl0booooolEo`00o`Sooooo0Ol00001ooooo`0000?o0000ooooooooool01Oooool3oomo01?ooooo
1?ooO`0Aooooo`Coogl0b_oooolEo`00o`Sooooo0Ol00001ooooo`0000?o0000ooooooooool01?oo
ool4oomo01Cooooo0_ooO`0Booooo`Coogl0b_oooolEo`00o`Sooooo0Ol00001ooooo`0000?o0000
ooooooooool01?ooool4oomo02Wooooo0_ooO`3;oooooaGo003o2?ooool1o`00007ooooo00000ol0
003oooooooooo`05ooooo`;oogl0mooooolEo`00o`Sooooo0Ol00001ooooo`0000?o0000oooooooo
ool0o_oooolEo`00o`Sooooo0Ol00001ooooo`0000?o0000ooooooooool0o_oooolEo`00o`Sooooo
0Ol00001ooooo`0000?o0000ooooooooool0o_oooolEo`00o`Sooooo0Ol00001ooooo`0000?o0000
ooooooooool0o_oooolEo`00o`Sooooo0Ol00001ooooo`0000?o0000ooooooooool0o_oooolEo`00
o`Sooooo0Ol00001ooooo`0000?o0000ooooooooool0o_oooolEo`00o`Sooooo0Ol00001ooooo`00
00?o0000ooooooooool0o_oooolEo`00o`Sooooo0Ol00001ooooo`0000?o0000ooooooooool0:_oo
ool6ool00<kooooo5Ol00?l8ooooo`7o00000Oooool00003o`000?oooooooooo02Wooooo00?oo`00
ooooooooool01?ooool5ool00<Wooooo5Ol00?l8ooooo`7o00000Oooool00003o`000?oooooooooo
02Oooooo0_oo000<ooooo`Coo`00aOoooolEo`00o`Sooooo0Ol00001ooooo`0000?o0000oooooooo
ool09_ooool00ooo003oooooooooo`0@ooooo`Coo`00`OoooolEo`00o`Sooooo0Ol00001ooooo`00
00?o0000ooooooooool09?ooool00oooO`3oo`00ooooo`09ooooo`;oogl02oooool3ool00;kooooo
5Ol00?l8ooooo`7o00000Oooool00003o`000?oooooooooo02?ooooo00Coogl0ool00?ooO`3oogl0
2?ooool4oomo00gooooo00?oo`00ooooooooool0^ooooolEo`00o`Sooooo0Ol00001ooooo`0000?o
0000ooooooooool08oooool01?ooO`3oo`00oomo0?ooO`08ooooo`Coogl03_ooool2ool00;_ooooo
5Ol00?l8ooooo`7o00000Oooool00003o`000?oooooooooo02Cooooo00?oogl0ool00?ooool02Ooo
ool2oomo017ooooo0_oo002ioooooaGo003o2?ooool1o`00007ooooo00000ol0003oooooooooo`0U
ooooo`03ool00?oooooooooo01gooooo0_oo002goooooaGo003o2?ooool1o`00007ooooo00000ol0
003oooooooooo`0Uooooo`03ool00?oooooooooo01oooooo0_oo002eoooooaGo003o2?ooool1o`00
007ooooo00000ol0003oooooooooo`0Vooooo`03ool00?oooooooooo017ooooo0_ooO`0=ooooo`;o
o`001?ooool2oomo00Oooooo0_ooO`2ToooooaGo003o2?ooool1o`00007ooooo00000ol0003ooooo
ooooo`0Vooooo`03ool00?oooooooooo00Gooooo0_ooO`09ooooo`Coogl03_ooool00ooo003ooooo
ooooo`04oomo00Gooooo1?ooO`2SoooooaGo003o2?ooool1o`00007ooooo00000ol0003ooooooooo
o`0Vooooo`03ool00?oooooooooo00Cooooo1?ooO`08ooooo`Coogl03oooool00ooo003ooooooomo
0003oomo00Gooooo1?ooO`2SoooooaGo003o2?ooool1o`00007ooooo00000ol0003oooooooooo`0W
ooooo`03ool00?oooooooooo00?ooooo1?ooO`09ooooo`;oogl04Oooool01?oo003ooooooomo0?oo
O`07ooooo`?oogl0XooooolEo`00o`Sooooo0Ol00001ooooo`0000?o0000ooooooooool09oooool0
0ooo003oooooooooo`04ooooo`;oogl07_ooool00ooo003oooooooooo`07ooooo`Coogl0X_oooolE
o`00o`Sooooo0Ol00001ooooo`0000?o0000ooooooooool0:?ooool00ooo003oooooooooo`0Toooo
o`03ool00?oooooooooo00Kooooo1?ooO`2RoooooaGo003o2?ooool1o`00007ooooo00000ol0003o
ooooooooo`0Yooooo`03ool00?oooooooooo02Cooooo0_oo00000oooooooogl0oomo0004ooooo`;o
ogl0XooooolEo`00o`Sooooo0Ol00001ooooo`0000?o0000ooooooooool0:_ooool00ooo003ooooo
ooooo`0Cooooo`Coo`003_ooool01?oo003oogl0oomo0?ooO`2XoooooaGo003o2?ooool1o`00007o
oooo00000ol0003oooooooooo`0[ooooo`03ool00?oooooooooo017ooooo1_oo000=ooooo`04oomo
0?oo003oo`00oomo0:Sooooo5Ol00?l8ooooo`7o00000Oooool00003o`000?oooooooooo02cooooo
00?oo`00ooooooooool02?ooool2oomo00Gooooo2?oo000=ooooo`;oogl000?oo`00ooooooooool0
Y_oooolEo`00o`Sooooo0Ol00001ooooo`0000?o0000ooooooooool0;Oooool00ooo003ooooooooo
o`06ooooo`Coogl01?ooool8ool0013ooooo00?oo`00ooooooooool0YOoooolEo`00o`Sooooo0Ol0
0001ooooo`0000?o0000ooooooooool0:oooool2oomo0003oooooooo003ooooo00Kooooo1?ooO`04
ooooo`Soo`004Oooool00ooo003oooooooooo`2ToooooaGo003o2?ooool1o`00007ooooo00000ol0
003oooooooooo`0Zooooo`Coogl000?oooooool00?ooool01_ooool2oomo00Gooooo2?oo000;oooo
o`;oogl01Oooool00ooo003oooooooooo`09ooooo`;oogl0V?oooolEo`00o`Sooooo0Ol00001oooo
o`0000?o0000ooooooooool0:_ooool4oomo00;ooooo00?oo`00ooooooooool03?ooool6ool000_o
oooo1?ooO`04ooooo`03ool00?oooooooooo00Sooooo1?ooO`2GoooooaGo003o2?ooool1o`00007o
oooo00000ol0003oooooooooo`0[ooooo`;oogl01?ooool00ooo003oooooooooo`0<ooooo`Coo`00
3?ooool4oomo00Gooooo00?oo`00ooooooooool01oooool4oomo09Oooooo5Ol00?l8ooooo`7o0000
0Oooool00003o`000?oooooooooo03;ooooo0_oo000Mooooo`;oogl01oooool00ooo003ooooooooo
o`07ooooo`;oogl0]Oooool1o`00007ooooo00000ol0003oooooooooo`0dooooo`03ool00?oooooo
oooo02Cooooo00?oo`00ooooooooool0_Oooool1o`00007ooooo00000ol0003oooooooooo`0eoooo
o`03ool00?oooooooooo02Cooooo00?oo`00ooooooooool0_?ooool1o`00007ooooo00000ol0003o
ooooooooo`0fooooo`;oo`009Oooool00ooo003oooooooooo`2kooooo`7o00000Oooool00003o`00
0?oooooooooo03Sooooo0_oo00000oooO`3oooooooooo`02oomo01kooooo00?oo`00ooooooooool0
^oooool1o`00007ooooo00000ol0003oooooooooo`0hooooo`;oogl00_oo0004oomo01kooooo00?o
o`00ooooooooool0^_ooool1o`00007ooooo00000ol0003oooooooooo`0hooooo`Coogl00_oo0002
oomo01kooooo00?oo`00ooooooooool0^_ooool1o`00007ooooo00000ol0003oooooooooo`0ioooo
o`Googl000?oo`00ooooooooool07Oooool00ooo003oogl0oomo002jooooo`7o00000Oooool00003
o`000?oooooooooo03_ooooo1?ooO`02ool001gooooo00Coogl0ool00?ooO`3oogl0^Oooool1o`00
007ooooo00000ol0003oooooooooo`0looooo`;oogl00oooool2ool001_ooooo00Coogl0ool00?oo
O`3oogl0^Oooool1o`00007ooooo00000ol0003oooooooooo`13ooooo`;oo`006_ooool00oooO`3o
o`00ooooo`2iooooo`7o00000Oooool00003o`000?oooooooooo04Gooooo0_oo000Iooooo`03ool0
0?oooooooooo0;Sooooo0Ol00001ooooo`0000?o0000ooooooooool0Aoooool2ool001Gooooo0_oo
002kooooo`7o00000Oooool00003o`000?oooooooooo04Wooooo0ooo000@ooooo`;oo`00_Oooool1
o`00007ooooo00000ol0003oooooooooo`0aooooo`;oogl06Oooool3ool000cooooo00?oo`00oooo
ooooool0_Oooool1o`00007ooooo00000ol0003oooooooooo`0`ooooo`Coogl06oooool6ool000Co
oooo0_oo0030ooooo`7o00000Oooool00003o`000?oooooooooo033ooooo1?ooO`0Qooooo`Coo`00
`_ooool1o`00007ooooo00000ol0003oooooooooo`0aooooo`;oogl0j?ooool1o`00007ooooo0000
0ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLoooo
o`7o00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003ooooo
ooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Ooo
ool00003o`000?oooooooooo07gooooo0_ooO`2Looooo`7o00000Oooool00003o`000?oooooooooo
07cooooo1?ooO`2Kooooo`7o00000Oooool00003o`000?oooooooooo05Cooooo0_ooO`0Vooooo`Co
ogl0Voooool1o`00007ooooo00000ol0003oooooooooo`1Cooooo`Coogl09_ooool2oomo09cooooo
0Ol00001ooooo`0000?o0000ooooooooool0Doooool4oomo0<Cooooo0Ol00001ooooo`0000?o0000
ooooooooool0E?ooool2oomo0<Gooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLoooo
o`7o00000Oooool00003o`000?oooooooooo06?ooooo0_ooO`04ooooo`;oogl0/?ooool1o`00007o
oooo00000ol0003oooooooooo`1Rooooo`Coogl00_ooool4oomo0:oooooo0Ol00001ooooo`0000?o
0000ooooooooool0H_ooool4oomo00;ooooo1?ooO`2_ooooo`7o00000Oooool00003o`000?oooooo
oooo06?ooooo0_ooO`04ooooo`;oogl0/?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooo
oacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`00
0?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol0
0001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo
0?oooooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`00
00?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?oo
ool1o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000oooo
ooooool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007o
oooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooo
oolLooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0
003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o
00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003ooooooooo
o`3ooooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool0
0003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooooaco
oooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oo
oooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001
ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo0?oo
oooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o
0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1
o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000oooooooo
ool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo
00000ol0003oooooooooo`3oooooo`Cooooo0_ooO`0Fooooo`7o00000Oooool00003o`000?oooooo
oooo0?oooooo0oooool4oomo01Gooooo0Ol00001ooooo`0000?o0000ooooooooool0ooooool3oooo
o`Coogl05Oooool1o`00007ooooo00000ol0003oooooooooo`3oooooo`Cooooo0_ooO`0Fooooo`7o
00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003ooooooooo
o`3ooooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool0
0003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooooaco
oooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oo
oooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001
ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo0?oo
oooo7?ooool1o`00007ooooo00000ol0003oooooooooo`2eooooo`;oogl0I?ooool1o`00007ooooo
00000ol0003oooooooooo`2dooooo`Coogl0Hoooool1o`00007ooooo00000ol0003oooooooooo`2d
ooooo`Coogl0Hoooool1o`00007ooooo00000ol0003oooooooooo`2eooooo`;oogl0=Oooool2oomo
02gooooo0Ol00001ooooo`0000?o0000ooooooooool0i?ooool2oomo00Gooooo1?ooO`0/ooooo`7o
00000Oooool00003o`000?oooooooooo0>?ooooo1?ooO`04ooooo`Coogl0;?ooool1o`00007ooooo
00000ol0003oooooooooo`33ooooo`;oogl07_ooool4oomo00Gooooo0_ooO`0]ooooo`7o00000Ooo
ool00003o`000?oooooooooo0<;ooooo1?ooO`0;o`00oa?ooooo0_ooO`0eooooo`7o00000Oooool0
0003o`000?oooooooooo0<;ooooo1?l00?l;ooooo`;o003oB?ooool1o`00007ooooo00000ol0003o
ooooooooo`2nooooo`Co003o00?ooooooomo0?ooO`003_ooool2o`00odKooooo0Ol00001ooooo`00
00?o0000ooooooooool0^Oooool2oomo00?o003o5oooool2o`00o`Wooooo0_ooO`0iooooo`7o0000
0Oooool00003o`000?oooooooooo0;Oooooo1?l00?l00oooO`3oooooooooo`0Iooooo`;o003o1_oo
ool4oomo03Sooooo0Ol00001ooooo`0000?o0000ooooooooool0]?ooool3o`00o`03ooooooooO`3o
ogl000;oogl07?ooool00ol00?ooooooooooo`04ooooo`Coogl00oooool2oomo03?ooooo0Ol00001
ooooo`0000?o0000ooooooooool0/_ooool2o`00o`?oogl00_ooool2oomo01?ooooo0_ooO`08oooo
o`03o`00oooooooooooo00Gooooo0_ooO`03ooooo`Coogl0<_ooool1o`00007ooooo00000ol0003o
ooooooooo`2`ooooo`;o003o00?ooooooomo0?ooO`000_ooO`06ooooo`;oogl03_ooool4oomo00Oo
oooo00?o003oooooooooool02_ooool4oomo03;ooooo0Ol00001ooooo`0000?o0000ooooooooool0
[_ooool2o`00o`Cooooo0_ooO`06ooooo`Coogl03Oooool4oomo00Oooooo00?o003oooooooooool0
2oooool2oomo03?ooooo0Ol00001ooooo`0000?o0000ooooooooool0Roooool2oomo023ooooo00?o
003oooooooooool01?ooool2oomo00Kooooo1?ooO`0>ooooo`;oogl02Oooool00ol00?oooooooooo
o`0oooooo`7o00000Oooool00003o`000?oooooooooo08[ooooo1?ooO`0Gooooo`Goo`3o00?ooooo
o`00ool00?l01_ooool4oomo00Kooooo0_ooO`0Jooooo`03o`00oooooooooooo03oooooo0Ol00001
ooooo`0000?o0000ooooooooool0R_ooool4oomo01Kooooo1ooo0?l8ooooo`Coogl08_ooool00ol0
0?ooooooooooo`0oooooo`7o00000Oooool00003o`000?oooooooooo08_ooooo0_ooO`0Fooooo`Wo
o`3o2?ooool2oomo02?ooooo00?o003oooooooooool0?oooool1o`00007ooooo00000ol0003ooooo
ooooo`2Fooooo`;oogl02_ooool;ool0obGooooo0_ooO`05ooooo`03o`00oooooooooooo03oooooo
0Ol00001ooooo`0000?o0000ooooooooool0UOooool4oomo00Wooooo2ooo0?lTooooo`Coogl00ooo
ool00ol00?ooooooooooo`10ooooo`7o00000Oooool00003o`000?oooooooooo09Gooooo1?ooO`09
ooooo`_oo`3o9?ooool4oomo00?ooooo00?o003oooooooooool0@?ooool1o`00007ooooo00000ol0
003oooooooooo`2Fooooo`;oogl02_ooool;ool0obGooooo0_ooO`04ooooo`03o`00oooooooooooo
043ooooo0Ol00001ooooo`0000?o0000ooooooooool0XOooool00ol00?ooo`3oool0o`09ool0ob[o
oooo00?o003oooooooooool0@Oooool1o`00007ooooo00000ol0003oooooooooo`2Pooooo`03o`00
oooooooooooo00Woo`3o:_ooool00ol00?ooooooooooo`0Booooo`;oogl0;_ooool1o`00007ooooo
00000ol0003oooooooooo`2Nooooo`;o003o1?ooool7ool0ob[ooooo00?o003oooooooooool04_oo
ool4oomo02gooooo0Ol00001ooooo`0000?o0000ooooooooool0WOooool00ol00?ooooooooooo`05
ooooo`Goo`3o2oooool4o`00oacooooo00?o003ooomo0?ooO`004_ooool4oomo02gooooo0Ol00001
ooooo`0000?o0000ooooooooool0W?ooool00ol00?ooooooooooo`0Eooooo`Ko003o6_ooool00ol0
0?ooogl0oomo0002oomo01;ooooo0_ooO`0^ooooo`7o00000Oooool00003o`000?oooooooooo09_o
oooo00?o003oooooooooool05Oooool8o`00oaSooooo00?o003oooooooooO`000oooO`12ooooo`7o
00000Oooool00003o`000?oooooooooo09_ooooo00?o003oooooooooool05Oooool8o`00oaOooooo
00Co003ooooooooooooooooo0_ooO`13ooooo`7o00000Oooool00003o`000?oooooooooo09[ooooo
00?o003oooooooooool05_ooool8o`00oaKooooo00?o003oooooooooool0Aoooool1o`00007ooooo
00000ol0003oooooooooo`2Iooooo`03o`00oooooooooooo00cooooo0_ooO`08ooooo`03oomo0?l0
0?oo003o00Ko003o5Oooool00ol00?ooooooooooo`02oomo04Kooooo0Ol00001ooooo`0000?o0000
ooooooooool0VOooool00ol00?ooooooooooo`0:ooooo`Googl01oooool2oomo00Ko003o4oooool2
oomo0003o`00oooooooooooo00Coogl0AOooool1o`00007ooooo00000ol0003oooooooooo`2Hoooo
o`03o`00oooooooooooo00[ooooo1_ooO`08ooooo`;oogl01?l00?lCooooo`;oogl00_l00?l2oooo
o`Coogl0AOooool1o`00007ooooo00000ol0003oooooooooo`2Hooooo`03o`00oooooooooooo00[o
oooo1OooO`0Rooooo`04oomo0?l00?ooogl0oomo00?ooooo0_ooO`16ooooo`7o00000Oooool00003
o`000?oooooooooo07Kooooo0_ooO`0Oooooo`03o`00oooooooooooo00cooooo0_ooO`0Tooooo`03
o`00ooooO`3oogl004cooooo0Ol00001ooooo`0000?o0000ooooooooool0MOooool4oomo01kooooo
00?o003oooooooooool0<Oooool00ol00?ooooooooooo`1=ooooo`7o00000Oooool00003o`000?oo
oooooooo07Gooooo1?ooO`0:ooooo`;oogl04Oooool00ol00?ooooooooooo`0aooooo`03o`00oooo
oooooooo04kooooo0Ol00001ooooo`0000?o0000ooooooooool0M_ooool2oomo00[ooooo1?ooO`0?
ooooo`03o`00oooooooooooo01Sooooo0_ooO`0Gooooo`03o`00oooooooooooo04oooooo0Ol00001
ooooo`0000?o0000ooooooooool0P_ooool4oomo00oooooo00?o003oooooooooool05oooool4oomo
01Cooooo0_l00?mBooooo`7o00000Oooool00003o`000?oooooooooo08?ooooo0_ooO`0?ooooo`03
o`00oooooooooooo01;ooooo0_ooO`04ooooo`Coogl04Oooool3o`00oeCooooo0Ol00001ooooo`00
00?o0000ooooooooool0U?ooool00ol00?ooooooooooo`0Aooooo`Coogl01?ooool2oomo013ooooo
0_l00?mGooooo`7o00000Oooool00003o`000?oooooooooo09Cooooo00?o003oooooooooool04Ooo
ool4oomo01Gooooo00?o003oooooooooool0Eoooool1o`00007ooooo00000ol0003oooooooooo`2D
ooooo`03o`00oooooooooooo01;ooooo0_ooO`0Dooooo`;o003oF_ooool1o`00007ooooo00000ol0
003oooooooooo`2Dooooo`03o`00oooooooooooo02Kooooo0_l00?mLooooo`7o00000Oooool00003
o`000?oooooooooo09Gooooo00?o003oooooooooool09?ooool00ol00?ooooooooooo`1Looooo`7o
00000Oooool00003o`000?oooooooooo09Gooooo00?o003oooooooooool08_ooool2o`00oeoooooo
0Ol00001ooooo`0000?o0000ooooooooool0UOooool00ol00?ooooooooooo`0Pooooo`;o003oHOoo
ool1o`00007ooooo00000ol0003oooooooooo`24ooooo`;oogl03oooool2o`00oaoooooo0_l00?mS
ooooo`7o00000Oooool00003o`000?oooooooooo08?ooooo1?ooO`0@ooooo`;o003o6_ooool3o`00
ofGooooo0Ol00001ooooo`0000?o0000ooooooooool0Poooool4oomo01;ooooo0_l00?lDooooo`Co
003oJ?ooool1o`00007ooooo00000ol0003oooooooooo`24ooooo`;oogl05Oooool3o`00o`kooooo
0ol00?l3ooooo`;oogl0Ioooool1o`00007ooooo00000ol0003oooooooooo`2Nooooo`?o003o1Ooo
ool6o`00o`Gooooo1?ooO`1Vooooo`7o00000Oooool00003o`000?oooooooooo0:7ooooo1Ol00?l;
ooooo`Coogl0I_ooool1o`00007ooooo00000ol0003oooooooooo`2booooo`;oogl0Ioooool1o`00
007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0
oooooolLooooo`7o00000Oooool00003o`000?oooooooooo07_ooooo0_ooO`2Nooooo`7o00000Ooo
ool00003o`000?oooooooooo07[ooooo1?ooO`2Mooooo`7o00000Oooool00003o`000?oooooooooo
07[ooooo1?ooO`0Pooooo`;oogl0Noooool1o`00007ooooo00000ol0003oooooooooo`1kooooo`;o
ogl08?ooool4oomo07[ooooo0Ol00001ooooo`0000?o0000ooooooooool0WOooool4oomo07[ooooo
0Ol00001ooooo`0000?o0000ooooooooool0T?ooool2oomo00cooooo0_ooO`1kooooo`7o00000Ooo
ool00003o`000?oooooooooo08oooooo1?ooO`28ooooo`7o00000Oooool00003o`000?oooooooooo
08oooooo1?ooO`28ooooo`7o00000Oooool00003o`000?oooooooooo093ooooo0_ooO`0Sooooo`;o
ogl0I?ooool1o`00007ooooo00000ol0003oooooooooo`2dooooo`Coogl0Hoooool1o`00007ooooo
00000ol0003oooooooooo`2dooooo`Coogl0Hoooool1o`00007ooooo00000ol0003oooooooooo`2e
ooooo`;oogl0I?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001oooo
o`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo
7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000
ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00
007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0
oooooolLooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo0000
0ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLoooo
o`7o00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003ooooo
ooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Ooo
ool00003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooo
oacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`00
0?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol0
0001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo
0?oooooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`00
00?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?oo
ool1o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000oooo
ooooool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007o
oooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooo
oolLooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0
003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o
00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003ooooooooo
o`3ooooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool0
0003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooooaco
oooo0Ol00001ooooo`0000?o0000ooooooooool0S_ooool2oomo08_ooooo0Ol00001ooooo`0000?o
0000ooooooooool0SOooool4oomo08[ooooo0Ol00001ooooo`0000?o0000ooooooooool0SOooool4
oomo08[ooooo0Ol00001ooooo`0000?o0000ooooooooool0S_ooool2oomo08_ooooo0Ol00001oooo
o`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo
7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000
ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00
007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0
oooooolLooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo0000
0ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLoooo
o`7o00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003ooooo
ooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Ooo
ool00003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooo
oacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`00
0?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol0
0001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo
0?oooooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`00
ool0000Po`00007ooooo0000\
\>"],
  ImageRangeCache->{{{0, 287}, {287, 0}} -> {-1.01089, -1.01089, 0.00704453, \
0.00704453}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.49505 0.5 0.49505 [
[ 0 0 -0.125 0 ]
[ 0 0 -0.125 0 ]
[ 0 1 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
0 0 m
1 0 L
s
0 0 m
0 1 L
s
0 1 m
1 1 L
s
1 0 m
1 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
1 .5 0 r
.015 w
.03175 .1355 Mdot
.03435 .12523 Mdot
.11137 .12765 Mdot
.14107 .18841 Mdot
.16218 .24538 Mdot
.17294 .21053 Mdot
.18267 .18577 Mdot
.18434 .1304 Mdot
.18553 .30956 Mdot
.20401 .239 Mdot
.21247 .27571 Mdot
.21687 .20845 Mdot
.22376 .2799 Mdot
.22832 .27485 Mdot
.29063 .20974 Mdot
.29686 .25079 Mdot
.30487 .22936 Mdot
.30683 .34623 Mdot
.32055 .20902 Mdot
.32574 .21979 Mdot
.34472 .28521 Mdot
.35998 .36393 Mdot
.36335 .24976 Mdot
.3794 .36608 Mdot
.42386 .66992 Mdot
.44391 .74519 Mdot
.45059 .34198 Mdot
.47208 .67586 Mdot
.47436 .71381 Mdot
.49778 .59825 Mdot
.50874 .91643 Mdot
.51516 .76219 Mdot
.53655 .61374 Mdot
.56563 .75219 Mdot
.59189 .65665 Mdot
.59581 .61604 Mdot
.59923 .6556 Mdot
.60292 .68499 Mdot
.62656 .67779 Mdot
.63555 .72451 Mdot
.63919 .652 Mdot
.64169 .6004 Mdot
.64246 .58611 Mdot
.64496 .54267 Mdot
.64608 .77288 Mdot
.65077 .64308 Mdot
.66065 .57816 Mdot
.67474 .59169 Mdot
.69296 .563 Mdot
.72815 .65902 Mdot
.73169 .58879 Mdot
.74669 .61318 Mdot
.74821 .65474 Mdot
.75963 .63781 Mdot
.79673 .57809 Mdot
.80925 .55852 Mdot
.81525 .58444 Mdot
.83417 .62985 Mdot
.83598 .55526 Mdot
.91595 .49319 Mdot
1 0 0 r
.005 w
.16128 .17044 m
.18734 .17269 L
.21339 .17909 L
.2345 .18734 L
.23945 .19126 L
.2655 .20415 L
.27874 .21339 L
.29156 .22295 L
.31204 .23945 L
.31761 .24532 L
.33549 .2655 L
.34367 .28341 L
.34499 .29156 L
.34367 .29798 L
.31761 .3104 L
.29156 .30711 L
.2655 .30014 L
.24507 .29156 L
.23945 .28747 L
.21339 .27402 L
.20155 .2655 L
.18734 .25472 L
.16884 .23945 L
.16128 .2313 L
.14618 .21339 L
.13806 .18734 L
.16128 .17044 L
s
0 0 1 r
.65633 .57701 m
.68239 .56842 L
.70844 .56313 L
.7345 .56168 L
.76055 .5752 L
.76359 .57817 L
.76859 .60422 L
.76055 .62333 L
.75627 .63028 L
.7345 .65485 L
.73298 .65633 L
.70844 .6775 L
.69922 .68239 L
.68239 .69294 L
.65633 .70579 L
.64983 .70844 L
.63028 .71539 L
.60422 .72268 L
.57817 .72651 L
.55211 .7214 L
.53145 .70844 L
.52926 .68239 L
.54239 .65633 L
.55211 .63983 L
.56625 .63028 L
.57817 .6193 L
.60119 .60422 L
.60422 .60227 L
.63028 .58726 L
.65315 .57817 L
.65633 .57701 L
s
1 0 0 r
.03 w
.24141 .24033 Mdot
0 0 1 r
.64872 .64417 Mdot
1 0 0 r
.79703 .00495 m
.79703 .00495 L
.87129 .00495 L
.87129 .00495 L
F
0 0 1 r
.89604 .00495 m
.89604 .25248 L
.9703 .25248 L
.9703 .00495 L
F
1 0 1 r
.04 w
.59923 .6556 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P000182000`400?l00000o`00003ooooooolQ
ooooo`00ool0000Po`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`00
00?o0000ooooooooool0o_oooolEo`00o`Sooooo0Ol00001ooooo`0000?o0000ooooooooool0o_oo
oolEo`00o`Sooooo0Ol00001ooooo`0000?o0000ooooooooool0o_oooolEo`00o`Sooooo0Ol00001
ooooo`0000?o0000ooooooooool0o_oooolEo`00o`Sooooo0Ol00001ooooo`0000?o0000oooooooo
ool0o_oooolEo`00o`Sooooo0Ol00001ooooo`0000?o0000ooooooooool0o_oooolEo`00o`Sooooo
0Ol00001ooooo`0000?o0000ooooooooool0o_oooolEo`00o`Sooooo0Ol00001ooooo`0000?o0000
ooooooooool0o_oooolEo`00o`Sooooo0Ol00001ooooo`0000?o0000ooooooooool0o_oooolEo`00
o`Sooooo0Ol00001ooooo`0000?o0000ooooooooool0o_oooolEo`00o`Sooooo0Ol00001ooooo`00
00?o0000ooooooooool0o_oooolEo`00o`Sooooo0Ol00001ooooo`0000?o0000ooooooooool0o_oo
oolEo`00o`Sooooo0Ol00001ooooo`0000?o0000ooooooooool0o_oooolEo`00o`Sooooo0Ol00001
ooooo`0000?o0000ooooooooool0o_oooolEo`00o`Sooooo0Ol00001ooooo`0000?o0000oooooooo
ool0o_oooolEo`00o`Sooooo0Ol00001ooooo`0000?o0000ooooooooool0o_oooolEo`00o`Sooooo
0Ol00001ooooo`0000?o0000ooooooooool0o_oooolEo`00o`Sooooo0Ol00001ooooo`0000?o0000
ooooooooool0o_oooolEo`00o`Sooooo0Ol00001ooooo`0000?o0000ooooooooool0o_oooolEo`00
o`Sooooo0Ol00001ooooo`0000?o0000ooooooooool0o_oooolEo`00o`Sooooo0Ol00001ooooo`00
00?o0000ooooooooool0o_oooolEo`00o`Sooooo0Ol00001ooooo`0000?o0000ooooooooool0o_oo
oolEo`00o`Sooooo0Ol00001ooooo`0000?o0000ooooooooool0o_oooolEo`00o`Sooooo0Ol00001
ooooo`0000?o0000ooooooooool0o_oooolEo`00o`Sooooo0Ol00001ooooo`0000?o0000oooooooo
ool0o_oooolEo`00o`Sooooo0Ol00001ooooo`0000?o0000ooooooooool0o_oooolEo`00o`Sooooo
0Ol00001ooooo`0000?o0000ooooooooool0o_oooolEo`00o`Sooooo0Ol00001ooooo`0000?o0000
ooooooooool0o_oooolEo`00o`Sooooo0Ol00001ooooo`0000?o0000ooooooooool0o_oooolEo`00
o`Sooooo0Ol00001ooooo`0000?o0000ooooooooool0o_oooolEo`00o`Sooooo0Ol00001ooooo`00
00?o0000ooooooooool0o_oooolEo`00o`Sooooo0Ol00001ooooo`0000?o0000ooooooooool0o_oo
oolEo`00o`Sooooo0Ol00001ooooo`0000?o0000ooooooooool01_ooool2oomo0?Kooooo5Ol00?l8
ooooo`7o00000Oooool00003o`000?oooooooooo00Gooooo1?ooO`0Cooooo`;oogl0h?oooolEo`00
o`Sooooo0Ol00001ooooo`0000?o0000ooooooooool01Oooool4oomo01;ooooo1?ooO`0Booooo`;o
ogl0booooolEo`00o`Sooooo0Ol00001ooooo`0000?o0000ooooooooool01Oooool3oomo01?ooooo
1?ooO`0Aooooo`Coogl0b_oooolEo`00o`Sooooo0Ol00001ooooo`0000?o0000ooooooooool01?oo
ool4oomo01Cooooo0_ooO`0Booooo`Coogl0b_oooolEo`00o`Sooooo0Ol00001ooooo`0000?o0000
ooooooooool01?ooool4oomo02Wooooo0_ooO`3;oooooaGo003o2?ooool1o`00007ooooo00000ol0
003oooooooooo`05ooooo`;oogl0mooooolEo`00o`Sooooo0Ol00001ooooo`0000?o0000oooooooo
ool0o_oooolEo`00o`Sooooo0Ol00001ooooo`0000?o0000ooooooooool0o_oooolEo`00o`Sooooo
0Ol00001ooooo`0000?o0000ooooooooool0o_oooolEo`00o`Sooooo0Ol00001ooooo`0000?o0000
ooooooooool0o_oooolEo`00o`Sooooo0Ol00001ooooo`0000?o0000ooooooooool0o_oooolEo`00
o`Sooooo0Ol00001ooooo`0000?o0000ooooooooool0o_oooolEo`00o`Sooooo0Ol00001ooooo`00
00?o0000ooooooooool0o_oooolEo`00o`Sooooo0Ol00001ooooo`0000?o0000ooooooooool0:_oo
ool6ool00<kooooo5Ol00?l8ooooo`7o00000Oooool00003o`000?oooooooooo02Wooooo00?oo`00
ooooooooool01?ooool5ool00<Wooooo5Ol00?l8ooooo`7o00000Oooool00003o`000?oooooooooo
02Oooooo0_oo000<ooooo`Coo`00aOoooolEo`00o`Sooooo0Ol00001ooooo`0000?o0000oooooooo
ool09_ooool00ooo003oooooooooo`0@ooooo`Coo`00`OoooolEo`00o`Sooooo0Ol00001ooooo`00
00?o0000ooooooooool09?ooool00oooO`3oo`00ooooo`09ooooo`;oogl02oooool3ool00;kooooo
5Ol00?l8ooooo`7o00000Oooool00003o`000?oooooooooo02?ooooo00Coogl0ool00?ooO`3oogl0
2?ooool4oomo00gooooo00?oo`00ooooooooool0^ooooolEo`00o`Sooooo0Ol00001ooooo`0000?o
0000ooooooooool08oooool01?ooO`3oo`00oomo0?ooO`08ooooo`Coogl03_ooool2ool00;_ooooo
5Ol00?l8ooooo`7o00000Oooool00003o`000?oooooooooo02Cooooo00?oogl0ool00?ooool02Ooo
ool2oomo017ooooo0_oo002ioooooaGo003o2?ooool1o`00007ooooo00000ol0003oooooooooo`0U
ooooo`03ool00?oooooooooo01gooooo0_oo002goooooaGo003o2?ooool1o`00007ooooo00000ol0
003oooooooooo`0Uooooo`03ool00?oooooooooo01oooooo0_oo002eoooooaGo003o2?ooool1o`00
007ooooo00000ol0003oooooooooo`0Vooooo`03ool00?oooooooooo017ooooo0_ooO`0=ooooo`;o
o`001?ooool2oomo00Oooooo0_ooO`2ToooooaGo003o2?ooool1o`00007ooooo00000ol0003ooooo
ooooo`0Vooooo`03ool00?oooooooooo00Gooooo0_ooO`09ooooo`Coogl03_ooool00ooo003ooooo
ooooo`04oomo00Gooooo1?ooO`2SoooooaGo003o2?ooool1o`00007ooooo00000ol0003ooooooooo
o`0Vooooo`03ool00?oooooooooo00Cooooo1?ooO`08ooooo`Coogl03oooool00ooo003ooooooomo
0003oomo00Gooooo1?ooO`2SoooooaGo003o2?ooool1o`00007ooooo00000ol0003oooooooooo`0W
ooooo`03ool00?oooooooooo00?ooooo1?ooO`09ooooo`;oogl04Oooool01?oo003ooooooomo0?oo
O`07ooooo`?oogl0XooooolEo`00o`Sooooo0Ol00001ooooo`0000?o0000ooooooooool09oooool0
0ooo003oooooooooo`04ooooo`;oogl07_ooool00ooo003oooooooooo`07ooooo`Coogl0X_oooolE
o`00o`Sooooo0Ol00001ooooo`0000?o0000ooooooooool0:?ooool00ooo003oooooooooo`0Toooo
o`03ool00?oooooooooo00Kooooo1?ooO`2RoooooaGo003o2?ooool1o`00007ooooo00000ol0003o
ooooooooo`0Yooooo`03ool00?oooooooooo02Cooooo0_oo00000oooooooogl0oomo0004ooooo`;o
ogl0XooooolEo`00o`Sooooo0Ol00001ooooo`0000?o0000ooooooooool0:_ooool00ooo003ooooo
ooooo`0Cooooo`Coo`003_ooool01?oo003oogl0oomo0?ooO`2XoooooaGo003o2?ooool1o`00007o
oooo00000ol0003oooooooooo`0[ooooo`03ool00?oooooooooo017ooooo1_oo000=ooooo`04oomo
0?oo003oo`00oomo0:Sooooo5Ol00?l8ooooo`7o00000Oooool00003o`000?oooooooooo02cooooo
00?oo`00ooooooooool02?ooool2oomo00Gooooo2?oo000=ooooo`;oogl000?oo`00ooooooooool0
Y_oooolEo`00o`Sooooo0Ol00001ooooo`0000?o0000ooooooooool0;Oooool00ooo003ooooooooo
o`06ooooo`Coogl01?ooool8ool0013ooooo00?oo`00ooooooooool0YOoooolEo`00o`Sooooo0Ol0
0001ooooo`0000?o0000ooooooooool0:oooool2oomo0003oooooooo003ooooo00Kooooo1?ooO`04
ooooo`Soo`004Oooool00ooo003oooooooooo`2ToooooaGo003o2?ooool1o`00007ooooo00000ol0
003oooooooooo`0Zooooo`Coogl000?oooooool00?ooool01_ooool2oomo00Gooooo2?oo000;oooo
o`;oogl01Oooool00ooo003oooooooooo`09ooooo`;oogl0V?oooolEo`00o`Sooooo0Ol00001oooo
o`0000?o0000ooooooooool0:_ooool4oomo00;ooooo00?oo`00ooooooooool03?ooool6ool000_o
oooo1?ooO`04ooooo`03ool00?oooooooooo00Sooooo1?ooO`2GoooooaGo003o2?ooool1o`00007o
oooo00000ol0003oooooooooo`0[ooooo`;oogl01?ooool00ooo003oooooooooo`0<ooooo`Coo`00
3?ooool4oomo00Gooooo00?oo`00ooooooooool01oooool4oomo09Oooooo5Ol00?l8ooooo`7o0000
0Oooool00003o`000?oooooooooo03;ooooo0_oo000Mooooo`;oogl01oooool00ooo003ooooooooo
o`07ooooo`;oogl0]Oooool1o`00007ooooo00000ol0003oooooooooo`0dooooo`03ool00?oooooo
oooo02Cooooo00?oo`00ooooooooool0_Oooool1o`00007ooooo00000ol0003oooooooooo`0eoooo
o`03ool00?oooooooooo02Cooooo00?oo`00ooooooooool0_?ooool1o`00007ooooo00000ol0003o
ooooooooo`0fooooo`;oo`009Oooool00ooo003oooooooooo`2kooooo`7o00000Oooool00003o`00
0?oooooooooo03Sooooo0_oo00000oooO`3oooooooooo`02oomo01kooooo00?oo`00ooooooooool0
^oooool1o`00007ooooo00000ol0003oooooooooo`0hooooo`;oogl00_oo0004oomo01kooooo00?o
o`00ooooooooool0^_ooool1o`00007ooooo00000ol0003oooooooooo`0hooooo`Coogl00_oo0002
oomo01kooooo00?oo`00ooooooooool0^_ooool1o`00007ooooo00000ol0003oooooooooo`0ioooo
o`Googl000?oo`00ooooooooool07Oooool00ooo003oogl0oomo002jooooo`7o00000Oooool00003
o`000?oooooooooo03_ooooo1?ooO`02ool001gooooo00Coogl0ool00?ooO`3oogl0^Oooool1o`00
007ooooo00000ol0003oooooooooo`0looooo`;oogl00oooool2ool001_ooooo00Coogl0ool00?oo
O`3oogl0^Oooool1o`00007ooooo00000ol0003oooooooooo`13ooooo`;oo`006_ooool00oooO`3o
o`00ooooo`2iooooo`7o00000Oooool00003o`000?oooooooooo04Gooooo0_oo000Iooooo`03ool0
0?oooooooooo0;Sooooo0Ol00001ooooo`0000?o0000ooooooooool0Aoooool2ool001Gooooo0_oo
002kooooo`7o00000Oooool00003o`000?oooooooooo04Wooooo0ooo000@ooooo`;oo`00_Oooool1
o`00007ooooo00000ol0003oooooooooo`0aooooo`;oogl06Oooool3ool000cooooo00?oo`00oooo
ooooool0_Oooool1o`00007ooooo00000ol0003oooooooooo`0`ooooo`Coogl06oooool6ool000Co
oooo0_oo0030ooooo`7o00000Oooool00003o`000?oooooooooo033ooooo1?ooO`0Qooooo`Coo`00
`_ooool1o`00007ooooo00000ol0003oooooooooo`0aooooo`;oogl0j?ooool1o`00007ooooo0000
0ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLoooo
o`7o00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003ooooo
ooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Ooo
ool00003o`000?oooooooooo07gooooo0_ooO`2Looooo`7o00000Oooool00003o`000?oooooooooo
07cooooo1?ooO`2Kooooo`7o00000Oooool00003o`000?oooooooooo05Cooooo0_ooO`0Vooooo`Co
ogl0Voooool1o`00007ooooo00000ol0003oooooooooo`1Cooooo`Coogl09_ooool2oomo09cooooo
0Ol00001ooooo`0000?o0000ooooooooool0Doooool4oomo0<Cooooo0Ol00001ooooo`0000?o0000
ooooooooool0E?ooool2oomo0<Gooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLoooo
o`7o00000Oooool00003o`000?oooooooooo06?ooooo0_ooO`04ooooo`;oogl0/?ooool1o`00007o
oooo00000ol0003oooooooooo`1Rooooo`Coogl00_ooool4oomo0:oooooo0Ol00001ooooo`0000?o
0000ooooooooool0H_ooool4oomo00;ooooo1?ooO`2_ooooo`7o00000Oooool00003o`000?oooooo
oooo06?ooooo0_ooO`04ooooo`;oogl0/?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooo
oacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`00
0?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol0
0001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo
0?oooooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`00
00?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?oo
ool1o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000oooo
ooooool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007o
oooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooo
oolLooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0
003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o
00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003ooooooooo
o`3ooooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool0
0003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooooaco
oooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oo
oooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001
ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo0?oo
oooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o
0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1
o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000oooooooo
ool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo
00000ol0003oooooooooo`3oooooo`Cooooo0_ooO`0Fooooo`7o00000Oooool00003o`000?oooooo
oooo0?oooooo0oooool4oomo01Gooooo0Ol00001ooooo`0000?o0000ooooooooool0ooooool3oooo
o`Coogl05Oooool1o`00007ooooo00000ol0003oooooooooo`3oooooo`Cooooo0_ooO`0Fooooo`7o
00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003ooooooooo
o`3ooooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool0
0003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooooaco
oooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oo
oooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001
ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo0?oo
oooo7?ooool1o`00007ooooo00000ol0003oooooooooo`2eooooo`;oogl0I?ooool1o`00007ooooo
00000ol0003oooooooooo`2dooooo`Coogl0Hoooool1o`00007ooooo00000ol0003oooooooooo`2d
ooooo`Coogl0Hoooool1o`00007ooooo00000ol0003oooooooooo`2eooooo`;oogl0=Oooool2oomo
02gooooo0Ol00001ooooo`0000?o0000ooooooooool0i?ooool2oomo00Gooooo1?ooO`0/ooooo`7o
00000Oooool00003o`000?oooooooooo0>?ooooo1?ooO`04ooooo`Coogl0;?ooool1o`00007ooooo
00000ol0003oooooooooo`33ooooo`;oogl07_ooool4oomo00Gooooo0_ooO`0]ooooo`7o00000Ooo
ool00003o`000?oooooooooo0<;ooooo1?ooO`0;o`00oa?ooooo0_ooO`0eooooo`7o00000Oooool0
0003o`000?oooooooooo0<;ooooo1?l00?l;ooooo`;o003oB?ooool1o`00007ooooo00000ol0003o
ooooooooo`2nooooo`Co003o00?ooooooomo0?ooO`003_ooool2o`00odKooooo0Ol00001ooooo`00
00?o0000ooooooooool0^Oooool2oomo00?o003o5oooool2o`00o`Wooooo0_ooO`0iooooo`7o0000
0Oooool00003o`000?oooooooooo0;Oooooo1?l00?l00oooO`3oooooooooo`0Iooooo`;o003o1_oo
ool4oomo03Sooooo0Ol00001ooooo`0000?o0000ooooooooool0]?ooool3o`00o`03ooooooooO`3o
ogl000;oogl07?ooool00ol00?ooooooooooo`04ooooo`Coogl00oooool2oomo03?ooooo0Ol00001
ooooo`0000?o0000ooooooooool0/_ooool2o`00o`?oogl00_ooool2oomo01?ooooo0_ooO`08oooo
o`03o`00oooooooooooo00Gooooo0_ooO`03ooooo`Coogl0<_ooool1o`00007ooooo00000ol0003o
ooooooooo`2`ooooo`;o003o00?ooooooomo0?ooO`000_ooO`06ooooo`;oogl03_ooool4oomo00Oo
oooo00?o003oooooooooool02_ooool4oomo03;ooooo0Ol00001ooooo`0000?o0000ooooooooool0
[_ooool2o`00o`Cooooo0_ooO`06ooooo`Coogl03Oooool4oomo00Oooooo00?o003oooooooooool0
2oooool2oomo03?ooooo0Ol00001ooooo`0000?o0000ooooooooool0Roooool2oomo023ooooo00?o
003oooooooooool01?ooool2oomo00Kooooo1?ooO`0>ooooo`;oogl02Oooool00ol00?oooooooooo
o`0oooooo`7o00000Oooool00003o`000?oooooooooo08[ooooo1?ooO`0Mooooo`;o003o1_ooool4
oomo00Kooooo0_ooO`0Jooooo`03o`00oooooooooooo03oooooo0Ol00001ooooo`0000?o0000oooo
ooooool0R_ooool4oomo01cooooo00?o003oooooooooool01_ooool4oomo02;ooooo00?o003ooooo
ooooool0?oooool1o`00007ooooo00000ol0003oooooooooo`2;ooooo`;oogl06oooool2o`00o`[o
oooo0_ooO`0Sooooo`03o`00oooooooooooo03oooooo0Ol00001ooooo`0000?o0000ooooooooool0
U_ooool2oomo00kooooo0_l00?lZooooo`;oogl01Oooool00ol00?ooooooooooo`0oooooo`7o0000
0Oooool00003o`000?oooooooooo09Gooooo1?ooO`0<ooooo`04o`00ooooooooogl0oomo02Sooooo
1?ooO`03ooooo`03o`00oooooooooooo043ooooo0Ol00001ooooo`0000?o0000ooooooooool0UOoo
ool4oomo00[ooooo0_l00?l00oooooooogl0oomo0002oomo02Oooooo1?ooO`03ooooo`03o`00oooo
oooooooo043ooooo0Ol00001ooooo`0000?o0000ooooooooool0U_ooool2oomo00[ooooo00Co003o
oooooooooooooooo1?ooO`0Xooooo`;oogl01?ooool00ol00?ooooooooooo`10ooooo`7o00000Ooo
ool00003o`000?oooooooooo0:7ooooo00?o003oooooooooool00oooool2oomo02kooooo00?o003o
ooooooooool0@Oooool1o`00007ooooo00000ol0003oooooooooo`2Pooooo`03o`00oooooooooooo
03?ooooo00?o003oooooooooool04_ooool2oomo02kooooo0Ol00001ooooo`0000?o0000oooooooo
ool0W_ooool2o`00ocGooooo00?o003oooooooooool04_ooool4oomo02gooooo0Ol00001ooooo`00
00?o0000ooooooooool0WOooool00ol00?ooooooooooo`0Eooooo`Co003o7?ooool00ol00?ooogl0
oomo000Booooo`Coogl0;Oooool1o`00007ooooo00000ol0003oooooooooo`2Looooo`03o`00oooo
oooooooo01Gooooo1_l00?lJooooo`03o`00ooooO`3oogl000;oogl04_ooool2oomo02kooooo0Ol0
0001ooooo`0000?o0000ooooooooool0Voooool00ol00?ooooooooooo`08ooooo`Goo`3o2?ooool8
o`00oaSooooo00?o003oooooooooO`000oooO`12ooooo`7o00000Oooool00003o`000?oooooooooo
09_ooooo00?o003oooooooooool01oooool7ool0o`Oooooo2?l00?lGooooo`04o`00oooooooooooo
ooooo`;oogl0@oooool1o`00007ooooo00000ol0003oooooooooo`2Jooooo`03o`00oooooooooooo
00Oooooo2Ooo0?l6ooooo`So003o5_ooool00ol00?ooooooooooo`17ooooo`7o00000Oooool00003
o`000?oooooooooo09Wooooo00?o003oooooooooool01oooool;ool0o`Cooooo00?oogl0o`00ool0
0?l01_l00?lEooooo`03o`00oooooooooooo00;oogl0A_ooool1o`00007ooooo00000ol0003ooooo
ooooo`2Iooooo`03o`00oooooooooooo00Oooooo2ooo0?l4ooooo`;oogl01_l00?lCooooo`;oogl0
00?o003oooooooooool01?ooO`15ooooo`7o00000Oooool00003o`000?oooooooooo09Sooooo00?o
003oooooooooool02?ooool;ool0o`Gooooo0_ooO`04o`00oa?ooooo0_ooO`02o`00o`;ooooo1?oo
O`15ooooo`7o00000Oooool00003o`000?oooooooooo09Sooooo00?o003oooooooooool02?ooool;
ool0oakooooo00Coogl0o`00ooooO`3oogl00oooool2oomo04Kooooo0Ol00001ooooo`0000?o0000
ooooooooool0M_ooool2oomo01oooooo00?o003oooooooooool02Oooool;ool0oakooooo00?o003o
oomo0?ooO`00C?ooool1o`00007ooooo00000ol0003oooooooooo`1eooooo`Coogl07_ooool00ol0
0?ooooooooooo`0:ooooo`Woo`3o7_ooool00ol00?ooooooooooo`1=ooooo`7o00000Oooool00003
o`000?oooooooooo07Gooooo1?ooO`0:ooooo`;oogl04Oooool00ol00?ooooooooooo`0<ooooo`Oo
o`3o7_ooool00ol00?ooooooooooo`1>ooooo`7o00000Oooool00003o`000?oooooooooo07Kooooo
0_ooO`0:ooooo`Coogl03oooool00ol00?ooooooooooo`0>ooooo`Goo`3o1Oooool2oomo01Oooooo
00?o003oooooooooool0Coooool1o`00007ooooo00000ol0003oooooooooo`22ooooo`Coogl03ooo
ool00ol00?ooooooooooo`0Gooooo`Coogl05?ooool2o`00oe;ooooo0Ol00001ooooo`0000?o0000
ooooooooool0Poooool2oomo00oooooo00?o003oooooooooool04_ooool2oomo00Cooooo1?ooO`0A
ooooo`?o003oE?ooool1o`00007ooooo00000ol0003oooooooooo`2Dooooo`03o`00oooooooooooo
017ooooo1?ooO`04ooooo`;oogl04?ooool2o`00oeOooooo0Ol00001ooooo`0000?o0000oooooooo
ool0U?ooool00ol00?ooooooooooo`0Aooooo`Coogl05Oooool00ol00?ooooooooooo`1Gooooo`7o
00000Oooool00003o`000?oooooooooo09Cooooo00?o003oooooooooool04_ooool2oomo01Cooooo
0_l00?mJooooo`7o00000Oooool00003o`000?oooooooooo09Cooooo00?o003oooooooooool09_oo
ool2o`00oecooooo0Ol00001ooooo`0000?o0000ooooooooool0UOooool00ol00?ooooooooooo`0T
ooooo`03o`00oooooooooooo05cooooo0Ol00001ooooo`0000?o0000ooooooooool0UOooool00ol0
0?ooooooooooo`0Rooooo`;o003oGoooool1o`00007ooooo00000ol0003oooooooooo`2Eooooo`03
o`00oooooooooooo023ooooo0_l00?mQooooo`7o00000Oooool00003o`000?oooooooooo08Cooooo
0_ooO`0?ooooo`;o003o7oooool2o`00of?ooooo0Ol00001ooooo`0000?o0000ooooooooool0Pooo
ool4oomo013ooooo0_l00?lJooooo`?o003oIOooool1o`00007ooooo00000ol0003oooooooooo`23
ooooo`Coogl04_ooool2o`00oaCooooo1?l00?mXooooo`7o00000Oooool00003o`000?oooooooooo
08Cooooo0_ooO`0Eooooo`?o003o3_ooool3o`00o`?ooooo0_ooO`1Wooooo`7o00000Oooool00003
o`000?oooooooooo09kooooo0ol00?l5ooooo`Ko003o1Oooool4oomo06Kooooo0Ol00001ooooo`00
00?o0000ooooooooool0XOooool5o`00o`_ooooo1?ooO`1Vooooo`7o00000Oooool00003o`000?oo
oooooooo0;;ooooo0_ooO`1Wooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1
o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000oooooooo
ool0Noooool2oomo09kooooo0Ol00001ooooo`0000?o0000ooooooooool0N_ooool4oomo09gooooo
0Ol00001ooooo`0000?o0000ooooooooool0N_ooool4oomo023ooooo0_ooO`1kooooo`7o00000Ooo
ool00003o`000?oooooooooo07_ooooo0_ooO`0Pooooo`Coogl0N_ooool1o`00007ooooo00000ol0
003oooooooooo`2Mooooo`Coogl0N_ooool1o`00007ooooo00000ol0003oooooooooo`2@ooooo`;o
ogl03?ooool2oomo07_ooooo0Ol00001ooooo`0000?o0000ooooooooool0Soooool4oomo08Sooooo
0Ol00001ooooo`0000?o0000ooooooooool0Soooool4oomo08Sooooo0Ol00001ooooo`0000?o0000
ooooooooool0T?ooool2oomo02?ooooo0_ooO`1Tooooo`7o00000Oooool00003o`000?oooooooooo
0;Cooooo1?ooO`1Sooooo`7o00000Oooool00003o`000?oooooooooo0;Cooooo1?ooO`1Sooooo`7o
00000Oooool00003o`000?oooooooooo0;Gooooo0_ooO`1Tooooo`7o00000Oooool00003o`000?oo
oooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001
ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo0?oo
oooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o
0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1
o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000oooooooo
ool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo
00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolL
ooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003o
ooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o0000
0Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3o
oooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003
o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo
0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oooooo
oooo0?oooooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001oooo
o`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo
7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000
ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00
007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0
oooooolLooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo0000
0ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLoooo
o`7o00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003ooooo
ooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Ooo
ool00003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003oooooooooo`2>oooo
o`;oogl0Roooool1o`00007ooooo00000ol0003oooooooooo`2=ooooo`Coogl0R_ooool1o`00007o
oooo00000ol0003oooooooooo`2=ooooo`Coogl0R_ooool1o`00007ooooo00000ol0003ooooooooo
o`2>ooooo`;oogl0Roooool1o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001
ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo0?oo
oooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o
0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1
o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000oooooooo
ool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo
00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolL
ooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003o
ooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o0000
0Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3o
oooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003
o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo
0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oooooo
oooo0?oooooo7?ooool1o`00007ooooo003oo`00023o00000Oooool00001\
\>"],
  ImageRangeCache->{{{0, 287}, {287, 0}} -> {-1.01089, -1.01089, 0.00704453, \
0.00704453}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.49505 0.5 0.49505 [
[ 0 0 -0.125 0 ]
[ 0 0 -0.125 0 ]
[ 0 1 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
0 0 m
1 0 L
s
0 0 m
0 1 L
s
0 1 m
1 1 L
s
1 0 m
1 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
1 .5 0 r
.015 w
.03175 .1355 Mdot
.03435 .12523 Mdot
.11137 .12765 Mdot
.14107 .18841 Mdot
.16218 .24538 Mdot
.17294 .21053 Mdot
.18267 .18577 Mdot
.18434 .1304 Mdot
.18553 .30956 Mdot
.20401 .239 Mdot
.21247 .27571 Mdot
.21687 .20845 Mdot
.22376 .2799 Mdot
.22832 .27485 Mdot
.29063 .20974 Mdot
.29686 .25079 Mdot
.30487 .22936 Mdot
.30683 .34623 Mdot
.32055 .20902 Mdot
.32574 .21979 Mdot
.34472 .28521 Mdot
.35998 .36393 Mdot
.36335 .24976 Mdot
.3794 .36608 Mdot
.42386 .66992 Mdot
.44391 .74519 Mdot
.45059 .34198 Mdot
.47208 .67586 Mdot
.47436 .71381 Mdot
.49778 .59825 Mdot
.50874 .91643 Mdot
.51516 .76219 Mdot
.53655 .61374 Mdot
.56563 .75219 Mdot
.59189 .65665 Mdot
.59581 .61604 Mdot
.59923 .6556 Mdot
.60292 .68499 Mdot
.62656 .67779 Mdot
.63555 .72451 Mdot
.63919 .652 Mdot
.64169 .6004 Mdot
.64246 .58611 Mdot
.64496 .54267 Mdot
.64608 .77288 Mdot
.65077 .64308 Mdot
.66065 .57816 Mdot
.67474 .59169 Mdot
.69296 .563 Mdot
.72815 .65902 Mdot
.73169 .58879 Mdot
.74669 .61318 Mdot
.74821 .65474 Mdot
.75963 .63781 Mdot
.79673 .57809 Mdot
.80925 .55852 Mdot
.81525 .58444 Mdot
.83417 .62985 Mdot
.83598 .55526 Mdot
.91595 .49319 Mdot
1 0 0 r
.005 w
.16128 .17044 m
.18734 .17269 L
.21339 .17909 L
.2345 .18734 L
.23945 .19126 L
.2655 .20415 L
.27874 .21339 L
.29156 .22295 L
.31204 .23945 L
.31761 .24532 L
.33549 .2655 L
.34367 .28341 L
.34499 .29156 L
.34367 .29798 L
.31761 .3104 L
.29156 .30711 L
.2655 .30014 L
.24507 .29156 L
.23945 .28747 L
.21339 .27402 L
.20155 .2655 L
.18734 .25472 L
.16884 .23945 L
.16128 .2313 L
.14618 .21339 L
.13806 .18734 L
.16128 .17044 L
s
0 0 1 r
.65633 .57701 m
.68239 .56842 L
.70844 .56313 L
.7345 .56168 L
.76055 .5752 L
.76359 .57817 L
.76859 .60422 L
.76055 .62333 L
.75627 .63028 L
.7345 .65485 L
.73298 .65633 L
.70844 .6775 L
.69922 .68239 L
.68239 .69294 L
.65633 .70579 L
.64983 .70844 L
.63028 .71539 L
.60422 .72268 L
.57817 .72651 L
.55211 .7214 L
.53145 .70844 L
.52926 .68239 L
.54239 .65633 L
.55211 .63983 L
.56625 .63028 L
.57817 .6193 L
.60119 .60422 L
.60422 .60227 L
.63028 .58726 L
.65315 .57817 L
.65633 .57701 L
s
1 0 0 r
.03 w
.24141 .24033 Mdot
0 0 1 r
.64872 .64417 Mdot
1 0 0 r
.79703 .00495 m
.79703 .00495 L
.87129 .00495 L
.87129 .00495 L
F
0 0 1 r
.89604 .00495 m
.89604 .25248 L
.9703 .25248 L
.9703 .00495 L
F
1 0 1 r
.04 w
.60292 .68499 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P000182000`400?l00000o`00003ooooooolQ
ooooo`00ool0000Po`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`00
00?o0000ooooooooool0o_oooolEo`00o`Sooooo0Ol00001ooooo`0000?o0000ooooooooool0o_oo
oolEo`00o`Sooooo0Ol00001ooooo`0000?o0000ooooooooool0o_oooolEo`00o`Sooooo0Ol00001
ooooo`0000?o0000ooooooooool0o_oooolEo`00o`Sooooo0Ol00001ooooo`0000?o0000oooooooo
ool0o_oooolEo`00o`Sooooo0Ol00001ooooo`0000?o0000ooooooooool0o_oooolEo`00o`Sooooo
0Ol00001ooooo`0000?o0000ooooooooool0o_oooolEo`00o`Sooooo0Ol00001ooooo`0000?o0000
ooooooooool0o_oooolEo`00o`Sooooo0Ol00001ooooo`0000?o0000ooooooooool0o_oooolEo`00
o`Sooooo0Ol00001ooooo`0000?o0000ooooooooool0o_oooolEo`00o`Sooooo0Ol00001ooooo`00
00?o0000ooooooooool0o_oooolEo`00o`Sooooo0Ol00001ooooo`0000?o0000ooooooooool0o_oo
oolEo`00o`Sooooo0Ol00001ooooo`0000?o0000ooooooooool0o_oooolEo`00o`Sooooo0Ol00001
ooooo`0000?o0000ooooooooool0o_oooolEo`00o`Sooooo0Ol00001ooooo`0000?o0000oooooooo
ool0o_oooolEo`00o`Sooooo0Ol00001ooooo`0000?o0000ooooooooool0o_oooolEo`00o`Sooooo
0Ol00001ooooo`0000?o0000ooooooooool0o_oooolEo`00o`Sooooo0Ol00001ooooo`0000?o0000
ooooooooool0o_oooolEo`00o`Sooooo0Ol00001ooooo`0000?o0000ooooooooool0o_oooolEo`00
o`Sooooo0Ol00001ooooo`0000?o0000ooooooooool0o_oooolEo`00o`Sooooo0Ol00001ooooo`00
00?o0000ooooooooool0o_oooolEo`00o`Sooooo0Ol00001ooooo`0000?o0000ooooooooool0o_oo
oolEo`00o`Sooooo0Ol00001ooooo`0000?o0000ooooooooool0o_oooolEo`00o`Sooooo0Ol00001
ooooo`0000?o0000ooooooooool0o_oooolEo`00o`Sooooo0Ol00001ooooo`0000?o0000oooooooo
ool0o_oooolEo`00o`Sooooo0Ol00001ooooo`0000?o0000ooooooooool0o_oooolEo`00o`Sooooo
0Ol00001ooooo`0000?o0000ooooooooool0o_oooolEo`00o`Sooooo0Ol00001ooooo`0000?o0000
ooooooooool0o_oooolEo`00o`Sooooo0Ol00001ooooo`0000?o0000ooooooooool0o_oooolEo`00
o`Sooooo0Ol00001ooooo`0000?o0000ooooooooool0o_oooolEo`00o`Sooooo0Ol00001ooooo`00
00?o0000ooooooooool0o_oooolEo`00o`Sooooo0Ol00001ooooo`0000?o0000ooooooooool0o_oo
oolEo`00o`Sooooo0Ol00001ooooo`0000?o0000ooooooooool01_ooool2oomo0?Kooooo5Ol00?l8
ooooo`7o00000Oooool00003o`000?oooooooooo00Gooooo1?ooO`0Cooooo`;oogl0h?oooolEo`00
o`Sooooo0Ol00001ooooo`0000?o0000ooooooooool01Oooool4oomo01;ooooo1?ooO`0Booooo`;o
ogl0booooolEo`00o`Sooooo0Ol00001ooooo`0000?o0000ooooooooool01Oooool3oomo01?ooooo
1?ooO`0Aooooo`Coogl0b_oooolEo`00o`Sooooo0Ol00001ooooo`0000?o0000ooooooooool01?oo
ool4oomo01Cooooo0_ooO`0Booooo`Coogl0b_oooolEo`00o`Sooooo0Ol00001ooooo`0000?o0000
ooooooooool01?ooool4oomo02Wooooo0_ooO`3;oooooaGo003o2?ooool1o`00007ooooo00000ol0
003oooooooooo`05ooooo`;oogl0mooooolEo`00o`Sooooo0Ol00001ooooo`0000?o0000oooooooo
ool0o_oooolEo`00o`Sooooo0Ol00001ooooo`0000?o0000ooooooooool0o_oooolEo`00o`Sooooo
0Ol00001ooooo`0000?o0000ooooooooool0o_oooolEo`00o`Sooooo0Ol00001ooooo`0000?o0000
ooooooooool0o_oooolEo`00o`Sooooo0Ol00001ooooo`0000?o0000ooooooooool0o_oooolEo`00
o`Sooooo0Ol00001ooooo`0000?o0000ooooooooool0o_oooolEo`00o`Sooooo0Ol00001ooooo`00
00?o0000ooooooooool0o_oooolEo`00o`Sooooo0Ol00001ooooo`0000?o0000ooooooooool0:_oo
ool6ool00<kooooo5Ol00?l8ooooo`7o00000Oooool00003o`000?oooooooooo02Wooooo00?oo`00
ooooooooool01?ooool5ool00<Wooooo5Ol00?l8ooooo`7o00000Oooool00003o`000?oooooooooo
02Oooooo0_oo000<ooooo`Coo`00aOoooolEo`00o`Sooooo0Ol00001ooooo`0000?o0000oooooooo
ool09_ooool00ooo003oooooooooo`0@ooooo`Coo`00`OoooolEo`00o`Sooooo0Ol00001ooooo`00
00?o0000ooooooooool09?ooool00oooO`3oo`00ooooo`09ooooo`;oogl02oooool3ool00;kooooo
5Ol00?l8ooooo`7o00000Oooool00003o`000?oooooooooo02?ooooo00Coogl0ool00?ooO`3oogl0
2?ooool4oomo00gooooo00?oo`00ooooooooool0^ooooolEo`00o`Sooooo0Ol00001ooooo`0000?o
0000ooooooooool08oooool01?ooO`3oo`00oomo0?ooO`08ooooo`Coogl03_ooool2ool00;_ooooo
5Ol00?l8ooooo`7o00000Oooool00003o`000?oooooooooo02Cooooo00?oogl0ool00?ooool02Ooo
ool2oomo017ooooo0_oo002ioooooaGo003o2?ooool1o`00007ooooo00000ol0003oooooooooo`0U
ooooo`03ool00?oooooooooo01gooooo0_oo002goooooaGo003o2?ooool1o`00007ooooo00000ol0
003oooooooooo`0Uooooo`03ool00?oooooooooo01oooooo0_oo002eoooooaGo003o2?ooool1o`00
007ooooo00000ol0003oooooooooo`0Vooooo`03ool00?oooooooooo017ooooo0_ooO`0=ooooo`;o
o`001?ooool2oomo00Oooooo0_ooO`2ToooooaGo003o2?ooool1o`00007ooooo00000ol0003ooooo
ooooo`0Vooooo`03ool00?oooooooooo00Gooooo0_ooO`09ooooo`Coogl03_ooool00ooo003ooooo
ooooo`04oomo00Gooooo1?ooO`2SoooooaGo003o2?ooool1o`00007ooooo00000ol0003ooooooooo
o`0Vooooo`03ool00?oooooooooo00Cooooo1?ooO`08ooooo`Coogl03oooool00ooo003ooooooomo
0003oomo00Gooooo1?ooO`2SoooooaGo003o2?ooool1o`00007ooooo00000ol0003oooooooooo`0W
ooooo`03ool00?oooooooooo00?ooooo1?ooO`09ooooo`;oogl04Oooool01?oo003ooooooomo0?oo
O`07ooooo`?oogl0XooooolEo`00o`Sooooo0Ol00001ooooo`0000?o0000ooooooooool09oooool0
0ooo003oooooooooo`04ooooo`;oogl07_ooool00ooo003oooooooooo`07ooooo`Coogl0X_oooolE
o`00o`Sooooo0Ol00001ooooo`0000?o0000ooooooooool0:?ooool00ooo003oooooooooo`0Toooo
o`03ool00?oooooooooo00Kooooo1?ooO`2RoooooaGo003o2?ooool1o`00007ooooo00000ol0003o
ooooooooo`0Yooooo`03ool00?oooooooooo02Cooooo0_oo00000oooooooogl0oomo0004ooooo`;o
ogl0XooooolEo`00o`Sooooo0Ol00001ooooo`0000?o0000ooooooooool0:_ooool00ooo003ooooo
ooooo`0Cooooo`Coo`003_ooool01?oo003oogl0oomo0?ooO`2XoooooaGo003o2?ooool1o`00007o
oooo00000ol0003oooooooooo`0[ooooo`03ool00?oooooooooo017ooooo1_oo000=ooooo`04oomo
0?oo003oo`00oomo0:Sooooo5Ol00?l8ooooo`7o00000Oooool00003o`000?oooooooooo02cooooo
00?oo`00ooooooooool02?ooool2oomo00Gooooo2?oo000=ooooo`;oogl000?oo`00ooooooooool0
Y_oooolEo`00o`Sooooo0Ol00001ooooo`0000?o0000ooooooooool0;Oooool00ooo003ooooooooo
o`06ooooo`Coogl01?ooool8ool0013ooooo00?oo`00ooooooooool0YOoooolEo`00o`Sooooo0Ol0
0001ooooo`0000?o0000ooooooooool0:oooool2oomo0003oooooooo003ooooo00Kooooo1?ooO`04
ooooo`Soo`004Oooool00ooo003oooooooooo`2ToooooaGo003o2?ooool1o`00007ooooo00000ol0
003oooooooooo`0Zooooo`Coogl000?oooooool00?ooool01_ooool2oomo00Gooooo2?oo000;oooo
o`;oogl01Oooool00ooo003oooooooooo`09ooooo`;oogl0V?oooolEo`00o`Sooooo0Ol00001oooo
o`0000?o0000ooooooooool0:_ooool4oomo00;ooooo00?oo`00ooooooooool03?ooool6ool000_o
oooo1?ooO`04ooooo`03ool00?oooooooooo00Sooooo1?ooO`2GoooooaGo003o2?ooool1o`00007o
oooo00000ol0003oooooooooo`0[ooooo`;oogl01?ooool00ooo003oooooooooo`0<ooooo`Coo`00
3?ooool4oomo00Gooooo00?oo`00ooooooooool01oooool4oomo09Oooooo5Ol00?l8ooooo`7o0000
0Oooool00003o`000?oooooooooo03;ooooo0_oo000Mooooo`;oogl01oooool00ooo003ooooooooo
o`07ooooo`;oogl0]Oooool1o`00007ooooo00000ol0003oooooooooo`0dooooo`03ool00?oooooo
oooo02Cooooo00?oo`00ooooooooool0_Oooool1o`00007ooooo00000ol0003oooooooooo`0eoooo
o`03ool00?oooooooooo02Cooooo00?oo`00ooooooooool0_?ooool1o`00007ooooo00000ol0003o
ooooooooo`0fooooo`;oo`009Oooool00ooo003oooooooooo`2kooooo`7o00000Oooool00003o`00
0?oooooooooo03Sooooo0_oo00000oooO`3oooooooooo`02oomo01kooooo00?oo`00ooooooooool0
^oooool1o`00007ooooo00000ol0003oooooooooo`0hooooo`;oogl00_oo0004oomo01kooooo00?o
o`00ooooooooool0^_ooool1o`00007ooooo00000ol0003oooooooooo`0hooooo`Coogl00_oo0002
oomo01kooooo00?oo`00ooooooooool0^_ooool1o`00007ooooo00000ol0003oooooooooo`0ioooo
o`Googl000?oo`00ooooooooool07Oooool00ooo003oogl0oomo002jooooo`7o00000Oooool00003
o`000?oooooooooo03_ooooo1?ooO`02ool001gooooo00Coogl0ool00?ooO`3oogl0^Oooool1o`00
007ooooo00000ol0003oooooooooo`0looooo`;oogl00oooool2ool001_ooooo00Coogl0ool00?oo
O`3oogl0^Oooool1o`00007ooooo00000ol0003oooooooooo`13ooooo`;oo`006_ooool00oooO`3o
o`00ooooo`2iooooo`7o00000Oooool00003o`000?oooooooooo04Gooooo0_oo000Iooooo`03ool0
0?oooooooooo0;Sooooo0Ol00001ooooo`0000?o0000ooooooooool0Aoooool2ool001Gooooo0_oo
002kooooo`7o00000Oooool00003o`000?oooooooooo04Wooooo0ooo000@ooooo`;oo`00_Oooool1
o`00007ooooo00000ol0003oooooooooo`0aooooo`;oogl06Oooool3ool000cooooo00?oo`00oooo
ooooool0_Oooool1o`00007ooooo00000ol0003oooooooooo`0`ooooo`Coogl06oooool6ool000Co
oooo0_oo0030ooooo`7o00000Oooool00003o`000?oooooooooo033ooooo1?ooO`0Qooooo`Coo`00
`_ooool1o`00007ooooo00000ol0003oooooooooo`0aooooo`;oogl0j?ooool1o`00007ooooo0000
0ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLoooo
o`7o00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003ooooo
ooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Ooo
ool00003o`000?oooooooooo07gooooo0_ooO`2Looooo`7o00000Oooool00003o`000?oooooooooo
07cooooo1?ooO`2Kooooo`7o00000Oooool00003o`000?oooooooooo05Cooooo0_ooO`0Vooooo`Co
ogl0Voooool1o`00007ooooo00000ol0003oooooooooo`1Cooooo`Coogl09_ooool2oomo09cooooo
0Ol00001ooooo`0000?o0000ooooooooool0Doooool4oomo0<Cooooo0Ol00001ooooo`0000?o0000
ooooooooool0E?ooool2oomo0<Gooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLoooo
o`7o00000Oooool00003o`000?oooooooooo06?ooooo0_ooO`04ooooo`;oogl0/?ooool1o`00007o
oooo00000ol0003oooooooooo`1Rooooo`Coogl00_ooool4oomo0:oooooo0Ol00001ooooo`0000?o
0000ooooooooool0H_ooool4oomo00;ooooo1?ooO`2_ooooo`7o00000Oooool00003o`000?oooooo
oooo06?ooooo0_ooO`04ooooo`;oogl0/?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooo
oacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`00
0?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol0
0001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo
0?oooooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`00
00?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?oo
ool1o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000oooo
ooooool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007o
oooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooo
oolLooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0
003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o
00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003ooooooooo
o`3ooooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool0
0003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooooaco
oooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oo
oooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001
ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo0?oo
oooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o
0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1
o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000oooooooo
ool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo
00000ol0003oooooooooo`3oooooo`Cooooo0_ooO`0Fooooo`7o00000Oooool00003o`000?oooooo
oooo0?oooooo0oooool4oomo01Gooooo0Ol00001ooooo`0000?o0000ooooooooool0ooooool3oooo
o`Coogl05Oooool1o`00007ooooo00000ol0003oooooooooo`3oooooo`Cooooo0_ooO`0Fooooo`7o
00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003ooooooooo
o`3ooooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool0
0003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooooaco
oooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oo
oooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001
ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo0?oo
oooo7?ooool1o`00007ooooo00000ol0003oooooooooo`2eooooo`;oogl0I?ooool1o`00007ooooo
00000ol0003oooooooooo`2dooooo`Coogl0Hoooool1o`00007ooooo00000ol0003oooooooooo`2d
ooooo`Coogl0Hoooool1o`00007ooooo00000ol0003oooooooooo`2eooooo`;oogl0=Oooool2oomo
02gooooo0Ol00001ooooo`0000?o0000ooooooooool0i?ooool2oomo00Gooooo1?ooO`0/ooooo`7o
00000Oooool00003o`000?oooooooooo0>?ooooo1?ooO`04ooooo`Coogl0;?ooool1o`00007ooooo
00000ol0003oooooooooo`33ooooo`;oogl07_ooool4oomo00Gooooo0_ooO`0]ooooo`7o00000Ooo
ool00003o`000?oooooooooo0<;ooooo1?ooO`0;o`00oa?ooooo0_ooO`0eooooo`7o00000Oooool0
0003o`000?oooooooooo0<;ooooo1?l00?l;ooooo`;o003oB?ooool1o`00007ooooo00000ol0003o
ooooooooo`2nooooo`Co003o00?ooooooomo0?ooO`003_ooool2o`00odKooooo0Ol00001ooooo`00
00?o0000ooooooooool0^Oooool2oomo00?o003o5oooool2o`00o`Wooooo0_ooO`0iooooo`7o0000
0Oooool00003o`000?oooooooooo0;Oooooo1?l00?l00oooO`3oooooooooo`0Iooooo`;o003o1_oo
ool4oomo03Sooooo0Ol00001ooooo`0000?o0000ooooooooool0]?ooool3o`00o`03ooooooooO`3o
ogl000;oogl07?ooool00ol00?ooooooooooo`04ooooo`Coogl00oooool2oomo03?ooooo0Ol00001
ooooo`0000?o0000ooooooooool0/_ooool2o`00o`?oogl00_ooool2oomo01?ooooo0_ooO`08oooo
o`03o`00oooooooooooo00Gooooo0_ooO`03ooooo`Coogl0<_ooool1o`00007ooooo00000ol0003o
ooooooooo`2`ooooo`;o003o00?ooooooomo0?ooO`000_ooO`06ooooo`;oogl03_ooool4oomo00Oo
oooo00?o003oooooooooool02_ooool4oomo03;ooooo0Ol00001ooooo`0000?o0000ooooooooool0
[_ooool2o`00o`Cooooo0_ooO`06ooooo`Coogl03Oooool4oomo00Oooooo00?o003oooooooooool0
2oooool2oomo03?ooooo0Ol00001ooooo`0000?o0000ooooooooool0Roooool2oomo023ooooo00?o
003oooooooooool01?ooool2oomo00Kooooo1?ooO`0>ooooo`;oogl02Oooool00ol00?oooooooooo
o`0oooooo`7o00000Oooool00003o`000?oooooooooo08[ooooo1?ooO`0Mooooo`;o003o1_ooool4
oomo00Kooooo0_ooO`0Jooooo`03o`00oooooooooooo03oooooo0Ol00001ooooo`0000?o0000oooo
ooooool0R_ooool4oomo01cooooo00?o003oooooooooool01_ooool4oomo02;ooooo00?o003ooooo
ooooool0?oooool1o`00007ooooo00000ol0003oooooooooo`2;ooooo`;oogl06oooool2o`00o`[o
oooo0_ooO`0Sooooo`03o`00oooooooooooo03oooooo0Ol00001ooooo`0000?o0000ooooooooool0
U_ooool2oomo00kooooo0_l00?lZooooo`;oogl01Oooool00ol00?ooooooooooo`0oooooo`7o0000
0Oooool00003o`000?oooooooooo09Gooooo1?ooO`0<ooooo`04o`00ooooooooogl0oomo02Sooooo
1?ooO`03ooooo`03o`00oooooooooooo043ooooo0Ol00001ooooo`0000?o0000ooooooooool0UOoo
ool4oomo00[ooooo0_l00?l00oooooooogl0oomo0002oomo02Oooooo1?ooO`03ooooo`03o`00oooo
oooooooo043ooooo0Ol00001ooooo`0000?o0000ooooooooool0U_ooool2oomo00[ooooo00Co003o
oooooooooooooooo1?ooO`0Xooooo`;oogl01?ooool00ol00?ooooooooooo`10ooooo`7o00000Ooo
ool00003o`000?oooooooooo0:7ooooo00?o003oooooooooool00oooool2oomo02kooooo00?o003o
ooooooooool0@Oooool1o`00007ooooo00000ol0003oooooooooo`2Pooooo`03o`00oooooooooooo
03?ooooo00?o003oooooooooool04_ooool2oomo02kooooo0Ol00001ooooo`0000?o0000oooooooo
ool0W_ooool2o`00ocGooooo00?o003oooooooooool04_ooool4oomo02gooooo0Ol00001ooooo`00
00?o0000ooooooooool0WOooool00ol00?ooooooooooo`0Eooooo`Co003o7?ooool00ol00?ooogl0
oomo000Booooo`Coogl0;Oooool1o`00007ooooo00000ol0003oooooooooo`2Looooo`03o`00oooo
oooooooo01Gooooo1_l00?lJooooo`03o`00ooooO`3oogl000;oogl04_ooool2oomo02kooooo0Ol0
0001ooooo`0000?o0000ooooooooool0Voooool00ol00?ooooooooooo`0Eooooo`So003o6?ooool0
0ol00?oooooooomo0003oomo04;ooooo0Ol00001ooooo`0000?o0000ooooooooool0Voooool00ol0
0?ooooooooooo`0Eooooo`So003o5oooool01?l00?ooooooooooooooool2oomo04?ooooo0Ol00001
ooooo`0000?o0000ooooooooool0V_ooool00ol00?ooooooooooo`0Fooooo`So003o5_ooool00ol0
0?ooooooooooo`17ooooo`7o00000Oooool00003o`000?oooooooooo09Wooooo00?o003ooooooooo
ool03?ooool2oomo00Sooooo00?oogl0o`00ool00?l01_l00?lEooooo`03o`00oooooooooooo00;o
ogl0A_ooool1o`00007ooooo00000ol0003oooooooooo`2Iooooo`03o`00oooooooooooo00[ooooo
1OooO`07ooooo`;oogl01_l00?lCooooo`;oogl000?o003oooooooooool01?ooO`15ooooo`7o0000
0Oooool00003o`000?oooooooooo09Sooooo00?o003oooooooooool02_ooool6oomo00Sooooo0_oo
O`04o`00oa?ooooo0_ooO`02o`00o`;ooooo1?ooO`15ooooo`7o00000Oooool00003o`000?oooooo
oooo09Sooooo00?o003oooooooooool02_ooool5oomo02;ooooo00Coogl0o`00ooooO`3oogl00ooo
ool2oomo04Kooooo0Ol00001ooooo`0000?o0000ooooooooool0M_ooool2oomo01oooooo00?o003o
ooooooooool03?ooool2oomo02Cooooo00?o003ooomo0?ooO`00C?ooool1o`00007ooooo00000ol0
003oooooooooo`1eooooo`Coogl07_ooool00ol00?ooooooooooo`0=ooooo`Goo`3o7oooool00ol0
0?ooooooooooo`1=ooooo`7o00000Oooool00003o`000?oooooooooo07Gooooo1?ooO`0:ooooo`;o
ogl04Oooool00ol00?ooooooooooo`0=ooooo`Ooo`3o7Oooool00ol00?ooooooooooo`1>ooooo`7o
00000Oooool00003o`000?oooooooooo07Kooooo0_ooO`0:ooooo`Coogl03oooool00ol00?oooooo
ooooo`0=ooooo`Woo`3o0_ooool2oomo01Oooooo00?o003oooooooooool0Coooool1o`00007ooooo
00000ol0003oooooooooo`22ooooo`Coogl03oooool00ol00?ooooooooooo`0<ooooo`_oo`3o1?oo
O`0Dooooo`;o003oD_ooool1o`00007ooooo00000ol0003oooooooooo`23ooooo`;oogl03oooool0
0ol00?ooooooooooo`0=ooooo`_oo`3o1?ooO`0Aooooo`?o003oE?ooool1o`00007ooooo00000ol0
003oooooooooo`2Dooooo`03o`00oooooooooooo00gooooo2ooo0?l00oooooooogl0oomo000@oooo
o`;o003oEoooool1o`00007ooooo00000ol0003oooooooooo`2Dooooo`03o`00oooooooooooo00go
oooo2ooo0?lBooooo`03o`00oooooooooooo05Oooooo0Ol00001ooooo`0000?o0000ooooooooool0
U?ooool00ol00?ooooooooooo`0=ooooo`_oo`3o4?ooool2o`00oe[ooooo0Ol00001ooooo`0000?o
0000ooooooooool0U?ooool00ol00?ooooooooooo`0>ooooo`Woo`3o3oooool2o`00oecooooo0Ol0
0001ooooo`0000?o0000ooooooooool0UOooool00ol00?ooooooooooo`0>ooooo`Ooo`3o3oooool0
0ol00?ooooooooooo`1Looooo`7o00000Oooool00003o`000?oooooooooo09Gooooo00?o003ooooo
ooooool03oooool5ool0o`kooooo0_l00?mOooooo`7o00000Oooool00003o`000?oooooooooo09Go
oooo00?o003oooooooooool08?ooool2o`00of7ooooo0Ol00001ooooo`0000?o0000ooooooooool0
Q?ooool2oomo00oooooo0_l00?lOooooo`;o003oHoooool1o`00007ooooo00000ol0003ooooooooo
o`23ooooo`Coogl04?ooool2o`00oa[ooooo0ol00?mUooooo`7o00000Oooool00003o`000?oooooo
oooo08?ooooo1?ooO`0Booooo`;o003o5?ooool4o`00ofSooooo0Ol00001ooooo`0000?o0000oooo
ooooool0Q?ooool2oomo01Gooooo0ol00?l>ooooo`?o003o0oooool2oomo06Oooooo0Ol00001oooo
o`0000?o0000ooooooooool0W_ooool3o`00o`Gooooo1_l00?l5ooooo`Coogl0I_ooool1o`00007o
oooo00000ol0003oooooooooo`2Qooooo`Go003o2oooool4oomo06Kooooo0Ol00001ooooo`0000?o
0000ooooooooool0/_ooool2oomo06Oooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolL
ooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003o
ooooooooo`1kooooo`;oogl0W_ooool1o`00007ooooo00000ol0003oooooooooo`1jooooo`Coogl0
WOooool1o`00007ooooo00000ol0003oooooooooo`1jooooo`Coogl08?ooool2oomo07_ooooo0Ol0
0001ooooo`0000?o0000ooooooooool0Noooool2oomo023ooooo1?ooO`1jooooo`7o00000Oooool0
0003o`000?oooooooooo09gooooo1?ooO`1jooooo`7o00000Oooool00003o`000?oooooooooo093o
oooo0_ooO`0<ooooo`;oogl0Noooool1o`00007ooooo00000ol0003oooooooooo`2?ooooo`Coogl0
R?ooool1o`00007ooooo00000ol0003oooooooooo`2?ooooo`Coogl0R?ooool1o`00007ooooo0000
0ol0003oooooooooo`2@ooooo`;oogl08oooool2oomo06Cooooo0Ol00001ooooo`0000?o0000oooo
ooooool0]?ooool4oomo06?ooooo0Ol00001ooooo`0000?o0000ooooooooool0]?ooool4oomo06?o
oooo0Ol00001ooooo`0000?o0000ooooooooool0]Oooool2oomo06Cooooo0Ol00001ooooo`0000?o
0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1
o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000oooooooo
ool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo
00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolL
ooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003o
ooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o0000
0Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3o
oooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003
o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo
0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oooooo
oooo0?oooooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001oooo
o`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo
7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000
ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00
007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0
oooooolLooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo0000
0ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLoooo
o`7o00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003ooooo
ooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Ooo
ool00003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooo
oacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`00
0?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol0
0001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo
08kooooo0_ooO`2;ooooo`7o00000Oooool00003o`000?oooooooooo08gooooo1?ooO`2:ooooo`7o
00000Oooool00003o`000?oooooooooo08gooooo1?ooO`2:ooooo`7o00000Oooool00003o`000?oo
oooooooo08kooooo0_ooO`2;ooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1
o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000oooooooo
ool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo
00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolL
ooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003o
ooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o0000
0Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3o
oooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003
o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo
0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oooooo
oooo0?oooooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001oooo
o`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo
7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000
ooooooooool0oooooolLooooo`7o00000Oooool00?oo00008?l00001ooooo`00\
\>"],
  ImageRangeCache->{{{0, 287}, {287, 0}} -> {-1.01089, -1.01089, 0.00704453, \
0.00704453}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.49505 0.5 0.49505 [
[ 0 0 -0.125 0 ]
[ 0 0 -0.125 0 ]
[ 0 1 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
0 0 m
1 0 L
s
0 0 m
0 1 L
s
0 1 m
1 1 L
s
1 0 m
1 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
1 .5 0 r
.015 w
.03175 .1355 Mdot
.03435 .12523 Mdot
.11137 .12765 Mdot
.14107 .18841 Mdot
.16218 .24538 Mdot
.17294 .21053 Mdot
.18267 .18577 Mdot
.18434 .1304 Mdot
.18553 .30956 Mdot
.20401 .239 Mdot
.21247 .27571 Mdot
.21687 .20845 Mdot
.22376 .2799 Mdot
.22832 .27485 Mdot
.29063 .20974 Mdot
.29686 .25079 Mdot
.30487 .22936 Mdot
.30683 .34623 Mdot
.32055 .20902 Mdot
.32574 .21979 Mdot
.34472 .28521 Mdot
.35998 .36393 Mdot
.36335 .24976 Mdot
.3794 .36608 Mdot
.42386 .66992 Mdot
.44391 .74519 Mdot
.45059 .34198 Mdot
.47208 .67586 Mdot
.47436 .71381 Mdot
.49778 .59825 Mdot
.50874 .91643 Mdot
.51516 .76219 Mdot
.53655 .61374 Mdot
.56563 .75219 Mdot
.59189 .65665 Mdot
.59581 .61604 Mdot
.59923 .6556 Mdot
.60292 .68499 Mdot
.62656 .67779 Mdot
.63555 .72451 Mdot
.63919 .652 Mdot
.64169 .6004 Mdot
.64246 .58611 Mdot
.64496 .54267 Mdot
.64608 .77288 Mdot
.65077 .64308 Mdot
.66065 .57816 Mdot
.67474 .59169 Mdot
.69296 .563 Mdot
.72815 .65902 Mdot
.73169 .58879 Mdot
.74669 .61318 Mdot
.74821 .65474 Mdot
.75963 .63781 Mdot
.79673 .57809 Mdot
.80925 .55852 Mdot
.81525 .58444 Mdot
.83417 .62985 Mdot
.83598 .55526 Mdot
.91595 .49319 Mdot
1 0 0 r
.005 w
.16128 .17044 m
.18734 .17269 L
.21339 .17909 L
.2345 .18734 L
.23945 .19126 L
.2655 .20415 L
.27874 .21339 L
.29156 .22295 L
.31204 .23945 L
.31761 .24532 L
.33549 .2655 L
.34367 .28341 L
.34499 .29156 L
.34367 .29798 L
.31761 .3104 L
.29156 .30711 L
.2655 .30014 L
.24507 .29156 L
.23945 .28747 L
.21339 .27402 L
.20155 .2655 L
.18734 .25472 L
.16884 .23945 L
.16128 .2313 L
.14618 .21339 L
.13806 .18734 L
.16128 .17044 L
s
0 0 1 r
.65633 .57701 m
.68239 .56842 L
.70844 .56313 L
.7345 .56168 L
.76055 .5752 L
.76359 .57817 L
.76859 .60422 L
.76055 .62333 L
.75627 .63028 L
.7345 .65485 L
.73298 .65633 L
.70844 .6775 L
.69922 .68239 L
.68239 .69294 L
.65633 .70579 L
.64983 .70844 L
.63028 .71539 L
.60422 .72268 L
.57817 .72651 L
.55211 .7214 L
.53145 .70844 L
.52926 .68239 L
.54239 .65633 L
.55211 .63983 L
.56625 .63028 L
.57817 .6193 L
.60119 .60422 L
.60422 .60227 L
.63028 .58726 L
.65315 .57817 L
.65633 .57701 L
s
1 0 0 r
.03 w
.24141 .24033 Mdot
0 0 1 r
.64872 .64417 Mdot
1 0 0 r
.79703 .00495 m
.79703 .00495 L
.87129 .00495 L
.87129 .00495 L
F
0 0 1 r
.89604 .00495 m
.89604 .25248 L
.9703 .25248 L
.9703 .00495 L
F
1 0 1 r
.04 w
.62656 .67779 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P000182000`400?l00000o`00003ooooooolQ
ooooo`00ool0000Po`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`00
00?o0000ooooooooool0o_oooolEo`00o`Sooooo0Ol00001ooooo`0000?o0000ooooooooool0o_oo
oolEo`00o`Sooooo0Ol00001ooooo`0000?o0000ooooooooool0o_oooolEo`00o`Sooooo0Ol00001
ooooo`0000?o0000ooooooooool0o_oooolEo`00o`Sooooo0Ol00001ooooo`0000?o0000oooooooo
ool0o_oooolEo`00o`Sooooo0Ol00001ooooo`0000?o0000ooooooooool0o_oooolEo`00o`Sooooo
0Ol00001ooooo`0000?o0000ooooooooool0o_oooolEo`00o`Sooooo0Ol00001ooooo`0000?o0000
ooooooooool0o_oooolEo`00o`Sooooo0Ol00001ooooo`0000?o0000ooooooooool0o_oooolEo`00
o`Sooooo0Ol00001ooooo`0000?o0000ooooooooool0o_oooolEo`00o`Sooooo0Ol00001ooooo`00
00?o0000ooooooooool0o_oooolEo`00o`Sooooo0Ol00001ooooo`0000?o0000ooooooooool0o_oo
oolEo`00o`Sooooo0Ol00001ooooo`0000?o0000ooooooooool0o_oooolEo`00o`Sooooo0Ol00001
ooooo`0000?o0000ooooooooool0o_oooolEo`00o`Sooooo0Ol00001ooooo`0000?o0000oooooooo
ool0o_oooolEo`00o`Sooooo0Ol00001ooooo`0000?o0000ooooooooool0o_oooolEo`00o`Sooooo
0Ol00001ooooo`0000?o0000ooooooooool0o_oooolEo`00o`Sooooo0Ol00001ooooo`0000?o0000
ooooooooool0o_oooolEo`00o`Sooooo0Ol00001ooooo`0000?o0000ooooooooool0o_oooolEo`00
o`Sooooo0Ol00001ooooo`0000?o0000ooooooooool0o_oooolEo`00o`Sooooo0Ol00001ooooo`00
00?o0000ooooooooool0o_oooolEo`00o`Sooooo0Ol00001ooooo`0000?o0000ooooooooool0o_oo
oolEo`00o`Sooooo0Ol00001ooooo`0000?o0000ooooooooool0o_oooolEo`00o`Sooooo0Ol00001
ooooo`0000?o0000ooooooooool0o_oooolEo`00o`Sooooo0Ol00001ooooo`0000?o0000oooooooo
ool0o_oooolEo`00o`Sooooo0Ol00001ooooo`0000?o0000ooooooooool0o_oooolEo`00o`Sooooo
0Ol00001ooooo`0000?o0000ooooooooool0o_oooolEo`00o`Sooooo0Ol00001ooooo`0000?o0000
ooooooooool0o_oooolEo`00o`Sooooo0Ol00001ooooo`0000?o0000ooooooooool0o_oooolEo`00
o`Sooooo0Ol00001ooooo`0000?o0000ooooooooool0o_oooolEo`00o`Sooooo0Ol00001ooooo`00
00?o0000ooooooooool0o_oooolEo`00o`Sooooo0Ol00001ooooo`0000?o0000ooooooooool0o_oo
oolEo`00o`Sooooo0Ol00001ooooo`0000?o0000ooooooooool01_ooool2oomo0?Kooooo5Ol00?l8
ooooo`7o00000Oooool00003o`000?oooooooooo00Gooooo1?ooO`0Cooooo`;oogl0h?oooolEo`00
o`Sooooo0Ol00001ooooo`0000?o0000ooooooooool01Oooool4oomo01;ooooo1?ooO`0Booooo`;o
ogl0booooolEo`00o`Sooooo0Ol00001ooooo`0000?o0000ooooooooool01Oooool3oomo01?ooooo
1?ooO`0Aooooo`Coogl0b_oooolEo`00o`Sooooo0Ol00001ooooo`0000?o0000ooooooooool01?oo
ool4oomo01Cooooo0_ooO`0Booooo`Coogl0b_oooolEo`00o`Sooooo0Ol00001ooooo`0000?o0000
ooooooooool01?ooool4oomo02Wooooo0_ooO`3;oooooaGo003o2?ooool1o`00007ooooo00000ol0
003oooooooooo`05ooooo`;oogl0mooooolEo`00o`Sooooo0Ol00001ooooo`0000?o0000oooooooo
ool0o_oooolEo`00o`Sooooo0Ol00001ooooo`0000?o0000ooooooooool0o_oooolEo`00o`Sooooo
0Ol00001ooooo`0000?o0000ooooooooool0o_oooolEo`00o`Sooooo0Ol00001ooooo`0000?o0000
ooooooooool0o_oooolEo`00o`Sooooo0Ol00001ooooo`0000?o0000ooooooooool0o_oooolEo`00
o`Sooooo0Ol00001ooooo`0000?o0000ooooooooool0o_oooolEo`00o`Sooooo0Ol00001ooooo`00
00?o0000ooooooooool0o_oooolEo`00o`Sooooo0Ol00001ooooo`0000?o0000ooooooooool0:_oo
ool6ool00<kooooo5Ol00?l8ooooo`7o00000Oooool00003o`000?oooooooooo02Wooooo00?oo`00
ooooooooool01?ooool5ool00<Wooooo5Ol00?l8ooooo`7o00000Oooool00003o`000?oooooooooo
02Oooooo0_oo000<ooooo`Coo`00aOoooolEo`00o`Sooooo0Ol00001ooooo`0000?o0000oooooooo
ool09_ooool00ooo003oooooooooo`0@ooooo`Coo`00`OoooolEo`00o`Sooooo0Ol00001ooooo`00
00?o0000ooooooooool09?ooool00oooO`3oo`00ooooo`09ooooo`;oogl02oooool3ool00;kooooo
5Ol00?l8ooooo`7o00000Oooool00003o`000?oooooooooo02?ooooo00Coogl0ool00?ooO`3oogl0
2?ooool4oomo00gooooo00?oo`00ooooooooool0^ooooolEo`00o`Sooooo0Ol00001ooooo`0000?o
0000ooooooooool08oooool01?ooO`3oo`00oomo0?ooO`08ooooo`Coogl03_ooool2ool00;_ooooo
5Ol00?l8ooooo`7o00000Oooool00003o`000?oooooooooo02Cooooo00?oogl0ool00?ooool02Ooo
ool2oomo017ooooo0_oo002ioooooaGo003o2?ooool1o`00007ooooo00000ol0003oooooooooo`0U
ooooo`03ool00?oooooooooo01gooooo0_oo002goooooaGo003o2?ooool1o`00007ooooo00000ol0
003oooooooooo`0Uooooo`03ool00?oooooooooo01oooooo0_oo002eoooooaGo003o2?ooool1o`00
007ooooo00000ol0003oooooooooo`0Vooooo`03ool00?oooooooooo017ooooo0_ooO`0=ooooo`;o
o`001?ooool2oomo00Oooooo0_ooO`2ToooooaGo003o2?ooool1o`00007ooooo00000ol0003ooooo
ooooo`0Vooooo`03ool00?oooooooooo00Gooooo0_ooO`09ooooo`Coogl03_ooool00ooo003ooooo
ooooo`04oomo00Gooooo1?ooO`2SoooooaGo003o2?ooool1o`00007ooooo00000ol0003ooooooooo
o`0Vooooo`03ool00?oooooooooo00Cooooo1?ooO`08ooooo`Coogl03oooool00ooo003ooooooomo
0003oomo00Gooooo1?ooO`2SoooooaGo003o2?ooool1o`00007ooooo00000ol0003oooooooooo`0W
ooooo`03ool00?oooooooooo00?ooooo1?ooO`09ooooo`;oogl04Oooool01?oo003ooooooomo0?oo
O`07ooooo`?oogl0XooooolEo`00o`Sooooo0Ol00001ooooo`0000?o0000ooooooooool09oooool0
0ooo003oooooooooo`04ooooo`;oogl07_ooool00ooo003oooooooooo`07ooooo`Coogl0X_oooolE
o`00o`Sooooo0Ol00001ooooo`0000?o0000ooooooooool0:?ooool00ooo003oooooooooo`0Toooo
o`03ool00?oooooooooo00Kooooo1?ooO`2RoooooaGo003o2?ooool1o`00007ooooo00000ol0003o
ooooooooo`0Yooooo`03ool00?oooooooooo02Cooooo0_oo00000oooooooogl0oomo0004ooooo`;o
ogl0XooooolEo`00o`Sooooo0Ol00001ooooo`0000?o0000ooooooooool0:_ooool00ooo003ooooo
ooooo`0Cooooo`Coo`003_ooool01?oo003oogl0oomo0?ooO`2XoooooaGo003o2?ooool1o`00007o
oooo00000ol0003oooooooooo`0[ooooo`03ool00?oooooooooo017ooooo1_oo000=ooooo`04oomo
0?oo003oo`00oomo0:Sooooo5Ol00?l8ooooo`7o00000Oooool00003o`000?oooooooooo02cooooo
00?oo`00ooooooooool02?ooool2oomo00Gooooo2?oo000=ooooo`;oogl000?oo`00ooooooooool0
Y_oooolEo`00o`Sooooo0Ol00001ooooo`0000?o0000ooooooooool0;Oooool00ooo003ooooooooo
o`06ooooo`Coogl01?ooool8ool0013ooooo00?oo`00ooooooooool0YOoooolEo`00o`Sooooo0Ol0
0001ooooo`0000?o0000ooooooooool0:oooool2oomo0003oooooooo003ooooo00Kooooo1?ooO`04
ooooo`Soo`004Oooool00ooo003oooooooooo`2ToooooaGo003o2?ooool1o`00007ooooo00000ol0
003oooooooooo`0Zooooo`Coogl000?oooooool00?ooool01_ooool2oomo00Gooooo2?oo000;oooo
o`;oogl01Oooool00ooo003oooooooooo`09ooooo`;oogl0V?oooolEo`00o`Sooooo0Ol00001oooo
o`0000?o0000ooooooooool0:_ooool4oomo00;ooooo00?oo`00ooooooooool03?ooool6ool000_o
oooo1?ooO`04ooooo`03ool00?oooooooooo00Sooooo1?ooO`2GoooooaGo003o2?ooool1o`00007o
oooo00000ol0003oooooooooo`0[ooooo`;oogl01?ooool00ooo003oooooooooo`0<ooooo`Coo`00
3?ooool4oomo00Gooooo00?oo`00ooooooooool01oooool4oomo09Oooooo5Ol00?l8ooooo`7o0000
0Oooool00003o`000?oooooooooo03;ooooo0_oo000Mooooo`;oogl01oooool00ooo003ooooooooo
o`07ooooo`;oogl0]Oooool1o`00007ooooo00000ol0003oooooooooo`0dooooo`03ool00?oooooo
oooo02Cooooo00?oo`00ooooooooool0_Oooool1o`00007ooooo00000ol0003oooooooooo`0eoooo
o`03ool00?oooooooooo02Cooooo00?oo`00ooooooooool0_?ooool1o`00007ooooo00000ol0003o
ooooooooo`0fooooo`;oo`009Oooool00ooo003oooooooooo`2kooooo`7o00000Oooool00003o`00
0?oooooooooo03Sooooo0_oo00000oooO`3oooooooooo`02oomo01kooooo00?oo`00ooooooooool0
^oooool1o`00007ooooo00000ol0003oooooooooo`0hooooo`;oogl00_oo0004oomo01kooooo00?o
o`00ooooooooool0^_ooool1o`00007ooooo00000ol0003oooooooooo`0hooooo`Coogl00_oo0002
oomo01kooooo00?oo`00ooooooooool0^_ooool1o`00007ooooo00000ol0003oooooooooo`0ioooo
o`Googl000?oo`00ooooooooool07Oooool00ooo003oogl0oomo002jooooo`7o00000Oooool00003
o`000?oooooooooo03_ooooo1?ooO`02ool001gooooo00Coogl0ool00?ooO`3oogl0^Oooool1o`00
007ooooo00000ol0003oooooooooo`0looooo`;oogl00oooool2ool001_ooooo00Coogl0ool00?oo
O`3oogl0^Oooool1o`00007ooooo00000ol0003oooooooooo`13ooooo`;oo`006_ooool00oooO`3o
o`00ooooo`2iooooo`7o00000Oooool00003o`000?oooooooooo04Gooooo0_oo000Iooooo`03ool0
0?oooooooooo0;Sooooo0Ol00001ooooo`0000?o0000ooooooooool0Aoooool2ool001Gooooo0_oo
002kooooo`7o00000Oooool00003o`000?oooooooooo04Wooooo0ooo000@ooooo`;oo`00_Oooool1
o`00007ooooo00000ol0003oooooooooo`0aooooo`;oogl06Oooool3ool000cooooo00?oo`00oooo
ooooool0_Oooool1o`00007ooooo00000ol0003oooooooooo`0`ooooo`Coogl06oooool6ool000Co
oooo0_oo0030ooooo`7o00000Oooool00003o`000?oooooooooo033ooooo1?ooO`0Qooooo`Coo`00
`_ooool1o`00007ooooo00000ol0003oooooooooo`0aooooo`;oogl0j?ooool1o`00007ooooo0000
0ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLoooo
o`7o00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003ooooo
ooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Ooo
ool00003o`000?oooooooooo07gooooo0_ooO`2Looooo`7o00000Oooool00003o`000?oooooooooo
07cooooo1?ooO`2Kooooo`7o00000Oooool00003o`000?oooooooooo05Cooooo0_ooO`0Vooooo`Co
ogl0Voooool1o`00007ooooo00000ol0003oooooooooo`1Cooooo`Coogl09_ooool2oomo09cooooo
0Ol00001ooooo`0000?o0000ooooooooool0Doooool4oomo0<Cooooo0Ol00001ooooo`0000?o0000
ooooooooool0E?ooool2oomo0<Gooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLoooo
o`7o00000Oooool00003o`000?oooooooooo06?ooooo0_ooO`04ooooo`;oogl0/?ooool1o`00007o
oooo00000ol0003oooooooooo`1Rooooo`Coogl00_ooool4oomo0:oooooo0Ol00001ooooo`0000?o
0000ooooooooool0H_ooool4oomo00;ooooo1?ooO`2_ooooo`7o00000Oooool00003o`000?oooooo
oooo06?ooooo0_ooO`04ooooo`;oogl0/?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooo
oacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`00
0?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol0
0001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo
0?oooooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`00
00?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?oo
ool1o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000oooo
ooooool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007o
oooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooo
oolLooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0
003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o
00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003ooooooooo
o`3ooooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool0
0003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooooaco
oooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oo
oooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001
ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo0?oo
oooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o
0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1
o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000oooooooo
ool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo
00000ol0003oooooooooo`3oooooo`Cooooo0_ooO`0Fooooo`7o00000Oooool00003o`000?oooooo
oooo0?oooooo0oooool4oomo01Gooooo0Ol00001ooooo`0000?o0000ooooooooool0ooooool3oooo
o`Coogl05Oooool1o`00007ooooo00000ol0003oooooooooo`3oooooo`Cooooo0_ooO`0Fooooo`7o
00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003ooooooooo
o`3ooooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool0
0003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooooaco
oooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oo
oooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001
ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo0?oo
oooo7?ooool1o`00007ooooo00000ol0003oooooooooo`2eooooo`;oogl0I?ooool1o`00007ooooo
00000ol0003oooooooooo`2dooooo`Coogl0Hoooool1o`00007ooooo00000ol0003oooooooooo`2d
ooooo`Coogl0Hoooool1o`00007ooooo00000ol0003oooooooooo`2eooooo`;oogl0=Oooool2oomo
02gooooo0Ol00001ooooo`0000?o0000ooooooooool0i?ooool2oomo00Gooooo1?ooO`0/ooooo`7o
00000Oooool00003o`000?oooooooooo0>?ooooo1?ooO`04ooooo`Coogl0;?ooool1o`00007ooooo
00000ol0003oooooooooo`33ooooo`;oogl07_ooool4oomo00Gooooo0_ooO`0]ooooo`7o00000Ooo
ool00003o`000?oooooooooo0<;ooooo1?ooO`0;o`00oa?ooooo0_ooO`0eooooo`7o00000Oooool0
0003o`000?oooooooooo0<;ooooo1?l00?l;ooooo`;o003oB?ooool1o`00007ooooo00000ol0003o
ooooooooo`2nooooo`Co003o00?ooooooomo0?ooO`003_ooool2o`00odKooooo0Ol00001ooooo`00
00?o0000ooooooooool0^Oooool2oomo00?o003o5oooool2o`00o`Wooooo0_ooO`0iooooo`7o0000
0Oooool00003o`000?oooooooooo0;Oooooo1?l00?l00oooO`3oooooooooo`0Iooooo`;o003o1_oo
ool4oomo03Sooooo0Ol00001ooooo`0000?o0000ooooooooool0]?ooool3o`00o`03ooooooooO`3o
ogl000;oogl07?ooool00ol00?ooooooooooo`04ooooo`Coogl00oooool2oomo03?ooooo0Ol00001
ooooo`0000?o0000ooooooooool0/_ooool2o`00o`?oogl00_ooool2oomo01?ooooo0_ooO`08oooo
o`03o`00oooooooooooo00Gooooo0_ooO`03ooooo`Coogl0<_ooool1o`00007ooooo00000ol0003o
ooooooooo`2`ooooo`;o003o00?ooooooomo0?ooO`000_ooO`06ooooo`;oogl03_ooool4oomo00Oo
oooo00?o003oooooooooool02_ooool4oomo03;ooooo0Ol00001ooooo`0000?o0000ooooooooool0
[_ooool2o`00o`Cooooo0_ooO`06ooooo`Coogl03Oooool4oomo00Oooooo00?o003oooooooooool0
2oooool2oomo03?ooooo0Ol00001ooooo`0000?o0000ooooooooool0Roooool2oomo023ooooo00?o
003oooooooooool01?ooool2oomo00Kooooo1?ooO`0>ooooo`;oogl02Oooool00ol00?oooooooooo
o`0oooooo`7o00000Oooool00003o`000?oooooooooo08[ooooo1?ooO`0Mooooo`;o003o1_ooool4
oomo00Kooooo0_ooO`0Jooooo`03o`00oooooooooooo03oooooo0Ol00001ooooo`0000?o0000oooo
ooooool0R_ooool4oomo01cooooo00?o003oooooooooool01_ooool4oomo02;ooooo00?o003ooooo
ooooool0?oooool1o`00007ooooo00000ol0003oooooooooo`2;ooooo`;oogl06oooool2o`00o`[o
oooo0_ooO`0Sooooo`03o`00oooooooooooo03oooooo0Ol00001ooooo`0000?o0000ooooooooool0
U_ooool2oomo00kooooo0_l00?lZooooo`;oogl01Oooool00ol00?ooooooooooo`0oooooo`7o0000
0Oooool00003o`000?oooooooooo09Gooooo1?ooO`0<ooooo`04o`00ooooooooogl0oomo02Sooooo
1?ooO`03ooooo`03o`00oooooooooooo043ooooo0Ol00001ooooo`0000?o0000ooooooooool0UOoo
ool4oomo00[ooooo0_l00?l00oooooooogl0oomo0002oomo02Oooooo1?ooO`03ooooo`03o`00oooo
oooooooo043ooooo0Ol00001ooooo`0000?o0000ooooooooool0U_ooool2oomo00[ooooo00Co003o
oooooooooooooooo1?ooO`0Xooooo`;oogl01?ooool00ol00?ooooooooooo`10ooooo`7o00000Ooo
ool00003o`000?oooooooooo0:7ooooo00?o003oooooooooool00oooool2oomo02kooooo00?o003o
ooooooooool0@Oooool1o`00007ooooo00000ol0003oooooooooo`2Pooooo`03o`00oooooooooooo
03?ooooo00?o003oooooooooool04_ooool2oomo02kooooo0Ol00001ooooo`0000?o0000oooooooo
ool0W_ooool2o`00ocGooooo00?o003oooooooooool04_ooool4oomo02gooooo0Ol00001ooooo`00
00?o0000ooooooooool0WOooool00ol00?ooooooooooo`0Eooooo`Co003o7?ooool00ol00?ooogl0
oomo000Booooo`Coogl0;Oooool1o`00007ooooo00000ol0003oooooooooo`2Looooo`03o`00oooo
oooooooo01Gooooo1_l00?lJooooo`03o`00ooooO`3oogl000;oogl04_ooool2oomo02kooooo0Ol0
0001ooooo`0000?o0000ooooooooool0Voooool00ol00?ooooooooooo`0Eooooo`So003o6?ooool0
0ol00?oooooooomo0003oomo04;ooooo0Ol00001ooooo`0000?o0000ooooooooool0Voooool00ol0
0?ooooooooooo`0Eooooo`So003o5oooool01?l00?ooooooooooooooool2oomo04?ooooo0Ol00001
ooooo`0000?o0000ooooooooool0V_ooool00ol00?ooooooooooo`0Fooooo`So003o5_ooool00ol0
0?ooooooooooo`17ooooo`7o00000Oooool00003o`000?oooooooooo09Wooooo00?o003ooooooooo
ool03?ooool2oomo00Sooooo00?oogl0o`00ool00?l01_l00?lEooooo`03o`00oooooooooooo00;o
ogl0A_ooool1o`00007ooooo00000ol0003oooooooooo`2Iooooo`03o`00oooooooooooo00[ooooo
1OooO`07ooooo`;oogl01_l00?lCooooo`;oogl000?o003oooooooooool01?ooO`15ooooo`7o0000
0Oooool00003o`000?oooooooooo09Sooooo00?o003oooooooooool02_ooool6oomo00Sooooo0_oo
O`04o`00oa?ooooo0_ooO`02o`00o`;ooooo1?ooO`15ooooo`7o00000Oooool00003o`000?oooooo
oooo09Sooooo00?o003oooooooooool02_ooool5oomo00Cooooo1Ooo0?lIooooo`04oomo0?l00?oo
ogl0oomo00?ooooo0_ooO`16ooooo`7o00000Oooool00003o`000?oooooooooo07Kooooo0_ooO`0O
ooooo`03o`00oooooooooooo00cooooo0_ooO`05ooooo`Ooo`3o6?ooool00ol00?ooogl0oomo001<
ooooo`7o00000Oooool00003o`000?oooooooooo07Gooooo1?ooO`0Nooooo`03o`00oooooooooooo
01;ooooo2Ooo0?lFooooo`03o`00oooooooooooo04gooooo0Ol00001ooooo`0000?o0000oooooooo
ool0MOooool4oomo00[ooooo0_ooO`0Aooooo`03o`00oooooooooooo01;ooooo2ooo0?lDooooo`03
o`00oooooooooooo04kooooo0Ol00001ooooo`0000?o0000ooooooooool0M_ooool2oomo00[ooooo
1?ooO`0?ooooo`03o`00oooooooooooo01?ooooo2ooo0?lCooooo`03o`00oooooooooooo04oooooo
0Ol00001ooooo`0000?o0000ooooooooool0P_ooool4oomo00oooooo00?o003oooooooooool04ooo
ool;ool0oa7ooooo0_l00?mBooooo`7o00000Oooool00003o`000?oooooooooo08?ooooo0_ooO`0?
ooooo`03o`00oooooooooooo01;ooooo0_ooO`0;ool0o`kooooo0ol00?mDooooo`7o00000Oooool0
0003o`000?oooooooooo09Cooooo00?o003oooooooooool04Oooool3oomo00_oo`3o3?ooool2o`00
oeOooooo0Ol00001ooooo`0000?o0000ooooooooool0U?ooool00ol00?ooooooooooo`0Aooooo`Co
ogl02Ooo0?l<ooooo`03o`00oooooooooooo05Oooooo0Ol00001ooooo`0000?o0000ooooooooool0
U?ooool00ol00?ooooooooooo`0Booooo`;oogl00_ooool7ool0o`_ooooo0_l00?mJooooo`7o0000
0Oooool00003o`000?oooooooooo09Cooooo00?o003oooooooooool05oooool5ool0o`[ooooo0_l0
0?mLooooo`7o00000Oooool00003o`000?oooooooooo09Gooooo00?o003oooooooooool09?ooool0
0ol00?ooooooooooo`1Looooo`7o00000Oooool00003o`000?oooooooooo09Gooooo00?o003ooooo
ooooool08_ooool2o`00oeoooooo0Ol00001ooooo`0000?o0000ooooooooool0UOooool00ol00?oo
ooooooooo`0Pooooo`;o003oHOooool1o`00007ooooo00000ol0003oooooooooo`24ooooo`;oogl0
3oooool2o`00oaoooooo0_l00?mSooooo`7o00000Oooool00003o`000?oooooooooo08?ooooo1?oo
O`0@ooooo`;o003o6_ooool3o`00ofGooooo0Ol00001ooooo`0000?o0000ooooooooool0Poooool4
oomo01;ooooo0_l00?lDooooo`Co003oJ?ooool1o`00007ooooo00000ol0003oooooooooo`24oooo
o`;oogl05Oooool3o`00o`kooooo0ol00?l3ooooo`;oogl0Ioooool1o`00007ooooo00000ol0003o
ooooooooo`2Nooooo`?o003o1Oooool6o`00o`Gooooo1?ooO`1Vooooo`7o00000Oooool00003o`00
0?oooooooooo0:7ooooo1Ol00?l;ooooo`Coogl0I_ooool1o`00007ooooo00000ol0003ooooooooo
o`2booooo`;oogl0Ioooool1o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001
ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo07_o
oooo0_ooO`2Nooooo`7o00000Oooool00003o`000?oooooooooo07[ooooo1?ooO`2Mooooo`7o0000
0Oooool00003o`000?oooooooooo07[ooooo1?ooO`0Pooooo`;oogl0Noooool1o`00007ooooo0000
0ol0003oooooooooo`1kooooo`;oogl08?ooool4oomo07[ooooo0Ol00001ooooo`0000?o0000oooo
ooooool0WOooool4oomo07[ooooo0Ol00001ooooo`0000?o0000ooooooooool0T?ooool2oomo00co
oooo0_ooO`1kooooo`7o00000Oooool00003o`000?oooooooooo08oooooo1?ooO`28ooooo`7o0000
0Oooool00003o`000?oooooooooo08oooooo1?ooO`28ooooo`7o00000Oooool00003o`000?oooooo
oooo093ooooo0_ooO`0Sooooo`;oogl0I?ooool1o`00007ooooo00000ol0003oooooooooo`2doooo
o`Coogl0Hoooool1o`00007ooooo00000ol0003oooooooooo`2dooooo`Coogl0Hoooool1o`00007o
oooo00000ol0003oooooooooo`2eooooo`;oogl0I?ooool1o`00007ooooo00000ol0003ooooooooo
o`3ooooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool0
0003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooooaco
oooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oo
oooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001
ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo0?oo
oooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o
0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1
o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000oooooooo
ool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo
00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolL
ooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003o
ooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o0000
0Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3o
oooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003
o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo
0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oooooo
oooo0?oooooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001oooo
o`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo
7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000
ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00
007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0
oooooolLooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo0000
0ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0S_ooool2oomo
08_ooooo0Ol00001ooooo`0000?o0000ooooooooool0SOooool4oomo08[ooooo0Ol00001ooooo`00
00?o0000ooooooooool0SOooool4oomo08[ooooo0Ol00001ooooo`0000?o0000ooooooooool0S_oo
ool2oomo08_ooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool0
0003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooooaco
oooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oo
oooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001
ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo0?oo
oooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o
0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1
o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000oooooooo
ool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo
00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolL
ooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003o
ooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o0000
0Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3o
oooooacooooo0Ol00001ooooo`00ool0000Po`00007ooooo0000\
\>"],
  ImageRangeCache->{{{0, 287}, {287, 0}} -> {-1.01089, -1.01089, 0.00704453, \
0.00704453}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.49505 0.5 0.49505 [
[ 0 0 -0.125 0 ]
[ 0 0 -0.125 0 ]
[ 0 1 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
0 0 m
1 0 L
s
0 0 m
0 1 L
s
0 1 m
1 1 L
s
1 0 m
1 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
1 .5 0 r
.015 w
.03175 .1355 Mdot
.03435 .12523 Mdot
.11137 .12765 Mdot
.14107 .18841 Mdot
.16218 .24538 Mdot
.17294 .21053 Mdot
.18267 .18577 Mdot
.18434 .1304 Mdot
.18553 .30956 Mdot
.20401 .239 Mdot
.21247 .27571 Mdot
.21687 .20845 Mdot
.22376 .2799 Mdot
.22832 .27485 Mdot
.29063 .20974 Mdot
.29686 .25079 Mdot
.30487 .22936 Mdot
.30683 .34623 Mdot
.32055 .20902 Mdot
.32574 .21979 Mdot
.34472 .28521 Mdot
.35998 .36393 Mdot
.36335 .24976 Mdot
.3794 .36608 Mdot
.42386 .66992 Mdot
.44391 .74519 Mdot
.45059 .34198 Mdot
.47208 .67586 Mdot
.47436 .71381 Mdot
.49778 .59825 Mdot
.50874 .91643 Mdot
.51516 .76219 Mdot
.53655 .61374 Mdot
.56563 .75219 Mdot
.59189 .65665 Mdot
.59581 .61604 Mdot
.59923 .6556 Mdot
.60292 .68499 Mdot
.62656 .67779 Mdot
.63555 .72451 Mdot
.63919 .652 Mdot
.64169 .6004 Mdot
.64246 .58611 Mdot
.64496 .54267 Mdot
.64608 .77288 Mdot
.65077 .64308 Mdot
.66065 .57816 Mdot
.67474 .59169 Mdot
.69296 .563 Mdot
.72815 .65902 Mdot
.73169 .58879 Mdot
.74669 .61318 Mdot
.74821 .65474 Mdot
.75963 .63781 Mdot
.79673 .57809 Mdot
.80925 .55852 Mdot
.81525 .58444 Mdot
.83417 .62985 Mdot
.83598 .55526 Mdot
.91595 .49319 Mdot
1 0 0 r
.005 w
.16128 .17044 m
.18734 .17269 L
.21339 .17909 L
.2345 .18734 L
.23945 .19126 L
.2655 .20415 L
.27874 .21339 L
.29156 .22295 L
.31204 .23945 L
.31761 .24532 L
.33549 .2655 L
.34367 .28341 L
.34499 .29156 L
.34367 .29798 L
.31761 .3104 L
.29156 .30711 L
.2655 .30014 L
.24507 .29156 L
.23945 .28747 L
.21339 .27402 L
.20155 .2655 L
.18734 .25472 L
.16884 .23945 L
.16128 .2313 L
.14618 .21339 L
.13806 .18734 L
.16128 .17044 L
s
0 0 1 r
.65633 .57701 m
.68239 .56842 L
.70844 .56313 L
.7345 .56168 L
.76055 .5752 L
.76359 .57817 L
.76859 .60422 L
.76055 .62333 L
.75627 .63028 L
.7345 .65485 L
.73298 .65633 L
.70844 .6775 L
.69922 .68239 L
.68239 .69294 L
.65633 .70579 L
.64983 .70844 L
.63028 .71539 L
.60422 .72268 L
.57817 .72651 L
.55211 .7214 L
.53145 .70844 L
.52926 .68239 L
.54239 .65633 L
.55211 .63983 L
.56625 .63028 L
.57817 .6193 L
.60119 .60422 L
.60422 .60227 L
.63028 .58726 L
.65315 .57817 L
.65633 .57701 L
s
1 0 0 r
.03 w
.24141 .24033 Mdot
0 0 1 r
.64872 .64417 Mdot
1 0 0 r
.79703 .00495 m
.79703 .00495 L
.87129 .00495 L
.87129 .00495 L
F
0 0 1 r
.89604 .00495 m
.89604 .25248 L
.9703 .25248 L
.9703 .00495 L
F
1 0 1 r
.04 w
.63555 .72451 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P000182000`400?l00000o`00003ooooooolQ
ooooo`00ool0000Po`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`00
00?o0000ooooooooool0o_oooolEo`00o`Sooooo0Ol00001ooooo`0000?o0000ooooooooool0o_oo
oolEo`00o`Sooooo0Ol00001ooooo`0000?o0000ooooooooool0o_oooolEo`00o`Sooooo0Ol00001
ooooo`0000?o0000ooooooooool0o_oooolEo`00o`Sooooo0Ol00001ooooo`0000?o0000oooooooo
ool0o_oooolEo`00o`Sooooo0Ol00001ooooo`0000?o0000ooooooooool0o_oooolEo`00o`Sooooo
0Ol00001ooooo`0000?o0000ooooooooool0o_oooolEo`00o`Sooooo0Ol00001ooooo`0000?o0000
ooooooooool0o_oooolEo`00o`Sooooo0Ol00001ooooo`0000?o0000ooooooooool0o_oooolEo`00
o`Sooooo0Ol00001ooooo`0000?o0000ooooooooool0o_oooolEo`00o`Sooooo0Ol00001ooooo`00
00?o0000ooooooooool0o_oooolEo`00o`Sooooo0Ol00001ooooo`0000?o0000ooooooooool0o_oo
oolEo`00o`Sooooo0Ol00001ooooo`0000?o0000ooooooooool0o_oooolEo`00o`Sooooo0Ol00001
ooooo`0000?o0000ooooooooool0o_oooolEo`00o`Sooooo0Ol00001ooooo`0000?o0000oooooooo
ool0o_oooolEo`00o`Sooooo0Ol00001ooooo`0000?o0000ooooooooool0o_oooolEo`00o`Sooooo
0Ol00001ooooo`0000?o0000ooooooooool0o_oooolEo`00o`Sooooo0Ol00001ooooo`0000?o0000
ooooooooool0o_oooolEo`00o`Sooooo0Ol00001ooooo`0000?o0000ooooooooool0o_oooolEo`00
o`Sooooo0Ol00001ooooo`0000?o0000ooooooooool0o_oooolEo`00o`Sooooo0Ol00001ooooo`00
00?o0000ooooooooool0o_oooolEo`00o`Sooooo0Ol00001ooooo`0000?o0000ooooooooool0o_oo
oolEo`00o`Sooooo0Ol00001ooooo`0000?o0000ooooooooool0o_oooolEo`00o`Sooooo0Ol00001
ooooo`0000?o0000ooooooooool0o_oooolEo`00o`Sooooo0Ol00001ooooo`0000?o0000oooooooo
ool0o_oooolEo`00o`Sooooo0Ol00001ooooo`0000?o0000ooooooooool0o_oooolEo`00o`Sooooo
0Ol00001ooooo`0000?o0000ooooooooool0o_oooolEo`00o`Sooooo0Ol00001ooooo`0000?o0000
ooooooooool0o_oooolEo`00o`Sooooo0Ol00001ooooo`0000?o0000ooooooooool0o_oooolEo`00
o`Sooooo0Ol00001ooooo`0000?o0000ooooooooool0o_oooolEo`00o`Sooooo0Ol00001ooooo`00
00?o0000ooooooooool0o_oooolEo`00o`Sooooo0Ol00001ooooo`0000?o0000ooooooooool0o_oo
oolEo`00o`Sooooo0Ol00001ooooo`0000?o0000ooooooooool01_ooool2oomo0?Kooooo5Ol00?l8
ooooo`7o00000Oooool00003o`000?oooooooooo00Gooooo1?ooO`0Cooooo`;oogl0h?oooolEo`00
o`Sooooo0Ol00001ooooo`0000?o0000ooooooooool01Oooool4oomo01;ooooo1?ooO`0Booooo`;o
ogl0booooolEo`00o`Sooooo0Ol00001ooooo`0000?o0000ooooooooool01Oooool3oomo01?ooooo
1?ooO`0Aooooo`Coogl0b_oooolEo`00o`Sooooo0Ol00001ooooo`0000?o0000ooooooooool01?oo
ool4oomo01Cooooo0_ooO`0Booooo`Coogl0b_oooolEo`00o`Sooooo0Ol00001ooooo`0000?o0000
ooooooooool01?ooool4oomo02Wooooo0_ooO`3;oooooaGo003o2?ooool1o`00007ooooo00000ol0
003oooooooooo`05ooooo`;oogl0mooooolEo`00o`Sooooo0Ol00001ooooo`0000?o0000oooooooo
ool0o_oooolEo`00o`Sooooo0Ol00001ooooo`0000?o0000ooooooooool0o_oooolEo`00o`Sooooo
0Ol00001ooooo`0000?o0000ooooooooool0o_oooolEo`00o`Sooooo0Ol00001ooooo`0000?o0000
ooooooooool0o_oooolEo`00o`Sooooo0Ol00001ooooo`0000?o0000ooooooooool0o_oooolEo`00
o`Sooooo0Ol00001ooooo`0000?o0000ooooooooool0o_oooolEo`00o`Sooooo0Ol00001ooooo`00
00?o0000ooooooooool0o_oooolEo`00o`Sooooo0Ol00001ooooo`0000?o0000ooooooooool0:_oo
ool6ool00<kooooo5Ol00?l8ooooo`7o00000Oooool00003o`000?oooooooooo02Wooooo00?oo`00
ooooooooool01?ooool5ool00<Wooooo5Ol00?l8ooooo`7o00000Oooool00003o`000?oooooooooo
02Oooooo0_oo000<ooooo`Coo`00aOoooolEo`00o`Sooooo0Ol00001ooooo`0000?o0000oooooooo
ool09_ooool00ooo003oooooooooo`0@ooooo`Coo`00`OoooolEo`00o`Sooooo0Ol00001ooooo`00
00?o0000ooooooooool09?ooool00oooO`3oo`00ooooo`09ooooo`;oogl02oooool3ool00;kooooo
5Ol00?l8ooooo`7o00000Oooool00003o`000?oooooooooo02?ooooo00Coogl0ool00?ooO`3oogl0
2?ooool4oomo00gooooo00?oo`00ooooooooool0^ooooolEo`00o`Sooooo0Ol00001ooooo`0000?o
0000ooooooooool08oooool01?ooO`3oo`00oomo0?ooO`08ooooo`Coogl03_ooool2ool00;_ooooo
5Ol00?l8ooooo`7o00000Oooool00003o`000?oooooooooo02Cooooo00?oogl0ool00?ooool02Ooo
ool2oomo017ooooo0_oo002ioooooaGo003o2?ooool1o`00007ooooo00000ol0003oooooooooo`0U
ooooo`03ool00?oooooooooo01gooooo0_oo002goooooaGo003o2?ooool1o`00007ooooo00000ol0
003oooooooooo`0Uooooo`03ool00?oooooooooo01oooooo0_oo002eoooooaGo003o2?ooool1o`00
007ooooo00000ol0003oooooooooo`0Vooooo`03ool00?oooooooooo017ooooo0_ooO`0=ooooo`;o
o`001?ooool2oomo00Oooooo0_ooO`2ToooooaGo003o2?ooool1o`00007ooooo00000ol0003ooooo
ooooo`0Vooooo`03ool00?oooooooooo00Gooooo0_ooO`09ooooo`Coogl03_ooool00ooo003ooooo
ooooo`04oomo00Gooooo1?ooO`2SoooooaGo003o2?ooool1o`00007ooooo00000ol0003ooooooooo
o`0Vooooo`03ool00?oooooooooo00Cooooo1?ooO`08ooooo`Coogl03oooool00ooo003ooooooomo
0003oomo00Gooooo1?ooO`2SoooooaGo003o2?ooool1o`00007ooooo00000ol0003oooooooooo`0W
ooooo`03ool00?oooooooooo00?ooooo1?ooO`09ooooo`;oogl04Oooool01?oo003ooooooomo0?oo
O`07ooooo`?oogl0XooooolEo`00o`Sooooo0Ol00001ooooo`0000?o0000ooooooooool09oooool0
0ooo003oooooooooo`04ooooo`;oogl07_ooool00ooo003oooooooooo`07ooooo`Coogl0X_oooolE
o`00o`Sooooo0Ol00001ooooo`0000?o0000ooooooooool0:?ooool00ooo003oooooooooo`0Toooo
o`03ool00?oooooooooo00Kooooo1?ooO`2RoooooaGo003o2?ooool1o`00007ooooo00000ol0003o
ooooooooo`0Yooooo`03ool00?oooooooooo02Cooooo0_oo00000oooooooogl0oomo0004ooooo`;o
ogl0XooooolEo`00o`Sooooo0Ol00001ooooo`0000?o0000ooooooooool0:_ooool00ooo003ooooo
ooooo`0Cooooo`Coo`003_ooool01?oo003oogl0oomo0?ooO`2XoooooaGo003o2?ooool1o`00007o
oooo00000ol0003oooooooooo`0[ooooo`03ool00?oooooooooo017ooooo1_oo000=ooooo`04oomo
0?oo003oo`00oomo0:Sooooo5Ol00?l8ooooo`7o00000Oooool00003o`000?oooooooooo02cooooo
00?oo`00ooooooooool02?ooool2oomo00Gooooo2?oo000=ooooo`;oogl000?oo`00ooooooooool0
Y_oooolEo`00o`Sooooo0Ol00001ooooo`0000?o0000ooooooooool0;Oooool00ooo003ooooooooo
o`06ooooo`Coogl01?ooool8ool0013ooooo00?oo`00ooooooooool0YOoooolEo`00o`Sooooo0Ol0
0001ooooo`0000?o0000ooooooooool0:oooool2oomo0003oooooooo003ooooo00Kooooo1?ooO`04
ooooo`Soo`004Oooool00ooo003oooooooooo`2ToooooaGo003o2?ooool1o`00007ooooo00000ol0
003oooooooooo`0Zooooo`Coogl000?oooooool00?ooool01_ooool2oomo00Gooooo2?oo000;oooo
o`;oogl01Oooool00ooo003oooooooooo`09ooooo`;oogl0V?oooolEo`00o`Sooooo0Ol00001oooo
o`0000?o0000ooooooooool0:_ooool4oomo00;ooooo00?oo`00ooooooooool03?ooool6ool000_o
oooo1?ooO`04ooooo`03ool00?oooooooooo00Sooooo1?ooO`2GoooooaGo003o2?ooool1o`00007o
oooo00000ol0003oooooooooo`0[ooooo`;oogl01?ooool00ooo003oooooooooo`0<ooooo`Coo`00
3?ooool4oomo00Gooooo00?oo`00ooooooooool01oooool4oomo09Oooooo5Ol00?l8ooooo`7o0000
0Oooool00003o`000?oooooooooo03;ooooo0_oo000Mooooo`;oogl01oooool00ooo003ooooooooo
o`07ooooo`;oogl0]Oooool1o`00007ooooo00000ol0003oooooooooo`0dooooo`03ool00?oooooo
oooo02Cooooo00?oo`00ooooooooool0_Oooool1o`00007ooooo00000ol0003oooooooooo`0eoooo
o`03ool00?oooooooooo02Cooooo00?oo`00ooooooooool0_?ooool1o`00007ooooo00000ol0003o
ooooooooo`0fooooo`;oo`009Oooool00ooo003oooooooooo`2kooooo`7o00000Oooool00003o`00
0?oooooooooo03Sooooo0_oo00000oooO`3oooooooooo`02oomo01kooooo00?oo`00ooooooooool0
^oooool1o`00007ooooo00000ol0003oooooooooo`0hooooo`;oogl00_oo0004oomo01kooooo00?o
o`00ooooooooool0^_ooool1o`00007ooooo00000ol0003oooooooooo`0hooooo`Coogl00_oo0002
oomo01kooooo00?oo`00ooooooooool0^_ooool1o`00007ooooo00000ol0003oooooooooo`0ioooo
o`Googl000?oo`00ooooooooool07Oooool00ooo003oogl0oomo002jooooo`7o00000Oooool00003
o`000?oooooooooo03_ooooo1?ooO`02ool001gooooo00Coogl0ool00?ooO`3oogl0^Oooool1o`00
007ooooo00000ol0003oooooooooo`0looooo`;oogl00oooool2ool001_ooooo00Coogl0ool00?oo
O`3oogl0^Oooool1o`00007ooooo00000ol0003oooooooooo`13ooooo`;oo`006_ooool00oooO`3o
o`00ooooo`2iooooo`7o00000Oooool00003o`000?oooooooooo04Gooooo0_oo000Iooooo`03ool0
0?oooooooooo0;Sooooo0Ol00001ooooo`0000?o0000ooooooooool0Aoooool2ool001Gooooo0_oo
002kooooo`7o00000Oooool00003o`000?oooooooooo04Wooooo0ooo000@ooooo`;oo`00_Oooool1
o`00007ooooo00000ol0003oooooooooo`0aooooo`;oogl06Oooool3ool000cooooo00?oo`00oooo
ooooool0_Oooool1o`00007ooooo00000ol0003oooooooooo`0`ooooo`Coogl06oooool6ool000Co
oooo0_oo0030ooooo`7o00000Oooool00003o`000?oooooooooo033ooooo1?ooO`0Qooooo`Coo`00
`_ooool1o`00007ooooo00000ol0003oooooooooo`0aooooo`;oogl0j?ooool1o`00007ooooo0000
0ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLoooo
o`7o00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003ooooo
ooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Ooo
ool00003o`000?oooooooooo07gooooo0_ooO`2Looooo`7o00000Oooool00003o`000?oooooooooo
07cooooo1?ooO`2Kooooo`7o00000Oooool00003o`000?oooooooooo05Cooooo0_ooO`0Vooooo`Co
ogl0Voooool1o`00007ooooo00000ol0003oooooooooo`1Cooooo`Coogl09_ooool2oomo09cooooo
0Ol00001ooooo`0000?o0000ooooooooool0Doooool4oomo0<Cooooo0Ol00001ooooo`0000?o0000
ooooooooool0E?ooool2oomo0<Gooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLoooo
o`7o00000Oooool00003o`000?oooooooooo06?ooooo0_ooO`04ooooo`;oogl0/?ooool1o`00007o
oooo00000ol0003oooooooooo`1Rooooo`Coogl00_ooool4oomo0:oooooo0Ol00001ooooo`0000?o
0000ooooooooool0H_ooool4oomo00;ooooo1?ooO`2_ooooo`7o00000Oooool00003o`000?oooooo
oooo06?ooooo0_ooO`04ooooo`;oogl0/?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooo
oacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`00
0?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol0
0001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo
0?oooooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`00
00?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?oo
ool1o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000oooo
ooooool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007o
oooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooo
oolLooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0
003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o
00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003ooooooooo
o`3ooooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool0
0003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooooaco
oooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oo
oooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001
ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo0?oo
oooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o
0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1
o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000oooooooo
ool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo
00000ol0003oooooooooo`3oooooo`Cooooo0_ooO`0Fooooo`7o00000Oooool00003o`000?oooooo
oooo0?oooooo0oooool4oomo01Gooooo0Ol00001ooooo`0000?o0000ooooooooool0ooooool3oooo
o`Coogl05Oooool1o`00007ooooo00000ol0003oooooooooo`3oooooo`Cooooo0_ooO`0Fooooo`7o
00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003ooooooooo
o`3ooooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool0
0003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooooaco
oooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oo
oooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001
ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo0?oo
oooo7?ooool1o`00007ooooo00000ol0003oooooooooo`2eooooo`;oogl0I?ooool1o`00007ooooo
00000ol0003oooooooooo`2dooooo`Coogl0Hoooool1o`00007ooooo00000ol0003oooooooooo`2d
ooooo`Coogl0Hoooool1o`00007ooooo00000ol0003oooooooooo`2eooooo`;oogl0=Oooool2oomo
02gooooo0Ol00001ooooo`0000?o0000ooooooooool0i?ooool2oomo00Gooooo1?ooO`0/ooooo`7o
00000Oooool00003o`000?oooooooooo0>?ooooo1?ooO`04ooooo`Coogl0;?ooool1o`00007ooooo
00000ol0003oooooooooo`33ooooo`;oogl07_ooool4oomo00Gooooo0_ooO`0]ooooo`7o00000Ooo
ool00003o`000?oooooooooo0<;ooooo1?ooO`0;o`00oa?ooooo0_ooO`0eooooo`7o00000Oooool0
0003o`000?oooooooooo0<;ooooo1?l00?l;ooooo`;o003oB?ooool1o`00007ooooo00000ol0003o
ooooooooo`2nooooo`Co003o00?ooooooomo0?ooO`003_ooool2o`00odKooooo0Ol00001ooooo`00
00?o0000ooooooooool0^Oooool2oomo00?o003o5oooool2o`00o`Wooooo0_ooO`0iooooo`7o0000
0Oooool00003o`000?oooooooooo0;Oooooo1?l00?l00oooO`3oooooooooo`0Iooooo`;o003o1_oo
ool4oomo03Sooooo0Ol00001ooooo`0000?o0000ooooooooool0]?ooool3o`00o`03ooooooooO`3o
ogl000;oogl07?ooool00ol00?ooooooooooo`04ooooo`Coogl00oooool2oomo03?ooooo0Ol00001
ooooo`0000?o0000ooooooooool0/_ooool2o`00o`?oogl00_ooool2oomo01?ooooo0_ooO`08oooo
o`03o`00oooooooooooo00Gooooo0_ooO`03ooooo`Coogl0<_ooool1o`00007ooooo00000ol0003o
ooooooooo`2`ooooo`;o003o00?ooooooomo0?ooO`000_ooO`06ooooo`;oogl03_ooool4oomo00Oo
oooo00?o003oooooooooool02_ooool4oomo03;ooooo0Ol00001ooooo`0000?o0000ooooooooool0
[_ooool2o`00o`Cooooo0_ooO`06ooooo`Coogl03Oooool4oomo00Oooooo00?o003oooooooooool0
2oooool2oomo03?ooooo0Ol00001ooooo`0000?o0000ooooooooool0Roooool2oomo023ooooo00?o
003oooooooooool01?ooool2oomo00Kooooo1?ooO`0>ooooo`;oogl02Oooool00ol00?oooooooooo
o`0oooooo`7o00000Oooool00003o`000?oooooooooo08[ooooo1?ooO`0Mooooo`;o003o1_ooool4
oomo00Kooooo0_ooO`0Jooooo`03o`00oooooooooooo03oooooo0Ol00001ooooo`0000?o0000oooo
ooooool0R_ooool4oomo01cooooo00?o003oooooooooool01_ooool4oomo02;ooooo00?o003ooooo
ooooool0?oooool1o`00007ooooo00000ol0003oooooooooo`2;ooooo`;oogl06oooool2o`00o`[o
oooo0_ooO`0Sooooo`03o`00oooooooooooo03oooooo0Ol00001ooooo`0000?o0000ooooooooool0
U_ooool2oomo00kooooo0_l00?lZooooo`;oogl01Oooool00ol00?ooooooooooo`0oooooo`7o0000
0Oooool00003o`000?oooooooooo09Gooooo1?ooO`0<ooooo`04o`00ooooooooogl0oomo02Sooooo
1?ooO`03ooooo`03o`00oooooooooooo043ooooo0Ol00001ooooo`0000?o0000ooooooooool0UOoo
ool4oomo00[ooooo0_l00?l00oooooooogl0oomo0002oomo02Oooooo1?ooO`03ooooo`03o`00oooo
oooooooo043ooooo0Ol00001ooooo`0000?o0000ooooooooool0U_ooool2oomo00[ooooo00Co003o
oooooooooooooooo1?ooO`0Xooooo`;oogl01?ooool00ol00?ooooooooooo`10ooooo`7o00000Ooo
ool00003o`000?oooooooooo0:7ooooo00?o003oooooooooool00oooool2oomo02kooooo00?o003o
ooooooooool0@Oooool1o`00007ooooo00000ol0003oooooooooo`2Pooooo`03o`00oooooooooooo
03?ooooo00?o003oooooooooool04_ooool2oomo02kooooo0Ol00001ooooo`0000?o0000oooooooo
ool0W_ooool2o`00ocGooooo00?o003oooooooooool04_ooool4oomo02gooooo0Ol00001ooooo`00
00?o0000ooooooooool0WOooool00ol00?ooooooooooo`0Eooooo`Co003o7?ooool00ol00?ooogl0
oomo000Booooo`Coogl0;Oooool1o`00007ooooo00000ol0003oooooooooo`2Looooo`03o`00oooo
oooooooo01Gooooo1_l00?lJooooo`03o`00ooooO`3oogl000;oogl04_ooool2oomo02kooooo0Ol0
0001ooooo`0000?o0000ooooooooool0Voooool00ol00?ooooooooooo`0Eooooo`So003o6?ooool0
0ol00?oooooooomo0003oomo04;ooooo0Ol00001ooooo`0000?o0000ooooooooool0Voooool00ol0
0?ooooooooooo`0Eooooo`So003o5oooool01?l00?ooooooooooooooool2oomo04?ooooo0Ol00001
ooooo`0000?o0000ooooooooool0V_ooool00ol00?ooooooooooo`0Fooooo`So003o5_ooool00ol0
0?ooooooooooo`17ooooo`7o00000Oooool00003o`000?oooooooooo09Wooooo00?o003ooooooooo
ool03?ooool2oomo00Sooooo00?oogl0o`00ool00?l01_l00?lEooooo`03o`00oooooooooooo00;o
ogl0A_ooool1o`00007ooooo00000ol0003oooooooooo`2Iooooo`03o`00oooooooooooo00[ooooo
1OooO`07ooooo`;oogl01_l00?lCooooo`;oogl000?o003oooooooooool01?ooO`15ooooo`7o0000
0Oooool00003o`000?oooooooooo09Sooooo00?o003oooooooooool02_ooool6oomo00Sooooo0_oo
O`04o`00oa?ooooo0_ooO`02o`00o`;ooooo1?ooO`15ooooo`7o00000Oooool00003o`000?oooooo
oooo09Sooooo00?o003oooooooooool02_ooool5oomo02;ooooo00Coogl0o`00ooooO`3oogl00ooo
ool2oomo04Kooooo0Ol00001ooooo`0000?o0000ooooooooool0M_ooool2oomo01oooooo00?o003o
ooooooooool03?ooool2oomo02Cooooo00?o003ooomo0?ooO`00C?ooool1o`00007ooooo00000ol0
003oooooooooo`1eooooo`Coogl07_ooool00ol00?ooooooooooo`0aooooo`03o`00oooooooooooo
04gooooo0Ol00001ooooo`0000?o0000ooooooooool0MOooool4oomo00[ooooo0_ooO`0Aooooo`03
o`00oooooooooooo037ooooo00?o003oooooooooool0C_ooool1o`00007ooooo00000ol0003ooooo
ooooo`1fooooo`;oogl02_ooool4oomo00oooooo00?o003oooooooooool06?ooool2oomo01Oooooo
00?o003oooooooooool0Coooool1o`00007ooooo00000ol0003oooooooooo`22ooooo`Coogl03ooo
ool00ol00?ooooooooooo`0Gooooo`Coogl05?ooool2o`00oe;ooooo0Ol00001ooooo`0000?o0000
ooooooooool0Poooool2oomo00oooooo00?o003oooooooooool04_ooool2oomo00Cooooo1?ooO`0A
ooooo`?o003oE?ooool1o`00007ooooo00000ol0003oooooooooo`2Dooooo`03o`00oooooooooooo
017ooooo1?ooO`04ooooo`;oogl04?ooool2o`00oeOooooo0Ol00001ooooo`0000?o0000oooooooo
ool0U?ooool00ol00?ooooooooooo`0Aooooo`Coogl05Oooool00ol00?ooooooooooo`1Gooooo`7o
00000Oooool00003o`000?oooooooooo09Cooooo00?o003oooooooooool04_ooool2oomo01Cooooo
0_l00?mJooooo`7o00000Oooool00003o`000?oooooooooo09Cooooo00?o003oooooooooool09_oo
ool2o`00oecooooo0Ol00001ooooo`0000?o0000ooooooooool0UOooool00ol00?ooooooooooo`0T
ooooo`03o`00oooooooooooo05cooooo0Ol00001ooooo`0000?o0000ooooooooool0UOooool00ol0
0?ooooooooooo`0Rooooo`;o003oGoooool1o`00007ooooo00000ol0003oooooooooo`2Eooooo`03
o`00oooooooooooo023ooooo0_l00?mQooooo`7o00000Oooool00003o`000?oooooooooo08Cooooo
0_ooO`0?ooooo`;o003o6_ooool5ool0o`;o003oHoooool1o`00007ooooo00000ol0003ooooooooo
o`23ooooo`Coogl04?ooool2o`00oaOooooo1ooo0?mTooooo`7o00000Oooool00003o`000?oooooo
oooo08?ooooo1?ooO`0Booooo`;o003o5?ooool9ool0of?ooooo0Ol00001ooooo`0000?o0000oooo
ooooool0Q?ooool2oomo01Gooooo0ol00?l>ooooo`;o003o2ooo0?mRooooo`7o00000Oooool00003
o`000?oooooooooo09kooooo0ol00?l5ooooo`Ko003o0_ooool;ool0of;ooooo0Ol00001ooooo`00
00?o0000ooooooooool0XOooool5o`00o`Sooooo2ooo0?mRooooo`7o00000Oooool00003o`000?oo
oooooooo0:kooooo2ooo0?mRooooo`7o00000Oooool00003o`000?oooooooooo0:kooooo2ooo0?mR
ooooo`7o00000Oooool00003o`000?oooooooooo0:oooooo2Ooo0?mSooooo`7o00000Oooool00003
o`000?oooooooooo07_ooooo0_ooO`0cooooo`Ooo`3oI?ooool1o`00007ooooo00000ol0003ooooo
ooooo`1jooooo`Coogl0<oooool5ool0ofGooooo0Ol00001ooooo`0000?o0000ooooooooool0N_oo
ool4oomo023ooooo0_ooO`1kooooo`7o00000Oooool00003o`000?oooooooooo07_ooooo0_ooO`0P
ooooo`Coogl0N_ooool1o`00007ooooo00000ol0003oooooooooo`2Mooooo`Coogl0N_ooool1o`00
007ooooo00000ol0003oooooooooo`2@ooooo`;oogl03?ooool2oomo07_ooooo0Ol00001ooooo`00
00?o0000ooooooooool0Soooool4oomo08Sooooo0Ol00001ooooo`0000?o0000ooooooooool0Sooo
ool4oomo08Sooooo0Ol00001ooooo`0000?o0000ooooooooool0T?ooool2oomo02?ooooo0_ooO`1T
ooooo`7o00000Oooool00003o`000?oooooooooo0;Cooooo1?ooO`1Sooooo`7o00000Oooool00003
o`000?oooooooooo0;Cooooo1?ooO`1Sooooo`7o00000Oooool00003o`000?oooooooooo0;Gooooo
0_ooO`1Tooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo0000
0ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLoooo
o`7o00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003ooooo
ooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Ooo
ool00003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooo
oacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`00
0?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol0
0001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo
0?oooooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`00
00?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?oo
ool1o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000oooo
ooooool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007o
oooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooo
oolLooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0
003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o
00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003ooooooooo
o`3ooooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool0
0003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooooaco
oooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oo
oooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001
ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo0?oo
oooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o
0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1
o`00007ooooo00000ol0003oooooooooo`2>ooooo`;oogl0Roooool1o`00007ooooo00000ol0003o
ooooooooo`2=ooooo`Coogl0R_ooool1o`00007ooooo00000ol0003oooooooooo`2=ooooo`Coogl0
R_ooool1o`00007ooooo00000ol0003oooooooooo`2>ooooo`;oogl0Roooool1o`00007ooooo0000
0ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLoooo
o`7o00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003ooooo
ooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Ooo
ool00003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooo
oacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`00
0?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol0
0001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo
0?oooooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`00
00?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?oo
ool1o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000oooo
ooooool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007o
oooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooo
oolLooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo003oo`00
023o00000Oooool00001\
\>"],
  ImageRangeCache->{{{0, 287}, {287, 0}} -> {-1.01089, -1.01089, 0.00704453, \
0.00704453}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.49505 0.5 0.49505 [
[ 0 0 -0.125 0 ]
[ 0 0 -0.125 0 ]
[ 0 1 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
0 0 m
1 0 L
s
0 0 m
0 1 L
s
0 1 m
1 1 L
s
1 0 m
1 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
1 .5 0 r
.015 w
.03175 .1355 Mdot
.03435 .12523 Mdot
.11137 .12765 Mdot
.14107 .18841 Mdot
.16218 .24538 Mdot
.17294 .21053 Mdot
.18267 .18577 Mdot
.18434 .1304 Mdot
.18553 .30956 Mdot
.20401 .239 Mdot
.21247 .27571 Mdot
.21687 .20845 Mdot
.22376 .2799 Mdot
.22832 .27485 Mdot
.29063 .20974 Mdot
.29686 .25079 Mdot
.30487 .22936 Mdot
.30683 .34623 Mdot
.32055 .20902 Mdot
.32574 .21979 Mdot
.34472 .28521 Mdot
.35998 .36393 Mdot
.36335 .24976 Mdot
.3794 .36608 Mdot
.42386 .66992 Mdot
.44391 .74519 Mdot
.45059 .34198 Mdot
.47208 .67586 Mdot
.47436 .71381 Mdot
.49778 .59825 Mdot
.50874 .91643 Mdot
.51516 .76219 Mdot
.53655 .61374 Mdot
.56563 .75219 Mdot
.59189 .65665 Mdot
.59581 .61604 Mdot
.59923 .6556 Mdot
.60292 .68499 Mdot
.62656 .67779 Mdot
.63555 .72451 Mdot
.63919 .652 Mdot
.64169 .6004 Mdot
.64246 .58611 Mdot
.64496 .54267 Mdot
.64608 .77288 Mdot
.65077 .64308 Mdot
.66065 .57816 Mdot
.67474 .59169 Mdot
.69296 .563 Mdot
.72815 .65902 Mdot
.73169 .58879 Mdot
.74669 .61318 Mdot
.74821 .65474 Mdot
.75963 .63781 Mdot
.79673 .57809 Mdot
.80925 .55852 Mdot
.81525 .58444 Mdot
.83417 .62985 Mdot
.83598 .55526 Mdot
.91595 .49319 Mdot
1 0 0 r
.005 w
.16128 .17044 m
.18734 .17269 L
.21339 .17909 L
.2345 .18734 L
.23945 .19126 L
.2655 .20415 L
.27874 .21339 L
.29156 .22295 L
.31204 .23945 L
.31761 .24532 L
.33549 .2655 L
.34367 .28341 L
.34499 .29156 L
.34367 .29798 L
.31761 .3104 L
.29156 .30711 L
.2655 .30014 L
.24507 .29156 L
.23945 .28747 L
.21339 .27402 L
.20155 .2655 L
.18734 .25472 L
.16884 .23945 L
.16128 .2313 L
.14618 .21339 L
.13806 .18734 L
.16128 .17044 L
s
0 0 1 r
.65633 .57701 m
.68239 .56842 L
.70844 .56313 L
.7345 .56168 L
.76055 .5752 L
.76359 .57817 L
.76859 .60422 L
.76055 .62333 L
.75627 .63028 L
.7345 .65485 L
.73298 .65633 L
.70844 .6775 L
.69922 .68239 L
.68239 .69294 L
.65633 .70579 L
.64983 .70844 L
.63028 .71539 L
.60422 .72268 L
.57817 .72651 L
.55211 .7214 L
.53145 .70844 L
.52926 .68239 L
.54239 .65633 L
.55211 .63983 L
.56625 .63028 L
.57817 .6193 L
.60119 .60422 L
.60422 .60227 L
.63028 .58726 L
.65315 .57817 L
.65633 .57701 L
s
1 0 0 r
.03 w
.24141 .24033 Mdot
0 0 1 r
.64872 .64417 Mdot
1 0 0 r
.79703 .00495 m
.79703 .00495 L
.87129 .00495 L
.87129 .00495 L
F
0 0 1 r
.89604 .00495 m
.89604 .25248 L
.9703 .25248 L
.9703 .00495 L
F
1 0 1 r
.04 w
.63919 .652 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P000182000`400?l00000o`00003ooooooolQ
ooooo`00ool0000Po`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`00
00?o0000ooooooooool0o_oooolEo`00o`Sooooo0Ol00001ooooo`0000?o0000ooooooooool0o_oo
oolEo`00o`Sooooo0Ol00001ooooo`0000?o0000ooooooooool0o_oooolEo`00o`Sooooo0Ol00001
ooooo`0000?o0000ooooooooool0o_oooolEo`00o`Sooooo0Ol00001ooooo`0000?o0000oooooooo
ool0o_oooolEo`00o`Sooooo0Ol00001ooooo`0000?o0000ooooooooool0o_oooolEo`00o`Sooooo
0Ol00001ooooo`0000?o0000ooooooooool0o_oooolEo`00o`Sooooo0Ol00001ooooo`0000?o0000
ooooooooool0o_oooolEo`00o`Sooooo0Ol00001ooooo`0000?o0000ooooooooool0o_oooolEo`00
o`Sooooo0Ol00001ooooo`0000?o0000ooooooooool0o_oooolEo`00o`Sooooo0Ol00001ooooo`00
00?o0000ooooooooool0o_oooolEo`00o`Sooooo0Ol00001ooooo`0000?o0000ooooooooool0o_oo
oolEo`00o`Sooooo0Ol00001ooooo`0000?o0000ooooooooool0o_oooolEo`00o`Sooooo0Ol00001
ooooo`0000?o0000ooooooooool0o_oooolEo`00o`Sooooo0Ol00001ooooo`0000?o0000oooooooo
ool0o_oooolEo`00o`Sooooo0Ol00001ooooo`0000?o0000ooooooooool0o_oooolEo`00o`Sooooo
0Ol00001ooooo`0000?o0000ooooooooool0o_oooolEo`00o`Sooooo0Ol00001ooooo`0000?o0000
ooooooooool0o_oooolEo`00o`Sooooo0Ol00001ooooo`0000?o0000ooooooooool0o_oooolEo`00
o`Sooooo0Ol00001ooooo`0000?o0000ooooooooool0o_oooolEo`00o`Sooooo0Ol00001ooooo`00
00?o0000ooooooooool0o_oooolEo`00o`Sooooo0Ol00001ooooo`0000?o0000ooooooooool0o_oo
oolEo`00o`Sooooo0Ol00001ooooo`0000?o0000ooooooooool0o_oooolEo`00o`Sooooo0Ol00001
ooooo`0000?o0000ooooooooool0o_oooolEo`00o`Sooooo0Ol00001ooooo`0000?o0000oooooooo
ool0o_oooolEo`00o`Sooooo0Ol00001ooooo`0000?o0000ooooooooool0o_oooolEo`00o`Sooooo
0Ol00001ooooo`0000?o0000ooooooooool0o_oooolEo`00o`Sooooo0Ol00001ooooo`0000?o0000
ooooooooool0o_oooolEo`00o`Sooooo0Ol00001ooooo`0000?o0000ooooooooool0o_oooolEo`00
o`Sooooo0Ol00001ooooo`0000?o0000ooooooooool0o_oooolEo`00o`Sooooo0Ol00001ooooo`00
00?o0000ooooooooool0o_oooolEo`00o`Sooooo0Ol00001ooooo`0000?o0000ooooooooool0o_oo
oolEo`00o`Sooooo0Ol00001ooooo`0000?o0000ooooooooool01_ooool2oomo0?Kooooo5Ol00?l8
ooooo`7o00000Oooool00003o`000?oooooooooo00Gooooo1?ooO`0Cooooo`;oogl0h?oooolEo`00
o`Sooooo0Ol00001ooooo`0000?o0000ooooooooool01Oooool4oomo01;ooooo1?ooO`0Booooo`;o
ogl0booooolEo`00o`Sooooo0Ol00001ooooo`0000?o0000ooooooooool01Oooool3oomo01?ooooo
1?ooO`0Aooooo`Coogl0b_oooolEo`00o`Sooooo0Ol00001ooooo`0000?o0000ooooooooool01?oo
ool4oomo01Cooooo0_ooO`0Booooo`Coogl0b_oooolEo`00o`Sooooo0Ol00001ooooo`0000?o0000
ooooooooool01?ooool4oomo02Wooooo0_ooO`3;oooooaGo003o2?ooool1o`00007ooooo00000ol0
003oooooooooo`05ooooo`;oogl0mooooolEo`00o`Sooooo0Ol00001ooooo`0000?o0000oooooooo
ool0o_oooolEo`00o`Sooooo0Ol00001ooooo`0000?o0000ooooooooool0o_oooolEo`00o`Sooooo
0Ol00001ooooo`0000?o0000ooooooooool0o_oooolEo`00o`Sooooo0Ol00001ooooo`0000?o0000
ooooooooool0o_oooolEo`00o`Sooooo0Ol00001ooooo`0000?o0000ooooooooool0o_oooolEo`00
o`Sooooo0Ol00001ooooo`0000?o0000ooooooooool0o_oooolEo`00o`Sooooo0Ol00001ooooo`00
00?o0000ooooooooool0o_oooolEo`00o`Sooooo0Ol00001ooooo`0000?o0000ooooooooool0:_oo
ool6ool00<kooooo5Ol00?l8ooooo`7o00000Oooool00003o`000?oooooooooo02Wooooo00?oo`00
ooooooooool01?ooool5ool00<Wooooo5Ol00?l8ooooo`7o00000Oooool00003o`000?oooooooooo
02Oooooo0_oo000<ooooo`Coo`00aOoooolEo`00o`Sooooo0Ol00001ooooo`0000?o0000oooooooo
ool09_ooool00ooo003oooooooooo`0@ooooo`Coo`00`OoooolEo`00o`Sooooo0Ol00001ooooo`00
00?o0000ooooooooool09?ooool00oooO`3oo`00ooooo`09ooooo`;oogl02oooool3ool00;kooooo
5Ol00?l8ooooo`7o00000Oooool00003o`000?oooooooooo02?ooooo00Coogl0ool00?ooO`3oogl0
2?ooool4oomo00gooooo00?oo`00ooooooooool0^ooooolEo`00o`Sooooo0Ol00001ooooo`0000?o
0000ooooooooool08oooool01?ooO`3oo`00oomo0?ooO`08ooooo`Coogl03_ooool2ool00;_ooooo
5Ol00?l8ooooo`7o00000Oooool00003o`000?oooooooooo02Cooooo00?oogl0ool00?ooool02Ooo
ool2oomo017ooooo0_oo002ioooooaGo003o2?ooool1o`00007ooooo00000ol0003oooooooooo`0U
ooooo`03ool00?oooooooooo01gooooo0_oo002goooooaGo003o2?ooool1o`00007ooooo00000ol0
003oooooooooo`0Uooooo`03ool00?oooooooooo01oooooo0_oo002eoooooaGo003o2?ooool1o`00
007ooooo00000ol0003oooooooooo`0Vooooo`03ool00?oooooooooo017ooooo0_ooO`0=ooooo`;o
o`001?ooool2oomo00Oooooo0_ooO`2ToooooaGo003o2?ooool1o`00007ooooo00000ol0003ooooo
ooooo`0Vooooo`03ool00?oooooooooo00Gooooo0_ooO`09ooooo`Coogl03_ooool00ooo003ooooo
ooooo`04oomo00Gooooo1?ooO`2SoooooaGo003o2?ooool1o`00007ooooo00000ol0003ooooooooo
o`0Vooooo`03ool00?oooooooooo00Cooooo1?ooO`08ooooo`Coogl03oooool00ooo003ooooooomo
0003oomo00Gooooo1?ooO`2SoooooaGo003o2?ooool1o`00007ooooo00000ol0003oooooooooo`0W
ooooo`03ool00?oooooooooo00?ooooo1?ooO`09ooooo`;oogl04Oooool01?oo003ooooooomo0?oo
O`07ooooo`?oogl0XooooolEo`00o`Sooooo0Ol00001ooooo`0000?o0000ooooooooool09oooool0
0ooo003oooooooooo`04ooooo`;oogl07_ooool00ooo003oooooooooo`07ooooo`Coogl0X_oooolE
o`00o`Sooooo0Ol00001ooooo`0000?o0000ooooooooool0:?ooool00ooo003oooooooooo`0Toooo
o`03ool00?oooooooooo00Kooooo1?ooO`2RoooooaGo003o2?ooool1o`00007ooooo00000ol0003o
ooooooooo`0Yooooo`03ool00?oooooooooo02Cooooo0_oo00000oooooooogl0oomo0004ooooo`;o
ogl0XooooolEo`00o`Sooooo0Ol00001ooooo`0000?o0000ooooooooool0:_ooool00ooo003ooooo
ooooo`0Cooooo`Coo`003_ooool01?oo003oogl0oomo0?ooO`2XoooooaGo003o2?ooool1o`00007o
oooo00000ol0003oooooooooo`0[ooooo`03ool00?oooooooooo017ooooo1_oo000=ooooo`04oomo
0?oo003oo`00oomo0:Sooooo5Ol00?l8ooooo`7o00000Oooool00003o`000?oooooooooo02cooooo
00?oo`00ooooooooool02?ooool2oomo00Gooooo2?oo000=ooooo`;oogl000?oo`00ooooooooool0
Y_oooolEo`00o`Sooooo0Ol00001ooooo`0000?o0000ooooooooool0;Oooool00ooo003ooooooooo
o`06ooooo`Coogl01?ooool8ool0013ooooo00?oo`00ooooooooool0YOoooolEo`00o`Sooooo0Ol0
0001ooooo`0000?o0000ooooooooool0:oooool2oomo0003oooooooo003ooooo00Kooooo1?ooO`04
ooooo`Soo`004Oooool00ooo003oooooooooo`2ToooooaGo003o2?ooool1o`00007ooooo00000ol0
003oooooooooo`0Zooooo`Coogl000?oooooool00?ooool01_ooool2oomo00Gooooo2?oo000;oooo
o`;oogl01Oooool00ooo003oooooooooo`09ooooo`;oogl0V?oooolEo`00o`Sooooo0Ol00001oooo
o`0000?o0000ooooooooool0:_ooool4oomo00;ooooo00?oo`00ooooooooool03?ooool6ool000_o
oooo1?ooO`04ooooo`03ool00?oooooooooo00Sooooo1?ooO`2GoooooaGo003o2?ooool1o`00007o
oooo00000ol0003oooooooooo`0[ooooo`;oogl01?ooool00ooo003oooooooooo`0<ooooo`Coo`00
3?ooool4oomo00Gooooo00?oo`00ooooooooool01oooool4oomo09Oooooo5Ol00?l8ooooo`7o0000
0Oooool00003o`000?oooooooooo03;ooooo0_oo000Mooooo`;oogl01oooool00ooo003ooooooooo
o`07ooooo`;oogl0]Oooool1o`00007ooooo00000ol0003oooooooooo`0dooooo`03ool00?oooooo
oooo02Cooooo00?oo`00ooooooooool0_Oooool1o`00007ooooo00000ol0003oooooooooo`0eoooo
o`03ool00?oooooooooo02Cooooo00?oo`00ooooooooool0_?ooool1o`00007ooooo00000ol0003o
ooooooooo`0fooooo`;oo`009Oooool00ooo003oooooooooo`2kooooo`7o00000Oooool00003o`00
0?oooooooooo03Sooooo0_oo00000oooO`3oooooooooo`02oomo01kooooo00?oo`00ooooooooool0
^oooool1o`00007ooooo00000ol0003oooooooooo`0hooooo`;oogl00_oo0004oomo01kooooo00?o
o`00ooooooooool0^_ooool1o`00007ooooo00000ol0003oooooooooo`0hooooo`Coogl00_oo0002
oomo01kooooo00?oo`00ooooooooool0^_ooool1o`00007ooooo00000ol0003oooooooooo`0ioooo
o`Googl000?oo`00ooooooooool07Oooool00ooo003oogl0oomo002jooooo`7o00000Oooool00003
o`000?oooooooooo03_ooooo1?ooO`02ool001gooooo00Coogl0ool00?ooO`3oogl0^Oooool1o`00
007ooooo00000ol0003oooooooooo`0looooo`;oogl00oooool2ool001_ooooo00Coogl0ool00?oo
O`3oogl0^Oooool1o`00007ooooo00000ol0003oooooooooo`13ooooo`;oo`006_ooool00oooO`3o
o`00ooooo`2iooooo`7o00000Oooool00003o`000?oooooooooo04Gooooo0_oo000Iooooo`03ool0
0?oooooooooo0;Sooooo0Ol00001ooooo`0000?o0000ooooooooool0Aoooool2ool001Gooooo0_oo
002kooooo`7o00000Oooool00003o`000?oooooooooo04Wooooo0ooo000@ooooo`;oo`00_Oooool1
o`00007ooooo00000ol0003oooooooooo`0aooooo`;oogl06Oooool3ool000cooooo00?oo`00oooo
ooooool0_Oooool1o`00007ooooo00000ol0003oooooooooo`0`ooooo`Coogl06oooool6ool000Co
oooo0_oo0030ooooo`7o00000Oooool00003o`000?oooooooooo033ooooo1?ooO`0Qooooo`Coo`00
`_ooool1o`00007ooooo00000ol0003oooooooooo`0aooooo`;oogl0j?ooool1o`00007ooooo0000
0ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLoooo
o`7o00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003ooooo
ooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Ooo
ool00003o`000?oooooooooo07gooooo0_ooO`2Looooo`7o00000Oooool00003o`000?oooooooooo
07cooooo1?ooO`2Kooooo`7o00000Oooool00003o`000?oooooooooo05Cooooo0_ooO`0Vooooo`Co
ogl0Voooool1o`00007ooooo00000ol0003oooooooooo`1Cooooo`Coogl09_ooool2oomo09cooooo
0Ol00001ooooo`0000?o0000ooooooooool0Doooool4oomo0<Cooooo0Ol00001ooooo`0000?o0000
ooooooooool0E?ooool2oomo0<Gooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLoooo
o`7o00000Oooool00003o`000?oooooooooo06?ooooo0_ooO`04ooooo`;oogl0/?ooool1o`00007o
oooo00000ol0003oooooooooo`1Rooooo`Coogl00_ooool4oomo0:oooooo0Ol00001ooooo`0000?o
0000ooooooooool0H_ooool4oomo00;ooooo1?ooO`2_ooooo`7o00000Oooool00003o`000?oooooo
oooo06?ooooo0_ooO`04ooooo`;oogl0/?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooo
oacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`00
0?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol0
0001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo
0?oooooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`00
00?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?oo
ool1o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000oooo
ooooool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007o
oooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooo
oolLooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0
003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o
00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003ooooooooo
o`3ooooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool0
0003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooooaco
oooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oo
oooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001
ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo0?oo
oooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o
0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1
o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000oooooooo
ool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo
00000ol0003oooooooooo`3oooooo`Cooooo0_ooO`0Fooooo`7o00000Oooool00003o`000?oooooo
oooo0?oooooo0oooool4oomo01Gooooo0Ol00001ooooo`0000?o0000ooooooooool0ooooool3oooo
o`Coogl05Oooool1o`00007ooooo00000ol0003oooooooooo`3oooooo`Cooooo0_ooO`0Fooooo`7o
00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003ooooooooo
o`3ooooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool0
0003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooooaco
oooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oo
oooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001
ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo0?oo
oooo7?ooool1o`00007ooooo00000ol0003oooooooooo`2eooooo`;oogl0I?ooool1o`00007ooooo
00000ol0003oooooooooo`2dooooo`Coogl0Hoooool1o`00007ooooo00000ol0003oooooooooo`2d
ooooo`Coogl0Hoooool1o`00007ooooo00000ol0003oooooooooo`2eooooo`;oogl0=Oooool2oomo
02gooooo0Ol00001ooooo`0000?o0000ooooooooool0i?ooool2oomo00Gooooo1?ooO`0/ooooo`7o
00000Oooool00003o`000?oooooooooo0>?ooooo1?ooO`04ooooo`Coogl0;?ooool1o`00007ooooo
00000ol0003oooooooooo`33ooooo`;oogl07_ooool4oomo00Gooooo0_ooO`0]ooooo`7o00000Ooo
ool00003o`000?oooooooooo0<;ooooo1?ooO`0;o`00oa?ooooo0_ooO`0eooooo`7o00000Oooool0
0003o`000?oooooooooo0<;ooooo1?l00?l;ooooo`;o003oB?ooool1o`00007ooooo00000ol0003o
ooooooooo`2nooooo`Co003o00?ooooooomo0?ooO`003_ooool2o`00odKooooo0Ol00001ooooo`00
00?o0000ooooooooool0^Oooool2oomo00?o003o5oooool2o`00o`Wooooo0_ooO`0iooooo`7o0000
0Oooool00003o`000?oooooooooo0;Oooooo1?l00?l00oooO`3oooooooooo`0Iooooo`;o003o1_oo
ool4oomo03Sooooo0Ol00001ooooo`0000?o0000ooooooooool0]?ooool3o`00o`03ooooooooO`3o
ogl000;oogl07?ooool00ol00?ooooooooooo`04ooooo`Coogl00oooool2oomo03?ooooo0Ol00001
ooooo`0000?o0000ooooooooool0/_ooool2o`00o`?oogl00_ooool2oomo01?ooooo0_ooO`08oooo
o`03o`00oooooooooooo00Gooooo0_ooO`03ooooo`Coogl0<_ooool1o`00007ooooo00000ol0003o
ooooooooo`2`ooooo`;o003o00?ooooooomo0?ooO`000_ooO`06ooooo`;oogl03_ooool4oomo00Oo
oooo00?o003oooooooooool02_ooool4oomo03;ooooo0Ol00001ooooo`0000?o0000ooooooooool0
[_ooool2o`00o`Cooooo0_ooO`06ooooo`Coogl03Oooool4oomo00Oooooo00?o003oooooooooool0
2oooool2oomo03?ooooo0Ol00001ooooo`0000?o0000ooooooooool0Roooool2oomo023ooooo00?o
003oooooooooool01?ooool2oomo00Kooooo1?ooO`0>ooooo`;oogl02Oooool00ol00?oooooooooo
o`0oooooo`7o00000Oooool00003o`000?oooooooooo08[ooooo1?ooO`0Mooooo`;o003o1_ooool4
oomo00Kooooo0_ooO`0Jooooo`03o`00oooooooooooo03oooooo0Ol00001ooooo`0000?o0000oooo
ooooool0R_ooool4oomo01cooooo00?o003oooooooooool01_ooool4oomo02;ooooo00?o003ooooo
ooooool0?oooool1o`00007ooooo00000ol0003oooooooooo`2;ooooo`;oogl06oooool2o`00o`[o
oooo0_ooO`0Sooooo`03o`00oooooooooooo03oooooo0Ol00001ooooo`0000?o0000ooooooooool0
U_ooool2oomo00kooooo0_l00?lZooooo`;oogl01Oooool00ol00?ooooooooooo`0oooooo`7o0000
0Oooool00003o`000?oooooooooo09Gooooo1?ooO`0<ooooo`04o`00ooooooooogl0oomo02Sooooo
1?ooO`03ooooo`03o`00oooooooooooo043ooooo0Ol00001ooooo`0000?o0000ooooooooool0UOoo
ool4oomo00[ooooo0_l00?l00oooooooogl0oomo0002oomo02Oooooo1?ooO`03ooooo`03o`00oooo
oooooooo043ooooo0Ol00001ooooo`0000?o0000ooooooooool0U_ooool2oomo00[ooooo00Co003o
oooooooooooooooo1?ooO`0Xooooo`;oogl01?ooool00ol00?ooooooooooo`10ooooo`7o00000Ooo
ool00003o`000?oooooooooo0:7ooooo00?o003oooooooooool00oooool2oomo02kooooo00?o003o
ooooooooool0@Oooool1o`00007ooooo00000ol0003oooooooooo`2Pooooo`03o`00oooooooooooo
03?ooooo00?o003oooooooooool04_ooool2oomo02kooooo0Ol00001ooooo`0000?o0000oooooooo
ool0W_ooool2o`00ocGooooo00?o003oooooooooool04_ooool4oomo02gooooo0Ol00001ooooo`00
00?o0000ooooooooool0WOooool00ol00?ooooooooooo`0Eooooo`Co003o7?ooool00ol00?ooogl0
oomo000Booooo`Coogl0;Oooool1o`00007ooooo00000ol0003oooooooooo`2Looooo`03o`00oooo
oooooooo01?ooooo1Ooo0?l3o`00oa[ooooo00?o003ooomo0?ooO`000_ooO`0Booooo`;oogl0;_oo
ool1o`00007ooooo00000ol0003oooooooooo`2Kooooo`03o`00oooooooooooo01?ooooo1ooo0?l3
o`00oaSooooo00?o003oooooooooO`000oooO`12ooooo`7o00000Oooool00003o`000?oooooooooo
09_ooooo00?o003oooooooooool04_ooool9ool0o`;o003o5oooool01?l00?ooooooooooooooool2
oomo04?ooooo0Ol00001ooooo`0000?o0000ooooooooool0V_ooool00ol00?ooooooooooo`0Boooo
o`_oo`3o00?o003oooooooooool05?ooool00ol00?ooooooooooo`17ooooo`7o00000Oooool00003
o`000?oooooooooo09Wooooo00?o003oooooooooool03?ooool2oomo00Gooooo2ooo0?l00ol00?oo
ooooooooo`0Cooooo`03o`00oooooooooooo00;oogl0A_ooool1o`00007ooooo00000ol0003ooooo
ooooo`2Iooooo`03o`00oooooooooooo00[ooooo1OooO`04ooooo`_oo`3o4oooool2oomo0003o`00
oooooooooooo00Coogl0AOooool1o`00007ooooo00000ol0003oooooooooo`2Hooooo`03o`00oooo
oooooooo00[ooooo1_ooO`04ooooo`_oo`3o4_ooool2oomo00;o003o0_ooool4oomo04Gooooo0Ol0
0001ooooo`0000?o0000ooooooooool0V?ooool00ol00?ooooooooooo`0:ooooo`Googl01Oooool;
ool0oa;ooooo00Coogl0o`00ooooO`3oogl00oooool2oomo04Kooooo0Ol00001ooooo`0000?o0000
ooooooooool0M_ooool2oomo01oooooo00?o003oooooooooool03?ooool2oomo00Sooooo2Ooo0?lC
ooooo`03o`00ooooO`3oogl004cooooo0Ol00001ooooo`0000?o0000ooooooooool0MOooool4oomo
01kooooo00?o003oooooooooool05oooool7ool0oa?ooooo00?o003oooooooooool0COooool1o`00
007ooooo00000ol0003oooooooooo`1eooooo`Coogl02_ooool2oomo017ooooo00?o003ooooooooo
ool06Oooool5ool0oa?ooooo00?o003oooooooooool0C_ooool1o`00007ooooo00000ol0003ooooo
ooooo`1fooooo`;oogl02_ooool4oomo00oooooo00?o003oooooooooool06?ooool2oomo01Oooooo
00?o003oooooooooool0Coooool1o`00007ooooo00000ol0003oooooooooo`22ooooo`Coogl03ooo
ool00ol00?ooooooooooo`0Gooooo`Coogl05?ooool2o`00oe;ooooo0Ol00001ooooo`0000?o0000
ooooooooool0Poooool2oomo00oooooo00?o003oooooooooool04_ooool2oomo00Cooooo1?ooO`0A
ooooo`?o003oE?ooool1o`00007ooooo00000ol0003oooooooooo`2Dooooo`03o`00oooooooooooo
017ooooo1?ooO`04ooooo`;oogl04?ooool2o`00oeOooooo0Ol00001ooooo`0000?o0000oooooooo
ool0U?ooool00ol00?ooooooooooo`0Aooooo`Coogl05Oooool00ol00?ooooooooooo`1Gooooo`7o
00000Oooool00003o`000?oooooooooo09Cooooo00?o003oooooooooool04_ooool2oomo01Cooooo
0_l00?mJooooo`7o00000Oooool00003o`000?oooooooooo09Cooooo00?o003oooooooooool09_oo
ool2o`00oecooooo0Ol00001ooooo`0000?o0000ooooooooool0UOooool00ol00?ooooooooooo`0T
ooooo`03o`00oooooooooooo05cooooo0Ol00001ooooo`0000?o0000ooooooooool0UOooool00ol0
0?ooooooooooo`0Rooooo`;o003oGoooool1o`00007ooooo00000ol0003oooooooooo`2Eooooo`03
o`00oooooooooooo023ooooo0_l00?mQooooo`7o00000Oooool00003o`000?oooooooooo08Cooooo
0_ooO`0?ooooo`;o003o7oooool2o`00of?ooooo0Ol00001ooooo`0000?o0000ooooooooool0Pooo
ool4oomo013ooooo0_l00?lJooooo`?o003oIOooool1o`00007ooooo00000ol0003oooooooooo`23
ooooo`Coogl04_ooool2o`00oaCooooo1?l00?mXooooo`7o00000Oooool00003o`000?oooooooooo
08Cooooo0_ooO`0Eooooo`?o003o3_ooool3o`00o`?ooooo0_ooO`1Wooooo`7o00000Oooool00003
o`000?oooooooooo09kooooo0ol00?l5ooooo`Ko003o1Oooool4oomo06Kooooo0Ol00001ooooo`00
00?o0000ooooooooool0XOooool5o`00o`_ooooo1?ooO`1Vooooo`7o00000Oooool00003o`000?oo
oooooooo0;;ooooo0_ooO`1Wooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1
o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000oooooooo
ool0Noooool2oomo09kooooo0Ol00001ooooo`0000?o0000ooooooooool0N_ooool4oomo09gooooo
0Ol00001ooooo`0000?o0000ooooooooool0N_ooool4oomo023ooooo0_ooO`1kooooo`7o00000Ooo
ool00003o`000?oooooooooo07_ooooo0_ooO`0Pooooo`Coogl0N_ooool1o`00007ooooo00000ol0
003oooooooooo`2Mooooo`Coogl0N_ooool1o`00007ooooo00000ol0003oooooooooo`2@ooooo`;o
ogl03?ooool2oomo07_ooooo0Ol00001ooooo`0000?o0000ooooooooool0Soooool4oomo08Sooooo
0Ol00001ooooo`0000?o0000ooooooooool0Soooool4oomo08Sooooo0Ol00001ooooo`0000?o0000
ooooooooool0T?ooool2oomo02?ooooo0_ooO`1Tooooo`7o00000Oooool00003o`000?oooooooooo
0;Cooooo1?ooO`1Sooooo`7o00000Oooool00003o`000?oooooooooo0;Cooooo1?ooO`1Sooooo`7o
00000Oooool00003o`000?oooooooooo0;Gooooo0_ooO`1Tooooo`7o00000Oooool00003o`000?oo
oooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001
ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo0?oo
oooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o
0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1
o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000oooooooo
ool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo
00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolL
ooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003o
ooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o0000
0Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3o
oooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003
o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo
0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oooooo
oooo0?oooooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001oooo
o`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo
7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000
ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00
007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0
oooooolLooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo0000
0ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLoooo
o`7o00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003ooooo
ooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Ooo
ool00003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003oooooooooo`2>oooo
o`;oogl0Roooool1o`00007ooooo00000ol0003oooooooooo`2=ooooo`Coogl0R_ooool1o`00007o
oooo00000ol0003oooooooooo`2=ooooo`Coogl0R_ooool1o`00007ooooo00000ol0003ooooooooo
o`2>ooooo`;oogl0Roooool1o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001
ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo0?oo
oooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o
0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1
o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000oooooooo
ool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo
00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolL
ooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003o
ooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o0000
0Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3o
oooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003
o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo
0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oooooo
oooo0?oooooo7?ooool1o`00007ooooo003oo`00023o00000Oooool00001\
\>"],
  ImageRangeCache->{{{0, 287}, {287, 0}} -> {-1.01089, -1.01089, 0.00704453, \
0.00704453}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.49505 0.5 0.49505 [
[ 0 0 -0.125 0 ]
[ 0 0 -0.125 0 ]
[ 0 1 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
0 0 m
1 0 L
s
0 0 m
0 1 L
s
0 1 m
1 1 L
s
1 0 m
1 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
1 .5 0 r
.015 w
.03175 .1355 Mdot
.03435 .12523 Mdot
.11137 .12765 Mdot
.14107 .18841 Mdot
.16218 .24538 Mdot
.17294 .21053 Mdot
.18267 .18577 Mdot
.18434 .1304 Mdot
.18553 .30956 Mdot
.20401 .239 Mdot
.21247 .27571 Mdot
.21687 .20845 Mdot
.22376 .2799 Mdot
.22832 .27485 Mdot
.29063 .20974 Mdot
.29686 .25079 Mdot
.30487 .22936 Mdot
.30683 .34623 Mdot
.32055 .20902 Mdot
.32574 .21979 Mdot
.34472 .28521 Mdot
.35998 .36393 Mdot
.36335 .24976 Mdot
.3794 .36608 Mdot
.42386 .66992 Mdot
.44391 .74519 Mdot
.45059 .34198 Mdot
.47208 .67586 Mdot
.47436 .71381 Mdot
.49778 .59825 Mdot
.50874 .91643 Mdot
.51516 .76219 Mdot
.53655 .61374 Mdot
.56563 .75219 Mdot
.59189 .65665 Mdot
.59581 .61604 Mdot
.59923 .6556 Mdot
.60292 .68499 Mdot
.62656 .67779 Mdot
.63555 .72451 Mdot
.63919 .652 Mdot
.64169 .6004 Mdot
.64246 .58611 Mdot
.64496 .54267 Mdot
.64608 .77288 Mdot
.65077 .64308 Mdot
.66065 .57816 Mdot
.67474 .59169 Mdot
.69296 .563 Mdot
.72815 .65902 Mdot
.73169 .58879 Mdot
.74669 .61318 Mdot
.74821 .65474 Mdot
.75963 .63781 Mdot
.79673 .57809 Mdot
.80925 .55852 Mdot
.81525 .58444 Mdot
.83417 .62985 Mdot
.83598 .55526 Mdot
.91595 .49319 Mdot
1 0 0 r
.005 w
.16128 .17044 m
.18734 .17269 L
.21339 .17909 L
.2345 .18734 L
.23945 .19126 L
.2655 .20415 L
.27874 .21339 L
.29156 .22295 L
.31204 .23945 L
.31761 .24532 L
.33549 .2655 L
.34367 .28341 L
.34499 .29156 L
.34367 .29798 L
.31761 .3104 L
.29156 .30711 L
.2655 .30014 L
.24507 .29156 L
.23945 .28747 L
.21339 .27402 L
.20155 .2655 L
.18734 .25472 L
.16884 .23945 L
.16128 .2313 L
.14618 .21339 L
.13806 .18734 L
.16128 .17044 L
s
0 0 1 r
.65633 .57701 m
.68239 .56842 L
.70844 .56313 L
.7345 .56168 L
.76055 .5752 L
.76359 .57817 L
.76859 .60422 L
.76055 .62333 L
.75627 .63028 L
.7345 .65485 L
.73298 .65633 L
.70844 .6775 L
.69922 .68239 L
.68239 .69294 L
.65633 .70579 L
.64983 .70844 L
.63028 .71539 L
.60422 .72268 L
.57817 .72651 L
.55211 .7214 L
.53145 .70844 L
.52926 .68239 L
.54239 .65633 L
.55211 .63983 L
.56625 .63028 L
.57817 .6193 L
.60119 .60422 L
.60422 .60227 L
.63028 .58726 L
.65315 .57817 L
.65633 .57701 L
s
1 0 0 r
.03 w
.24141 .24033 Mdot
0 0 1 r
.64872 .64417 Mdot
1 0 0 r
.79703 .00495 m
.79703 .00495 L
.87129 .00495 L
.87129 .00495 L
F
0 0 1 r
.89604 .00495 m
.89604 .25247 L
.9703 .25247 L
.9703 .00495 L
F
1 0 1 r
.04 w
.64169 .6004 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P000182000`400?l00000o`00003ooooooolQ
ooooo`00ool0000Po`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`00
00?o0000ooooooooool0o_oooolEo`00o`Sooooo0Ol00001ooooo`0000?o0000ooooooooool0o_oo
oolEo`00o`Sooooo0Ol00001ooooo`0000?o0000ooooooooool0o_oooolEo`00o`Sooooo0Ol00001
ooooo`0000?o0000ooooooooool0o_oooolEo`00o`Sooooo0Ol00001ooooo`0000?o0000oooooooo
ool0o_oooolEo`00o`Sooooo0Ol00001ooooo`0000?o0000ooooooooool0o_oooolEo`00o`Sooooo
0Ol00001ooooo`0000?o0000ooooooooool0o_oooolEo`00o`Sooooo0Ol00001ooooo`0000?o0000
ooooooooool0o_oooolEo`00o`Sooooo0Ol00001ooooo`0000?o0000ooooooooool0o_oooolEo`00
o`Sooooo0Ol00001ooooo`0000?o0000ooooooooool0o_oooolEo`00o`Sooooo0Ol00001ooooo`00
00?o0000ooooooooool0o_oooolEo`00o`Sooooo0Ol00001ooooo`0000?o0000ooooooooool0o_oo
oolEo`00o`Sooooo0Ol00001ooooo`0000?o0000ooooooooool0o_oooolEo`00o`Sooooo0Ol00001
ooooo`0000?o0000ooooooooool0o_oooolEo`00o`Sooooo0Ol00001ooooo`0000?o0000oooooooo
ool0o_oooolEo`00o`Sooooo0Ol00001ooooo`0000?o0000ooooooooool0o_oooolEo`00o`Sooooo
0Ol00001ooooo`0000?o0000ooooooooool0o_oooolEo`00o`Sooooo0Ol00001ooooo`0000?o0000
ooooooooool0o_oooolEo`00o`Sooooo0Ol00001ooooo`0000?o0000ooooooooool0o_oooolEo`00
o`Sooooo0Ol00001ooooo`0000?o0000ooooooooool0o_oooolEo`00o`Sooooo0Ol00001ooooo`00
00?o0000ooooooooool0o_oooolEo`00o`Sooooo0Ol00001ooooo`0000?o0000ooooooooool0o_oo
oolEo`00o`Sooooo0Ol00001ooooo`0000?o0000ooooooooool0o_oooolEo`00o`Sooooo0Ol00001
ooooo`0000?o0000ooooooooool0o_oooolEo`00o`Sooooo0Ol00001ooooo`0000?o0000oooooooo
ool0o_oooolEo`00o`Sooooo0Ol00001ooooo`0000?o0000ooooooooool0o_oooolEo`00o`Sooooo
0Ol00001ooooo`0000?o0000ooooooooool0o_oooolEo`00o`Sooooo0Ol00001ooooo`0000?o0000
ooooooooool0o_oooolEo`00o`Sooooo0Ol00001ooooo`0000?o0000ooooooooool0o_oooolEo`00
o`Sooooo0Ol00001ooooo`0000?o0000ooooooooool0o_oooolEo`00o`Sooooo0Ol00001ooooo`00
00?o0000ooooooooool0o_oooolEo`00o`Sooooo0Ol00001ooooo`0000?o0000ooooooooool0o_oo
oolEo`00o`Sooooo0Ol00001ooooo`0000?o0000ooooooooool01_ooool2oomo0?Kooooo5Ol00?l8
ooooo`7o00000Oooool00003o`000?oooooooooo00Gooooo1?ooO`0Cooooo`;oogl0h?oooolEo`00
o`Sooooo0Ol00001ooooo`0000?o0000ooooooooool01Oooool4oomo01;ooooo1?ooO`0Booooo`;o
ogl0booooolEo`00o`Sooooo0Ol00001ooooo`0000?o0000ooooooooool01Oooool3oomo01?ooooo
1?ooO`0Aooooo`Coogl0b_oooolEo`00o`Sooooo0Ol00001ooooo`0000?o0000ooooooooool01?oo
ool4oomo01Cooooo0_ooO`0Booooo`Coogl0b_oooolEo`00o`Sooooo0Ol00001ooooo`0000?o0000
ooooooooool01?ooool4oomo02Wooooo0_ooO`3;oooooaGo003o2?ooool1o`00007ooooo00000ol0
003oooooooooo`05ooooo`;oogl0mooooolEo`00o`Sooooo0Ol00001ooooo`0000?o0000oooooooo
ool0o_oooolEo`00o`Sooooo0Ol00001ooooo`0000?o0000ooooooooool0o_oooolEo`00o`Sooooo
0Ol00001ooooo`0000?o0000ooooooooool0o_oooolEo`00o`Sooooo0Ol00001ooooo`0000?o0000
ooooooooool0o_oooolEo`00o`Sooooo0Ol00001ooooo`0000?o0000ooooooooool0o_oooolEo`00
o`Sooooo0Ol00001ooooo`0000?o0000ooooooooool0o_oooolEo`00o`Sooooo0Ol00001ooooo`00
00?o0000ooooooooool0o_oooolEo`00o`Sooooo0Ol00001ooooo`0000?o0000ooooooooool0:_oo
ool6ool00<kooooo5Ol00?l8ooooo`7o00000Oooool00003o`000?oooooooooo02Wooooo00?oo`00
ooooooooool01?ooool5ool00<Wooooo5Ol00?l8ooooo`7o00000Oooool00003o`000?oooooooooo
02Oooooo0_oo000<ooooo`Coo`00aOoooolEo`00o`Sooooo0Ol00001ooooo`0000?o0000oooooooo
ool09_ooool00ooo003oooooooooo`0@ooooo`Coo`00`OoooolEo`00o`Sooooo0Ol00001ooooo`00
00?o0000ooooooooool09?ooool00oooO`3oo`00ooooo`09ooooo`;oogl02oooool3ool00;kooooo
5Ol00?l8ooooo`7o00000Oooool00003o`000?oooooooooo02?ooooo00Coogl0ool00?ooO`3oogl0
2?ooool4oomo00gooooo00?oo`00ooooooooool0^ooooolEo`00o`Sooooo0Ol00001ooooo`0000?o
0000ooooooooool08oooool01?ooO`3oo`00oomo0?ooO`08ooooo`Coogl03_ooool2ool00;_ooooo
5Ol00?l8ooooo`7o00000Oooool00003o`000?oooooooooo02Cooooo00?oogl0ool00?ooool02Ooo
ool2oomo017ooooo0_oo002ioooooaGo003o2?ooool1o`00007ooooo00000ol0003oooooooooo`0U
ooooo`03ool00?oooooooooo01gooooo0_oo002goooooaGo003o2?ooool1o`00007ooooo00000ol0
003oooooooooo`0Uooooo`03ool00?oooooooooo01oooooo0_oo002eoooooaGo003o2?ooool1o`00
007ooooo00000ol0003oooooooooo`0Vooooo`03ool00?oooooooooo017ooooo0_ooO`0=ooooo`;o
o`001?ooool2oomo00Oooooo0_ooO`2ToooooaGo003o2?ooool1o`00007ooooo00000ol0003ooooo
ooooo`0Vooooo`03ool00?oooooooooo00Gooooo0_ooO`09ooooo`Coogl03_ooool00ooo003ooooo
ooooo`04oomo00Gooooo1?ooO`2SoooooaGo003o2?ooool1o`00007ooooo00000ol0003ooooooooo
o`0Vooooo`03ool00?oooooooooo00Cooooo1?ooO`08ooooo`Coogl03oooool00ooo003ooooooomo
0003oomo00Gooooo1?ooO`2SoooooaGo003o2?ooool1o`00007ooooo00000ol0003oooooooooo`0W
ooooo`03ool00?oooooooooo00?ooooo1?ooO`09ooooo`;oogl04Oooool01?oo003ooooooomo0?oo
O`07ooooo`?oogl0XooooolEo`00o`Sooooo0Ol00001ooooo`0000?o0000ooooooooool09oooool0
0ooo003oooooooooo`04ooooo`;oogl07_ooool00ooo003oooooooooo`07ooooo`Coogl0X_oooolE
o`00o`Sooooo0Ol00001ooooo`0000?o0000ooooooooool0:?ooool00ooo003oooooooooo`0Toooo
o`03ool00?oooooooooo00Kooooo1?ooO`2RoooooaGo003o2?ooool1o`00007ooooo00000ol0003o
ooooooooo`0Yooooo`03ool00?oooooooooo02Cooooo0_oo00000oooooooogl0oomo0004ooooo`;o
ogl0XooooolEo`00o`Sooooo0Ol00001ooooo`0000?o0000ooooooooool0:_ooool00ooo003ooooo
ooooo`0Cooooo`Coo`003_ooool01?oo003oogl0oomo0?ooO`2XoooooaGo003o2?ooool1o`00007o
oooo00000ol0003oooooooooo`0[ooooo`03ool00?oooooooooo017ooooo1_oo000=ooooo`04oomo
0?oo003oo`00oomo0:Sooooo5Ol00?l8ooooo`7o00000Oooool00003o`000?oooooooooo02cooooo
00?oo`00ooooooooool02?ooool2oomo00Gooooo2?oo000=ooooo`;oogl000?oo`00ooooooooool0
Y_oooolEo`00o`Sooooo0Ol00001ooooo`0000?o0000ooooooooool0;Oooool00ooo003ooooooooo
o`06ooooo`Coogl01?ooool8ool0013ooooo00?oo`00ooooooooool0YOoooolEo`00o`Sooooo0Ol0
0001ooooo`0000?o0000ooooooooool0:oooool2oomo0003oooooooo003ooooo00Kooooo1?ooO`04
ooooo`Soo`004Oooool00ooo003oooooooooo`2ToooooaGo003o2?ooool1o`00007ooooo00000ol0
003oooooooooo`0Zooooo`Coogl000?oooooool00?ooool01_ooool2oomo00Gooooo2?oo000;oooo
o`;oogl01Oooool00ooo003oooooooooo`09ooooo`;oogl0V?oooolEo`00o`Sooooo0Ol00001oooo
o`0000?o0000ooooooooool0:_ooool4oomo00;ooooo00?oo`00ooooooooool03?ooool6ool000_o
oooo1?ooO`04ooooo`03ool00?oooooooooo00Sooooo1?ooO`2GoooooaGo003o2?ooool1o`00007o
oooo00000ol0003oooooooooo`0[ooooo`;oogl01?ooool00ooo003oooooooooo`0<ooooo`Coo`00
3?ooool4oomo00Gooooo00?oo`00ooooooooool01oooool4oomo09Oooooo5Ol00?l8ooooo`7o0000
0Oooool00003o`000?oooooooooo03;ooooo0_oo000Mooooo`;oogl01oooool00ooo003ooooooooo
o`07ooooo`;oogl0]Oooool1o`00007ooooo00000ol0003oooooooooo`0dooooo`03ool00?oooooo
oooo02Cooooo00?oo`00ooooooooool0_Oooool1o`00007ooooo00000ol0003oooooooooo`0eoooo
o`03ool00?oooooooooo02Cooooo00?oo`00ooooooooool0_?ooool1o`00007ooooo00000ol0003o
ooooooooo`0fooooo`;oo`009Oooool00ooo003oooooooooo`2kooooo`7o00000Oooool00003o`00
0?oooooooooo03Sooooo0_oo00000oooO`3oooooooooo`02oomo01kooooo00?oo`00ooooooooool0
^oooool1o`00007ooooo00000ol0003oooooooooo`0hooooo`;oogl00_oo0004oomo01kooooo00?o
o`00ooooooooool0^_ooool1o`00007ooooo00000ol0003oooooooooo`0hooooo`Coogl00_oo0002
oomo01kooooo00?oo`00ooooooooool0^_ooool1o`00007ooooo00000ol0003oooooooooo`0ioooo
o`Googl000?oo`00ooooooooool07Oooool00ooo003oogl0oomo002jooooo`7o00000Oooool00003
o`000?oooooooooo03_ooooo1?ooO`02ool001gooooo00Coogl0ool00?ooO`3oogl0^Oooool1o`00
007ooooo00000ol0003oooooooooo`0looooo`;oogl00oooool2ool001_ooooo00Coogl0ool00?oo
O`3oogl0^Oooool1o`00007ooooo00000ol0003oooooooooo`13ooooo`;oo`006_ooool00oooO`3o
o`00ooooo`2iooooo`7o00000Oooool00003o`000?oooooooooo04Gooooo0_oo000Iooooo`03ool0
0?oooooooooo0;Sooooo0Ol00001ooooo`0000?o0000ooooooooool0Aoooool2ool001Gooooo0_oo
002kooooo`7o00000Oooool00003o`000?oooooooooo04Wooooo0ooo000@ooooo`;oo`00_Oooool1
o`00007ooooo00000ol0003oooooooooo`0aooooo`;oogl06Oooool3ool000cooooo00?oo`00oooo
ooooool0_Oooool1o`00007ooooo00000ol0003oooooooooo`0`ooooo`Coogl06oooool6ool000Co
oooo0_oo0030ooooo`7o00000Oooool00003o`000?oooooooooo033ooooo1?ooO`0Qooooo`Coo`00
`_ooool1o`00007ooooo00000ol0003oooooooooo`0aooooo`;oogl0j?ooool1o`00007ooooo0000
0ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLoooo
o`7o00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003ooooo
ooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Ooo
ool00003o`000?oooooooooo07gooooo0_ooO`2Looooo`7o00000Oooool00003o`000?oooooooooo
07cooooo1?ooO`2Kooooo`7o00000Oooool00003o`000?oooooooooo05Cooooo0_ooO`0Vooooo`Co
ogl0Voooool1o`00007ooooo00000ol0003oooooooooo`1Cooooo`Coogl09_ooool2oomo09cooooo
0Ol00001ooooo`0000?o0000ooooooooool0Doooool4oomo0<Cooooo0Ol00001ooooo`0000?o0000
ooooooooool0E?ooool2oomo0<Gooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLoooo
o`7o00000Oooool00003o`000?oooooooooo06?ooooo0_ooO`04ooooo`;oogl0/?ooool1o`00007o
oooo00000ol0003oooooooooo`1Rooooo`Coogl00_ooool4oomo0:oooooo0Ol00001ooooo`0000?o
0000ooooooooool0H_ooool4oomo00;ooooo1?ooO`2_ooooo`7o00000Oooool00003o`000?oooooo
oooo06?ooooo0_ooO`04ooooo`;oogl0/?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooo
oacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`00
0?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol0
0001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo
0?oooooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`00
00?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?oo
ool1o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000oooo
ooooool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007o
oooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooo
oolLooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0
003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o
00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003ooooooooo
o`3ooooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool0
0003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooooaco
oooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oo
oooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001
ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo0?oo
oooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o
0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1
o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000oooooooo
ool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo
00000ol0003oooooooooo`3oooooo`Cooooo0_ooO`0Fooooo`7o00000Oooool00003o`000?oooooo
oooo0?oooooo0oooool4oomo01Gooooo0Ol00001ooooo`0000?o0000ooooooooool0ooooool3oooo
o`Coogl05Oooool1o`00007ooooo00000ol0003oooooooooo`3oooooo`Cooooo0_ooO`0Fooooo`7o
00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003ooooooooo
o`3ooooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool0
0003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooooaco
oooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oo
oooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001
ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo0?oo
oooo7?ooool1o`00007ooooo00000ol0003oooooooooo`2eooooo`;oogl0I?ooool1o`00007ooooo
00000ol0003oooooooooo`2dooooo`Coogl0Hoooool1o`00007ooooo00000ol0003oooooooooo`2d
ooooo`Coogl0Hoooool1o`00007ooooo00000ol0003oooooooooo`2eooooo`;oogl0=Oooool2oomo
02gooooo0Ol00001ooooo`0000?o0000ooooooooool0i?ooool2oomo00Gooooo1?ooO`0/ooooo`7o
00000Oooool00003o`000?oooooooooo0>?ooooo1?ooO`04ooooo`Coogl0;?ooool1o`00007ooooo
00000ol0003oooooooooo`33ooooo`;oogl07_ooool4oomo00Gooooo0_ooO`0]ooooo`7o00000Ooo
ool00003o`000?oooooooooo0<;ooooo1?ooO`0;o`00oa?ooooo0_ooO`0eooooo`7o00000Oooool0
0003o`000?oooooooooo0<;ooooo1?l00?l;ooooo`;o003oB?ooool1o`00007ooooo00000ol0003o
ooooooooo`2nooooo`Co003o00?ooooooomo0?ooO`003_ooool2o`00odKooooo0Ol00001ooooo`00
00?o0000ooooooooool0^Oooool2oomo00?o003o5oooool2o`00o`Wooooo0_ooO`0iooooo`7o0000
0Oooool00003o`000?oooooooooo0;Oooooo1?l00?l00oooO`3oooooooooo`0Iooooo`;o003o1_oo
ool4oomo03Sooooo0Ol00001ooooo`0000?o0000ooooooooool0]?ooool3o`00o`03ooooooooO`3o
ogl000;oogl07?ooool00ol00?ooooooooooo`04ooooo`Coogl00oooool2oomo03?ooooo0Ol00001
ooooo`0000?o0000ooooooooool0/_ooool5ool0o`;ooooo0_ooO`0Cooooo`;oogl02?ooool00ol0
0?ooooooooooo`05ooooo`;oogl00oooool4oomo03;ooooo0Ol00001ooooo`0000?o0000oooooooo
ool0/?ooool00ol00?ooo`3oool0o`05ool0o`Gooooo0_ooO`0>ooooo`Coogl01oooool00ol00?oo
ooooooooo`0:ooooo`Coogl0<_ooool1o`00007ooooo00000ol0003oooooooooo`2^ooooo`;o003o
2Ooo0?l3ooooo`Coogl03Oooool4oomo00Oooooo00?o003oooooooooool02oooool2oomo03?ooooo
0Ol00001ooooo`0000?o0000ooooooooool0Roooool2oomo023ooooo00?o003ooooooooo0?l02_oo
0?l2ooooo`Coogl03_ooool2oomo00Wooooo00?o003oooooooooool0?oooool1o`00007ooooo0000
0ol0003oooooooooo`2:ooooo`Coogl07Oooool2o`00o`;ooooo2ooo0?l3ooooo`;oogl06_ooool0
0ol00?ooooooooooo`0oooooo`7o00000Oooool00003o`000?oooooooooo08[ooooo1?ooO`0Loooo
o`03o`00oooooooooooo00;ooooo2ooo0?lOooooo`03o`00oooooooooooo03oooooo0Ol00001oooo
o`0000?o0000ooooooooool0Roooool2oomo01_ooooo0_l00?l5ooooo`_oo`3o7oooool00ol00?oo
ooooooooo`0oooooo`7o00000Oooool00003o`000?oooooooooo09Kooooo0_ooO`0>ooooo`;o003o
1oooool;ool0oaSooooo0_ooO`05ooooo`03o`00oooooooooooo03oooooo0Ol00001ooooo`0000?o
0000ooooooooool0UOooool4oomo00cooooo00Co003oooooooooO`3oogl01oooool9ool0oaSooooo
1?ooO`03ooooo`03o`00oooooooooooo043ooooo0Ol00001ooooo`0000?o0000ooooooooool0UOoo
ool4oomo00[ooooo0_l00?l00oooooooogl0oomo0002oomo00Oooooo1ooo0?lIooooo`Coogl00ooo
ool00ol00?ooooooooooo`10ooooo`7o00000Oooool00003o`000?oooooooooo09Kooooo0_ooO`0:
ooooo`04o`00ooooooooooooooooo`Coogl02?ooool5ool0oa_ooooo0_ooO`04ooooo`03o`00oooo
oooooooo043ooooo0Ol00001ooooo`0000?o0000ooooooooool0XOooool00ol00?ooooooooooo`03
ooooo`;oogl0;_ooool00ol00?ooooooooooo`11ooooo`7o00000Oooool00003o`000?oooooooooo
0:3ooooo00?o003oooooooooool0<oooool00ol00?ooooooooooo`0Booooo`;oogl0;_ooool1o`00
007ooooo00000ol0003oooooooooo`2Nooooo`;o003o=Oooool00ol00?ooooooooooo`0Booooo`Co
ogl0;Oooool1o`00007ooooo00000ol0003oooooooooo`2Mooooo`03o`00oooooooooooo01Gooooo
1?l00?lLooooo`03o`00ooooO`3oogl001;ooooo1?ooO`0]ooooo`7o00000Oooool00003o`000?oo
oooooooo09cooooo00?o003oooooooooool05Oooool6o`00oa[ooooo00?o003ooomo0?ooO`000_oo
O`0Booooo`;oogl0;_ooool1o`00007ooooo00000ol0003oooooooooo`2Kooooo`03o`00oooooooo
oooo01Gooooo2?l00?lHooooo`03o`00ooooooooogl000?oogl0@_ooool1o`00007ooooo00000ol0
003oooooooooo`2Kooooo`03o`00oooooooooooo01Gooooo2?l00?lGooooo`04o`00oooooooooooo
ooooo`;oogl0@oooool1o`00007ooooo00000ol0003oooooooooo`2Jooooo`03o`00oooooooooooo
01Kooooo2?l00?lFooooo`03o`00oooooooooooo04Oooooo0Ol00001ooooo`0000?o0000oooooooo
ool0VOooool00ol00?ooooooooooo`0<ooooo`;oogl02?ooool00oooO`3o003oo`00o`06o`00oaGo
oooo00?o003oooooooooool00_ooO`16ooooo`7o00000Oooool00003o`000?oooooooooo09Wooooo
00?o003oooooooooool02_ooool5oomo00Oooooo0_ooO`06o`00oa?ooooo0_ooO`000ol00?oooooo
ooooo`04oomo04Gooooo0Ol00001ooooo`0000?o0000ooooooooool0V?ooool00ol00?oooooooooo
o`0:ooooo`Koogl02?ooool2oomo00Co003o4oooool2oomo00;o003o0_ooool4oomo04Gooooo0Ol0
0001ooooo`0000?o0000ooooooooool0V?ooool00ol00?ooooooooooo`0:ooooo`Googl08_ooool0
1?ooO`3o003ooomo0?ooO`03ooooo`;oogl0A_ooool1o`00007ooooo00000ol0003oooooooooo`1f
ooooo`;oogl07oooool00ol00?ooooooooooo`0<ooooo`;oogl09?ooool00ol00?ooogl0oomo001<
ooooo`7o00000Oooool00003o`000?oooooooooo07Gooooo1?ooO`0Nooooo`03o`00oooooooooooo
037ooooo00?o003oooooooooool0COooool1o`00007ooooo00000ol0003oooooooooo`1eooooo`Co
ogl02_ooool2oomo017ooooo00?o003oooooooooool0<Oooool00ol00?ooooooooooo`1>ooooo`7o
00000Oooool00003o`000?oooooooooo07Kooooo0_ooO`0:ooooo`Coogl03oooool00ol00?oooooo
ooooo`0Hooooo`;oogl05oooool00ol00?ooooooooooo`1?ooooo`7o00000Oooool00003o`000?oo
oooooooo08;ooooo1?ooO`0?ooooo`03o`00oooooooooooo01Oooooo1?ooO`0Dooooo`;o003oD_oo
ool1o`00007ooooo00000ol0003oooooooooo`23ooooo`;oogl03oooool00ol00?ooooooooooo`0B
ooooo`;oogl01?ooool4oomo017ooooo0ol00?mDooooo`7o00000Oooool00003o`000?oooooooooo
09Cooooo00?o003oooooooooool04Oooool4oomo00Cooooo0_ooO`0@ooooo`;o003oEoooool1o`00
007ooooo00000ol0003oooooooooo`2Dooooo`03o`00oooooooooooo017ooooo1?ooO`0Eooooo`03
o`00oooooooooooo05Oooooo0Ol00001ooooo`0000?o0000ooooooooool0U?ooool00ol00?oooooo
ooooo`0Booooo`;oogl05?ooool2o`00oe[ooooo0Ol00001ooooo`0000?o0000ooooooooool0U?oo
ool00ol00?ooooooooooo`0Vooooo`;o003oG?ooool1o`00007ooooo00000ol0003oooooooooo`2E
ooooo`03o`00oooooooooooo02Cooooo00?o003oooooooooool0G?ooool1o`00007ooooo00000ol0
003oooooooooo`2Eooooo`03o`00oooooooooooo02;ooooo0_l00?mOooooo`7o00000Oooool00003
o`000?oooooooooo09Gooooo00?o003oooooooooool08?ooool2o`00of7ooooo0Ol00001ooooo`00
00?o0000ooooooooool0Q?ooool2oomo00oooooo0_l00?lOooooo`;o003oHoooool1o`00007ooooo
00000ol0003oooooooooo`23ooooo`Coogl04?ooool2o`00oa[ooooo0ol00?mUooooo`7o00000Ooo
ool00003o`000?oooooooooo08?ooooo1?ooO`0Booooo`;o003o5?ooool4o`00ofSooooo0Ol00001
ooooo`0000?o0000ooooooooool0Q?ooool2oomo01Gooooo0ol00?l>ooooo`?o003o0oooool2oomo
06Oooooo0Ol00001ooooo`0000?o0000ooooooooool0W_ooool3o`00o`Gooooo1_l00?l5ooooo`Co
ogl0I_ooool1o`00007ooooo00000ol0003oooooooooo`2Qooooo`Go003o2oooool4oomo06Kooooo
0Ol00001ooooo`0000?o0000ooooooooool0/_ooool2oomo06Oooooo0Ol00001ooooo`0000?o0000
ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00
007ooooo00000ol0003oooooooooo`1kooooo`;oogl0W_ooool1o`00007ooooo00000ol0003ooooo
ooooo`1jooooo`Coogl0WOooool1o`00007ooooo00000ol0003oooooooooo`1jooooo`Coogl08?oo
ool2oomo07_ooooo0Ol00001ooooo`0000?o0000ooooooooool0Noooool2oomo023ooooo1?ooO`1j
ooooo`7o00000Oooool00003o`000?oooooooooo09gooooo1?ooO`1jooooo`7o00000Oooool00003
o`000?oooooooooo093ooooo0_ooO`0<ooooo`;oogl0Noooool1o`00007ooooo00000ol0003ooooo
ooooo`2?ooooo`Coogl0R?ooool1o`00007ooooo00000ol0003oooooooooo`2?ooooo`Coogl0R?oo
ool1o`00007ooooo00000ol0003oooooooooo`2@ooooo`;oogl08oooool2oomo06Cooooo0Ol00001
ooooo`0000?o0000ooooooooool0]?ooool4oomo06?ooooo0Ol00001ooooo`0000?o0000oooooooo
ool0]?ooool4oomo06?ooooo0Ol00001ooooo`0000?o0000ooooooooool0]Oooool2oomo06Cooooo
0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oooooo
oooo0?oooooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001oooo
o`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo
7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000
ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00
007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0
oooooolLooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo0000
0ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLoooo
o`7o00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003ooooo
ooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Ooo
ool00003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooo
oacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`00
0?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol0
0001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo
0?oooooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`00
00?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?oo
ool1o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000oooo
ooooool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007o
oooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooo
oolLooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0
003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o
00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003ooooooooo
o`3ooooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool0
0003o`000?oooooooooo08kooooo0_ooO`2;ooooo`7o00000Oooool00003o`000?oooooooooo08go
oooo1?ooO`2:ooooo`7o00000Oooool00003o`000?oooooooooo08gooooo1?ooO`2:ooooo`7o0000
0Oooool00003o`000?oooooooooo08kooooo0_ooO`2;ooooo`7o00000Oooool00003o`000?oooooo
oooo0?oooooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001oooo
o`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo
7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000
ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00
007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0
oooooolLooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo0000
0ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLoooo
o`7o00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003ooooo
ooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Ooo
ool00003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooo
oacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`00
0?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol0
0001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool00?oo00008?l00001oooo
o`00\
\>"],
  ImageRangeCache->{{{0, 287}, {287, 0}} -> {-1.01089, -1.01089, 0.00704453, \
0.00704453}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.49505 0.5 0.49505 [
[ 0 0 -0.125 0 ]
[ 0 0 -0.125 0 ]
[ 0 1 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
0 0 m
1 0 L
s
0 0 m
0 1 L
s
0 1 m
1 1 L
s
1 0 m
1 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
1 .5 0 r
.015 w
.03175 .1355 Mdot
.03435 .12523 Mdot
.11137 .12765 Mdot
.14107 .18841 Mdot
.16218 .24538 Mdot
.17294 .21053 Mdot
.18267 .18577 Mdot
.18434 .1304 Mdot
.18553 .30956 Mdot
.20401 .239 Mdot
.21247 .27571 Mdot
.21687 .20845 Mdot
.22376 .2799 Mdot
.22832 .27485 Mdot
.29063 .20974 Mdot
.29686 .25079 Mdot
.30487 .22936 Mdot
.30683 .34623 Mdot
.32055 .20902 Mdot
.32574 .21979 Mdot
.34472 .28521 Mdot
.35998 .36393 Mdot
.36335 .24976 Mdot
.3794 .36608 Mdot
.42386 .66992 Mdot
.44391 .74519 Mdot
.45059 .34198 Mdot
.47208 .67586 Mdot
.47436 .71381 Mdot
.49778 .59825 Mdot
.50874 .91643 Mdot
.51516 .76219 Mdot
.53655 .61374 Mdot
.56563 .75219 Mdot
.59189 .65665 Mdot
.59581 .61604 Mdot
.59923 .6556 Mdot
.60292 .68499 Mdot
.62656 .67779 Mdot
.63555 .72451 Mdot
.63919 .652 Mdot
.64169 .6004 Mdot
.64246 .58611 Mdot
.64496 .54267 Mdot
.64608 .77288 Mdot
.65077 .64308 Mdot
.66065 .57816 Mdot
.67474 .59169 Mdot
.69296 .563 Mdot
.72815 .65902 Mdot
.73169 .58879 Mdot
.74669 .61318 Mdot
.74821 .65474 Mdot
.75963 .63781 Mdot
.79673 .57809 Mdot
.80925 .55852 Mdot
.81525 .58444 Mdot
.83417 .62985 Mdot
.83598 .55526 Mdot
.91595 .49319 Mdot
1 0 0 r
.005 w
.16128 .17044 m
.18734 .17269 L
.21339 .17909 L
.2345 .18734 L
.23945 .19126 L
.2655 .20415 L
.27874 .21339 L
.29156 .22295 L
.31204 .23945 L
.31761 .24532 L
.33549 .2655 L
.34367 .28341 L
.34499 .29156 L
.34367 .29798 L
.31761 .3104 L
.29156 .30711 L
.2655 .30014 L
.24507 .29156 L
.23945 .28747 L
.21339 .27402 L
.20155 .2655 L
.18734 .25472 L
.16884 .23945 L
.16128 .2313 L
.14618 .21339 L
.13806 .18734 L
.16128 .17044 L
s
0 0 1 r
.65633 .57701 m
.68239 .56842 L
.70844 .56313 L
.7345 .56168 L
.76055 .5752 L
.76359 .57817 L
.76859 .60422 L
.76055 .62333 L
.75627 .63028 L
.7345 .65485 L
.73298 .65633 L
.70844 .6775 L
.69922 .68239 L
.68239 .69294 L
.65633 .70579 L
.64983 .70844 L
.63028 .71539 L
.60422 .72268 L
.57817 .72651 L
.55211 .7214 L
.53145 .70844 L
.52926 .68239 L
.54239 .65633 L
.55211 .63983 L
.56625 .63028 L
.57817 .6193 L
.60119 .60422 L
.60422 .60227 L
.63028 .58726 L
.65315 .57817 L
.65633 .57701 L
s
1 0 0 r
.03 w
.24141 .24033 Mdot
0 0 1 r
.64872 .64417 Mdot
1 0 0 r
.79703 .00495 m
.79703 .00495 L
.87129 .00495 L
.87129 .00495 L
F
0 0 1 r
.89604 .00495 m
.89604 .25247 L
.9703 .25247 L
.9703 .00495 L
F
1 0 1 r
.04 w
.64246 .58611 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P000182000`400?l00000o`00003ooooooolQ
ooooo`00ool0000Po`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`00
00?o0000ooooooooool0o_oooolEo`00o`Sooooo0Ol00001ooooo`0000?o0000ooooooooool0o_oo
oolEo`00o`Sooooo0Ol00001ooooo`0000?o0000ooooooooool0o_oooolEo`00o`Sooooo0Ol00001
ooooo`0000?o0000ooooooooool0o_oooolEo`00o`Sooooo0Ol00001ooooo`0000?o0000oooooooo
ool0o_oooolEo`00o`Sooooo0Ol00001ooooo`0000?o0000ooooooooool0o_oooolEo`00o`Sooooo
0Ol00001ooooo`0000?o0000ooooooooool0o_oooolEo`00o`Sooooo0Ol00001ooooo`0000?o0000
ooooooooool0o_oooolEo`00o`Sooooo0Ol00001ooooo`0000?o0000ooooooooool0o_oooolEo`00
o`Sooooo0Ol00001ooooo`0000?o0000ooooooooool0o_oooolEo`00o`Sooooo0Ol00001ooooo`00
00?o0000ooooooooool0o_oooolEo`00o`Sooooo0Ol00001ooooo`0000?o0000ooooooooool0o_oo
oolEo`00o`Sooooo0Ol00001ooooo`0000?o0000ooooooooool0o_oooolEo`00o`Sooooo0Ol00001
ooooo`0000?o0000ooooooooool0o_oooolEo`00o`Sooooo0Ol00001ooooo`0000?o0000oooooooo
ool0o_oooolEo`00o`Sooooo0Ol00001ooooo`0000?o0000ooooooooool0o_oooolEo`00o`Sooooo
0Ol00001ooooo`0000?o0000ooooooooool0o_oooolEo`00o`Sooooo0Ol00001ooooo`0000?o0000
ooooooooool0o_oooolEo`00o`Sooooo0Ol00001ooooo`0000?o0000ooooooooool0o_oooolEo`00
o`Sooooo0Ol00001ooooo`0000?o0000ooooooooool0o_oooolEo`00o`Sooooo0Ol00001ooooo`00
00?o0000ooooooooool0o_oooolEo`00o`Sooooo0Ol00001ooooo`0000?o0000ooooooooool0o_oo
oolEo`00o`Sooooo0Ol00001ooooo`0000?o0000ooooooooool0o_oooolEo`00o`Sooooo0Ol00001
ooooo`0000?o0000ooooooooool0o_oooolEo`00o`Sooooo0Ol00001ooooo`0000?o0000oooooooo
ool0o_oooolEo`00o`Sooooo0Ol00001ooooo`0000?o0000ooooooooool0o_oooolEo`00o`Sooooo
0Ol00001ooooo`0000?o0000ooooooooool0o_oooolEo`00o`Sooooo0Ol00001ooooo`0000?o0000
ooooooooool0o_oooolEo`00o`Sooooo0Ol00001ooooo`0000?o0000ooooooooool0o_oooolEo`00
o`Sooooo0Ol00001ooooo`0000?o0000ooooooooool0o_oooolEo`00o`Sooooo0Ol00001ooooo`00
00?o0000ooooooooool0o_oooolEo`00o`Sooooo0Ol00001ooooo`0000?o0000ooooooooool0o_oo
oolEo`00o`Sooooo0Ol00001ooooo`0000?o0000ooooooooool01_ooool2oomo0?Kooooo5Ol00?l8
ooooo`7o00000Oooool00003o`000?oooooooooo00Gooooo1?ooO`0Cooooo`;oogl0h?oooolEo`00
o`Sooooo0Ol00001ooooo`0000?o0000ooooooooool01Oooool4oomo01;ooooo1?ooO`0Booooo`;o
ogl0booooolEo`00o`Sooooo0Ol00001ooooo`0000?o0000ooooooooool01Oooool3oomo01?ooooo
1?ooO`0Aooooo`Coogl0b_oooolEo`00o`Sooooo0Ol00001ooooo`0000?o0000ooooooooool01?oo
ool4oomo01Cooooo0_ooO`0Booooo`Coogl0b_oooolEo`00o`Sooooo0Ol00001ooooo`0000?o0000
ooooooooool01?ooool4oomo02Wooooo0_ooO`3;oooooaGo003o2?ooool1o`00007ooooo00000ol0
003oooooooooo`05ooooo`;oogl0mooooolEo`00o`Sooooo0Ol00001ooooo`0000?o0000oooooooo
ool0o_oooolEo`00o`Sooooo0Ol00001ooooo`0000?o0000ooooooooool0o_oooolEo`00o`Sooooo
0Ol00001ooooo`0000?o0000ooooooooool0o_oooolEo`00o`Sooooo0Ol00001ooooo`0000?o0000
ooooooooool0o_oooolEo`00o`Sooooo0Ol00001ooooo`0000?o0000ooooooooool0o_oooolEo`00
o`Sooooo0Ol00001ooooo`0000?o0000ooooooooool0o_oooolEo`00o`Sooooo0Ol00001ooooo`00
00?o0000ooooooooool0o_oooolEo`00o`Sooooo0Ol00001ooooo`0000?o0000ooooooooool0:_oo
ool6ool00<kooooo5Ol00?l8ooooo`7o00000Oooool00003o`000?oooooooooo02Wooooo00?oo`00
ooooooooool01?ooool5ool00<Wooooo5Ol00?l8ooooo`7o00000Oooool00003o`000?oooooooooo
02Oooooo0_oo000<ooooo`Coo`00aOoooolEo`00o`Sooooo0Ol00001ooooo`0000?o0000oooooooo
ool09_ooool00ooo003oooooooooo`0@ooooo`Coo`00`OoooolEo`00o`Sooooo0Ol00001ooooo`00
00?o0000ooooooooool09?ooool00oooO`3oo`00ooooo`09ooooo`;oogl02oooool3ool00;kooooo
5Ol00?l8ooooo`7o00000Oooool00003o`000?oooooooooo02?ooooo00Coogl0ool00?ooO`3oogl0
2?ooool4oomo00gooooo00?oo`00ooooooooool0^ooooolEo`00o`Sooooo0Ol00001ooooo`0000?o
0000ooooooooool08oooool01?ooO`3oo`00oomo0?ooO`08ooooo`Coogl03_ooool2ool00;_ooooo
5Ol00?l8ooooo`7o00000Oooool00003o`000?oooooooooo02Cooooo00?oogl0ool00?ooool02Ooo
ool2oomo017ooooo0_oo002ioooooaGo003o2?ooool1o`00007ooooo00000ol0003oooooooooo`0U
ooooo`03ool00?oooooooooo01gooooo0_oo002goooooaGo003o2?ooool1o`00007ooooo00000ol0
003oooooooooo`0Uooooo`03ool00?oooooooooo01oooooo0_oo002eoooooaGo003o2?ooool1o`00
007ooooo00000ol0003oooooooooo`0Vooooo`03ool00?oooooooooo017ooooo0_ooO`0=ooooo`;o
o`001?ooool2oomo00Oooooo0_ooO`2ToooooaGo003o2?ooool1o`00007ooooo00000ol0003ooooo
ooooo`0Vooooo`03ool00?oooooooooo00Gooooo0_ooO`09ooooo`Coogl03_ooool00ooo003ooooo
ooooo`04oomo00Gooooo1?ooO`2SoooooaGo003o2?ooool1o`00007ooooo00000ol0003ooooooooo
o`0Vooooo`03ool00?oooooooooo00Cooooo1?ooO`08ooooo`Coogl03oooool00ooo003ooooooomo
0003oomo00Gooooo1?ooO`2SoooooaGo003o2?ooool1o`00007ooooo00000ol0003oooooooooo`0W
ooooo`03ool00?oooooooooo00?ooooo1?ooO`09ooooo`;oogl04Oooool01?oo003ooooooomo0?oo
O`07ooooo`?oogl0XooooolEo`00o`Sooooo0Ol00001ooooo`0000?o0000ooooooooool09oooool0
0ooo003oooooooooo`04ooooo`;oogl07_ooool00ooo003oooooooooo`07ooooo`Coogl0X_oooolE
o`00o`Sooooo0Ol00001ooooo`0000?o0000ooooooooool0:?ooool00ooo003oooooooooo`0Toooo
o`03ool00?oooooooooo00Kooooo1?ooO`2RoooooaGo003o2?ooool1o`00007ooooo00000ol0003o
ooooooooo`0Yooooo`03ool00?oooooooooo02Cooooo0_oo00000oooooooogl0oomo0004ooooo`;o
ogl0XooooolEo`00o`Sooooo0Ol00001ooooo`0000?o0000ooooooooool0:_ooool00ooo003ooooo
ooooo`0Cooooo`Coo`003_ooool01?oo003oogl0oomo0?ooO`2XoooooaGo003o2?ooool1o`00007o
oooo00000ol0003oooooooooo`0[ooooo`03ool00?oooooooooo017ooooo1_oo000=ooooo`04oomo
0?oo003oo`00oomo0:Sooooo5Ol00?l8ooooo`7o00000Oooool00003o`000?oooooooooo02cooooo
00?oo`00ooooooooool02?ooool2oomo00Gooooo2?oo000=ooooo`;oogl000?oo`00ooooooooool0
Y_oooolEo`00o`Sooooo0Ol00001ooooo`0000?o0000ooooooooool0;Oooool00ooo003ooooooooo
o`06ooooo`Coogl01?ooool8ool0013ooooo00?oo`00ooooooooool0YOoooolEo`00o`Sooooo0Ol0
0001ooooo`0000?o0000ooooooooool0:oooool2oomo0003oooooooo003ooooo00Kooooo1?ooO`04
ooooo`Soo`004Oooool00ooo003oooooooooo`2ToooooaGo003o2?ooool1o`00007ooooo00000ol0
003oooooooooo`0Zooooo`Coogl000?oooooool00?ooool01_ooool2oomo00Gooooo2?oo000;oooo
o`;oogl01Oooool00ooo003oooooooooo`09ooooo`;oogl0V?oooolEo`00o`Sooooo0Ol00001oooo
o`0000?o0000ooooooooool0:_ooool4oomo00;ooooo00?oo`00ooooooooool03?ooool6ool000_o
oooo1?ooO`04ooooo`03ool00?oooooooooo00Sooooo1?ooO`2GoooooaGo003o2?ooool1o`00007o
oooo00000ol0003oooooooooo`0[ooooo`;oogl01?ooool00ooo003oooooooooo`0<ooooo`Coo`00
3?ooool4oomo00Gooooo00?oo`00ooooooooool01oooool4oomo09Oooooo5Ol00?l8ooooo`7o0000
0Oooool00003o`000?oooooooooo03;ooooo0_oo000Mooooo`;oogl01oooool00ooo003ooooooooo
o`07ooooo`;oogl0]Oooool1o`00007ooooo00000ol0003oooooooooo`0dooooo`03ool00?oooooo
oooo02Cooooo00?oo`00ooooooooool0_Oooool1o`00007ooooo00000ol0003oooooooooo`0eoooo
o`03ool00?oooooooooo02Cooooo00?oo`00ooooooooool0_?ooool1o`00007ooooo00000ol0003o
ooooooooo`0fooooo`;oo`009Oooool00ooo003oooooooooo`2kooooo`7o00000Oooool00003o`00
0?oooooooooo03Sooooo0_oo00000oooO`3oooooooooo`02oomo01kooooo00?oo`00ooooooooool0
^oooool1o`00007ooooo00000ol0003oooooooooo`0hooooo`;oogl00_oo0004oomo01kooooo00?o
o`00ooooooooool0^_ooool1o`00007ooooo00000ol0003oooooooooo`0hooooo`Coogl00_oo0002
oomo01kooooo00?oo`00ooooooooool0^_ooool1o`00007ooooo00000ol0003oooooooooo`0ioooo
o`Googl000?oo`00ooooooooool07Oooool00ooo003oogl0oomo002jooooo`7o00000Oooool00003
o`000?oooooooooo03_ooooo1?ooO`02ool001gooooo00Coogl0ool00?ooO`3oogl0^Oooool1o`00
007ooooo00000ol0003oooooooooo`0looooo`;oogl00oooool2ool001_ooooo00Coogl0ool00?oo
O`3oogl0^Oooool1o`00007ooooo00000ol0003oooooooooo`13ooooo`;oo`006_ooool00oooO`3o
o`00ooooo`2iooooo`7o00000Oooool00003o`000?oooooooooo04Gooooo0_oo000Iooooo`03ool0
0?oooooooooo0;Sooooo0Ol00001ooooo`0000?o0000ooooooooool0Aoooool2ool001Gooooo0_oo
002kooooo`7o00000Oooool00003o`000?oooooooooo04Wooooo0ooo000@ooooo`;oo`00_Oooool1
o`00007ooooo00000ol0003oooooooooo`0aooooo`;oogl06Oooool3ool000cooooo00?oo`00oooo
ooooool0_Oooool1o`00007ooooo00000ol0003oooooooooo`0`ooooo`Coogl06oooool6ool000Co
oooo0_oo0030ooooo`7o00000Oooool00003o`000?oooooooooo033ooooo1?ooO`0Qooooo`Coo`00
`_ooool1o`00007ooooo00000ol0003oooooooooo`0aooooo`;oogl0j?ooool1o`00007ooooo0000
0ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLoooo
o`7o00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003ooooo
ooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Ooo
ool00003o`000?oooooooooo07gooooo0_ooO`2Looooo`7o00000Oooool00003o`000?oooooooooo
07cooooo1?ooO`2Kooooo`7o00000Oooool00003o`000?oooooooooo05Cooooo0_ooO`0Vooooo`Co
ogl0Voooool1o`00007ooooo00000ol0003oooooooooo`1Cooooo`Coogl09_ooool2oomo09cooooo
0Ol00001ooooo`0000?o0000ooooooooool0Doooool4oomo0<Cooooo0Ol00001ooooo`0000?o0000
ooooooooool0E?ooool2oomo0<Gooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLoooo
o`7o00000Oooool00003o`000?oooooooooo06?ooooo0_ooO`04ooooo`;oogl0/?ooool1o`00007o
oooo00000ol0003oooooooooo`1Rooooo`Coogl00_ooool4oomo0:oooooo0Ol00001ooooo`0000?o
0000ooooooooool0H_ooool4oomo00;ooooo1?ooO`2_ooooo`7o00000Oooool00003o`000?oooooo
oooo06?ooooo0_ooO`04ooooo`;oogl0/?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooo
oacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`00
0?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol0
0001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo
0?oooooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`00
00?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?oo
ool1o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000oooo
ooooool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007o
oooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooo
oolLooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0
003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o
00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003ooooooooo
o`3ooooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool0
0003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooooaco
oooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oo
oooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001
ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo0?oo
oooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o
0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1
o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000oooooooo
ool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo
00000ol0003oooooooooo`3oooooo`Cooooo0_ooO`0Fooooo`7o00000Oooool00003o`000?oooooo
oooo0?oooooo0oooool4oomo01Gooooo0Ol00001ooooo`0000?o0000ooooooooool0ooooool3oooo
o`Coogl05Oooool1o`00007ooooo00000ol0003oooooooooo`3oooooo`Cooooo0_ooO`0Fooooo`7o
00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003ooooooooo
o`3ooooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool0
0003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooooaco
oooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oo
oooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001
ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo0?oo
oooo7?ooool1o`00007ooooo00000ol0003oooooooooo`2eooooo`;oogl0I?ooool1o`00007ooooo
00000ol0003oooooooooo`2dooooo`Coogl0Hoooool1o`00007ooooo00000ol0003oooooooooo`2d
ooooo`Coogl0Hoooool1o`00007ooooo00000ol0003oooooooooo`2eooooo`;oogl0=Oooool2oomo
02gooooo0Ol00001ooooo`0000?o0000ooooooooool0i?ooool2oomo00Gooooo1?ooO`0/ooooo`7o
00000Oooool00003o`000?oooooooooo0>?ooooo1?ooO`04ooooo`Coogl0;?ooool1o`00007ooooo
00000ol0003oooooooooo`33ooooo`;oogl07_ooool4oomo00Gooooo0_ooO`0]ooooo`7o00000Ooo
ool00003o`000?oooooooooo0<;ooooo1?ooO`0;o`00oa?ooooo0_ooO`0eooooo`7o00000Oooool0
0003o`000?oooooooooo0<;ooooo1?l00?l;ooooo`;o003oB?ooool1o`00007ooooo00000ol0003o
ooooooooo`2cooooo`Goo`3o1_ooool4o`00o`03ooooooooO`3oogl000kooooo0_l00?m6ooooo`7o
00000Oooool00003o`000?oooooooooo0;;ooooo1ooo0?l2oomo00?o003o5oooool2o`00o`Wooooo
0_ooO`0iooooo`7o00000Oooool00003o`000?oooooooooo0;7ooooo2Ooo0?l00ol00?ooogl0oooo
o`0Jooooo`;o003o1_ooool4oomo03Sooooo0Ol00001ooooo`0000?o0000ooooooooool0/?ooool;
ool0o`03oomo0?oooooooooo01[ooooo00?o003oooooooooool01?ooool4oomo00?ooooo0_ooO`0c
ooooo`7o00000Oooool00003o`000?oooooooooo0;3ooooo2ooo0?lCooooo`;oogl02?ooool00ol0
0?ooooooooooo`05ooooo`;oogl00oooool4oomo03;ooooo0Ol00001ooooo`0000?o0000oooooooo
ool0/?ooool;ool0o`;ooooo0_ooO`0>ooooo`Coogl01oooool00ol00?ooooooooooo`0:ooooo`Co
ogl0<_ooool1o`00007ooooo00000ol0003oooooooooo`2^ooooo`;o003o2ooo0?l00oooooooogl0
oomo0002oomo00gooooo1?ooO`07ooooo`03o`00oooooooooooo00_ooooo0_ooO`0cooooo`7o0000
0Oooool00003o`000?oooooooooo08_ooooo0_ooO`0Pooooo`03o`00oooooooooooo00_oo`3o00?o
oooooomo0?ooO`000_ooO`0>ooooo`;oogl02Oooool00ol00?ooooooooooo`0oooooo`7o00000Ooo
ool00003o`000?oooooooooo08[ooooo1?ooO`0Mooooo`;o003o1?ooool9ool0o`?ooooo0_ooO`0J
ooooo`03o`00oooooooooooo03oooooo0Ol00001ooooo`0000?o0000ooooooooool0R_ooool4oomo
01cooooo00?o003oooooooooool01Oooool7ool0ob3ooooo00?o003oooooooooool0?oooool1o`00
007ooooo00000ol0003oooooooooo`2;ooooo`;oogl06oooool2o`00o`Wooooo1Ooo0?lQooooo`03
o`00oooooooooooo03oooooo0Ol00001ooooo`0000?o0000ooooooooool0U_ooool2oomo00kooooo
0_l00?lZooooo`;oogl01Oooool00ol00?ooooooooooo`0oooooo`7o00000Oooool00003o`000?oo
oooooooo09Gooooo1?ooO`0<ooooo`04o`00ooooooooogl0oomo02Sooooo1?ooO`03ooooo`03o`00
oooooooooooo043ooooo0Ol00001ooooo`0000?o0000ooooooooool0UOooool4oomo00[ooooo0_l0
0?l00oooooooogl0oomo0002oomo02Oooooo1?ooO`03ooooo`03o`00oooooooooooo043ooooo0Ol0
0001ooooo`0000?o0000ooooooooool0U_ooool2oomo00[ooooo00Co003ooooooooooooooooo1?oo
O`0Xooooo`;oogl01?ooool00ol00?ooooooooooo`10ooooo`7o00000Oooool00003o`000?oooooo
oooo0:7ooooo00?o003oooooooooool00oooool2oomo02kooooo00?o003oooooooooool0@Oooool1
o`00007ooooo00000ol0003oooooooooo`2Pooooo`03o`00oooooooooooo03?ooooo00?o003ooooo
ooooool04_ooool2oomo02kooooo0Ol00001ooooo`0000?o0000ooooooooool0W_ooool2o`00ocGo
oooo00?o003oooooooooool04_ooool4oomo02gooooo0Ol00001ooooo`0000?o0000ooooooooool0
WOooool00ol00?ooooooooooo`0Eooooo`Co003o7?ooool00ol00?ooogl0oomo000Booooo`Coogl0
;Oooool1o`00007ooooo00000ol0003oooooooooo`2Looooo`03o`00oooooooooooo01Gooooo1_l0
0?lJooooo`03o`00ooooO`3oogl000;oogl04_ooool2oomo02kooooo0Ol00001ooooo`0000?o0000
ooooooooool0Voooool00ol00?ooooooooooo`0Eooooo`So003o6?ooool00ol00?oooooooomo0003
oomo04;ooooo0Ol00001ooooo`0000?o0000ooooooooool0Voooool00ol00?ooooooooooo`0Eoooo
o`So003o5oooool01?l00?ooooooooooooooool2oomo04?ooooo0Ol00001ooooo`0000?o0000oooo
ooooool0V_ooool00ol00?ooooooooooo`0Fooooo`So003o5_ooool00ol00?ooooooooooo`17oooo
o`7o00000Oooool00003o`000?oooooooooo09Wooooo00?o003oooooooooool03?ooool2oomo00So
oooo00?oogl0o`00ool00?l01_l00?lEooooo`03o`00oooooooooooo00;oogl0A_ooool1o`00007o
oooo00000ol0003oooooooooo`2Iooooo`03o`00oooooooooooo00[ooooo1OooO`07ooooo`;oogl0
1_l00?lCooooo`;oogl000?o003oooooooooool01?ooO`15ooooo`7o00000Oooool00003o`000?oo
oooooooo09Sooooo00?o003oooooooooool02_ooool6oomo00Sooooo0_ooO`04o`00oa?ooooo0_oo
O`02o`00o`;ooooo1?ooO`15ooooo`7o00000Oooool00003o`000?oooooooooo09Sooooo00?o003o
ooooooooool02_ooool5oomo02;ooooo00Coogl0o`00ooooO`3oogl00oooool2oomo04Kooooo0Ol0
0001ooooo`0000?o0000ooooooooool0M_ooool2oomo01oooooo00?o003oooooooooool03?ooool2
oomo02Cooooo00?o003ooomo0?ooO`00C?ooool1o`00007ooooo00000ol0003oooooooooo`1eoooo
o`Coogl07_ooool00ol00?ooooooooooo`0aooooo`03o`00oooooooooooo04gooooo0Ol00001oooo
o`0000?o0000ooooooooool0MOooool4oomo00[ooooo0_ooO`0Aooooo`03o`00oooooooooooo037o
oooo00?o003oooooooooool0C_ooool1o`00007ooooo00000ol0003oooooooooo`1fooooo`;oogl0
2_ooool4oomo00oooooo00?o003oooooooooool06?ooool2oomo01Oooooo00?o003oooooooooool0
Coooool1o`00007ooooo00000ol0003oooooooooo`22ooooo`Coogl03oooool00ol00?oooooooooo
o`0Gooooo`Coogl05?ooool2o`00oe;ooooo0Ol00001ooooo`0000?o0000ooooooooool0Poooool2
oomo00oooooo00?o003oooooooooool04_ooool2oomo00Cooooo1?ooO`0Aooooo`?o003oE?ooool1
o`00007ooooo00000ol0003oooooooooo`2Dooooo`03o`00oooooooooooo017ooooo1?ooO`04oooo
o`;oogl04?ooool2o`00oeOooooo0Ol00001ooooo`0000?o0000ooooooooool0U?ooool00ol00?oo
ooooooooo`0Aooooo`Coogl05Oooool00ol00?ooooooooooo`1Gooooo`7o00000Oooool00003o`00
0?oooooooooo09Cooooo00?o003oooooooooool04_ooool2oomo01Cooooo0_l00?mJooooo`7o0000
0Oooool00003o`000?oooooooooo09Cooooo00?o003oooooooooool09_ooool2o`00oecooooo0Ol0
0001ooooo`0000?o0000ooooooooool0UOooool00ol00?ooooooooooo`0Tooooo`03o`00oooooooo
oooo05cooooo0Ol00001ooooo`0000?o0000ooooooooool0UOooool00ol00?ooooooooooo`0Roooo
o`;o003oGoooool1o`00007ooooo00000ol0003oooooooooo`2Eooooo`03o`00oooooooooooo023o
oooo0_l00?mQooooo`7o00000Oooool00003o`000?oooooooooo08Cooooo0_ooO`0?ooooo`;o003o
7oooool2o`00of?ooooo0Ol00001ooooo`0000?o0000ooooooooool0Poooool4oomo013ooooo0_l0
0?lJooooo`?o003oIOooool1o`00007ooooo00000ol0003oooooooooo`23ooooo`Coogl04_ooool2
o`00oaCooooo1?l00?mXooooo`7o00000Oooool00003o`000?oooooooooo08Cooooo0_ooO`0Eoooo
o`?o003o3_ooool3o`00o`?ooooo0_ooO`1Wooooo`7o00000Oooool00003o`000?oooooooooo09ko
oooo0ol00?l5ooooo`Ko003o1Oooool4oomo06Kooooo0Ol00001ooooo`0000?o0000ooooooooool0
XOooool5o`00o`_ooooo1?ooO`1Vooooo`7o00000Oooool00003o`000?oooooooooo0;;ooooo0_oo
O`1Wooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0
003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0Noooool2oomo09ko
oooo0Ol00001ooooo`0000?o0000ooooooooool0N_ooool4oomo09gooooo0Ol00001ooooo`0000?o
0000ooooooooool0N_ooool4oomo023ooooo0_ooO`1kooooo`7o00000Oooool00003o`000?oooooo
oooo07_ooooo0_ooO`0Pooooo`Coogl0N_ooool1o`00007ooooo00000ol0003oooooooooo`2Moooo
o`Coogl0N_ooool1o`00007ooooo00000ol0003oooooooooo`2@ooooo`;oogl03?ooool2oomo07_o
oooo0Ol00001ooooo`0000?o0000ooooooooool0Soooool4oomo08Sooooo0Ol00001ooooo`0000?o
0000ooooooooool0Soooool4oomo08Sooooo0Ol00001ooooo`0000?o0000ooooooooool0T?ooool2
oomo02?ooooo0_ooO`1Tooooo`7o00000Oooool00003o`000?oooooooooo0;Cooooo1?ooO`1Soooo
o`7o00000Oooool00003o`000?oooooooooo0;Cooooo1?ooO`1Sooooo`7o00000Oooool00003o`00
0?oooooooooo0;Gooooo0_ooO`1Tooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?oo
ool1o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000oooo
ooooool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007o
oooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooo
oolLooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0
003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o
00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003ooooooooo
o`3ooooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool0
0003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooooaco
oooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oo
oooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001
ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo0?oo
oooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o
0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1
o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000oooooooo
ool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo
00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolL
ooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003o
ooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o0000
0Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3o
oooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003
o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo
0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oooooo
oooo0?oooooo7?ooool1o`00007ooooo00000ol0003oooooooooo`2>ooooo`;oogl0Roooool1o`00
007ooooo00000ol0003oooooooooo`2=ooooo`Coogl0R_ooool1o`00007ooooo00000ol0003ooooo
ooooo`2=ooooo`Coogl0R_ooool1o`00007ooooo00000ol0003oooooooooo`2>ooooo`;oogl0Rooo
ool1o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000oooo
ooooool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007o
oooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooo
oolLooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0
003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o
00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003ooooooooo
o`3ooooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool0
0003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooooaco
oooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oo
oooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001
ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo0?oo
oooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o
0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1
o`00007ooooo003oo`00023o00000Oooool00001\
\>"],
  ImageRangeCache->{{{0, 287}, {287, 0}} -> {-1.01089, -1.01089, 0.00704453, \
0.00704453}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.49505 0.5 0.49505 [
[ 0 0 -0.125 0 ]
[ 0 0 -0.125 0 ]
[ 0 1 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
0 0 m
1 0 L
s
0 0 m
0 1 L
s
0 1 m
1 1 L
s
1 0 m
1 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
1 .5 0 r
.015 w
.03175 .1355 Mdot
.03435 .12523 Mdot
.11137 .12765 Mdot
.14107 .18841 Mdot
.16218 .24538 Mdot
.17294 .21053 Mdot
.18267 .18577 Mdot
.18434 .1304 Mdot
.18553 .30956 Mdot
.20401 .239 Mdot
.21247 .27571 Mdot
.21687 .20845 Mdot
.22376 .2799 Mdot
.22832 .27485 Mdot
.29063 .20974 Mdot
.29686 .25079 Mdot
.30487 .22936 Mdot
.30683 .34623 Mdot
.32055 .20902 Mdot
.32574 .21979 Mdot
.34472 .28521 Mdot
.35998 .36393 Mdot
.36335 .24976 Mdot
.3794 .36608 Mdot
.42386 .66992 Mdot
.44391 .74519 Mdot
.45059 .34198 Mdot
.47208 .67586 Mdot
.47436 .71381 Mdot
.49778 .59825 Mdot
.50874 .91643 Mdot
.51516 .76219 Mdot
.53655 .61374 Mdot
.56563 .75219 Mdot
.59189 .65665 Mdot
.59581 .61604 Mdot
.59923 .6556 Mdot
.60292 .68499 Mdot
.62656 .67779 Mdot
.63555 .72451 Mdot
.63919 .652 Mdot
.64169 .6004 Mdot
.64246 .58611 Mdot
.64496 .54267 Mdot
.64608 .77288 Mdot
.65077 .64308 Mdot
.66065 .57816 Mdot
.67474 .59169 Mdot
.69296 .563 Mdot
.72815 .65902 Mdot
.73169 .58879 Mdot
.74669 .61318 Mdot
.74821 .65474 Mdot
.75963 .63781 Mdot
.79673 .57809 Mdot
.80925 .55852 Mdot
.81525 .58444 Mdot
.83417 .62985 Mdot
.83598 .55526 Mdot
.91595 .49319 Mdot
1 0 0 r
.005 w
.16128 .17044 m
.18734 .17269 L
.21339 .17909 L
.2345 .18734 L
.23945 .19126 L
.2655 .20415 L
.27874 .21339 L
.29156 .22295 L
.31204 .23945 L
.31761 .24532 L
.33549 .2655 L
.34367 .28341 L
.34499 .29156 L
.34367 .29798 L
.31761 .3104 L
.29156 .30711 L
.2655 .30014 L
.24507 .29156 L
.23945 .28747 L
.21339 .27402 L
.20155 .2655 L
.18734 .25472 L
.16884 .23945 L
.16128 .2313 L
.14618 .21339 L
.13806 .18734 L
.16128 .17044 L
s
0 0 1 r
.65633 .57701 m
.68239 .56842 L
.70844 .56313 L
.7345 .56168 L
.76055 .5752 L
.76359 .57817 L
.76859 .60422 L
.76055 .62333 L
.75627 .63028 L
.7345 .65485 L
.73298 .65633 L
.70844 .6775 L
.69922 .68239 L
.68239 .69294 L
.65633 .70579 L
.64983 .70844 L
.63028 .71539 L
.60422 .72268 L
.57817 .72651 L
.55211 .7214 L
.53145 .70844 L
.52926 .68239 L
.54239 .65633 L
.55211 .63983 L
.56625 .63028 L
.57817 .6193 L
.60119 .60422 L
.60422 .60227 L
.63028 .58726 L
.65315 .57817 L
.65633 .57701 L
s
1 0 0 r
.03 w
.24141 .24033 Mdot
0 0 1 r
.64872 .64417 Mdot
1 0 0 r
.79703 .00495 m
.79703 .005 L
.87129 .005 L
.87129 .00495 L
F
0 0 1 r
.89604 .00495 m
.89604 .25243 L
.9703 .25243 L
.9703 .00495 L
F
1 0 1 r
.04 w
.64496 .54267 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P000182000`400?l00000o`00003ooooooolQ
ooooo`00ool0000Po`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`00
00?o0000ooooooooool0o_oooolEo`00o`Sooooo0Ol00001ooooo`0000?o0000ooooooooool0o_oo
oolEo`00o`Sooooo0Ol00001ooooo`0000?o0000ooooooooool0o_oooolEo`00o`Sooooo0Ol00001
ooooo`0000?o0000ooooooooool0o_oooolEo`00o`Sooooo0Ol00001ooooo`0000?o0000oooooooo
ool0o_oooolEo`00o`Sooooo0Ol00001ooooo`0000?o0000ooooooooool0o_oooolEo`00o`Sooooo
0Ol00001ooooo`0000?o0000ooooooooool0o_oooolEo`00o`Sooooo0Ol00001ooooo`0000?o0000
ooooooooool0o_oooolEo`00o`Sooooo0Ol00001ooooo`0000?o0000ooooooooool0o_oooolEo`00
o`Sooooo0Ol00001ooooo`0000?o0000ooooooooool0o_oooolEo`00o`Sooooo0Ol00001ooooo`00
00?o0000ooooooooool0o_oooolEo`00o`Sooooo0Ol00001ooooo`0000?o0000ooooooooool0o_oo
oolEo`00o`Sooooo0Ol00001ooooo`0000?o0000ooooooooool0o_oooolEo`00o`Sooooo0Ol00001
ooooo`0000?o0000ooooooooool0o_oooolEo`00o`Sooooo0Ol00001ooooo`0000?o0000oooooooo
ool0o_oooolEo`00o`Sooooo0Ol00001ooooo`0000?o0000ooooooooool0o_oooolEo`00o`Sooooo
0Ol00001ooooo`0000?o0000ooooooooool0o_oooolEo`00o`Sooooo0Ol00001ooooo`0000?o0000
ooooooooool0o_oooolEo`00o`Sooooo0Ol00001ooooo`0000?o0000ooooooooool0o_oooolEo`00
o`Sooooo0Ol00001ooooo`0000?o0000ooooooooool0o_oooolEo`00o`Sooooo0Ol00001ooooo`00
00?o0000ooooooooool0o_oooolEo`00o`Sooooo0Ol00001ooooo`0000?o0000ooooooooool0o_oo
oolEo`00o`Sooooo0Ol00001ooooo`0000?o0000ooooooooool0o_oooolEo`00o`Sooooo0Ol00001
ooooo`0000?o0000ooooooooool0o_oooolEo`00o`Sooooo0Ol00001ooooo`0000?o0000oooooooo
ool0o_oooolEo`00o`Sooooo0Ol00001ooooo`0000?o0000ooooooooool0o_oooolEo`00o`Sooooo
0Ol00001ooooo`0000?o0000ooooooooool0o_oooolEo`00o`Sooooo0Ol00001ooooo`0000?o0000
ooooooooool0o_oooolEo`00o`Sooooo0Ol00001ooooo`0000?o0000ooooooooool0o_oooolEo`00
o`Sooooo0Ol00001ooooo`0000?o0000ooooooooool0o_oooolEo`00o`Sooooo0Ol00001ooooo`00
00?o0000ooooooooool0o_oooolEo`00o`Sooooo0Ol00001ooooo`0000?o0000ooooooooool0o_oo
oolEo`00o`Sooooo0Ol00001ooooo`0000?o0000ooooooooool01_ooool2oomo0?Kooooo5Ol00?l8
ooooo`7o00000Oooool00003o`000?oooooooooo00Gooooo1?ooO`0Cooooo`;oogl0h?oooolEo`00
o`Sooooo0Ol00001ooooo`0000?o0000ooooooooool01Oooool4oomo01;ooooo1?ooO`0Booooo`;o
ogl0booooolEo`00o`Sooooo0Ol00001ooooo`0000?o0000ooooooooool01Oooool3oomo01?ooooo
1?ooO`0Aooooo`Coogl0b_oooolEo`00o`Sooooo0Ol00001ooooo`0000?o0000ooooooooool01?oo
ool4oomo01Cooooo0_ooO`0Booooo`Coogl0b_oooolEo`00o`Sooooo0Ol00001ooooo`0000?o0000
ooooooooool01?ooool4oomo02Wooooo0_ooO`3;oooooaGo003o2?ooool1o`00007ooooo00000ol0
003oooooooooo`05ooooo`;oogl0mooooolEo`00o`Sooooo0Ol00001ooooo`0000?o0000oooooooo
ool0o_oooolEo`00o`Sooooo0Ol00001ooooo`0000?o0000ooooooooool0o_oooolEo`00o`Sooooo
0Ol00001ooooo`0000?o0000ooooooooool0o_oooolEo`00o`Sooooo0Ol00001ooooo`0000?o0000
ooooooooool0o_oooolEo`00o`Sooooo0Ol00001ooooo`0000?o0000ooooooooool0o_oooolEo`00
o`Sooooo0Ol00001ooooo`0000?o0000ooooooooool0o_oooolEo`00o`Sooooo0Ol00001ooooo`00
00?o0000ooooooooool0o_oooolEo`00o`Sooooo0Ol00001ooooo`0000?o0000ooooooooool0:_oo
ool6ool00<kooooo5Ol00?l8ooooo`7o00000Oooool00003o`000?oooooooooo02Wooooo00?oo`00
ooooooooool01?ooool5ool00<Wooooo5Ol00?l8ooooo`7o00000Oooool00003o`000?oooooooooo
02Oooooo0_oo000<ooooo`Coo`00aOoooolEo`00o`Sooooo0Ol00001ooooo`0000?o0000oooooooo
ool09_ooool00ooo003oooooooooo`0@ooooo`Coo`00`OoooolEo`00o`Sooooo0Ol00001ooooo`00
00?o0000ooooooooool09?ooool00oooO`3oo`00ooooo`09ooooo`;oogl02oooool3ool00;kooooo
5Ol00?l8ooooo`7o00000Oooool00003o`000?oooooooooo02?ooooo00Coogl0ool00?ooO`3oogl0
2?ooool4oomo00gooooo00?oo`00ooooooooool0^ooooolEo`00o`Sooooo0Ol00001ooooo`0000?o
0000ooooooooool08oooool01?ooO`3oo`00oomo0?ooO`08ooooo`Coogl03_ooool2ool00;_ooooo
5Ol00?l8ooooo`7o00000Oooool00003o`000?oooooooooo02Cooooo00?oogl0ool00?ooool02Ooo
ool2oomo017ooooo0_oo002ioooooaGo003o2?ooool1o`00007ooooo00000ol0003oooooooooo`0U
ooooo`03ool00?oooooooooo01gooooo0_oo002goooooaGo003o2?ooool1o`00007ooooo00000ol0
003oooooooooo`0Uooooo`03ool00?oooooooooo01oooooo0_oo002eoooooaGo003o2?ooool1o`00
007ooooo00000ol0003oooooooooo`0Vooooo`03ool00?oooooooooo017ooooo0_ooO`0=ooooo`;o
o`001?ooool2oomo00Oooooo0_ooO`2ToooooaGo003o2?ooool1o`00007ooooo00000ol0003ooooo
ooooo`0Vooooo`03ool00?oooooooooo00Gooooo0_ooO`09ooooo`Coogl03_ooool00ooo003ooooo
ooooo`04oomo00Gooooo1?ooO`2SoooooaGo003o2?ooool1o`00007ooooo00000ol0003ooooooooo
o`0Vooooo`03ool00?oooooooooo00Cooooo1?ooO`08ooooo`Coogl03oooool00ooo003ooooooomo
0003oomo00Gooooo1?ooO`2SoooooaGo003o2?ooool1o`00007ooooo00000ol0003oooooooooo`0W
ooooo`03ool00?oooooooooo00?ooooo1?ooO`09ooooo`;oogl04Oooool01?oo003ooooooomo0?oo
O`07ooooo`?oogl0XooooolEo`00o`Sooooo0Ol00001ooooo`0000?o0000ooooooooool09oooool0
0ooo003oooooooooo`04ooooo`;oogl07_ooool00ooo003oooooooooo`07ooooo`Coogl0X_oooolE
o`00o`Sooooo0Ol00001ooooo`0000?o0000ooooooooool0:?ooool00ooo003oooooooooo`0Toooo
o`03ool00?oooooooooo00Kooooo1?ooO`2RoooooaGo003o2?ooool1o`00007ooooo00000ol0003o
ooooooooo`0Yooooo`03ool00?oooooooooo02Cooooo0_oo00000oooooooogl0oomo0004ooooo`;o
ogl0XooooolEo`00o`Sooooo0Ol00001ooooo`0000?o0000ooooooooool0:_ooool00ooo003ooooo
ooooo`0Cooooo`Coo`003_ooool01?oo003oogl0oomo0?ooO`2XoooooaGo003o2?ooool1o`00007o
oooo00000ol0003oooooooooo`0[ooooo`03ool00?oooooooooo017ooooo1_oo000=ooooo`04oomo
0?oo003oo`00oomo0:Sooooo5Ol00?l8ooooo`7o00000Oooool00003o`000?oooooooooo02cooooo
00?oo`00ooooooooool02?ooool2oomo00Gooooo2?oo000=ooooo`;oogl000?oo`00ooooooooool0
Y_oooolEo`00o`Sooooo0Ol00001ooooo`0000?o0000ooooooooool0;Oooool00ooo003ooooooooo
o`06ooooo`Coogl01?ooool8ool0013ooooo00?oo`00ooooooooool0YOoooolEo`00o`Sooooo0Ol0
0001ooooo`0000?o0000ooooooooool0:oooool2oomo0003oooooooo003ooooo00Kooooo1?ooO`04
ooooo`Soo`004Oooool00ooo003oooooooooo`2ToooooaGo003o2?ooool1o`00007ooooo00000ol0
003oooooooooo`0Zooooo`Coogl000?oooooool00?ooool01_ooool2oomo00Gooooo2?oo000;oooo
o`;oogl01Oooool00ooo003oooooooooo`09ooooo`;oogl0V?oooolEo`00o`Sooooo0Ol00001oooo
o`0000?o0000ooooooooool0:_ooool4oomo00;ooooo00?oo`00ooooooooool03?ooool6ool000_o
oooo1?ooO`04ooooo`03ool00?oooooooooo00Sooooo1?ooO`2GoooooaGo003o2?ooool1o`00007o
oooo00000ol0003oooooooooo`0[ooooo`;oogl01?ooool00ooo003oooooooooo`0<ooooo`Coo`00
3?ooool4oomo00Gooooo00?oo`00ooooooooool01oooool4oomo09Oooooo5Ol00?l8ooooo`7o0000
0Oooool00003o`000?oooooooooo03;ooooo0_oo000Mooooo`;oogl01oooool00ooo003ooooooooo
o`07ooooo`;oogl0]Oooool1o`00007ooooo00000ol0003oooooooooo`0dooooo`03ool00?oooooo
oooo02Cooooo00?oo`00ooooooooool0_Oooool1o`00007ooooo00000ol0003oooooooooo`0eoooo
o`03ool00?oooooooooo02Cooooo00?oo`00ooooooooool0_?ooool1o`00007ooooo00000ol0003o
ooooooooo`0fooooo`;oo`009Oooool00ooo003oooooooooo`2kooooo`7o00000Oooool00003o`00
0?oooooooooo03Sooooo0_oo00000oooO`3oooooooooo`02oomo01kooooo00?oo`00ooooooooool0
^oooool1o`00007ooooo00000ol0003oooooooooo`0hooooo`;oogl00_oo0004oomo01kooooo00?o
o`00ooooooooool0^_ooool1o`00007ooooo00000ol0003oooooooooo`0hooooo`Coogl00_oo0002
oomo01kooooo00?oo`00ooooooooool0^_ooool1o`00007ooooo00000ol0003oooooooooo`0ioooo
o`Googl000?oo`00ooooooooool07Oooool00ooo003oogl0oomo002jooooo`7o00000Oooool00003
o`000?oooooooooo03_ooooo1?ooO`02ool001gooooo00Coogl0ool00?ooO`3oogl0^Oooool1o`00
007ooooo00000ol0003oooooooooo`0looooo`;oogl00oooool2ool001_ooooo00Coogl0ool00?oo
O`3oogl0^Oooool1o`00007ooooo00000ol0003oooooooooo`13ooooo`;oo`006_ooool00oooO`3o
o`00ooooo`2iooooo`7o00000Oooool00003o`000?oooooooooo04Gooooo0_oo000Iooooo`03ool0
0?oooooooooo0;Sooooo0Ol00001ooooo`0000?o0000ooooooooool0Aoooool2ool001Gooooo0_oo
002kooooo`7o00000Oooool00003o`000?oooooooooo04Wooooo0ooo000@ooooo`;oo`00_Oooool1
o`00007ooooo00000ol0003oooooooooo`0aooooo`;oogl06Oooool3ool000cooooo00?oo`00oooo
ooooool0_Oooool1o`00007ooooo00000ol0003oooooooooo`0`ooooo`Coogl06oooool6ool000Co
oooo0_oo0030ooooo`7o00000Oooool00003o`000?oooooooooo033ooooo1?ooO`0Qooooo`Coo`00
`_ooool1o`00007ooooo00000ol0003oooooooooo`0aooooo`;oogl0j?ooool1o`00007ooooo0000
0ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLoooo
o`7o00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003ooooo
ooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Ooo
ool00003o`000?oooooooooo07gooooo0_ooO`2Looooo`7o00000Oooool00003o`000?oooooooooo
07cooooo1?ooO`2Kooooo`7o00000Oooool00003o`000?oooooooooo05Cooooo0_ooO`0Vooooo`Co
ogl0Voooool1o`00007ooooo00000ol0003oooooooooo`1Cooooo`Coogl09_ooool2oomo09cooooo
0Ol00001ooooo`0000?o0000ooooooooool0Doooool4oomo0<Cooooo0Ol00001ooooo`0000?o0000
ooooooooool0E?ooool2oomo0<Gooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLoooo
o`7o00000Oooool00003o`000?oooooooooo06?ooooo0_ooO`04ooooo`;oogl0/?ooool1o`00007o
oooo00000ol0003oooooooooo`1Rooooo`Coogl00_ooool4oomo0:oooooo0Ol00001ooooo`0000?o
0000ooooooooool0H_ooool4oomo00;ooooo1?ooO`2_ooooo`7o00000Oooool00003o`000?oooooo
oooo06?ooooo0_ooO`04ooooo`;oogl0/?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooo
oacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`00
0?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol0
0001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo
0?oooooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`00
00?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?oo
ool1o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000oooo
ooooool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007o
oooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooo
oolLooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0
003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o
00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003ooooooooo
o`3ooooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool0
0003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooooaco
oooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oo
oooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001
ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo0?oo
oooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o
0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1
o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000oooooooo
ool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo
00000ol0003oooooooooo`3oooooo`Cooooo0_ooO`0Fooooo`7o00000Oooool00003o`000?oooooo
oooo0?oooooo0oooool4oomo01Gooooo0Ol00001ooooo`0000?o0000ooooooooool0ooooool3oooo
o`Coogl05Oooool1o`00007ooooo00000ol0003oooooooooo`3oooooo`Cooooo0_ooO`0Fooooo`7o
00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003ooooooooo
o`3ooooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool0
0003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooooaco
oooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oo
oooooooo0;?ooooo1Ooo0?mSooooo`7o00000Oooool00003o`000?oooooooooo0;;ooooo1ooo0?mR
ooooo`7o00000Oooool00003o`000?oooooooooo0;7ooooo2Ooo0?mQooooo`7o00000Oooool00003
o`000?oooooooooo0;3ooooo2ooo0?mPooooo`7o00000Oooool00003o`000?oooooooooo0;3ooooo
2ooo0?mPooooo`7o00000Oooool00003o`000?oooooooooo0;3ooooo2ooo0?mPooooo`7o00000Ooo
ool00003o`000?oooooooooo0;3ooooo2ooo0?mPooooo`7o00000Oooool00003o`000?oooooooooo
0;3ooooo2ooo0?laooooo`;oogl0;Oooool1o`00007ooooo00000ol0003oooooooooo`2aooooo`Wo
o`3o:_ooool2oomo00Gooooo1?ooO`0/ooooo`7o00000Oooool00003o`000?oooooooooo0;;ooooo
1ooo0?lZooooo`Coogl01?ooool4oomo02cooooo0Ol00001ooooo`0000?o0000ooooooooool0/ooo
ool5ool0o`_ooooo0_ooO`0Nooooo`Coogl01Oooool2oomo02gooooo0Ol00001ooooo`0000?o0000
ooooooooool0`_ooool4oomo00_o003o4oooool2oomo03Gooooo0Ol00001ooooo`0000?o0000oooo
ooooool0`_ooool4o`00o`_ooooo0_l00?m8ooooo`7o00000Oooool00003o`000?oooooooooo0;ko
oooo1?l00?l00oooooooogl0oomo000>ooooo`;o003oA_ooool1o`00007ooooo00000ol0003ooooo
ooooo`2iooooo`;oogl00ol00?lGooooo`;o003o2Oooool2oomo03Wooooo0Ol00001ooooo`0000?o
0000ooooooooool0]oooool4o`00o`03oomo0?oooooooooo01Wooooo0_l00?l6ooooo`Coogl0>?oo
ool1o`00007ooooo00000ol0003oooooooooo`2dooooo`?o003o00?ooooooomo0?ooO`000_ooO`0L
ooooo`03o`00oooooooooooo00Cooooo1?ooO`03ooooo`;oogl0<oooool1o`00007ooooo00000ol0
003oooooooooo`2booooo`;o003o0oooO`02ooooo`;oogl04oooool2oomo00Sooooo00?o003ooooo
ooooool01Oooool2oomo00?ooooo1?ooO`0booooo`7o00000Oooool00003o`000?oooooooooo0;3o
oooo0_l00?l00oooooooogl0oomo0002oomo00Kooooo0_ooO`0>ooooo`Coogl01oooool00ol00?oo
ooooooooo`0:ooooo`Coogl0<_ooool1o`00007ooooo00000ol0003oooooooooo`2^ooooo`;o003o
1?ooool2oomo00Kooooo1?ooO`0=ooooo`Coogl01oooool00ol00?ooooooooooo`0;ooooo`;oogl0
<oooool1o`00007ooooo00000ol0003oooooooooo`2;ooooo`;oogl08?ooool00ol00?oooooooooo
o`04ooooo`;oogl01_ooool4oomo00kooooo0_ooO`09ooooo`03o`00oooooooooooo03oooooo0Ol0
0001ooooo`0000?o0000ooooooooool0R_ooool4oomo01gooooo0_l00?l6ooooo`Coogl01_ooool2
oomo01[ooooo00?o003oooooooooool0?oooool1o`00007ooooo00000ol0003oooooooooo`2:oooo
o`Coogl07?ooool00ol00?ooooooooooo`06ooooo`Coogl08_ooool00ol00?ooooooooooo`0ooooo
o`7o00000Oooool00003o`000?oooooooooo08_ooooo0_ooO`0Kooooo`;o003o2_ooool2oomo02?o
oooo00?o003oooooooooool0?oooool1o`00007ooooo00000ol0003oooooooooo`2Fooooo`;oogl0
3_ooool2o`00ob[ooooo0_ooO`05ooooo`03o`00oooooooooooo03oooooo0Ol00001ooooo`0000?o
0000ooooooooool0UOooool4oomo00cooooo00Co003oooooooooO`3oogl0:?ooool4oomo00?ooooo
00?o003oooooooooool0@?ooool1o`00007ooooo00000ol0003oooooooooo`2Eooooo`Coogl02_oo
ool2o`00o`03ooooooooO`3oogl000;oogl09oooool4oomo00?ooooo00?o003oooooooooool0@?oo
ool1o`00007ooooo00000ol0003oooooooooo`2Fooooo`;oogl02_ooool01?l00?oooooooooooooo
ool4oomo02Sooooo0_ooO`04ooooo`03o`00oooooooooooo043ooooo0Ol00001ooooo`0000?o0000
ooooooooool0XOooool00ol00?ooooooooooo`03ooooo`;oogl0;_ooool00ol00?ooooooooooo`11
ooooo`7o00000Oooool00003o`000?oooooooooo0:3ooooo00?o003oooooooooool0<oooool00ol0
0?ooooooooooo`0Booooo`;oogl0;_ooool1o`00007ooooo00000ol0003oooooooooo`2Nooooo`;o
003o=Oooool00ol00?ooooooooooo`0Booooo`Coogl0;Oooool1o`00007ooooo00000ol0003ooooo
ooooo`2Mooooo`03o`00oooooooooooo01Gooooo1?l00?lLooooo`03o`00ooooO`3oogl001;ooooo
1?ooO`0]ooooo`7o00000Oooool00003o`000?oooooooooo09cooooo00?o003oooooooooool05Ooo
ool6o`00oa[ooooo00?o003ooomo0?ooO`000_ooO`0Booooo`;oogl0;_ooool1o`00007ooooo0000
0ol0003oooooooooo`2Kooooo`03o`00oooooooooooo01Gooooo2?l00?lHooooo`03o`00oooooooo
ogl000?oogl0@_ooool1o`00007ooooo00000ol0003oooooooooo`2Kooooo`03o`00oooooooooooo
01Gooooo2?l00?lGooooo`04o`00ooooooooooooooooo`;oogl0@oooool1o`00007ooooo00000ol0
003oooooooooo`2Jooooo`03o`00oooooooooooo01Kooooo2?l00?lFooooo`03o`00oooooooooooo
04Oooooo0Ol00001ooooo`0000?o0000ooooooooool0VOooool00ol00?ooooooooooo`0<ooooo`;o
ogl02?ooool00oooO`3o003oo`00o`06o`00oaGooooo00?o003oooooooooool00_ooO`16ooooo`7o
00000Oooool00003o`000?oooooooooo09Wooooo00?o003oooooooooool02_ooool5oomo00Oooooo
0_ooO`06o`00oa?ooooo0_ooO`000ol00?ooooooooooo`04oomo04Gooooo0Ol00001ooooo`0000?o
0000ooooooooool0V?ooool00ol00?ooooooooooo`0:ooooo`Koogl02?ooool2oomo00Co003o4ooo
ool2oomo00;o003o0_ooool4oomo04Gooooo0Ol00001ooooo`0000?o0000ooooooooool0V?ooool0
0ol00?ooooooooooo`0:ooooo`Googl08_ooool01?ooO`3o003ooomo0?ooO`03ooooo`;oogl0A_oo
ool1o`00007ooooo00000ol0003oooooooooo`1fooooo`;oogl07oooool00ol00?ooooooooooo`0<
ooooo`;oogl09?ooool00ol00?ooogl0oomo001<ooooo`7o00000Oooool00003o`000?oooooooooo
07Gooooo1?ooO`0Nooooo`03o`00oooooooooooo037ooooo00?o003oooooooooool0COooool1o`00
007ooooo00000ol0003oooooooooo`1eooooo`Coogl02_ooool2oomo017ooooo00?o003ooooooooo
ool0<Oooool00ol00?ooooooooooo`1>ooooo`7o00000Oooool00003o`000?oooooooooo07Kooooo
0_ooO`0:ooooo`Coogl03oooool00ol00?ooooooooooo`0Hooooo`;oogl05oooool00ol00?oooooo
ooooo`1?ooooo`7o00000Oooool00003o`000?oooooooooo08;ooooo1?ooO`0?ooooo`03o`00oooo
oooooooo01Oooooo1?ooO`0Dooooo`;o003oD_ooool1o`00007ooooo00000ol0003oooooooooo`23
ooooo`;oogl03oooool00ol00?ooooooooooo`0Booooo`;oogl01?ooool4oomo017ooooo0ol00?mD
ooooo`7o00000Oooool00003o`000?oooooooooo09Cooooo00?o003oooooooooool04Oooool4oomo
00Cooooo0_ooO`0@ooooo`;o003oEoooool1o`00007ooooo00000ol0003oooooooooo`2Dooooo`03
o`00oooooooooooo017ooooo1?ooO`0Eooooo`03o`00oooooooooooo05Oooooo0Ol00001ooooo`00
00?o0000ooooooooool0U?ooool00ol00?ooooooooooo`0Booooo`;oogl05?ooool2o`00oe[ooooo
0Ol00001ooooo`0000?o0000ooooooooool0U?ooool00ol00?ooooooooooo`0Vooooo`;o003oG?oo
ool1o`00007ooooo00000ol0003oooooooooo`2Eooooo`03o`00oooooooooooo02Cooooo00?o003o
ooooooooool0G?ooool1o`00007ooooo00000ol0003oooooooooo`2Eooooo`03o`00oooooooooooo
02;ooooo0_l00?mOooooo`7o00000Oooool00003o`000?oooooooooo09Gooooo00?o003ooooooooo
ool08?ooool2o`00of7ooooo0Ol00001ooooo`0000?o0000ooooooooool0Q?ooool2oomo00oooooo
0_l00?lOooooo`;o003oHoooool1o`00007ooooo00000ol0003oooooooooo`23ooooo`Coogl04?oo
ool2o`00oa[ooooo0ol00?mUooooo`7o00000Oooool00003o`000?oooooooooo08?ooooo1?ooO`0B
ooooo`;o003o5?ooool4o`00ofSooooo0Ol00001ooooo`0000?o0000ooooooooool0Q?ooool2oomo
01Gooooo0ol00?l>ooooo`?o003o0oooool2oomo06Oooooo0Ol00001ooooo`0000?o0000oooooooo
ool0W_ooool3o`00o`Gooooo1_l00?l5ooooo`Coogl0I_ooool1o`00007ooooo00000ol0003ooooo
ooooo`2Qooooo`Go003o2oooool4oomo06Kooooo0Ol00001ooooo`0000?o0000ooooooooool0/_oo
ool2oomo06Oooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool0
0003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003oooooooooo`1kooooo`;o
ogl0W_ooool1o`00007ooooo00000ol0003oooooooooo`1jooooo`Coogl0WOooool1o`00007ooooo
00000ol0003oooooooooo`1jooooo`Coogl08?ooool2oomo07_ooooo0Ol00001ooooo`0000?o0000
ooooooooool0Noooool2oomo023ooooo1?ooO`1jooooo`7o00000Oooool00003o`000?oooooooooo
09gooooo1?ooO`1jooooo`7o00000Oooool00003o`000?oooooooooo093ooooo0_ooO`0<ooooo`;o
ogl0Noooool1o`00007ooooo00000ol0003oooooooooo`2?ooooo`Coogl0R?ooool1o`00007ooooo
00000ol0003oooooooooo`2?ooooo`Coogl0R?ooool1o`00007ooooo00000ol0003oooooooooo`2@
ooooo`;oogl08oooool2oomo06Cooooo0Ol00001ooooo`0000?o0000ooooooooool0]?ooool4oomo
06?ooooo0Ol00001ooooo`0000?o0000ooooooooool0]?ooool4oomo06?ooooo0Ol00001ooooo`00
00?o0000ooooooooool0]Oooool2oomo06Cooooo0Ol00001ooooo`0000?o0000ooooooooool0oooo
oolLooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0
003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o
00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003ooooooooo
o`3ooooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool0
0003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooooaco
oooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oo
oooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001
ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo0?oo
oooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o
0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1
o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000oooooooo
ool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo
00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolL
ooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003o
ooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o0000
0Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3o
oooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003
o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo
0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oooooo
oooo0?oooooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001oooo
o`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo
7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000
ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo08kooooo0_ooO`2;oooo
o`7o00000Oooool00003o`000?oooooooooo08gooooo1?ooO`2:ooooo`7o00000Oooool00003o`00
0?oooooooooo08gooooo1?ooO`2:ooooo`7o00000Oooool00003o`000?oooooooooo08kooooo0_oo
O`2;ooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0
003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o
00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003ooooooooo
o`3ooooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool0
0003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooooaco
oooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oo
oooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001
ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo0?oo
oooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o
0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1
o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000oooooooo
ool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo
00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolL
ooooo`7o00000Oooool00?oo00008?l00001ooooo`00\
\>"],
  ImageRangeCache->{{{0, 287}, {287, 0}} -> {-1.01089, -1.01089, 0.00704453, \
0.00704453}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.49505 0.5 0.49505 [
[ 0 0 -0.125 0 ]
[ 0 0 -0.125 0 ]
[ 0 1 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
0 0 m
1 0 L
s
0 0 m
0 1 L
s
0 1 m
1 1 L
s
1 0 m
1 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
1 .5 0 r
.015 w
.03175 .1355 Mdot
.03435 .12523 Mdot
.11137 .12765 Mdot
.14107 .18841 Mdot
.16218 .24538 Mdot
.17294 .21053 Mdot
.18267 .18577 Mdot
.18434 .1304 Mdot
.18553 .30956 Mdot
.20401 .239 Mdot
.21247 .27571 Mdot
.21687 .20845 Mdot
.22376 .2799 Mdot
.22832 .27485 Mdot
.29063 .20974 Mdot
.29686 .25079 Mdot
.30487 .22936 Mdot
.30683 .34623 Mdot
.32055 .20902 Mdot
.32574 .21979 Mdot
.34472 .28521 Mdot
.35998 .36393 Mdot
.36335 .24976 Mdot
.3794 .36608 Mdot
.42386 .66992 Mdot
.44391 .74519 Mdot
.45059 .34198 Mdot
.47208 .67586 Mdot
.47436 .71381 Mdot
.49778 .59825 Mdot
.50874 .91643 Mdot
.51516 .76219 Mdot
.53655 .61374 Mdot
.56563 .75219 Mdot
.59189 .65665 Mdot
.59581 .61604 Mdot
.59923 .6556 Mdot
.60292 .68499 Mdot
.62656 .67779 Mdot
.63555 .72451 Mdot
.63919 .652 Mdot
.64169 .6004 Mdot
.64246 .58611 Mdot
.64496 .54267 Mdot
.64608 .77288 Mdot
.65077 .64308 Mdot
.66065 .57816 Mdot
.67474 .59169 Mdot
.69296 .563 Mdot
.72815 .65902 Mdot
.73169 .58879 Mdot
.74669 .61318 Mdot
.74821 .65474 Mdot
.75963 .63781 Mdot
.79673 .57809 Mdot
.80925 .55852 Mdot
.81525 .58444 Mdot
.83417 .62985 Mdot
.83598 .55526 Mdot
.91595 .49319 Mdot
1 0 0 r
.005 w
.16128 .17044 m
.18734 .17269 L
.21339 .17909 L
.2345 .18734 L
.23945 .19126 L
.2655 .20415 L
.27874 .21339 L
.29156 .22295 L
.31204 .23945 L
.31761 .24532 L
.33549 .2655 L
.34367 .28341 L
.34499 .29156 L
.34367 .29798 L
.31761 .3104 L
.29156 .30711 L
.2655 .30014 L
.24507 .29156 L
.23945 .28747 L
.21339 .27402 L
.20155 .2655 L
.18734 .25472 L
.16884 .23945 L
.16128 .2313 L
.14618 .21339 L
.13806 .18734 L
.16128 .17044 L
s
0 0 1 r
.65633 .57701 m
.68239 .56842 L
.70844 .56313 L
.7345 .56168 L
.76055 .5752 L
.76359 .57817 L
.76859 .60422 L
.76055 .62333 L
.75627 .63028 L
.7345 .65485 L
.73298 .65633 L
.70844 .6775 L
.69922 .68239 L
.68239 .69294 L
.65633 .70579 L
.64983 .70844 L
.63028 .71539 L
.60422 .72268 L
.57817 .72651 L
.55211 .7214 L
.53145 .70844 L
.52926 .68239 L
.54239 .65633 L
.55211 .63983 L
.56625 .63028 L
.57817 .6193 L
.60119 .60422 L
.60422 .60227 L
.63028 .58726 L
.65315 .57817 L
.65633 .57701 L
s
1 0 0 r
.03 w
.24141 .24033 Mdot
0 0 1 r
.64872 .64417 Mdot
1 0 0 r
.79703 .00495 m
.79703 .00495 L
.87129 .00495 L
.87129 .00495 L
F
0 0 1 r
.89604 .00495 m
.89604 .25248 L
.9703 .25248 L
.9703 .00495 L
F
1 0 1 r
.04 w
.64608 .77288 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P000182000`400?l00000o`00003ooooooolQ
ooooo`00ool0000Po`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`00
00?o0000ooooooooool0o_oooolEo`00o`Sooooo0Ol00001ooooo`0000?o0000ooooooooool0o_oo
oolEo`00o`Sooooo0Ol00001ooooo`0000?o0000ooooooooool0o_oooolEo`00o`Sooooo0Ol00001
ooooo`0000?o0000ooooooooool0o_oooolEo`00o`Sooooo0Ol00001ooooo`0000?o0000oooooooo
ool0o_oooolEo`00o`Sooooo0Ol00001ooooo`0000?o0000ooooooooool0o_oooolEo`00o`Sooooo
0Ol00001ooooo`0000?o0000ooooooooool0o_oooolEo`00o`Sooooo0Ol00001ooooo`0000?o0000
ooooooooool0o_oooolEo`00o`Sooooo0Ol00001ooooo`0000?o0000ooooooooool0o_oooolEo`00
o`Sooooo0Ol00001ooooo`0000?o0000ooooooooool0o_oooolEo`00o`Sooooo0Ol00001ooooo`00
00?o0000ooooooooool0o_oooolEo`00o`Sooooo0Ol00001ooooo`0000?o0000ooooooooool0o_oo
oolEo`00o`Sooooo0Ol00001ooooo`0000?o0000ooooooooool0o_oooolEo`00o`Sooooo0Ol00001
ooooo`0000?o0000ooooooooool0o_oooolEo`00o`Sooooo0Ol00001ooooo`0000?o0000oooooooo
ool0o_oooolEo`00o`Sooooo0Ol00001ooooo`0000?o0000ooooooooool0o_oooolEo`00o`Sooooo
0Ol00001ooooo`0000?o0000ooooooooool0o_oooolEo`00o`Sooooo0Ol00001ooooo`0000?o0000
ooooooooool0o_oooolEo`00o`Sooooo0Ol00001ooooo`0000?o0000ooooooooool0o_oooolEo`00
o`Sooooo0Ol00001ooooo`0000?o0000ooooooooool0o_oooolEo`00o`Sooooo0Ol00001ooooo`00
00?o0000ooooooooool0o_oooolEo`00o`Sooooo0Ol00001ooooo`0000?o0000ooooooooool0o_oo
oolEo`00o`Sooooo0Ol00001ooooo`0000?o0000ooooooooool0o_oooolEo`00o`Sooooo0Ol00001
ooooo`0000?o0000ooooooooool0o_oooolEo`00o`Sooooo0Ol00001ooooo`0000?o0000oooooooo
ool0o_oooolEo`00o`Sooooo0Ol00001ooooo`0000?o0000ooooooooool0o_oooolEo`00o`Sooooo
0Ol00001ooooo`0000?o0000ooooooooool0o_oooolEo`00o`Sooooo0Ol00001ooooo`0000?o0000
ooooooooool0o_oooolEo`00o`Sooooo0Ol00001ooooo`0000?o0000ooooooooool0o_oooolEo`00
o`Sooooo0Ol00001ooooo`0000?o0000ooooooooool0o_oooolEo`00o`Sooooo0Ol00001ooooo`00
00?o0000ooooooooool0o_oooolEo`00o`Sooooo0Ol00001ooooo`0000?o0000ooooooooool0o_oo
oolEo`00o`Sooooo0Ol00001ooooo`0000?o0000ooooooooool01_ooool2oomo0?Kooooo5Ol00?l8
ooooo`7o00000Oooool00003o`000?oooooooooo00Gooooo1?ooO`0Cooooo`;oogl0h?oooolEo`00
o`Sooooo0Ol00001ooooo`0000?o0000ooooooooool01Oooool4oomo01;ooooo1?ooO`0Booooo`;o
ogl0booooolEo`00o`Sooooo0Ol00001ooooo`0000?o0000ooooooooool01Oooool3oomo01?ooooo
1?ooO`0Aooooo`Coogl0b_oooolEo`00o`Sooooo0Ol00001ooooo`0000?o0000ooooooooool01?oo
ool4oomo01Cooooo0_ooO`0Booooo`Coogl0b_oooolEo`00o`Sooooo0Ol00001ooooo`0000?o0000
ooooooooool01?ooool4oomo02Wooooo0_ooO`3;oooooaGo003o2?ooool1o`00007ooooo00000ol0
003oooooooooo`05ooooo`;oogl0mooooolEo`00o`Sooooo0Ol00001ooooo`0000?o0000oooooooo
ool0o_oooolEo`00o`Sooooo0Ol00001ooooo`0000?o0000ooooooooool0o_oooolEo`00o`Sooooo
0Ol00001ooooo`0000?o0000ooooooooool0o_oooolEo`00o`Sooooo0Ol00001ooooo`0000?o0000
ooooooooool0o_oooolEo`00o`Sooooo0Ol00001ooooo`0000?o0000ooooooooool0o_oooolEo`00
o`Sooooo0Ol00001ooooo`0000?o0000ooooooooool0o_oooolEo`00o`Sooooo0Ol00001ooooo`00
00?o0000ooooooooool0o_oooolEo`00o`Sooooo0Ol00001ooooo`0000?o0000ooooooooool0:_oo
ool6ool00<kooooo5Ol00?l8ooooo`7o00000Oooool00003o`000?oooooooooo02Wooooo00?oo`00
ooooooooool01?ooool5ool00<Wooooo5Ol00?l8ooooo`7o00000Oooool00003o`000?oooooooooo
02Oooooo0_oo000<ooooo`Coo`00aOoooolEo`00o`Sooooo0Ol00001ooooo`0000?o0000oooooooo
ool09_ooool00ooo003oooooooooo`0@ooooo`Coo`00`OoooolEo`00o`Sooooo0Ol00001ooooo`00
00?o0000ooooooooool09?ooool00oooO`3oo`00ooooo`09ooooo`;oogl02oooool3ool00;kooooo
5Ol00?l8ooooo`7o00000Oooool00003o`000?oooooooooo02?ooooo00Coogl0ool00?ooO`3oogl0
2?ooool4oomo00gooooo00?oo`00ooooooooool0^ooooolEo`00o`Sooooo0Ol00001ooooo`0000?o
0000ooooooooool08oooool01?ooO`3oo`00oomo0?ooO`08ooooo`Coogl03_ooool2ool00;_ooooo
5Ol00?l8ooooo`7o00000Oooool00003o`000?oooooooooo02Cooooo00?oogl0ool00?ooool02Ooo
ool2oomo017ooooo0_oo002ioooooaGo003o2?ooool1o`00007ooooo00000ol0003oooooooooo`0U
ooooo`03ool00?oooooooooo01gooooo0_oo002goooooaGo003o2?ooool1o`00007ooooo00000ol0
003oooooooooo`0Uooooo`03ool00?oooooooooo01oooooo0_oo002eoooooaGo003o2?ooool1o`00
007ooooo00000ol0003oooooooooo`0Vooooo`03ool00?oooooooooo017ooooo0_ooO`0=ooooo`;o
o`001?ooool2oomo00Oooooo0_ooO`2ToooooaGo003o2?ooool1o`00007ooooo00000ol0003ooooo
ooooo`0Vooooo`03ool00?oooooooooo00Gooooo0_ooO`09ooooo`Coogl03_ooool00ooo003ooooo
ooooo`04oomo00Gooooo1?ooO`2SoooooaGo003o2?ooool1o`00007ooooo00000ol0003ooooooooo
o`0Vooooo`03ool00?oooooooooo00Cooooo1?ooO`08ooooo`Coogl03oooool00ooo003ooooooomo
0003oomo00Gooooo1?ooO`2SoooooaGo003o2?ooool1o`00007ooooo00000ol0003oooooooooo`0W
ooooo`03ool00?oooooooooo00?ooooo1?ooO`09ooooo`;oogl04Oooool01?oo003ooooooomo0?oo
O`07ooooo`?oogl0XooooolEo`00o`Sooooo0Ol00001ooooo`0000?o0000ooooooooool09oooool0
0ooo003oooooooooo`04ooooo`;oogl07_ooool00ooo003oooooooooo`07ooooo`Coogl0X_oooolE
o`00o`Sooooo0Ol00001ooooo`0000?o0000ooooooooool0:?ooool00ooo003oooooooooo`0Toooo
o`03ool00?oooooooooo00Kooooo1?ooO`2RoooooaGo003o2?ooool1o`00007ooooo00000ol0003o
ooooooooo`0Yooooo`03ool00?oooooooooo02Cooooo0_oo00000oooooooogl0oomo0004ooooo`;o
ogl0XooooolEo`00o`Sooooo0Ol00001ooooo`0000?o0000ooooooooool0:_ooool00ooo003ooooo
ooooo`0Cooooo`Coo`003_ooool01?oo003oogl0oomo0?ooO`2XoooooaGo003o2?ooool1o`00007o
oooo00000ol0003oooooooooo`0[ooooo`03ool00?oooooooooo017ooooo1_oo000=ooooo`04oomo
0?oo003oo`00oomo0:Sooooo5Ol00?l8ooooo`7o00000Oooool00003o`000?oooooooooo02cooooo
00?oo`00ooooooooool02?ooool2oomo00Gooooo2?oo000=ooooo`;oogl000?oo`00ooooooooool0
Y_oooolEo`00o`Sooooo0Ol00001ooooo`0000?o0000ooooooooool0;Oooool00ooo003ooooooooo
o`06ooooo`Coogl01?ooool8ool0013ooooo00?oo`00ooooooooool0YOoooolEo`00o`Sooooo0Ol0
0001ooooo`0000?o0000ooooooooool0:oooool2oomo0003oooooooo003ooooo00Kooooo1?ooO`04
ooooo`Soo`004Oooool00ooo003oooooooooo`2ToooooaGo003o2?ooool1o`00007ooooo00000ol0
003oooooooooo`0Zooooo`Coogl000?oooooool00?ooool01_ooool2oomo00Gooooo2?oo000;oooo
o`;oogl01Oooool00ooo003oooooooooo`09ooooo`;oogl0V?oooolEo`00o`Sooooo0Ol00001oooo
o`0000?o0000ooooooooool0:_ooool4oomo00;ooooo00?oo`00ooooooooool03?ooool6ool000_o
oooo1?ooO`04ooooo`03ool00?oooooooooo00Sooooo1?ooO`2GoooooaGo003o2?ooool1o`00007o
oooo00000ol0003oooooooooo`0[ooooo`;oogl01?ooool00ooo003oooooooooo`0<ooooo`Coo`00
3?ooool4oomo00Gooooo00?oo`00ooooooooool01oooool4oomo09Oooooo5Ol00?l8ooooo`7o0000
0Oooool00003o`000?oooooooooo03;ooooo0_oo000Mooooo`;oogl01oooool00ooo003ooooooooo
o`07ooooo`;oogl0]Oooool1o`00007ooooo00000ol0003oooooooooo`0dooooo`03ool00?oooooo
oooo02Cooooo00?oo`00ooooooooool0_Oooool1o`00007ooooo00000ol0003oooooooooo`0eoooo
o`03ool00?oooooooooo02Cooooo00?oo`00ooooooooool0_?ooool1o`00007ooooo00000ol0003o
ooooooooo`0fooooo`;oo`009Oooool00ooo003oooooooooo`2kooooo`7o00000Oooool00003o`00
0?oooooooooo03Sooooo0_oo00000oooO`3oooooooooo`02oomo01kooooo00?oo`00ooooooooool0
^oooool1o`00007ooooo00000ol0003oooooooooo`0hooooo`;oogl00_oo0004oomo01kooooo00?o
o`00ooooooooool0^_ooool1o`00007ooooo00000ol0003oooooooooo`0hooooo`Coogl00_oo0002
oomo01kooooo00?oo`00ooooooooool0^_ooool1o`00007ooooo00000ol0003oooooooooo`0ioooo
o`Googl000?oo`00ooooooooool07Oooool00ooo003oogl0oomo002jooooo`7o00000Oooool00003
o`000?oooooooooo03_ooooo1?ooO`02ool001gooooo00Coogl0ool00?ooO`3oogl0^Oooool1o`00
007ooooo00000ol0003oooooooooo`0looooo`;oogl00oooool2ool001_ooooo00Coogl0ool00?oo
O`3oogl0^Oooool1o`00007ooooo00000ol0003oooooooooo`13ooooo`;oo`006_ooool00oooO`3o
o`00ooooo`2iooooo`7o00000Oooool00003o`000?oooooooooo04Gooooo0_oo000Iooooo`03ool0
0?oooooooooo0;Sooooo0Ol00001ooooo`0000?o0000ooooooooool0Aoooool2ool001Gooooo0_oo
002kooooo`7o00000Oooool00003o`000?oooooooooo04Wooooo0ooo000@ooooo`;oo`00_Oooool1
o`00007ooooo00000ol0003oooooooooo`0aooooo`;oogl06Oooool3ool000cooooo00?oo`00oooo
ooooool0_Oooool1o`00007ooooo00000ol0003oooooooooo`0`ooooo`Coogl06oooool6ool000Co
oooo0_oo0030ooooo`7o00000Oooool00003o`000?oooooooooo033ooooo1?ooO`0Qooooo`Coo`00
`_ooool1o`00007ooooo00000ol0003oooooooooo`0aooooo`;oogl0j?ooool1o`00007ooooo0000
0ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLoooo
o`7o00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003ooooo
ooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Ooo
ool00003o`000?oooooooooo07gooooo0_ooO`2Looooo`7o00000Oooool00003o`000?oooooooooo
07cooooo1?ooO`2Kooooo`7o00000Oooool00003o`000?oooooooooo05Cooooo0_ooO`0Vooooo`Co
ogl0Voooool1o`00007ooooo00000ol0003oooooooooo`1Cooooo`Coogl09_ooool2oomo09cooooo
0Ol00001ooooo`0000?o0000ooooooooool0Doooool4oomo0<Cooooo0Ol00001ooooo`0000?o0000
ooooooooool0E?ooool2oomo0<Gooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLoooo
o`7o00000Oooool00003o`000?oooooooooo06?ooooo0_ooO`04ooooo`;oogl0/?ooool1o`00007o
oooo00000ol0003oooooooooo`1Rooooo`Coogl00_ooool4oomo0:oooooo0Ol00001ooooo`0000?o
0000ooooooooool0H_ooool4oomo00;ooooo1?ooO`2_ooooo`7o00000Oooool00003o`000?oooooo
oooo06?ooooo0_ooO`04ooooo`;oogl0/?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooo
oacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`00
0?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol0
0001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo
0?oooooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`00
00?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?oo
ool1o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000oooo
ooooool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007o
oooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooo
oolLooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0
003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o
00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003ooooooooo
o`3ooooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool0
0003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooooaco
oooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oo
oooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001
ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo0?oo
oooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o
0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1
o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000oooooooo
ool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo
00000ol0003oooooooooo`3oooooo`Cooooo0_ooO`0Fooooo`7o00000Oooool00003o`000?oooooo
oooo0?oooooo0oooool4oomo01Gooooo0Ol00001ooooo`0000?o0000ooooooooool0ooooool3oooo
o`Coogl05Oooool1o`00007ooooo00000ol0003oooooooooo`3oooooo`Cooooo0_ooO`0Fooooo`7o
00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003ooooooooo
o`3ooooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool0
0003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooooaco
oooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oo
oooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001
ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo0?oo
oooo7?ooool1o`00007ooooo00000ol0003oooooooooo`2eooooo`;oogl0I?ooool1o`00007ooooo
00000ol0003oooooooooo`2dooooo`Coogl0Hoooool1o`00007ooooo00000ol0003oooooooooo`2d
ooooo`Coogl0Hoooool1o`00007ooooo00000ol0003oooooooooo`2eooooo`;oogl0=Oooool2oomo
02gooooo0Ol00001ooooo`0000?o0000ooooooooool0i?ooool2oomo00Gooooo1?ooO`0/ooooo`7o
00000Oooool00003o`000?oooooooooo0>?ooooo1?ooO`04ooooo`Coogl0;?ooool1o`00007ooooo
00000ol0003oooooooooo`33ooooo`;oogl07_ooool4oomo00Gooooo0_ooO`0]ooooo`7o00000Ooo
ool00003o`000?oooooooooo0<;ooooo1?ooO`0;o`00oa?ooooo0_ooO`0eooooo`7o00000Oooool0
0003o`000?oooooooooo0<;ooooo1?l00?l;ooooo`;o003oB?ooool1o`00007ooooo00000ol0003o
ooooooooo`2nooooo`Co003o00?ooooooomo0?ooO`003_ooool2o`00odKooooo0Ol00001ooooo`00
00?o0000ooooooooool0^Oooool2oomo00?o003o5oooool2o`00o`Wooooo0_ooO`0iooooo`7o0000
0Oooool00003o`000?oooooooooo0;Oooooo1?l00?l00oooO`3oooooooooo`0Iooooo`;o003o1_oo
ool4oomo03Sooooo0Ol00001ooooo`0000?o0000ooooooooool0]?ooool3o`00o`03ooooooooO`3o
ogl000;oogl07?ooool00ol00?ooooooooooo`04ooooo`Coogl00oooool2oomo03?ooooo0Ol00001
ooooo`0000?o0000ooooooooool0/_ooool2o`00o`?oogl00_ooool2oomo01?ooooo0_ooO`08oooo
o`03o`00oooooooooooo00Gooooo0_ooO`03ooooo`Coogl0<_ooool1o`00007ooooo00000ol0003o
ooooooooo`2`ooooo`;o003o00?ooooooomo0?ooO`000_ooO`06ooooo`;oogl03_ooool4oomo00Oo
oooo00?o003oooooooooool02_ooool4oomo03;ooooo0Ol00001ooooo`0000?o0000ooooooooool0
[_ooool2o`00o`Cooooo0_ooO`06ooooo`Coogl03Oooool4oomo00Oooooo00?o003oooooooooool0
2oooool2oomo03?ooooo0Ol00001ooooo`0000?o0000ooooooooool0Roooool2oomo023ooooo00?o
003oooooooooool01?ooool2oomo00Kooooo1?ooO`0>ooooo`;oogl02Oooool00ol00?oooooooooo
o`0oooooo`7o00000Oooool00003o`000?oooooooooo08[ooooo1?ooO`0Mooooo`;o003o1_ooool4
oomo00Kooooo0_ooO`0Jooooo`03o`00oooooooooooo03oooooo0Ol00001ooooo`0000?o0000oooo
ooooool0R_ooool4oomo01cooooo00?o003oooooooooool01_ooool4oomo02;ooooo00?o003ooooo
ooooool0?oooool1o`00007ooooo00000ol0003oooooooooo`2;ooooo`;oogl06oooool2o`00o`[o
oooo0_ooO`0Sooooo`03o`00oooooooooooo03oooooo0Ol00001ooooo`0000?o0000ooooooooool0
U_ooool2oomo00kooooo0_l00?lZooooo`;oogl01Oooool00ol00?ooooooooooo`0oooooo`7o0000
0Oooool00003o`000?oooooooooo09Gooooo1?ooO`0<ooooo`04o`00ooooooooogl0oomo02Sooooo
1?ooO`03ooooo`03o`00oooooooooooo043ooooo0Ol00001ooooo`0000?o0000ooooooooool0UOoo
ool4oomo00[ooooo0_l00?l00oooooooogl0oomo0002oomo02Oooooo1?ooO`03ooooo`03o`00oooo
oooooooo043ooooo0Ol00001ooooo`0000?o0000ooooooooool0U_ooool2oomo00[ooooo00Co003o
oooooooooooooooo1?ooO`0Xooooo`;oogl01?ooool00ol00?ooooooooooo`10ooooo`7o00000Ooo
ool00003o`000?oooooooooo0:7ooooo00?o003oooooooooool00oooool2oomo02kooooo00?o003o
ooooooooool0@Oooool1o`00007ooooo00000ol0003oooooooooo`2Pooooo`03o`00oooooooooooo
03?ooooo00?o003oooooooooool04_ooool2oomo02kooooo0Ol00001ooooo`0000?o0000oooooooo
ool0W_ooool2o`00ocGooooo00?o003oooooooooool04_ooool4oomo02gooooo0Ol00001ooooo`00
00?o0000ooooooooool0WOooool00ol00?ooooooooooo`0Eooooo`Co003o7?ooool00ol00?ooogl0
oomo000Booooo`Coogl0;Oooool1o`00007ooooo00000ol0003oooooooooo`2Looooo`03o`00oooo
oooooooo01Gooooo1_l00?lJooooo`03o`00ooooO`3oogl000;oogl04_ooool2oomo02kooooo0Ol0
0001ooooo`0000?o0000ooooooooool0Voooool00ol00?ooooooooooo`0Eooooo`So003o6?ooool0
0ol00?oooooooomo0003oomo04;ooooo0Ol00001ooooo`0000?o0000ooooooooool0Voooool00ol0
0?ooooooooooo`0Eooooo`So003o5oooool01?l00?ooooooooooooooool2oomo04?ooooo0Ol00001
ooooo`0000?o0000ooooooooool0V_ooool00ol00?ooooooooooo`0Fooooo`So003o5_ooool00ol0
0?ooooooooooo`17ooooo`7o00000Oooool00003o`000?oooooooooo09Wooooo00?o003ooooooooo
ool03?ooool2oomo00Sooooo00?oogl0o`00ool00?l01_l00?lEooooo`03o`00oooooooooooo00;o
ogl0A_ooool1o`00007ooooo00000ol0003oooooooooo`2Iooooo`03o`00oooooooooooo00[ooooo
1OooO`07ooooo`;oogl01_l00?lCooooo`;oogl000?o003oooooooooool01?ooO`15ooooo`7o0000
0Oooool00003o`000?oooooooooo09Sooooo00?o003oooooooooool02_ooool6oomo00Sooooo0_oo
O`04o`00oa?ooooo0_ooO`02o`00o`;ooooo1?ooO`15ooooo`7o00000Oooool00003o`000?oooooo
oooo09Sooooo00?o003oooooooooool02_ooool5oomo02;ooooo00Coogl0o`00ooooO`3oogl00ooo
ool2oomo04Kooooo0Ol00001ooooo`0000?o0000ooooooooool0M_ooool2oomo01oooooo00?o003o
ooooooooool03?ooool2oomo02Cooooo00?o003ooomo0?ooO`00C?ooool1o`00007ooooo00000ol0
003oooooooooo`1eooooo`Coogl07_ooool00ol00?ooooooooooo`0aooooo`03o`00oooooooooooo
04gooooo0Ol00001ooooo`0000?o0000ooooooooool0MOooool4oomo00[ooooo0_ooO`0Aooooo`03
o`00oooooooooooo037ooooo00?o003oooooooooool0C_ooool1o`00007ooooo00000ol0003ooooo
ooooo`1fooooo`;oogl02_ooool4oomo00oooooo00?o003oooooooooool06?ooool2oomo01Oooooo
00?o003oooooooooool0Coooool1o`00007ooooo00000ol0003oooooooooo`22ooooo`Coogl03ooo
ool00ol00?ooooooooooo`0Gooooo`Coogl05?ooool2o`00oe;ooooo0Ol00001ooooo`0000?o0000
ooooooooool0Poooool2oomo00oooooo00?o003oooooooooool04_ooool2oomo00Cooooo1?ooO`0A
ooooo`?o003oE?ooool1o`00007ooooo00000ol0003oooooooooo`2Dooooo`03o`00oooooooooooo
017ooooo1?ooO`04ooooo`;oogl04?ooool2o`00oeOooooo0Ol00001ooooo`0000?o0000oooooooo
ool0U?ooool00ol00?ooooooooooo`0Aooooo`Coogl05Oooool00ol00?ooooooooooo`1Gooooo`7o
00000Oooool00003o`000?oooooooooo09Cooooo00?o003oooooooooool04_ooool2oomo01Cooooo
0_l00?mJooooo`7o00000Oooool00003o`000?oooooooooo09Cooooo00?o003oooooooooool09_oo
ool2o`00oecooooo0Ol00001ooooo`0000?o0000ooooooooool0UOooool00ol00?ooooooooooo`0T
ooooo`03o`00oooooooooooo05cooooo0Ol00001ooooo`0000?o0000ooooooooool0UOooool00ol0
0?ooooooooooo`0Rooooo`;o003oGoooool1o`00007ooooo00000ol0003oooooooooo`2Eooooo`03
o`00oooooooooooo023ooooo0_l00?mQooooo`7o00000Oooool00003o`000?oooooooooo08Cooooo
0_ooO`0?ooooo`;o003o7oooool2o`00of?ooooo0Ol00001ooooo`0000?o0000ooooooooool0Pooo
ool4oomo013ooooo0_l00?lJooooo`?o003oIOooool1o`00007ooooo00000ol0003oooooooooo`23
ooooo`Coogl04_ooool2o`00oaCooooo1?l00?mXooooo`7o00000Oooool00003o`000?oooooooooo
08Cooooo0_ooO`0Eooooo`?o003o3_ooool3o`00o`?ooooo0_ooO`1Wooooo`7o00000Oooool00003
o`000?oooooooooo09kooooo0ol00?l5ooooo`Ko003o1Oooool4oomo06Kooooo0Ol00001ooooo`00
00?o0000ooooooooool0XOooool5o`00o`_ooooo1?ooO`1Vooooo`7o00000Oooool00003o`000?oo
oooooooo0;;ooooo0_ooO`1Wooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1
o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000oooooooo
ool0Noooool2oomo09kooooo0Ol00001ooooo`0000?o0000ooooooooool0N_ooool4oomo09gooooo
0Ol00001ooooo`0000?o0000ooooooooool0N_ooool4oomo023ooooo0_ooO`1kooooo`7o00000Ooo
ool00003o`000?oooooooooo07_ooooo0_ooO`0Pooooo`Coogl0N_ooool1o`00007ooooo00000ol0
003oooooooooo`2Mooooo`Coogl04oooool5ool0of;ooooo0Ol00001ooooo`0000?o0000oooooooo
ool0T?ooool2oomo00cooooo0_ooO`0Cooooo`Ooo`3oHOooool1o`00007ooooo00000ol0003ooooo
ooooo`2?ooooo`Coogl07oooool9ool0of3ooooo0Ol00001ooooo`0000?o0000ooooooooool0Sooo
ool4oomo01kooooo2ooo0?mOooooo`7o00000Oooool00003o`000?oooooooooo093ooooo0_ooO`0O
ooooo`_oo`3oGoooool1o`00007ooooo00000ol0003oooooooooo`2aooooo`_oo`3oGoooool1o`00
007ooooo00000ol0003oooooooooo`2aooooo`_oo`3oGoooool1o`00007ooooo00000ol0003ooooo
ooooo`2aooooo`_oo`3oGoooool1o`00007ooooo00000ol0003oooooooooo`2booooo`Woo`3oH?oo
ool1o`00007ooooo00000ol0003oooooooooo`2cooooo`Ooo`3oHOooool1o`00007ooooo00000ol0
003oooooooooo`2dooooo`Goo`3oH_ooool1o`00007ooooo00000ol0003oooooooooo`3ooooooaco
oooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oo
oooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001
ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo0?oo
oooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o
0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1
o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000oooooooo
ool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo
00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolL
ooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003o
ooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o0000
0Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3o
oooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003
o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo
0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oooooo
oooo0?oooooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001oooo
o`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo
7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000
ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00
007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0
oooooolLooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo0000
0ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0S_ooool2oomo
08_ooooo0Ol00001ooooo`0000?o0000ooooooooool0SOooool4oomo08[ooooo0Ol00001ooooo`00
00?o0000ooooooooool0SOooool4oomo08[ooooo0Ol00001ooooo`0000?o0000ooooooooool0S_oo
ool2oomo08_ooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool0
0003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooooaco
oooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oo
oooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001
ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo0?oo
oooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o
0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1
o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000oooooooo
ool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo
00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolL
ooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003o
ooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o0000
0Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3o
oooooacooooo0Ol00001ooooo`00ool0000Po`00007ooooo0000\
\>"],
  ImageRangeCache->{{{0, 287}, {287, 0}} -> {-1.01089, -1.01089, 0.00704453, \
0.00704453}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.49505 0.5 0.49505 [
[ 0 0 -0.125 0 ]
[ 0 0 -0.125 0 ]
[ 0 1 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
0 0 m
1 0 L
s
0 0 m
0 1 L
s
0 1 m
1 1 L
s
1 0 m
1 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
1 .5 0 r
.015 w
.03175 .1355 Mdot
.03435 .12523 Mdot
.11137 .12765 Mdot
.14107 .18841 Mdot
.16218 .24538 Mdot
.17294 .21053 Mdot
.18267 .18577 Mdot
.18434 .1304 Mdot
.18553 .30956 Mdot
.20401 .239 Mdot
.21247 .27571 Mdot
.21687 .20845 Mdot
.22376 .2799 Mdot
.22832 .27485 Mdot
.29063 .20974 Mdot
.29686 .25079 Mdot
.30487 .22936 Mdot
.30683 .34623 Mdot
.32055 .20902 Mdot
.32574 .21979 Mdot
.34472 .28521 Mdot
.35998 .36393 Mdot
.36335 .24976 Mdot
.3794 .36608 Mdot
.42386 .66992 Mdot
.44391 .74519 Mdot
.45059 .34198 Mdot
.47208 .67586 Mdot
.47436 .71381 Mdot
.49778 .59825 Mdot
.50874 .91643 Mdot
.51516 .76219 Mdot
.53655 .61374 Mdot
.56563 .75219 Mdot
.59189 .65665 Mdot
.59581 .61604 Mdot
.59923 .6556 Mdot
.60292 .68499 Mdot
.62656 .67779 Mdot
.63555 .72451 Mdot
.63919 .652 Mdot
.64169 .6004 Mdot
.64246 .58611 Mdot
.64496 .54267 Mdot
.64608 .77288 Mdot
.65077 .64308 Mdot
.66065 .57816 Mdot
.67474 .59169 Mdot
.69296 .563 Mdot
.72815 .65902 Mdot
.73169 .58879 Mdot
.74669 .61318 Mdot
.74821 .65474 Mdot
.75963 .63781 Mdot
.79673 .57809 Mdot
.80925 .55852 Mdot
.81525 .58444 Mdot
.83417 .62985 Mdot
.83598 .55526 Mdot
.91595 .49319 Mdot
1 0 0 r
.005 w
.16128 .17044 m
.18734 .17269 L
.21339 .17909 L
.2345 .18734 L
.23945 .19126 L
.2655 .20415 L
.27874 .21339 L
.29156 .22295 L
.31204 .23945 L
.31761 .24532 L
.33549 .2655 L
.34367 .28341 L
.34499 .29156 L
.34367 .29798 L
.31761 .3104 L
.29156 .30711 L
.2655 .30014 L
.24507 .29156 L
.23945 .28747 L
.21339 .27402 L
.20155 .2655 L
.18734 .25472 L
.16884 .23945 L
.16128 .2313 L
.14618 .21339 L
.13806 .18734 L
.16128 .17044 L
s
0 0 1 r
.65633 .57701 m
.68239 .56842 L
.70844 .56313 L
.7345 .56168 L
.76055 .5752 L
.76359 .57817 L
.76859 .60422 L
.76055 .62333 L
.75627 .63028 L
.7345 .65485 L
.73298 .65633 L
.70844 .6775 L
.69922 .68239 L
.68239 .69294 L
.65633 .70579 L
.64983 .70844 L
.63028 .71539 L
.60422 .72268 L
.57817 .72651 L
.55211 .7214 L
.53145 .70844 L
.52926 .68239 L
.54239 .65633 L
.55211 .63983 L
.56625 .63028 L
.57817 .6193 L
.60119 .60422 L
.60422 .60227 L
.63028 .58726 L
.65315 .57817 L
.65633 .57701 L
s
1 0 0 r
.03 w
.24141 .24033 Mdot
0 0 1 r
.64872 .64417 Mdot
1 0 0 r
.79703 .00495 m
.79703 .00495 L
.87129 .00495 L
.87129 .00495 L
F
0 0 1 r
.89604 .00495 m
.89604 .25248 L
.9703 .25248 L
.9703 .00495 L
F
1 0 1 r
.04 w
.65077 .64308 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P000182000`400?l00000o`00003oo`3ooolQ
0?ooo`00ool0000Po`000040oooo00000ol00000oooo0?ooo`3o0?oooa`0oooo0Ol000010?ooo`00
00?o00000?ooo`3oool0oP3ooolEo`00o`P0oooo0Ol000010?ooo`0000?o00000?ooo`3oool0oP3o
oolEo`00o`P0oooo0Ol000010?ooo`0000?o00000?ooo`3oool0oP3ooolEo`00o`P0oooo0Ol00001
0?ooo`0000?o00000?ooo`3oool0oP3ooolEo`00o`P0oooo0Ol000010?ooo`0000?o00000?ooo`3o
ool0oP3ooolEo`00o`P0oooo0Ol000010?ooo`0000?o00000?ooo`3oool0oP3ooolEo`00o`P0oooo
0Ol000010?ooo`0000?o00000?ooo`3oool0oP3ooolEo`00o`P0oooo0Ol000010?ooo`0000?o0000
0?ooo`3oool0oP3ooolEo`00o`P0oooo0Ol000010?ooo`0000?o00000?ooo`3oool0oP3ooolEo`00
o`P0oooo0Ol000010?ooo`0000?o00000?ooo`3oool0oP3ooolEo`00o`P0oooo0Ol000010?ooo`00
00?o00000?ooo`3oool0oP3ooolEo`00o`P0oooo0Ol000010?ooo`0000?o00000?ooo`3oool0oP3o
oolEo`00o`P0oooo0Ol000010?ooo`0000?o00000?ooo`3oool0oP3ooolEo`00o`P0oooo0Ol00001
0?ooo`0000?o00000?ooo`3oool0oP3ooolEo`00o`P0oooo0Ol000010?ooo`0000?o00000?ooo`3o
ool0oP3ooolEo`00o`P0oooo0Ol000010?ooo`0000?o00000?ooo`3oool0oP3ooolEo`00o`P0oooo
0Ol000010?ooo`0000?o00000?ooo`3oool0oP3ooolEo`00o`P0oooo0Ol000010?ooo`0000?o0000
0?ooo`3oool0oP3ooolEo`00o`P0oooo0Ol000010?ooo`0000?o00000?ooo`3oool0oP3ooolEo`00
o`P0oooo0Ol000010?ooo`0000?o00000?ooo`3oool0oP3ooolEo`00o`P0oooo0Ol000010?ooo`00
00?o00000?ooo`3oool0oP3ooolEo`00o`P0oooo0Ol000010?ooo`0000?o00000?ooo`3oool0oP3o
oolEo`00o`P0oooo0Ol000010?ooo`0000?o00000?ooo`3oool0oP3ooolEo`00o`P0oooo0Ol00001
0?ooo`0000?o00000?ooo`3oool0oP3ooolEo`00o`P0oooo0Ol000010?ooo`0000?o00000?ooo`3o
ool0oP3ooolEo`00o`P0oooo0Ol000010?ooo`0000?o00000?ooo`3oool0oP3ooolEo`00o`P0oooo
0Ol000010?ooo`0000?o00000?ooo`3oool0oP3ooolEo`00o`P0oooo0Ol000010?ooo`0000?o0000
0?ooo`3oool0oP3ooolEo`00o`P0oooo0Ol000010?ooo`0000?o00000?ooo`3oool0oP3ooolEo`00
o`P0oooo0Ol000010?ooo`0000?o00000?ooo`3oool0oP3ooolEo`00o`P0oooo0Ol000010?ooo`00
00?o00000?ooo`3oool0oP3ooolEo`00o`P0oooo0Ol000010?ooo`0000?o00000?ooo`3oool0oP3o
oolEo`00o`P0oooo0Ol000010?ooo`0000?o00000?ooo`3oool01P3oool20?mo0?H0oooo5Ol00?l8
0?ooo`7o00000@3oool00003o`00003oool0oooo00D0oooo103oO`0C0?ooo`80ogl0h03ooolEo`00
o`P0oooo0Ol000010?ooo`0000?o00000?ooo`3oool01@3oool40?mo0180oooo103oO`0B0?ooo`80
ogl0b`3ooolEo`00o`P0oooo0Ol000010?ooo`0000?o00000?ooo`3oool01@3oool30?mo01<0oooo
103oO`0A0?ooo`@0ogl0bP3ooolEo`00o`P0oooo0Ol000010?ooo`0000?o00000?ooo`3oool0103o
ool40?mo01@0oooo0P3oO`0B0?ooo`@0ogl0bP3ooolEo`00o`P0oooo0Ol000010?ooo`0000?o0000
0?ooo`3oool0103oool40?mo02T0oooo0P3oO`3;0?oooaGo003o203oool1o`000040oooo00000ol0
0000oooo0?ooo`050?ooo`80ogl0m`3ooolEo`00o`P0oooo0Ol000010?ooo`0000?o00000?ooo`3o
ool0oP3ooolEo`00o`P0oooo0Ol000010?ooo`0000?o00000?ooo`3oool0oP3ooolEo`00o`P0oooo
0Ol000010?ooo`0000?o00000?ooo`3oool0oP3ooolEo`00o`P0oooo0Ol000010?ooo`0000?o0000
0?ooo`3oool0oP3ooolEo`00o`P0oooo0Ol000010?ooo`0000?o00000?ooo`3oool0oP3ooolEo`00
o`P0oooo0Ol000010?ooo`0000?o00000?ooo`3oool0oP3ooolEo`00o`P0oooo0Ol000010?ooo`00
00?o00000?ooo`3oool0oP3ooolEo`00o`P0oooo0Ol000010?ooo`0000?o00000?ooo`3oool0:P3o
ool6ool00<h0oooo5Ol00?l80?ooo`7o00000@3oool00003o`00003oool0oooo02T0oooo00?oo`00
0?ooo`3oool0103oool5ool00<T0oooo5Ol00?l80?ooo`7o00000@3oool00003o`00003oool0oooo
02L0oooo0_oo000<0?ooo`Coo`00a@3ooolEo`00o`P0oooo0Ol000010?ooo`0000?o00000?ooo`3o
ool09P3oool00ooo0000oooo0?ooo`0@0?ooo`Coo`00`@3ooolEo`00o`P0oooo0Ol000010?ooo`00
00?o00000?ooo`3oool0903oool00`3oO`3oo`000?ooo`090?ooo`80ogl02`3oool3ool00;h0oooo
5Ol00?l80?ooo`7o00000@3oool00003o`00003oool0oooo02<0oooo00@0ogl0ool0003oO`00ogl0
203oool40?mo00d0oooo00?oo`000?ooo`3oool0^`3ooolEo`00o`P0oooo0Ol000010?ooo`0000?o
00000?ooo`3oool08`3oool0103oO`3oo`000?mo003oO`080?ooo`@0ogl03P3oool2ool00;/0oooo
5Ol00?l80?ooo`7o00000@3oool00003o`00003oool0oooo02@0oooo00<0ogl0ool0003oool02@3o
ool20?mo0140oooo0_oo002i0?oooaGo003o203oool1o`000040oooo00000ol00000oooo0?ooo`0U
0?ooo`03ool0003oool0oooo01d0oooo0_oo002g0?oooaGo003o203oool1o`000040oooo00000ol0
0000oooo0?ooo`0U0?ooo`03ool0003oool0oooo01l0oooo0_oo002e0?oooaGo003o203oool1o`00
0040oooo00000ol00000oooo0?ooo`0V0?ooo`03ool0003oool0oooo0140oooo0P3oO`0=0?ooo`;o
o`00103oool20?mo00L0oooo0P3oO`2T0?oooaGo003o203oool1o`000040oooo00000ol00000oooo
0?ooo`0V0?ooo`03ool0003oool0oooo00D0oooo0P3oO`090?ooo`@0ogl03P3oool00ooo0000oooo
0?ooo`040?mo00D0oooo103oO`2S0?oooaGo003o203oool1o`000040oooo00000ol00000oooo0?oo
o`0V0?ooo`03ool0003oool0oooo00@0oooo103oO`080?ooo`@0ogl03`3oool00ooo0000oooo0?mo
00030?mo00D0oooo103oO`2S0?oooaGo003o203oool1o`000040oooo00000ol00000oooo0?ooo`0W
0?ooo`03ool0003oool0oooo00<0oooo103oO`090?ooo`80ogl04@3oool01?oo0000oooo0?mo003o
O`070?ooo`<0ogl0X`3ooolEo`00o`P0oooo0Ol000010?ooo`0000?o00000?ooo`3oool09`3oool0
0ooo0000oooo0?ooo`040?ooo`80ogl07P3oool00ooo0000oooo0?ooo`070?ooo`@0ogl0XP3ooolE
o`00o`P0oooo0Ol000010?ooo`0000?o00000?ooo`3oool0:03oool00ooo0000oooo0?ooo`0T0?oo
o`03ool0003oool0oooo00H0oooo103oO`2R0?oooaGo003o203oool1o`000040oooo00000ol00000
oooo0?ooo`0Y0?ooo`03ool0003oool0oooo02@0oooo0_oo00000`3oool0ogl00?mo00040?ooo`80
ogl0X`3ooolEo`00o`P0oooo0Ol000010?ooo`0000?o00000?ooo`3oool0:P3oool00ooo0000oooo
0?ooo`0C0?ooo`@0o`003P3oool01?oo0000ogl00?mo003oO`2X0?oooaGo003o203oool1o`000040
oooo00000ol00000oooo0?ooo`0[0?ooo`03ool0003oool0oooo0140oooo1P3o000=0?ooo`040?mo
0?oo003oo`000?mo0:P0oooo5Ol00?l80?ooo`7o00000@3oool00003o`00003oool0oooo02`0oooo
00?oo`000?ooo`3oool0203oool20?mo00D0oooo203o000=0?ooo`80ogl000?oo`000?ooo`3oool0
YP3ooolEo`00o`P0oooo0Ol000010?ooo`0000?o00000?ooo`3oool0;@3oool00ooo0000oooo0?oo
o`060?ooo`@0ogl0103oool80?l00100oooo00?oo`000?ooo`3oool0Y@3ooolEo`00o`P0oooo0Ol0
00010?ooo`0000?o00000?ooo`3oool0:`3oool20?mo00030?oooooo0000oooo00H0oooo103oO`04
0?ooo`P0o`004@3oool00ooo0000oooo0?ooo`2T0?oooaGo003o203oool1o`000040oooo00000ol0
0000oooo0?ooo`0Z0?ooo`@0ogl000<0ooooool0003oool01P3oool20?mo00D0oooo203o000;0?oo
o`80ogl01@3oool00ooo0000oooo0?ooo`090?ooo`80ogl0V03ooolEo`00o`P0oooo0Ol000010?oo
o`0000?o00000?ooo`3oool0:P3oool40?mo0080oooo00?oo`000?ooo`3oool0303oool60?l000/0
oooo103oO`040?ooo`03ool0003oool0oooo00P0oooo103oO`2G0?oooaGo003o203oool1o`000040
oooo00000ol00000oooo0?ooo`0[0?ooo`80ogl0103oool00ooo0000oooo0?ooo`0<0?ooo`@0o`00
303oool40?mo00D0oooo00?oo`000?ooo`3oool01`3oool40?mo09L0oooo5Ol00?l80?ooo`7o0000
0@3oool00003o`00003oool0oooo0380oooo0_oo000M0?ooo`80ogl01`3oool00ooo0000oooo0?oo
o`070?ooo`80ogl0]@3oool1o`000040oooo00000ol00000oooo0?ooo`0d0?ooo`03ool0003oool0
oooo02@0oooo00?oo`000?ooo`3oool0_@3oool1o`000040oooo00000ol00000oooo0?ooo`0e0?oo
o`03ool0003oool0oooo02@0oooo00?oo`000?ooo`3oool0_03oool1o`000040oooo00000ol00000
oooo0?ooo`0f0?ooo`;oo`009@3oool00ooo0000oooo0?ooo`2k0?ooo`7o00000@3oool00003o`00
003oool0oooo03P0oooo0_oo00000`3oO`00oooo0?ooo`020?mo01h0oooo00?oo`000?ooo`3oool0
^`3oool1o`000040oooo00000ol00000oooo0?ooo`0h0?ooo`80ogl00_oo00040?mo01h0oooo00?o
o`000?ooo`3oool0^P3oool1o`000040oooo00000ol00000oooo0?ooo`0h0?ooo`@0ogl00_oo0002
0?mo01h0oooo00?oo`000?ooo`3oool0^P3oool1o`000040oooo00000ol00000oooo0?ooo`0i0?oo
o`D0ogl000?oo`000?ooo`3oool07@3oool00ooo0000ogl00?mo002j0?ooo`7o00000@3oool00003
o`00003oool0oooo03/0oooo103oO`02ool001d0oooo00@0ogl0ool0003oO`00ogl0^@3oool1o`00
0040oooo00000ol00000oooo0?ooo`0l0?ooo`80ogl00`3oool2ool001/0oooo00@0ogl0ool0003o
O`00ogl0^@3oool1o`000040oooo00000ol00000oooo0?ooo`130?ooo`;oo`006P3oool00`3oO`3o
o`000?ooo`2i0?ooo`7o00000@3oool00003o`00003oool0oooo04D0oooo0_oo000I0?ooo`03ool0
003oool0oooo0;P0oooo0Ol000010?ooo`0000?o00000?ooo`3oool0A`3oool2ool001D0oooo0_oo
002k0?ooo`7o00000@3oool00003o`00003oool0oooo04T0oooo0ooo000@0?ooo`;oo`00_@3oool1
o`000040oooo00000ol00000oooo0?ooo`0a0?ooo`80ogl06@3oool3ool000`0oooo00?oo`000?oo
o`3oool0_@3oool1o`000040oooo00000ol00000oooo0?ooo`0`0?ooo`@0ogl06`3oool6ool000@0
oooo0_oo00300?ooo`7o00000@3oool00003o`00003oool0oooo0300oooo103oO`0Q0?ooo`Coo`00
`P3oool1o`000040oooo00000ol00000oooo0?ooo`0a0?ooo`80ogl0j03oool1o`000040oooo0000
0ol00000oooo0?ooo`3o0?oooa`0oooo0Ol000010?ooo`0000?o00000?ooo`3oool0o`3ooolL0?oo
o`7o00000@3oool00003o`00003oool0oooo0?l0oooo703oool1o`000040oooo00000ol00000oooo
0?ooo`3o0?oooa`0oooo0Ol000010?ooo`0000?o00000?ooo`3oool0o`3ooolL0?ooo`7o00000@3o
ool00003o`00003oool0oooo07d0oooo0P3oO`2L0?ooo`7o00000@3oool00003o`00003oool0oooo
07`0oooo103oO`2K0?ooo`7o00000@3oool00003o`00003oool0oooo05@0oooo0P3oO`0V0?ooo`@0
ogl0V`3oool1o`000040oooo00000ol00000oooo0?ooo`1C0?ooo`@0ogl09P3oool20?mo09`0oooo
0Ol000010?ooo`0000?o00000?ooo`3oool0D`3oool40?mo0<@0oooo0Ol000010?ooo`0000?o0000
0?ooo`3oool0E03oool20?mo0<D0oooo0Ol000010?ooo`0000?o00000?ooo`3oool0o`3ooolL0?oo
o`7o00000@3oool00003o`00003oool0oooo06<0oooo0P3oO`040?ooo`80ogl0/03oool1o`000040
oooo00000ol00000oooo0?ooo`1R0?ooo`@0ogl00P3oool40?mo0:l0oooo0Ol000010?ooo`0000?o
00000?ooo`3oool0HP3oool40?mo0080oooo103oO`2_0?ooo`7o00000@3oool00003o`00003oool0
oooo06<0oooo0P3oO`040?ooo`80ogl0/03oool1o`000040oooo00000ol00000oooo0?ooo`3o0?oo
oa`0oooo0Ol000010?ooo`0000?o00000?ooo`3oool0o`3ooolL0?ooo`7o00000@3oool00003o`00
003oool0oooo0?l0oooo703oool1o`000040oooo00000ol00000oooo0?ooo`3o0?oooa`0oooo0Ol0
00010?ooo`0000?o00000?ooo`3oool0o`3ooolL0?ooo`7o00000@3oool00003o`00003oool0oooo
0?l0oooo703oool1o`000040oooo00000ol00000oooo0?ooo`3o0?oooa`0oooo0Ol000010?ooo`00
00?o00000?ooo`3oool0o`3ooolL0?ooo`7o00000@3oool00003o`00003oool0oooo0?l0oooo703o
ool1o`000040oooo00000ol00000oooo0?ooo`3o0?oooa`0oooo0Ol000010?ooo`0000?o00000?oo
o`3oool0o`3ooolL0?ooo`7o00000@3oool00003o`00003oool0oooo0?l0oooo703oool1o`000040
oooo00000ol00000oooo0?ooo`3o0?oooa`0oooo0Ol000010?ooo`0000?o00000?ooo`3oool0o`3o
oolL0?ooo`7o00000@3oool00003o`00003oool0oooo0?l0oooo703oool1o`000040oooo00000ol0
0000oooo0?ooo`3o0?oooa`0oooo0Ol000010?ooo`0000?o00000?ooo`3oool0o`3ooolL0?ooo`7o
00000@3oool00003o`00003oool0oooo0?l0oooo703oool1o`000040oooo00000ol00000oooo0?oo
o`3o0?oooa`0oooo0Ol000010?ooo`0000?o00000?ooo`3oool0o`3ooolL0?ooo`7o00000@3oool0
0003o`00003oool0oooo0?l0oooo703oool1o`000040oooo00000ol00000oooo0?ooo`3o0?oooa`0
oooo0Ol000010?ooo`0000?o00000?ooo`3oool0o`3ooolL0?ooo`7o00000@3oool00003o`00003o
ool0oooo0?l0oooo703oool1o`000040oooo00000ol00000oooo0?ooo`3o0?oooa`0oooo0Ol00001
0?ooo`0000?o00000?ooo`3oool0o`3ooolL0?ooo`7o00000@3oool00003o`00003oool0oooo0?l0
oooo703oool1o`000040oooo00000ol00000oooo0?ooo`3o0?oooa`0oooo0Ol000010?ooo`0000?o
00000?ooo`3oool0o`3ooolL0?ooo`7o00000@3oool00003o`00003oool0oooo0?l0oooo703oool1
o`000040oooo00000ol00000oooo0?ooo`3o0?oooa`0oooo0Ol000010?ooo`0000?o00000?ooo`3o
ool0o`3ooolL0?ooo`7o00000@3oool00003o`00003oool0oooo0?l0oooo703oool1o`000040oooo
00000ol00000oooo0?ooo`3o0?ooo`@0oooo0P3oO`0F0?ooo`7o00000@3oool00003o`00003oool0
oooo0?l0oooo0`3oool40?mo01D0oooo0Ol000010?ooo`0000?o00000?ooo`3oool0o`3oool30?oo
o`@0ogl05@3oool1o`000040oooo00000ol00000oooo0?ooo`3o0?ooo`@0oooo0P3oO`0F0?ooo`7o
00000@3oool00003o`00003oool0oooo0?l0oooo703oool1o`000040oooo00000ol00000oooo0?oo
o`3o0?oooa`0oooo0Ol000010?ooo`0000?o00000?ooo`3oool0o`3ooolL0?ooo`7o00000@3oool0
0003o`00003oool0oooo0?l0oooo703oool1o`000040oooo00000ol00000oooo0?ooo`3o0?oooa`0
oooo0Ol000010?ooo`0000?o00000?ooo`3oool0o`3ooolL0?ooo`7o00000@3oool00003o`00003o
ool0oooo0?l0oooo703oool1o`000040oooo00000ol00000oooo0?ooo`3o0?oooa`0oooo0Ol00001
0?ooo`0000?o00000?ooo`3oool0o`3ooolL0?ooo`7o00000@3oool00003o`00003oool0oooo0?l0
oooo703oool1o`000040oooo00000ol00000oooo0?ooo`2e0?ooo`80ogl0I03oool1o`000040oooo
00000ol00000oooo0?ooo`2d0?ooo`@0ogl0H`3oool1o`000040oooo00000ol00000oooo0?ooo`2d
0?ooo`@0ogl0H`3oool1o`000040oooo00000ol00000oooo0?ooo`2e0?ooo`80ogl0=@3oool20?mo
02d0oooo0Ol000010?ooo`0000?o00000?ooo`3oool0i03oool20?mo00D0oooo103oO`0/0?ooo`7o
00000@3oool00003o`00003oool0oooo0><0oooo103oO`040?ooo`@0ogl0;03oool1o`000040oooo
00000ol00000oooo0?ooo`330?ooo`80ogl07P3oool40?mo00D0oooo0P3oO`0]0?ooo`7o00000@3o
ool00003o`00003oool0oooo0<80oooo103oO`0;o`00oa<0oooo0P3oO`0e0?ooo`7o00000@3oool0
0003o`00003oool0oooo0<80oooo1?l00?l;0?ooo`;o003oB03oool1o`000040oooo00000ol00000
oooo0?ooo`2n0?ooo`Co003o00<0oooo0?mo003oO`003P3oool2o`00odH0oooo0Ol000010?ooo`00
00?o00000?ooo`3oool0^@3oool20?mo00?o003o5`3oool2o`00o`T0oooo0P3oO`0i0?ooo`7o0000
0@3oool00003o`00003oool0oooo0;L0oooo1?l00?l00`3oO`00oooo0?ooo`0I0?ooo`;o003o1P3o
ool40?mo03P0oooo0Ol000010?ooo`0000?o00000?ooo`3oool0]03oool3o`00o`030?ooo`3oO`00
ogl00080ogl0703oool00ol00?l0oooo0?ooo`040?ooo`@0ogl00`3oool20?mo03<0oooo0Ol00001
0?ooo`0000?o00000?ooo`3oool0/P3oool2o`00o`<0ogl00P3oool20?mo01<0oooo0P3oO`080?oo
o`03o`00o`3oool0oooo00D0oooo0P3oO`030?ooo`@0ogl0<P3oool1o`000040oooo00000ol00000
oooo0?ooo`2`0?ooo`;o003o00<0oooo0?mo003oO`000P3oO`060?ooo`80ogl03P3oool40?mo00L0
oooo00?o003o0?ooo`3oool02P3oool40?mo0380oooo0Ol000010?ooo`0000?o00000?ooo`3oool0
[P3oool2o`00o`@0oooo0P3oO`060?ooo`@0ogl03@3oool40?mo00L0oooo00?o003o0?ooo`3oool0
2`3oool20?mo03<0oooo0Ol000010?ooo`0000?o00000?ooo`3oool0R`3oool20?mo0200oooo00?o
003o0?ooo`3oool0103oool20?mo00H0oooo103oO`0>0?ooo`80ogl02@3oool00ol00?l0oooo0?oo
o`0o0?ooo`7o00000@3oool00003o`00003oool0oooo08X0oooo103oO`0M0?ooo`;o003o1P3oool4
0?mo00H0oooo0P3oO`0J0?ooo`03o`00o`3oool0oooo03l0oooo0Ol000010?ooo`0000?o00000?oo
o`3oool0RP3oool40?mo01`0oooo00?o003o0?ooo`3oool01P3oool40?mo0280oooo00?o003o0?oo
o`3oool0?`3oool1o`000040oooo00000ol00000oooo0?ooo`2;0?ooo`80ogl06`3oool2o`00o`X0
oooo0P3oO`0S0?ooo`03o`00o`3oool0oooo03l0oooo0Ol000010?ooo`0000?o00000?ooo`3oool0
UP3oool20?mo00h0oooo0_l00?lZ0?ooo`80ogl01@3oool00ol00?l0oooo0?ooo`0o0?ooo`7o0000
0@3oool00003o`00003oool0oooo09D0oooo103oO`0<0?ooo`04o`00o`3oool0ogl00?mo02P0oooo
103oO`030?ooo`03o`00o`3oool0oooo0400oooo0Ol000010?ooo`0000?o00000?ooo`3oool0U@3o
ool40?mo00X0oooo0_l00?l00`3oool0ogl00?mo00020?mo02L0oooo103oO`030?ooo`03o`00o`3o
ool0oooo0400oooo0Ol000010?ooo`0000?o00000?ooo`3oool0UP3oool20?mo00X0oooo00Co003o
0?ooo`3oool0oooo103oO`0X0?ooo`80ogl0103oool00ol00?l0oooo0?ooo`100?ooo`7o00000@3o
ool00003o`00003oool0oooo0:40oooo00?o003o0?ooo`3oool00`3oool20?mo02h0oooo00?o003o
0?ooo`3oool0@@3oool1o`000040oooo00000ol00000oooo0?ooo`2P0?ooo`03o`00o`3oool0oooo
0180oooo1@3o0?lL0?ooo`03o`00o`3oool0oooo0180oooo0P3oO`0^0?ooo`7o00000@3oool00003
o`00003oool0oooo09h0oooo0_l00?lD0?ooo`L0o`3o6P3oool00ol00?l0oooo0?ooo`0B0?ooo`@0
ogl0;@3oool1o`000040oooo00000ol00000oooo0?ooo`2M0?ooo`03o`00o`3oool0oooo01<0oooo
2@3o0?lI0?ooo`03o`00o`3oO`00ogl00180oooo103oO`0]0?ooo`7o00000@3oool00003o`00003o
ool0oooo09`0oooo00?o003o0?ooo`3oool04`3oool;0?l0oaL0oooo00?o003o0?mo003oO`000P3o
O`0B0?ooo`80ogl0;P3oool1o`000040oooo00000ol00000oooo0?ooo`2K0?ooo`03o`00o`3oool0
oooo01@0oooo2`3o0?lF0?ooo`03o`00o`3oool0ogl000<0ogl0@P3oool1o`000040oooo00000ol0
0000oooo0?ooo`2K0?ooo`03o`00o`3oool0oooo01@0oooo2`3o0?lE0?ooo`04o`00o`3oool0oooo
0?ooo`80ogl0@`3oool1o`000040oooo00000ol00000oooo0?ooo`2J0?ooo`03o`00o`3oool0oooo
01D0oooo2`3o0?lD0?ooo`03o`00o`3oool0oooo04L0oooo0Ol000010?ooo`0000?o00000?ooo`3o
ool0V@3oool00ol00?l0oooo0?ooo`0<0?ooo`80ogl0203oool;0?l0oa<0oooo00?o003o0?ooo`3o
ool00P3oO`160?ooo`7o00000@3oool00003o`00003oool0oooo09T0oooo00?o003o0?ooo`3oool0
2P3oool50?mo00L0oooo00<0ogl00?l0o`3o0?l01`3o0?lA0?ooo`80ogl000?o003o0?ooo`3oool0
103oO`150?ooo`7o00000@3oool00003o`00003oool0oooo09P0oooo00?o003o0?ooo`3oool02P3o
ool60?mo00P0oooo00<0ogl00?l0o`3o0?l01@3o0?lA0?ooo`80ogl00_l00?l20?ooo`@0ogl0A@3o
ool1o`000040oooo00000ol00000oooo0?ooo`2H0?ooo`03o`00o`3oool0oooo00X0oooo1@3oO`0;
0?ooo`D0o`3o4P3oool0103oO`3o003o0?mo003oO`030?ooo`80ogl0AP3oool1o`000040oooo0000
0ol00000oooo0?ooo`1f0?ooo`80ogl07`3oool00ol00?l0oooo0?ooo`0<0?ooo`80ogl0903oool0
0ol00?l0ogl00?mo001<0?ooo`7o00000@3oool00003o`00003oool0oooo07D0oooo103oO`0N0?oo
o`03o`00o`3oool0oooo0340oooo00?o003o0?ooo`3oool0C@3oool1o`000040oooo00000ol00000
oooo0?ooo`1e0?ooo`@0ogl02P3oool20?mo0140oooo00?o003o0?ooo`3oool0<@3oool00ol00?l0
oooo0?ooo`1>0?ooo`7o00000@3oool00003o`00003oool0oooo07H0oooo0P3oO`0:0?ooo`@0ogl0
3`3oool00ol00?l0oooo0?ooo`0H0?ooo`80ogl05`3oool00ol00?l0oooo0?ooo`1?0?ooo`7o0000
0@3oool00003o`00003oool0oooo0880oooo103oO`0?0?ooo`03o`00o`3oool0oooo01L0oooo103o
O`0D0?ooo`;o003oDP3oool1o`000040oooo00000ol00000oooo0?ooo`230?ooo`80ogl03`3oool0
0ol00?l0oooo0?ooo`0B0?ooo`80ogl0103oool40?mo0140oooo0ol00?mD0?ooo`7o00000@3oool0
0003o`00003oool0oooo09@0oooo00?o003o0?ooo`3oool04@3oool40?mo00@0oooo0P3oO`0@0?oo
o`;o003oE`3oool1o`000040oooo00000ol00000oooo0?ooo`2D0?ooo`03o`00o`3oool0oooo0140
oooo103oO`0E0?ooo`03o`00o`3oool0oooo05L0oooo0Ol000010?ooo`0000?o00000?ooo`3oool0
U03oool00ol00?l0oooo0?ooo`0B0?ooo`80ogl0503oool2o`00oeX0oooo0Ol000010?ooo`0000?o
00000?ooo`3oool0U03oool00ol00?l0oooo0?ooo`0V0?ooo`;o003oG03oool1o`000040oooo0000
0ol00000oooo0?ooo`2E0?ooo`03o`00o`3oool0oooo02@0oooo00?o003o0?ooo`3oool0G03oool1
o`000040oooo00000ol00000oooo0?ooo`2E0?ooo`03o`00o`3oool0oooo0280oooo0_l00?mO0?oo
o`7o00000@3oool00003o`00003oool0oooo09D0oooo00?o003o0?ooo`3oool0803oool2o`00of40
oooo0Ol000010?ooo`0000?o00000?ooo`3oool0Q03oool20?mo00l0oooo0_l00?lO0?ooo`;o003o
H`3oool1o`000040oooo00000ol00000oooo0?ooo`230?ooo`@0ogl0403oool2o`00oaX0oooo0ol0
0?mU0?ooo`7o00000@3oool00003o`00003oool0oooo08<0oooo103oO`0B0?ooo`;o003o503oool4
o`00ofP0oooo0Ol000010?ooo`0000?o00000?ooo`3oool0Q03oool20?mo01D0oooo0ol00?l>0?oo
o`?o003o0`3oool20?mo06L0oooo0Ol000010?ooo`0000?o00000?ooo`3oool0WP3oool3o`00o`D0
oooo1_l00?l50?ooo`@0ogl0IP3oool1o`000040oooo00000ol00000oooo0?ooo`2Q0?ooo`Go003o
2`3oool40?mo06H0oooo0Ol000010?ooo`0000?o00000?ooo`3oool0/P3oool20?mo06L0oooo0Ol0
00010?ooo`0000?o00000?ooo`3oool0o`3ooolL0?ooo`7o00000@3oool00003o`00003oool0oooo
0?l0oooo703oool1o`000040oooo00000ol00000oooo0?ooo`1k0?ooo`80ogl0WP3oool1o`000040
oooo00000ol00000oooo0?ooo`1j0?ooo`@0ogl0W@3oool1o`000040oooo00000ol00000oooo0?oo
o`1j0?ooo`@0ogl0803oool20?mo07/0oooo0Ol000010?ooo`0000?o00000?ooo`3oool0N`3oool2
0?mo0200oooo103oO`1j0?ooo`7o00000@3oool00003o`00003oool0oooo09d0oooo103oO`1j0?oo
o`7o00000@3oool00003o`00003oool0oooo0900oooo0P3oO`0<0?ooo`80ogl0N`3oool1o`000040
oooo00000ol00000oooo0?ooo`2?0?ooo`@0ogl0R03oool1o`000040oooo00000ol00000oooo0?oo
o`2?0?ooo`@0ogl0R03oool1o`000040oooo00000ol00000oooo0?ooo`2@0?ooo`80ogl08`3oool2
0?mo06@0oooo0Ol000010?ooo`0000?o00000?ooo`3oool0]03oool40?mo06<0oooo0Ol000010?oo
o`0000?o00000?ooo`3oool0]03oool40?mo06<0oooo0Ol000010?ooo`0000?o00000?ooo`3oool0
]@3oool20?mo06@0oooo0Ol000010?ooo`0000?o00000?ooo`3oool0o`3ooolL0?ooo`7o00000@3o
ool00003o`00003oool0oooo0?l0oooo703oool1o`000040oooo00000ol00000oooo0?ooo`3o0?oo
oa`0oooo0Ol000010?ooo`0000?o00000?ooo`3oool0o`3ooolL0?ooo`7o00000@3oool00003o`00
003oool0oooo0?l0oooo703oool1o`000040oooo00000ol00000oooo0?ooo`3o0?oooa`0oooo0Ol0
00010?ooo`0000?o00000?ooo`3oool0o`3ooolL0?ooo`7o00000@3oool00003o`00003oool0oooo
0?l0oooo703oool1o`000040oooo00000ol00000oooo0?ooo`3o0?oooa`0oooo0Ol000010?ooo`00
00?o00000?ooo`3oool0o`3ooolL0?ooo`7o00000@3oool00003o`00003oool0oooo0?l0oooo703o
ool1o`000040oooo00000ol00000oooo0?ooo`3o0?oooa`0oooo0Ol000010?ooo`0000?o00000?oo
o`3oool0o`3ooolL0?ooo`7o00000@3oool00003o`00003oool0oooo0?l0oooo703oool1o`000040
oooo00000ol00000oooo0?ooo`3o0?oooa`0oooo0Ol000010?ooo`0000?o00000?ooo`3oool0o`3o
oolL0?ooo`7o00000@3oool00003o`00003oool0oooo0?l0oooo703oool1o`000040oooo00000ol0
0000oooo0?ooo`3o0?oooa`0oooo0Ol000010?ooo`0000?o00000?ooo`3oool0o`3ooolL0?ooo`7o
00000@3oool00003o`00003oool0oooo0?l0oooo703oool1o`000040oooo00000ol00000oooo0?oo
o`3o0?oooa`0oooo0Ol000010?ooo`0000?o00000?ooo`3oool0o`3ooolL0?ooo`7o00000@3oool0
0003o`00003oool0oooo0?l0oooo703oool1o`000040oooo00000ol00000oooo0?ooo`3o0?oooa`0
oooo0Ol000010?ooo`0000?o00000?ooo`3oool0o`3ooolL0?ooo`7o00000@3oool00003o`00003o
ool0oooo0?l0oooo703oool1o`000040oooo00000ol00000oooo0?ooo`3o0?oooa`0oooo0Ol00001
0?ooo`0000?o00000?ooo`3oool0o`3ooolL0?ooo`7o00000@3oool00003o`00003oool0oooo0?l0
oooo703oool1o`000040oooo00000ol00000oooo0?ooo`3o0?oooa`0oooo0Ol000010?ooo`0000?o
00000?ooo`3oool0o`3ooolL0?ooo`7o00000@3oool00003o`00003oool0oooo0?l0oooo703oool1
o`000040oooo00000ol00000oooo0?ooo`3o0?oooa`0oooo0Ol000010?ooo`0000?o00000?ooo`3o
ool0o`3ooolL0?ooo`7o00000@3oool00003o`00003oool0oooo0?l0oooo703oool1o`000040oooo
00000ol00000oooo0?ooo`3o0?oooa`0oooo0Ol000010?ooo`0000?o00000?ooo`3oool0o`3ooolL
0?ooo`7o00000@3oool00003o`00003oool0oooo08h0oooo0P3oO`2;0?ooo`7o00000@3oool00003
o`00003oool0oooo08d0oooo103oO`2:0?ooo`7o00000@3oool00003o`00003oool0oooo08d0oooo
103oO`2:0?ooo`7o00000@3oool00003o`00003oool0oooo08h0oooo0P3oO`2;0?ooo`7o00000@3o
ool00003o`00003oool0oooo0?l0oooo703oool1o`000040oooo00000ol00000oooo0?ooo`3o0?oo
oa`0oooo0Ol000010?ooo`0000?o00000?ooo`3oool0o`3ooolL0?ooo`7o00000@3oool00003o`00
003oool0oooo0?l0oooo703oool1o`000040oooo00000ol00000oooo0?ooo`3o0?oooa`0oooo0Ol0
00010?ooo`0000?o00000?ooo`3oool0o`3ooolL0?ooo`7o00000@3oool00003o`00003oool0oooo
0?l0oooo703oool1o`000040oooo00000ol00000oooo0?ooo`3o0?oooa`0oooo0Ol000010?ooo`00
00?o00000?ooo`3oool0o`3ooolL0?ooo`7o00000@3oool00003o`00003oool0oooo0?l0oooo703o
ool1o`000040oooo00000ol00000oooo0?ooo`3o0?oooa`0oooo0Ol000010?ooo`0000?o00000?oo
o`3oool0o`3ooolL0?ooo`7o00000@3oool00003o`00003oool0oooo0?l0oooo703oool1o`000040
oooo00000ol00000oooo0?ooo`3o0?oooa`0oooo0Ol000010?ooo`0000?o00000?ooo`3oool0o`3o
oolL0?ooo`7o00000@3oool00003o`00003oool0oooo0?l0oooo703oool1o`000040oooo00000ol0
0000oooo0?ooo`3o0?oooa`0oooo0Ol000010?ooo`0000?o00000?ooo`3oool0o`3ooolL0?ooo`7o
00000@3oool00003o`00003oool0oooo0?l0oooo703oool1o`000040oooo00000ol00000oooo0?oo
o`3o0?oooa`0oooo0Ol000010?ooo`0000?o00000?ooo`3oool0o`3ooolL0?ooo`7o00000@3oool0
0?oo00008?l000010?ooo`00\
\>"],
  ImageRangeCache->{{{0, 287}, {287, 0}} -> {-1.01089, -1.01089, 0.00704453, \
0.00704453}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.49505 0.5 0.49505 [
[ 0 0 -0.125 0 ]
[ 0 0 -0.125 0 ]
[ 0 1 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
0 0 m
1 0 L
s
0 0 m
0 1 L
s
0 1 m
1 1 L
s
1 0 m
1 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
1 .5 0 r
.015 w
.03175 .1355 Mdot
.03435 .12523 Mdot
.11137 .12765 Mdot
.14107 .18841 Mdot
.16218 .24538 Mdot
.17294 .21053 Mdot
.18267 .18577 Mdot
.18434 .1304 Mdot
.18553 .30956 Mdot
.20401 .239 Mdot
.21247 .27571 Mdot
.21687 .20845 Mdot
.22376 .2799 Mdot
.22832 .27485 Mdot
.29063 .20974 Mdot
.29686 .25079 Mdot
.30487 .22936 Mdot
.30683 .34623 Mdot
.32055 .20902 Mdot
.32574 .21979 Mdot
.34472 .28521 Mdot
.35998 .36393 Mdot
.36335 .24976 Mdot
.3794 .36608 Mdot
.42386 .66992 Mdot
.44391 .74519 Mdot
.45059 .34198 Mdot
.47208 .67586 Mdot
.47436 .71381 Mdot
.49778 .59825 Mdot
.50874 .91643 Mdot
.51516 .76219 Mdot
.53655 .61374 Mdot
.56563 .75219 Mdot
.59189 .65665 Mdot
.59581 .61604 Mdot
.59923 .6556 Mdot
.60292 .68499 Mdot
.62656 .67779 Mdot
.63555 .72451 Mdot
.63919 .652 Mdot
.64169 .6004 Mdot
.64246 .58611 Mdot
.64496 .54267 Mdot
.64608 .77288 Mdot
.65077 .64308 Mdot
.66065 .57816 Mdot
.67474 .59169 Mdot
.69296 .563 Mdot
.72815 .65902 Mdot
.73169 .58879 Mdot
.74669 .61318 Mdot
.74821 .65474 Mdot
.75963 .63781 Mdot
.79673 .57809 Mdot
.80925 .55852 Mdot
.81525 .58444 Mdot
.83417 .62985 Mdot
.83598 .55526 Mdot
.91595 .49319 Mdot
1 0 0 r
.005 w
.16128 .17044 m
.18734 .17269 L
.21339 .17909 L
.2345 .18734 L
.23945 .19126 L
.2655 .20415 L
.27874 .21339 L
.29156 .22295 L
.31204 .23945 L
.31761 .24532 L
.33549 .2655 L
.34367 .28341 L
.34499 .29156 L
.34367 .29798 L
.31761 .3104 L
.29156 .30711 L
.2655 .30014 L
.24507 .29156 L
.23945 .28747 L
.21339 .27402 L
.20155 .2655 L
.18734 .25472 L
.16884 .23945 L
.16128 .2313 L
.14618 .21339 L
.13806 .18734 L
.16128 .17044 L
s
0 0 1 r
.65633 .57701 m
.68239 .56842 L
.70844 .56313 L
.7345 .56168 L
.76055 .5752 L
.76359 .57817 L
.76859 .60422 L
.76055 .62333 L
.75627 .63028 L
.7345 .65485 L
.73298 .65633 L
.70844 .6775 L
.69922 .68239 L
.68239 .69294 L
.65633 .70579 L
.64983 .70844 L
.63028 .71539 L
.60422 .72268 L
.57817 .72651 L
.55211 .7214 L
.53145 .70844 L
.52926 .68239 L
.54239 .65633 L
.55211 .63983 L
.56625 .63028 L
.57817 .6193 L
.60119 .60422 L
.60422 .60227 L
.63028 .58726 L
.65315 .57817 L
.65633 .57701 L
s
1 0 0 r
.03 w
.24141 .24033 Mdot
0 0 1 r
.64872 .64417 Mdot
1 0 0 r
.79703 .00495 m
.79703 .00495 L
.87129 .00495 L
.87129 .00495 L
F
0 0 1 r
.89604 .00495 m
.89604 .25247 L
.9703 .25247 L
.9703 .00495 L
F
1 0 1 r
.04 w
.66065 .57816 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P000182000`400?l00000o`00003ooooooolQ
ooooo`00o`00000P0000007ooooo00000`00003oooooooooo`3ooooooacooooo0@000001ooooo`00
00<00000ooooooooool0o_oooolE0000o`Sooooo0@000001ooooo`0000<00000ooooooooool0o_oo
oolE0000o`Sooooo0@000001ooooo`0000<00000ooooooooool0o_oooolE0000o`Sooooo0@000001
ooooo`0000<00000ooooooooool0o_oooolE0000o`Sooooo0@000001ooooo`0000<00000oooooooo
ool0o_oooolE0000o`Sooooo0@000001ooooo`0000<00000ooooooooool0o_oooolE0000o`Sooooo
0@000001ooooo`0000<00000ooooooooool0o_oooolE0000o`Sooooo0@000001ooooo`0000<00000
ooooooooool0o_oooolE0000o`Sooooo0@000001ooooo`0000<00000ooooooooool0o_oooolE0000
o`Sooooo0@000001ooooo`0000<00000ooooooooool0o_oooolE0000o`Sooooo0@000001ooooo`00
00<00000ooooooooool0o_oooolE0000o`Sooooo0@000001ooooo`0000<00000ooooooooool0o_oo
oolE0000o`Sooooo0@000001ooooo`0000<00000ooooooooool0o_oooolE0000o`Sooooo0@000001
ooooo`0000<00000ooooooooool0o_oooolE0000o`Sooooo0@000001ooooo`0000<00000oooooooo
ool0o_oooolE0000o`Sooooo0@000001ooooo`0000<00000ooooooooool0o_oooolE0000o`Sooooo
0@000001ooooo`0000<00000ooooooooool0o_oooolE0000o`Sooooo0@000001ooooo`0000<00000
ooooooooool0o_oooolE0000o`Sooooo0@000001ooooo`0000<00000ooooooooool0o_oooolE0000
o`Sooooo0@000001ooooo`0000<00000ooooooooool0o_oooolE0000o`Sooooo0@000001ooooo`00
00<00000ooooooooool0o_oooolE0000o`Sooooo0@000001ooooo`0000<00000ooooooooool0o_oo
oolE0000o`Sooooo0@000001ooooo`0000<00000ooooooooool0o_oooolE0000o`Sooooo0@000001
ooooo`0000<00000ooooooooool0o_oooolE0000o`Sooooo0@000001ooooo`0000<00000oooooooo
ool0o_oooolE0000o`Sooooo0@000001ooooo`0000<00000ooooooooool0o_oooolE0000o`Sooooo
0@000001ooooo`0000<00000ooooooooool0o_oooolE0000o`Sooooo0@000001ooooo`0000<00000
ooooooooool0o_oooolE0000o`Sooooo0@000001ooooo`0000<00000ooooooooool0o_oooolE0000
o`Sooooo0@000001ooooo`0000<00000ooooooooool0o_oooolE0000o`Sooooo0@000001ooooo`00
00<00000ooooooooool0o_oooolE0000o`Sooooo0@000001ooooo`0000<00000ooooooooool0o_oo
oolE0000o`Sooooo0@000001ooooo`0000<00000ooooooooool01_ooool2oomo0?Kooooo5@000?l8
ooooo`4000000Oooool0000300000?oooooooooo00Gooooo1?ooO`0Cooooo`;oogl0h?oooolE0000
o`Sooooo0@000001ooooo`0000<00000ooooooooool01Oooool4oomo01;ooooo1?ooO`0Booooo`;o
ogl0booooolE0000o`Sooooo0@000001ooooo`0000<00000ooooooooool01Oooool3oomo01?ooooo
1?ooO`0Aooooo`Coogl0b_oooolE0000o`Sooooo0@000001ooooo`0000<00000ooooooooool01?oo
ool4oomo01Cooooo0_ooO`0Booooo`Coogl0b_oooolE0000o`Sooooo0@000001ooooo`0000<00000
ooooooooool01?ooool4oomo02Wooooo0_ooO`3;oooooaD0003o2?ooool10000007ooooo00000`00
003oooooooooo`05ooooo`;oogl0mooooolE0000o`Sooooo0@000001ooooo`0000<00000oooooooo
ool0o_oooolE0000o`Sooooo0@000001ooooo`0000<00000ooooooooool0o_oooolE0000o`Sooooo
0@000001ooooo`0000<00000ooooooooool0o_oooolE0000o`Sooooo0@000001ooooo`0000<00000
ooooooooool0o_oooolE0000o`Sooooo0@000001ooooo`0000<00000ooooooooool0o_oooolE0000
o`Sooooo0@000001ooooo`0000<00000ooooooooool0o_oooolE0000o`Sooooo0@000001ooooo`00
00<00000ooooooooool0o_oooolE0000o`Sooooo0@000001ooooo`0000<00000ooooooooool0:_oo
ool60?l00<kooooo5@000?l8ooooo`4000000Oooool0000300000?oooooooooo02Wooooo00<0o`00
ooooooooool01?ooool50?l00<Wooooo5@000?l8ooooo`4000000Oooool0000300000?oooooooooo
02Oooooo0P3o000<ooooo`@0o`00aOoooolE0000o`Sooooo0@000001ooooo`0000<00000oooooooo
ool09_ooool00`3o003oooooooooo`0@ooooo`@0o`00`OoooolE0000o`Sooooo0@000001ooooo`00
00<00000ooooooooool09?ooool00oooO`00o`00ooooo`09ooooo`;oogl02oooool30?l00;kooooo
5@000?l8ooooo`4000000Oooool0000300000?oooooooooo02?ooooo00Coogl00?l00?ooO`3oogl0
2?ooool4oomo00gooooo00?oo`00ooooooooool0^ooooolE0000o`Sooooo0@000001ooooo`0000<0
0000ooooooooool08oooool01?ooO`00o`00oomo0?ooO`08ooooo`Coogl03_ooool20?l00;_ooooo
5@000?l8ooooo`4000000Oooool0000300000?oooooooooo02Cooooo00?oogl00?l00?ooool02Ooo
ool2oomo017ooooo0P3o002ioooooaD0003o2?ooool10000007ooooo00000`00003oooooooooo`0U
ooooo`030?l00?oooooooooo01gooooo0P3o002goooooaD0003o2?ooool10000007ooooo00000`00
003oooooooooo`0Uooooo`030?l00?oooooooooo01oooooo0P3o002eoooooaD0003o2?ooool10000
007ooooo00000`00003oooooooooo`0Vooooo`030?l00?oooooooooo017ooooo0_ooO`0=ooooo`80
o`001?ooool2oomo00Oooooo0_ooO`2ToooooaD0003o2?ooool10000007ooooo00000`00003ooooo
ooooo`0Vooooo`030?l00?oooooooooo00Gooooo0_ooO`09ooooo`Coogl03_ooool00`3o003ooooo
ooooo`04oomo00Gooooo1?ooO`2SoooooaD0003o2?ooool10000007ooooo00000`00003ooooooooo
o`0Vooooo`030?l00?oooooooooo00Cooooo1?ooO`08ooooo`Coogl03oooool00`3o003ooooooomo
0003oomo00Gooooo1?ooO`2SoooooaD0003o2?ooool10000007ooooo00000`00003oooooooooo`0W
ooooo`030?l00?oooooooooo00?ooooo1?ooO`09ooooo`;oogl04Oooool0103o003ooooooomo0?oo
O`07ooooo`?oogl0XooooolE0000o`Sooooo0@000001ooooo`0000<00000ooooooooool09oooool0
0`3o003oooooooooo`04ooooo`;oogl07_ooool00`3o003oooooooooo`07ooooo`Coogl0X_oooolE
0000o`Sooooo0@000001ooooo`0000<00000ooooooooool0:?ooool00`3o003oooooooooo`0Toooo
o`030?l00?oooooooooo00Kooooo1?ooO`2RoooooaD0003o2?ooool10000007ooooo00000`00003o
ooooooooo`0Yooooo`030?l00?oooooooooo02Cooooo0P3o00000oooooooogl0oomo0004ooooo`;o
ogl0XooooolE0000o`Sooooo0@000001ooooo`0000<00000ooooooooool0:_ooool00`3o003ooooo
ooooo`0Cooooo`Coo`003_ooool0103o003oogl0oomo0?ooO`2XoooooaD0003o2?ooool10000007o
oooo00000`00003oooooooooo`0[ooooo`030?l00?oooooooooo017ooooo1_oo000=ooooo`04oomo
003o0000o`00oomo0:Sooooo5@000?l8ooooo`4000000Oooool0000300000?oooooooooo02cooooo
00<0o`00ooooooooool02?ooool2oomo00Gooooo2?oo000=ooooo`;oogl000<0o`00ooooooooool0
Y_oooolE0000o`Sooooo0@000001ooooo`0000<00000ooooooooool0;Oooool00`3o003ooooooooo
o`06ooooo`Coogl01?ooool8ool0013ooooo00<0o`00ooooooooool0YOoooolE0000o`Sooooo0@00
0001ooooo`0000<00000ooooooooool0:oooool2oomo0003ooooo`3o003ooooo00Kooooo1?ooO`04
ooooo`Soo`004Oooool00`3o003oooooooooo`2ToooooaD0003o2?ooool10000007ooooo00000`00
003oooooooooo`0Zooooo`Coogl000?ooooo0?l00?ooool01_ooool2oomo00Gooooo2?oo000;oooo
o`;oogl01Oooool00`3o003oooooooooo`09ooooo`;oogl0V?oooolE0000o`Sooooo0@000001oooo
o`0000<00000ooooooooool0:_ooool4oomo00;ooooo00<0o`00ooooooooool03?ooool6ool000_o
oooo1?ooO`04ooooo`030?l00?oooooooooo00Sooooo1?ooO`2GoooooaD0003o2?ooool10000007o
oooo00000`00003oooooooooo`0[ooooo`;oogl01?ooool00`3o003oooooooooo`0<ooooo`Coo`00
3?ooool4oomo00Gooooo00<0o`00ooooooooool01oooool4oomo09Oooooo5@000?l8ooooo`400000
0Oooool0000300000?oooooooooo03;ooooo0P3o000Mooooo`;oogl01oooool00`3o003ooooooooo
o`07ooooo`;oogl0]Oooool10000007ooooo00000`00003oooooooooo`0dooooo`030?l00?oooooo
oooo02Cooooo00<0o`00ooooooooool0_Oooool10000007ooooo00000`00003oooooooooo`0eoooo
o`030?l00?oooooooooo02Cooooo00<0o`00ooooooooool0_?ooool10000007ooooo00000`00003o
ooooooooo`0fooooo`80o`009Oooool00`3o003oooooooooo`2kooooo`4000000Oooool000030000
0?oooooooooo03Sooooo0P3o00000oooO`3oooooooooo`02oomo01kooooo00<0o`00ooooooooool0
^oooool10000007ooooo00000`00003oooooooooo`0hooooo`;oogl00P3o0004oomo01kooooo00<0
o`00ooooooooool0^_ooool10000007ooooo00000`00003oooooooooo`0hooooo`Coogl00P3o0002
oomo01kooooo00<0o`00ooooooooool0^_ooool10000007ooooo00000`00003oooooooooo`0ioooo
o`Googl000<0o`00ooooooooool07Oooool00`3o003oogl0oomo002jooooo`4000000Oooool00003
00000?oooooooooo03_ooooo1?ooO`020?l001gooooo00Coogl00?l00?ooO`3oogl0^Oooool10000
007ooooo00000`00003oooooooooo`0looooo`;oogl00oooool20?l001_ooooo00Coogl00?l00?oo
O`3oogl0^Oooool10000007ooooo00000`00003oooooooooo`13ooooo`80o`006_ooool00oooO`00
o`00ooooo`2iooooo`4000000Oooool0000300000?oooooooooo04Gooooo0P3o000Iooooo`030?l0
0?oooooooooo0;Sooooo0@000001ooooo`0000<00000ooooooooool0Aoooool20?l001Gooooo0P3o
002kooooo`4000000Oooool0000300000?oooooooooo04Wooooo0`3o000@ooooo`80o`00_Oooool1
0000007ooooo00000`00003oooooooooo`0aooooo`;oogl06Oooool30?l000cooooo00<0o`00oooo
ooooool0_Oooool10000007ooooo00000`00003oooooooooo`0`ooooo`Coogl06oooool60?l000Co
oooo0P3o0030ooooo`4000000Oooool0000300000?oooooooooo033ooooo1?ooO`0Qooooo`@0o`00
`_ooool10000007ooooo00000`00003oooooooooo`0aooooo`;oogl0j?ooool10000007ooooo0000
0`00003oooooooooo`3ooooooacooooo0@000001ooooo`0000<00000ooooooooool0oooooolLoooo
o`4000000Oooool0000300000?oooooooooo0?oooooo7?ooool10000007ooooo00000`00003ooooo
ooooo`3ooooooacooooo0@000001ooooo`0000<00000ooooooooool0oooooolLooooo`4000000Ooo
ool0000300000?oooooooooo07gooooo0_ooO`2Looooo`4000000Oooool0000300000?oooooooooo
07cooooo1?ooO`2Kooooo`4000000Oooool0000300000?oooooooooo05Cooooo0_ooO`0Vooooo`Co
ogl0Voooool10000007ooooo00000`00003oooooooooo`1Cooooo`Coogl09_ooool2oomo09cooooo
0@000001ooooo`0000<00000ooooooooool0Doooool4oomo0<Cooooo0@000001ooooo`0000<00000
ooooooooool0E?ooool2oomo0<Gooooo0@000001ooooo`0000<00000ooooooooool0oooooolLoooo
o`4000000Oooool0000300000?oooooooooo06?ooooo0_ooO`04ooooo`;oogl0/?ooool10000007o
oooo00000`00003oooooooooo`1Rooooo`Coogl00_ooool4oomo0:oooooo0@000001ooooo`0000<0
0000ooooooooool0H_ooool4oomo00;ooooo1?ooO`2_ooooo`4000000Oooool0000300000?oooooo
oooo06?ooooo0_ooO`04ooooo`;oogl0/?ooool10000007ooooo00000`00003oooooooooo`3ooooo
oacooooo0@000001ooooo`0000<00000ooooooooool0oooooolLooooo`4000000Oooool000030000
0?oooooooooo0?oooooo7?ooool10000007ooooo00000`00003oooooooooo`3ooooooacooooo0@00
0001ooooo`0000<00000ooooooooool0oooooolLooooo`4000000Oooool0000300000?oooooooooo
0?oooooo7?ooool10000007ooooo00000`00003oooooooooo`3ooooooacooooo0@000001ooooo`00
00<00000ooooooooool0oooooolLooooo`4000000Oooool0000300000?oooooooooo0?oooooo7?oo
ool10000007ooooo00000`00003oooooooooo`3ooooooacooooo0@000001ooooo`0000<00000oooo
ooooool0oooooolLooooo`4000000Oooool0000300000?oooooooooo0?oooooo7?ooool10000007o
oooo00000`00003oooooooooo`3ooooooacooooo0@000001ooooo`0000<00000ooooooooool0oooo
oolLooooo`4000000Oooool0000300000?oooooooooo0?oooooo7?ooool10000007ooooo00000`00
003oooooooooo`3ooooooacooooo0@000001ooooo`0000<00000ooooooooool0oooooolLooooo`40
00000Oooool0000300000?oooooooooo0?oooooo7?ooool10000007ooooo00000`00003ooooooooo
o`3ooooooacooooo0@000001ooooo`0000<00000ooooooooool0oooooolLooooo`4000000Oooool0
000300000?oooooooooo0?oooooo7?ooool10000007ooooo00000`00003oooooooooo`3ooooooaco
oooo0@000001ooooo`0000<00000ooooooooool0oooooolLooooo`4000000Oooool0000300000?oo
oooooooo0?oooooo7?ooool10000007ooooo00000`00003oooooooooo`3ooooooacooooo0@000001
ooooo`0000<00000ooooooooool0oooooolLooooo`4000000Oooool0000300000?oooooooooo0?oo
oooo7?ooool10000007ooooo00000`00003oooooooooo`3ooooooacooooo0@000001ooooo`0000<0
0000ooooooooool0oooooolLooooo`4000000Oooool0000300000?oooooooooo0?oooooo7?ooool1
0000007ooooo00000`00003oooooooooo`3ooooooacooooo0@000001ooooo`0000<00000oooooooo
ool0oooooolLooooo`4000000Oooool0000300000?oooooooooo0?oooooo7?ooool10000007ooooo
00000`00003oooooooooo`3oooooo`Cooooo0_ooO`0Fooooo`4000000Oooool0000300000?oooooo
oooo0?oooooo0oooool4oomo01Gooooo0@000001ooooo`0000<00000ooooooooool0ooooool3oooo
o`Coogl05Oooool10000007ooooo00000`00003oooooooooo`3oooooo`Cooooo0_ooO`0Fooooo`40
00000Oooool0000300000?oooooooooo0?oooooo7?ooool10000007ooooo00000`00003ooooooooo
o`3ooooooacooooo0@000001ooooo`0000<00000ooooooooool0oooooolLooooo`4000000Oooool0
000300000?oooooooooo0?oooooo7?ooool10000007ooooo00000`00003oooooooooo`3ooooooaco
oooo0@000001ooooo`0000<00000ooooooooool0oooooolLooooo`4000000Oooool0000300000?oo
oooooooo0?oooooo7?ooool10000007ooooo00000`00003oooooooooo`3ooooooacooooo0@000001
ooooo`0000<00000ooooooooool0oooooolLooooo`4000000Oooool0000300000?oooooooooo0?oo
oooo7?ooool10000007ooooo00000`00003oooooooooo`2eooooo`;oogl0I?ooool10000007ooooo
00000`00003oooooooooo`2dooooo`Coogl0Hoooool10000007ooooo00000`00003oooooooooo`2d
ooooo`Coogl0Hoooool10000007ooooo00000`00003oooooooooo`2eooooo`;oogl0=Oooool2oomo
02gooooo0@000001ooooo`0000<00000ooooooooool0i?ooool2oomo00Gooooo1?ooO`0/ooooo`40
00000Oooool0000300000?oooooooooo0>?ooooo1?ooO`04ooooo`Coogl0;?ooool10000007ooooo
00000`00003oooooooooo`33ooooo`;oogl07_ooool4oomo00Gooooo0_ooO`0]ooooo`4000000Ooo
ool0000300000?oooooooooo0;Sooooo1Ooo0?l5ooooo`Coogl02`000?lCooooo`;oogl0=Oooool1
0000007ooooo00000`00003oooooooooo`2gooooo`Ooo`3o1?ooool40000o`_ooooo0P000?m8oooo
o`4000000Oooool0000300000?oooooooooo0;Kooooo2Ooo0?l30000o`03ooooooooO`3oogl000ko
oooo0P000?m6ooooo`4000000Oooool0000300000?oooooooooo0;Gooooo2ooo0?lEooooo`80003o
2Oooool2oomo03Wooooo0@000001ooooo`0000<00000ooooooooool0]Oooool;ool0oaOooooo00?o
003o0000ooooool01Oooool4oomo03Sooooo0@000001ooooo`0000<00000ooooooooool0]?ooool0
0`000?ooo`3oool0o`09ool0oaSooooo00<0003oooooooooool01?ooool4oomo00?ooooo0_ooO`0c
ooooo`4000000Oooool0000300000?oooooooooo0;;ooooo0P000?l00oooO`3oo`3oool0o`09ool0
o`kooooo0_ooO`08ooooo`030000oooooooooooo00Gooooo0_ooO`03ooooo`Coogl0<_ooool10000
007ooooo00000`00003oooooooooo`2`ooooo`80003o00?ooooooomo0?ooO`002ooo0?l=ooooo`Co
ogl01oooool00`000?ooooooooooo`0:ooooo`Coogl0<_ooool10000007ooooo00000`00003ooooo
ooooo`2^ooooo`80003o1?ooool2oomo00Woo`3o00?oogl0ooooooooool02oooool4oomo00Oooooo
00<0003oooooooooool02oooool2oomo03?ooooo0@000001ooooo`0000<00000ooooooooool0Rooo
ool2oomo023ooooo00<0003oooooooooool01?ooool2oomo0003oooooooo0?ooo`3o00Goo`3o0_oo
O`0>ooooo`;oogl02Oooool00`000?ooooooooooo`0oooooo`4000000Oooool0000300000?oooooo
oooo08[ooooo1?ooO`0Mooooo`80003o1_ooool4oomo0003oooooooo0?ooo`3o00?oo`3o0_ooO`0J
ooooo`030000oooooooooooo03oooooo0@000001ooooo`0000<00000ooooooooool0R_ooool4oomo
01cooooo00<0003oooooooooool01_ooool4oomo02;ooooo00<0003oooooooooool0?oooool10000
007ooooo00000`00003oooooooooo`2;ooooo`;oogl06oooool00`000?oo003oooooo`09ooooo`;o
ogl08oooool00`000?ooooooooooo`0oooooo`4000000Oooool0000300000?oooooooooo09Kooooo
0_ooO`0>ooooo`80003o:_ooool2oomo00Gooooo00<0003oooooooooool0?oooool10000007ooooo
00000`00003oooooooooo`2Eooooo`Coogl03?ooool010000?oooooooomo0?ooO`0Xooooo`Coogl0
0oooool00`000?ooooooooooo`10ooooo`4000000Oooool0000300000?oooooooooo09Gooooo1?oo
O`0:ooooo`80003o00?ooooooomo0?ooO`000_ooO`0Wooooo`Coogl00oooool00`000?oooooooooo
o`10ooooo`4000000Oooool0000300000?oooooooooo09Kooooo0_ooO`0:ooooo`040000oooooooo
ooooooooo`Coogl0:?ooool2oomo00Cooooo00<0003oooooooooool0@?ooool10000007ooooo0000
0`00003oooooooooo`2Qooooo`030000oooooooooooo00?ooooo0_ooO`0^ooooo`030000oooooooo
oooo047ooooo0@000001ooooo`0000<00000ooooooooool0X?ooool00`000?ooooooooooo`0coooo
o`030000oooooooooooo01;ooooo0_ooO`0^ooooo`4000000Oooool0000300000?oooooooooo09ko
oooo0P000?leooooo`030000oooooooooooo01;ooooo1?ooO`0]ooooo`4000000Oooool000030000
0?oooooooooo09gooooo00<0003oooooooooool05Oooool4o`00oacooooo00<0003ooomo0?ooO`00
4_ooool4oomo02gooooo0@000001ooooo`0000<00000ooooooooool0W?ooool00`000?oooooooooo
o`0Eooooo`Ko003o6_ooool00`000?ooogl0oomo0002oomo01;ooooo0_ooO`0^ooooo`4000000Ooo
ool0000300000?oooooooooo09_ooooo00<0003oooooooooool05Oooool8o`00oaSooooo00<0003o
ooooooooO`000oooO`12ooooo`4000000Oooool0000300000?oooooooooo09_ooooo00<0003ooooo
ooooool05Oooool8o`00oaOooooo00@0003ooooooooooooooooo0_ooO`13ooooo`4000000Oooool0
000300000?oooooooooo09[ooooo00<0003oooooooooool05_ooool8o`00oaKooooo00<0003ooooo
ooooool0Aoooool10000007ooooo00000`00003oooooooooo`2Iooooo`030000oooooooooooo00co
oooo0_ooO`08ooooo`03oomo0?l00?oo003o00Ko003o5Oooool00`000?ooooooooooo`02oomo04Ko
oooo0@000001ooooo`0000<00000ooooooooool0VOooool00`000?ooooooooooo`0:ooooo`Googl0
1oooool2oomo00Ko003o4oooool2oomo0003o`00oooooooooooo00Coogl0AOooool10000007ooooo
00000`00003oooooooooo`2Hooooo`030000oooooooooooo00[ooooo1_ooO`08ooooo`;oogl01?l0
0?lCooooo`;oogl00P000?l2ooooo`Coogl0AOooool10000007ooooo00000`00003oooooooooo`2H
ooooo`030000oooooooooooo00[ooooo1OooO`0Rooooo`04oomo00000?ooogl0oomo00?ooooo0_oo
O`16ooooo`4000000Oooool0000300000?oooooooooo07Kooooo0_ooO`0Oooooo`030000oooooooo
oooo00cooooo0_ooO`0Tooooo`030000ooooO`3oogl004cooooo0@000001ooooo`0000<00000oooo
ooooool0MOooool4oomo01kooooo00<0003oooooooooool0<Oooool00`000?ooooooooooo`1=oooo
o`4000000Oooool0000300000?oooooooooo07Gooooo1?ooO`0:ooooo`;oogl04Oooool00`000?oo
ooooooooo`0aooooo`030000oooooooooooo04kooooo0@000001ooooo`0000<00000ooooooooool0
M_ooool2oomo00[ooooo1?ooO`0?ooooo`030000oooooooooooo01Sooooo0_ooO`0Gooooo`030000
oooooooooooo04oooooo0@000001ooooo`0000<00000ooooooooool0P_ooool4oomo00oooooo00<0
003oooooooooool05oooool4oomo01Cooooo0P000?mBooooo`4000000Oooool0000300000?oooooo
oooo08?ooooo0_ooO`0?ooooo`030000oooooooooooo01;ooooo0_ooO`04ooooo`Coogl04Oooool3
0000oeCooooo0@000001ooooo`0000<00000ooooooooool0U?ooool00`000?ooooooooooo`0Aoooo
o`Coogl01?ooool2oomo013ooooo0P000?mGooooo`4000000Oooool0000300000?oooooooooo09Co
oooo00<0003oooooooooool04Oooool4oomo01Gooooo00<0003oooooooooool0Eoooool10000007o
oooo00000`00003oooooooooo`2Dooooo`030000oooooooooooo01;ooooo0_ooO`0Dooooo`80003o
F_ooool10000007ooooo00000`00003oooooooooo`2Dooooo`030000oooooooooooo02Kooooo0P00
0?mLooooo`4000000Oooool0000300000?oooooooooo09Gooooo00<0003oooooooooool09?ooool0
0`000?ooooooooooo`1Looooo`4000000Oooool0000300000?oooooooooo09Gooooo00<0003ooooo
ooooool08_ooool20000oeoooooo0@000001ooooo`0000<00000ooooooooool0UOooool00`000?oo
ooooooooo`0Pooooo`80003oHOooool10000007ooooo00000`00003oooooooooo`24ooooo`;oogl0
3oooool20000oaoooooo0P000?mSooooo`4000000Oooool0000300000?oooooooooo08?ooooo1?oo
O`0@ooooo`80003o6_ooool30000ofGooooo0@000001ooooo`0000<00000ooooooooool0Poooool4
oomo01;ooooo0P000?lDooooo`@0003oJ?ooool10000007ooooo00000`00003oooooooooo`24oooo
o`;oogl05Oooool30000o`kooooo0`000?l3ooooo`;oogl0Ioooool10000007ooooo00000`00003o
ooooooooo`2Nooooo`<0003o1Oooool60000o`Gooooo1?ooO`1Vooooo`4000000Oooool000030000
0?oooooooooo0:7ooooo1@000?l;ooooo`Coogl0I_ooool10000007ooooo00000`00003ooooooooo
o`2booooo`;oogl0Ioooool10000007ooooo00000`00003oooooooooo`3ooooooacooooo0@000001
ooooo`0000<00000ooooooooool0oooooolLooooo`4000000Oooool0000300000?oooooooooo07_o
oooo0_ooO`2Nooooo`4000000Oooool0000300000?oooooooooo07[ooooo1?ooO`2Mooooo`400000
0Oooool0000300000?oooooooooo07[ooooo1?ooO`0Pooooo`;oogl0Noooool10000007ooooo0000
0`00003oooooooooo`1kooooo`;oogl08?ooool4oomo07[ooooo0@000001ooooo`0000<00000oooo
ooooool0WOooool4oomo07[ooooo0@000001ooooo`0000<00000ooooooooool0T?ooool2oomo00co
oooo0_ooO`1kooooo`4000000Oooool0000300000?oooooooooo08oooooo1?ooO`28ooooo`400000
0Oooool0000300000?oooooooooo08oooooo1?ooO`28ooooo`4000000Oooool0000300000?oooooo
oooo093ooooo0_ooO`0Sooooo`;oogl0I?ooool10000007ooooo00000`00003oooooooooo`2doooo
o`Coogl0Hoooool10000007ooooo00000`00003oooooooooo`2dooooo`Coogl0Hoooool10000007o
oooo00000`00003oooooooooo`2eooooo`;oogl0I?ooool10000007ooooo00000`00003ooooooooo
o`3ooooooacooooo0@000001ooooo`0000<00000ooooooooool0oooooolLooooo`4000000Oooool0
000300000?oooooooooo0?oooooo7?ooool10000007ooooo00000`00003oooooooooo`3ooooooaco
oooo0@000001ooooo`0000<00000ooooooooool0oooooolLooooo`4000000Oooool0000300000?oo
oooooooo0?oooooo7?ooool10000007ooooo00000`00003oooooooooo`3ooooooacooooo0@000001
ooooo`0000<00000ooooooooool0oooooolLooooo`4000000Oooool0000300000?oooooooooo0?oo
oooo7?ooool10000007ooooo00000`00003oooooooooo`3ooooooacooooo0@000001ooooo`0000<0
0000ooooooooool0oooooolLooooo`4000000Oooool0000300000?oooooooooo0?oooooo7?ooool1
0000007ooooo00000`00003oooooooooo`3ooooooacooooo0@000001ooooo`0000<00000oooooooo
ool0oooooolLooooo`4000000Oooool0000300000?oooooooooo0?oooooo7?ooool10000007ooooo
00000`00003oooooooooo`3ooooooacooooo0@000001ooooo`0000<00000ooooooooool0oooooolL
ooooo`4000000Oooool0000300000?oooooooooo0?oooooo7?ooool10000007ooooo00000`00003o
ooooooooo`3ooooooacooooo0@000001ooooo`0000<00000ooooooooool0oooooolLooooo`400000
0Oooool0000300000?oooooooooo0?oooooo7?ooool10000007ooooo00000`00003oooooooooo`3o
oooooacooooo0@000001ooooo`0000<00000ooooooooool0oooooolLooooo`4000000Oooool00003
00000?oooooooooo0?oooooo7?ooool10000007ooooo00000`00003oooooooooo`3ooooooacooooo
0@000001ooooo`0000<00000ooooooooool0oooooolLooooo`4000000Oooool0000300000?oooooo
oooo0?oooooo7?ooool10000007ooooo00000`00003oooooooooo`3ooooooacooooo0@000001oooo
o`0000<00000ooooooooool0oooooolLooooo`4000000Oooool0000300000?oooooooooo0?oooooo
7?ooool10000007ooooo00000`00003oooooooooo`3ooooooacooooo0@000001ooooo`0000<00000
ooooooooool0oooooolLooooo`4000000Oooool0000300000?oooooooooo0?oooooo7?ooool10000
007ooooo00000`00003oooooooooo`3ooooooacooooo0@000001ooooo`0000<00000ooooooooool0
oooooolLooooo`4000000Oooool0000300000?oooooooooo0?oooooo7?ooool10000007ooooo0000
0`00003oooooooooo`3ooooooacooooo0@000001ooooo`0000<00000ooooooooool0S_ooool2oomo
08_ooooo0@000001ooooo`0000<00000ooooooooool0SOooool4oomo08[ooooo0@000001ooooo`00
00<00000ooooooooool0SOooool4oomo08[ooooo0@000001ooooo`0000<00000ooooooooool0S_oo
ool2oomo08_ooooo0@000001ooooo`0000<00000ooooooooool0oooooolLooooo`4000000Oooool0
000300000?oooooooooo0?oooooo7?ooool10000007ooooo00000`00003oooooooooo`3ooooooaco
oooo0@000001ooooo`0000<00000ooooooooool0oooooolLooooo`4000000Oooool0000300000?oo
oooooooo0?oooooo7?ooool10000007ooooo00000`00003oooooooooo`3ooooooacooooo0@000001
ooooo`0000<00000ooooooooool0oooooolLooooo`4000000Oooool0000300000?oooooooooo0?oo
oooo7?ooool10000007ooooo00000`00003oooooooooo`3ooooooacooooo0@000001ooooo`0000<0
0000ooooooooool0oooooolLooooo`4000000Oooool0000300000?oooooooooo0?oooooo7?ooool1
0000007ooooo00000`00003oooooooooo`3ooooooacooooo0@000001ooooo`0000<00000oooooooo
ool0oooooolLooooo`4000000Oooool0000300000?oooooooooo0?oooooo7?ooool10000007ooooo
00000`00003oooooooooo`3ooooooacooooo0@000001ooooo`0000<00000ooooooooool0oooooolL
ooooo`4000000Oooool0000300000?oooooooooo0?oooooo7?ooool10000007ooooo00000`00003o
ooooooooo`3ooooooacooooo0@000001ooooo`0000<00000ooooooooool0oooooolLooooo`400000
0Oooool0000300000?oooooooooo0?oooooo7?ooool10000007ooooo00000`00003oooooooooo`3o
oooooacooooo0@000001ooooo`00o`00000P0000007ooooo0000\
\>"],
  ImageRangeCache->{{{0, 287}, {287, 0}} -> {-1.01089, -1.01089, 0.00704453, \
0.00704453}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.49505 0.5 0.49505 [
[ 0 0 -0.125 0 ]
[ 0 0 -0.125 0 ]
[ 0 1 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
0 0 m
1 0 L
s
0 0 m
0 1 L
s
0 1 m
1 1 L
s
1 0 m
1 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
1 .5 0 r
.015 w
.03175 .1355 Mdot
.03435 .12523 Mdot
.11137 .12765 Mdot
.14107 .18841 Mdot
.16218 .24538 Mdot
.17294 .21053 Mdot
.18267 .18577 Mdot
.18434 .1304 Mdot
.18553 .30956 Mdot
.20401 .239 Mdot
.21247 .27571 Mdot
.21687 .20845 Mdot
.22376 .2799 Mdot
.22832 .27485 Mdot
.29063 .20974 Mdot
.29686 .25079 Mdot
.30487 .22936 Mdot
.30683 .34623 Mdot
.32055 .20902 Mdot
.32574 .21979 Mdot
.34472 .28521 Mdot
.35998 .36393 Mdot
.36335 .24976 Mdot
.3794 .36608 Mdot
.42386 .66992 Mdot
.44391 .74519 Mdot
.45059 .34198 Mdot
.47208 .67586 Mdot
.47436 .71381 Mdot
.49778 .59825 Mdot
.50874 .91643 Mdot
.51516 .76219 Mdot
.53655 .61374 Mdot
.56563 .75219 Mdot
.59189 .65665 Mdot
.59581 .61604 Mdot
.59923 .6556 Mdot
.60292 .68499 Mdot
.62656 .67779 Mdot
.63555 .72451 Mdot
.63919 .652 Mdot
.64169 .6004 Mdot
.64246 .58611 Mdot
.64496 .54267 Mdot
.64608 .77288 Mdot
.65077 .64308 Mdot
.66065 .57816 Mdot
.67474 .59169 Mdot
.69296 .563 Mdot
.72815 .65902 Mdot
.73169 .58879 Mdot
.74669 .61318 Mdot
.74821 .65474 Mdot
.75963 .63781 Mdot
.79673 .57809 Mdot
.80925 .55852 Mdot
.81525 .58444 Mdot
.83417 .62985 Mdot
.83598 .55526 Mdot
.91595 .49319 Mdot
1 0 0 r
.005 w
.16128 .17044 m
.18734 .17269 L
.21339 .17909 L
.2345 .18734 L
.23945 .19126 L
.2655 .20415 L
.27874 .21339 L
.29156 .22295 L
.31204 .23945 L
.31761 .24532 L
.33549 .2655 L
.34367 .28341 L
.34499 .29156 L
.34367 .29798 L
.31761 .3104 L
.29156 .30711 L
.2655 .30014 L
.24507 .29156 L
.23945 .28747 L
.21339 .27402 L
.20155 .2655 L
.18734 .25472 L
.16884 .23945 L
.16128 .2313 L
.14618 .21339 L
.13806 .18734 L
.16128 .17044 L
s
0 0 1 r
.65633 .57701 m
.68239 .56842 L
.70844 .56313 L
.7345 .56168 L
.76055 .5752 L
.76359 .57817 L
.76859 .60422 L
.76055 .62333 L
.75627 .63028 L
.7345 .65485 L
.73298 .65633 L
.70844 .6775 L
.69922 .68239 L
.68239 .69294 L
.65633 .70579 L
.64983 .70844 L
.63028 .71539 L
.60422 .72268 L
.57817 .72651 L
.55211 .7214 L
.53145 .70844 L
.52926 .68239 L
.54239 .65633 L
.55211 .63983 L
.56625 .63028 L
.57817 .6193 L
.60119 .60422 L
.60422 .60227 L
.63028 .58726 L
.65315 .57817 L
.65633 .57701 L
s
1 0 0 r
.03 w
.24141 .24033 Mdot
0 0 1 r
.64872 .64417 Mdot
1 0 0 r
.79703 .00495 m
.79703 .00495 L
.87129 .00495 L
.87129 .00495 L
F
0 0 1 r
.89604 .00495 m
.89604 .25247 L
.9703 .25247 L
.9703 .00495 L
F
1 0 1 r
.04 w
.67474 .59169 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P000182000`400?l00000o`00003ooooooolQ
ooooo`00ool0000Po`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`00
00?o0000ooooooooool0o_oooolEo`00o`Sooooo0Ol00001ooooo`0000?o0000ooooooooool0o_oo
oolEo`00o`Sooooo0Ol00001ooooo`0000?o0000ooooooooool0o_oooolEo`00o`Sooooo0Ol00001
ooooo`0000?o0000ooooooooool0o_oooolEo`00o`Sooooo0Ol00001ooooo`0000?o0000oooooooo
ool0o_oooolEo`00o`Sooooo0Ol00001ooooo`0000?o0000ooooooooool0o_oooolEo`00o`Sooooo
0Ol00001ooooo`0000?o0000ooooooooool0o_oooolEo`00o`Sooooo0Ol00001ooooo`0000?o0000
ooooooooool0o_oooolEo`00o`Sooooo0Ol00001ooooo`0000?o0000ooooooooool0o_oooolEo`00
o`Sooooo0Ol00001ooooo`0000?o0000ooooooooool0o_oooolEo`00o`Sooooo0Ol00001ooooo`00
00?o0000ooooooooool0o_oooolEo`00o`Sooooo0Ol00001ooooo`0000?o0000ooooooooool0o_oo
oolEo`00o`Sooooo0Ol00001ooooo`0000?o0000ooooooooool0o_oooolEo`00o`Sooooo0Ol00001
ooooo`0000?o0000ooooooooool0o_oooolEo`00o`Sooooo0Ol00001ooooo`0000?o0000oooooooo
ool0o_oooolEo`00o`Sooooo0Ol00001ooooo`0000?o0000ooooooooool0o_oooolEo`00o`Sooooo
0Ol00001ooooo`0000?o0000ooooooooool0o_oooolEo`00o`Sooooo0Ol00001ooooo`0000?o0000
ooooooooool0o_oooolEo`00o`Sooooo0Ol00001ooooo`0000?o0000ooooooooool0o_oooolEo`00
o`Sooooo0Ol00001ooooo`0000?o0000ooooooooool0o_oooolEo`00o`Sooooo0Ol00001ooooo`00
00?o0000ooooooooool0o_oooolEo`00o`Sooooo0Ol00001ooooo`0000?o0000ooooooooool0o_oo
oolEo`00o`Sooooo0Ol00001ooooo`0000?o0000ooooooooool0o_oooolEo`00o`Sooooo0Ol00001
ooooo`0000?o0000ooooooooool0o_oooolEo`00o`Sooooo0Ol00001ooooo`0000?o0000oooooooo
ool0o_oooolEo`00o`Sooooo0Ol00001ooooo`0000?o0000ooooooooool0o_oooolEo`00o`Sooooo
0Ol00001ooooo`0000?o0000ooooooooool0o_oooolEo`00o`Sooooo0Ol00001ooooo`0000?o0000
ooooooooool0o_oooolEo`00o`Sooooo0Ol00001ooooo`0000?o0000ooooooooool0o_oooolEo`00
o`Sooooo0Ol00001ooooo`0000?o0000ooooooooool0o_oooolEo`00o`Sooooo0Ol00001ooooo`00
00?o0000ooooooooool0o_oooolEo`00o`Sooooo0Ol00001ooooo`0000?o0000ooooooooool0o_oo
oolEo`00o`Sooooo0Ol00001ooooo`0000?o0000ooooooooool01_ooool2oomo0?Kooooo5Ol00?l8
ooooo`7o00000Oooool00003o`000?oooooooooo00Gooooo1?ooO`0Cooooo`;oogl0h?oooolEo`00
o`Sooooo0Ol00001ooooo`0000?o0000ooooooooool01Oooool4oomo01;ooooo1?ooO`0Booooo`;o
ogl0booooolEo`00o`Sooooo0Ol00001ooooo`0000?o0000ooooooooool01Oooool3oomo01?ooooo
1?ooO`0Aooooo`Coogl0b_oooolEo`00o`Sooooo0Ol00001ooooo`0000?o0000ooooooooool01?oo
ool4oomo01Cooooo0_ooO`0Booooo`Coogl0b_oooolEo`00o`Sooooo0Ol00001ooooo`0000?o0000
ooooooooool01?ooool4oomo02Wooooo0_ooO`3;oooooaGo003o2?ooool1o`00007ooooo00000ol0
003oooooooooo`05ooooo`;oogl0mooooolEo`00o`Sooooo0Ol00001ooooo`0000?o0000oooooooo
ool0o_oooolEo`00o`Sooooo0Ol00001ooooo`0000?o0000ooooooooool0o_oooolEo`00o`Sooooo
0Ol00001ooooo`0000?o0000ooooooooool0o_oooolEo`00o`Sooooo0Ol00001ooooo`0000?o0000
ooooooooool0o_oooolEo`00o`Sooooo0Ol00001ooooo`0000?o0000ooooooooool0o_oooolEo`00
o`Sooooo0Ol00001ooooo`0000?o0000ooooooooool0o_oooolEo`00o`Sooooo0Ol00001ooooo`00
00?o0000ooooooooool0o_oooolEo`00o`Sooooo0Ol00001ooooo`0000?o0000ooooooooool0:_oo
ool6ool00<kooooo5Ol00?l8ooooo`7o00000Oooool00003o`000?oooooooooo02Wooooo00?oo`00
ooooooooool01?ooool5ool00<Wooooo5Ol00?l8ooooo`7o00000Oooool00003o`000?oooooooooo
02Oooooo0_oo000<ooooo`Coo`00aOoooolEo`00o`Sooooo0Ol00001ooooo`0000?o0000oooooooo
ool09_ooool00ooo003oooooooooo`0@ooooo`Coo`00`OoooolEo`00o`Sooooo0Ol00001ooooo`00
00?o0000ooooooooool09?ooool00oooO`3oo`00ooooo`09ooooo`;oogl02oooool3ool00;kooooo
5Ol00?l8ooooo`7o00000Oooool00003o`000?oooooooooo02?ooooo00Coogl0ool00?ooO`3oogl0
2?ooool4oomo00gooooo00?oo`00ooooooooool0^ooooolEo`00o`Sooooo0Ol00001ooooo`0000?o
0000ooooooooool08oooool01?ooO`3oo`00oomo0?ooO`08ooooo`Coogl03_ooool2ool00;_ooooo
5Ol00?l8ooooo`7o00000Oooool00003o`000?oooooooooo02Cooooo00?oogl0ool00?ooool02Ooo
ool2oomo017ooooo0_oo002ioooooaGo003o2?ooool1o`00007ooooo00000ol0003oooooooooo`0U
ooooo`03ool00?oooooooooo01gooooo0_oo002goooooaGo003o2?ooool1o`00007ooooo00000ol0
003oooooooooo`0Uooooo`03ool00?oooooooooo01oooooo0_oo002eoooooaGo003o2?ooool1o`00
007ooooo00000ol0003oooooooooo`0Vooooo`03ool00?oooooooooo017ooooo0_ooO`0=ooooo`;o
o`001?ooool2oomo00Oooooo0_ooO`2ToooooaGo003o2?ooool1o`00007ooooo00000ol0003ooooo
ooooo`0Vooooo`03ool00?oooooooooo00Gooooo0_ooO`09ooooo`Coogl03_ooool00ooo003ooooo
ooooo`04oomo00Gooooo1?ooO`2SoooooaGo003o2?ooool1o`00007ooooo00000ol0003ooooooooo
o`0Vooooo`03ool00?oooooooooo00Cooooo1?ooO`08ooooo`Coogl03oooool00ooo003ooooooomo
0003oomo00Gooooo1?ooO`2SoooooaGo003o2?ooool1o`00007ooooo00000ol0003oooooooooo`0W
ooooo`03ool00?oooooooooo00?ooooo1?ooO`09ooooo`;oogl04Oooool01?oo003ooooooomo0?oo
O`07ooooo`?oogl0XooooolEo`00o`Sooooo0Ol00001ooooo`0000?o0000ooooooooool09oooool0
0ooo003oooooooooo`04ooooo`;oogl07_ooool00ooo003oooooooooo`07ooooo`Coogl0X_oooolE
o`00o`Sooooo0Ol00001ooooo`0000?o0000ooooooooool0:?ooool00ooo003oooooooooo`0Toooo
o`03ool00?oooooooooo00Kooooo1?ooO`2RoooooaGo003o2?ooool1o`00007ooooo00000ol0003o
ooooooooo`0Yooooo`03ool00?oooooooooo02Cooooo0_oo00000oooooooogl0oomo0004ooooo`;o
ogl0XooooolEo`00o`Sooooo0Ol00001ooooo`0000?o0000ooooooooool0:_ooool00ooo003ooooo
ooooo`0Cooooo`Coo`003_ooool01?oo003oogl0oomo0?ooO`2XoooooaGo003o2?ooool1o`00007o
oooo00000ol0003oooooooooo`0[ooooo`03ool00?oooooooooo017ooooo1_oo000=ooooo`04oomo
0?oo003oo`00oomo0:Sooooo5Ol00?l8ooooo`7o00000Oooool00003o`000?oooooooooo02cooooo
00?oo`00ooooooooool02?ooool2oomo00Gooooo2?oo000=ooooo`;oogl000?oo`00ooooooooool0
Y_oooolEo`00o`Sooooo0Ol00001ooooo`0000?o0000ooooooooool0;Oooool00ooo003ooooooooo
o`06ooooo`Coogl01?ooool8ool0013ooooo00?oo`00ooooooooool0YOoooolEo`00o`Sooooo0Ol0
0001ooooo`0000?o0000ooooooooool0:oooool2oomo0003oooooooo003ooooo00Kooooo1?ooO`04
ooooo`Soo`004Oooool00ooo003oooooooooo`2ToooooaGo003o2?ooool1o`00007ooooo00000ol0
003oooooooooo`0Zooooo`Coogl000?oooooool00?ooool01_ooool2oomo00Gooooo2?oo000;oooo
o`;oogl01Oooool00ooo003oooooooooo`09ooooo`;oogl0V?oooolEo`00o`Sooooo0Ol00001oooo
o`0000?o0000ooooooooool0:_ooool4oomo00;ooooo00?oo`00ooooooooool03?ooool6ool000_o
oooo1?ooO`04ooooo`03ool00?oooooooooo00Sooooo1?ooO`2GoooooaGo003o2?ooool1o`00007o
oooo00000ol0003oooooooooo`0[ooooo`;oogl01?ooool00ooo003oooooooooo`0<ooooo`Coo`00
3?ooool4oomo00Gooooo00?oo`00ooooooooool01oooool4oomo09Oooooo5Ol00?l8ooooo`7o0000
0Oooool00003o`000?oooooooooo03;ooooo0_oo000Mooooo`;oogl01oooool00ooo003ooooooooo
o`07ooooo`;oogl0]Oooool1o`00007ooooo00000ol0003oooooooooo`0dooooo`03ool00?oooooo
oooo02Cooooo00?oo`00ooooooooool0_Oooool1o`00007ooooo00000ol0003oooooooooo`0eoooo
o`03ool00?oooooooooo02Cooooo00?oo`00ooooooooool0_?ooool1o`00007ooooo00000ol0003o
ooooooooo`0fooooo`;oo`009Oooool00ooo003oooooooooo`2kooooo`7o00000Oooool00003o`00
0?oooooooooo03Sooooo0_oo00000oooO`3oooooooooo`02oomo01kooooo00?oo`00ooooooooool0
^oooool1o`00007ooooo00000ol0003oooooooooo`0hooooo`;oogl00_oo0004oomo01kooooo00?o
o`00ooooooooool0^_ooool1o`00007ooooo00000ol0003oooooooooo`0hooooo`Coogl00_oo0002
oomo01kooooo00?oo`00ooooooooool0^_ooool1o`00007ooooo00000ol0003oooooooooo`0ioooo
o`Googl000?oo`00ooooooooool07Oooool00ooo003oogl0oomo002jooooo`7o00000Oooool00003
o`000?oooooooooo03_ooooo1?ooO`02ool001gooooo00Coogl0ool00?ooO`3oogl0^Oooool1o`00
007ooooo00000ol0003oooooooooo`0looooo`;oogl00oooool2ool001_ooooo00Coogl0ool00?oo
O`3oogl0^Oooool1o`00007ooooo00000ol0003oooooooooo`13ooooo`;oo`006_ooool00oooO`3o
o`00ooooo`2iooooo`7o00000Oooool00003o`000?oooooooooo04Gooooo0_oo000Iooooo`03ool0
0?oooooooooo0;Sooooo0Ol00001ooooo`0000?o0000ooooooooool0Aoooool2ool001Gooooo0_oo
002kooooo`7o00000Oooool00003o`000?oooooooooo04Wooooo0ooo000@ooooo`;oo`00_Oooool1
o`00007ooooo00000ol0003oooooooooo`0aooooo`;oogl06Oooool3ool000cooooo00?oo`00oooo
ooooool0_Oooool1o`00007ooooo00000ol0003oooooooooo`0`ooooo`Coogl06oooool6ool000Co
oooo0_oo0030ooooo`7o00000Oooool00003o`000?oooooooooo033ooooo1?ooO`0Qooooo`Coo`00
`_ooool1o`00007ooooo00000ol0003oooooooooo`0aooooo`;oogl0j?ooool1o`00007ooooo0000
0ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLoooo
o`7o00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003ooooo
ooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Ooo
ool00003o`000?oooooooooo07gooooo0_ooO`2Looooo`7o00000Oooool00003o`000?oooooooooo
07cooooo1?ooO`2Kooooo`7o00000Oooool00003o`000?oooooooooo05Cooooo0_ooO`0Vooooo`Co
ogl0Voooool1o`00007ooooo00000ol0003oooooooooo`1Cooooo`Coogl09_ooool2oomo09cooooo
0Ol00001ooooo`0000?o0000ooooooooool0Doooool4oomo0<Cooooo0Ol00001ooooo`0000?o0000
ooooooooool0E?ooool2oomo0<Gooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLoooo
o`7o00000Oooool00003o`000?oooooooooo06?ooooo0_ooO`04ooooo`;oogl0/?ooool1o`00007o
oooo00000ol0003oooooooooo`1Rooooo`Coogl00_ooool4oomo0:oooooo0Ol00001ooooo`0000?o
0000ooooooooool0H_ooool4oomo00;ooooo1?ooO`2_ooooo`7o00000Oooool00003o`000?oooooo
oooo06?ooooo0_ooO`04ooooo`;oogl0/?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooo
oacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`00
0?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol0
0001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo
0?oooooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`00
00?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?oo
ool1o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000oooo
ooooool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007o
oooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooo
oolLooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0
003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o
00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003ooooooooo
o`3ooooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool0
0003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooooaco
oooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oo
oooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001
ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo0?oo
oooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o
0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1
o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000oooooooo
ool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo
00000ol0003oooooooooo`3oooooo`Cooooo0_ooO`0Fooooo`7o00000Oooool00003o`000?oooooo
oooo0?oooooo0oooool4oomo01Gooooo0Ol00001ooooo`0000?o0000ooooooooool0ooooool3oooo
o`Coogl05Oooool1o`00007ooooo00000ol0003oooooooooo`3oooooo`Cooooo0_ooO`0Fooooo`7o
00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003ooooooooo
o`3ooooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool0
0003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooooaco
oooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oo
oooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001
ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo0?oo
oooo7?ooool1o`00007ooooo00000ol0003oooooooooo`2eooooo`;oogl0I?ooool1o`00007ooooo
00000ol0003oooooooooo`2dooooo`Coogl0Hoooool1o`00007ooooo00000ol0003oooooooooo`2d
ooooo`Coogl0Hoooool1o`00007ooooo00000ol0003oooooooooo`2eooooo`;oogl0=Oooool2oomo
02gooooo0Ol00001ooooo`0000?o0000ooooooooool0i?ooool2oomo00Gooooo1?ooO`0/ooooo`7o
00000Oooool00003o`000?oooooooooo0>?ooooo1?ooO`04ooooo`Coogl0;?ooool1o`00007ooooo
00000ol0003oooooooooo`33ooooo`;oogl07_ooool4oomo00Gooooo0_ooO`0]ooooo`7o00000Ooo
ool00003o`000?oooooooooo0<;ooooo1?ooO`0;o`00oa?ooooo0_ooO`0eooooo`7o00000Oooool0
0003o`000?oooooooooo0<;ooooo1?l00?l;ooooo`;o003oB?ooool1o`00007ooooo00000ol0003o
ooooooooo`2nooooo`Co003o00?ooooooomo0?ooO`003_ooool2o`00odKooooo0Ol00001ooooo`00
00?o0000ooooooooool0^Oooool2oomo0003o`00oooo0?ooo`3o00?oo`3o5?ooool2o`00o`Wooooo
0_ooO`0iooooo`7o00000Oooool00003o`000?oooooooooo0;Oooooo1?l00?l7ool0oaGooooo0_l0
0?l6ooooo`Coogl0>?ooool1o`00007ooooo00000ol0003oooooooooo`2dooooo`?o003o00?ooooo
oomo0?ooO`002Ooo0?lEooooo`03o`00oooooooooooo00Cooooo1?ooO`03ooooo`;oogl0<oooool1
o`00007ooooo00000ol0003oooooooooo`2booooo`;o003o0oooO`02ooooo`_oo`3o2_ooool2oomo
00Sooooo00?o003oooooooooool01Oooool2oomo00?ooooo1?ooO`0booooo`7o00000Oooool00003
o`000?oooooooooo0;3ooooo0_l00?l00oooooooogl0oomo0002oomo00;ooooo2ooo0?l9ooooo`Co
ogl01oooool00ol00?ooooooooooo`0:ooooo`Coogl0<_ooool1o`00007ooooo00000ol0003ooooo
ooooo`2^ooooo`;o003o1?ooool2oomo00?ooooo2ooo0?l9ooooo`Coogl01oooool00ol00?oooooo
ooooo`0;ooooo`;oogl0<oooool1o`00007ooooo00000ol0003oooooooooo`2;ooooo`;oogl08?oo
ool00ol00?ooooooooooo`04ooooo`;oogl00oooool;ool0o`[ooooo0_ooO`09ooooo`03o`00oooo
oooooooo03oooooo0Ol00001ooooo`0000?o0000ooooooooool0R_ooool4oomo01gooooo0_l00?l6
ooooo`Coogl00_ooool;ool0oaGooooo00?o003oooooooooool0?oooool1o`00007ooooo00000ol0
003oooooooooo`2:ooooo`Coogl07?ooool00ol00?ooooooooooo`06ooooo`Coogl00oooool9ool0
oaKooooo00?o003oooooooooool0?oooool1o`00007ooooo00000ol0003oooooooooo`2;ooooo`;o
ogl06oooool2o`00o`[ooooo0_ooO`05ooooo`Ooo`3o5oooool00ol00?ooooooooooo`0oooooo`7o
00000Oooool00003o`000?oooooooooo09Kooooo0_ooO`0>ooooo`;o003o5?ooool5ool0oa7ooooo
0_ooO`05ooooo`03o`00oooooooooooo03oooooo0Ol00001ooooo`0000?o0000ooooooooool0UOoo
ool4oomo00cooooo00Co003oooooooooO`3oogl0:?ooool4oomo00?ooooo00?o003oooooooooool0
@?ooool1o`00007ooooo00000ol0003oooooooooo`2Eooooo`Coogl02_ooool2o`00o`03oooooooo
O`3oogl000;oogl09oooool4oomo00?ooooo00?o003oooooooooool0@?ooool1o`00007ooooo0000
0ol0003oooooooooo`2Fooooo`;oogl02_ooool01?l00?ooooooooooooooool4oomo02Sooooo0_oo
O`04ooooo`03o`00oooooooooooo043ooooo0Ol00001ooooo`0000?o0000ooooooooool0XOooool0
0ol00?ooooooooooo`03ooooo`;oogl0;_ooool00ol00?ooooooooooo`11ooooo`7o00000Oooool0
0003o`000?oooooooooo0:3ooooo00?o003oooooooooool0<oooool00ol00?ooooooooooo`0Boooo
o`;oogl0;_ooool1o`00007ooooo00000ol0003oooooooooo`2Nooooo`;o003o=Oooool00ol00?oo
ooooooooo`0Booooo`Coogl0;Oooool1o`00007ooooo00000ol0003oooooooooo`2Mooooo`03o`00
oooooooooooo01Gooooo1?l00?lLooooo`03o`00ooooO`3oogl001;ooooo1?ooO`0]ooooo`7o0000
0Oooool00003o`000?oooooooooo09cooooo00?o003oooooooooool05Oooool6o`00oa[ooooo00?o
003ooomo0?ooO`000_ooO`0Booooo`;oogl0;_ooool1o`00007ooooo00000ol0003oooooooooo`2K
ooooo`03o`00oooooooooooo01Gooooo2?l00?lHooooo`03o`00ooooooooogl000?oogl0@_ooool1
o`00007ooooo00000ol0003oooooooooo`2Kooooo`03o`00oooooooooooo01Gooooo2?l00?lGoooo
o`04o`00ooooooooooooooooo`;oogl0@oooool1o`00007ooooo00000ol0003oooooooooo`2Joooo
o`03o`00oooooooooooo01Kooooo2?l00?lFooooo`03o`00oooooooooooo04Oooooo0Ol00001oooo
o`0000?o0000ooooooooool0VOooool00ol00?ooooooooooo`0<ooooo`;oogl02?ooool00oooO`3o
003oo`00o`06o`00oaGooooo00?o003oooooooooool00_ooO`16ooooo`7o00000Oooool00003o`00
0?oooooooooo09Wooooo00?o003oooooooooool02_ooool5oomo00Oooooo0_ooO`06o`00oa?ooooo
0_ooO`000ol00?ooooooooooo`04oomo04Gooooo0Ol00001ooooo`0000?o0000ooooooooool0V?oo
ool00ol00?ooooooooooo`0:ooooo`Koogl02?ooool2oomo00Co003o4oooool2oomo00;o003o0_oo
ool4oomo04Gooooo0Ol00001ooooo`0000?o0000ooooooooool0V?ooool00ol00?ooooooooooo`0:
ooooo`Googl08_ooool01?ooO`3o003ooomo0?ooO`03ooooo`;oogl0A_ooool1o`00007ooooo0000
0ol0003oooooooooo`1fooooo`;oogl07oooool00ol00?ooooooooooo`0<ooooo`;oogl09?ooool0
0ol00?ooogl0oomo001<ooooo`7o00000Oooool00003o`000?oooooooooo07Gooooo1?ooO`0Noooo
o`03o`00oooooooooooo037ooooo00?o003oooooooooool0COooool1o`00007ooooo00000ol0003o
ooooooooo`1eooooo`Coogl02_ooool2oomo017ooooo00?o003oooooooooool0<Oooool00ol00?oo
ooooooooo`1>ooooo`7o00000Oooool00003o`000?oooooooooo07Kooooo0_ooO`0:ooooo`Coogl0
3oooool00ol00?ooooooooooo`0Hooooo`;oogl05oooool00ol00?ooooooooooo`1?ooooo`7o0000
0Oooool00003o`000?oooooooooo08;ooooo1?ooO`0?ooooo`03o`00oooooooooooo01Oooooo1?oo
O`0Dooooo`;o003oD_ooool1o`00007ooooo00000ol0003oooooooooo`23ooooo`;oogl03oooool0
0ol00?ooooooooooo`0Booooo`;oogl01?ooool4oomo017ooooo0ol00?mDooooo`7o00000Oooool0
0003o`000?oooooooooo09Cooooo00?o003oooooooooool04Oooool4oomo00Cooooo0_ooO`0@oooo
o`;o003oEoooool1o`00007ooooo00000ol0003oooooooooo`2Dooooo`03o`00oooooooooooo017o
oooo1?ooO`0Eooooo`03o`00oooooooooooo05Oooooo0Ol00001ooooo`0000?o0000ooooooooool0
U?ooool00ol00?ooooooooooo`0Booooo`;oogl05?ooool2o`00oe[ooooo0Ol00001ooooo`0000?o
0000ooooooooool0U?ooool00ol00?ooooooooooo`0Vooooo`;o003oG?ooool1o`00007ooooo0000
0ol0003oooooooooo`2Eooooo`03o`00oooooooooooo02Cooooo00?o003oooooooooool0G?ooool1
o`00007ooooo00000ol0003oooooooooo`2Eooooo`03o`00oooooooooooo02;ooooo0_l00?mOoooo
o`7o00000Oooool00003o`000?oooooooooo09Gooooo00?o003oooooooooool08?ooool2o`00of7o
oooo0Ol00001ooooo`0000?o0000ooooooooool0Q?ooool2oomo00oooooo0_l00?lOooooo`;o003o
Hoooool1o`00007ooooo00000ol0003oooooooooo`23ooooo`Coogl04?ooool2o`00oa[ooooo0ol0
0?mUooooo`7o00000Oooool00003o`000?oooooooooo08?ooooo1?ooO`0Booooo`;o003o5?ooool4
o`00ofSooooo0Ol00001ooooo`0000?o0000ooooooooool0Q?ooool2oomo01Gooooo0ol00?l>oooo
o`?o003o0oooool2oomo06Oooooo0Ol00001ooooo`0000?o0000ooooooooool0W_ooool3o`00o`Go
oooo1_l00?l5ooooo`Coogl0I_ooool1o`00007ooooo00000ol0003oooooooooo`2Qooooo`Go003o
2oooool4oomo06Kooooo0Ol00001ooooo`0000?o0000ooooooooool0/_ooool2oomo06Oooooo0Ol0
0001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo
0?oooooo7?ooool1o`00007ooooo00000ol0003oooooooooo`1kooooo`;oogl0W_ooool1o`00007o
oooo00000ol0003oooooooooo`1jooooo`Coogl0WOooool1o`00007ooooo00000ol0003ooooooooo
o`1jooooo`Coogl08?ooool2oomo07_ooooo0Ol00001ooooo`0000?o0000ooooooooool0Noooool2
oomo023ooooo1?ooO`1jooooo`7o00000Oooool00003o`000?oooooooooo09gooooo1?ooO`1joooo
o`7o00000Oooool00003o`000?oooooooooo093ooooo0_ooO`0<ooooo`;oogl0Noooool1o`00007o
oooo00000ol0003oooooooooo`2?ooooo`Coogl0R?ooool1o`00007ooooo00000ol0003ooooooooo
o`2?ooooo`Coogl0R?ooool1o`00007ooooo00000ol0003oooooooooo`2@ooooo`;oogl08oooool2
oomo06Cooooo0Ol00001ooooo`0000?o0000ooooooooool0]?ooool4oomo06?ooooo0Ol00001oooo
o`0000?o0000ooooooooool0]?ooool4oomo06?ooooo0Ol00001ooooo`0000?o0000ooooooooool0
]Oooool2oomo06Cooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Ooo
ool00003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooo
oacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`00
0?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol0
0001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo
0?oooooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`00
00?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?oo
ool1o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000oooo
ooooool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007o
oooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooo
oolLooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0
003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o
00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003ooooooooo
o`3ooooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool0
0003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooooaco
oooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oo
oooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001
ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo0?oo
oooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o
0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1
o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000oooooooo
ool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo
00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolL
ooooo`7o00000Oooool00003o`000?oooooooooo08kooooo0_ooO`2;ooooo`7o00000Oooool00003
o`000?oooooooooo08gooooo1?ooO`2:ooooo`7o00000Oooool00003o`000?oooooooooo08gooooo
1?ooO`2:ooooo`7o00000Oooool00003o`000?oooooooooo08kooooo0_ooO`2;ooooo`7o00000Ooo
ool00003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooo
oacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`00
0?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol0
0001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo
0?oooooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`00
00?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?oo
ool1o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000oooo
ooooool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007o
oooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooo
oolLooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0
003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o
00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003ooooooooo
o`3ooooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool0
0?oo00008?l00001ooooo`00\
\>"],
  ImageRangeCache->{{{0, 287}, {287, 0}} -> {-1.01089, -1.01089, 0.00704453, \
0.00704453}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.49505 0.5 0.49505 [
[ 0 0 -0.125 0 ]
[ 0 0 -0.125 0 ]
[ 0 1 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
0 0 m
1 0 L
s
0 0 m
0 1 L
s
0 1 m
1 1 L
s
1 0 m
1 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
1 .5 0 r
.015 w
.03175 .1355 Mdot
.03435 .12523 Mdot
.11137 .12765 Mdot
.14107 .18841 Mdot
.16218 .24538 Mdot
.17294 .21053 Mdot
.18267 .18577 Mdot
.18434 .1304 Mdot
.18553 .30956 Mdot
.20401 .239 Mdot
.21247 .27571 Mdot
.21687 .20845 Mdot
.22376 .2799 Mdot
.22832 .27485 Mdot
.29063 .20974 Mdot
.29686 .25079 Mdot
.30487 .22936 Mdot
.30683 .34623 Mdot
.32055 .20902 Mdot
.32574 .21979 Mdot
.34472 .28521 Mdot
.35998 .36393 Mdot
.36335 .24976 Mdot
.3794 .36608 Mdot
.42386 .66992 Mdot
.44391 .74519 Mdot
.45059 .34198 Mdot
.47208 .67586 Mdot
.47436 .71381 Mdot
.49778 .59825 Mdot
.50874 .91643 Mdot
.51516 .76219 Mdot
.53655 .61374 Mdot
.56563 .75219 Mdot
.59189 .65665 Mdot
.59581 .61604 Mdot
.59923 .6556 Mdot
.60292 .68499 Mdot
.62656 .67779 Mdot
.63555 .72451 Mdot
.63919 .652 Mdot
.64169 .6004 Mdot
.64246 .58611 Mdot
.64496 .54267 Mdot
.64608 .77288 Mdot
.65077 .64308 Mdot
.66065 .57816 Mdot
.67474 .59169 Mdot
.69296 .563 Mdot
.72815 .65902 Mdot
.73169 .58879 Mdot
.74669 .61318 Mdot
.74821 .65474 Mdot
.75963 .63781 Mdot
.79673 .57809 Mdot
.80925 .55852 Mdot
.81525 .58444 Mdot
.83417 .62985 Mdot
.83598 .55526 Mdot
.91595 .49319 Mdot
1 0 0 r
.005 w
.16128 .17044 m
.18734 .17269 L
.21339 .17909 L
.2345 .18734 L
.23945 .19126 L
.2655 .20415 L
.27874 .21339 L
.29156 .22295 L
.31204 .23945 L
.31761 .24532 L
.33549 .2655 L
.34367 .28341 L
.34499 .29156 L
.34367 .29798 L
.31761 .3104 L
.29156 .30711 L
.2655 .30014 L
.24507 .29156 L
.23945 .28747 L
.21339 .27402 L
.20155 .2655 L
.18734 .25472 L
.16884 .23945 L
.16128 .2313 L
.14618 .21339 L
.13806 .18734 L
.16128 .17044 L
s
0 0 1 r
.65633 .57701 m
.68239 .56842 L
.70844 .56313 L
.7345 .56168 L
.76055 .5752 L
.76359 .57817 L
.76859 .60422 L
.76055 .62333 L
.75627 .63028 L
.7345 .65485 L
.73298 .65633 L
.70844 .6775 L
.69922 .68239 L
.68239 .69294 L
.65633 .70579 L
.64983 .70844 L
.63028 .71539 L
.60422 .72268 L
.57817 .72651 L
.55211 .7214 L
.53145 .70844 L
.52926 .68239 L
.54239 .65633 L
.55211 .63983 L
.56625 .63028 L
.57817 .6193 L
.60119 .60422 L
.60422 .60227 L
.63028 .58726 L
.65315 .57817 L
.65633 .57701 L
s
1 0 0 r
.03 w
.24141 .24033 Mdot
0 0 1 r
.64872 .64417 Mdot
1 0 0 r
.79703 .00495 m
.79703 .00495 L
.87129 .00495 L
.87129 .00495 L
F
0 0 1 r
.89604 .00495 m
.89604 .25247 L
.9703 .25247 L
.9703 .00495 L
F
1 0 1 r
.04 w
.69296 .563 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P000182000`400?l00000o`00003ooooooolQ
ooooo`00ool0000Po`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`00
00?o0000ooooooooool0o_oooolEo`00o`Sooooo0Ol00001ooooo`0000?o0000ooooooooool0o_oo
oolEo`00o`Sooooo0Ol00001ooooo`0000?o0000ooooooooool0o_oooolEo`00o`Sooooo0Ol00001
ooooo`0000?o0000ooooooooool0o_oooolEo`00o`Sooooo0Ol00001ooooo`0000?o0000oooooooo
ool0o_oooolEo`00o`Sooooo0Ol00001ooooo`0000?o0000ooooooooool0o_oooolEo`00o`Sooooo
0Ol00001ooooo`0000?o0000ooooooooool0o_oooolEo`00o`Sooooo0Ol00001ooooo`0000?o0000
ooooooooool0o_oooolEo`00o`Sooooo0Ol00001ooooo`0000?o0000ooooooooool0o_oooolEo`00
o`Sooooo0Ol00001ooooo`0000?o0000ooooooooool0o_oooolEo`00o`Sooooo0Ol00001ooooo`00
00?o0000ooooooooool0o_oooolEo`00o`Sooooo0Ol00001ooooo`0000?o0000ooooooooool0o_oo
oolEo`00o`Sooooo0Ol00001ooooo`0000?o0000ooooooooool0o_oooolEo`00o`Sooooo0Ol00001
ooooo`0000?o0000ooooooooool0o_oooolEo`00o`Sooooo0Ol00001ooooo`0000?o0000oooooooo
ool0o_oooolEo`00o`Sooooo0Ol00001ooooo`0000?o0000ooooooooool0o_oooolEo`00o`Sooooo
0Ol00001ooooo`0000?o0000ooooooooool0o_oooolEo`00o`Sooooo0Ol00001ooooo`0000?o0000
ooooooooool0o_oooolEo`00o`Sooooo0Ol00001ooooo`0000?o0000ooooooooool0o_oooolEo`00
o`Sooooo0Ol00001ooooo`0000?o0000ooooooooool0o_oooolEo`00o`Sooooo0Ol00001ooooo`00
00?o0000ooooooooool0o_oooolEo`00o`Sooooo0Ol00001ooooo`0000?o0000ooooooooool0o_oo
oolEo`00o`Sooooo0Ol00001ooooo`0000?o0000ooooooooool0o_oooolEo`00o`Sooooo0Ol00001
ooooo`0000?o0000ooooooooool0o_oooolEo`00o`Sooooo0Ol00001ooooo`0000?o0000oooooooo
ool0o_oooolEo`00o`Sooooo0Ol00001ooooo`0000?o0000ooooooooool0o_oooolEo`00o`Sooooo
0Ol00001ooooo`0000?o0000ooooooooool0o_oooolEo`00o`Sooooo0Ol00001ooooo`0000?o0000
ooooooooool0o_oooolEo`00o`Sooooo0Ol00001ooooo`0000?o0000ooooooooool0o_oooolEo`00
o`Sooooo0Ol00001ooooo`0000?o0000ooooooooool0o_oooolEo`00o`Sooooo0Ol00001ooooo`00
00?o0000ooooooooool0o_oooolEo`00o`Sooooo0Ol00001ooooo`0000?o0000ooooooooool0o_oo
oolEo`00o`Sooooo0Ol00001ooooo`0000?o0000ooooooooool01_ooool2oomo0?Kooooo5Ol00?l8
ooooo`7o00000Oooool00003o`000?oooooooooo00Gooooo1?ooO`0Cooooo`;oogl0h?oooolEo`00
o`Sooooo0Ol00001ooooo`0000?o0000ooooooooool01Oooool4oomo01;ooooo1?ooO`0Booooo`;o
ogl0booooolEo`00o`Sooooo0Ol00001ooooo`0000?o0000ooooooooool01Oooool3oomo01?ooooo
1?ooO`0Aooooo`Coogl0b_oooolEo`00o`Sooooo0Ol00001ooooo`0000?o0000ooooooooool01?oo
ool4oomo01Cooooo0_ooO`0Booooo`Coogl0b_oooolEo`00o`Sooooo0Ol00001ooooo`0000?o0000
ooooooooool01?ooool4oomo02Wooooo0_ooO`3;oooooaGo003o2?ooool1o`00007ooooo00000ol0
003oooooooooo`05ooooo`;oogl0mooooolEo`00o`Sooooo0Ol00001ooooo`0000?o0000oooooooo
ool0o_oooolEo`00o`Sooooo0Ol00001ooooo`0000?o0000ooooooooool0o_oooolEo`00o`Sooooo
0Ol00001ooooo`0000?o0000ooooooooool0o_oooolEo`00o`Sooooo0Ol00001ooooo`0000?o0000
ooooooooool0o_oooolEo`00o`Sooooo0Ol00001ooooo`0000?o0000ooooooooool0o_oooolEo`00
o`Sooooo0Ol00001ooooo`0000?o0000ooooooooool0o_oooolEo`00o`Sooooo0Ol00001ooooo`00
00?o0000ooooooooool0o_oooolEo`00o`Sooooo0Ol00001ooooo`0000?o0000ooooooooool0:_oo
ool6ool00<kooooo5Ol00?l8ooooo`7o00000Oooool00003o`000?oooooooooo02Wooooo00?oo`00
ooooooooool01?ooool5ool00<Wooooo5Ol00?l8ooooo`7o00000Oooool00003o`000?oooooooooo
02Oooooo0_oo000<ooooo`Coo`00aOoooolEo`00o`Sooooo0Ol00001ooooo`0000?o0000oooooooo
ool09_ooool00ooo003oooooooooo`0@ooooo`Coo`00`OoooolEo`00o`Sooooo0Ol00001ooooo`00
00?o0000ooooooooool09?ooool00oooO`3oo`00ooooo`09ooooo`;oogl02oooool3ool00;kooooo
5Ol00?l8ooooo`7o00000Oooool00003o`000?oooooooooo02?ooooo00Coogl0ool00?ooO`3oogl0
2?ooool4oomo00gooooo00?oo`00ooooooooool0^ooooolEo`00o`Sooooo0Ol00001ooooo`0000?o
0000ooooooooool08oooool01?ooO`3oo`00oomo0?ooO`08ooooo`Coogl03_ooool2ool00;_ooooo
5Ol00?l8ooooo`7o00000Oooool00003o`000?oooooooooo02Cooooo00?oogl0ool00?ooool02Ooo
ool2oomo017ooooo0_oo002ioooooaGo003o2?ooool1o`00007ooooo00000ol0003oooooooooo`0U
ooooo`03ool00?oooooooooo01gooooo0_oo002goooooaGo003o2?ooool1o`00007ooooo00000ol0
003oooooooooo`0Uooooo`03ool00?oooooooooo01oooooo0_oo002eoooooaGo003o2?ooool1o`00
007ooooo00000ol0003oooooooooo`0Vooooo`03ool00?oooooooooo017ooooo0_ooO`0=ooooo`;o
o`001?ooool2oomo00Oooooo0_ooO`2ToooooaGo003o2?ooool1o`00007ooooo00000ol0003ooooo
ooooo`0Vooooo`03ool00?oooooooooo00Gooooo0_ooO`09ooooo`Coogl03_ooool00ooo003ooooo
ooooo`04oomo00Gooooo1?ooO`2SoooooaGo003o2?ooool1o`00007ooooo00000ol0003ooooooooo
o`0Vooooo`03ool00?oooooooooo00Cooooo1?ooO`08ooooo`Coogl03oooool00ooo003ooooooomo
0003oomo00Gooooo1?ooO`2SoooooaGo003o2?ooool1o`00007ooooo00000ol0003oooooooooo`0W
ooooo`03ool00?oooooooooo00?ooooo1?ooO`09ooooo`;oogl04Oooool01?oo003ooooooomo0?oo
O`07ooooo`?oogl0XooooolEo`00o`Sooooo0Ol00001ooooo`0000?o0000ooooooooool09oooool0
0ooo003oooooooooo`04ooooo`;oogl07_ooool00ooo003oooooooooo`07ooooo`Coogl0X_oooolE
o`00o`Sooooo0Ol00001ooooo`0000?o0000ooooooooool0:?ooool00ooo003oooooooooo`0Toooo
o`03ool00?oooooooooo00Kooooo1?ooO`2RoooooaGo003o2?ooool1o`00007ooooo00000ol0003o
ooooooooo`0Yooooo`03ool00?oooooooooo02Cooooo0_oo00000oooooooogl0oomo0004ooooo`;o
ogl0XooooolEo`00o`Sooooo0Ol00001ooooo`0000?o0000ooooooooool0:_ooool00ooo003ooooo
ooooo`0Cooooo`Coo`003_ooool01?oo003oogl0oomo0?ooO`2XoooooaGo003o2?ooool1o`00007o
oooo00000ol0003oooooooooo`0[ooooo`03ool00?oooooooooo017ooooo1_oo000=ooooo`04oomo
0?oo003oo`00oomo0:Sooooo5Ol00?l8ooooo`7o00000Oooool00003o`000?oooooooooo02cooooo
00?oo`00ooooooooool02?ooool2oomo00Gooooo2?oo000=ooooo`;oogl000?oo`00ooooooooool0
Y_oooolEo`00o`Sooooo0Ol00001ooooo`0000?o0000ooooooooool0;Oooool00ooo003ooooooooo
o`06ooooo`Coogl01?ooool8ool0013ooooo00?oo`00ooooooooool0YOoooolEo`00o`Sooooo0Ol0
0001ooooo`0000?o0000ooooooooool0:oooool2oomo0003oooooooo003ooooo00Kooooo1?ooO`04
ooooo`Soo`004Oooool00ooo003oooooooooo`2ToooooaGo003o2?ooool1o`00007ooooo00000ol0
003oooooooooo`0Zooooo`Coogl000?oooooool00?ooool01_ooool2oomo00Gooooo2?oo000;oooo
o`;oogl01Oooool00ooo003oooooooooo`09ooooo`;oogl0V?oooolEo`00o`Sooooo0Ol00001oooo
o`0000?o0000ooooooooool0:_ooool4oomo00;ooooo00?oo`00ooooooooool03?ooool6ool000_o
oooo1?ooO`04ooooo`03ool00?oooooooooo00Sooooo1?ooO`2GoooooaGo003o2?ooool1o`00007o
oooo00000ol0003oooooooooo`0[ooooo`;oogl01?ooool00ooo003oooooooooo`0<ooooo`Coo`00
3?ooool4oomo00Gooooo00?oo`00ooooooooool01oooool4oomo09Oooooo5Ol00?l8ooooo`7o0000
0Oooool00003o`000?oooooooooo03;ooooo0_oo000Mooooo`;oogl01oooool00ooo003ooooooooo
o`07ooooo`;oogl0]Oooool1o`00007ooooo00000ol0003oooooooooo`0dooooo`03ool00?oooooo
oooo02Cooooo00?oo`00ooooooooool0_Oooool1o`00007ooooo00000ol0003oooooooooo`0eoooo
o`03ool00?oooooooooo02Cooooo00?oo`00ooooooooool0_?ooool1o`00007ooooo00000ol0003o
ooooooooo`0fooooo`;oo`009Oooool00ooo003oooooooooo`2kooooo`7o00000Oooool00003o`00
0?oooooooooo03Sooooo0_oo00000oooO`3oooooooooo`02oomo01kooooo00?oo`00ooooooooool0
^oooool1o`00007ooooo00000ol0003oooooooooo`0hooooo`;oogl00_oo0004oomo01kooooo00?o
o`00ooooooooool0^_ooool1o`00007ooooo00000ol0003oooooooooo`0hooooo`Coogl00_oo0002
oomo01kooooo00?oo`00ooooooooool0^_ooool1o`00007ooooo00000ol0003oooooooooo`0ioooo
o`Googl000?oo`00ooooooooool07Oooool00ooo003oogl0oomo002jooooo`7o00000Oooool00003
o`000?oooooooooo03_ooooo1?ooO`02ool001gooooo00Coogl0ool00?ooO`3oogl0^Oooool1o`00
007ooooo00000ol0003oooooooooo`0looooo`;oogl00oooool2ool001_ooooo00Coogl0ool00?oo
O`3oogl0^Oooool1o`00007ooooo00000ol0003oooooooooo`13ooooo`;oo`006_ooool00oooO`3o
o`00ooooo`2iooooo`7o00000Oooool00003o`000?oooooooooo04Gooooo0_oo000Iooooo`03ool0
0?oooooooooo0;Sooooo0Ol00001ooooo`0000?o0000ooooooooool0Aoooool2ool001Gooooo0_oo
002kooooo`7o00000Oooool00003o`000?oooooooooo04Wooooo0ooo000@ooooo`;oo`00_Oooool1
o`00007ooooo00000ol0003oooooooooo`0aooooo`;oogl06Oooool3ool000cooooo00?oo`00oooo
ooooool0_Oooool1o`00007ooooo00000ol0003oooooooooo`0`ooooo`Coogl06oooool6ool000Co
oooo0_oo0030ooooo`7o00000Oooool00003o`000?oooooooooo033ooooo1?ooO`0Qooooo`Coo`00
`_ooool1o`00007ooooo00000ol0003oooooooooo`0aooooo`;oogl0j?ooool1o`00007ooooo0000
0ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLoooo
o`7o00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003ooooo
ooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Ooo
ool00003o`000?oooooooooo07gooooo0_ooO`2Looooo`7o00000Oooool00003o`000?oooooooooo
07cooooo1?ooO`2Kooooo`7o00000Oooool00003o`000?oooooooooo05Cooooo0_ooO`0Vooooo`Co
ogl0Voooool1o`00007ooooo00000ol0003oooooooooo`1Cooooo`Coogl09_ooool2oomo09cooooo
0Ol00001ooooo`0000?o0000ooooooooool0Doooool4oomo0<Cooooo0Ol00001ooooo`0000?o0000
ooooooooool0E?ooool2oomo0<Gooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLoooo
o`7o00000Oooool00003o`000?oooooooooo06?ooooo0_ooO`04ooooo`;oogl0/?ooool1o`00007o
oooo00000ol0003oooooooooo`1Rooooo`Coogl00_ooool4oomo0:oooooo0Ol00001ooooo`0000?o
0000ooooooooool0H_ooool4oomo00;ooooo1?ooO`2_ooooo`7o00000Oooool00003o`000?oooooo
oooo06?ooooo0_ooO`04ooooo`;oogl0/?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooo
oacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`00
0?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol0
0001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo
0?oooooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`00
00?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?oo
ool1o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000oooo
ooooool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007o
oooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooo
oolLooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0
003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o
00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003ooooooooo
o`3ooooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool0
0003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooooaco
oooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oo
oooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001
ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo0?oo
oooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o
0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1
o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000oooooooo
ool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo
00000ol0003oooooooooo`3oooooo`Cooooo0_ooO`0Fooooo`7o00000Oooool00003o`000?oooooo
oooo0?oooooo0oooool4oomo01Gooooo0Ol00001ooooo`0000?o0000ooooooooool0ooooool3oooo
o`Coogl05Oooool1o`00007ooooo00000ol0003oooooooooo`3oooooo`Cooooo0_ooO`0Fooooo`7o
00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003ooooooooo
o`3ooooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool0
0003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooooaco
oooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oo
oooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001
ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo0?oo
oooo7?ooool1o`00007ooooo00000ol0003oooooooooo`2eooooo`;oogl0I?ooool1o`00007ooooo
00000ol0003oooooooooo`2dooooo`Coogl0Hoooool1o`00007ooooo00000ol0003oooooooooo`2d
ooooo`Coogl02Oooool5ool0oeGooooo0Ol00001ooooo`0000?o0000ooooooooool0]Oooool2oomo
00Wooooo1ooo0?lUooooo`;oogl0;Oooool1o`00007ooooo00000ol0003oooooooooo`2oooooo`Wo
o`3o7?ooool2oomo00Gooooo1?ooO`0/ooooo`7o00000Oooool00003o`000?oooooooooo0;kooooo
2ooo0?lJooooo`Coogl01?ooool4oomo02cooooo0Ol00001ooooo`0000?o0000ooooooooool0__oo
ool;ool0oa[ooooo1?ooO`05ooooo`;oogl0;Oooool1o`00007ooooo00000ol0003oooooooooo`2n
ooooo`_oo`3o2?l00?lCooooo`;oogl0=Oooool1o`00007ooooo00000ol0003oooooooooo`2noooo
o`_oo`3o2?ooool2o`00odSooooo0Ol00001ooooo`0000?o0000ooooooooool0__ooool;ool0o`[o
oooo0_l00?m6ooooo`7o00000Oooool00003o`000?oooooooooo0;Wooooo0_ooO`03o`00o`03oooo
oooo0?ooo`3o00Ooo`3o3Oooool2o`00o`Wooooo0_ooO`0iooooo`7o00000Oooool00003o`000?oo
oooooooo0;Oooooo1?l00?l00oooO`3oooooooooo`02ooooo`Ooo`3o4?ooool2o`00o`Kooooo1?oo
O`0hooooo`7o00000Oooool00003o`000?oooooooooo0;Cooooo0ol00?l00oooooooogl0oomo0002
oomo00Gooooo1Ooo0?lBooooo`03o`00oooooooooooo00Cooooo1?ooO`03ooooo`;oogl0<oooool1
o`00007ooooo00000ol0003oooooooooo`2booooo`;o003o0oooO`02ooooo`;oogl04oooool2oomo
00Sooooo00?o003oooooooooool01Oooool2oomo00?ooooo1?ooO`0booooo`7o00000Oooool00003
o`000?oooooooooo0;3ooooo0_l00?l00oooooooogl0oomo0002oomo00Kooooo0_ooO`0>ooooo`Co
ogl01oooool00ol00?ooooooooooo`0:ooooo`Coogl0<_ooool1o`00007ooooo00000ol0003ooooo
ooooo`2^ooooo`;o003o1?ooool2oomo00Kooooo1?ooO`0=ooooo`Coogl01oooool00ol00?oooooo
ooooo`0;ooooo`;oogl0<oooool1o`00007ooooo00000ol0003oooooooooo`2;ooooo`;oogl08?oo
ool00ol00?ooooooooooo`04ooooo`;oogl01_ooool4oomo00kooooo0_ooO`09ooooo`03o`00oooo
oooooooo03oooooo0Ol00001ooooo`0000?o0000ooooooooool0R_ooool4oomo01gooooo0_l00?l6
ooooo`Coogl01_ooool2oomo01[ooooo00?o003oooooooooool0?oooool1o`00007ooooo00000ol0
003oooooooooo`2:ooooo`Coogl07?ooool00ol00?ooooooooooo`06ooooo`Coogl08_ooool00ol0
0?ooooooooooo`0oooooo`7o00000Oooool00003o`000?oooooooooo08_ooooo0_ooO`0Kooooo`;o
003o2_ooool2oomo02?ooooo00?o003oooooooooool0?oooool1o`00007ooooo00000ol0003ooooo
ooooo`2Fooooo`;oogl03_ooool2o`00ob[ooooo0_ooO`05ooooo`03o`00oooooooooooo03oooooo
0Ol00001ooooo`0000?o0000ooooooooool0UOooool4oomo00cooooo00Co003oooooooooO`3oogl0
:?ooool4oomo00?ooooo00?o003oooooooooool0@?ooool1o`00007ooooo00000ol0003ooooooooo
o`2Eooooo`Coogl02_ooool2o`00o`03ooooooooO`3oogl000;oogl09oooool4oomo00?ooooo00?o
003oooooooooool0@?ooool1o`00007ooooo00000ol0003oooooooooo`2Fooooo`;oogl02_ooool0
1?l00?ooooooooooooooool4oomo02Sooooo0_ooO`04ooooo`03o`00oooooooooooo043ooooo0Ol0
0001ooooo`0000?o0000ooooooooool0XOooool00ol00?ooooooooooo`03ooooo`;oogl0;_ooool0
0ol00?ooooooooooo`11ooooo`7o00000Oooool00003o`000?oooooooooo0:3ooooo00?o003ooooo
ooooool0<oooool00ol00?ooooooooooo`0Booooo`;oogl0;_ooool1o`00007ooooo00000ol0003o
ooooooooo`2Nooooo`;o003o=Oooool00ol00?ooooooooooo`0Booooo`Coogl0;Oooool1o`00007o
oooo00000ol0003oooooooooo`2Mooooo`03o`00oooooooooooo01Gooooo1?l00?lLooooo`03o`00
ooooO`3oogl001;ooooo1?ooO`0]ooooo`7o00000Oooool00003o`000?oooooooooo09cooooo00?o
003oooooooooool05Oooool6o`00oa[ooooo00?o003ooomo0?ooO`000_ooO`0Booooo`;oogl0;_oo
ool1o`00007ooooo00000ol0003oooooooooo`2Kooooo`03o`00oooooooooooo01Gooooo2?l00?lH
ooooo`03o`00ooooooooogl000?oogl0@_ooool1o`00007ooooo00000ol0003oooooooooo`2Koooo
o`03o`00oooooooooooo01Gooooo2?l00?lGooooo`04o`00ooooooooooooooooo`;oogl0@oooool1
o`00007ooooo00000ol0003oooooooooo`2Jooooo`03o`00oooooooooooo01Kooooo2?l00?lFoooo
o`03o`00oooooooooooo04Oooooo0Ol00001ooooo`0000?o0000ooooooooool0VOooool00ol00?oo
ooooooooo`0<ooooo`;oogl02?ooool00oooO`3o003oo`00o`06o`00oaGooooo00?o003ooooooooo
ool00_ooO`16ooooo`7o00000Oooool00003o`000?oooooooooo09Wooooo00?o003oooooooooool0
2_ooool5oomo00Oooooo0_ooO`06o`00oa?ooooo0_ooO`000ol00?ooooooooooo`04oomo04Gooooo
0Ol00001ooooo`0000?o0000ooooooooool0V?ooool00ol00?ooooooooooo`0:ooooo`Koogl02?oo
ool2oomo00Co003o4oooool2oomo00;o003o0_ooool4oomo04Gooooo0Ol00001ooooo`0000?o0000
ooooooooool0V?ooool00ol00?ooooooooooo`0:ooooo`Googl08_ooool01?ooO`3o003ooomo0?oo
O`03ooooo`;oogl0A_ooool1o`00007ooooo00000ol0003oooooooooo`1fooooo`;oogl07oooool0
0ol00?ooooooooooo`0<ooooo`;oogl09?ooool00ol00?ooogl0oomo001<ooooo`7o00000Oooool0
0003o`000?oooooooooo07Gooooo1?ooO`0Nooooo`03o`00oooooooooooo037ooooo00?o003ooooo
ooooool0COooool1o`00007ooooo00000ol0003oooooooooo`1eooooo`Coogl02_ooool2oomo017o
oooo00?o003oooooooooool0<Oooool00ol00?ooooooooooo`1>ooooo`7o00000Oooool00003o`00
0?oooooooooo07Kooooo0_ooO`0:ooooo`Coogl03oooool00ol00?ooooooooooo`0Hooooo`;oogl0
5oooool00ol00?ooooooooooo`1?ooooo`7o00000Oooool00003o`000?oooooooooo08;ooooo1?oo
O`0?ooooo`03o`00oooooooooooo01Oooooo1?ooO`0Dooooo`;o003oD_ooool1o`00007ooooo0000
0ol0003oooooooooo`23ooooo`;oogl03oooool00ol00?ooooooooooo`0Booooo`;oogl01?ooool4
oomo017ooooo0ol00?mDooooo`7o00000Oooool00003o`000?oooooooooo09Cooooo00?o003ooooo
ooooool04Oooool4oomo00Cooooo0_ooO`0@ooooo`;o003oEoooool1o`00007ooooo00000ol0003o
ooooooooo`2Dooooo`03o`00oooooooooooo017ooooo1?ooO`0Eooooo`03o`00oooooooooooo05Oo
oooo0Ol00001ooooo`0000?o0000ooooooooool0U?ooool00ol00?ooooooooooo`0Booooo`;oogl0
5?ooool2o`00oe[ooooo0Ol00001ooooo`0000?o0000ooooooooool0U?ooool00ol00?oooooooooo
o`0Vooooo`;o003oG?ooool1o`00007ooooo00000ol0003oooooooooo`2Eooooo`03o`00oooooooo
oooo02Cooooo00?o003oooooooooool0G?ooool1o`00007ooooo00000ol0003oooooooooo`2Eoooo
o`03o`00oooooooooooo02;ooooo0_l00?mOooooo`7o00000Oooool00003o`000?oooooooooo09Go
oooo00?o003oooooooooool08?ooool2o`00of7ooooo0Ol00001ooooo`0000?o0000ooooooooool0
Q?ooool2oomo00oooooo0_l00?lOooooo`;o003oHoooool1o`00007ooooo00000ol0003ooooooooo
o`23ooooo`Coogl04?ooool2o`00oa[ooooo0ol00?mUooooo`7o00000Oooool00003o`000?oooooo
oooo08?ooooo1?ooO`0Booooo`;o003o5?ooool4o`00ofSooooo0Ol00001ooooo`0000?o0000oooo
ooooool0Q?ooool2oomo01Gooooo0ol00?l>ooooo`?o003o0oooool2oomo06Oooooo0Ol00001oooo
o`0000?o0000ooooooooool0W_ooool3o`00o`Gooooo1_l00?l5ooooo`Coogl0I_ooool1o`00007o
oooo00000ol0003oooooooooo`2Qooooo`Go003o2oooool4oomo06Kooooo0Ol00001ooooo`0000?o
0000ooooooooool0/_ooool2oomo06Oooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolL
ooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003o
ooooooooo`1kooooo`;oogl0W_ooool1o`00007ooooo00000ol0003oooooooooo`1jooooo`Coogl0
WOooool1o`00007ooooo00000ol0003oooooooooo`1jooooo`Coogl08?ooool2oomo07_ooooo0Ol0
0001ooooo`0000?o0000ooooooooool0Noooool2oomo023ooooo1?ooO`1jooooo`7o00000Oooool0
0003o`000?oooooooooo09gooooo1?ooO`1jooooo`7o00000Oooool00003o`000?oooooooooo093o
oooo0_ooO`0<ooooo`;oogl0Noooool1o`00007ooooo00000ol0003oooooooooo`2?ooooo`Coogl0
R?ooool1o`00007ooooo00000ol0003oooooooooo`2?ooooo`Coogl0R?ooool1o`00007ooooo0000
0ol0003oooooooooo`2@ooooo`;oogl08oooool2oomo06Cooooo0Ol00001ooooo`0000?o0000oooo
ooooool0]?ooool4oomo06?ooooo0Ol00001ooooo`0000?o0000ooooooooool0]?ooool4oomo06?o
oooo0Ol00001ooooo`0000?o0000ooooooooool0]Oooool2oomo06Cooooo0Ol00001ooooo`0000?o
0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1
o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000oooooooo
ool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo
00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolL
ooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003o
ooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o0000
0Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3o
oooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003
o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo
0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oooooo
oooo0?oooooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001oooo
o`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo
7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000
ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00
007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0
oooooolLooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo0000
0ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLoooo
o`7o00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003ooooo
ooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Ooo
ool00003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooo
oacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`00
0?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol0
0001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo
08kooooo0_ooO`2;ooooo`7o00000Oooool00003o`000?oooooooooo08gooooo1?ooO`2:ooooo`7o
00000Oooool00003o`000?oooooooooo08gooooo1?ooO`2:ooooo`7o00000Oooool00003o`000?oo
oooooooo08kooooo0_ooO`2;ooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1
o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000oooooooo
ool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo
00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolL
ooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003o
ooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o0000
0Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3o
oooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003
o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo
0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oooooo
oooo0?oooooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001oooo
o`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo
7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000
ooooooooool0oooooolLooooo`7o00000Oooool00?oo00008?l00001ooooo`00\
\>"],
  ImageRangeCache->{{{0, 287}, {287, 0}} -> {-1.01089, -1.01089, 0.00704453, \
0.00704453}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.49505 0.5 0.49505 [
[ 0 0 -0.125 0 ]
[ 0 0 -0.125 0 ]
[ 0 1 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
0 0 m
1 0 L
s
0 0 m
0 1 L
s
0 1 m
1 1 L
s
1 0 m
1 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
1 .5 0 r
.015 w
.03175 .1355 Mdot
.03435 .12523 Mdot
.11137 .12765 Mdot
.14107 .18841 Mdot
.16218 .24538 Mdot
.17294 .21053 Mdot
.18267 .18577 Mdot
.18434 .1304 Mdot
.18553 .30956 Mdot
.20401 .239 Mdot
.21247 .27571 Mdot
.21687 .20845 Mdot
.22376 .2799 Mdot
.22832 .27485 Mdot
.29063 .20974 Mdot
.29686 .25079 Mdot
.30487 .22936 Mdot
.30683 .34623 Mdot
.32055 .20902 Mdot
.32574 .21979 Mdot
.34472 .28521 Mdot
.35998 .36393 Mdot
.36335 .24976 Mdot
.3794 .36608 Mdot
.42386 .66992 Mdot
.44391 .74519 Mdot
.45059 .34198 Mdot
.47208 .67586 Mdot
.47436 .71381 Mdot
.49778 .59825 Mdot
.50874 .91643 Mdot
.51516 .76219 Mdot
.53655 .61374 Mdot
.56563 .75219 Mdot
.59189 .65665 Mdot
.59581 .61604 Mdot
.59923 .6556 Mdot
.60292 .68499 Mdot
.62656 .67779 Mdot
.63555 .72451 Mdot
.63919 .652 Mdot
.64169 .6004 Mdot
.64246 .58611 Mdot
.64496 .54267 Mdot
.64608 .77288 Mdot
.65077 .64308 Mdot
.66065 .57816 Mdot
.67474 .59169 Mdot
.69296 .563 Mdot
.72815 .65902 Mdot
.73169 .58879 Mdot
.74669 .61318 Mdot
.74821 .65474 Mdot
.75963 .63781 Mdot
.79673 .57809 Mdot
.80925 .55852 Mdot
.81525 .58444 Mdot
.83417 .62985 Mdot
.83598 .55526 Mdot
.91595 .49319 Mdot
1 0 0 r
.005 w
.16128 .17044 m
.18734 .17269 L
.21339 .17909 L
.2345 .18734 L
.23945 .19126 L
.2655 .20415 L
.27874 .21339 L
.29156 .22295 L
.31204 .23945 L
.31761 .24532 L
.33549 .2655 L
.34367 .28341 L
.34499 .29156 L
.34367 .29798 L
.31761 .3104 L
.29156 .30711 L
.2655 .30014 L
.24507 .29156 L
.23945 .28747 L
.21339 .27402 L
.20155 .2655 L
.18734 .25472 L
.16884 .23945 L
.16128 .2313 L
.14618 .21339 L
.13806 .18734 L
.16128 .17044 L
s
0 0 1 r
.65633 .57701 m
.68239 .56842 L
.70844 .56313 L
.7345 .56168 L
.76055 .5752 L
.76359 .57817 L
.76859 .60422 L
.76055 .62333 L
.75627 .63028 L
.7345 .65485 L
.73298 .65633 L
.70844 .6775 L
.69922 .68239 L
.68239 .69294 L
.65633 .70579 L
.64983 .70844 L
.63028 .71539 L
.60422 .72268 L
.57817 .72651 L
.55211 .7214 L
.53145 .70844 L
.52926 .68239 L
.54239 .65633 L
.55211 .63983 L
.56625 .63028 L
.57817 .6193 L
.60119 .60422 L
.60422 .60227 L
.63028 .58726 L
.65315 .57817 L
.65633 .57701 L
s
1 0 0 r
.03 w
.24141 .24033 Mdot
0 0 1 r
.64872 .64417 Mdot
1 0 0 r
.79703 .00495 m
.79703 .00495 L
.87129 .00495 L
.87129 .00495 L
F
0 0 1 r
.89604 .00495 m
.89604 .25248 L
.9703 .25248 L
.9703 .00495 L
F
1 0 1 r
.04 w
.72815 .65902 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P000182000`400?l00000o`00003ooooooolQ
ooooo`00ool0000Po`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`00
00?o0000ooooooooool0o_oooolEo`00o`Sooooo0Ol00001ooooo`0000?o0000ooooooooool0o_oo
oolEo`00o`Sooooo0Ol00001ooooo`0000?o0000ooooooooool0o_oooolEo`00o`Sooooo0Ol00001
ooooo`0000?o0000ooooooooool0o_oooolEo`00o`Sooooo0Ol00001ooooo`0000?o0000oooooooo
ool0o_oooolEo`00o`Sooooo0Ol00001ooooo`0000?o0000ooooooooool0o_oooolEo`00o`Sooooo
0Ol00001ooooo`0000?o0000ooooooooool0o_oooolEo`00o`Sooooo0Ol00001ooooo`0000?o0000
ooooooooool0o_oooolEo`00o`Sooooo0Ol00001ooooo`0000?o0000ooooooooool0o_oooolEo`00
o`Sooooo0Ol00001ooooo`0000?o0000ooooooooool0o_oooolEo`00o`Sooooo0Ol00001ooooo`00
00?o0000ooooooooool0o_oooolEo`00o`Sooooo0Ol00001ooooo`0000?o0000ooooooooool0o_oo
oolEo`00o`Sooooo0Ol00001ooooo`0000?o0000ooooooooool0o_oooolEo`00o`Sooooo0Ol00001
ooooo`0000?o0000ooooooooool0o_oooolEo`00o`Sooooo0Ol00001ooooo`0000?o0000oooooooo
ool0o_oooolEo`00o`Sooooo0Ol00001ooooo`0000?o0000ooooooooool0o_oooolEo`00o`Sooooo
0Ol00001ooooo`0000?o0000ooooooooool0o_oooolEo`00o`Sooooo0Ol00001ooooo`0000?o0000
ooooooooool0o_oooolEo`00o`Sooooo0Ol00001ooooo`0000?o0000ooooooooool0o_oooolEo`00
o`Sooooo0Ol00001ooooo`0000?o0000ooooooooool0o_oooolEo`00o`Sooooo0Ol00001ooooo`00
00?o0000ooooooooool0o_oooolEo`00o`Sooooo0Ol00001ooooo`0000?o0000ooooooooool0o_oo
oolEo`00o`Sooooo0Ol00001ooooo`0000?o0000ooooooooool0o_oooolEo`00o`Sooooo0Ol00001
ooooo`0000?o0000ooooooooool0o_oooolEo`00o`Sooooo0Ol00001ooooo`0000?o0000oooooooo
ool0o_oooolEo`00o`Sooooo0Ol00001ooooo`0000?o0000ooooooooool0o_oooolEo`00o`Sooooo
0Ol00001ooooo`0000?o0000ooooooooool0o_oooolEo`00o`Sooooo0Ol00001ooooo`0000?o0000
ooooooooool0o_oooolEo`00o`Sooooo0Ol00001ooooo`0000?o0000ooooooooool0o_oooolEo`00
o`Sooooo0Ol00001ooooo`0000?o0000ooooooooool0o_oooolEo`00o`Sooooo0Ol00001ooooo`00
00?o0000ooooooooool0o_oooolEo`00o`Sooooo0Ol00001ooooo`0000?o0000ooooooooool0o_oo
oolEo`00o`Sooooo0Ol00001ooooo`0000?o0000ooooooooool01_ooool2oomo0?Kooooo5Ol00?l8
ooooo`7o00000Oooool00003o`000?oooooooooo00Gooooo1?ooO`0Cooooo`;oogl0h?oooolEo`00
o`Sooooo0Ol00001ooooo`0000?o0000ooooooooool01Oooool4oomo01;ooooo1?ooO`0Booooo`;o
ogl0booooolEo`00o`Sooooo0Ol00001ooooo`0000?o0000ooooooooool01Oooool3oomo01?ooooo
1?ooO`0Aooooo`Coogl0b_oooolEo`00o`Sooooo0Ol00001ooooo`0000?o0000ooooooooool01?oo
ool4oomo01Cooooo0_ooO`0Booooo`Coogl0b_oooolEo`00o`Sooooo0Ol00001ooooo`0000?o0000
ooooooooool01?ooool4oomo02Wooooo0_ooO`3;oooooaGo003o2?ooool1o`00007ooooo00000ol0
003oooooooooo`05ooooo`;oogl0mooooolEo`00o`Sooooo0Ol00001ooooo`0000?o0000oooooooo
ool0o_oooolEo`00o`Sooooo0Ol00001ooooo`0000?o0000ooooooooool0o_oooolEo`00o`Sooooo
0Ol00001ooooo`0000?o0000ooooooooool0o_oooolEo`00o`Sooooo0Ol00001ooooo`0000?o0000
ooooooooool0o_oooolEo`00o`Sooooo0Ol00001ooooo`0000?o0000ooooooooool0o_oooolEo`00
o`Sooooo0Ol00001ooooo`0000?o0000ooooooooool0o_oooolEo`00o`Sooooo0Ol00001ooooo`00
00?o0000ooooooooool0o_oooolEo`00o`Sooooo0Ol00001ooooo`0000?o0000ooooooooool0:_oo
ool6ool00<kooooo5Ol00?l8ooooo`7o00000Oooool00003o`000?oooooooooo02Wooooo00?oo`00
ooooooooool01?ooool5ool00<Wooooo5Ol00?l8ooooo`7o00000Oooool00003o`000?oooooooooo
02Oooooo0_oo000<ooooo`Coo`00aOoooolEo`00o`Sooooo0Ol00001ooooo`0000?o0000oooooooo
ool09_ooool00ooo003oooooooooo`0@ooooo`Coo`00`OoooolEo`00o`Sooooo0Ol00001ooooo`00
00?o0000ooooooooool09?ooool00oooO`3oo`00ooooo`09ooooo`;oogl02oooool3ool00;kooooo
5Ol00?l8ooooo`7o00000Oooool00003o`000?oooooooooo02?ooooo00Coogl0ool00?ooO`3oogl0
2?ooool4oomo00gooooo00?oo`00ooooooooool0^ooooolEo`00o`Sooooo0Ol00001ooooo`0000?o
0000ooooooooool08oooool01?ooO`3oo`00oomo0?ooO`08ooooo`Coogl03_ooool2ool00;_ooooo
5Ol00?l8ooooo`7o00000Oooool00003o`000?oooooooooo02Cooooo00?oogl0ool00?ooool02Ooo
ool2oomo017ooooo0_oo002ioooooaGo003o2?ooool1o`00007ooooo00000ol0003oooooooooo`0U
ooooo`03ool00?oooooooooo01gooooo0_oo002goooooaGo003o2?ooool1o`00007ooooo00000ol0
003oooooooooo`0Uooooo`03ool00?oooooooooo01oooooo0_oo002eoooooaGo003o2?ooool1o`00
007ooooo00000ol0003oooooooooo`0Vooooo`03ool00?oooooooooo017ooooo0_ooO`0=ooooo`;o
o`001?ooool2oomo00Oooooo0_ooO`2ToooooaGo003o2?ooool1o`00007ooooo00000ol0003ooooo
ooooo`0Vooooo`03ool00?oooooooooo00Gooooo0_ooO`09ooooo`Coogl03_ooool00ooo003ooooo
ooooo`04oomo00Gooooo1?ooO`2SoooooaGo003o2?ooool1o`00007ooooo00000ol0003ooooooooo
o`0Vooooo`03ool00?oooooooooo00Cooooo1?ooO`08ooooo`Coogl03oooool00ooo003ooooooomo
0003oomo00Gooooo1?ooO`2SoooooaGo003o2?ooool1o`00007ooooo00000ol0003oooooooooo`0W
ooooo`03ool00?oooooooooo00?ooooo1?ooO`09ooooo`;oogl04Oooool01?oo003ooooooomo0?oo
O`07ooooo`?oogl0XooooolEo`00o`Sooooo0Ol00001ooooo`0000?o0000ooooooooool09oooool0
0ooo003oooooooooo`04ooooo`;oogl07_ooool00ooo003oooooooooo`07ooooo`Coogl0X_oooolE
o`00o`Sooooo0Ol00001ooooo`0000?o0000ooooooooool0:?ooool00ooo003oooooooooo`0Toooo
o`03ool00?oooooooooo00Kooooo1?ooO`2RoooooaGo003o2?ooool1o`00007ooooo00000ol0003o
ooooooooo`0Yooooo`03ool00?oooooooooo02Cooooo0_oo00000oooooooogl0oomo0004ooooo`;o
ogl0XooooolEo`00o`Sooooo0Ol00001ooooo`0000?o0000ooooooooool0:_ooool00ooo003ooooo
ooooo`0Cooooo`Coo`003_ooool01?oo003oogl0oomo0?ooO`2XoooooaGo003o2?ooool1o`00007o
oooo00000ol0003oooooooooo`0[ooooo`03ool00?oooooooooo017ooooo1_oo000=ooooo`04oomo
0?oo003oo`00oomo0:Sooooo5Ol00?l8ooooo`7o00000Oooool00003o`000?oooooooooo02cooooo
00?oo`00ooooooooool02?ooool2oomo00Gooooo2?oo000=ooooo`;oogl000?oo`00ooooooooool0
Y_oooolEo`00o`Sooooo0Ol00001ooooo`0000?o0000ooooooooool0;Oooool00ooo003ooooooooo
o`06ooooo`Coogl01?ooool8ool0013ooooo00?oo`00ooooooooool0YOoooolEo`00o`Sooooo0Ol0
0001ooooo`0000?o0000ooooooooool0:oooool2oomo0003oooooooo003ooooo00Kooooo1?ooO`04
ooooo`Soo`004Oooool00ooo003oooooooooo`2ToooooaGo003o2?ooool1o`00007ooooo00000ol0
003oooooooooo`0Zooooo`Coogl000?oooooool00?ooool01_ooool2oomo00Gooooo2?oo000;oooo
o`;oogl01Oooool00ooo003oooooooooo`09ooooo`;oogl0V?oooolEo`00o`Sooooo0Ol00001oooo
o`0000?o0000ooooooooool0:_ooool4oomo00;ooooo00?oo`00ooooooooool03?ooool6ool000_o
oooo1?ooO`04ooooo`03ool00?oooooooooo00Sooooo1?ooO`2GoooooaGo003o2?ooool1o`00007o
oooo00000ol0003oooooooooo`0[ooooo`;oogl01?ooool00ooo003oooooooooo`0<ooooo`Coo`00
3?ooool4oomo00Gooooo00?oo`00ooooooooool01oooool4oomo09Oooooo5Ol00?l8ooooo`7o0000
0Oooool00003o`000?oooooooooo03;ooooo0_oo000Mooooo`;oogl01oooool00ooo003ooooooooo
o`07ooooo`;oogl0]Oooool1o`00007ooooo00000ol0003oooooooooo`0dooooo`03ool00?oooooo
oooo02Cooooo00?oo`00ooooooooool0_Oooool1o`00007ooooo00000ol0003oooooooooo`0eoooo
o`03ool00?oooooooooo02Cooooo00?oo`00ooooooooool0_?ooool1o`00007ooooo00000ol0003o
ooooooooo`0fooooo`;oo`009Oooool00ooo003oooooooooo`2kooooo`7o00000Oooool00003o`00
0?oooooooooo03Sooooo0_oo00000oooO`3oooooooooo`02oomo01kooooo00?oo`00ooooooooool0
^oooool1o`00007ooooo00000ol0003oooooooooo`0hooooo`;oogl00_oo0004oomo01kooooo00?o
o`00ooooooooool0^_ooool1o`00007ooooo00000ol0003oooooooooo`0hooooo`Coogl00_oo0002
oomo01kooooo00?oo`00ooooooooool0^_ooool1o`00007ooooo00000ol0003oooooooooo`0ioooo
o`Googl000?oo`00ooooooooool07Oooool00ooo003oogl0oomo002jooooo`7o00000Oooool00003
o`000?oooooooooo03_ooooo1?ooO`02ool001gooooo00Coogl0ool00?ooO`3oogl0^Oooool1o`00
007ooooo00000ol0003oooooooooo`0looooo`;oogl00oooool2ool001_ooooo00Coogl0ool00?oo
O`3oogl0^Oooool1o`00007ooooo00000ol0003oooooooooo`13ooooo`;oo`006_ooool00oooO`3o
o`00ooooo`2iooooo`7o00000Oooool00003o`000?oooooooooo04Gooooo0_oo000Iooooo`03ool0
0?oooooooooo0;Sooooo0Ol00001ooooo`0000?o0000ooooooooool0Aoooool2ool001Gooooo0_oo
002kooooo`7o00000Oooool00003o`000?oooooooooo04Wooooo0ooo000@ooooo`;oo`00_Oooool1
o`00007ooooo00000ol0003oooooooooo`0aooooo`;oogl06Oooool3ool000cooooo00?oo`00oooo
ooooool0_Oooool1o`00007ooooo00000ol0003oooooooooo`0`ooooo`Coogl06oooool6ool000Co
oooo0_oo0030ooooo`7o00000Oooool00003o`000?oooooooooo033ooooo1?ooO`0Qooooo`Coo`00
`_ooool1o`00007ooooo00000ol0003oooooooooo`0aooooo`;oogl0j?ooool1o`00007ooooo0000
0ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLoooo
o`7o00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003ooooo
ooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Ooo
ool00003o`000?oooooooooo07gooooo0_ooO`2Looooo`7o00000Oooool00003o`000?oooooooooo
07cooooo1?ooO`2Kooooo`7o00000Oooool00003o`000?oooooooooo05Cooooo0_ooO`0Vooooo`Co
ogl0Voooool1o`00007ooooo00000ol0003oooooooooo`1Cooooo`Coogl09_ooool2oomo09cooooo
0Ol00001ooooo`0000?o0000ooooooooool0Doooool4oomo0<Cooooo0Ol00001ooooo`0000?o0000
ooooooooool0E?ooool2oomo0<Gooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLoooo
o`7o00000Oooool00003o`000?oooooooooo06?ooooo0_ooO`04ooooo`;oogl0/?ooool1o`00007o
oooo00000ol0003oooooooooo`1Rooooo`Coogl00_ooool4oomo0:oooooo0Ol00001ooooo`0000?o
0000ooooooooool0H_ooool4oomo00;ooooo1?ooO`2_ooooo`7o00000Oooool00003o`000?oooooo
oooo06?ooooo0_ooO`04ooooo`;oogl0/?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooo
oacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`00
0?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol0
0001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo
0?oooooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`00
00?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?oo
ool1o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000oooo
ooooool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007o
oooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooo
oolLooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0
003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o
00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003ooooooooo
o`3ooooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool0
0003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooooaco
oooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oo
oooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001
ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo0?oo
oooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o
0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1
o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000oooooooo
ool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo
00000ol0003oooooooooo`3oooooo`Cooooo0_ooO`0Fooooo`7o00000Oooool00003o`000?oooooo
oooo0?oooooo0oooool4oomo01Gooooo0Ol00001ooooo`0000?o0000ooooooooool0ooooool3oooo
o`Coogl05Oooool1o`00007ooooo00000ol0003oooooooooo`3oooooo`Cooooo0_ooO`0Fooooo`7o
00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003ooooooooo
o`3ooooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool0
0003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooooaco
oooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oo
oooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001
ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo0?oo
oooo7?ooool1o`00007ooooo00000ol0003oooooooooo`2eooooo`;oogl0I?ooool1o`00007ooooo
00000ol0003oooooooooo`2dooooo`Coogl0Hoooool1o`00007ooooo00000ol0003oooooooooo`2d
ooooo`Coogl0Hoooool1o`00007ooooo00000ol0003oooooooooo`2eooooo`;oogl0=Oooool2oomo
02gooooo0Ol00001ooooo`0000?o0000ooooooooool0i?ooool2oomo00Gooooo1?ooO`0/ooooo`7o
00000Oooool00003o`000?oooooooooo0>?ooooo1?ooO`04ooooo`Coogl0;?ooool1o`00007ooooo
00000ol0003oooooooooo`33ooooo`;oogl07_ooool4oomo00Gooooo0_ooO`0]ooooo`7o00000Ooo
ool00003o`000?oooooooooo0<;ooooo1?ooO`0;o`00oa?ooooo0_ooO`0eooooo`7o00000Oooool0
0003o`000?oooooooooo0<;ooooo1?l00?l;ooooo`;o003oB?ooool1o`00007ooooo00000ol0003o
ooooooooo`2nooooo`Co003o00?ooooooomo0?ooO`003_ooool2o`00odKooooo0Ol00001ooooo`00
00?o0000ooooooooool0^Oooool2oomo00?o003o5oooool2o`00o`Wooooo0_ooO`0iooooo`7o0000
0Oooool00003o`000?oooooooooo0;Oooooo1?l00?l00oooO`3oooooooooo`0Iooooo`;o003o1_oo
ool4oomo03Sooooo0Ol00001ooooo`0000?o0000ooooooooool0]?ooool3o`00o`03ooooooooO`3o
ogl000;oogl07?ooool00ol00?ooooooooooo`04ooooo`Coogl00oooool2oomo03?ooooo0Ol00001
ooooo`0000?o0000ooooooooool0/_ooool2o`00o`?oogl00_ooool2oomo01?ooooo0_ooO`08oooo
o`03o`00oooooooooooo00Gooooo0_ooO`03ooooo`Coogl0<_ooool1o`00007ooooo00000ol0003o
ooooooooo`2`ooooo`;o003o00?ooooooomo0?ooO`000_ooO`06ooooo`;oogl03_ooool4oomo00Oo
oooo00?o003oooooooooool02_ooool4oomo03;ooooo0Ol00001ooooo`0000?o0000ooooooooool0
[_ooool2o`00o`Cooooo0_ooO`06ooooo`Coogl03Oooool4oomo00Oooooo00?o003oooooooooool0
2oooool2oomo03?ooooo0Ol00001ooooo`0000?o0000ooooooooool0Roooool2oomo023ooooo00?o
003oooooooooool01?ooool2oomo00Kooooo1?ooO`0>ooooo`;oogl02Oooool00ol00?oooooooooo
o`0oooooo`7o00000Oooool00003o`000?oooooooooo08[ooooo1?ooO`0Mooooo`;o003o1_ooool4
oomo00Kooooo0_ooO`0Jooooo`03o`00oooooooooooo03oooooo0Ol00001ooooo`0000?o0000oooo
ooooool0R_ooool4oomo01cooooo00?o003oooooooooool01_ooool4oomo02;ooooo00?o003ooooo
ooooool0?oooool1o`00007ooooo00000ol0003oooooooooo`2;ooooo`;oogl06oooool2o`00o`[o
oooo0_ooO`0Sooooo`03o`00oooooooooooo03oooooo0Ol00001ooooo`0000?o0000ooooooooool0
U_ooool2oomo00kooooo0_l00?lZooooo`;oogl01Oooool00ol00?ooooooooooo`0oooooo`7o0000
0Oooool00003o`000?oooooooooo09Gooooo1?ooO`0<ooooo`04o`00ooooooooogl0oomo02Sooooo
1?ooO`03ooooo`03o`00oooooooooooo043ooooo0Ol00001ooooo`0000?o0000ooooooooool0UOoo
ool4oomo00[ooooo0_l00?l00oooooooogl0oomo0002oomo02Oooooo1?ooO`03ooooo`03o`00oooo
oooooooo043ooooo0Ol00001ooooo`0000?o0000ooooooooool0U_ooool2oomo00[ooooo00Co003o
oooooooooooooooo1?ooO`0Xooooo`;oogl01?ooool00ol00?ooooooooooo`10ooooo`7o00000Ooo
ool00003o`000?oooooooooo0:7ooooo00?o003oooooooooool00oooool2oomo02kooooo00?o003o
ooooooooool0@Oooool1o`00007ooooo00000ol0003oooooooooo`2Pooooo`03o`00oooooooooooo
03?ooooo00?o003oooooooooool04_ooool2oomo02kooooo0Ol00001ooooo`0000?o0000oooooooo
ool0W_ooool2o`00ocGooooo00?o003oooooooooool04_ooool4oomo02gooooo0Ol00001ooooo`00
00?o0000ooooooooool0WOooool00ol00?ooooooooooo`0Eooooo`Co003o7?ooool00ol00?ooogl0
oomo000Booooo`Coogl0;Oooool1o`00007ooooo00000ol0003oooooooooo`2Looooo`03o`00oooo
oooooooo01Gooooo1_l00?lJooooo`03o`00ooooO`3oogl000;oogl04_ooool2oomo02kooooo0Ol0
0001ooooo`0000?o0000ooooooooool0Voooool00ol00?ooooooooooo`0Eooooo`So003o6?ooool0
0ol00?oooooooomo0003oomo04;ooooo0Ol00001ooooo`0000?o0000ooooooooool0Voooool00ol0
0?ooooooooooo`0Eooooo`So003o4?ooool5ool0o`;ooooo00Co003ooooooooooooooooo0_ooO`13
ooooo`7o00000Oooool00003o`000?oooooooooo09[ooooo00?o003oooooooooool05_ooool8o`00
o`oooooo1ooo0?l00ol00?ooooooooooo`17ooooo`7o00000Oooool00003o`000?oooooooooo09Wo
oooo00?o003oooooooooool03?ooool2oomo00Sooooo00?oogl0o`00ool00?l01_l00?l>ooooo`Wo
o`3o00?ooooooomo0?ooO`00A_ooool1o`00007ooooo00000ol0003oooooooooo`2Iooooo`03o`00
oooooooooooo00[ooooo1OooO`07ooooo`;oogl01_l00?l>ooooo`_oo`3o0oooO`15ooooo`7o0000
0Oooool00003o`000?oooooooooo09Sooooo00?o003oooooooooool02_ooool6oomo00Sooooo0_oo
O`04o`00o`oooooo2ooo0?l3oomo04Gooooo0Ol00001ooooo`0000?o0000ooooooooool0V?ooool0
0ol00?ooooooooooo`0:ooooo`Googl07_ooool;ool0o`;oogl0A_ooool1o`00007ooooo00000ol0
003oooooooooo`1fooooo`;oogl07oooool00ol00?ooooooooooo`0<ooooo`;oogl08?ooool;ool0
odSooooo0Ol00001ooooo`0000?o0000ooooooooool0MOooool4oomo01kooooo00?o003ooooooooo
ool0;_ooool;ool0odSooooo0Ol00001ooooo`0000?o0000ooooooooool0MOooool4oomo00[ooooo
0_ooO`0Aooooo`03o`00oooooooooooo033ooooo2Ooo0?m9ooooo`7o00000Oooool00003o`000?oo
oooooooo07Kooooo0_ooO`0:ooooo`Coogl03oooool00ol00?ooooooooooo`0Hooooo`;oogl05ooo
ool00ol00?ooo`3oool0o`05ool0od[ooooo0Ol00001ooooo`0000?o0000ooooooooool0P_ooool4
oomo00oooooo00?o003oooooooooool05oooool4oomo01Cooooo0_l00?l2ooooo`Goo`3oBoooool1
o`00007ooooo00000ol0003oooooooooo`23ooooo`;oogl03oooool00ol00?ooooooooooo`0Boooo
o`;oogl01?ooool4oomo017ooooo0ol00?mDooooo`7o00000Oooool00003o`000?oooooooooo09Co
oooo00?o003oooooooooool04Oooool4oomo00Cooooo0_ooO`0@ooooo`;o003oEoooool1o`00007o
oooo00000ol0003oooooooooo`2Dooooo`03o`00oooooooooooo017ooooo1?ooO`0Eooooo`03o`00
oooooooooooo05Oooooo0Ol00001ooooo`0000?o0000ooooooooool0U?ooool00ol00?oooooooooo
o`0Booooo`;oogl05?ooool2o`00oe[ooooo0Ol00001ooooo`0000?o0000ooooooooool0U?ooool0
0ol00?ooooooooooo`0Vooooo`;o003oG?ooool1o`00007ooooo00000ol0003oooooooooo`2Eoooo
o`03o`00oooooooooooo02Cooooo00?o003oooooooooool0G?ooool1o`00007ooooo00000ol0003o
ooooooooo`2Eooooo`03o`00oooooooooooo02;ooooo0_l00?mOooooo`7o00000Oooool00003o`00
0?oooooooooo09Gooooo00?o003oooooooooool08?ooool2o`00of7ooooo0Ol00001ooooo`0000?o
0000ooooooooool0Q?ooool2oomo00oooooo0_l00?lOooooo`;o003oHoooool1o`00007ooooo0000
0ol0003oooooooooo`23ooooo`Coogl04?ooool2o`00oa[ooooo0ol00?mUooooo`7o00000Oooool0
0003o`000?oooooooooo08?ooooo1?ooO`0Booooo`;o003o5?ooool4o`00ofSooooo0Ol00001oooo
o`0000?o0000ooooooooool0Q?ooool2oomo01Gooooo0ol00?l>ooooo`?o003o0oooool2oomo06Oo
oooo0Ol00001ooooo`0000?o0000ooooooooool0W_ooool3o`00o`Gooooo1_l00?l5ooooo`Coogl0
I_ooool1o`00007ooooo00000ol0003oooooooooo`2Qooooo`Go003o2oooool4oomo06Kooooo0Ol0
0001ooooo`0000?o0000ooooooooool0/_ooool2oomo06Oooooo0Ol00001ooooo`0000?o0000oooo
ooooool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007o
oooo00000ol0003oooooooooo`1kooooo`;oogl0W_ooool1o`00007ooooo00000ol0003ooooooooo
o`1jooooo`Coogl0WOooool1o`00007ooooo00000ol0003oooooooooo`1jooooo`Coogl08?ooool2
oomo07_ooooo0Ol00001ooooo`0000?o0000ooooooooool0Noooool2oomo023ooooo1?ooO`1joooo
o`7o00000Oooool00003o`000?oooooooooo09gooooo1?ooO`1jooooo`7o00000Oooool00003o`00
0?oooooooooo093ooooo0_ooO`0<ooooo`;oogl0Noooool1o`00007ooooo00000ol0003ooooooooo
o`2?ooooo`Coogl0R?ooool1o`00007ooooo00000ol0003oooooooooo`2?ooooo`Coogl0R?ooool1
o`00007ooooo00000ol0003oooooooooo`2@ooooo`;oogl08oooool2oomo06Cooooo0Ol00001oooo
o`0000?o0000ooooooooool0]?ooool4oomo06?ooooo0Ol00001ooooo`0000?o0000ooooooooool0
]?ooool4oomo06?ooooo0Ol00001ooooo`0000?o0000ooooooooool0]Oooool2oomo06Cooooo0Ol0
0001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo
0?oooooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`00
00?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?oo
ool1o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000oooo
ooooool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007o
oooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooo
oolLooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0
003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o
00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003ooooooooo
o`3ooooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool0
0003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooooaco
oooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oo
oooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001
ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo0?oo
oooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o
0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1
o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000oooooooo
ool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo
00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolL
ooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003o
ooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o0000
0Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3o
oooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003
o`000?oooooooooo08kooooo0_ooO`2;ooooo`7o00000Oooool00003o`000?oooooooooo08gooooo
1?ooO`2:ooooo`7o00000Oooool00003o`000?oooooooooo08gooooo1?ooO`2:ooooo`7o00000Ooo
ool00003o`000?oooooooooo08kooooo0_ooO`2;ooooo`7o00000Oooool00003o`000?oooooooooo
0?oooooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`00
00?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?oo
ool1o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000oooo
ooooool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007o
oooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooo
oolLooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0
003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o
00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003ooooooooo
o`3ooooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool0
0003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooooaco
oooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oo
oooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001
ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool00?oo00008?l00001ooooo`00
\
\>"],
  ImageRangeCache->{{{0, 287}, {287, 0}} -> {-1.01089, -1.01089, 0.00704453, \
0.00704453}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.49505 0.5 0.49505 [
[ 0 0 -0.125 0 ]
[ 0 0 -0.125 0 ]
[ 0 1 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
0 0 m
1 0 L
s
0 0 m
0 1 L
s
0 1 m
1 1 L
s
1 0 m
1 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
1 .5 0 r
.015 w
.03175 .1355 Mdot
.03435 .12523 Mdot
.11137 .12765 Mdot
.14107 .18841 Mdot
.16218 .24538 Mdot
.17294 .21053 Mdot
.18267 .18577 Mdot
.18434 .1304 Mdot
.18553 .30956 Mdot
.20401 .239 Mdot
.21247 .27571 Mdot
.21687 .20845 Mdot
.22376 .2799 Mdot
.22832 .27485 Mdot
.29063 .20974 Mdot
.29686 .25079 Mdot
.30487 .22936 Mdot
.30683 .34623 Mdot
.32055 .20902 Mdot
.32574 .21979 Mdot
.34472 .28521 Mdot
.35998 .36393 Mdot
.36335 .24976 Mdot
.3794 .36608 Mdot
.42386 .66992 Mdot
.44391 .74519 Mdot
.45059 .34198 Mdot
.47208 .67586 Mdot
.47436 .71381 Mdot
.49778 .59825 Mdot
.50874 .91643 Mdot
.51516 .76219 Mdot
.53655 .61374 Mdot
.56563 .75219 Mdot
.59189 .65665 Mdot
.59581 .61604 Mdot
.59923 .6556 Mdot
.60292 .68499 Mdot
.62656 .67779 Mdot
.63555 .72451 Mdot
.63919 .652 Mdot
.64169 .6004 Mdot
.64246 .58611 Mdot
.64496 .54267 Mdot
.64608 .77288 Mdot
.65077 .64308 Mdot
.66065 .57816 Mdot
.67474 .59169 Mdot
.69296 .563 Mdot
.72815 .65902 Mdot
.73169 .58879 Mdot
.74669 .61318 Mdot
.74821 .65474 Mdot
.75963 .63781 Mdot
.79673 .57809 Mdot
.80925 .55852 Mdot
.81525 .58444 Mdot
.83417 .62985 Mdot
.83598 .55526 Mdot
.91595 .49319 Mdot
1 0 0 r
.005 w
.16128 .17044 m
.18734 .17269 L
.21339 .17909 L
.2345 .18734 L
.23945 .19126 L
.2655 .20415 L
.27874 .21339 L
.29156 .22295 L
.31204 .23945 L
.31761 .24532 L
.33549 .2655 L
.34367 .28341 L
.34499 .29156 L
.34367 .29798 L
.31761 .3104 L
.29156 .30711 L
.2655 .30014 L
.24507 .29156 L
.23945 .28747 L
.21339 .27402 L
.20155 .2655 L
.18734 .25472 L
.16884 .23945 L
.16128 .2313 L
.14618 .21339 L
.13806 .18734 L
.16128 .17044 L
s
0 0 1 r
.65633 .57701 m
.68239 .56842 L
.70844 .56313 L
.7345 .56168 L
.76055 .5752 L
.76359 .57817 L
.76859 .60422 L
.76055 .62333 L
.75627 .63028 L
.7345 .65485 L
.73298 .65633 L
.70844 .6775 L
.69922 .68239 L
.68239 .69294 L
.65633 .70579 L
.64983 .70844 L
.63028 .71539 L
.60422 .72268 L
.57817 .72651 L
.55211 .7214 L
.53145 .70844 L
.52926 .68239 L
.54239 .65633 L
.55211 .63983 L
.56625 .63028 L
.57817 .6193 L
.60119 .60422 L
.60422 .60227 L
.63028 .58726 L
.65315 .57817 L
.65633 .57701 L
s
1 0 0 r
.03 w
.24141 .24033 Mdot
0 0 1 r
.64872 .64417 Mdot
1 0 0 r
.79703 .00495 m
.79703 .00495 L
.87129 .00495 L
.87129 .00495 L
F
0 0 1 r
.89604 .00495 m
.89604 .25247 L
.9703 .25247 L
.9703 .00495 L
F
1 0 1 r
.04 w
.73169 .58879 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P000182000`400?l00000o`00003ooooooolQ
ooooo`00ool0000Po`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`00
00?o0000ooooooooool0o_oooolEo`00o`Sooooo0Ol00001ooooo`0000?o0000ooooooooool0o_oo
oolEo`00o`Sooooo0Ol00001ooooo`0000?o0000ooooooooool0o_oooolEo`00o`Sooooo0Ol00001
ooooo`0000?o0000ooooooooool0o_oooolEo`00o`Sooooo0Ol00001ooooo`0000?o0000oooooooo
ool0o_oooolEo`00o`Sooooo0Ol00001ooooo`0000?o0000ooooooooool0o_oooolEo`00o`Sooooo
0Ol00001ooooo`0000?o0000ooooooooool0o_oooolEo`00o`Sooooo0Ol00001ooooo`0000?o0000
ooooooooool0o_oooolEo`00o`Sooooo0Ol00001ooooo`0000?o0000ooooooooool0o_oooolEo`00
o`Sooooo0Ol00001ooooo`0000?o0000ooooooooool0o_oooolEo`00o`Sooooo0Ol00001ooooo`00
00?o0000ooooooooool0o_oooolEo`00o`Sooooo0Ol00001ooooo`0000?o0000ooooooooool0o_oo
oolEo`00o`Sooooo0Ol00001ooooo`0000?o0000ooooooooool0o_oooolEo`00o`Sooooo0Ol00001
ooooo`0000?o0000ooooooooool0o_oooolEo`00o`Sooooo0Ol00001ooooo`0000?o0000oooooooo
ool0o_oooolEo`00o`Sooooo0Ol00001ooooo`0000?o0000ooooooooool0o_oooolEo`00o`Sooooo
0Ol00001ooooo`0000?o0000ooooooooool0o_oooolEo`00o`Sooooo0Ol00001ooooo`0000?o0000
ooooooooool0o_oooolEo`00o`Sooooo0Ol00001ooooo`0000?o0000ooooooooool0o_oooolEo`00
o`Sooooo0Ol00001ooooo`0000?o0000ooooooooool0o_oooolEo`00o`Sooooo0Ol00001ooooo`00
00?o0000ooooooooool0o_oooolEo`00o`Sooooo0Ol00001ooooo`0000?o0000ooooooooool0o_oo
oolEo`00o`Sooooo0Ol00001ooooo`0000?o0000ooooooooool0o_oooolEo`00o`Sooooo0Ol00001
ooooo`0000?o0000ooooooooool0o_oooolEo`00o`Sooooo0Ol00001ooooo`0000?o0000oooooooo
ool0o_oooolEo`00o`Sooooo0Ol00001ooooo`0000?o0000ooooooooool0o_oooolEo`00o`Sooooo
0Ol00001ooooo`0000?o0000ooooooooool0o_oooolEo`00o`Sooooo0Ol00001ooooo`0000?o0000
ooooooooool0o_oooolEo`00o`Sooooo0Ol00001ooooo`0000?o0000ooooooooool0o_oooolEo`00
o`Sooooo0Ol00001ooooo`0000?o0000ooooooooool0o_oooolEo`00o`Sooooo0Ol00001ooooo`00
00?o0000ooooooooool0o_oooolEo`00o`Sooooo0Ol00001ooooo`0000?o0000ooooooooool0o_oo
oolEo`00o`Sooooo0Ol00001ooooo`0000?o0000ooooooooool01_ooool2oomo0?Kooooo5Ol00?l8
ooooo`7o00000Oooool00003o`000?oooooooooo00Gooooo1?ooO`0Cooooo`;oogl0h?oooolEo`00
o`Sooooo0Ol00001ooooo`0000?o0000ooooooooool01Oooool4oomo01;ooooo1?ooO`0Booooo`;o
ogl0booooolEo`00o`Sooooo0Ol00001ooooo`0000?o0000ooooooooool01Oooool3oomo01?ooooo
1?ooO`0Aooooo`Coogl0b_oooolEo`00o`Sooooo0Ol00001ooooo`0000?o0000ooooooooool01?oo
ool4oomo01Cooooo0_ooO`0Booooo`Coogl0b_oooolEo`00o`Sooooo0Ol00001ooooo`0000?o0000
ooooooooool01?ooool4oomo02Wooooo0_ooO`3;oooooaGo003o2?ooool1o`00007ooooo00000ol0
003oooooooooo`05ooooo`;oogl0mooooolEo`00o`Sooooo0Ol00001ooooo`0000?o0000oooooooo
ool0o_oooolEo`00o`Sooooo0Ol00001ooooo`0000?o0000ooooooooool0o_oooolEo`00o`Sooooo
0Ol00001ooooo`0000?o0000ooooooooool0o_oooolEo`00o`Sooooo0Ol00001ooooo`0000?o0000
ooooooooool0o_oooolEo`00o`Sooooo0Ol00001ooooo`0000?o0000ooooooooool0o_oooolEo`00
o`Sooooo0Ol00001ooooo`0000?o0000ooooooooool0o_oooolEo`00o`Sooooo0Ol00001ooooo`00
00?o0000ooooooooool0o_oooolEo`00o`Sooooo0Ol00001ooooo`0000?o0000ooooooooool0:_oo
ool6ool00<kooooo5Ol00?l8ooooo`7o00000Oooool00003o`000?oooooooooo02Wooooo00?oo`00
ooooooooool01?ooool5ool00<Wooooo5Ol00?l8ooooo`7o00000Oooool00003o`000?oooooooooo
02Oooooo0_oo000<ooooo`Coo`00aOoooolEo`00o`Sooooo0Ol00001ooooo`0000?o0000oooooooo
ool09_ooool00ooo003oooooooooo`0@ooooo`Coo`00`OoooolEo`00o`Sooooo0Ol00001ooooo`00
00?o0000ooooooooool09?ooool00oooO`3oo`00ooooo`09ooooo`;oogl02oooool3ool00;kooooo
5Ol00?l8ooooo`7o00000Oooool00003o`000?oooooooooo02?ooooo00Coogl0ool00?ooO`3oogl0
2?ooool4oomo00gooooo00?oo`00ooooooooool0^ooooolEo`00o`Sooooo0Ol00001ooooo`0000?o
0000ooooooooool08oooool01?ooO`3oo`00oomo0?ooO`08ooooo`Coogl03_ooool2ool00;_ooooo
5Ol00?l8ooooo`7o00000Oooool00003o`000?oooooooooo02Cooooo00?oogl0ool00?ooool02Ooo
ool2oomo017ooooo0_oo002ioooooaGo003o2?ooool1o`00007ooooo00000ol0003oooooooooo`0U
ooooo`03ool00?oooooooooo01gooooo0_oo002goooooaGo003o2?ooool1o`00007ooooo00000ol0
003oooooooooo`0Uooooo`03ool00?oooooooooo01oooooo0_oo002eoooooaGo003o2?ooool1o`00
007ooooo00000ol0003oooooooooo`0Vooooo`03ool00?oooooooooo017ooooo0_ooO`0=ooooo`;o
o`001?ooool2oomo00Oooooo0_ooO`2ToooooaGo003o2?ooool1o`00007ooooo00000ol0003ooooo
ooooo`0Vooooo`03ool00?oooooooooo00Gooooo0_ooO`09ooooo`Coogl03_ooool00ooo003ooooo
ooooo`04oomo00Gooooo1?ooO`2SoooooaGo003o2?ooool1o`00007ooooo00000ol0003ooooooooo
o`0Vooooo`03ool00?oooooooooo00Cooooo1?ooO`08ooooo`Coogl03oooool00ooo003ooooooomo
0003oomo00Gooooo1?ooO`2SoooooaGo003o2?ooool1o`00007ooooo00000ol0003oooooooooo`0W
ooooo`03ool00?oooooooooo00?ooooo1?ooO`09ooooo`;oogl04Oooool01?oo003ooooooomo0?oo
O`07ooooo`?oogl0XooooolEo`00o`Sooooo0Ol00001ooooo`0000?o0000ooooooooool09oooool0
0ooo003oooooooooo`04ooooo`;oogl07_ooool00ooo003oooooooooo`07ooooo`Coogl0X_oooolE
o`00o`Sooooo0Ol00001ooooo`0000?o0000ooooooooool0:?ooool00ooo003oooooooooo`0Toooo
o`03ool00?oooooooooo00Kooooo1?ooO`2RoooooaGo003o2?ooool1o`00007ooooo00000ol0003o
ooooooooo`0Yooooo`03ool00?oooooooooo02Cooooo0_oo00000oooooooogl0oomo0004ooooo`;o
ogl0XooooolEo`00o`Sooooo0Ol00001ooooo`0000?o0000ooooooooool0:_ooool00ooo003ooooo
ooooo`0Cooooo`Coo`003_ooool01?oo003oogl0oomo0?ooO`2XoooooaGo003o2?ooool1o`00007o
oooo00000ol0003oooooooooo`0[ooooo`03ool00?oooooooooo017ooooo1_oo000=ooooo`04oomo
0?oo003oo`00oomo0:Sooooo5Ol00?l8ooooo`7o00000Oooool00003o`000?oooooooooo02cooooo
00?oo`00ooooooooool02?ooool2oomo00Gooooo2?oo000=ooooo`;oogl000?oo`00ooooooooool0
Y_oooolEo`00o`Sooooo0Ol00001ooooo`0000?o0000ooooooooool0;Oooool00ooo003ooooooooo
o`06ooooo`Coogl01?ooool8ool0013ooooo00?oo`00ooooooooool0YOoooolEo`00o`Sooooo0Ol0
0001ooooo`0000?o0000ooooooooool0:oooool2oomo0003oooooooo003ooooo00Kooooo1?ooO`04
ooooo`Soo`004Oooool00ooo003oooooooooo`2ToooooaGo003o2?ooool1o`00007ooooo00000ol0
003oooooooooo`0Zooooo`Coogl000?oooooool00?ooool01_ooool2oomo00Gooooo2?oo000;oooo
o`;oogl01Oooool00ooo003oooooooooo`09ooooo`;oogl0V?oooolEo`00o`Sooooo0Ol00001oooo
o`0000?o0000ooooooooool0:_ooool4oomo00;ooooo00?oo`00ooooooooool03?ooool6ool000_o
oooo1?ooO`04ooooo`03ool00?oooooooooo00Sooooo1?ooO`2GoooooaGo003o2?ooool1o`00007o
oooo00000ol0003oooooooooo`0[ooooo`;oogl01?ooool00ooo003oooooooooo`0<ooooo`Coo`00
3?ooool4oomo00Gooooo00?oo`00ooooooooool01oooool4oomo09Oooooo5Ol00?l8ooooo`7o0000
0Oooool00003o`000?oooooooooo03;ooooo0_oo000Mooooo`;oogl01oooool00ooo003ooooooooo
o`07ooooo`;oogl0]Oooool1o`00007ooooo00000ol0003oooooooooo`0dooooo`03ool00?oooooo
oooo02Cooooo00?oo`00ooooooooool0_Oooool1o`00007ooooo00000ol0003oooooooooo`0eoooo
o`03ool00?oooooooooo02Cooooo00?oo`00ooooooooool0_?ooool1o`00007ooooo00000ol0003o
ooooooooo`0fooooo`;oo`009Oooool00ooo003oooooooooo`2kooooo`7o00000Oooool00003o`00
0?oooooooooo03Sooooo0_oo00000oooO`3oooooooooo`02oomo01kooooo00?oo`00ooooooooool0
^oooool1o`00007ooooo00000ol0003oooooooooo`0hooooo`;oogl00_oo0004oomo01kooooo00?o
o`00ooooooooool0^_ooool1o`00007ooooo00000ol0003oooooooooo`0hooooo`Coogl00_oo0002
oomo01kooooo00?oo`00ooooooooool0^_ooool1o`00007ooooo00000ol0003oooooooooo`0ioooo
o`Googl000?oo`00ooooooooool07Oooool00ooo003oogl0oomo002jooooo`7o00000Oooool00003
o`000?oooooooooo03_ooooo1?ooO`02ool001gooooo00Coogl0ool00?ooO`3oogl0^Oooool1o`00
007ooooo00000ol0003oooooooooo`0looooo`;oogl00oooool2ool001_ooooo00Coogl0ool00?oo
O`3oogl0^Oooool1o`00007ooooo00000ol0003oooooooooo`13ooooo`;oo`006_ooool00oooO`3o
o`00ooooo`2iooooo`7o00000Oooool00003o`000?oooooooooo04Gooooo0_oo000Iooooo`03ool0
0?oooooooooo0;Sooooo0Ol00001ooooo`0000?o0000ooooooooool0Aoooool2ool001Gooooo0_oo
002kooooo`7o00000Oooool00003o`000?oooooooooo04Wooooo0ooo000@ooooo`;oo`00_Oooool1
o`00007ooooo00000ol0003oooooooooo`0aooooo`;oogl06Oooool3ool000cooooo00?oo`00oooo
ooooool0_Oooool1o`00007ooooo00000ol0003oooooooooo`0`ooooo`Coogl06oooool6ool000Co
oooo0_oo0030ooooo`7o00000Oooool00003o`000?oooooooooo033ooooo1?ooO`0Qooooo`Coo`00
`_ooool1o`00007ooooo00000ol0003oooooooooo`0aooooo`;oogl0j?ooool1o`00007ooooo0000
0ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLoooo
o`7o00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003ooooo
ooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Ooo
ool00003o`000?oooooooooo07gooooo0_ooO`2Looooo`7o00000Oooool00003o`000?oooooooooo
07cooooo1?ooO`2Kooooo`7o00000Oooool00003o`000?oooooooooo05Cooooo0_ooO`0Vooooo`Co
ogl0Voooool1o`00007ooooo00000ol0003oooooooooo`1Cooooo`Coogl09_ooool2oomo09cooooo
0Ol00001ooooo`0000?o0000ooooooooool0Doooool4oomo0<Cooooo0Ol00001ooooo`0000?o0000
ooooooooool0E?ooool2oomo0<Gooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLoooo
o`7o00000Oooool00003o`000?oooooooooo06?ooooo0_ooO`04ooooo`;oogl0/?ooool1o`00007o
oooo00000ol0003oooooooooo`1Rooooo`Coogl00_ooool4oomo0:oooooo0Ol00001ooooo`0000?o
0000ooooooooool0H_ooool4oomo00;ooooo1?ooO`2_ooooo`7o00000Oooool00003o`000?oooooo
oooo06?ooooo0_ooO`04ooooo`;oogl0/?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooo
oacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`00
0?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol0
0001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo
0?oooooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`00
00?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?oo
ool1o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000oooo
ooooool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007o
oooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooo
oolLooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0
003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o
00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003ooooooooo
o`3ooooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool0
0003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooooaco
oooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oo
oooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001
ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo0?oo
oooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o
0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1
o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000oooooooo
ool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo
00000ol0003oooooooooo`3oooooo`Cooooo0_ooO`0Fooooo`7o00000Oooool00003o`000?oooooo
oooo0?oooooo0oooool4oomo01Gooooo0Ol00001ooooo`0000?o0000ooooooooool0ooooool3oooo
o`Coogl05Oooool1o`00007ooooo00000ol0003oooooooooo`3oooooo`Cooooo0_ooO`0Fooooo`7o
00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003ooooooooo
o`3ooooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool0
0003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooooaco
oooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oo
oooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001
ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo0?oo
oooo7?ooool1o`00007ooooo00000ol0003oooooooooo`2eooooo`;oogl0I?ooool1o`00007ooooo
00000ol0003oooooooooo`2dooooo`Coogl0Hoooool1o`00007ooooo00000ol0003oooooooooo`2d
ooooo`Coogl0Hoooool1o`00007ooooo00000ol0003oooooooooo`2eooooo`;oogl0=Oooool2oomo
02gooooo0Ol00001ooooo`0000?o0000ooooooooool0i?ooool2oomo00Gooooo1?ooO`0/ooooo`7o
00000Oooool00003o`000?oooooooooo0>?ooooo1?ooO`04ooooo`Coogl0;?ooool1o`00007ooooo
00000ol0003oooooooooo`33ooooo`;oogl07_ooool4oomo00Gooooo0_ooO`0]ooooo`7o00000Ooo
ool00003o`000?oooooooooo0<;ooooo1?ooO`0;o`00oa?ooooo0_ooO`0eooooo`7o00000Oooool0
0003o`000?oooooooooo0<;ooooo1?l00?l;ooooo`;o003oB?ooool1o`00007ooooo00000ol0003o
ooooooooo`2nooooo`Co003o00?ooooooomo0?ooO`003_ooool2o`00odKooooo0Ol00001ooooo`00
00?o0000ooooooooool0^Oooool2oomo00?o003o3_ooool5ool0o`Cooooo0_l00?l9ooooo`;oogl0
>Oooool1o`00007ooooo00000ol0003oooooooooo`2gooooo`Co003o00?oogl0ooooooooool03Ooo
ool7ool0o`Gooooo0_l00?l6ooooo`Coogl0>?ooool1o`00007ooooo00000ol0003oooooooooo`2d
ooooo`?o003o00?ooooooomo0?ooO`000_ooO`0>ooooo`Woo`3o1Oooool00ol00?ooooooooooo`04
ooooo`Coogl00oooool2oomo03?ooooo0Ol00001ooooo`0000?o0000ooooooooool0/_ooool2o`00
o`?oogl00_ooool2oomo00kooooo2ooo0?l4ooooo`03o`00oooooooooooo00Gooooo0_ooO`03oooo
o`Coogl0<_ooool1o`00007ooooo00000ol0003oooooooooo`2`ooooo`;o003o00?ooooooomo0?oo
O`000_ooO`06ooooo`;oogl02_ooool;ool0o`Cooooo00?o003oooooooooool02_ooool4oomo03;o
oooo0Ol00001ooooo`0000?o0000ooooooooool0[_ooool2o`00o`Cooooo0_ooO`06ooooo`Coogl0
2Oooool;ool0o`Cooooo00?o003oooooooooool02oooool2oomo03?ooooo0Ol00001ooooo`0000?o
0000ooooooooool0Roooool2oomo023ooooo00?o003oooooooooool01?ooool2oomo00Kooooo1?oo
O`09ooooo`_oo`3o1Oooool00ol00?ooooooooooo`0oooooo`7o00000Oooool00003o`000?oooooo
oooo08[ooooo1?ooO`0Mooooo`;o003o1_ooool4oomo00Kooooo0_ooO`0:ooooo`_oo`3o1Oooool0
0ol00?ooooooooooo`0oooooo`7o00000Oooool00003o`000?oooooooooo08[ooooo1?ooO`0Loooo
o`03o`00oooooooooooo00Kooooo1?ooO`0Cooooo`Woo`3o1_ooool00ol00?ooooooooooo`0ooooo
o`7o00000Oooool00003o`000?oooooooooo08_ooooo0_ooO`0Kooooo`;o003o2_ooool2oomo01Go
oooo1ooo0?l7ooooo`03o`00oooooooooooo03oooooo0Ol00001ooooo`0000?o0000ooooooooool0
U_ooool2oomo00kooooo0_l00?lTooooo`Goo`3o00?ooooooomo0?ooO`001Oooool00ol00?oooooo
ooooo`0oooooo`7o00000Oooool00003o`000?oooooooooo09Gooooo1?ooO`0<ooooo`04o`00oooo
ooooogl0oomo02Sooooo1?ooO`03ooooo`03o`00oooooooooooo043ooooo0Ol00001ooooo`0000?o
0000ooooooooool0UOooool4oomo00[ooooo0_l00?l00oooooooogl0oomo0002oomo02Oooooo1?oo
O`03ooooo`03o`00oooooooooooo043ooooo0Ol00001ooooo`0000?o0000ooooooooool0U_ooool2
oomo00[ooooo00Co003ooooooooooooooooo1?ooO`0Xooooo`;oogl01?ooool00ol00?oooooooooo
o`10ooooo`7o00000Oooool00003o`000?oooooooooo0:7ooooo00?o003oooooooooool00oooool2
oomo02kooooo00?o003oooooooooool0@Oooool1o`00007ooooo00000ol0003oooooooooo`2Poooo
o`03o`00oooooooooooo03?ooooo00?o003oooooooooool04_ooool2oomo02kooooo0Ol00001oooo
o`0000?o0000ooooooooool0W_ooool2o`00ocGooooo00?o003oooooooooool04_ooool4oomo02go
oooo0Ol00001ooooo`0000?o0000ooooooooool0WOooool00ol00?ooooooooooo`0Eooooo`Co003o
7?ooool00ol00?ooogl0oomo000Booooo`Coogl0;Oooool1o`00007ooooo00000ol0003ooooooooo
o`2Looooo`03o`00oooooooooooo01Gooooo1_l00?lJooooo`03o`00ooooO`3oogl000;oogl04_oo
ool2oomo02kooooo0Ol00001ooooo`0000?o0000ooooooooool0Voooool00ol00?ooooooooooo`0E
ooooo`So003o6?ooool00ol00?oooooooomo0003oomo04;ooooo0Ol00001ooooo`0000?o0000oooo
ooooool0Voooool00ol00?ooooooooooo`0Eooooo`So003o5oooool01?l00?ooooooooooooooool2
oomo04?ooooo0Ol00001ooooo`0000?o0000ooooooooool0V_ooool00ol00?ooooooooooo`0Foooo
o`So003o5_ooool00ol00?ooooooooooo`17ooooo`7o00000Oooool00003o`000?oooooooooo09Wo
oooo00?o003oooooooooool03?ooool2oomo00Sooooo00?oogl0o`00ool00?l01_l00?lEooooo`03
o`00oooooooooooo00;oogl0A_ooool1o`00007ooooo00000ol0003oooooooooo`2Iooooo`03o`00
oooooooooooo00[ooooo1OooO`07ooooo`;oogl01_l00?lCooooo`;oogl000?o003oooooooooool0
1?ooO`15ooooo`7o00000Oooool00003o`000?oooooooooo09Sooooo00?o003oooooooooool02_oo
ool6oomo00Sooooo0_ooO`04o`00oa?ooooo0_ooO`02o`00o`;ooooo1?ooO`15ooooo`7o00000Ooo
ool00003o`000?oooooooooo09Sooooo00?o003oooooooooool02_ooool5oomo02;ooooo00Coogl0
o`00ooooO`3oogl00oooool2oomo04Kooooo0Ol00001ooooo`0000?o0000ooooooooool0M_ooool2
oomo01oooooo00?o003oooooooooool03?ooool2oomo02Cooooo00?o003ooomo0?ooO`00C?ooool1
o`00007ooooo00000ol0003oooooooooo`1eooooo`Coogl07_ooool00ol00?ooooooooooo`0aoooo
o`03o`00oooooooooooo04gooooo0Ol00001ooooo`0000?o0000ooooooooool0MOooool4oomo00[o
oooo0_ooO`0Aooooo`03o`00oooooooooooo037ooooo00?o003oooooooooool0C_ooool1o`00007o
oooo00000ol0003oooooooooo`1fooooo`;oogl02_ooool4oomo00oooooo00?o003oooooooooool0
6?ooool2oomo01Oooooo00?o003oooooooooool0Coooool1o`00007ooooo00000ol0003ooooooooo
o`22ooooo`Coogl03oooool00ol00?ooooooooooo`0Gooooo`Coogl05?ooool2o`00oe;ooooo0Ol0
0001ooooo`0000?o0000ooooooooool0Poooool2oomo00oooooo00?o003oooooooooool04_ooool2
oomo00Cooooo1?ooO`0Aooooo`?o003oE?ooool1o`00007ooooo00000ol0003oooooooooo`2Doooo
o`03o`00oooooooooooo017ooooo1?ooO`04ooooo`;oogl04?ooool2o`00oeOooooo0Ol00001oooo
o`0000?o0000ooooooooool0U?ooool00ol00?ooooooooooo`0Aooooo`Coogl05Oooool00ol00?oo
ooooooooo`1Gooooo`7o00000Oooool00003o`000?oooooooooo09Cooooo00?o003oooooooooool0
4_ooool2oomo01Cooooo0_l00?mJooooo`7o00000Oooool00003o`000?oooooooooo09Cooooo00?o
003oooooooooool09_ooool2o`00oecooooo0Ol00001ooooo`0000?o0000ooooooooool0UOooool0
0ol00?ooooooooooo`0Tooooo`03o`00oooooooooooo05cooooo0Ol00001ooooo`0000?o0000oooo
ooooool0UOooool00ol00?ooooooooooo`0Rooooo`;o003oGoooool1o`00007ooooo00000ol0003o
ooooooooo`2Eooooo`03o`00oooooooooooo023ooooo0_l00?mQooooo`7o00000Oooool00003o`00
0?oooooooooo08Cooooo0_ooO`0?ooooo`;o003o7oooool2o`00of?ooooo0Ol00001ooooo`0000?o
0000ooooooooool0Poooool4oomo013ooooo0_l00?lJooooo`?o003oIOooool1o`00007ooooo0000
0ol0003oooooooooo`23ooooo`Coogl04_ooool2o`00oaCooooo1?l00?mXooooo`7o00000Oooool0
0003o`000?oooooooooo08Cooooo0_ooO`0Eooooo`?o003o3_ooool3o`00o`?ooooo0_ooO`1Woooo
o`7o00000Oooool00003o`000?oooooooooo09kooooo0ol00?l5ooooo`Ko003o1Oooool4oomo06Ko
oooo0Ol00001ooooo`0000?o0000ooooooooool0XOooool5o`00o`_ooooo1?ooO`1Vooooo`7o0000
0Oooool00003o`000?oooooooooo0;;ooooo0_ooO`1Wooooo`7o00000Oooool00003o`000?oooooo
oooo0?oooooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001oooo
o`0000?o0000ooooooooool0Noooool2oomo09kooooo0Ol00001ooooo`0000?o0000ooooooooool0
N_ooool4oomo09gooooo0Ol00001ooooo`0000?o0000ooooooooool0N_ooool4oomo023ooooo0_oo
O`1kooooo`7o00000Oooool00003o`000?oooooooooo07_ooooo0_ooO`0Pooooo`Coogl0N_ooool1
o`00007ooooo00000ol0003oooooooooo`2Mooooo`Coogl0N_ooool1o`00007ooooo00000ol0003o
ooooooooo`2@ooooo`;oogl03?ooool2oomo07_ooooo0Ol00001ooooo`0000?o0000ooooooooool0
Soooool4oomo08Sooooo0Ol00001ooooo`0000?o0000ooooooooool0Soooool4oomo08Sooooo0Ol0
0001ooooo`0000?o0000ooooooooool0T?ooool2oomo02?ooooo0_ooO`1Tooooo`7o00000Oooool0
0003o`000?oooooooooo0;Cooooo1?ooO`1Sooooo`7o00000Oooool00003o`000?oooooooooo0;Co
oooo1?ooO`1Sooooo`7o00000Oooool00003o`000?oooooooooo0;Gooooo0_ooO`1Tooooo`7o0000
0Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3o
oooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003
o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo
0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oooooo
oooo0?oooooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001oooo
o`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo
7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000
ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00
007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0
oooooolLooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo0000
0ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLoooo
o`7o00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003ooooo
ooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Ooo
ool00003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooo
oacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`00
0?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol0
0001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo
0?oooooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`00
00?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?oo
ool1o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000oooo
ooooool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007o
oooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooo
oolLooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0
003oooooooooo`2>ooooo`;oogl0Roooool1o`00007ooooo00000ol0003oooooooooo`2=ooooo`Co
ogl0R_ooool1o`00007ooooo00000ol0003oooooooooo`2=ooooo`Coogl0R_ooool1o`00007ooooo
00000ol0003oooooooooo`2>ooooo`;oogl0Roooool1o`00007ooooo00000ol0003oooooooooo`3o
oooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003
o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo
0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oooooo
oooo0?oooooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001oooo
o`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo
7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000
ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00
007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0
oooooolLooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo0000
0ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLoooo
o`7o00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003ooooo
ooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Ooo
ool00003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo003oo`00023o00000Oooool00001
\
\>"],
  ImageRangeCache->{{{0, 287}, {287, 0}} -> {-1.01089, -1.01089, 0.00704453, \
0.00704453}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.49505 0.5 0.49505 [
[ 0 0 -0.125 0 ]
[ 0 0 -0.125 0 ]
[ 0 1 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
0 0 m
1 0 L
s
0 0 m
0 1 L
s
0 1 m
1 1 L
s
1 0 m
1 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
1 .5 0 r
.015 w
.03175 .1355 Mdot
.03435 .12523 Mdot
.11137 .12765 Mdot
.14107 .18841 Mdot
.16218 .24538 Mdot
.17294 .21053 Mdot
.18267 .18577 Mdot
.18434 .1304 Mdot
.18553 .30956 Mdot
.20401 .239 Mdot
.21247 .27571 Mdot
.21687 .20845 Mdot
.22376 .2799 Mdot
.22832 .27485 Mdot
.29063 .20974 Mdot
.29686 .25079 Mdot
.30487 .22936 Mdot
.30683 .34623 Mdot
.32055 .20902 Mdot
.32574 .21979 Mdot
.34472 .28521 Mdot
.35998 .36393 Mdot
.36335 .24976 Mdot
.3794 .36608 Mdot
.42386 .66992 Mdot
.44391 .74519 Mdot
.45059 .34198 Mdot
.47208 .67586 Mdot
.47436 .71381 Mdot
.49778 .59825 Mdot
.50874 .91643 Mdot
.51516 .76219 Mdot
.53655 .61374 Mdot
.56563 .75219 Mdot
.59189 .65665 Mdot
.59581 .61604 Mdot
.59923 .6556 Mdot
.60292 .68499 Mdot
.62656 .67779 Mdot
.63555 .72451 Mdot
.63919 .652 Mdot
.64169 .6004 Mdot
.64246 .58611 Mdot
.64496 .54267 Mdot
.64608 .77288 Mdot
.65077 .64308 Mdot
.66065 .57816 Mdot
.67474 .59169 Mdot
.69296 .563 Mdot
.72815 .65902 Mdot
.73169 .58879 Mdot
.74669 .61318 Mdot
.74821 .65474 Mdot
.75963 .63781 Mdot
.79673 .57809 Mdot
.80925 .55852 Mdot
.81525 .58444 Mdot
.83417 .62985 Mdot
.83598 .55526 Mdot
.91595 .49319 Mdot
1 0 0 r
.005 w
.16128 .17044 m
.18734 .17269 L
.21339 .17909 L
.2345 .18734 L
.23945 .19126 L
.2655 .20415 L
.27874 .21339 L
.29156 .22295 L
.31204 .23945 L
.31761 .24532 L
.33549 .2655 L
.34367 .28341 L
.34499 .29156 L
.34367 .29798 L
.31761 .3104 L
.29156 .30711 L
.2655 .30014 L
.24507 .29156 L
.23945 .28747 L
.21339 .27402 L
.20155 .2655 L
.18734 .25472 L
.16884 .23945 L
.16128 .2313 L
.14618 .21339 L
.13806 .18734 L
.16128 .17044 L
s
0 0 1 r
.65633 .57701 m
.68239 .56842 L
.70844 .56313 L
.7345 .56168 L
.76055 .5752 L
.76359 .57817 L
.76859 .60422 L
.76055 .62333 L
.75627 .63028 L
.7345 .65485 L
.73298 .65633 L
.70844 .6775 L
.69922 .68239 L
.68239 .69294 L
.65633 .70579 L
.64983 .70844 L
.63028 .71539 L
.60422 .72268 L
.57817 .72651 L
.55211 .7214 L
.53145 .70844 L
.52926 .68239 L
.54239 .65633 L
.55211 .63983 L
.56625 .63028 L
.57817 .6193 L
.60119 .60422 L
.60422 .60227 L
.63028 .58726 L
.65315 .57817 L
.65633 .57701 L
s
1 0 0 r
.03 w
.24141 .24033 Mdot
0 0 1 r
.64872 .64417 Mdot
1 0 0 r
.79703 .00495 m
.79703 .00495 L
.87129 .00495 L
.87129 .00495 L
F
0 0 1 r
.89604 .00495 m
.89604 .25248 L
.9703 .25248 L
.9703 .00495 L
F
1 0 1 r
.04 w
.74669 .61318 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P000182000`400?l00000o`00003ooooooolQ
ooooo`00ool0000Po`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`00
00?o0000ooooooooool0o_oooolEo`00o`Sooooo0Ol00001ooooo`0000?o0000ooooooooool0o_oo
oolEo`00o`Sooooo0Ol00001ooooo`0000?o0000ooooooooool0o_oooolEo`00o`Sooooo0Ol00001
ooooo`0000?o0000ooooooooool0o_oooolEo`00o`Sooooo0Ol00001ooooo`0000?o0000oooooooo
ool0o_oooolEo`00o`Sooooo0Ol00001ooooo`0000?o0000ooooooooool0o_oooolEo`00o`Sooooo
0Ol00001ooooo`0000?o0000ooooooooool0o_oooolEo`00o`Sooooo0Ol00001ooooo`0000?o0000
ooooooooool0o_oooolEo`00o`Sooooo0Ol00001ooooo`0000?o0000ooooooooool0o_oooolEo`00
o`Sooooo0Ol00001ooooo`0000?o0000ooooooooool0o_oooolEo`00o`Sooooo0Ol00001ooooo`00
00?o0000ooooooooool0o_oooolEo`00o`Sooooo0Ol00001ooooo`0000?o0000ooooooooool0o_oo
oolEo`00o`Sooooo0Ol00001ooooo`0000?o0000ooooooooool0o_oooolEo`00o`Sooooo0Ol00001
ooooo`0000?o0000ooooooooool0o_oooolEo`00o`Sooooo0Ol00001ooooo`0000?o0000oooooooo
ool0o_oooolEo`00o`Sooooo0Ol00001ooooo`0000?o0000ooooooooool0o_oooolEo`00o`Sooooo
0Ol00001ooooo`0000?o0000ooooooooool0o_oooolEo`00o`Sooooo0Ol00001ooooo`0000?o0000
ooooooooool0o_oooolEo`00o`Sooooo0Ol00001ooooo`0000?o0000ooooooooool0o_oooolEo`00
o`Sooooo0Ol00001ooooo`0000?o0000ooooooooool0o_oooolEo`00o`Sooooo0Ol00001ooooo`00
00?o0000ooooooooool0o_oooolEo`00o`Sooooo0Ol00001ooooo`0000?o0000ooooooooool0o_oo
oolEo`00o`Sooooo0Ol00001ooooo`0000?o0000ooooooooool0o_oooolEo`00o`Sooooo0Ol00001
ooooo`0000?o0000ooooooooool0o_oooolEo`00o`Sooooo0Ol00001ooooo`0000?o0000oooooooo
ool0o_oooolEo`00o`Sooooo0Ol00001ooooo`0000?o0000ooooooooool0o_oooolEo`00o`Sooooo
0Ol00001ooooo`0000?o0000ooooooooool0o_oooolEo`00o`Sooooo0Ol00001ooooo`0000?o0000
ooooooooool0o_oooolEo`00o`Sooooo0Ol00001ooooo`0000?o0000ooooooooool0o_oooolEo`00
o`Sooooo0Ol00001ooooo`0000?o0000ooooooooool0o_oooolEo`00o`Sooooo0Ol00001ooooo`00
00?o0000ooooooooool0o_oooolEo`00o`Sooooo0Ol00001ooooo`0000?o0000ooooooooool0o_oo
oolEo`00o`Sooooo0Ol00001ooooo`0000?o0000ooooooooool01_ooool2oomo0?Kooooo5Ol00?l8
ooooo`7o00000Oooool00003o`000?oooooooooo00Gooooo1?ooO`0Cooooo`;oogl0h?oooolEo`00
o`Sooooo0Ol00001ooooo`0000?o0000ooooooooool01Oooool4oomo01;ooooo1?ooO`0Booooo`;o
ogl0booooolEo`00o`Sooooo0Ol00001ooooo`0000?o0000ooooooooool01Oooool3oomo01?ooooo
1?ooO`0Aooooo`Coogl0b_oooolEo`00o`Sooooo0Ol00001ooooo`0000?o0000ooooooooool01?oo
ool4oomo01Cooooo0_ooO`0Booooo`Coogl0b_oooolEo`00o`Sooooo0Ol00001ooooo`0000?o0000
ooooooooool01?ooool4oomo02Wooooo0_ooO`3;oooooaGo003o2?ooool1o`00007ooooo00000ol0
003oooooooooo`05ooooo`;oogl0mooooolEo`00o`Sooooo0Ol00001ooooo`0000?o0000oooooooo
ool0o_oooolEo`00o`Sooooo0Ol00001ooooo`0000?o0000ooooooooool0o_oooolEo`00o`Sooooo
0Ol00001ooooo`0000?o0000ooooooooool0o_oooolEo`00o`Sooooo0Ol00001ooooo`0000?o0000
ooooooooool0o_oooolEo`00o`Sooooo0Ol00001ooooo`0000?o0000ooooooooool0o_oooolEo`00
o`Sooooo0Ol00001ooooo`0000?o0000ooooooooool0o_oooolEo`00o`Sooooo0Ol00001ooooo`00
00?o0000ooooooooool0o_oooolEo`00o`Sooooo0Ol00001ooooo`0000?o0000ooooooooool0:_oo
ool6ool00<kooooo5Ol00?l8ooooo`7o00000Oooool00003o`000?oooooooooo02Wooooo00?oo`00
ooooooooool01?ooool5ool00<Wooooo5Ol00?l8ooooo`7o00000Oooool00003o`000?oooooooooo
02Oooooo0_oo000<ooooo`Coo`00aOoooolEo`00o`Sooooo0Ol00001ooooo`0000?o0000oooooooo
ool09_ooool00ooo003oooooooooo`0@ooooo`Coo`00`OoooolEo`00o`Sooooo0Ol00001ooooo`00
00?o0000ooooooooool09?ooool00oooO`3oo`00ooooo`09ooooo`;oogl02oooool3ool00;kooooo
5Ol00?l8ooooo`7o00000Oooool00003o`000?oooooooooo02?ooooo00Coogl0ool00?ooO`3oogl0
2?ooool4oomo00gooooo00?oo`00ooooooooool0^ooooolEo`00o`Sooooo0Ol00001ooooo`0000?o
0000ooooooooool08oooool01?ooO`3oo`00oomo0?ooO`08ooooo`Coogl03_ooool2ool00;_ooooo
5Ol00?l8ooooo`7o00000Oooool00003o`000?oooooooooo02Cooooo00?oogl0ool00?ooool02Ooo
ool2oomo017ooooo0_oo002ioooooaGo003o2?ooool1o`00007ooooo00000ol0003oooooooooo`0U
ooooo`03ool00?oooooooooo01gooooo0_oo002goooooaGo003o2?ooool1o`00007ooooo00000ol0
003oooooooooo`0Uooooo`03ool00?oooooooooo01oooooo0_oo002eoooooaGo003o2?ooool1o`00
007ooooo00000ol0003oooooooooo`0Vooooo`03ool00?oooooooooo017ooooo0_ooO`0=ooooo`;o
o`001?ooool2oomo00Oooooo0_ooO`2ToooooaGo003o2?ooool1o`00007ooooo00000ol0003ooooo
ooooo`0Vooooo`03ool00?oooooooooo00Gooooo0_ooO`09ooooo`Coogl03_ooool00ooo003ooooo
ooooo`04oomo00Gooooo1?ooO`2SoooooaGo003o2?ooool1o`00007ooooo00000ol0003ooooooooo
o`0Vooooo`03ool00?oooooooooo00Cooooo1?ooO`08ooooo`Coogl03oooool00ooo003ooooooomo
0003oomo00Gooooo1?ooO`2SoooooaGo003o2?ooool1o`00007ooooo00000ol0003oooooooooo`0W
ooooo`03ool00?oooooooooo00?ooooo1?ooO`09ooooo`;oogl04Oooool01?oo003ooooooomo0?oo
O`07ooooo`?oogl0XooooolEo`00o`Sooooo0Ol00001ooooo`0000?o0000ooooooooool09oooool0
0ooo003oooooooooo`04ooooo`;oogl07_ooool00ooo003oooooooooo`07ooooo`Coogl0X_oooolE
o`00o`Sooooo0Ol00001ooooo`0000?o0000ooooooooool0:?ooool00ooo003oooooooooo`0Toooo
o`03ool00?oooooooooo00Kooooo1?ooO`2RoooooaGo003o2?ooool1o`00007ooooo00000ol0003o
ooooooooo`0Yooooo`03ool00?oooooooooo02Cooooo0_oo00000oooooooogl0oomo0004ooooo`;o
ogl0XooooolEo`00o`Sooooo0Ol00001ooooo`0000?o0000ooooooooool0:_ooool00ooo003ooooo
ooooo`0Cooooo`Coo`003_ooool01?oo003oogl0oomo0?ooO`2XoooooaGo003o2?ooool1o`00007o
oooo00000ol0003oooooooooo`0[ooooo`03ool00?oooooooooo017ooooo1_oo000=ooooo`04oomo
0?oo003oo`00oomo0:Sooooo5Ol00?l8ooooo`7o00000Oooool00003o`000?oooooooooo02cooooo
00?oo`00ooooooooool02?ooool2oomo00Gooooo2?oo000=ooooo`;oogl000?oo`00ooooooooool0
Y_oooolEo`00o`Sooooo0Ol00001ooooo`0000?o0000ooooooooool0;Oooool00ooo003ooooooooo
o`06ooooo`Coogl01?ooool8ool0013ooooo00?oo`00ooooooooool0YOoooolEo`00o`Sooooo0Ol0
0001ooooo`0000?o0000ooooooooool0:oooool2oomo0003oooooooo003ooooo00Kooooo1?ooO`04
ooooo`Soo`004Oooool00ooo003oooooooooo`2ToooooaGo003o2?ooool1o`00007ooooo00000ol0
003oooooooooo`0Zooooo`Coogl000?oooooool00?ooool01_ooool2oomo00Gooooo2?oo000;oooo
o`;oogl01Oooool00ooo003oooooooooo`09ooooo`;oogl0V?oooolEo`00o`Sooooo0Ol00001oooo
o`0000?o0000ooooooooool0:_ooool4oomo00;ooooo00?oo`00ooooooooool03?ooool6ool000_o
oooo1?ooO`04ooooo`03ool00?oooooooooo00Sooooo1?ooO`2GoooooaGo003o2?ooool1o`00007o
oooo00000ol0003oooooooooo`0[ooooo`;oogl01?ooool00ooo003oooooooooo`0<ooooo`Coo`00
3?ooool4oomo00Gooooo00?oo`00ooooooooool01oooool4oomo09Oooooo5Ol00?l8ooooo`7o0000
0Oooool00003o`000?oooooooooo03;ooooo0_oo000Mooooo`;oogl01oooool00ooo003ooooooooo
o`07ooooo`;oogl0]Oooool1o`00007ooooo00000ol0003oooooooooo`0dooooo`03ool00?oooooo
oooo02Cooooo00?oo`00ooooooooool0_Oooool1o`00007ooooo00000ol0003oooooooooo`0eoooo
o`03ool00?oooooooooo02Cooooo00?oo`00ooooooooool0_?ooool1o`00007ooooo00000ol0003o
ooooooooo`0fooooo`;oo`009Oooool00ooo003oooooooooo`2kooooo`7o00000Oooool00003o`00
0?oooooooooo03Sooooo0_oo00000oooO`3oooooooooo`02oomo01kooooo00?oo`00ooooooooool0
^oooool1o`00007ooooo00000ol0003oooooooooo`0hooooo`;oogl00_oo0004oomo01kooooo00?o
o`00ooooooooool0^_ooool1o`00007ooooo00000ol0003oooooooooo`0hooooo`Coogl00_oo0002
oomo01kooooo00?oo`00ooooooooool0^_ooool1o`00007ooooo00000ol0003oooooooooo`0ioooo
o`Googl000?oo`00ooooooooool07Oooool00ooo003oogl0oomo002jooooo`7o00000Oooool00003
o`000?oooooooooo03_ooooo1?ooO`02ool001gooooo00Coogl0ool00?ooO`3oogl0^Oooool1o`00
007ooooo00000ol0003oooooooooo`0looooo`;oogl00oooool2ool001_ooooo00Coogl0ool00?oo
O`3oogl0^Oooool1o`00007ooooo00000ol0003oooooooooo`13ooooo`;oo`006_ooool00oooO`3o
o`00ooooo`2iooooo`7o00000Oooool00003o`000?oooooooooo04Gooooo0_oo000Iooooo`03ool0
0?oooooooooo0;Sooooo0Ol00001ooooo`0000?o0000ooooooooool0Aoooool2ool001Gooooo0_oo
002kooooo`7o00000Oooool00003o`000?oooooooooo04Wooooo0ooo000@ooooo`;oo`00_Oooool1
o`00007ooooo00000ol0003oooooooooo`0aooooo`;oogl06Oooool3ool000cooooo00?oo`00oooo
ooooool0_Oooool1o`00007ooooo00000ol0003oooooooooo`0`ooooo`Coogl06oooool6ool000Co
oooo0_oo0030ooooo`7o00000Oooool00003o`000?oooooooooo033ooooo1?ooO`0Qooooo`Coo`00
`_ooool1o`00007ooooo00000ol0003oooooooooo`0aooooo`;oogl0j?ooool1o`00007ooooo0000
0ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLoooo
o`7o00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003ooooo
ooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Ooo
ool00003o`000?oooooooooo07gooooo0_ooO`2Looooo`7o00000Oooool00003o`000?oooooooooo
07cooooo1?ooO`2Kooooo`7o00000Oooool00003o`000?oooooooooo05Cooooo0_ooO`0Vooooo`Co
ogl0Voooool1o`00007ooooo00000ol0003oooooooooo`1Cooooo`Coogl09_ooool2oomo09cooooo
0Ol00001ooooo`0000?o0000ooooooooool0Doooool4oomo0<Cooooo0Ol00001ooooo`0000?o0000
ooooooooool0E?ooool2oomo0<Gooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLoooo
o`7o00000Oooool00003o`000?oooooooooo06?ooooo0_ooO`04ooooo`;oogl0/?ooool1o`00007o
oooo00000ol0003oooooooooo`1Rooooo`Coogl00_ooool4oomo0:oooooo0Ol00001ooooo`0000?o
0000ooooooooool0H_ooool4oomo00;ooooo1?ooO`2_ooooo`7o00000Oooool00003o`000?oooooo
oooo06?ooooo0_ooO`04ooooo`;oogl0/?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooo
oacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`00
0?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol0
0001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo
0?oooooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`00
00?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?oo
ool1o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000oooo
ooooool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007o
oooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooo
oolLooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0
003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o
00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003ooooooooo
o`3ooooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool0
0003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooooaco
oooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oo
oooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001
ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo0?oo
oooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o
0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1
o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000oooooooo
ool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo
00000ol0003oooooooooo`3oooooo`Cooooo0_ooO`0Fooooo`7o00000Oooool00003o`000?oooooo
oooo0?oooooo0oooool4oomo01Gooooo0Ol00001ooooo`0000?o0000ooooooooool0ooooool3oooo
o`Coogl05Oooool1o`00007ooooo00000ol0003oooooooooo`3oooooo`Cooooo0_ooO`0Fooooo`7o
00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003ooooooooo
o`3ooooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool0
0003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooooaco
oooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oo
oooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001
ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo0?oo
oooo7?ooool1o`00007ooooo00000ol0003oooooooooo`2eooooo`;oogl0I?ooool1o`00007ooooo
00000ol0003oooooooooo`2dooooo`Coogl0Hoooool1o`00007ooooo00000ol0003oooooooooo`2d
ooooo`Coogl0Hoooool1o`00007ooooo00000ol0003oooooooooo`2eooooo`;oogl0=Oooool2oomo
02gooooo0Ol00001ooooo`0000?o0000ooooooooool0i?ooool2oomo00Gooooo1?ooO`0/ooooo`7o
00000Oooool00003o`000?oooooooooo0>?ooooo1?ooO`04ooooo`Coogl0;?ooool1o`00007ooooo
00000ol0003oooooooooo`33ooooo`;oogl07_ooool4oomo00Gooooo0_ooO`0]ooooo`7o00000Ooo
ool00003o`000?oooooooooo0<;ooooo1?ooO`0;o`00oa?ooooo0_ooO`0eooooo`7o00000Oooool0
0003o`000?oooooooooo0<;ooooo1?l00?l;ooooo`;o003oB?ooool1o`00007ooooo00000ol0003o
ooooooooo`2nooooo`Co003o00?ooooooomo0?ooO`003_ooool2o`00odKooooo0Ol00001ooooo`00
00?o0000ooooooooool0^Oooool2oomo00?o003o5oooool2o`00o`Wooooo0_ooO`0iooooo`7o0000
0Oooool00003o`000?oooooooooo0;Oooooo1?l00?l00oooO`3oooooooooo`0Iooooo`;o003o1_oo
ool4oomo03Sooooo0Ol00001ooooo`0000?o0000ooooooooool0]?ooool3o`00o`03ooooooooO`3o
ogl000;oogl07?ooool00ol00?ooooooooooo`04ooooo`Coogl00oooool2oomo03?ooooo0Ol00001
ooooo`0000?o0000ooooooooool0/_ooool2o`00o`?oogl00_ooool2oomo01?ooooo0_ooO`08oooo
o`03o`00oooooooooooo00Gooooo0_ooO`03ooooo`Coogl0<_ooool1o`00007ooooo00000ol0003o
ooooooooo`2`ooooo`;o003o00?ooooooomo0?ooO`000_ooO`06ooooo`;oogl03_ooool4oomo00Oo
oooo00?o003oooooooooool02_ooool4oomo03;ooooo0Ol00001ooooo`0000?o0000ooooooooool0
[_ooool2o`00o`Cooooo0_ooO`06ooooo`Coogl03Oooool4oomo00Oooooo00?o003oooooooooool0
2oooool2oomo03?ooooo0Ol00001ooooo`0000?o0000ooooooooool0Roooool2oomo023ooooo00?o
003oooooooooool01?ooool2oomo00Kooooo1?ooO`0>ooooo`;oogl02Oooool00ol00?oooooooooo
o`0oooooo`7o00000Oooool00003o`000?oooooooooo08[ooooo1?ooO`0Mooooo`;o003o1_ooool4
oomo00Kooooo0_ooO`0Booooo`Goo`3o0oooool00ol00?ooooooooooo`0oooooo`7o00000Oooool0
0003o`000?oooooooooo08[ooooo1?ooO`0Looooo`03o`00oooooooooooo00Kooooo1?ooO`0Ioooo
o`Ooo`3o0_ooool00ol00?ooooooooooo`0oooooo`7o00000Oooool00003o`000?oooooooooo08_o
oooo0_ooO`0Kooooo`;o003o2_ooool2oomo01Wooooo2Ooo0?l00ooooooo003oooooo`10ooooo`7o
00000Oooool00003o`000?oooooooooo09Kooooo0_ooO`0>ooooo`;o003o9_ooool;ool0o`03o`00
oooooooooooo03oooooo0Ol00001ooooo`0000?o0000ooooooooool0UOooool4oomo00cooooo00Co
003oooooooooO`3oogl09Oooool;ool0od;ooooo0Ol00001ooooo`0000?o0000ooooooooool0UOoo
ool4oomo00[ooooo0_l00?l00oooooooogl0oomo0002oomo02Cooooo2ooo0?m2ooooo`7o00000Ooo
ool00003o`000?oooooooooo09Kooooo0_ooO`0:ooooo`04o`00ooooooooooooooooo`Coogl09?oo
ool;ool0od;ooooo0Ol00001ooooo`0000?o0000ooooooooool0XOooool00ol00?ooooooooooo`03
ooooo`;oogl09Oooool;ool0od;ooooo0Ol00001ooooo`0000?o0000ooooooooool0X?ooool00ol0
0?ooooooooooo`0/ooooo`Woo`3o4oooool2oomo02kooooo0Ol00001ooooo`0000?o0000oooooooo
ool0W_ooool2o`00oc3ooooo1ooo0?lCooooo`Coogl0;Oooool1o`00007ooooo00000ol0003ooooo
ooooo`2Mooooo`03o`00oooooooooooo01Gooooo1?l00?lHooooo`Goo`3o0_ooO`0Booooo`Coogl0
;Oooool1o`00007ooooo00000ol0003oooooooooo`2Looooo`03o`00oooooooooooo01Gooooo1_l0
0?lJooooo`03o`00ooooO`3oogl000;oogl04_ooool2oomo02kooooo0Ol00001ooooo`0000?o0000
ooooooooool0Voooool00ol00?ooooooooooo`0Eooooo`So003o6?ooool00ol00?oooooooomo0003
oomo04;ooooo0Ol00001ooooo`0000?o0000ooooooooool0Voooool00ol00?ooooooooooo`0Eoooo
o`So003o5oooool01?l00?ooooooooooooooool2oomo04?ooooo0Ol00001ooooo`0000?o0000oooo
ooooool0V_ooool00ol00?ooooooooooo`0Fooooo`So003o5_ooool00ol00?ooooooooooo`17oooo
o`7o00000Oooool00003o`000?oooooooooo09Wooooo00?o003oooooooooool03?ooool2oomo00So
oooo00?oogl0o`00ool00?l01_l00?lEooooo`03o`00oooooooooooo00;oogl0A_ooool1o`00007o
oooo00000ol0003oooooooooo`2Iooooo`03o`00oooooooooooo00[ooooo1OooO`07ooooo`;oogl0
1_l00?lCooooo`;oogl000?o003oooooooooool01?ooO`15ooooo`7o00000Oooool00003o`000?oo
oooooooo09Sooooo00?o003oooooooooool02_ooool6oomo00Sooooo0_ooO`04o`00oa?ooooo0_oo
O`02o`00o`;ooooo1?ooO`15ooooo`7o00000Oooool00003o`000?oooooooooo09Sooooo00?o003o
ooooooooool02_ooool5oomo02;ooooo00Coogl0o`00ooooO`3oogl00oooool2oomo04Kooooo0Ol0
0001ooooo`0000?o0000ooooooooool0M_ooool2oomo01oooooo00?o003oooooooooool03?ooool2
oomo02Cooooo00?o003ooomo0?ooO`00C?ooool1o`00007ooooo00000ol0003oooooooooo`1eoooo
o`Coogl07_ooool00ol00?ooooooooooo`0aooooo`03o`00oooooooooooo04gooooo0Ol00001oooo
o`0000?o0000ooooooooool0MOooool4oomo00[ooooo0_ooO`0Aooooo`03o`00oooooooooooo037o
oooo00?o003oooooooooool0C_ooool1o`00007ooooo00000ol0003oooooooooo`1fooooo`;oogl0
2_ooool4oomo00oooooo00?o003oooooooooool06?ooool2oomo01Oooooo00?o003oooooooooool0
Coooool1o`00007ooooo00000ol0003oooooooooo`22ooooo`Coogl03oooool00ol00?oooooooooo
o`0Gooooo`Coogl05?ooool2o`00oe;ooooo0Ol00001ooooo`0000?o0000ooooooooool0Poooool2
oomo00oooooo00?o003oooooooooool04_ooool2oomo00Cooooo1?ooO`0Aooooo`?o003oE?ooool1
o`00007ooooo00000ol0003oooooooooo`2Dooooo`03o`00oooooooooooo017ooooo1?ooO`04oooo
o`;oogl04?ooool2o`00oeOooooo0Ol00001ooooo`0000?o0000ooooooooool0U?ooool00ol00?oo
ooooooooo`0Aooooo`Coogl05Oooool00ol00?ooooooooooo`1Gooooo`7o00000Oooool00003o`00
0?oooooooooo09Cooooo00?o003oooooooooool04_ooool2oomo01Cooooo0_l00?mJooooo`7o0000
0Oooool00003o`000?oooooooooo09Cooooo00?o003oooooooooool09_ooool2o`00oecooooo0Ol0
0001ooooo`0000?o0000ooooooooool0UOooool00ol00?ooooooooooo`0Tooooo`03o`00oooooooo
oooo05cooooo0Ol00001ooooo`0000?o0000ooooooooool0UOooool00ol00?ooooooooooo`0Roooo
o`;o003oGoooool1o`00007ooooo00000ol0003oooooooooo`2Eooooo`03o`00oooooooooooo023o
oooo0_l00?mQooooo`7o00000Oooool00003o`000?oooooooooo08Cooooo0_ooO`0?ooooo`;o003o
7oooool2o`00of?ooooo0Ol00001ooooo`0000?o0000ooooooooool0Poooool4oomo013ooooo0_l0
0?lJooooo`?o003oIOooool1o`00007ooooo00000ol0003oooooooooo`23ooooo`Coogl04_ooool2
o`00oaCooooo1?l00?mXooooo`7o00000Oooool00003o`000?oooooooooo08Cooooo0_ooO`0Eoooo
o`?o003o3_ooool3o`00o`?ooooo0_ooO`1Wooooo`7o00000Oooool00003o`000?oooooooooo09ko
oooo0ol00?l5ooooo`Ko003o1Oooool4oomo06Kooooo0Ol00001ooooo`0000?o0000ooooooooool0
XOooool5o`00o`_ooooo1?ooO`1Vooooo`7o00000Oooool00003o`000?oooooooooo0;;ooooo0_oo
O`1Wooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0
003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0Noooool2oomo09ko
oooo0Ol00001ooooo`0000?o0000ooooooooool0N_ooool4oomo09gooooo0Ol00001ooooo`0000?o
0000ooooooooool0N_ooool4oomo023ooooo0_ooO`1kooooo`7o00000Oooool00003o`000?oooooo
oooo07_ooooo0_ooO`0Pooooo`Coogl0N_ooool1o`00007ooooo00000ol0003oooooooooo`2Moooo
o`Coogl0N_ooool1o`00007ooooo00000ol0003oooooooooo`2@ooooo`;oogl03?ooool2oomo07_o
oooo0Ol00001ooooo`0000?o0000ooooooooool0Soooool4oomo08Sooooo0Ol00001ooooo`0000?o
0000ooooooooool0Soooool4oomo08Sooooo0Ol00001ooooo`0000?o0000ooooooooool0T?ooool2
oomo02?ooooo0_ooO`1Tooooo`7o00000Oooool00003o`000?oooooooooo0;Cooooo1?ooO`1Soooo
o`7o00000Oooool00003o`000?oooooooooo0;Cooooo1?ooO`1Sooooo`7o00000Oooool00003o`00
0?oooooooooo0;Gooooo0_ooO`1Tooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?oo
ool1o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000oooo
ooooool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007o
oooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooo
oolLooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0
003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o
00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003ooooooooo
o`3ooooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool0
0003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooooaco
oooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oo
oooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001
ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo0?oo
oooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o
0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1
o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000oooooooo
ool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo
00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolL
ooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003o
ooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o0000
0Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3o
oooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003
o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo
0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oooooo
oooo0?oooooo7?ooool1o`00007ooooo00000ol0003oooooooooo`2>ooooo`;oogl0Roooool1o`00
007ooooo00000ol0003oooooooooo`2=ooooo`Coogl0R_ooool1o`00007ooooo00000ol0003ooooo
ooooo`2=ooooo`Coogl0R_ooool1o`00007ooooo00000ol0003oooooooooo`2>ooooo`;oogl0Rooo
ool1o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000oooo
ooooool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007o
oooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooo
oolLooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0
003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o
00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003ooooooooo
o`3ooooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool0
0003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooooaco
oooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oo
oooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001
ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo0?oo
oooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o
0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1
o`00007ooooo003oo`00023o00000Oooool00001\
\>"],
  ImageRangeCache->{{{0, 287}, {287, 0}} -> {-1.01089, -1.01089, 0.00704453, \
0.00704453}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.49505 0.5 0.49505 [
[ 0 0 -0.125 0 ]
[ 0 0 -0.125 0 ]
[ 0 1 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
0 0 m
1 0 L
s
0 0 m
0 1 L
s
0 1 m
1 1 L
s
1 0 m
1 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
1 .5 0 r
.015 w
.03175 .1355 Mdot
.03435 .12523 Mdot
.11137 .12765 Mdot
.14107 .18841 Mdot
.16218 .24538 Mdot
.17294 .21053 Mdot
.18267 .18577 Mdot
.18434 .1304 Mdot
.18553 .30956 Mdot
.20401 .239 Mdot
.21247 .27571 Mdot
.21687 .20845 Mdot
.22376 .2799 Mdot
.22832 .27485 Mdot
.29063 .20974 Mdot
.29686 .25079 Mdot
.30487 .22936 Mdot
.30683 .34623 Mdot
.32055 .20902 Mdot
.32574 .21979 Mdot
.34472 .28521 Mdot
.35998 .36393 Mdot
.36335 .24976 Mdot
.3794 .36608 Mdot
.42386 .66992 Mdot
.44391 .74519 Mdot
.45059 .34198 Mdot
.47208 .67586 Mdot
.47436 .71381 Mdot
.49778 .59825 Mdot
.50874 .91643 Mdot
.51516 .76219 Mdot
.53655 .61374 Mdot
.56563 .75219 Mdot
.59189 .65665 Mdot
.59581 .61604 Mdot
.59923 .6556 Mdot
.60292 .68499 Mdot
.62656 .67779 Mdot
.63555 .72451 Mdot
.63919 .652 Mdot
.64169 .6004 Mdot
.64246 .58611 Mdot
.64496 .54267 Mdot
.64608 .77288 Mdot
.65077 .64308 Mdot
.66065 .57816 Mdot
.67474 .59169 Mdot
.69296 .563 Mdot
.72815 .65902 Mdot
.73169 .58879 Mdot
.74669 .61318 Mdot
.74821 .65474 Mdot
.75963 .63781 Mdot
.79673 .57809 Mdot
.80925 .55852 Mdot
.81525 .58444 Mdot
.83417 .62985 Mdot
.83598 .55526 Mdot
.91595 .49319 Mdot
1 0 0 r
.005 w
.16128 .17044 m
.18734 .17269 L
.21339 .17909 L
.2345 .18734 L
.23945 .19126 L
.2655 .20415 L
.27874 .21339 L
.29156 .22295 L
.31204 .23945 L
.31761 .24532 L
.33549 .2655 L
.34367 .28341 L
.34499 .29156 L
.34367 .29798 L
.31761 .3104 L
.29156 .30711 L
.2655 .30014 L
.24507 .29156 L
.23945 .28747 L
.21339 .27402 L
.20155 .2655 L
.18734 .25472 L
.16884 .23945 L
.16128 .2313 L
.14618 .21339 L
.13806 .18734 L
.16128 .17044 L
s
0 0 1 r
.65633 .57701 m
.68239 .56842 L
.70844 .56313 L
.7345 .56168 L
.76055 .5752 L
.76359 .57817 L
.76859 .60422 L
.76055 .62333 L
.75627 .63028 L
.7345 .65485 L
.73298 .65633 L
.70844 .6775 L
.69922 .68239 L
.68239 .69294 L
.65633 .70579 L
.64983 .70844 L
.63028 .71539 L
.60422 .72268 L
.57817 .72651 L
.55211 .7214 L
.53145 .70844 L
.52926 .68239 L
.54239 .65633 L
.55211 .63983 L
.56625 .63028 L
.57817 .6193 L
.60119 .60422 L
.60422 .60227 L
.63028 .58726 L
.65315 .57817 L
.65633 .57701 L
s
1 0 0 r
.03 w
.24141 .24033 Mdot
0 0 1 r
.64872 .64417 Mdot
1 0 0 r
.79703 .00495 m
.79703 .00495 L
.87129 .00495 L
.87129 .00495 L
F
0 0 1 r
.89604 .00495 m
.89604 .25248 L
.9703 .25248 L
.9703 .00495 L
F
1 0 1 r
.04 w
.74821 .65474 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P000182000`400?l00000o`00003ooooooolQ
ooooo`00ool0000Po`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`00
00?o0000ooooooooool0o_oooolEo`00o`Sooooo0Ol00001ooooo`0000?o0000ooooooooool0o_oo
oolEo`00o`Sooooo0Ol00001ooooo`0000?o0000ooooooooool0o_oooolEo`00o`Sooooo0Ol00001
ooooo`0000?o0000ooooooooool0o_oooolEo`00o`Sooooo0Ol00001ooooo`0000?o0000oooooooo
ool0o_oooolEo`00o`Sooooo0Ol00001ooooo`0000?o0000ooooooooool0o_oooolEo`00o`Sooooo
0Ol00001ooooo`0000?o0000ooooooooool0o_oooolEo`00o`Sooooo0Ol00001ooooo`0000?o0000
ooooooooool0o_oooolEo`00o`Sooooo0Ol00001ooooo`0000?o0000ooooooooool0o_oooolEo`00
o`Sooooo0Ol00001ooooo`0000?o0000ooooooooool0o_oooolEo`00o`Sooooo0Ol00001ooooo`00
00?o0000ooooooooool0o_oooolEo`00o`Sooooo0Ol00001ooooo`0000?o0000ooooooooool0o_oo
oolEo`00o`Sooooo0Ol00001ooooo`0000?o0000ooooooooool0o_oooolEo`00o`Sooooo0Ol00001
ooooo`0000?o0000ooooooooool0o_oooolEo`00o`Sooooo0Ol00001ooooo`0000?o0000oooooooo
ool0o_oooolEo`00o`Sooooo0Ol00001ooooo`0000?o0000ooooooooool0o_oooolEo`00o`Sooooo
0Ol00001ooooo`0000?o0000ooooooooool0o_oooolEo`00o`Sooooo0Ol00001ooooo`0000?o0000
ooooooooool0o_oooolEo`00o`Sooooo0Ol00001ooooo`0000?o0000ooooooooool0o_oooolEo`00
o`Sooooo0Ol00001ooooo`0000?o0000ooooooooool0o_oooolEo`00o`Sooooo0Ol00001ooooo`00
00?o0000ooooooooool0o_oooolEo`00o`Sooooo0Ol00001ooooo`0000?o0000ooooooooool0o_oo
oolEo`00o`Sooooo0Ol00001ooooo`0000?o0000ooooooooool0o_oooolEo`00o`Sooooo0Ol00001
ooooo`0000?o0000ooooooooool0o_oooolEo`00o`Sooooo0Ol00001ooooo`0000?o0000oooooooo
ool0o_oooolEo`00o`Sooooo0Ol00001ooooo`0000?o0000ooooooooool0o_oooolEo`00o`Sooooo
0Ol00001ooooo`0000?o0000ooooooooool0o_oooolEo`00o`Sooooo0Ol00001ooooo`0000?o0000
ooooooooool0o_oooolEo`00o`Sooooo0Ol00001ooooo`0000?o0000ooooooooool0o_oooolEo`00
o`Sooooo0Ol00001ooooo`0000?o0000ooooooooool0o_oooolEo`00o`Sooooo0Ol00001ooooo`00
00?o0000ooooooooool0o_oooolEo`00o`Sooooo0Ol00001ooooo`0000?o0000ooooooooool0o_oo
oolEo`00o`Sooooo0Ol00001ooooo`0000?o0000ooooooooool01_ooool2oomo0?Kooooo5Ol00?l8
ooooo`7o00000Oooool00003o`000?oooooooooo00Gooooo1?ooO`0Cooooo`;oogl0h?oooolEo`00
o`Sooooo0Ol00001ooooo`0000?o0000ooooooooool01Oooool4oomo01;ooooo1?ooO`0Booooo`;o
ogl0booooolEo`00o`Sooooo0Ol00001ooooo`0000?o0000ooooooooool01Oooool3oomo01?ooooo
1?ooO`0Aooooo`Coogl0b_oooolEo`00o`Sooooo0Ol00001ooooo`0000?o0000ooooooooool01?oo
ool4oomo01Cooooo0_ooO`0Booooo`Coogl0b_oooolEo`00o`Sooooo0Ol00001ooooo`0000?o0000
ooooooooool01?ooool4oomo02Wooooo0_ooO`3;oooooaGo003o2?ooool1o`00007ooooo00000ol0
003oooooooooo`05ooooo`;oogl0mooooolEo`00o`Sooooo0Ol00001ooooo`0000?o0000oooooooo
ool0o_oooolEo`00o`Sooooo0Ol00001ooooo`0000?o0000ooooooooool0o_oooolEo`00o`Sooooo
0Ol00001ooooo`0000?o0000ooooooooool0o_oooolEo`00o`Sooooo0Ol00001ooooo`0000?o0000
ooooooooool0o_oooolEo`00o`Sooooo0Ol00001ooooo`0000?o0000ooooooooool0o_oooolEo`00
o`Sooooo0Ol00001ooooo`0000?o0000ooooooooool0o_oooolEo`00o`Sooooo0Ol00001ooooo`00
00?o0000ooooooooool0o_oooolEo`00o`Sooooo0Ol00001ooooo`0000?o0000ooooooooool0:_oo
ool6ool00<kooooo5Ol00?l8ooooo`7o00000Oooool00003o`000?oooooooooo02Wooooo00?oo`00
ooooooooool01?ooool5ool00<Wooooo5Ol00?l8ooooo`7o00000Oooool00003o`000?oooooooooo
02Oooooo0_oo000<ooooo`Coo`00aOoooolEo`00o`Sooooo0Ol00001ooooo`0000?o0000oooooooo
ool09_ooool00ooo003oooooooooo`0@ooooo`Coo`00`OoooolEo`00o`Sooooo0Ol00001ooooo`00
00?o0000ooooooooool09?ooool00oooO`3oo`00ooooo`09ooooo`;oogl02oooool3ool00;kooooo
5Ol00?l8ooooo`7o00000Oooool00003o`000?oooooooooo02?ooooo00Coogl0ool00?ooO`3oogl0
2?ooool4oomo00gooooo00?oo`00ooooooooool0^ooooolEo`00o`Sooooo0Ol00001ooooo`0000?o
0000ooooooooool08oooool01?ooO`3oo`00oomo0?ooO`08ooooo`Coogl03_ooool2ool00;_ooooo
5Ol00?l8ooooo`7o00000Oooool00003o`000?oooooooooo02Cooooo00?oogl0ool00?ooool02Ooo
ool2oomo017ooooo0_oo002ioooooaGo003o2?ooool1o`00007ooooo00000ol0003oooooooooo`0U
ooooo`03ool00?oooooooooo01gooooo0_oo002goooooaGo003o2?ooool1o`00007ooooo00000ol0
003oooooooooo`0Uooooo`03ool00?oooooooooo01oooooo0_oo002eoooooaGo003o2?ooool1o`00
007ooooo00000ol0003oooooooooo`0Vooooo`03ool00?oooooooooo017ooooo0_ooO`0=ooooo`;o
o`001?ooool2oomo00Oooooo0_ooO`2ToooooaGo003o2?ooool1o`00007ooooo00000ol0003ooooo
ooooo`0Vooooo`03ool00?oooooooooo00Gooooo0_ooO`09ooooo`Coogl03_ooool00ooo003ooooo
ooooo`04oomo00Gooooo1?ooO`2SoooooaGo003o2?ooool1o`00007ooooo00000ol0003ooooooooo
o`0Vooooo`03ool00?oooooooooo00Cooooo1?ooO`08ooooo`Coogl03oooool00ooo003ooooooomo
0003oomo00Gooooo1?ooO`2SoooooaGo003o2?ooool1o`00007ooooo00000ol0003oooooooooo`0W
ooooo`03ool00?oooooooooo00?ooooo1?ooO`09ooooo`;oogl04Oooool01?oo003ooooooomo0?oo
O`07ooooo`?oogl0XooooolEo`00o`Sooooo0Ol00001ooooo`0000?o0000ooooooooool09oooool0
0ooo003oooooooooo`04ooooo`;oogl07_ooool00ooo003oooooooooo`07ooooo`Coogl0X_oooolE
o`00o`Sooooo0Ol00001ooooo`0000?o0000ooooooooool0:?ooool00ooo003oooooooooo`0Toooo
o`03ool00?oooooooooo00Kooooo1?ooO`2RoooooaGo003o2?ooool1o`00007ooooo00000ol0003o
ooooooooo`0Yooooo`03ool00?oooooooooo02Cooooo0_oo00000oooooooogl0oomo0004ooooo`;o
ogl0XooooolEo`00o`Sooooo0Ol00001ooooo`0000?o0000ooooooooool0:_ooool00ooo003ooooo
ooooo`0Cooooo`Coo`003_ooool01?oo003oogl0oomo0?ooO`2XoooooaGo003o2?ooool1o`00007o
oooo00000ol0003oooooooooo`0[ooooo`03ool00?oooooooooo017ooooo1_oo000=ooooo`04oomo
0?oo003oo`00oomo0:Sooooo5Ol00?l8ooooo`7o00000Oooool00003o`000?oooooooooo02cooooo
00?oo`00ooooooooool02?ooool2oomo00Gooooo2?oo000=ooooo`;oogl000?oo`00ooooooooool0
Y_oooolEo`00o`Sooooo0Ol00001ooooo`0000?o0000ooooooooool0;Oooool00ooo003ooooooooo
o`06ooooo`Coogl01?ooool8ool0013ooooo00?oo`00ooooooooool0YOoooolEo`00o`Sooooo0Ol0
0001ooooo`0000?o0000ooooooooool0:oooool2oomo0003oooooooo003ooooo00Kooooo1?ooO`04
ooooo`Soo`004Oooool00ooo003oooooooooo`2ToooooaGo003o2?ooool1o`00007ooooo00000ol0
003oooooooooo`0Zooooo`Coogl000?oooooool00?ooool01_ooool2oomo00Gooooo2?oo000;oooo
o`;oogl01Oooool00ooo003oooooooooo`09ooooo`;oogl0V?oooolEo`00o`Sooooo0Ol00001oooo
o`0000?o0000ooooooooool0:_ooool4oomo00;ooooo00?oo`00ooooooooool03?ooool6ool000_o
oooo1?ooO`04ooooo`03ool00?oooooooooo00Sooooo1?ooO`2GoooooaGo003o2?ooool1o`00007o
oooo00000ol0003oooooooooo`0[ooooo`;oogl01?ooool00ooo003oooooooooo`0<ooooo`Coo`00
3?ooool4oomo00Gooooo00?oo`00ooooooooool01oooool4oomo09Oooooo5Ol00?l8ooooo`7o0000
0Oooool00003o`000?oooooooooo03;ooooo0_oo000Mooooo`;oogl01oooool00ooo003ooooooooo
o`07ooooo`;oogl0]Oooool1o`00007ooooo00000ol0003oooooooooo`0dooooo`03ool00?oooooo
oooo02Cooooo00?oo`00ooooooooool0_Oooool1o`00007ooooo00000ol0003oooooooooo`0eoooo
o`03ool00?oooooooooo02Cooooo00?oo`00ooooooooool0_?ooool1o`00007ooooo00000ol0003o
ooooooooo`0fooooo`;oo`009Oooool00ooo003oooooooooo`2kooooo`7o00000Oooool00003o`00
0?oooooooooo03Sooooo0_oo00000oooO`3oooooooooo`02oomo01kooooo00?oo`00ooooooooool0
^oooool1o`00007ooooo00000ol0003oooooooooo`0hooooo`;oogl00_oo0004oomo01kooooo00?o
o`00ooooooooool0^_ooool1o`00007ooooo00000ol0003oooooooooo`0hooooo`Coogl00_oo0002
oomo01kooooo00?oo`00ooooooooool0^_ooool1o`00007ooooo00000ol0003oooooooooo`0ioooo
o`Googl000?oo`00ooooooooool07Oooool00ooo003oogl0oomo002jooooo`7o00000Oooool00003
o`000?oooooooooo03_ooooo1?ooO`02ool001gooooo00Coogl0ool00?ooO`3oogl0^Oooool1o`00
007ooooo00000ol0003oooooooooo`0looooo`;oogl00oooool2ool001_ooooo00Coogl0ool00?oo
O`3oogl0^Oooool1o`00007ooooo00000ol0003oooooooooo`13ooooo`;oo`006_ooool00oooO`3o
o`00ooooo`2iooooo`7o00000Oooool00003o`000?oooooooooo04Gooooo0_oo000Iooooo`03ool0
0?oooooooooo0;Sooooo0Ol00001ooooo`0000?o0000ooooooooool0Aoooool2ool001Gooooo0_oo
002kooooo`7o00000Oooool00003o`000?oooooooooo04Wooooo0ooo000@ooooo`;oo`00_Oooool1
o`00007ooooo00000ol0003oooooooooo`0aooooo`;oogl06Oooool3ool000cooooo00?oo`00oooo
ooooool0_Oooool1o`00007ooooo00000ol0003oooooooooo`0`ooooo`Coogl06oooool6ool000Co
oooo0_oo0030ooooo`7o00000Oooool00003o`000?oooooooooo033ooooo1?ooO`0Qooooo`Coo`00
`_ooool1o`00007ooooo00000ol0003oooooooooo`0aooooo`;oogl0j?ooool1o`00007ooooo0000
0ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLoooo
o`7o00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003ooooo
ooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Ooo
ool00003o`000?oooooooooo07gooooo0_ooO`2Looooo`7o00000Oooool00003o`000?oooooooooo
07cooooo1?ooO`2Kooooo`7o00000Oooool00003o`000?oooooooooo05Cooooo0_ooO`0Vooooo`Co
ogl0Voooool1o`00007ooooo00000ol0003oooooooooo`1Cooooo`Coogl09_ooool2oomo09cooooo
0Ol00001ooooo`0000?o0000ooooooooool0Doooool4oomo0<Cooooo0Ol00001ooooo`0000?o0000
ooooooooool0E?ooool2oomo0<Gooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLoooo
o`7o00000Oooool00003o`000?oooooooooo06?ooooo0_ooO`04ooooo`;oogl0/?ooool1o`00007o
oooo00000ol0003oooooooooo`1Rooooo`Coogl00_ooool4oomo0:oooooo0Ol00001ooooo`0000?o
0000ooooooooool0H_ooool4oomo00;ooooo1?ooO`2_ooooo`7o00000Oooool00003o`000?oooooo
oooo06?ooooo0_ooO`04ooooo`;oogl0/?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooo
oacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`00
0?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol0
0001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo
0?oooooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`00
00?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?oo
ool1o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000oooo
ooooool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007o
oooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooo
oolLooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0
003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o
00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003ooooooooo
o`3ooooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool0
0003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooooaco
oooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oo
oooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001
ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo0?oo
oooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o
0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1
o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000oooooooo
ool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo
00000ol0003oooooooooo`3oooooo`Cooooo0_ooO`0Fooooo`7o00000Oooool00003o`000?oooooo
oooo0?oooooo0oooool4oomo01Gooooo0Ol00001ooooo`0000?o0000ooooooooool0ooooool3oooo
o`Coogl05Oooool1o`00007ooooo00000ol0003oooooooooo`3oooooo`Cooooo0_ooO`0Fooooo`7o
00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003ooooooooo
o`3ooooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool0
0003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooooaco
oooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oo
oooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001
ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo0?oo
oooo7?ooool1o`00007ooooo00000ol0003oooooooooo`2eooooo`;oogl0I?ooool1o`00007ooooo
00000ol0003oooooooooo`2dooooo`Coogl0Hoooool1o`00007ooooo00000ol0003oooooooooo`2d
ooooo`Coogl0Hoooool1o`00007ooooo00000ol0003oooooooooo`2eooooo`;oogl0=Oooool2oomo
02gooooo0Ol00001ooooo`0000?o0000ooooooooool0i?ooool2oomo00Gooooo1?ooO`0/ooooo`7o
00000Oooool00003o`000?oooooooooo0>?ooooo1?ooO`04ooooo`Coogl0;?ooool1o`00007ooooo
00000ol0003oooooooooo`33ooooo`;oogl07_ooool4oomo00Gooooo0_ooO`0]ooooo`7o00000Ooo
ool00003o`000?oooooooooo0<;ooooo1?ooO`0;o`00oa?ooooo0_ooO`0eooooo`7o00000Oooool0
0003o`000?oooooooooo0<;ooooo1?l00?l;ooooo`;o003oB?ooool1o`00007ooooo00000ol0003o
ooooooooo`2nooooo`Co003o00?ooooooomo0?ooO`003_ooool2o`00odKooooo0Ol00001ooooo`00
00?o0000ooooooooool0^Oooool2oomo00?o003o5oooool2o`00o`Wooooo0_ooO`0iooooo`7o0000
0Oooool00003o`000?oooooooooo0;Oooooo1?l00?l00oooO`3oooooooooo`0Iooooo`;o003o1_oo
ool4oomo03Sooooo0Ol00001ooooo`0000?o0000ooooooooool0]?ooool3o`00o`03ooooooooO`3o
ogl000;oogl07?ooool00ol00?ooooooooooo`04ooooo`Coogl00oooool2oomo03?ooooo0Ol00001
ooooo`0000?o0000ooooooooool0/_ooool2o`00o`?oogl00_ooool2oomo01?ooooo0_ooO`08oooo
o`03o`00oooooooooooo00Gooooo0_ooO`03ooooo`Coogl0<_ooool1o`00007ooooo00000ol0003o
ooooooooo`2`ooooo`;o003o00?ooooooomo0?ooO`000_ooO`06ooooo`;oogl03_ooool4oomo00Oo
oooo00?o003oooooooooool02_ooool4oomo03;ooooo0Ol00001ooooo`0000?o0000ooooooooool0
[_ooool2o`00o`Cooooo0_ooO`06ooooo`Coogl03Oooool4oomo00Oooooo00?o003oooooooooool0
2oooool2oomo03?ooooo0Ol00001ooooo`0000?o0000ooooooooool0Roooool2oomo023ooooo00?o
003oooooooooool01?ooool2oomo00Kooooo1?ooO`0>ooooo`;oogl02Oooool00ol00?oooooooooo
o`0oooooo`7o00000Oooool00003o`000?oooooooooo08[ooooo1?ooO`0Mooooo`;o003o1_ooool4
oomo00Kooooo0_ooO`0Jooooo`03o`00oooooooooooo03oooooo0Ol00001ooooo`0000?o0000oooo
ooooool0R_ooool4oomo01cooooo00?o003oooooooooool01_ooool4oomo02;ooooo00?o003ooooo
ooooool0?oooool1o`00007ooooo00000ol0003oooooooooo`2;ooooo`;oogl06oooool2o`00o`[o
oooo0_ooO`0Sooooo`03o`00oooooooooooo03oooooo0Ol00001ooooo`0000?o0000ooooooooool0
U_ooool2oomo00kooooo0_l00?lZooooo`;oogl01Oooool00ol00?ooooooooooo`0oooooo`7o0000
0Oooool00003o`000?oooooooooo09Gooooo1?ooO`0<ooooo`04o`00ooooooooogl0oomo02Sooooo
1?ooO`03ooooo`03o`00oooooooooooo043ooooo0Ol00001ooooo`0000?o0000ooooooooool0UOoo
ool4oomo00[ooooo0_l00?l00oooooooogl0oomo0002oomo02Oooooo1?ooO`03ooooo`03o`00oooo
oooooooo043ooooo0Ol00001ooooo`0000?o0000ooooooooool0U_ooool2oomo00[ooooo00Co003o
oooooooooooooooo1?ooO`0Xooooo`;oogl01?ooool00ol00?ooooooooooo`10ooooo`7o00000Ooo
ool00003o`000?oooooooooo0:7ooooo00?o003oooooooooool00oooool2oomo02kooooo00?o003o
ooooooooool0@Oooool1o`00007ooooo00000ol0003oooooooooo`2Pooooo`03o`00oooooooooooo
03?ooooo00?o003oooooooooool04_ooool2oomo02kooooo0Ol00001ooooo`0000?o0000oooooooo
ool0W_ooool2o`00ocGooooo00?o003oooooooooool04_ooool4oomo02gooooo0Ol00001ooooo`00
00?o0000ooooooooool0WOooool00ol00?ooooooooooo`0Eooooo`Co003o7?ooool00ol00?ooogl0
oomo000Booooo`Coogl0;Oooool1o`00007ooooo00000ol0003oooooooooo`2Looooo`03o`00oooo
oooooooo01Gooooo1_l00?lJooooo`03o`00ooooO`3oogl000;oogl04_ooool2oomo02kooooo0Ol0
0001ooooo`0000?o0000ooooooooool0Voooool00ol00?ooooooooooo`0Eooooo`So003o5_ooool5
ool0o`?oogl0@_ooool1o`00007ooooo00000ol0003oooooooooo`2Kooooo`03o`00oooooooooooo
01Gooooo2?l00?lEooooo`Ooo`3o00?oogl0ooooooooool0@Oooool1o`00007ooooo00000ol0003o
ooooooooo`2Jooooo`03o`00oooooooooooo01Kooooo2?l00?lDooooo`Woo`3o@oooool1o`00007o
oooo00000ol0003oooooooooo`2Iooooo`03o`00oooooooooooo00cooooo0_ooO`08ooooo`03oomo
0?l00?oo003o00Ko003o4oooool;ool0od;ooooo0Ol00001ooooo`0000?o0000ooooooooool0VOoo
ool00ol00?ooooooooooo`0:ooooo`Googl01oooool2oomo00Ko003o4oooool00oooO`3oo`3oool0
o`09ool0od;ooooo0Ol00001ooooo`0000?o0000ooooooooool0V?ooool00ol00?ooooooooooo`0:
ooooo`Koogl02?ooool2oomo00Co003o4oooool2oomo00_oo`3o@_ooool1o`00007ooooo00000ol0
003oooooooooo`2Hooooo`03o`00oooooooooooo00[ooooo1OooO`0Rooooo`03oomo0?l00?ooo`3o
00[oo`3o@_ooool1o`00007ooooo00000ol0003oooooooooo`1fooooo`;oogl07oooool00ol00?oo
ooooooooo`0<ooooo`;oogl09?ooool00ol00?ooogl0ool0o`0:ool0od;ooooo0Ol00001ooooo`00
00?o0000ooooooooool0MOooool4oomo01kooooo00?o003oooooooooool0<Oooool01?l00?oooooo
ooooooooool9ool0od?ooooo0Ol00001ooooo`0000?o0000ooooooooool0MOooool4oomo00[ooooo
0_ooO`0Aooooo`03o`00oooooooooooo037ooooo00?o003oooooooooool00oooool7ool0odCooooo
0Ol00001ooooo`0000?o0000ooooooooool0M_ooool2oomo00[ooooo1?ooO`0?ooooo`03o`00oooo
oooooooo01Sooooo0_ooO`0Gooooo`03o`00oooooooooooo00Gooooo1Ooo0?m5ooooo`7o00000Ooo
ool00003o`000?oooooooooo08;ooooo1?ooO`0?ooooo`03o`00oooooooooooo01Oooooo1?ooO`0D
ooooo`;o003oD_ooool1o`00007ooooo00000ol0003oooooooooo`23ooooo`;oogl03oooool00ol0
0?ooooooooooo`0Booooo`;oogl01?ooool4oomo017ooooo0ol00?mDooooo`7o00000Oooool00003
o`000?oooooooooo09Cooooo00?o003oooooooooool04Oooool4oomo00Cooooo0_ooO`0@ooooo`;o
003oEoooool1o`00007ooooo00000ol0003oooooooooo`2Dooooo`03o`00oooooooooooo017ooooo
1?ooO`0Eooooo`03o`00oooooooooooo05Oooooo0Ol00001ooooo`0000?o0000ooooooooool0U?oo
ool00ol00?ooooooooooo`0Booooo`;oogl05?ooool2o`00oe[ooooo0Ol00001ooooo`0000?o0000
ooooooooool0U?ooool00ol00?ooooooooooo`0Vooooo`;o003oG?ooool1o`00007ooooo00000ol0
003oooooooooo`2Eooooo`03o`00oooooooooooo02Cooooo00?o003oooooooooool0G?ooool1o`00
007ooooo00000ol0003oooooooooo`2Eooooo`03o`00oooooooooooo02;ooooo0_l00?mOooooo`7o
00000Oooool00003o`000?oooooooooo09Gooooo00?o003oooooooooool08?ooool2o`00of7ooooo
0Ol00001ooooo`0000?o0000ooooooooool0Q?ooool2oomo00oooooo0_l00?lOooooo`;o003oHooo
ool1o`00007ooooo00000ol0003oooooooooo`23ooooo`Coogl04?ooool2o`00oa[ooooo0ol00?mU
ooooo`7o00000Oooool00003o`000?oooooooooo08?ooooo1?ooO`0Booooo`;o003o5?ooool4o`00
ofSooooo0Ol00001ooooo`0000?o0000ooooooooool0Q?ooool2oomo01Gooooo0ol00?l>ooooo`?o
003o0oooool2oomo06Oooooo0Ol00001ooooo`0000?o0000ooooooooool0W_ooool3o`00o`Gooooo
1_l00?l5ooooo`Coogl0I_ooool1o`00007ooooo00000ol0003oooooooooo`2Qooooo`Go003o2ooo
ool4oomo06Kooooo0Ol00001ooooo`0000?o0000ooooooooool0/_ooool2oomo06Oooooo0Ol00001
ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo0?oo
oooo7?ooool1o`00007ooooo00000ol0003oooooooooo`1kooooo`;oogl0W_ooool1o`00007ooooo
00000ol0003oooooooooo`1jooooo`Coogl0WOooool1o`00007ooooo00000ol0003oooooooooo`1j
ooooo`Coogl08?ooool2oomo07_ooooo0Ol00001ooooo`0000?o0000ooooooooool0Noooool2oomo
023ooooo1?ooO`1jooooo`7o00000Oooool00003o`000?oooooooooo09gooooo1?ooO`1jooooo`7o
00000Oooool00003o`000?oooooooooo093ooooo0_ooO`0<ooooo`;oogl0Noooool1o`00007ooooo
00000ol0003oooooooooo`2?ooooo`Coogl0R?ooool1o`00007ooooo00000ol0003oooooooooo`2?
ooooo`Coogl0R?ooool1o`00007ooooo00000ol0003oooooooooo`2@ooooo`;oogl08oooool2oomo
06Cooooo0Ol00001ooooo`0000?o0000ooooooooool0]?ooool4oomo06?ooooo0Ol00001ooooo`00
00?o0000ooooooooool0]?ooool4oomo06?ooooo0Ol00001ooooo`0000?o0000ooooooooool0]Ooo
ool2oomo06Cooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool0
0003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooooaco
oooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oo
oooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001
ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo0?oo
oooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o
0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1
o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000oooooooo
ool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo
00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolL
ooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003o
ooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o0000
0Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3o
oooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003
o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo
0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oooooo
oooo0?oooooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001oooo
o`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo
7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000
ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00
007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0
oooooolLooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo0000
0ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLoooo
o`7o00000Oooool00003o`000?oooooooooo08kooooo0_ooO`2;ooooo`7o00000Oooool00003o`00
0?oooooooooo08gooooo1?ooO`2:ooooo`7o00000Oooool00003o`000?oooooooooo08gooooo1?oo
O`2:ooooo`7o00000Oooool00003o`000?oooooooooo08kooooo0_ooO`2;ooooo`7o00000Oooool0
0003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooooaco
oooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oo
oooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001
ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo0?oo
oooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o
0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1
o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000oooooooo
ool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo
00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolL
ooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003o
ooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o0000
0Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3o
oooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool00?oo
00008?l00001ooooo`00\
\>"],
  ImageRangeCache->{{{0, 287}, {287, 0}} -> {-1.01089, -1.01089, 0.00704453, \
0.00704453}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.49505 0.5 0.49505 [
[ 0 0 -0.125 0 ]
[ 0 0 -0.125 0 ]
[ 0 1 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
0 0 m
1 0 L
s
0 0 m
0 1 L
s
0 1 m
1 1 L
s
1 0 m
1 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
1 .5 0 r
.015 w
.03175 .1355 Mdot
.03435 .12523 Mdot
.11137 .12765 Mdot
.14107 .18841 Mdot
.16218 .24538 Mdot
.17294 .21053 Mdot
.18267 .18577 Mdot
.18434 .1304 Mdot
.18553 .30956 Mdot
.20401 .239 Mdot
.21247 .27571 Mdot
.21687 .20845 Mdot
.22376 .2799 Mdot
.22832 .27485 Mdot
.29063 .20974 Mdot
.29686 .25079 Mdot
.30487 .22936 Mdot
.30683 .34623 Mdot
.32055 .20902 Mdot
.32574 .21979 Mdot
.34472 .28521 Mdot
.35998 .36393 Mdot
.36335 .24976 Mdot
.3794 .36608 Mdot
.42386 .66992 Mdot
.44391 .74519 Mdot
.45059 .34198 Mdot
.47208 .67586 Mdot
.47436 .71381 Mdot
.49778 .59825 Mdot
.50874 .91643 Mdot
.51516 .76219 Mdot
.53655 .61374 Mdot
.56563 .75219 Mdot
.59189 .65665 Mdot
.59581 .61604 Mdot
.59923 .6556 Mdot
.60292 .68499 Mdot
.62656 .67779 Mdot
.63555 .72451 Mdot
.63919 .652 Mdot
.64169 .6004 Mdot
.64246 .58611 Mdot
.64496 .54267 Mdot
.64608 .77288 Mdot
.65077 .64308 Mdot
.66065 .57816 Mdot
.67474 .59169 Mdot
.69296 .563 Mdot
.72815 .65902 Mdot
.73169 .58879 Mdot
.74669 .61318 Mdot
.74821 .65474 Mdot
.75963 .63781 Mdot
.79673 .57809 Mdot
.80925 .55852 Mdot
.81525 .58444 Mdot
.83417 .62985 Mdot
.83598 .55526 Mdot
.91595 .49319 Mdot
1 0 0 r
.005 w
.16128 .17044 m
.18734 .17269 L
.21339 .17909 L
.2345 .18734 L
.23945 .19126 L
.2655 .20415 L
.27874 .21339 L
.29156 .22295 L
.31204 .23945 L
.31761 .24532 L
.33549 .2655 L
.34367 .28341 L
.34499 .29156 L
.34367 .29798 L
.31761 .3104 L
.29156 .30711 L
.2655 .30014 L
.24507 .29156 L
.23945 .28747 L
.21339 .27402 L
.20155 .2655 L
.18734 .25472 L
.16884 .23945 L
.16128 .2313 L
.14618 .21339 L
.13806 .18734 L
.16128 .17044 L
s
0 0 1 r
.65633 .57701 m
.68239 .56842 L
.70844 .56313 L
.7345 .56168 L
.76055 .5752 L
.76359 .57817 L
.76859 .60422 L
.76055 .62333 L
.75627 .63028 L
.7345 .65485 L
.73298 .65633 L
.70844 .6775 L
.69922 .68239 L
.68239 .69294 L
.65633 .70579 L
.64983 .70844 L
.63028 .71539 L
.60422 .72268 L
.57817 .72651 L
.55211 .7214 L
.53145 .70844 L
.52926 .68239 L
.54239 .65633 L
.55211 .63983 L
.56625 .63028 L
.57817 .6193 L
.60119 .60422 L
.60422 .60227 L
.63028 .58726 L
.65315 .57817 L
.65633 .57701 L
s
1 0 0 r
.03 w
.24141 .24033 Mdot
0 0 1 r
.64872 .64417 Mdot
1 0 0 r
.79703 .00495 m
.79703 .00495 L
.87129 .00495 L
.87129 .00495 L
F
0 0 1 r
.89604 .00495 m
.89604 .25248 L
.9703 .25248 L
.9703 .00495 L
F
1 0 1 r
.04 w
.75963 .63781 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P000182000`400?l00000o`00003ooooooolQ
ooooo`00ool0000Po`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`00
00?o0000ooooooooool0o_oooolEo`00o`Sooooo0Ol00001ooooo`0000?o0000ooooooooool0o_oo
oolEo`00o`Sooooo0Ol00001ooooo`0000?o0000ooooooooool0o_oooolEo`00o`Sooooo0Ol00001
ooooo`0000?o0000ooooooooool0o_oooolEo`00o`Sooooo0Ol00001ooooo`0000?o0000oooooooo
ool0o_oooolEo`00o`Sooooo0Ol00001ooooo`0000?o0000ooooooooool0o_oooolEo`00o`Sooooo
0Ol00001ooooo`0000?o0000ooooooooool0o_oooolEo`00o`Sooooo0Ol00001ooooo`0000?o0000
ooooooooool0o_oooolEo`00o`Sooooo0Ol00001ooooo`0000?o0000ooooooooool0o_oooolEo`00
o`Sooooo0Ol00001ooooo`0000?o0000ooooooooool0o_oooolEo`00o`Sooooo0Ol00001ooooo`00
00?o0000ooooooooool0o_oooolEo`00o`Sooooo0Ol00001ooooo`0000?o0000ooooooooool0o_oo
oolEo`00o`Sooooo0Ol00001ooooo`0000?o0000ooooooooool0o_oooolEo`00o`Sooooo0Ol00001
ooooo`0000?o0000ooooooooool0o_oooolEo`00o`Sooooo0Ol00001ooooo`0000?o0000oooooooo
ool0o_oooolEo`00o`Sooooo0Ol00001ooooo`0000?o0000ooooooooool0o_oooolEo`00o`Sooooo
0Ol00001ooooo`0000?o0000ooooooooool0o_oooolEo`00o`Sooooo0Ol00001ooooo`0000?o0000
ooooooooool0o_oooolEo`00o`Sooooo0Ol00001ooooo`0000?o0000ooooooooool0o_oooolEo`00
o`Sooooo0Ol00001ooooo`0000?o0000ooooooooool0o_oooolEo`00o`Sooooo0Ol00001ooooo`00
00?o0000ooooooooool0o_oooolEo`00o`Sooooo0Ol00001ooooo`0000?o0000ooooooooool0o_oo
oolEo`00o`Sooooo0Ol00001ooooo`0000?o0000ooooooooool0o_oooolEo`00o`Sooooo0Ol00001
ooooo`0000?o0000ooooooooool0o_oooolEo`00o`Sooooo0Ol00001ooooo`0000?o0000oooooooo
ool0o_oooolEo`00o`Sooooo0Ol00001ooooo`0000?o0000ooooooooool0o_oooolEo`00o`Sooooo
0Ol00001ooooo`0000?o0000ooooooooool0o_oooolEo`00o`Sooooo0Ol00001ooooo`0000?o0000
ooooooooool0o_oooolEo`00o`Sooooo0Ol00001ooooo`0000?o0000ooooooooool0o_oooolEo`00
o`Sooooo0Ol00001ooooo`0000?o0000ooooooooool0o_oooolEo`00o`Sooooo0Ol00001ooooo`00
00?o0000ooooooooool0o_oooolEo`00o`Sooooo0Ol00001ooooo`0000?o0000ooooooooool0o_oo
oolEo`00o`Sooooo0Ol00001ooooo`0000?o0000ooooooooool01_ooool2oomo0?Kooooo5Ol00?l8
ooooo`7o00000Oooool00003o`000?oooooooooo00Gooooo1?ooO`0Cooooo`;oogl0h?oooolEo`00
o`Sooooo0Ol00001ooooo`0000?o0000ooooooooool01Oooool4oomo01;ooooo1?ooO`0Booooo`;o
ogl0booooolEo`00o`Sooooo0Ol00001ooooo`0000?o0000ooooooooool01Oooool3oomo01?ooooo
1?ooO`0Aooooo`Coogl0b_oooolEo`00o`Sooooo0Ol00001ooooo`0000?o0000ooooooooool01?oo
ool4oomo01Cooooo0_ooO`0Booooo`Coogl0b_oooolEo`00o`Sooooo0Ol00001ooooo`0000?o0000
ooooooooool01?ooool4oomo02Wooooo0_ooO`3;oooooaGo003o2?ooool1o`00007ooooo00000ol0
003oooooooooo`05ooooo`;oogl0mooooolEo`00o`Sooooo0Ol00001ooooo`0000?o0000oooooooo
ool0o_oooolEo`00o`Sooooo0Ol00001ooooo`0000?o0000ooooooooool0o_oooolEo`00o`Sooooo
0Ol00001ooooo`0000?o0000ooooooooool0o_oooolEo`00o`Sooooo0Ol00001ooooo`0000?o0000
ooooooooool0o_oooolEo`00o`Sooooo0Ol00001ooooo`0000?o0000ooooooooool0o_oooolEo`00
o`Sooooo0Ol00001ooooo`0000?o0000ooooooooool0o_oooolEo`00o`Sooooo0Ol00001ooooo`00
00?o0000ooooooooool0o_oooolEo`00o`Sooooo0Ol00001ooooo`0000?o0000ooooooooool0:_oo
ool6ool00<kooooo5Ol00?l8ooooo`7o00000Oooool00003o`000?oooooooooo02Wooooo00?oo`00
ooooooooool01?ooool5ool00<Wooooo5Ol00?l8ooooo`7o00000Oooool00003o`000?oooooooooo
02Oooooo0_oo000<ooooo`Coo`00aOoooolEo`00o`Sooooo0Ol00001ooooo`0000?o0000oooooooo
ool09_ooool00ooo003oooooooooo`0@ooooo`Coo`00`OoooolEo`00o`Sooooo0Ol00001ooooo`00
00?o0000ooooooooool09?ooool00oooO`3oo`00ooooo`09ooooo`;oogl02oooool3ool00;kooooo
5Ol00?l8ooooo`7o00000Oooool00003o`000?oooooooooo02?ooooo00Coogl0ool00?ooO`3oogl0
2?ooool4oomo00gooooo00?oo`00ooooooooool0^ooooolEo`00o`Sooooo0Ol00001ooooo`0000?o
0000ooooooooool08oooool01?ooO`3oo`00oomo0?ooO`08ooooo`Coogl03_ooool2ool00;_ooooo
5Ol00?l8ooooo`7o00000Oooool00003o`000?oooooooooo02Cooooo00?oogl0ool00?ooool02Ooo
ool2oomo017ooooo0_oo002ioooooaGo003o2?ooool1o`00007ooooo00000ol0003oooooooooo`0U
ooooo`03ool00?oooooooooo01gooooo0_oo002goooooaGo003o2?ooool1o`00007ooooo00000ol0
003oooooooooo`0Uooooo`03ool00?oooooooooo01oooooo0_oo002eoooooaGo003o2?ooool1o`00
007ooooo00000ol0003oooooooooo`0Vooooo`03ool00?oooooooooo017ooooo0_ooO`0=ooooo`;o
o`001?ooool2oomo00Oooooo0_ooO`2ToooooaGo003o2?ooool1o`00007ooooo00000ol0003ooooo
ooooo`0Vooooo`03ool00?oooooooooo00Gooooo0_ooO`09ooooo`Coogl03_ooool00ooo003ooooo
ooooo`04oomo00Gooooo1?ooO`2SoooooaGo003o2?ooool1o`00007ooooo00000ol0003ooooooooo
o`0Vooooo`03ool00?oooooooooo00Cooooo1?ooO`08ooooo`Coogl03oooool00ooo003ooooooomo
0003oomo00Gooooo1?ooO`2SoooooaGo003o2?ooool1o`00007ooooo00000ol0003oooooooooo`0W
ooooo`03ool00?oooooooooo00?ooooo1?ooO`09ooooo`;oogl04Oooool01?oo003ooooooomo0?oo
O`07ooooo`?oogl0XooooolEo`00o`Sooooo0Ol00001ooooo`0000?o0000ooooooooool09oooool0
0ooo003oooooooooo`04ooooo`;oogl07_ooool00ooo003oooooooooo`07ooooo`Coogl0X_oooolE
o`00o`Sooooo0Ol00001ooooo`0000?o0000ooooooooool0:?ooool00ooo003oooooooooo`0Toooo
o`03ool00?oooooooooo00Kooooo1?ooO`2RoooooaGo003o2?ooool1o`00007ooooo00000ol0003o
ooooooooo`0Yooooo`03ool00?oooooooooo02Cooooo0_oo00000oooooooogl0oomo0004ooooo`;o
ogl0XooooolEo`00o`Sooooo0Ol00001ooooo`0000?o0000ooooooooool0:_ooool00ooo003ooooo
ooooo`0Cooooo`Coo`003_ooool01?oo003oogl0oomo0?ooO`2XoooooaGo003o2?ooool1o`00007o
oooo00000ol0003oooooooooo`0[ooooo`03ool00?oooooooooo017ooooo1_oo000=ooooo`04oomo
0?oo003oo`00oomo0:Sooooo5Ol00?l8ooooo`7o00000Oooool00003o`000?oooooooooo02cooooo
00?oo`00ooooooooool02?ooool2oomo00Gooooo2?oo000=ooooo`;oogl000?oo`00ooooooooool0
Y_oooolEo`00o`Sooooo0Ol00001ooooo`0000?o0000ooooooooool0;Oooool00ooo003ooooooooo
o`06ooooo`Coogl01?ooool8ool0013ooooo00?oo`00ooooooooool0YOoooolEo`00o`Sooooo0Ol0
0001ooooo`0000?o0000ooooooooool0:oooool2oomo0003oooooooo003ooooo00Kooooo1?ooO`04
ooooo`Soo`004Oooool00ooo003oooooooooo`2ToooooaGo003o2?ooool1o`00007ooooo00000ol0
003oooooooooo`0Zooooo`Coogl000?oooooool00?ooool01_ooool2oomo00Gooooo2?oo000;oooo
o`;oogl01Oooool00ooo003oooooooooo`09ooooo`;oogl0V?oooolEo`00o`Sooooo0Ol00001oooo
o`0000?o0000ooooooooool0:_ooool4oomo00;ooooo00?oo`00ooooooooool03?ooool6ool000_o
oooo1?ooO`04ooooo`03ool00?oooooooooo00Sooooo1?ooO`2GoooooaGo003o2?ooool1o`00007o
oooo00000ol0003oooooooooo`0[ooooo`;oogl01?ooool00ooo003oooooooooo`0<ooooo`Coo`00
3?ooool4oomo00Gooooo00?oo`00ooooooooool01oooool4oomo09Oooooo5Ol00?l8ooooo`7o0000
0Oooool00003o`000?oooooooooo03;ooooo0_oo000Mooooo`;oogl01oooool00ooo003ooooooooo
o`07ooooo`;oogl0]Oooool1o`00007ooooo00000ol0003oooooooooo`0dooooo`03ool00?oooooo
oooo02Cooooo00?oo`00ooooooooool0_Oooool1o`00007ooooo00000ol0003oooooooooo`0eoooo
o`03ool00?oooooooooo02Cooooo00?oo`00ooooooooool0_?ooool1o`00007ooooo00000ol0003o
ooooooooo`0fooooo`;oo`009Oooool00ooo003oooooooooo`2kooooo`7o00000Oooool00003o`00
0?oooooooooo03Sooooo0_oo00000oooO`3oooooooooo`02oomo01kooooo00?oo`00ooooooooool0
^oooool1o`00007ooooo00000ol0003oooooooooo`0hooooo`;oogl00_oo0004oomo01kooooo00?o
o`00ooooooooool0^_ooool1o`00007ooooo00000ol0003oooooooooo`0hooooo`Coogl00_oo0002
oomo01kooooo00?oo`00ooooooooool0^_ooool1o`00007ooooo00000ol0003oooooooooo`0ioooo
o`Googl000?oo`00ooooooooool07Oooool00ooo003oogl0oomo002jooooo`7o00000Oooool00003
o`000?oooooooooo03_ooooo1?ooO`02ool001gooooo00Coogl0ool00?ooO`3oogl0^Oooool1o`00
007ooooo00000ol0003oooooooooo`0looooo`;oogl00oooool2ool001_ooooo00Coogl0ool00?oo
O`3oogl0^Oooool1o`00007ooooo00000ol0003oooooooooo`13ooooo`;oo`006_ooool00oooO`3o
o`00ooooo`2iooooo`7o00000Oooool00003o`000?oooooooooo04Gooooo0_oo000Iooooo`03ool0
0?oooooooooo0;Sooooo0Ol00001ooooo`0000?o0000ooooooooool0Aoooool2ool001Gooooo0_oo
002kooooo`7o00000Oooool00003o`000?oooooooooo04Wooooo0ooo000@ooooo`;oo`00_Oooool1
o`00007ooooo00000ol0003oooooooooo`0aooooo`;oogl06Oooool3ool000cooooo00?oo`00oooo
ooooool0_Oooool1o`00007ooooo00000ol0003oooooooooo`0`ooooo`Coogl06oooool6ool000Co
oooo0_oo0030ooooo`7o00000Oooool00003o`000?oooooooooo033ooooo1?ooO`0Qooooo`Coo`00
`_ooool1o`00007ooooo00000ol0003oooooooooo`0aooooo`;oogl0j?ooool1o`00007ooooo0000
0ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLoooo
o`7o00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003ooooo
ooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Ooo
ool00003o`000?oooooooooo07gooooo0_ooO`2Looooo`7o00000Oooool00003o`000?oooooooooo
07cooooo1?ooO`2Kooooo`7o00000Oooool00003o`000?oooooooooo05Cooooo0_ooO`0Vooooo`Co
ogl0Voooool1o`00007ooooo00000ol0003oooooooooo`1Cooooo`Coogl09_ooool2oomo09cooooo
0Ol00001ooooo`0000?o0000ooooooooool0Doooool4oomo0<Cooooo0Ol00001ooooo`0000?o0000
ooooooooool0E?ooool2oomo0<Gooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLoooo
o`7o00000Oooool00003o`000?oooooooooo06?ooooo0_ooO`04ooooo`;oogl0/?ooool1o`00007o
oooo00000ol0003oooooooooo`1Rooooo`Coogl00_ooool4oomo0:oooooo0Ol00001ooooo`0000?o
0000ooooooooool0H_ooool4oomo00;ooooo1?ooO`2_ooooo`7o00000Oooool00003o`000?oooooo
oooo06?ooooo0_ooO`04ooooo`;oogl0/?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooo
oacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`00
0?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol0
0001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo
0?oooooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`00
00?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?oo
ool1o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000oooo
ooooool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007o
oooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooo
oolLooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0
003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o
00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003ooooooooo
o`3ooooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool0
0003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooooaco
oooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oo
oooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001
ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo0?oo
oooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o
0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1
o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000oooooooo
ool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo
00000ol0003oooooooooo`3oooooo`Cooooo0_ooO`0Fooooo`7o00000Oooool00003o`000?oooooo
oooo0?oooooo0oooool4oomo01Gooooo0Ol00001ooooo`0000?o0000ooooooooool0ooooool3oooo
o`Coogl05Oooool1o`00007ooooo00000ol0003oooooooooo`3oooooo`Cooooo0_ooO`0Fooooo`7o
00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003ooooooooo
o`3ooooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool0
0003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooooaco
oooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oo
oooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001
ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo0?oo
oooo7?ooool1o`00007ooooo00000ol0003oooooooooo`2eooooo`;oogl0I?ooool1o`00007ooooo
00000ol0003oooooooooo`2dooooo`Coogl0Hoooool1o`00007ooooo00000ol0003oooooooooo`2d
ooooo`Coogl0Hoooool1o`00007ooooo00000ol0003oooooooooo`2eooooo`;oogl0=Oooool2oomo
02gooooo0Ol00001ooooo`0000?o0000ooooooooool0i?ooool2oomo00Gooooo1?ooO`0/ooooo`7o
00000Oooool00003o`000?oooooooooo0>?ooooo1?ooO`04ooooo`Coogl0;?ooool1o`00007ooooo
00000ol0003oooooooooo`33ooooo`;oogl07_ooool4oomo00Gooooo0_ooO`0]ooooo`7o00000Ooo
ool00003o`000?oooooooooo0<;ooooo1?ooO`0;o`00oa?ooooo0_ooO`0eooooo`7o00000Oooool0
0003o`000?oooooooooo0<;ooooo1?l00?l;ooooo`;o003oB?ooool1o`00007ooooo00000ol0003o
ooooooooo`2nooooo`Co003o00?ooooooomo0?ooO`003_ooool2o`00odKooooo0Ol00001ooooo`00
00?o0000ooooooooool0^Oooool2oomo00?o003o5oooool2o`00o`Wooooo0_ooO`0iooooo`7o0000
0Oooool00003o`000?oooooooooo0;Oooooo1?l00?l00oooO`3oooooooooo`0Iooooo`;o003o1_oo
ool4oomo03Sooooo0Ol00001ooooo`0000?o0000ooooooooool0]?ooool3o`00o`03ooooooooO`3o
ogl000;oogl07?ooool00ol00?ooooooooooo`04ooooo`Coogl00oooool2oomo03?ooooo0Ol00001
ooooo`0000?o0000ooooooooool0/_ooool2o`00o`?oogl00_ooool2oomo01?ooooo0_ooO`08oooo
o`03o`00oooooooooooo00Gooooo0_ooO`03ooooo`Coogl0<_ooool1o`00007ooooo00000ol0003o
ooooooooo`2`ooooo`;o003o00?ooooooomo0?ooO`000_ooO`06ooooo`;oogl03_ooool4oomo00Oo
oooo00?o003oooooooooool02_ooool4oomo03;ooooo0Ol00001ooooo`0000?o0000ooooooooool0
[_ooool2o`00o`Cooooo0_ooO`06ooooo`Coogl03Oooool4oomo00Oooooo00?o003oooooooooool0
2oooool2oomo03?ooooo0Ol00001ooooo`0000?o0000ooooooooool0Roooool2oomo023ooooo00?o
003oooooooooool01?ooool2oomo00Kooooo1?ooO`0>ooooo`;oogl02Oooool00ol00?oooooooooo
o`0oooooo`7o00000Oooool00003o`000?oooooooooo08[ooooo1?ooO`0Mooooo`;o003o1_ooool4
oomo00Kooooo0_ooO`0Jooooo`03o`00oooooooooooo03oooooo0Ol00001ooooo`0000?o0000oooo
ooooool0R_ooool4oomo01cooooo00?o003oooooooooool01_ooool4oomo02;ooooo00?o003ooooo
ooooool0?oooool1o`00007ooooo00000ol0003oooooooooo`2;ooooo`;oogl06oooool2o`00o`[o
oooo0_ooO`0Sooooo`03o`00oooooooooooo03oooooo0Ol00001ooooo`0000?o0000ooooooooool0
U_ooool2oomo00kooooo0_l00?lZooooo`;oogl01Oooool00ol00?ooooooooooo`0oooooo`7o0000
0Oooool00003o`000?oooooooooo09Gooooo1?ooO`0<ooooo`04o`00ooooooooogl0oomo02Sooooo
1?ooO`03ooooo`03o`00oooooooooooo043ooooo0Ol00001ooooo`0000?o0000ooooooooool0UOoo
ool4oomo00[ooooo0_l00?l00oooooooogl0oomo0002oomo02Oooooo1?ooO`03ooooo`03o`00oooo
oooooooo043ooooo0Ol00001ooooo`0000?o0000ooooooooool0U_ooool2oomo00[ooooo00Co003o
oooooooooooooooo1?ooO`0Xooooo`;oogl01?ooool00ol00?ooooooooooo`10ooooo`7o00000Ooo
ool00003o`000?oooooooooo0:7ooooo00?o003oooooooooool00oooool2oomo02_ooooo1Ooo0?m2
ooooo`7o00000Oooool00003o`000?oooooooooo0:3ooooo00?o003oooooooooool0<?ooool7ool0
oa7ooooo0_ooO`0^ooooo`7o00000Oooool00003o`000?oooooooooo09kooooo0_l00?lbooooo`Wo
o`3o3oooool4oomo02gooooo0Ol00001ooooo`0000?o0000ooooooooool0WOooool00ol00?oooooo
ooooo`0Eooooo`Co003o6?ooool;ool0o`kooooo1?ooO`0]ooooo`7o00000Oooool00003o`000?oo
oooooooo09cooooo00?o003oooooooooool05Oooool6o`00oaOooooo2ooo0?l?ooooo`;oogl0;_oo
ool1o`00007ooooo00000ol0003oooooooooo`2Kooooo`03o`00oooooooooooo01Gooooo2?l00?lF
ooooo`_oo`3o?oooool1o`00007ooooo00000ol0003oooooooooo`2Kooooo`03o`00oooooooooooo
01Gooooo2?l00?lFooooo`_oo`3o?oooool1o`00007ooooo00000ol0003oooooooooo`2Jooooo`03
o`00oooooooooooo01Kooooo2?l00?lFooooo`_oo`3o?oooool1o`00007ooooo00000ol0003ooooo
ooooo`2Iooooo`03o`00oooooooooooo00cooooo0_ooO`08ooooo`03oomo0?l00?oo003o00Ko003o
5Oooool00ol00?ooooooool0o`08ool0od3ooooo0Ol00001ooooo`0000?o0000ooooooooool0VOoo
ool00ol00?ooooooooooo`0:ooooo`Googl01oooool2oomo00Ko003o4oooool2oomo0004o`00oooo
oooooooooomo00Ooo`3o@Oooool1o`00007ooooo00000ol0003oooooooooo`2Hooooo`03o`00oooo
oooooooo00[ooooo1_ooO`08ooooo`;oogl01?l00?lCooooo`;oogl00_l00?l2ooooo`;oogl01Ooo
0?m2ooooo`7o00000Oooool00003o`000?oooooooooo09Sooooo00?o003oooooooooool02_ooool5
oomo02;ooooo00Coogl0o`00ooooO`3oogl00oooool2oomo04Kooooo0Ol00001ooooo`0000?o0000
ooooooooool0M_ooool2oomo01oooooo00?o003oooooooooool03?ooool2oomo02Cooooo00?o003o
oomo0?ooO`00C?ooool1o`00007ooooo00000ol0003oooooooooo`1eooooo`Coogl07_ooool00ol0
0?ooooooooooo`0aooooo`03o`00oooooooooooo04gooooo0Ol00001ooooo`0000?o0000oooooooo
ool0MOooool4oomo00[ooooo0_ooO`0Aooooo`03o`00oooooooooooo037ooooo00?o003ooooooooo
ool0C_ooool1o`00007ooooo00000ol0003oooooooooo`1fooooo`;oogl02_ooool4oomo00oooooo
00?o003oooooooooool06?ooool2oomo01Oooooo00?o003oooooooooool0Coooool1o`00007ooooo
00000ol0003oooooooooo`22ooooo`Coogl03oooool00ol00?ooooooooooo`0Gooooo`Coogl05?oo
ool2o`00oe;ooooo0Ol00001ooooo`0000?o0000ooooooooool0Poooool2oomo00oooooo00?o003o
ooooooooool04_ooool2oomo00Cooooo1?ooO`0Aooooo`?o003oE?ooool1o`00007ooooo00000ol0
003oooooooooo`2Dooooo`03o`00oooooooooooo017ooooo1?ooO`04ooooo`;oogl04?ooool2o`00
oeOooooo0Ol00001ooooo`0000?o0000ooooooooool0U?ooool00ol00?ooooooooooo`0Aooooo`Co
ogl05Oooool00ol00?ooooooooooo`1Gooooo`7o00000Oooool00003o`000?oooooooooo09Cooooo
00?o003oooooooooool04_ooool2oomo01Cooooo0_l00?mJooooo`7o00000Oooool00003o`000?oo
oooooooo09Cooooo00?o003oooooooooool09_ooool2o`00oecooooo0Ol00001ooooo`0000?o0000
ooooooooool0UOooool00ol00?ooooooooooo`0Tooooo`03o`00oooooooooooo05cooooo0Ol00001
ooooo`0000?o0000ooooooooool0UOooool00ol00?ooooooooooo`0Rooooo`;o003oGoooool1o`00
007ooooo00000ol0003oooooooooo`2Eooooo`03o`00oooooooooooo023ooooo0_l00?mQooooo`7o
00000Oooool00003o`000?oooooooooo08Cooooo0_ooO`0?ooooo`;o003o7oooool2o`00of?ooooo
0Ol00001ooooo`0000?o0000ooooooooool0Poooool4oomo013ooooo0_l00?lJooooo`?o003oIOoo
ool1o`00007ooooo00000ol0003oooooooooo`23ooooo`Coogl04_ooool2o`00oaCooooo1?l00?mX
ooooo`7o00000Oooool00003o`000?oooooooooo08Cooooo0_ooO`0Eooooo`?o003o3_ooool3o`00
o`?ooooo0_ooO`1Wooooo`7o00000Oooool00003o`000?oooooooooo09kooooo0ol00?l5ooooo`Ko
003o1Oooool4oomo06Kooooo0Ol00001ooooo`0000?o0000ooooooooool0XOooool5o`00o`_ooooo
1?ooO`1Vooooo`7o00000Oooool00003o`000?oooooooooo0;;ooooo0_ooO`1Wooooo`7o00000Ooo
ool00003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooo
oacooooo0Ol00001ooooo`0000?o0000ooooooooool0Noooool2oomo09kooooo0Ol00001ooooo`00
00?o0000ooooooooool0N_ooool4oomo09gooooo0Ol00001ooooo`0000?o0000ooooooooool0N_oo
ool4oomo023ooooo0_ooO`1kooooo`7o00000Oooool00003o`000?oooooooooo07_ooooo0_ooO`0P
ooooo`Coogl0N_ooool1o`00007ooooo00000ol0003oooooooooo`2Mooooo`Coogl0N_ooool1o`00
007ooooo00000ol0003oooooooooo`2@ooooo`;oogl03?ooool2oomo07_ooooo0Ol00001ooooo`00
00?o0000ooooooooool0Soooool4oomo08Sooooo0Ol00001ooooo`0000?o0000ooooooooool0Sooo
ool4oomo08Sooooo0Ol00001ooooo`0000?o0000ooooooooool0T?ooool2oomo02?ooooo0_ooO`1T
ooooo`7o00000Oooool00003o`000?oooooooooo0;Cooooo1?ooO`1Sooooo`7o00000Oooool00003
o`000?oooooooooo0;Cooooo1?ooO`1Sooooo`7o00000Oooool00003o`000?oooooooooo0;Gooooo
0_ooO`1Tooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo0000
0ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLoooo
o`7o00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003ooooo
ooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Ooo
ool00003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooo
oacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`00
0?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol0
0001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo
0?oooooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`00
00?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?oo
ool1o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000oooo
ooooool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007o
oooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooo
oolLooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0
003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o
00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003ooooooooo
o`3ooooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool0
0003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooooaco
oooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oo
oooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001
ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo0?oo
oooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o
0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1
o`00007ooooo00000ol0003oooooooooo`2>ooooo`;oogl0Roooool1o`00007ooooo00000ol0003o
ooooooooo`2=ooooo`Coogl0R_ooool1o`00007ooooo00000ol0003oooooooooo`2=ooooo`Coogl0
R_ooool1o`00007ooooo00000ol0003oooooooooo`2>ooooo`;oogl0Roooool1o`00007ooooo0000
0ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLoooo
o`7o00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003ooooo
ooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Ooo
ool00003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooo
oacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`00
0?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol0
0001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo
0?oooooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`00
00?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?oo
ool1o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000oooo
ooooool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007o
oooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooo
oolLooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo003oo`00
023o00000Oooool00001\
\>"],
  ImageRangeCache->{{{0, 287}, {287, 0}} -> {-1.01089, -1.01089, 0.00704453, \
0.00704453}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.49505 0.5 0.49505 [
[ 0 0 -0.125 0 ]
[ 0 0 -0.125 0 ]
[ 0 1 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
0 0 m
1 0 L
s
0 0 m
0 1 L
s
0 1 m
1 1 L
s
1 0 m
1 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
1 .5 0 r
.015 w
.03175 .1355 Mdot
.03435 .12523 Mdot
.11137 .12765 Mdot
.14107 .18841 Mdot
.16218 .24538 Mdot
.17294 .21053 Mdot
.18267 .18577 Mdot
.18434 .1304 Mdot
.18553 .30956 Mdot
.20401 .239 Mdot
.21247 .27571 Mdot
.21687 .20845 Mdot
.22376 .2799 Mdot
.22832 .27485 Mdot
.29063 .20974 Mdot
.29686 .25079 Mdot
.30487 .22936 Mdot
.30683 .34623 Mdot
.32055 .20902 Mdot
.32574 .21979 Mdot
.34472 .28521 Mdot
.35998 .36393 Mdot
.36335 .24976 Mdot
.3794 .36608 Mdot
.42386 .66992 Mdot
.44391 .74519 Mdot
.45059 .34198 Mdot
.47208 .67586 Mdot
.47436 .71381 Mdot
.49778 .59825 Mdot
.50874 .91643 Mdot
.51516 .76219 Mdot
.53655 .61374 Mdot
.56563 .75219 Mdot
.59189 .65665 Mdot
.59581 .61604 Mdot
.59923 .6556 Mdot
.60292 .68499 Mdot
.62656 .67779 Mdot
.63555 .72451 Mdot
.63919 .652 Mdot
.64169 .6004 Mdot
.64246 .58611 Mdot
.64496 .54267 Mdot
.64608 .77288 Mdot
.65077 .64308 Mdot
.66065 .57816 Mdot
.67474 .59169 Mdot
.69296 .563 Mdot
.72815 .65902 Mdot
.73169 .58879 Mdot
.74669 .61318 Mdot
.74821 .65474 Mdot
.75963 .63781 Mdot
.79673 .57809 Mdot
.80925 .55852 Mdot
.81525 .58444 Mdot
.83417 .62985 Mdot
.83598 .55526 Mdot
.91595 .49319 Mdot
1 0 0 r
.005 w
.16128 .17044 m
.18734 .17269 L
.21339 .17909 L
.2345 .18734 L
.23945 .19126 L
.2655 .20415 L
.27874 .21339 L
.29156 .22295 L
.31204 .23945 L
.31761 .24532 L
.33549 .2655 L
.34367 .28341 L
.34499 .29156 L
.34367 .29798 L
.31761 .3104 L
.29156 .30711 L
.2655 .30014 L
.24507 .29156 L
.23945 .28747 L
.21339 .27402 L
.20155 .2655 L
.18734 .25472 L
.16884 .23945 L
.16128 .2313 L
.14618 .21339 L
.13806 .18734 L
.16128 .17044 L
s
0 0 1 r
.65633 .57701 m
.68239 .56842 L
.70844 .56313 L
.7345 .56168 L
.76055 .5752 L
.76359 .57817 L
.76859 .60422 L
.76055 .62333 L
.75627 .63028 L
.7345 .65485 L
.73298 .65633 L
.70844 .6775 L
.69922 .68239 L
.68239 .69294 L
.65633 .70579 L
.64983 .70844 L
.63028 .71539 L
.60422 .72268 L
.57817 .72651 L
.55211 .7214 L
.53145 .70844 L
.52926 .68239 L
.54239 .65633 L
.55211 .63983 L
.56625 .63028 L
.57817 .6193 L
.60119 .60422 L
.60422 .60227 L
.63028 .58726 L
.65315 .57817 L
.65633 .57701 L
s
1 0 0 r
.03 w
.24141 .24033 Mdot
0 0 1 r
.64872 .64417 Mdot
1 0 0 r
.79703 .00495 m
.79703 .00495 L
.87129 .00495 L
.87129 .00495 L
F
0 0 1 r
.89604 .00495 m
.89604 .25248 L
.9703 .25248 L
.9703 .00495 L
F
1 0 1 r
.04 w
.79673 .57809 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P000182000`400?l00000o`00003ooooooolQ
ooooo`00ool0000Po`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`00
00?o0000ooooooooool0o_oooolEo`00o`Sooooo0Ol00001ooooo`0000?o0000ooooooooool0o_oo
oolEo`00o`Sooooo0Ol00001ooooo`0000?o0000ooooooooool0o_oooolEo`00o`Sooooo0Ol00001
ooooo`0000?o0000ooooooooool0o_oooolEo`00o`Sooooo0Ol00001ooooo`0000?o0000oooooooo
ool0o_oooolEo`00o`Sooooo0Ol00001ooooo`0000?o0000ooooooooool0o_oooolEo`00o`Sooooo
0Ol00001ooooo`0000?o0000ooooooooool0o_oooolEo`00o`Sooooo0Ol00001ooooo`0000?o0000
ooooooooool0o_oooolEo`00o`Sooooo0Ol00001ooooo`0000?o0000ooooooooool0o_oooolEo`00
o`Sooooo0Ol00001ooooo`0000?o0000ooooooooool0o_oooolEo`00o`Sooooo0Ol00001ooooo`00
00?o0000ooooooooool0o_oooolEo`00o`Sooooo0Ol00001ooooo`0000?o0000ooooooooool0o_oo
oolEo`00o`Sooooo0Ol00001ooooo`0000?o0000ooooooooool0o_oooolEo`00o`Sooooo0Ol00001
ooooo`0000?o0000ooooooooool0o_oooolEo`00o`Sooooo0Ol00001ooooo`0000?o0000oooooooo
ool0o_oooolEo`00o`Sooooo0Ol00001ooooo`0000?o0000ooooooooool0o_oooolEo`00o`Sooooo
0Ol00001ooooo`0000?o0000ooooooooool0o_oooolEo`00o`Sooooo0Ol00001ooooo`0000?o0000
ooooooooool0o_oooolEo`00o`Sooooo0Ol00001ooooo`0000?o0000ooooooooool0o_oooolEo`00
o`Sooooo0Ol00001ooooo`0000?o0000ooooooooool0o_oooolEo`00o`Sooooo0Ol00001ooooo`00
00?o0000ooooooooool0o_oooolEo`00o`Sooooo0Ol00001ooooo`0000?o0000ooooooooool0o_oo
oolEo`00o`Sooooo0Ol00001ooooo`0000?o0000ooooooooool0o_oooolEo`00o`Sooooo0Ol00001
ooooo`0000?o0000ooooooooool0o_oooolEo`00o`Sooooo0Ol00001ooooo`0000?o0000oooooooo
ool0o_oooolEo`00o`Sooooo0Ol00001ooooo`0000?o0000ooooooooool0o_oooolEo`00o`Sooooo
0Ol00001ooooo`0000?o0000ooooooooool0o_oooolEo`00o`Sooooo0Ol00001ooooo`0000?o0000
ooooooooool0o_oooolEo`00o`Sooooo0Ol00001ooooo`0000?o0000ooooooooool0o_oooolEo`00
o`Sooooo0Ol00001ooooo`0000?o0000ooooooooool0o_oooolEo`00o`Sooooo0Ol00001ooooo`00
00?o0000ooooooooool0o_oooolEo`00o`Sooooo0Ol00001ooooo`0000?o0000ooooooooool0o_oo
oolEo`00o`Sooooo0Ol00001ooooo`0000?o0000ooooooooool01_ooool2oomo0?Kooooo5Ol00?l8
ooooo`7o00000Oooool00003o`000?oooooooooo00Gooooo1?ooO`0Cooooo`;oogl0h?oooolEo`00
o`Sooooo0Ol00001ooooo`0000?o0000ooooooooool01Oooool4oomo01;ooooo1?ooO`0Booooo`;o
ogl0booooolEo`00o`Sooooo0Ol00001ooooo`0000?o0000ooooooooool01Oooool3oomo01?ooooo
1?ooO`0Aooooo`Coogl0b_oooolEo`00o`Sooooo0Ol00001ooooo`0000?o0000ooooooooool01?oo
ool4oomo01Cooooo0_ooO`0Booooo`Coogl0b_oooolEo`00o`Sooooo0Ol00001ooooo`0000?o0000
ooooooooool01?ooool4oomo02Wooooo0_ooO`3;oooooaGo003o2?ooool1o`00007ooooo00000ol0
003oooooooooo`05ooooo`;oogl0mooooolEo`00o`Sooooo0Ol00001ooooo`0000?o0000oooooooo
ool0o_oooolEo`00o`Sooooo0Ol00001ooooo`0000?o0000ooooooooool0o_oooolEo`00o`Sooooo
0Ol00001ooooo`0000?o0000ooooooooool0o_oooolEo`00o`Sooooo0Ol00001ooooo`0000?o0000
ooooooooool0o_oooolEo`00o`Sooooo0Ol00001ooooo`0000?o0000ooooooooool0o_oooolEo`00
o`Sooooo0Ol00001ooooo`0000?o0000ooooooooool0o_oooolEo`00o`Sooooo0Ol00001ooooo`00
00?o0000ooooooooool0o_oooolEo`00o`Sooooo0Ol00001ooooo`0000?o0000ooooooooool0:_oo
ool6ool00<kooooo5Ol00?l8ooooo`7o00000Oooool00003o`000?oooooooooo02Wooooo00?oo`00
ooooooooool01?ooool5ool00<Wooooo5Ol00?l8ooooo`7o00000Oooool00003o`000?oooooooooo
02Oooooo0_oo000<ooooo`Coo`00aOoooolEo`00o`Sooooo0Ol00001ooooo`0000?o0000oooooooo
ool09_ooool00ooo003oooooooooo`0@ooooo`Coo`00`OoooolEo`00o`Sooooo0Ol00001ooooo`00
00?o0000ooooooooool09?ooool00oooO`3oo`00ooooo`09ooooo`;oogl02oooool3ool00;kooooo
5Ol00?l8ooooo`7o00000Oooool00003o`000?oooooooooo02?ooooo00Coogl0ool00?ooO`3oogl0
2?ooool4oomo00gooooo00?oo`00ooooooooool0^ooooolEo`00o`Sooooo0Ol00001ooooo`0000?o
0000ooooooooool08oooool01?ooO`3oo`00oomo0?ooO`08ooooo`Coogl03_ooool2ool00;_ooooo
5Ol00?l8ooooo`7o00000Oooool00003o`000?oooooooooo02Cooooo00?oogl0ool00?ooool02Ooo
ool2oomo017ooooo0_oo002ioooooaGo003o2?ooool1o`00007ooooo00000ol0003oooooooooo`0U
ooooo`03ool00?oooooooooo01gooooo0_oo002goooooaGo003o2?ooool1o`00007ooooo00000ol0
003oooooooooo`0Uooooo`03ool00?oooooooooo01oooooo0_oo002eoooooaGo003o2?ooool1o`00
007ooooo00000ol0003oooooooooo`0Vooooo`03ool00?oooooooooo017ooooo0_ooO`0=ooooo`;o
o`001?ooool2oomo00Oooooo0_ooO`2ToooooaGo003o2?ooool1o`00007ooooo00000ol0003ooooo
ooooo`0Vooooo`03ool00?oooooooooo00Gooooo0_ooO`09ooooo`Coogl03_ooool00ooo003ooooo
ooooo`04oomo00Gooooo1?ooO`2SoooooaGo003o2?ooool1o`00007ooooo00000ol0003ooooooooo
o`0Vooooo`03ool00?oooooooooo00Cooooo1?ooO`08ooooo`Coogl03oooool00ooo003ooooooomo
0003oomo00Gooooo1?ooO`2SoooooaGo003o2?ooool1o`00007ooooo00000ol0003oooooooooo`0W
ooooo`03ool00?oooooooooo00?ooooo1?ooO`09ooooo`;oogl04Oooool01?oo003ooooooomo0?oo
O`07ooooo`?oogl0XooooolEo`00o`Sooooo0Ol00001ooooo`0000?o0000ooooooooool09oooool0
0ooo003oooooooooo`04ooooo`;oogl07_ooool00ooo003oooooooooo`07ooooo`Coogl0X_oooolE
o`00o`Sooooo0Ol00001ooooo`0000?o0000ooooooooool0:?ooool00ooo003oooooooooo`0Toooo
o`03ool00?oooooooooo00Kooooo1?ooO`2RoooooaGo003o2?ooool1o`00007ooooo00000ol0003o
ooooooooo`0Yooooo`03ool00?oooooooooo02Cooooo0_oo00000oooooooogl0oomo0004ooooo`;o
ogl0XooooolEo`00o`Sooooo0Ol00001ooooo`0000?o0000ooooooooool0:_ooool00ooo003ooooo
ooooo`0Cooooo`Coo`003_ooool01?oo003oogl0oomo0?ooO`2XoooooaGo003o2?ooool1o`00007o
oooo00000ol0003oooooooooo`0[ooooo`03ool00?oooooooooo017ooooo1_oo000=ooooo`04oomo
0?oo003oo`00oomo0:Sooooo5Ol00?l8ooooo`7o00000Oooool00003o`000?oooooooooo02cooooo
00?oo`00ooooooooool02?ooool2oomo00Gooooo2?oo000=ooooo`;oogl000?oo`00ooooooooool0
Y_oooolEo`00o`Sooooo0Ol00001ooooo`0000?o0000ooooooooool0;Oooool00ooo003ooooooooo
o`06ooooo`Coogl01?ooool8ool0013ooooo00?oo`00ooooooooool0YOoooolEo`00o`Sooooo0Ol0
0001ooooo`0000?o0000ooooooooool0:oooool2oomo0003oooooooo003ooooo00Kooooo1?ooO`04
ooooo`Soo`004Oooool00ooo003oooooooooo`2ToooooaGo003o2?ooool1o`00007ooooo00000ol0
003oooooooooo`0Zooooo`Coogl000?oooooool00?ooool01_ooool2oomo00Gooooo2?oo000;oooo
o`;oogl01Oooool00ooo003oooooooooo`09ooooo`;oogl0V?oooolEo`00o`Sooooo0Ol00001oooo
o`0000?o0000ooooooooool0:_ooool4oomo00;ooooo00?oo`00ooooooooool03?ooool6ool000_o
oooo1?ooO`04ooooo`03ool00?oooooooooo00Sooooo1?ooO`2GoooooaGo003o2?ooool1o`00007o
oooo00000ol0003oooooooooo`0[ooooo`;oogl01?ooool00ooo003oooooooooo`0<ooooo`Coo`00
3?ooool4oomo00Gooooo00?oo`00ooooooooool01oooool4oomo09Oooooo5Ol00?l8ooooo`7o0000
0Oooool00003o`000?oooooooooo03;ooooo0_oo000Mooooo`;oogl01oooool00ooo003ooooooooo
o`07ooooo`;oogl0]Oooool1o`00007ooooo00000ol0003oooooooooo`0dooooo`03ool00?oooooo
oooo02Cooooo00?oo`00ooooooooool0_Oooool1o`00007ooooo00000ol0003oooooooooo`0eoooo
o`03ool00?oooooooooo02Cooooo00?oo`00ooooooooool0_?ooool1o`00007ooooo00000ol0003o
ooooooooo`0fooooo`;oo`009Oooool00ooo003oooooooooo`2kooooo`7o00000Oooool00003o`00
0?oooooooooo03Sooooo0_oo00000oooO`3oooooooooo`02oomo01kooooo00?oo`00ooooooooool0
^oooool1o`00007ooooo00000ol0003oooooooooo`0hooooo`;oogl00_oo0004oomo01kooooo00?o
o`00ooooooooool0^_ooool1o`00007ooooo00000ol0003oooooooooo`0hooooo`Coogl00_oo0002
oomo01kooooo00?oo`00ooooooooool0^_ooool1o`00007ooooo00000ol0003oooooooooo`0ioooo
o`Googl000?oo`00ooooooooool07Oooool00ooo003oogl0oomo002jooooo`7o00000Oooool00003
o`000?oooooooooo03_ooooo1?ooO`02ool001gooooo00Coogl0ool00?ooO`3oogl0^Oooool1o`00
007ooooo00000ol0003oooooooooo`0looooo`;oogl00oooool2ool001_ooooo00Coogl0ool00?oo
O`3oogl0^Oooool1o`00007ooooo00000ol0003oooooooooo`13ooooo`;oo`006_ooool00oooO`3o
o`00ooooo`2iooooo`7o00000Oooool00003o`000?oooooooooo04Gooooo0_oo000Iooooo`03ool0
0?oooooooooo0;Sooooo0Ol00001ooooo`0000?o0000ooooooooool0Aoooool2ool001Gooooo0_oo
002kooooo`7o00000Oooool00003o`000?oooooooooo04Wooooo0ooo000@ooooo`;oo`00_Oooool1
o`00007ooooo00000ol0003oooooooooo`0aooooo`;oogl06Oooool3ool000cooooo00?oo`00oooo
ooooool0_Oooool1o`00007ooooo00000ol0003oooooooooo`0`ooooo`Coogl06oooool6ool000Co
oooo0_oo0030ooooo`7o00000Oooool00003o`000?oooooooooo033ooooo1?ooO`0Qooooo`Coo`00
`_ooool1o`00007ooooo00000ol0003oooooooooo`0aooooo`;oogl0j?ooool1o`00007ooooo0000
0ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLoooo
o`7o00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003ooooo
ooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Ooo
ool00003o`000?oooooooooo07gooooo0_ooO`2Looooo`7o00000Oooool00003o`000?oooooooooo
07cooooo1?ooO`2Kooooo`7o00000Oooool00003o`000?oooooooooo05Cooooo0_ooO`0Vooooo`Co
ogl0Voooool1o`00007ooooo00000ol0003oooooooooo`1Cooooo`Coogl09_ooool2oomo09cooooo
0Ol00001ooooo`0000?o0000ooooooooool0Doooool4oomo0<Cooooo0Ol00001ooooo`0000?o0000
ooooooooool0E?ooool2oomo0<Gooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLoooo
o`7o00000Oooool00003o`000?oooooooooo06?ooooo0_ooO`04ooooo`;oogl0/?ooool1o`00007o
oooo00000ol0003oooooooooo`1Rooooo`Coogl00_ooool4oomo0:oooooo0Ol00001ooooo`0000?o
0000ooooooooool0H_ooool4oomo00;ooooo1?ooO`2_ooooo`7o00000Oooool00003o`000?oooooo
oooo06?ooooo0_ooO`04ooooo`;oogl0/?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooo
oacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`00
0?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol0
0001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo
0?oooooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`00
00?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?oo
ool1o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000oooo
ooooool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007o
oooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooo
oolLooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0
003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o
00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003ooooooooo
o`3ooooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool0
0003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooooaco
oooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oo
oooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001
ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo0?oo
oooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o
0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1
o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000oooooooo
ool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo
00000ol0003oooooooooo`3oooooo`Cooooo0_ooO`0Fooooo`7o00000Oooool00003o`000?oooooo
oooo0?oooooo0oooool4oomo01Gooooo0Ol00001ooooo`0000?o0000ooooooooool0ooooool3oooo
o`Coogl05Oooool1o`00007ooooo00000ol0003oooooooooo`3oooooo`Cooooo0_ooO`0Fooooo`7o
00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003ooooooooo
o`3ooooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool0
0003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooooaco
oooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oo
oooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001
ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo0?oo
oooo7?ooool1o`00007ooooo00000ol0003oooooooooo`2eooooo`;oogl0I?ooool1o`00007ooooo
00000ol0003oooooooooo`2dooooo`Coogl0Hoooool1o`00007ooooo00000ol0003oooooooooo`2d
ooooo`Coogl0Hoooool1o`00007ooooo00000ol0003oooooooooo`2eooooo`;oogl0=Oooool2oomo
02gooooo0Ol00001ooooo`0000?o0000ooooooooool0i?ooool2oomo00Gooooo1?ooO`0/ooooo`7o
00000Oooool00003o`000?oooooooooo0>?ooooo1?ooO`04ooooo`Coogl0;?ooool1o`00007ooooo
00000ol0003oooooooooo`33ooooo`;oogl07_ooool4oomo00Gooooo0_ooO`0]ooooo`7o00000Ooo
ool00003o`000?oooooooooo0<;ooooo1?ooO`0;o`00o`kooooo1Ooo0?l2oomo03Gooooo0Ol00001
ooooo`0000?o0000ooooooooool0`_ooool4o`00o`_ooooo0_l00?l;ooooo`Ooo`3o=_ooool1o`00
007ooooo00000ol0003oooooooooo`2nooooo`Co003o00?ooooooomo0?ooO`003_ooool2o`00o`So
oooo2Ooo0?leooooo`7o00000Oooool00003o`000?oooooooooo0;Wooooo0_ooO`03o`00oaOooooo
0_l00?l5ooooo`_oo`3o=?ooool1o`00007ooooo00000ol0003oooooooooo`2gooooo`Co003o00?o
ogl0ooooooooool06Oooool2o`00o`?ooooo2ooo0?ldooooo`7o00000Oooool00003o`000?oooooo
oooo0;Cooooo0ol00?l00oooooooogl0oomo0002oomo01cooooo00Co003ooooooooooooooooo2ooo
0?l00oooO`3oooooooooo`0aooooo`7o00000Oooool00003o`000?oooooooooo0;;ooooo0_l00?l3
oomo00;ooooo0_ooO`0Cooooo`;oogl02?ooool01?l00?ooooooooooooooool;ool0o`;oogl0<_oo
ool1o`00007ooooo00000ol0003oooooooooo`2`ooooo`;o003o00?ooooooomo0?ooO`000_ooO`06
ooooo`;oogl03_ooool4oomo00Oooooo00Co003ooooooooooooooooo2ooo0?l2oomo03;ooooo0Ol0
0001ooooo`0000?o0000ooooooooool0[_ooool2o`00o`Cooooo0_ooO`06ooooo`Coogl03Oooool4
oomo00Oooooo00?o003oooooooooool00_ooool9ool0o`;oogl0<oooool1o`00007ooooo00000ol0
003oooooooooo`2;ooooo`;oogl08?ooool00ol00?ooooooooooo`04ooooo`;oogl01_ooool4oomo
00kooooo0_ooO`09ooooo`03o`00oooooooooooo00;ooooo1ooo0?lfooooo`7o00000Oooool00003
o`000?oooooooooo08[ooooo1?ooO`0Mooooo`;o003o1_ooool4oomo00Kooooo0_ooO`0Jooooo`03
o`00oooooooooooo00?ooooo1Ooo0?lgooooo`7o00000Oooool00003o`000?oooooooooo08[ooooo
1?ooO`0Looooo`03o`00oooooooooooo00Kooooo1?ooO`0Rooooo`03o`00oooooooooooo03oooooo
0Ol00001ooooo`0000?o0000ooooooooool0Roooool2oomo01_ooooo0_l00?l:ooooo`;oogl08ooo
ool00ol00?ooooooooooo`0oooooo`7o00000Oooool00003o`000?oooooooooo09Kooooo0_ooO`0>
ooooo`;o003o:_ooool2oomo00Gooooo00?o003oooooooooool0?oooool1o`00007ooooo00000ol0
003oooooooooo`2Eooooo`Coogl03?ooool01?l00?oooooooomo0?ooO`0Xooooo`Coogl00oooool0
0ol00?ooooooooooo`10ooooo`7o00000Oooool00003o`000?oooooooooo09Gooooo1?ooO`0:oooo
o`;o003o00?ooooooomo0?ooO`000_ooO`0Wooooo`Coogl00oooool00ol00?ooooooooooo`10oooo
o`7o00000Oooool00003o`000?oooooooooo09Kooooo0_ooO`0:ooooo`04o`00oooooooooooooooo
o`Coogl0:?ooool2oomo00Cooooo00?o003oooooooooool0@?ooool1o`00007ooooo00000ol0003o
ooooooooo`2Qooooo`03o`00oooooooooooo00?ooooo0_ooO`0^ooooo`03o`00oooooooooooo047o
oooo0Ol00001ooooo`0000?o0000ooooooooool0X?ooool00ol00?ooooooooooo`0cooooo`03o`00
oooooooooooo01;ooooo0_ooO`0^ooooo`7o00000Oooool00003o`000?oooooooooo09kooooo0_l0
0?leooooo`03o`00oooooooooooo01;ooooo1?ooO`0]ooooo`7o00000Oooool00003o`000?oooooo
oooo09gooooo00?o003oooooooooool05Oooool4o`00oacooooo00?o003ooomo0?ooO`004_ooool4
oomo02gooooo0Ol00001ooooo`0000?o0000ooooooooool0W?ooool00ol00?ooooooooooo`0Eoooo
o`Ko003o6_ooool00ol00?ooogl0oomo0002oomo01;ooooo0_ooO`0^ooooo`7o00000Oooool00003
o`000?oooooooooo09_ooooo00?o003oooooooooool05Oooool8o`00oaSooooo00?o003ooooooooo
O`000oooO`12ooooo`7o00000Oooool00003o`000?oooooooooo09_ooooo00?o003oooooooooool0
5Oooool8o`00oaOooooo00Co003ooooooooooooooooo0_ooO`13ooooo`7o00000Oooool00003o`00
0?oooooooooo09[ooooo00?o003oooooooooool05_ooool8o`00oaKooooo00?o003oooooooooool0
Aoooool1o`00007ooooo00000ol0003oooooooooo`2Iooooo`03o`00oooooooooooo00cooooo0_oo
O`08ooooo`03oomo0?l00?oo003o00Ko003o5Oooool00ol00?ooooooooooo`02oomo04Kooooo0Ol0
0001ooooo`0000?o0000ooooooooool0VOooool00ol00?ooooooooooo`0:ooooo`Googl01oooool2
oomo00Ko003o4oooool2oomo0003o`00oooooooooooo00Coogl0AOooool1o`00007ooooo00000ol0
003oooooooooo`2Hooooo`03o`00oooooooooooo00[ooooo1_ooO`08ooooo`;oogl01?l00?lCoooo
o`;oogl00_l00?l2ooooo`Coogl0AOooool1o`00007ooooo00000ol0003oooooooooo`2Hooooo`03
o`00oooooooooooo00[ooooo1OooO`0Rooooo`04oomo0?l00?ooogl0oomo00?ooooo0_ooO`16oooo
o`7o00000Oooool00003o`000?oooooooooo07Kooooo0_ooO`0Oooooo`03o`00oooooooooooo00co
oooo0_ooO`0Tooooo`03o`00ooooO`3oogl004cooooo0Ol00001ooooo`0000?o0000ooooooooool0
MOooool4oomo01kooooo00?o003oooooooooool0<Oooool00ol00?ooooooooooo`1=ooooo`7o0000
0Oooool00003o`000?oooooooooo07Gooooo1?ooO`0:ooooo`;oogl04Oooool00ol00?oooooooooo
o`0aooooo`03o`00oooooooooooo04kooooo0Ol00001ooooo`0000?o0000ooooooooool0M_ooool2
oomo00[ooooo1?ooO`0?ooooo`03o`00oooooooooooo01Sooooo0_ooO`0Gooooo`03o`00oooooooo
oooo04oooooo0Ol00001ooooo`0000?o0000ooooooooool0P_ooool4oomo00oooooo00?o003ooooo
ooooool05oooool4oomo01Cooooo0_l00?mBooooo`7o00000Oooool00003o`000?oooooooooo08?o
oooo0_ooO`0?ooooo`03o`00oooooooooooo01;ooooo0_ooO`04ooooo`Coogl04Oooool3o`00oeCo
oooo0Ol00001ooooo`0000?o0000ooooooooool0U?ooool00ol00?ooooooooooo`0Aooooo`Coogl0
1?ooool2oomo013ooooo0_l00?mGooooo`7o00000Oooool00003o`000?oooooooooo09Cooooo00?o
003oooooooooool04Oooool4oomo01Gooooo00?o003oooooooooool0Eoooool1o`00007ooooo0000
0ol0003oooooooooo`2Dooooo`03o`00oooooooooooo01;ooooo0_ooO`0Dooooo`;o003oF_ooool1
o`00007ooooo00000ol0003oooooooooo`2Dooooo`03o`00oooooooooooo02Kooooo0_l00?mLoooo
o`7o00000Oooool00003o`000?oooooooooo09Gooooo00?o003oooooooooool09?ooool00ol00?oo
ooooooooo`1Looooo`7o00000Oooool00003o`000?oooooooooo09Gooooo00?o003oooooooooool0
8_ooool2o`00oeoooooo0Ol00001ooooo`0000?o0000ooooooooool0UOooool00ol00?oooooooooo
o`0Pooooo`;o003oHOooool1o`00007ooooo00000ol0003oooooooooo`24ooooo`;oogl03oooool2
o`00oaoooooo0_l00?mSooooo`7o00000Oooool00003o`000?oooooooooo08?ooooo1?ooO`0@oooo
o`;o003o6_ooool3o`00ofGooooo0Ol00001ooooo`0000?o0000ooooooooool0Poooool4oomo01;o
oooo0_l00?lDooooo`Co003oJ?ooool1o`00007ooooo00000ol0003oooooooooo`24ooooo`;oogl0
5Oooool3o`00o`kooooo0ol00?l3ooooo`;oogl0Ioooool1o`00007ooooo00000ol0003ooooooooo
o`2Nooooo`?o003o1Oooool6o`00o`Gooooo1?ooO`1Vooooo`7o00000Oooool00003o`000?oooooo
oooo0:7ooooo1Ol00?l;ooooo`Coogl0I_ooool1o`00007ooooo00000ol0003oooooooooo`2boooo
o`;oogl0Ioooool1o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`00
00?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo07_ooooo0_oo
O`2Nooooo`7o00000Oooool00003o`000?oooooooooo07[ooooo1?ooO`2Mooooo`7o00000Oooool0
0003o`000?oooooooooo07[ooooo1?ooO`0Pooooo`;oogl0Noooool1o`00007ooooo00000ol0003o
ooooooooo`1kooooo`;oogl08?ooool4oomo07[ooooo0Ol00001ooooo`0000?o0000ooooooooool0
WOooool4oomo07[ooooo0Ol00001ooooo`0000?o0000ooooooooool0T?ooool2oomo00cooooo0_oo
O`1kooooo`7o00000Oooool00003o`000?oooooooooo08oooooo1?ooO`28ooooo`7o00000Oooool0
0003o`000?oooooooooo08oooooo1?ooO`28ooooo`7o00000Oooool00003o`000?oooooooooo093o
oooo0_ooO`0Sooooo`;oogl0I?ooool1o`00007ooooo00000ol0003oooooooooo`2dooooo`Coogl0
Hoooool1o`00007ooooo00000ol0003oooooooooo`2dooooo`Coogl0Hoooool1o`00007ooooo0000
0ol0003oooooooooo`2eooooo`;oogl0I?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooo
oacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`00
0?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol0
0001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo
0?oooooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`00
00?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?oo
ool1o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000oooo
ooooool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007o
oooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooo
oolLooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0
003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o
00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003ooooooooo
o`3ooooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool0
0003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooooaco
oooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oo
oooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001
ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo0?oo
oooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o
0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1
o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000oooooooo
ool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo
00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolL
ooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003o
ooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0S_ooool2oomo08_ooooo
0Ol00001ooooo`0000?o0000ooooooooool0SOooool4oomo08[ooooo0Ol00001ooooo`0000?o0000
ooooooooool0SOooool4oomo08[ooooo0Ol00001ooooo`0000?o0000ooooooooool0S_ooool2oomo
08_ooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`00
0?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol0
0001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo
0?oooooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`00
00?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?oo
ool1o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000oooo
ooooool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007o
oooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooo
oolLooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0
003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o
00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003ooooooooo
o`3ooooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool0
0003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooooaco
oooo0Ol00001ooooo`00ool0000Po`00007ooooo0000\
\>"],
  ImageRangeCache->{{{0, 287}, {287, 0}} -> {-1.01089, -1.01089, 0.00704453, \
0.00704453}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.49505 0.5 0.49505 [
[ 0 0 -0.125 0 ]
[ 0 0 -0.125 0 ]
[ 0 1 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
0 0 m
1 0 L
s
0 0 m
0 1 L
s
0 1 m
1 1 L
s
1 0 m
1 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
1 .5 0 r
.015 w
.03175 .1355 Mdot
.03435 .12523 Mdot
.11137 .12765 Mdot
.14107 .18841 Mdot
.16218 .24538 Mdot
.17294 .21053 Mdot
.18267 .18577 Mdot
.18434 .1304 Mdot
.18553 .30956 Mdot
.20401 .239 Mdot
.21247 .27571 Mdot
.21687 .20845 Mdot
.22376 .2799 Mdot
.22832 .27485 Mdot
.29063 .20974 Mdot
.29686 .25079 Mdot
.30487 .22936 Mdot
.30683 .34623 Mdot
.32055 .20902 Mdot
.32574 .21979 Mdot
.34472 .28521 Mdot
.35998 .36393 Mdot
.36335 .24976 Mdot
.3794 .36608 Mdot
.42386 .66992 Mdot
.44391 .74519 Mdot
.45059 .34198 Mdot
.47208 .67586 Mdot
.47436 .71381 Mdot
.49778 .59825 Mdot
.50874 .91643 Mdot
.51516 .76219 Mdot
.53655 .61374 Mdot
.56563 .75219 Mdot
.59189 .65665 Mdot
.59581 .61604 Mdot
.59923 .6556 Mdot
.60292 .68499 Mdot
.62656 .67779 Mdot
.63555 .72451 Mdot
.63919 .652 Mdot
.64169 .6004 Mdot
.64246 .58611 Mdot
.64496 .54267 Mdot
.64608 .77288 Mdot
.65077 .64308 Mdot
.66065 .57816 Mdot
.67474 .59169 Mdot
.69296 .563 Mdot
.72815 .65902 Mdot
.73169 .58879 Mdot
.74669 .61318 Mdot
.74821 .65474 Mdot
.75963 .63781 Mdot
.79673 .57809 Mdot
.80925 .55852 Mdot
.81525 .58444 Mdot
.83417 .62985 Mdot
.83598 .55526 Mdot
.91595 .49319 Mdot
1 0 0 r
.005 w
.16128 .17044 m
.18734 .17269 L
.21339 .17909 L
.2345 .18734 L
.23945 .19126 L
.2655 .20415 L
.27874 .21339 L
.29156 .22295 L
.31204 .23945 L
.31761 .24532 L
.33549 .2655 L
.34367 .28341 L
.34499 .29156 L
.34367 .29798 L
.31761 .3104 L
.29156 .30711 L
.2655 .30014 L
.24507 .29156 L
.23945 .28747 L
.21339 .27402 L
.20155 .2655 L
.18734 .25472 L
.16884 .23945 L
.16128 .2313 L
.14618 .21339 L
.13806 .18734 L
.16128 .17044 L
s
0 0 1 r
.65633 .57701 m
.68239 .56842 L
.70844 .56313 L
.7345 .56168 L
.76055 .5752 L
.76359 .57817 L
.76859 .60422 L
.76055 .62333 L
.75627 .63028 L
.7345 .65485 L
.73298 .65633 L
.70844 .6775 L
.69922 .68239 L
.68239 .69294 L
.65633 .70579 L
.64983 .70844 L
.63028 .71539 L
.60422 .72268 L
.57817 .72651 L
.55211 .7214 L
.53145 .70844 L
.52926 .68239 L
.54239 .65633 L
.55211 .63983 L
.56625 .63028 L
.57817 .6193 L
.60119 .60422 L
.60422 .60227 L
.63028 .58726 L
.65315 .57817 L
.65633 .57701 L
s
1 0 0 r
.03 w
.24141 .24033 Mdot
0 0 1 r
.64872 .64417 Mdot
1 0 0 r
.79703 .00495 m
.79703 .00495 L
.87129 .00495 L
.87129 .00495 L
F
0 0 1 r
.89604 .00495 m
.89604 .25248 L
.9703 .25248 L
.9703 .00495 L
F
1 0 1 r
.04 w
.80925 .55852 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P000182000`400?l00000o`00003ooooooolQ
ooooo`00ool0000Po`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`00
00?o0000ooooooooool0o_oooolEo`00o`Sooooo0Ol00001ooooo`0000?o0000ooooooooool0o_oo
oolEo`00o`Sooooo0Ol00001ooooo`0000?o0000ooooooooool0o_oooolEo`00o`Sooooo0Ol00001
ooooo`0000?o0000ooooooooool0o_oooolEo`00o`Sooooo0Ol00001ooooo`0000?o0000oooooooo
ool0o_oooolEo`00o`Sooooo0Ol00001ooooo`0000?o0000ooooooooool0o_oooolEo`00o`Sooooo
0Ol00001ooooo`0000?o0000ooooooooool0o_oooolEo`00o`Sooooo0Ol00001ooooo`0000?o0000
ooooooooool0o_oooolEo`00o`Sooooo0Ol00001ooooo`0000?o0000ooooooooool0o_oooolEo`00
o`Sooooo0Ol00001ooooo`0000?o0000ooooooooool0o_oooolEo`00o`Sooooo0Ol00001ooooo`00
00?o0000ooooooooool0o_oooolEo`00o`Sooooo0Ol00001ooooo`0000?o0000ooooooooool0o_oo
oolEo`00o`Sooooo0Ol00001ooooo`0000?o0000ooooooooool0o_oooolEo`00o`Sooooo0Ol00001
ooooo`0000?o0000ooooooooool0o_oooolEo`00o`Sooooo0Ol00001ooooo`0000?o0000oooooooo
ool0o_oooolEo`00o`Sooooo0Ol00001ooooo`0000?o0000ooooooooool0o_oooolEo`00o`Sooooo
0Ol00001ooooo`0000?o0000ooooooooool0o_oooolEo`00o`Sooooo0Ol00001ooooo`0000?o0000
ooooooooool0o_oooolEo`00o`Sooooo0Ol00001ooooo`0000?o0000ooooooooool0o_oooolEo`00
o`Sooooo0Ol00001ooooo`0000?o0000ooooooooool0o_oooolEo`00o`Sooooo0Ol00001ooooo`00
00?o0000ooooooooool0o_oooolEo`00o`Sooooo0Ol00001ooooo`0000?o0000ooooooooool0o_oo
oolEo`00o`Sooooo0Ol00001ooooo`0000?o0000ooooooooool0o_oooolEo`00o`Sooooo0Ol00001
ooooo`0000?o0000ooooooooool0o_oooolEo`00o`Sooooo0Ol00001ooooo`0000?o0000oooooooo
ool0o_oooolEo`00o`Sooooo0Ol00001ooooo`0000?o0000ooooooooool0o_oooolEo`00o`Sooooo
0Ol00001ooooo`0000?o0000ooooooooool0o_oooolEo`00o`Sooooo0Ol00001ooooo`0000?o0000
ooooooooool0o_oooolEo`00o`Sooooo0Ol00001ooooo`0000?o0000ooooooooool0o_oooolEo`00
o`Sooooo0Ol00001ooooo`0000?o0000ooooooooool0o_oooolEo`00o`Sooooo0Ol00001ooooo`00
00?o0000ooooooooool0o_oooolEo`00o`Sooooo0Ol00001ooooo`0000?o0000ooooooooool0o_oo
oolEo`00o`Sooooo0Ol00001ooooo`0000?o0000ooooooooool01_ooool2oomo0?Kooooo5Ol00?l8
ooooo`7o00000Oooool00003o`000?oooooooooo00Gooooo1?ooO`0Cooooo`;oogl0h?oooolEo`00
o`Sooooo0Ol00001ooooo`0000?o0000ooooooooool01Oooool4oomo01;ooooo1?ooO`0Booooo`;o
ogl0booooolEo`00o`Sooooo0Ol00001ooooo`0000?o0000ooooooooool01Oooool3oomo01?ooooo
1?ooO`0Aooooo`Coogl0b_oooolEo`00o`Sooooo0Ol00001ooooo`0000?o0000ooooooooool01?oo
ool4oomo01Cooooo0_ooO`0Booooo`Coogl0b_oooolEo`00o`Sooooo0Ol00001ooooo`0000?o0000
ooooooooool01?ooool4oomo02Wooooo0_ooO`3;oooooaGo003o2?ooool1o`00007ooooo00000ol0
003oooooooooo`05ooooo`;oogl0mooooolEo`00o`Sooooo0Ol00001ooooo`0000?o0000oooooooo
ool0o_oooolEo`00o`Sooooo0Ol00001ooooo`0000?o0000ooooooooool0o_oooolEo`00o`Sooooo
0Ol00001ooooo`0000?o0000ooooooooool0o_oooolEo`00o`Sooooo0Ol00001ooooo`0000?o0000
ooooooooool0o_oooolEo`00o`Sooooo0Ol00001ooooo`0000?o0000ooooooooool0o_oooolEo`00
o`Sooooo0Ol00001ooooo`0000?o0000ooooooooool0o_oooolEo`00o`Sooooo0Ol00001ooooo`00
00?o0000ooooooooool0o_oooolEo`00o`Sooooo0Ol00001ooooo`0000?o0000ooooooooool0:_oo
ool6ool00<kooooo5Ol00?l8ooooo`7o00000Oooool00003o`000?oooooooooo02Wooooo00?oo`00
ooooooooool01?ooool5ool00<Wooooo5Ol00?l8ooooo`7o00000Oooool00003o`000?oooooooooo
02Oooooo0_oo000<ooooo`Coo`00aOoooolEo`00o`Sooooo0Ol00001ooooo`0000?o0000oooooooo
ool09_ooool00ooo003oooooooooo`0@ooooo`Coo`00`OoooolEo`00o`Sooooo0Ol00001ooooo`00
00?o0000ooooooooool09?ooool00oooO`3oo`00ooooo`09ooooo`;oogl02oooool3ool00;kooooo
5Ol00?l8ooooo`7o00000Oooool00003o`000?oooooooooo02?ooooo00Coogl0ool00?ooO`3oogl0
2?ooool4oomo00gooooo00?oo`00ooooooooool0^ooooolEo`00o`Sooooo0Ol00001ooooo`0000?o
0000ooooooooool08oooool01?ooO`3oo`00oomo0?ooO`08ooooo`Coogl03_ooool2ool00;_ooooo
5Ol00?l8ooooo`7o00000Oooool00003o`000?oooooooooo02Cooooo00?oogl0ool00?ooool02Ooo
ool2oomo017ooooo0_oo002ioooooaGo003o2?ooool1o`00007ooooo00000ol0003oooooooooo`0U
ooooo`03ool00?oooooooooo01gooooo0_oo002goooooaGo003o2?ooool1o`00007ooooo00000ol0
003oooooooooo`0Uooooo`03ool00?oooooooooo01oooooo0_oo002eoooooaGo003o2?ooool1o`00
007ooooo00000ol0003oooooooooo`0Vooooo`03ool00?oooooooooo017ooooo0_ooO`0=ooooo`;o
o`001?ooool2oomo00Oooooo0_ooO`2ToooooaGo003o2?ooool1o`00007ooooo00000ol0003ooooo
ooooo`0Vooooo`03ool00?oooooooooo00Gooooo0_ooO`09ooooo`Coogl03_ooool00ooo003ooooo
ooooo`04oomo00Gooooo1?ooO`2SoooooaGo003o2?ooool1o`00007ooooo00000ol0003ooooooooo
o`0Vooooo`03ool00?oooooooooo00Cooooo1?ooO`08ooooo`Coogl03oooool00ooo003ooooooomo
0003oomo00Gooooo1?ooO`2SoooooaGo003o2?ooool1o`00007ooooo00000ol0003oooooooooo`0W
ooooo`03ool00?oooooooooo00?ooooo1?ooO`09ooooo`;oogl04Oooool01?oo003ooooooomo0?oo
O`07ooooo`?oogl0XooooolEo`00o`Sooooo0Ol00001ooooo`0000?o0000ooooooooool09oooool0
0ooo003oooooooooo`04ooooo`;oogl07_ooool00ooo003oooooooooo`07ooooo`Coogl0X_oooolE
o`00o`Sooooo0Ol00001ooooo`0000?o0000ooooooooool0:?ooool00ooo003oooooooooo`0Toooo
o`03ool00?oooooooooo00Kooooo1?ooO`2RoooooaGo003o2?ooool1o`00007ooooo00000ol0003o
ooooooooo`0Yooooo`03ool00?oooooooooo02Cooooo0_oo00000oooooooogl0oomo0004ooooo`;o
ogl0XooooolEo`00o`Sooooo0Ol00001ooooo`0000?o0000ooooooooool0:_ooool00ooo003ooooo
ooooo`0Cooooo`Coo`003_ooool01?oo003oogl0oomo0?ooO`2XoooooaGo003o2?ooool1o`00007o
oooo00000ol0003oooooooooo`0[ooooo`03ool00?oooooooooo017ooooo1_oo000=ooooo`04oomo
0?oo003oo`00oomo0:Sooooo5Ol00?l8ooooo`7o00000Oooool00003o`000?oooooooooo02cooooo
00?oo`00ooooooooool02?ooool2oomo00Gooooo2?oo000=ooooo`;oogl000?oo`00ooooooooool0
Y_oooolEo`00o`Sooooo0Ol00001ooooo`0000?o0000ooooooooool0;Oooool00ooo003ooooooooo
o`06ooooo`Coogl01?ooool8ool0013ooooo00?oo`00ooooooooool0YOoooolEo`00o`Sooooo0Ol0
0001ooooo`0000?o0000ooooooooool0:oooool2oomo0003oooooooo003ooooo00Kooooo1?ooO`04
ooooo`Soo`004Oooool00ooo003oooooooooo`2ToooooaGo003o2?ooool1o`00007ooooo00000ol0
003oooooooooo`0Zooooo`Coogl000?oooooool00?ooool01_ooool2oomo00Gooooo2?oo000;oooo
o`;oogl01Oooool00ooo003oooooooooo`09ooooo`;oogl0V?oooolEo`00o`Sooooo0Ol00001oooo
o`0000?o0000ooooooooool0:_ooool4oomo00;ooooo00?oo`00ooooooooool03?ooool6ool000_o
oooo1?ooO`04ooooo`03ool00?oooooooooo00Sooooo1?ooO`2GoooooaGo003o2?ooool1o`00007o
oooo00000ol0003oooooooooo`0[ooooo`;oogl01?ooool00ooo003oooooooooo`0<ooooo`Coo`00
3?ooool4oomo00Gooooo00?oo`00ooooooooool01oooool4oomo09Oooooo5Ol00?l8ooooo`7o0000
0Oooool00003o`000?oooooooooo03;ooooo0_oo000Mooooo`;oogl01oooool00ooo003ooooooooo
o`07ooooo`;oogl0]Oooool1o`00007ooooo00000ol0003oooooooooo`0dooooo`03ool00?oooooo
oooo02Cooooo00?oo`00ooooooooool0_Oooool1o`00007ooooo00000ol0003oooooooooo`0eoooo
o`03ool00?oooooooooo02Cooooo00?oo`00ooooooooool0_?ooool1o`00007ooooo00000ol0003o
ooooooooo`0fooooo`;oo`009Oooool00ooo003oooooooooo`2kooooo`7o00000Oooool00003o`00
0?oooooooooo03Sooooo0_oo00000oooO`3oooooooooo`02oomo01kooooo00?oo`00ooooooooool0
^oooool1o`00007ooooo00000ol0003oooooooooo`0hooooo`;oogl00_oo0004oomo01kooooo00?o
o`00ooooooooool0^_ooool1o`00007ooooo00000ol0003oooooooooo`0hooooo`Coogl00_oo0002
oomo01kooooo00?oo`00ooooooooool0^_ooool1o`00007ooooo00000ol0003oooooooooo`0ioooo
o`Googl000?oo`00ooooooooool07Oooool00ooo003oogl0oomo002jooooo`7o00000Oooool00003
o`000?oooooooooo03_ooooo1?ooO`02ool001gooooo00Coogl0ool00?ooO`3oogl0^Oooool1o`00
007ooooo00000ol0003oooooooooo`0looooo`;oogl00oooool2ool001_ooooo00Coogl0ool00?oo
O`3oogl0^Oooool1o`00007ooooo00000ol0003oooooooooo`13ooooo`;oo`006_ooool00oooO`3o
o`00ooooo`2iooooo`7o00000Oooool00003o`000?oooooooooo04Gooooo0_oo000Iooooo`03ool0
0?oooooooooo0;Sooooo0Ol00001ooooo`0000?o0000ooooooooool0Aoooool2ool001Gooooo0_oo
002kooooo`7o00000Oooool00003o`000?oooooooooo04Wooooo0ooo000@ooooo`;oo`00_Oooool1
o`00007ooooo00000ol0003oooooooooo`0aooooo`;oogl06Oooool3ool000cooooo00?oo`00oooo
ooooool0_Oooool1o`00007ooooo00000ol0003oooooooooo`0`ooooo`Coogl06oooool6ool000Co
oooo0_oo0030ooooo`7o00000Oooool00003o`000?oooooooooo033ooooo1?ooO`0Qooooo`Coo`00
`_ooool1o`00007ooooo00000ol0003oooooooooo`0aooooo`;oogl0j?ooool1o`00007ooooo0000
0ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLoooo
o`7o00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003ooooo
ooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Ooo
ool00003o`000?oooooooooo07gooooo0_ooO`2Looooo`7o00000Oooool00003o`000?oooooooooo
07cooooo1?ooO`2Kooooo`7o00000Oooool00003o`000?oooooooooo05Cooooo0_ooO`0Vooooo`Co
ogl0Voooool1o`00007ooooo00000ol0003oooooooooo`1Cooooo`Coogl09_ooool2oomo09cooooo
0Ol00001ooooo`0000?o0000ooooooooool0Doooool4oomo0<Cooooo0Ol00001ooooo`0000?o0000
ooooooooool0E?ooool2oomo0<Gooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLoooo
o`7o00000Oooool00003o`000?oooooooooo06?ooooo0_ooO`04ooooo`;oogl0/?ooool1o`00007o
oooo00000ol0003oooooooooo`1Rooooo`Coogl00_ooool4oomo0:oooooo0Ol00001ooooo`0000?o
0000ooooooooool0H_ooool4oomo00;ooooo1?ooO`2_ooooo`7o00000Oooool00003o`000?oooooo
oooo06?ooooo0_ooO`04ooooo`;oogl0/?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooo
oacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`00
0?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol0
0001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo
0?oooooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`00
00?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?oo
ool1o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000oooo
ooooool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007o
oooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooo
oolLooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0
003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o
00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003ooooooooo
o`3ooooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool0
0003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooooaco
oooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oo
oooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001
ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo0?oo
oooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o
0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1
o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000oooooooo
ool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo
00000ol0003oooooooooo`3oooooo`Cooooo0_ooO`0Fooooo`7o00000Oooool00003o`000?oooooo
oooo0?oooooo0oooool4oomo01Gooooo0Ol00001ooooo`0000?o0000ooooooooool0ooooool3oooo
o`Coogl05Oooool1o`00007ooooo00000ol0003oooooooooo`3oooooo`Cooooo0_ooO`0Fooooo`7o
00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003ooooooooo
o`3ooooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool0
0003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooooaco
oooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oo
oooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001
ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo0?oo
oooo7?ooool1o`00007ooooo00000ol0003oooooooooo`2eooooo`;oogl0I?ooool1o`00007ooooo
00000ol0003oooooooooo`2dooooo`Coogl0:_ooool5ool0ocCooooo0Ol00001ooooo`0000?o0000
ooooooooool0]?ooool4oomo02Wooooo1ooo0?lcooooo`7o00000Oooool00003o`000?oooooooooo
0;Gooooo0_ooO`0Yooooo`Woo`3o0oooool2oomo02gooooo0Ol00001ooooo`0000?o0000oooooooo
ool0goooool;ool0o`03ooooooooO`3oogl000;oogl0;?ooool1o`00007ooooo00000ol0003ooooo
ooooo`3Oooooo`_oo`3o00?ooooooomo0?ooO`000_ooO`0/ooooo`7o00000Oooool00003o`000?oo
oooooooo0<?ooooo0_ooO`0Jooooo`_oo`3o0_ooool2oomo02gooooo0Ol00001ooooo`0000?o0000
ooooooooool0`_ooool4oomo00_o003o3_ooool;ool0oc7ooooo0Ol00001ooooo`0000?o0000oooo
ooooool0`_ooool4o`00o`_ooooo0_l00?l<ooooo`_oo`3o<Oooool1o`00007ooooo00000ol0003o
ooooooooo`2nooooo`Co003o00?ooooooomo0?ooO`003_ooool2o`00o`_ooooo2Ooo0?lbooooo`7o
00000Oooool00003o`000?oooooooooo0;Wooooo0_ooO`03o`00oaOooooo0_l00?l9ooooo`03oomo
0?oo0?ooo`3o00Goo`3o<oooool1o`00007ooooo00000ol0003oooooooooo`2gooooo`Co003o00?o
ogl0ooooooooool06Oooool2o`00o`Kooooo0oooO`05ool0ocCooooo0Ol00001ooooo`0000?o0000
ooooooooool0]?ooool3o`00o`03ooooooooO`3oogl000;oogl07?ooool00ol00?ooooooooooo`04
ooooo`Coogl00oooool2oomo03?ooooo0Ol00001ooooo`0000?o0000ooooooooool0/_ooool2o`00
o`?oogl00_ooool2oomo01?ooooo0_ooO`08ooooo`03o`00oooooooooooo00Gooooo0_ooO`03oooo
o`Coogl0<_ooool1o`00007ooooo00000ol0003oooooooooo`2`ooooo`;o003o00?ooooooomo0?oo
O`000_ooO`06ooooo`;oogl03_ooool4oomo00Oooooo00?o003oooooooooool02_ooool4oomo03;o
oooo0Ol00001ooooo`0000?o0000ooooooooool0[_ooool2o`00o`Cooooo0_ooO`06ooooo`Coogl0
3Oooool4oomo00Oooooo00?o003oooooooooool02oooool2oomo03?ooooo0Ol00001ooooo`0000?o
0000ooooooooool0Roooool2oomo023ooooo00?o003oooooooooool01?ooool2oomo00Kooooo1?oo
O`0>ooooo`;oogl02Oooool00ol00?ooooooooooo`0oooooo`7o00000Oooool00003o`000?oooooo
oooo08[ooooo1?ooO`0Mooooo`;o003o1_ooool4oomo00Kooooo0_ooO`0Jooooo`03o`00oooooooo
oooo03oooooo0Ol00001ooooo`0000?o0000ooooooooool0R_ooool4oomo01cooooo00?o003ooooo
ooooool01_ooool4oomo02;ooooo00?o003oooooooooool0?oooool1o`00007ooooo00000ol0003o
ooooooooo`2;ooooo`;oogl06oooool2o`00o`[ooooo0_ooO`0Sooooo`03o`00oooooooooooo03oo
oooo0Ol00001ooooo`0000?o0000ooooooooool0U_ooool2oomo00kooooo0_l00?lZooooo`;oogl0
1Oooool00ol00?ooooooooooo`0oooooo`7o00000Oooool00003o`000?oooooooooo09Gooooo1?oo
O`0<ooooo`04o`00ooooooooogl0oomo02Sooooo1?ooO`03ooooo`03o`00oooooooooooo043ooooo
0Ol00001ooooo`0000?o0000ooooooooool0UOooool4oomo00[ooooo0_l00?l00oooooooogl0oomo
0002oomo02Oooooo1?ooO`03ooooo`03o`00oooooooooooo043ooooo0Ol00001ooooo`0000?o0000
ooooooooool0U_ooool2oomo00[ooooo00Co003ooooooooooooooooo1?ooO`0Xooooo`;oogl01?oo
ool00ol00?ooooooooooo`10ooooo`7o00000Oooool00003o`000?oooooooooo0:7ooooo00?o003o
ooooooooool00oooool2oomo02kooooo00?o003oooooooooool0@Oooool1o`00007ooooo00000ol0
003oooooooooo`2Pooooo`03o`00oooooooooooo03?ooooo00?o003oooooooooool04_ooool2oomo
02kooooo0Ol00001ooooo`0000?o0000ooooooooool0W_ooool2o`00ocGooooo00?o003ooooooooo
ool04_ooool4oomo02gooooo0Ol00001ooooo`0000?o0000ooooooooool0WOooool00ol00?oooooo
ooooo`0Eooooo`Co003o7?ooool00ol00?ooogl0oomo000Booooo`Coogl0;Oooool1o`00007ooooo
00000ol0003oooooooooo`2Looooo`03o`00oooooooooooo01Gooooo1_l00?lJooooo`03o`00oooo
O`3oogl000;oogl04_ooool2oomo02kooooo0Ol00001ooooo`0000?o0000ooooooooool0Voooool0
0ol00?ooooooooooo`0Eooooo`So003o6?ooool00ol00?oooooooomo0003oomo04;ooooo0Ol00001
ooooo`0000?o0000ooooooooool0Voooool00ol00?ooooooooooo`0Eooooo`So003o5oooool01?l0
0?ooooooooooooooool2oomo04?ooooo0Ol00001ooooo`0000?o0000ooooooooool0V_ooool00ol0
0?ooooooooooo`0Fooooo`So003o5_ooool00ol00?ooooooooooo`17ooooo`7o00000Oooool00003
o`000?oooooooooo09Wooooo00?o003oooooooooool03?ooool2oomo00Sooooo00?oogl0o`00ool0
0?l01_l00?lEooooo`03o`00oooooooooooo00;oogl0A_ooool1o`00007ooooo00000ol0003ooooo
ooooo`2Iooooo`03o`00oooooooooooo00[ooooo1OooO`07ooooo`;oogl01_l00?lCooooo`;oogl0
00?o003oooooooooool01?ooO`15ooooo`7o00000Oooool00003o`000?oooooooooo09Sooooo00?o
003oooooooooool02_ooool6oomo00Sooooo0_ooO`04o`00oa?ooooo0_ooO`02o`00o`;ooooo1?oo
O`15ooooo`7o00000Oooool00003o`000?oooooooooo09Sooooo00?o003oooooooooool02_ooool5
oomo02;ooooo00Coogl0o`00ooooO`3oogl00oooool2oomo04Kooooo0Ol00001ooooo`0000?o0000
ooooooooool0M_ooool2oomo01oooooo00?o003oooooooooool03?ooool2oomo02Cooooo00?o003o
oomo0?ooO`00C?ooool1o`00007ooooo00000ol0003oooooooooo`1eooooo`Coogl07_ooool00ol0
0?ooooooooooo`0aooooo`03o`00oooooooooooo04gooooo0Ol00001ooooo`0000?o0000oooooooo
ool0MOooool4oomo00[ooooo0_ooO`0Aooooo`03o`00oooooooooooo037ooooo00?o003ooooooooo
ool0C_ooool1o`00007ooooo00000ol0003oooooooooo`1fooooo`;oogl02_ooool4oomo00oooooo
00?o003oooooooooool06?ooool2oomo01Oooooo00?o003oooooooooool0Coooool1o`00007ooooo
00000ol0003oooooooooo`22ooooo`Coogl03oooool00ol00?ooooooooooo`0Gooooo`Coogl05?oo
ool2o`00oe;ooooo0Ol00001ooooo`0000?o0000ooooooooool0Poooool2oomo00oooooo00?o003o
ooooooooool04_ooool2oomo00Cooooo1?ooO`0Aooooo`?o003oE?ooool1o`00007ooooo00000ol0
003oooooooooo`2Dooooo`03o`00oooooooooooo017ooooo1?ooO`04ooooo`;oogl04?ooool2o`00
oeOooooo0Ol00001ooooo`0000?o0000ooooooooool0U?ooool00ol00?ooooooooooo`0Aooooo`Co
ogl05Oooool00ol00?ooooooooooo`1Gooooo`7o00000Oooool00003o`000?oooooooooo09Cooooo
00?o003oooooooooool04_ooool2oomo01Cooooo0_l00?mJooooo`7o00000Oooool00003o`000?oo
oooooooo09Cooooo00?o003oooooooooool09_ooool2o`00oecooooo0Ol00001ooooo`0000?o0000
ooooooooool0UOooool00ol00?ooooooooooo`0Tooooo`03o`00oooooooooooo05cooooo0Ol00001
ooooo`0000?o0000ooooooooool0UOooool00ol00?ooooooooooo`0Rooooo`;o003oGoooool1o`00
007ooooo00000ol0003oooooooooo`2Eooooo`03o`00oooooooooooo023ooooo0_l00?mQooooo`7o
00000Oooool00003o`000?oooooooooo08Cooooo0_ooO`0?ooooo`;o003o7oooool2o`00of?ooooo
0Ol00001ooooo`0000?o0000ooooooooool0Poooool4oomo013ooooo0_l00?lJooooo`?o003oIOoo
ool1o`00007ooooo00000ol0003oooooooooo`23ooooo`Coogl04_ooool2o`00oaCooooo1?l00?mX
ooooo`7o00000Oooool00003o`000?oooooooooo08Cooooo0_ooO`0Eooooo`?o003o3_ooool3o`00
o`?ooooo0_ooO`1Wooooo`7o00000Oooool00003o`000?oooooooooo09kooooo0ol00?l5ooooo`Ko
003o1Oooool4oomo06Kooooo0Ol00001ooooo`0000?o0000ooooooooool0XOooool5o`00o`_ooooo
1?ooO`1Vooooo`7o00000Oooool00003o`000?oooooooooo0;;ooooo0_ooO`1Wooooo`7o00000Ooo
ool00003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooo
oacooooo0Ol00001ooooo`0000?o0000ooooooooool0Noooool2oomo09kooooo0Ol00001ooooo`00
00?o0000ooooooooool0N_ooool4oomo09gooooo0Ol00001ooooo`0000?o0000ooooooooool0N_oo
ool4oomo023ooooo0_ooO`1kooooo`7o00000Oooool00003o`000?oooooooooo07_ooooo0_ooO`0P
ooooo`Coogl0N_ooool1o`00007ooooo00000ol0003oooooooooo`2Mooooo`Coogl0N_ooool1o`00
007ooooo00000ol0003oooooooooo`2@ooooo`;oogl03?ooool2oomo07_ooooo0Ol00001ooooo`00
00?o0000ooooooooool0Soooool4oomo08Sooooo0Ol00001ooooo`0000?o0000ooooooooool0Sooo
ool4oomo08Sooooo0Ol00001ooooo`0000?o0000ooooooooool0T?ooool2oomo02?ooooo0_ooO`1T
ooooo`7o00000Oooool00003o`000?oooooooooo0;Cooooo1?ooO`1Sooooo`7o00000Oooool00003
o`000?oooooooooo0;Cooooo1?ooO`1Sooooo`7o00000Oooool00003o`000?oooooooooo0;Gooooo
0_ooO`1Tooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo0000
0ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLoooo
o`7o00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003ooooo
ooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Ooo
ool00003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooo
oacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`00
0?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol0
0001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo
0?oooooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`00
00?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?oo
ool1o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000oooo
ooooool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007o
oooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooo
oolLooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0
003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o
00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003ooooooooo
o`3ooooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool0
0003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooooaco
oooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oo
oooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001
ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo0?oo
oooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o
0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1
o`00007ooooo00000ol0003oooooooooo`2>ooooo`;oogl0Roooool1o`00007ooooo00000ol0003o
ooooooooo`2=ooooo`Coogl0R_ooool1o`00007ooooo00000ol0003oooooooooo`2=ooooo`Coogl0
R_ooool1o`00007ooooo00000ol0003oooooooooo`2>ooooo`;oogl0Roooool1o`00007ooooo0000
0ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLoooo
o`7o00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003ooooo
ooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Ooo
ool00003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooo
oacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`00
0?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol0
0001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo
0?oooooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`00
00?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?oo
ool1o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000oooo
ooooool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007o
oooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooo
oolLooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo003oo`00
023o00000Oooool00001\
\>"],
  ImageRangeCache->{{{0, 287}, {287, 0}} -> {-1.01089, -1.01089, 0.00704453, \
0.00704453}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.49505 0.5 0.49505 [
[ 0 0 -0.125 0 ]
[ 0 0 -0.125 0 ]
[ 0 1 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
0 0 m
1 0 L
s
0 0 m
0 1 L
s
0 1 m
1 1 L
s
1 0 m
1 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
1 .5 0 r
.015 w
.03175 .1355 Mdot
.03435 .12523 Mdot
.11137 .12765 Mdot
.14107 .18841 Mdot
.16218 .24538 Mdot
.17294 .21053 Mdot
.18267 .18577 Mdot
.18434 .1304 Mdot
.18553 .30956 Mdot
.20401 .239 Mdot
.21247 .27571 Mdot
.21687 .20845 Mdot
.22376 .2799 Mdot
.22832 .27485 Mdot
.29063 .20974 Mdot
.29686 .25079 Mdot
.30487 .22936 Mdot
.30683 .34623 Mdot
.32055 .20902 Mdot
.32574 .21979 Mdot
.34472 .28521 Mdot
.35998 .36393 Mdot
.36335 .24976 Mdot
.3794 .36608 Mdot
.42386 .66992 Mdot
.44391 .74519 Mdot
.45059 .34198 Mdot
.47208 .67586 Mdot
.47436 .71381 Mdot
.49778 .59825 Mdot
.50874 .91643 Mdot
.51516 .76219 Mdot
.53655 .61374 Mdot
.56563 .75219 Mdot
.59189 .65665 Mdot
.59581 .61604 Mdot
.59923 .6556 Mdot
.60292 .68499 Mdot
.62656 .67779 Mdot
.63555 .72451 Mdot
.63919 .652 Mdot
.64169 .6004 Mdot
.64246 .58611 Mdot
.64496 .54267 Mdot
.64608 .77288 Mdot
.65077 .64308 Mdot
.66065 .57816 Mdot
.67474 .59169 Mdot
.69296 .563 Mdot
.72815 .65902 Mdot
.73169 .58879 Mdot
.74669 .61318 Mdot
.74821 .65474 Mdot
.75963 .63781 Mdot
.79673 .57809 Mdot
.80925 .55852 Mdot
.81525 .58444 Mdot
.83417 .62985 Mdot
.83598 .55526 Mdot
.91595 .49319 Mdot
1 0 0 r
.005 w
.16128 .17044 m
.18734 .17269 L
.21339 .17909 L
.2345 .18734 L
.23945 .19126 L
.2655 .20415 L
.27874 .21339 L
.29156 .22295 L
.31204 .23945 L
.31761 .24532 L
.33549 .2655 L
.34367 .28341 L
.34499 .29156 L
.34367 .29798 L
.31761 .3104 L
.29156 .30711 L
.2655 .30014 L
.24507 .29156 L
.23945 .28747 L
.21339 .27402 L
.20155 .2655 L
.18734 .25472 L
.16884 .23945 L
.16128 .2313 L
.14618 .21339 L
.13806 .18734 L
.16128 .17044 L
s
0 0 1 r
.65633 .57701 m
.68239 .56842 L
.70844 .56313 L
.7345 .56168 L
.76055 .5752 L
.76359 .57817 L
.76859 .60422 L
.76055 .62333 L
.75627 .63028 L
.7345 .65485 L
.73298 .65633 L
.70844 .6775 L
.69922 .68239 L
.68239 .69294 L
.65633 .70579 L
.64983 .70844 L
.63028 .71539 L
.60422 .72268 L
.57817 .72651 L
.55211 .7214 L
.53145 .70844 L
.52926 .68239 L
.54239 .65633 L
.55211 .63983 L
.56625 .63028 L
.57817 .6193 L
.60119 .60422 L
.60422 .60227 L
.63028 .58726 L
.65315 .57817 L
.65633 .57701 L
s
1 0 0 r
.03 w
.24141 .24033 Mdot
0 0 1 r
.64872 .64417 Mdot
1 0 0 r
.79703 .00495 m
.79703 .00495 L
.87129 .00495 L
.87129 .00495 L
F
0 0 1 r
.89604 .00495 m
.89604 .25248 L
.9703 .25248 L
.9703 .00495 L
F
1 0 1 r
.04 w
.81525 .58444 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P000182000`400?l00000o`00003ooooooolQ
ooooo`00ool0000Po`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`00
00?o0000ooooooooool0o_oooolEo`00o`Sooooo0Ol00001ooooo`0000?o0000ooooooooool0o_oo
oolEo`00o`Sooooo0Ol00001ooooo`0000?o0000ooooooooool0o_oooolEo`00o`Sooooo0Ol00001
ooooo`0000?o0000ooooooooool0o_oooolEo`00o`Sooooo0Ol00001ooooo`0000?o0000oooooooo
ool0o_oooolEo`00o`Sooooo0Ol00001ooooo`0000?o0000ooooooooool0o_oooolEo`00o`Sooooo
0Ol00001ooooo`0000?o0000ooooooooool0o_oooolEo`00o`Sooooo0Ol00001ooooo`0000?o0000
ooooooooool0o_oooolEo`00o`Sooooo0Ol00001ooooo`0000?o0000ooooooooool0o_oooolEo`00
o`Sooooo0Ol00001ooooo`0000?o0000ooooooooool0o_oooolEo`00o`Sooooo0Ol00001ooooo`00
00?o0000ooooooooool0o_oooolEo`00o`Sooooo0Ol00001ooooo`0000?o0000ooooooooool0o_oo
oolEo`00o`Sooooo0Ol00001ooooo`0000?o0000ooooooooool0o_oooolEo`00o`Sooooo0Ol00001
ooooo`0000?o0000ooooooooool0o_oooolEo`00o`Sooooo0Ol00001ooooo`0000?o0000oooooooo
ool0o_oooolEo`00o`Sooooo0Ol00001ooooo`0000?o0000ooooooooool0o_oooolEo`00o`Sooooo
0Ol00001ooooo`0000?o0000ooooooooool0o_oooolEo`00o`Sooooo0Ol00001ooooo`0000?o0000
ooooooooool0o_oooolEo`00o`Sooooo0Ol00001ooooo`0000?o0000ooooooooool0o_oooolEo`00
o`Sooooo0Ol00001ooooo`0000?o0000ooooooooool0o_oooolEo`00o`Sooooo0Ol00001ooooo`00
00?o0000ooooooooool0o_oooolEo`00o`Sooooo0Ol00001ooooo`0000?o0000ooooooooool0o_oo
oolEo`00o`Sooooo0Ol00001ooooo`0000?o0000ooooooooool0o_oooolEo`00o`Sooooo0Ol00001
ooooo`0000?o0000ooooooooool0o_oooolEo`00o`Sooooo0Ol00001ooooo`0000?o0000oooooooo
ool0o_oooolEo`00o`Sooooo0Ol00001ooooo`0000?o0000ooooooooool0o_oooolEo`00o`Sooooo
0Ol00001ooooo`0000?o0000ooooooooool0o_oooolEo`00o`Sooooo0Ol00001ooooo`0000?o0000
ooooooooool0o_oooolEo`00o`Sooooo0Ol00001ooooo`0000?o0000ooooooooool0o_oooolEo`00
o`Sooooo0Ol00001ooooo`0000?o0000ooooooooool0o_oooolEo`00o`Sooooo0Ol00001ooooo`00
00?o0000ooooooooool0o_oooolEo`00o`Sooooo0Ol00001ooooo`0000?o0000ooooooooool0o_oo
oolEo`00o`Sooooo0Ol00001ooooo`0000?o0000ooooooooool01_ooool2oomo0?Kooooo5Ol00?l8
ooooo`7o00000Oooool00003o`000?oooooooooo00Gooooo1?ooO`0Cooooo`;oogl0h?oooolEo`00
o`Sooooo0Ol00001ooooo`0000?o0000ooooooooool01Oooool4oomo01;ooooo1?ooO`0Booooo`;o
ogl0booooolEo`00o`Sooooo0Ol00001ooooo`0000?o0000ooooooooool01Oooool3oomo01?ooooo
1?ooO`0Aooooo`Coogl0b_oooolEo`00o`Sooooo0Ol00001ooooo`0000?o0000ooooooooool01?oo
ool4oomo01Cooooo0_ooO`0Booooo`Coogl0b_oooolEo`00o`Sooooo0Ol00001ooooo`0000?o0000
ooooooooool01?ooool4oomo02Wooooo0_ooO`3;oooooaGo003o2?ooool1o`00007ooooo00000ol0
003oooooooooo`05ooooo`;oogl0mooooolEo`00o`Sooooo0Ol00001ooooo`0000?o0000oooooooo
ool0o_oooolEo`00o`Sooooo0Ol00001ooooo`0000?o0000ooooooooool0o_oooolEo`00o`Sooooo
0Ol00001ooooo`0000?o0000ooooooooool0o_oooolEo`00o`Sooooo0Ol00001ooooo`0000?o0000
ooooooooool0o_oooolEo`00o`Sooooo0Ol00001ooooo`0000?o0000ooooooooool0o_oooolEo`00
o`Sooooo0Ol00001ooooo`0000?o0000ooooooooool0o_oooolEo`00o`Sooooo0Ol00001ooooo`00
00?o0000ooooooooool0o_oooolEo`00o`Sooooo0Ol00001ooooo`0000?o0000ooooooooool0:_oo
ool6ool00<kooooo5Ol00?l8ooooo`7o00000Oooool00003o`000?oooooooooo02Wooooo00?oo`00
ooooooooool01?ooool5ool00<Wooooo5Ol00?l8ooooo`7o00000Oooool00003o`000?oooooooooo
02Oooooo0_oo000<ooooo`Coo`00aOoooolEo`00o`Sooooo0Ol00001ooooo`0000?o0000oooooooo
ool09_ooool00ooo003oooooooooo`0@ooooo`Coo`00`OoooolEo`00o`Sooooo0Ol00001ooooo`00
00?o0000ooooooooool09?ooool00oooO`3oo`00ooooo`09ooooo`;oogl02oooool3ool00;kooooo
5Ol00?l8ooooo`7o00000Oooool00003o`000?oooooooooo02?ooooo00Coogl0ool00?ooO`3oogl0
2?ooool4oomo00gooooo00?oo`00ooooooooool0^ooooolEo`00o`Sooooo0Ol00001ooooo`0000?o
0000ooooooooool08oooool01?ooO`3oo`00oomo0?ooO`08ooooo`Coogl03_ooool2ool00;_ooooo
5Ol00?l8ooooo`7o00000Oooool00003o`000?oooooooooo02Cooooo00?oogl0ool00?ooool02Ooo
ool2oomo017ooooo0_oo002ioooooaGo003o2?ooool1o`00007ooooo00000ol0003oooooooooo`0U
ooooo`03ool00?oooooooooo01gooooo0_oo002goooooaGo003o2?ooool1o`00007ooooo00000ol0
003oooooooooo`0Uooooo`03ool00?oooooooooo01oooooo0_oo002eoooooaGo003o2?ooool1o`00
007ooooo00000ol0003oooooooooo`0Vooooo`03ool00?oooooooooo017ooooo0_ooO`0=ooooo`;o
o`001?ooool2oomo00Oooooo0_ooO`2ToooooaGo003o2?ooool1o`00007ooooo00000ol0003ooooo
ooooo`0Vooooo`03ool00?oooooooooo00Gooooo0_ooO`09ooooo`Coogl03_ooool00ooo003ooooo
ooooo`04oomo00Gooooo1?ooO`2SoooooaGo003o2?ooool1o`00007ooooo00000ol0003ooooooooo
o`0Vooooo`03ool00?oooooooooo00Cooooo1?ooO`08ooooo`Coogl03oooool00ooo003ooooooomo
0003oomo00Gooooo1?ooO`2SoooooaGo003o2?ooool1o`00007ooooo00000ol0003oooooooooo`0W
ooooo`03ool00?oooooooooo00?ooooo1?ooO`09ooooo`;oogl04Oooool01?oo003ooooooomo0?oo
O`07ooooo`?oogl0XooooolEo`00o`Sooooo0Ol00001ooooo`0000?o0000ooooooooool09oooool0
0ooo003oooooooooo`04ooooo`;oogl07_ooool00ooo003oooooooooo`07ooooo`Coogl0X_oooolE
o`00o`Sooooo0Ol00001ooooo`0000?o0000ooooooooool0:?ooool00ooo003oooooooooo`0Toooo
o`03ool00?oooooooooo00Kooooo1?ooO`2RoooooaGo003o2?ooool1o`00007ooooo00000ol0003o
ooooooooo`0Yooooo`03ool00?oooooooooo02Cooooo0_oo00000oooooooogl0oomo0004ooooo`;o
ogl0XooooolEo`00o`Sooooo0Ol00001ooooo`0000?o0000ooooooooool0:_ooool00ooo003ooooo
ooooo`0Cooooo`Coo`003_ooool01?oo003oogl0oomo0?ooO`2XoooooaGo003o2?ooool1o`00007o
oooo00000ol0003oooooooooo`0[ooooo`03ool00?oooooooooo017ooooo1_oo000=ooooo`04oomo
0?oo003oo`00oomo0:Sooooo5Ol00?l8ooooo`7o00000Oooool00003o`000?oooooooooo02cooooo
00?oo`00ooooooooool02?ooool2oomo00Gooooo2?oo000=ooooo`;oogl000?oo`00ooooooooool0
Y_oooolEo`00o`Sooooo0Ol00001ooooo`0000?o0000ooooooooool0;Oooool00ooo003ooooooooo
o`06ooooo`Coogl01?ooool8ool0013ooooo00?oo`00ooooooooool0YOoooolEo`00o`Sooooo0Ol0
0001ooooo`0000?o0000ooooooooool0:oooool2oomo0003oooooooo003ooooo00Kooooo1?ooO`04
ooooo`Soo`004Oooool00ooo003oooooooooo`2ToooooaGo003o2?ooool1o`00007ooooo00000ol0
003oooooooooo`0Zooooo`Coogl000?oooooool00?ooool01_ooool2oomo00Gooooo2?oo000;oooo
o`;oogl01Oooool00ooo003oooooooooo`09ooooo`;oogl0V?oooolEo`00o`Sooooo0Ol00001oooo
o`0000?o0000ooooooooool0:_ooool4oomo00;ooooo00?oo`00ooooooooool03?ooool6ool000_o
oooo1?ooO`04ooooo`03ool00?oooooooooo00Sooooo1?ooO`2GoooooaGo003o2?ooool1o`00007o
oooo00000ol0003oooooooooo`0[ooooo`;oogl01?ooool00ooo003oooooooooo`0<ooooo`Coo`00
3?ooool4oomo00Gooooo00?oo`00ooooooooool01oooool4oomo09Oooooo5Ol00?l8ooooo`7o0000
0Oooool00003o`000?oooooooooo03;ooooo0_oo000Mooooo`;oogl01oooool00ooo003ooooooooo
o`07ooooo`;oogl0]Oooool1o`00007ooooo00000ol0003oooooooooo`0dooooo`03ool00?oooooo
oooo02Cooooo00?oo`00ooooooooool0_Oooool1o`00007ooooo00000ol0003oooooooooo`0eoooo
o`03ool00?oooooooooo02Cooooo00?oo`00ooooooooool0_?ooool1o`00007ooooo00000ol0003o
ooooooooo`0fooooo`;oo`009Oooool00ooo003oooooooooo`2kooooo`7o00000Oooool00003o`00
0?oooooooooo03Sooooo0_oo00000oooO`3oooooooooo`02oomo01kooooo00?oo`00ooooooooool0
^oooool1o`00007ooooo00000ol0003oooooooooo`0hooooo`;oogl00_oo0004oomo01kooooo00?o
o`00ooooooooool0^_ooool1o`00007ooooo00000ol0003oooooooooo`0hooooo`Coogl00_oo0002
oomo01kooooo00?oo`00ooooooooool0^_ooool1o`00007ooooo00000ol0003oooooooooo`0ioooo
o`Googl000?oo`00ooooooooool07Oooool00ooo003oogl0oomo002jooooo`7o00000Oooool00003
o`000?oooooooooo03_ooooo1?ooO`02ool001gooooo00Coogl0ool00?ooO`3oogl0^Oooool1o`00
007ooooo00000ol0003oooooooooo`0looooo`;oogl00oooool2ool001_ooooo00Coogl0ool00?oo
O`3oogl0^Oooool1o`00007ooooo00000ol0003oooooooooo`13ooooo`;oo`006_ooool00oooO`3o
o`00ooooo`2iooooo`7o00000Oooool00003o`000?oooooooooo04Gooooo0_oo000Iooooo`03ool0
0?oooooooooo0;Sooooo0Ol00001ooooo`0000?o0000ooooooooool0Aoooool2ool001Gooooo0_oo
002kooooo`7o00000Oooool00003o`000?oooooooooo04Wooooo0ooo000@ooooo`;oo`00_Oooool1
o`00007ooooo00000ol0003oooooooooo`0aooooo`;oogl06Oooool3ool000cooooo00?oo`00oooo
ooooool0_Oooool1o`00007ooooo00000ol0003oooooooooo`0`ooooo`Coogl06oooool6ool000Co
oooo0_oo0030ooooo`7o00000Oooool00003o`000?oooooooooo033ooooo1?ooO`0Qooooo`Coo`00
`_ooool1o`00007ooooo00000ol0003oooooooooo`0aooooo`;oogl0j?ooool1o`00007ooooo0000
0ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLoooo
o`7o00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003ooooo
ooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Ooo
ool00003o`000?oooooooooo07gooooo0_ooO`2Looooo`7o00000Oooool00003o`000?oooooooooo
07cooooo1?ooO`2Kooooo`7o00000Oooool00003o`000?oooooooooo05Cooooo0_ooO`0Vooooo`Co
ogl0Voooool1o`00007ooooo00000ol0003oooooooooo`1Cooooo`Coogl09_ooool2oomo09cooooo
0Ol00001ooooo`0000?o0000ooooooooool0Doooool4oomo0<Cooooo0Ol00001ooooo`0000?o0000
ooooooooool0E?ooool2oomo0<Gooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLoooo
o`7o00000Oooool00003o`000?oooooooooo06?ooooo0_ooO`04ooooo`;oogl0/?ooool1o`00007o
oooo00000ol0003oooooooooo`1Rooooo`Coogl00_ooool4oomo0:oooooo0Ol00001ooooo`0000?o
0000ooooooooool0H_ooool4oomo00;ooooo1?ooO`2_ooooo`7o00000Oooool00003o`000?oooooo
oooo06?ooooo0_ooO`04ooooo`;oogl0/?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooo
oacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`00
0?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol0
0001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo
0?oooooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`00
00?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?oo
ool1o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000oooo
ooooool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007o
oooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooo
oolLooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0
003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o
00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003ooooooooo
o`3ooooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool0
0003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooooaco
oooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oo
oooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001
ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo0?oo
oooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o
0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1
o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000oooooooo
ool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo
00000ol0003oooooooooo`3oooooo`Cooooo0_ooO`0Fooooo`7o00000Oooool00003o`000?oooooo
oooo0?oooooo0oooool4oomo01Gooooo0Ol00001ooooo`0000?o0000ooooooooool0ooooool3oooo
o`Coogl05Oooool1o`00007ooooo00000ol0003oooooooooo`3oooooo`Cooooo0_ooO`0Fooooo`7o
00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003ooooooooo
o`3ooooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool0
0003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooooaco
oooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oo
oooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001
ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo0?oo
oooo7?ooool1o`00007ooooo00000ol0003oooooooooo`2eooooo`;oogl0I?ooool1o`00007ooooo
00000ol0003oooooooooo`2dooooo`Coogl0Hoooool1o`00007ooooo00000ol0003oooooooooo`2d
ooooo`Coogl0Hoooool1o`00007ooooo00000ol0003oooooooooo`2eooooo`;oogl0=Oooool2oomo
02gooooo0Ol00001ooooo`0000?o0000ooooooooool0i?ooool2oomo00Gooooo1?ooO`0/ooooo`7o
00000Oooool00003o`000?oooooooooo0>?ooooo1?ooO`04ooooo`Coogl0;?ooool1o`00007ooooo
00000ol0003oooooooooo`33ooooo`;oogl07_ooool4oomo00Gooooo0_ooO`0]ooooo`7o00000Ooo
ool00003o`000?oooooooooo0<;ooooo1?ooO`0;o`00oa?ooooo0_ooO`0eooooo`7o00000Oooool0
0003o`000?oooooooooo0<;ooooo1?l00?l;ooooo`;o003o4Oooool5ool0oc;ooooo0Ol00001oooo
o`0000?o0000ooooooooool0__ooool4o`00o`03ooooooooO`3oogl000kooooo0_l00?l>ooooo`Oo
o`3o<Oooool1o`00007ooooo00000ol0003oooooooooo`2iooooo`;oogl00ol00?lGooooo`;o003o
2Oooool2oomo00Woo`3o<?ooool1o`00007ooooo00000ol0003oooooooooo`2gooooo`Co003o00?o
ogl0ooooooooool06Oooool2o`00o`Kooooo0_ooO`0;ool0oboooooo0Ol00001ooooo`0000?o0000
ooooooooool0]?ooool3o`00o`03ooooooooO`3oogl000;oogl07?ooool00ol00?ooooooooooo`04
ooooo`;oogl02ooo0?l_ooooo`7o00000Oooool00003o`000?oooooooooo0;;ooooo0_l00?l3oomo
00;ooooo0_ooO`0Cooooo`;oogl02?ooool00ol00?ooooooooooo`05ooooo`03oomo0?oo0?ooo`3o
00Woo`3o;oooool1o`00007ooooo00000ol0003oooooooooo`2`ooooo`;o003o00?ooooooomo0?oo
O`000_ooO`06ooooo`;oogl03_ooool4oomo00Oooooo00?o003oooooooooool01_ooool;ool0oboo
oooo0Ol00001ooooo`0000?o0000ooooooooool0[_ooool2o`00o`Cooooo0_ooO`06ooooo`Coogl0
3Oooool4oomo00Oooooo00?o003oooooooooool01_ooool;ool0oboooooo0Ol00001ooooo`0000?o
0000ooooooooool0Roooool2oomo023ooooo00?o003oooooooooool01?ooool2oomo00Kooooo1?oo
O`0>ooooo`;oogl02Oooool00ol00?ooooooooooo`06ooooo`Woo`3o<?ooool1o`00007ooooo0000
0ol0003oooooooooo`2:ooooo`Coogl07Oooool2o`00o`Kooooo1?ooO`06ooooo`;oogl06_ooool0
0ol00?ooooooooooo`07ooooo`Ooo`3o<Oooool1o`00007ooooo00000ol0003oooooooooo`2:oooo
o`Coogl07?ooool00ol00?ooooooooooo`06ooooo`Coogl08_ooool00ol00?ooooooooooo`08oooo
o`Goo`3o<_ooool1o`00007ooooo00000ol0003oooooooooo`2;ooooo`;oogl06oooool2o`00o`[o
oooo0_ooO`0Sooooo`03o`00oooooooooooo03oooooo0Ol00001ooooo`0000?o0000ooooooooool0
U_ooool2oomo00kooooo0_l00?lZooooo`;oogl01Oooool00ol00?ooooooooooo`0oooooo`7o0000
0Oooool00003o`000?oooooooooo09Gooooo1?ooO`0<ooooo`04o`00ooooooooogl0oomo02Sooooo
1?ooO`03ooooo`03o`00oooooooooooo043ooooo0Ol00001ooooo`0000?o0000ooooooooool0UOoo
ool4oomo00[ooooo0_l00?l00oooooooogl0oomo0002oomo02Oooooo1?ooO`03ooooo`03o`00oooo
oooooooo043ooooo0Ol00001ooooo`0000?o0000ooooooooool0U_ooool2oomo00[ooooo00Co003o
oooooooooooooooo1?ooO`0Xooooo`;oogl01?ooool00ol00?ooooooooooo`10ooooo`7o00000Ooo
ool00003o`000?oooooooooo0:7ooooo00?o003oooooooooool00oooool2oomo02kooooo00?o003o
ooooooooool0@Oooool1o`00007ooooo00000ol0003oooooooooo`2Pooooo`03o`00oooooooooooo
03?ooooo00?o003oooooooooool04_ooool2oomo02kooooo0Ol00001ooooo`0000?o0000oooooooo
ool0W_ooool2o`00ocGooooo00?o003oooooooooool04_ooool4oomo02gooooo0Ol00001ooooo`00
00?o0000ooooooooool0WOooool00ol00?ooooooooooo`0Eooooo`Co003o7?ooool00ol00?ooogl0
oomo000Booooo`Coogl0;Oooool1o`00007ooooo00000ol0003oooooooooo`2Looooo`03o`00oooo
oooooooo01Gooooo1_l00?lJooooo`03o`00ooooO`3oogl000;oogl04_ooool2oomo02kooooo0Ol0
0001ooooo`0000?o0000ooooooooool0Voooool00ol00?ooooooooooo`0Eooooo`So003o6?ooool0
0ol00?oooooooomo0003oomo04;ooooo0Ol00001ooooo`0000?o0000ooooooooool0Voooool00ol0
0?ooooooooooo`0Eooooo`So003o5oooool01?l00?ooooooooooooooool2oomo04?ooooo0Ol00001
ooooo`0000?o0000ooooooooool0V_ooool00ol00?ooooooooooo`0Fooooo`So003o5_ooool00ol0
0?ooooooooooo`17ooooo`7o00000Oooool00003o`000?oooooooooo09Wooooo00?o003ooooooooo
ool03?ooool2oomo00Sooooo00?oogl0o`00ool00?l01_l00?lEooooo`03o`00oooooooooooo00;o
ogl0A_ooool1o`00007ooooo00000ol0003oooooooooo`2Iooooo`03o`00oooooooooooo00[ooooo
1OooO`07ooooo`;oogl01_l00?lCooooo`;oogl000?o003oooooooooool01?ooO`15ooooo`7o0000
0Oooool00003o`000?oooooooooo09Sooooo00?o003oooooooooool02_ooool6oomo00Sooooo0_oo
O`04o`00oa?ooooo0_ooO`02o`00o`;ooooo1?ooO`15ooooo`7o00000Oooool00003o`000?oooooo
oooo09Sooooo00?o003oooooooooool02_ooool5oomo02;ooooo00Coogl0o`00ooooO`3oogl00ooo
ool2oomo04Kooooo0Ol00001ooooo`0000?o0000ooooooooool0M_ooool2oomo01oooooo00?o003o
ooooooooool03?ooool2oomo02Cooooo00?o003ooomo0?ooO`00C?ooool1o`00007ooooo00000ol0
003oooooooooo`1eooooo`Coogl07_ooool00ol00?ooooooooooo`0aooooo`03o`00oooooooooooo
04gooooo0Ol00001ooooo`0000?o0000ooooooooool0MOooool4oomo00[ooooo0_ooO`0Aooooo`03
o`00oooooooooooo037ooooo00?o003oooooooooool0C_ooool1o`00007ooooo00000ol0003ooooo
ooooo`1fooooo`;oogl02_ooool4oomo00oooooo00?o003oooooooooool06?ooool2oomo01Oooooo
00?o003oooooooooool0Coooool1o`00007ooooo00000ol0003oooooooooo`22ooooo`Coogl03ooo
ool00ol00?ooooooooooo`0Gooooo`Coogl05?ooool2o`00oe;ooooo0Ol00001ooooo`0000?o0000
ooooooooool0Poooool2oomo00oooooo00?o003oooooooooool04_ooool2oomo00Cooooo1?ooO`0A
ooooo`?o003oE?ooool1o`00007ooooo00000ol0003oooooooooo`2Dooooo`03o`00oooooooooooo
017ooooo1?ooO`04ooooo`;oogl04?ooool2o`00oeOooooo0Ol00001ooooo`0000?o0000oooooooo
ool0U?ooool00ol00?ooooooooooo`0Aooooo`Coogl05Oooool00ol00?ooooooooooo`1Gooooo`7o
00000Oooool00003o`000?oooooooooo09Cooooo00?o003oooooooooool04_ooool2oomo01Cooooo
0_l00?mJooooo`7o00000Oooool00003o`000?oooooooooo09Cooooo00?o003oooooooooool09_oo
ool2o`00oecooooo0Ol00001ooooo`0000?o0000ooooooooool0UOooool00ol00?ooooooooooo`0T
ooooo`03o`00oooooooooooo05cooooo0Ol00001ooooo`0000?o0000ooooooooool0UOooool00ol0
0?ooooooooooo`0Rooooo`;o003oGoooool1o`00007ooooo00000ol0003oooooooooo`2Eooooo`03
o`00oooooooooooo023ooooo0_l00?mQooooo`7o00000Oooool00003o`000?oooooooooo08Cooooo
0_ooO`0?ooooo`;o003o7oooool2o`00of?ooooo0Ol00001ooooo`0000?o0000ooooooooool0Pooo
ool4oomo013ooooo0_l00?lJooooo`?o003oIOooool1o`00007ooooo00000ol0003oooooooooo`23
ooooo`Coogl04_ooool2o`00oaCooooo1?l00?mXooooo`7o00000Oooool00003o`000?oooooooooo
08Cooooo0_ooO`0Eooooo`?o003o3_ooool3o`00o`?ooooo0_ooO`1Wooooo`7o00000Oooool00003
o`000?oooooooooo09kooooo0ol00?l5ooooo`Ko003o1Oooool4oomo06Kooooo0Ol00001ooooo`00
00?o0000ooooooooool0XOooool5o`00o`_ooooo1?ooO`1Vooooo`7o00000Oooool00003o`000?oo
oooooooo0;;ooooo0_ooO`1Wooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1
o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000oooooooo
ool0Noooool2oomo09kooooo0Ol00001ooooo`0000?o0000ooooooooool0N_ooool4oomo09gooooo
0Ol00001ooooo`0000?o0000ooooooooool0N_ooool4oomo023ooooo0_ooO`1kooooo`7o00000Ooo
ool00003o`000?oooooooooo07_ooooo0_ooO`0Pooooo`Coogl0N_ooool1o`00007ooooo00000ol0
003oooooooooo`2Mooooo`Coogl0N_ooool1o`00007ooooo00000ol0003oooooooooo`2@ooooo`;o
ogl03?ooool2oomo07_ooooo0Ol00001ooooo`0000?o0000ooooooooool0Soooool4oomo08Sooooo
0Ol00001ooooo`0000?o0000ooooooooool0Soooool4oomo08Sooooo0Ol00001ooooo`0000?o0000
ooooooooool0T?ooool2oomo02?ooooo0_ooO`1Tooooo`7o00000Oooool00003o`000?oooooooooo
0;Cooooo1?ooO`1Sooooo`7o00000Oooool00003o`000?oooooooooo0;Cooooo1?ooO`1Sooooo`7o
00000Oooool00003o`000?oooooooooo0;Gooooo0_ooO`1Tooooo`7o00000Oooool00003o`000?oo
oooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001
ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo0?oo
oooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o
0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1
o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000oooooooo
ool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo
00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolL
ooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003o
ooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o0000
0Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3o
oooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003
o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo
0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oooooo
oooo0?oooooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001oooo
o`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo
7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000
ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00
007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0
oooooolLooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo0000
0ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLoooo
o`7o00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003ooooo
ooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Ooo
ool00003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003oooooooooo`2>oooo
o`;oogl0Roooool1o`00007ooooo00000ol0003oooooooooo`2=ooooo`Coogl0R_ooool1o`00007o
oooo00000ol0003oooooooooo`2=ooooo`Coogl0R_ooool1o`00007ooooo00000ol0003ooooooooo
o`2>ooooo`;oogl0Roooool1o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001
ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo0?oo
oooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o
0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1
o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000oooooooo
ool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo
00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolL
ooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003o
ooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o0000
0Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3o
oooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003
o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo
0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oooooo
oooo0?oooooo7?ooool1o`00007ooooo003oo`00023o00000Oooool00001\
\>"],
  ImageRangeCache->{{{0, 287}, {287, 0}} -> {-1.01089, -1.01089, 0.00704453, \
0.00704453}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.49505 0.5 0.49505 [
[ 0 0 -0.125 0 ]
[ 0 0 -0.125 0 ]
[ 0 1 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
0 0 m
1 0 L
s
0 0 m
0 1 L
s
0 1 m
1 1 L
s
1 0 m
1 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
1 .5 0 r
.015 w
.03175 .1355 Mdot
.03435 .12523 Mdot
.11137 .12765 Mdot
.14107 .18841 Mdot
.16218 .24538 Mdot
.17294 .21053 Mdot
.18267 .18577 Mdot
.18434 .1304 Mdot
.18553 .30956 Mdot
.20401 .239 Mdot
.21247 .27571 Mdot
.21687 .20845 Mdot
.22376 .2799 Mdot
.22832 .27485 Mdot
.29063 .20974 Mdot
.29686 .25079 Mdot
.30487 .22936 Mdot
.30683 .34623 Mdot
.32055 .20902 Mdot
.32574 .21979 Mdot
.34472 .28521 Mdot
.35998 .36393 Mdot
.36335 .24976 Mdot
.3794 .36608 Mdot
.42386 .66992 Mdot
.44391 .74519 Mdot
.45059 .34198 Mdot
.47208 .67586 Mdot
.47436 .71381 Mdot
.49778 .59825 Mdot
.50874 .91643 Mdot
.51516 .76219 Mdot
.53655 .61374 Mdot
.56563 .75219 Mdot
.59189 .65665 Mdot
.59581 .61604 Mdot
.59923 .6556 Mdot
.60292 .68499 Mdot
.62656 .67779 Mdot
.63555 .72451 Mdot
.63919 .652 Mdot
.64169 .6004 Mdot
.64246 .58611 Mdot
.64496 .54267 Mdot
.64608 .77288 Mdot
.65077 .64308 Mdot
.66065 .57816 Mdot
.67474 .59169 Mdot
.69296 .563 Mdot
.72815 .65902 Mdot
.73169 .58879 Mdot
.74669 .61318 Mdot
.74821 .65474 Mdot
.75963 .63781 Mdot
.79673 .57809 Mdot
.80925 .55852 Mdot
.81525 .58444 Mdot
.83417 .62985 Mdot
.83598 .55526 Mdot
.91595 .49319 Mdot
1 0 0 r
.005 w
.16128 .17044 m
.18734 .17269 L
.21339 .17909 L
.2345 .18734 L
.23945 .19126 L
.2655 .20415 L
.27874 .21339 L
.29156 .22295 L
.31204 .23945 L
.31761 .24532 L
.33549 .2655 L
.34367 .28341 L
.34499 .29156 L
.34367 .29798 L
.31761 .3104 L
.29156 .30711 L
.2655 .30014 L
.24507 .29156 L
.23945 .28747 L
.21339 .27402 L
.20155 .2655 L
.18734 .25472 L
.16884 .23945 L
.16128 .2313 L
.14618 .21339 L
.13806 .18734 L
.16128 .17044 L
s
0 0 1 r
.65633 .57701 m
.68239 .56842 L
.70844 .56313 L
.7345 .56168 L
.76055 .5752 L
.76359 .57817 L
.76859 .60422 L
.76055 .62333 L
.75627 .63028 L
.7345 .65485 L
.73298 .65633 L
.70844 .6775 L
.69922 .68239 L
.68239 .69294 L
.65633 .70579 L
.64983 .70844 L
.63028 .71539 L
.60422 .72268 L
.57817 .72651 L
.55211 .7214 L
.53145 .70844 L
.52926 .68239 L
.54239 .65633 L
.55211 .63983 L
.56625 .63028 L
.57817 .6193 L
.60119 .60422 L
.60422 .60227 L
.63028 .58726 L
.65315 .57817 L
.65633 .57701 L
s
1 0 0 r
.03 w
.24141 .24033 Mdot
0 0 1 r
.64872 .64417 Mdot
1 0 0 r
.79703 .00495 m
.79703 .00495 L
.87129 .00495 L
.87129 .00495 L
F
0 0 1 r
.89604 .00495 m
.89604 .25248 L
.9703 .25248 L
.9703 .00495 L
F
1 0 1 r
.04 w
.83417 .62985 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P000182000`400?l00000o`00003ooooooolQ
ooooo`00ool0000Po`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`00
00?o0000ooooooooool0o_oooolEo`00o`Sooooo0Ol00001ooooo`0000?o0000ooooooooool0o_oo
oolEo`00o`Sooooo0Ol00001ooooo`0000?o0000ooooooooool0o_oooolEo`00o`Sooooo0Ol00001
ooooo`0000?o0000ooooooooool0o_oooolEo`00o`Sooooo0Ol00001ooooo`0000?o0000oooooooo
ool0o_oooolEo`00o`Sooooo0Ol00001ooooo`0000?o0000ooooooooool0o_oooolEo`00o`Sooooo
0Ol00001ooooo`0000?o0000ooooooooool0o_oooolEo`00o`Sooooo0Ol00001ooooo`0000?o0000
ooooooooool0o_oooolEo`00o`Sooooo0Ol00001ooooo`0000?o0000ooooooooool0o_oooolEo`00
o`Sooooo0Ol00001ooooo`0000?o0000ooooooooool0o_oooolEo`00o`Sooooo0Ol00001ooooo`00
00?o0000ooooooooool0o_oooolEo`00o`Sooooo0Ol00001ooooo`0000?o0000ooooooooool0o_oo
oolEo`00o`Sooooo0Ol00001ooooo`0000?o0000ooooooooool0o_oooolEo`00o`Sooooo0Ol00001
ooooo`0000?o0000ooooooooool0o_oooolEo`00o`Sooooo0Ol00001ooooo`0000?o0000oooooooo
ool0o_oooolEo`00o`Sooooo0Ol00001ooooo`0000?o0000ooooooooool0o_oooolEo`00o`Sooooo
0Ol00001ooooo`0000?o0000ooooooooool0o_oooolEo`00o`Sooooo0Ol00001ooooo`0000?o0000
ooooooooool0o_oooolEo`00o`Sooooo0Ol00001ooooo`0000?o0000ooooooooool0o_oooolEo`00
o`Sooooo0Ol00001ooooo`0000?o0000ooooooooool0o_oooolEo`00o`Sooooo0Ol00001ooooo`00
00?o0000ooooooooool0o_oooolEo`00o`Sooooo0Ol00001ooooo`0000?o0000ooooooooool0o_oo
oolEo`00o`Sooooo0Ol00001ooooo`0000?o0000ooooooooool0o_oooolEo`00o`Sooooo0Ol00001
ooooo`0000?o0000ooooooooool0o_oooolEo`00o`Sooooo0Ol00001ooooo`0000?o0000oooooooo
ool0o_oooolEo`00o`Sooooo0Ol00001ooooo`0000?o0000ooooooooool0o_oooolEo`00o`Sooooo
0Ol00001ooooo`0000?o0000ooooooooool0o_oooolEo`00o`Sooooo0Ol00001ooooo`0000?o0000
ooooooooool0o_oooolEo`00o`Sooooo0Ol00001ooooo`0000?o0000ooooooooool0o_oooolEo`00
o`Sooooo0Ol00001ooooo`0000?o0000ooooooooool0o_oooolEo`00o`Sooooo0Ol00001ooooo`00
00?o0000ooooooooool0o_oooolEo`00o`Sooooo0Ol00001ooooo`0000?o0000ooooooooool0o_oo
oolEo`00o`Sooooo0Ol00001ooooo`0000?o0000ooooooooool01_ooool20?mo0?Kooooo5Ol00?l8
ooooo`7o00000Oooool00003o`000?oooooooooo00Gooooo103oO`0Cooooo`80ogl0h?oooolEo`00
o`Sooooo0Ol00001ooooo`0000?o0000ooooooooool01Oooool40?mo01;ooooo103oO`0Booooo`80
ogl0booooolEo`00o`Sooooo0Ol00001ooooo`0000?o0000ooooooooool01Oooool30?mo01?ooooo
103oO`0Aooooo`@0ogl0b_oooolEo`00o`Sooooo0Ol00001ooooo`0000?o0000ooooooooool01?oo
ool40?mo01Cooooo0P3oO`0Booooo`@0ogl0b_oooolEo`00o`Sooooo0Ol00001ooooo`0000?o0000
ooooooooool01?ooool40?mo02Wooooo0P3oO`3;oooooaGo003o2?ooool1o`00007ooooo00000ol0
003oooooooooo`05ooooo`80ogl0mooooolEo`00o`Sooooo0Ol00001ooooo`0000?o0000oooooooo
ool0o_oooolEo`00o`Sooooo0Ol00001ooooo`0000?o0000ooooooooool0o_oooolEo`00o`Sooooo
0Ol00001ooooo`0000?o0000ooooooooool0o_oooolEo`00o`Sooooo0Ol00001ooooo`0000?o0000
ooooooooool0o_oooolEo`00o`Sooooo0Ol00001ooooo`0000?o0000ooooooooool0o_oooolEo`00
o`Sooooo0Ol00001ooooo`0000?o0000ooooooooool0o_oooolEo`00o`Sooooo0Ol00001ooooo`00
00?o0000ooooooooool0o_oooolEo`00o`Sooooo0Ol00001ooooo`0000?o0000ooooooooool0:_oo
ool6ool00<kooooo5Ol00?l8ooooo`7o00000Oooool00003o`000?oooooooooo02Wooooo00?oo`00
ooooooooool01?ooool5ool00<Wooooo5Ol00?l8ooooo`7o00000Oooool00003o`000?oooooooooo
02Oooooo0_oo000<ooooo`Coo`00aOoooolEo`00o`Sooooo0Ol00001ooooo`0000?o0000oooooooo
ool09_ooool00ooo003oooooooooo`0@ooooo`Coo`00`OoooolEo`00o`Sooooo0Ol00001ooooo`00
00?o0000ooooooooool09?ooool00`3oO`3oo`00ooooo`09ooooo`80ogl02oooool3ool00;kooooo
5Ol00?l8ooooo`7o00000Oooool00003o`000?oooooooooo02?ooooo00@0ogl0ool0003oO`00ogl0
2?ooool40?mo00gooooo00?oo`00ooooooooool0^ooooolEo`00o`Sooooo0Ol00001ooooo`0000?o
0000ooooooooool08oooool0103oO`3oo`000?mo003oO`08ooooo`@0ogl03_ooool2ool00;_ooooo
5Ol00?l8ooooo`7o00000Oooool00003o`000?oooooooooo02Cooooo00<0ogl0ool00?ooool02Ooo
ool20?mo017ooooo0_oo002ioooooaGo003o2?ooool1o`00007ooooo00000ol0003oooooooooo`0U
ooooo`03ool00?oooooooooo01gooooo0_oo002goooooaGo003o2?ooool1o`00007ooooo00000ol0
003oooooooooo`0Uooooo`03ool00?oooooooooo01oooooo0_oo002eoooooaGo003o2?ooool1o`00
007ooooo00000ol0003oooooooooo`0Vooooo`03ool00?oooooooooo017ooooo0P3oO`0=ooooo`;o
o`001?ooool20?mo00Oooooo0P3oO`2ToooooaGo003o2?ooool1o`00007ooooo00000ol0003ooooo
ooooo`0Vooooo`03ool00?oooooooooo00Gooooo0P3oO`09ooooo`@0ogl03_ooool00ooo003ooooo
ooooo`040?mo00Gooooo103oO`2SoooooaGo003o2?ooool1o`00007ooooo00000ol0003ooooooooo
o`0Vooooo`03ool00?oooooooooo00Cooooo103oO`08ooooo`@0ogl03oooool00ooo003ooooo0?mo
00030?mo00Gooooo103oO`2SoooooaGo003o2?ooool1o`00007ooooo00000ol0003oooooooooo`0W
ooooo`03ool00?oooooooooo00?ooooo103oO`09ooooo`80ogl04Oooool01?oo003ooooo0?mo003o
O`07ooooo`<0ogl0XooooolEo`00o`Sooooo0Ol00001ooooo`0000?o0000ooooooooool09oooool0
0ooo003oooooooooo`04ooooo`80ogl07_ooool00ooo003oooooooooo`07ooooo`@0ogl0X_oooolE
o`00o`Sooooo0Ol00001ooooo`0000?o0000ooooooooool0:?ooool00ooo003oooooooooo`0Toooo
o`03ool00?oooooooooo00Kooooo103oO`2RoooooaGo003o2?ooool1o`00007ooooo00000ol0003o
ooooooooo`0Yooooo`03ool00?oooooooooo02Cooooo0_oo00000oooool0ogl00?mo0004ooooo`80
ogl0XooooolEo`00o`Sooooo0Ol00001ooooo`0000?o0000ooooooooool0:_ooool00ooo003ooooo
ooooo`0Cooooo`@0o`003_ooool01?oo0000ogl00?mo003oO`2XoooooaGo003o2?ooool1o`00007o
oooo00000ol0003oooooooooo`0[ooooo`03ool00?oooooooooo017ooooo1P3o000=ooooo`040?mo
0?oo003oo`000?mo0:Sooooo5Ol00?l8ooooo`7o00000Oooool00003o`000?oooooooooo02cooooo
00?oo`00ooooooooool02?ooool20?mo00Gooooo203o000=ooooo`80ogl000?oo`00ooooooooool0
Y_oooolEo`00o`Sooooo0Ol00001ooooo`0000?o0000ooooooooool0;Oooool00ooo003ooooooooo
o`06ooooo`@0ogl01?ooool80?l0013ooooo00?oo`00ooooooooool0YOoooolEo`00o`Sooooo0Ol0
0001ooooo`0000?o0000ooooooooool0:oooool20?mo0003oooooooo003ooooo00Kooooo103oO`04
ooooo`P0o`004Oooool00ooo003oooooooooo`2ToooooaGo003o2?ooool1o`00007ooooo00000ol0
003oooooooooo`0Zooooo`@0ogl000?oooooool00?ooool01_ooool20?mo00Gooooo203o000;oooo
o`80ogl01Oooool00ooo003oooooooooo`09ooooo`80ogl0V?oooolEo`00o`Sooooo0Ol00001oooo
o`0000?o0000ooooooooool0:_ooool40?mo00;ooooo00?oo`00ooooooooool03?ooool60?l000_o
oooo103oO`04ooooo`03ool00?oooooooooo00Sooooo103oO`2GoooooaGo003o2?ooool1o`00007o
oooo00000ol0003oooooooooo`0[ooooo`80ogl01?ooool00ooo003oooooooooo`0<ooooo`@0o`00
3?ooool40?mo00Gooooo00?oo`00ooooooooool01oooool40?mo09Oooooo5Ol00?l8ooooo`7o0000
0Oooool00003o`000?oooooooooo03;ooooo0_oo000Mooooo`80ogl01oooool00ooo003ooooooooo
o`07ooooo`80ogl0]Oooool1o`00007ooooo00000ol0003oooooooooo`0dooooo`03ool00?oooooo
oooo02Cooooo00?oo`00ooooooooool0_Oooool1o`00007ooooo00000ol0003oooooooooo`0eoooo
o`03ool00?oooooooooo02Cooooo00?oo`00ooooooooool0_?ooool1o`00007ooooo00000ol0003o
ooooooooo`0fooooo`;oo`009Oooool00ooo003oooooooooo`2kooooo`7o00000Oooool00003o`00
0?oooooooooo03Sooooo0_oo00000`3oO`3oooooooooo`020?mo01kooooo00?oo`00ooooooooool0
^oooool1o`00007ooooo00000ol0003oooooooooo`0hooooo`80ogl00_oo00040?mo01kooooo00?o
o`00ooooooooool0^_ooool1o`00007ooooo00000ol0003oooooooooo`0hooooo`@0ogl00_oo0002
0?mo01kooooo00?oo`00ooooooooool0^_ooool1o`00007ooooo00000ol0003oooooooooo`0ioooo
o`D0ogl000?oo`00ooooooooool07Oooool00ooo0000ogl00?mo002jooooo`7o00000Oooool00003
o`000?oooooooooo03_ooooo103oO`02ool001gooooo00@0ogl0ool0003oO`00ogl0^Oooool1o`00
007ooooo00000ol0003oooooooooo`0looooo`80ogl00oooool2ool001_ooooo00@0ogl0ool0003o
O`00ogl0^Oooool1o`00007ooooo00000ol0003oooooooooo`13ooooo`;oo`006_ooool00`3oO`3o
o`00ooooo`2iooooo`7o00000Oooool00003o`000?oooooooooo04Gooooo0_oo000Iooooo`03ool0
0?oooooooooo0;Sooooo0Ol00001ooooo`0000?o0000ooooooooool0Aoooool2ool001Gooooo0_oo
002kooooo`7o00000Oooool00003o`000?oooooooooo04Wooooo0ooo000@ooooo`;oo`00_Oooool1
o`00007ooooo00000ol0003oooooooooo`0aooooo`80ogl06Oooool3ool000cooooo00?oo`00oooo
ooooool0_Oooool1o`00007ooooo00000ol0003oooooooooo`0`ooooo`@0ogl06oooool6ool000Co
oooo0_oo0030ooooo`7o00000Oooool00003o`000?oooooooooo033ooooo103oO`0Qooooo`Coo`00
`_ooool1o`00007ooooo00000ol0003oooooooooo`0aooooo`80ogl0j?ooool1o`00007ooooo0000
0ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLoooo
o`7o00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003ooooo
ooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Ooo
ool00003o`000?oooooooooo07gooooo0P3oO`2Looooo`7o00000Oooool00003o`000?oooooooooo
07cooooo103oO`2Kooooo`7o00000Oooool00003o`000?oooooooooo05Cooooo0P3oO`0Vooooo`@0
ogl0Voooool1o`00007ooooo00000ol0003oooooooooo`1Cooooo`@0ogl09_ooool20?mo09cooooo
0Ol00001ooooo`0000?o0000ooooooooool0Doooool40?mo0<Cooooo0Ol00001ooooo`0000?o0000
ooooooooool0E?ooool20?mo0<Gooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLoooo
o`7o00000Oooool00003o`000?oooooooooo06?ooooo0P3oO`04ooooo`80ogl0/?ooool1o`00007o
oooo00000ol0003oooooooooo`1Rooooo`@0ogl00_ooool40?mo0:oooooo0Ol00001ooooo`0000?o
0000ooooooooool0H_ooool40?mo00;ooooo103oO`2_ooooo`7o00000Oooool00003o`000?oooooo
oooo06?ooooo0P3oO`04ooooo`80ogl0/?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooo
oacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`00
0?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol0
0001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo
0?oooooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`00
00?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?oo
ool1o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000oooo
ooooool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007o
oooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooo
oolLooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0
003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o
00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003ooooooooo
o`3ooooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool0
0003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooooaco
oooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oo
oooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001
ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo0?oo
oooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o
0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1
o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000oooooooo
ool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo
00000ol0003oooooooooo`3oooooo`Cooooo0P3oO`0Fooooo`7o00000Oooool00003o`000?oooooo
oooo0?oooooo0oooool40?mo01Gooooo0Ol00001ooooo`0000?o0000ooooooooool0ooooool3oooo
o`@0ogl05Oooool1o`00007ooooo00000ol0003oooooooooo`3oooooo`Cooooo0P3oO`0Fooooo`7o
00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003ooooooooo
o`3ooooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool0
0003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooooaco
oooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oo
oooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001
ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo0?oo
oooo7?ooool1o`00007ooooo00000ol0003oooooooooo`2eooooo`80ogl0I?ooool1o`00007ooooo
00000ol0003oooooooooo`2dooooo`@0ogl0Hoooool1o`00007ooooo00000ol0003oooooooooo`2d
ooooo`@0ogl0Hoooool1o`00007ooooo00000ol0003oooooooooo`2eooooo`80ogl0=Oooool20?mo
02gooooo0Ol00001ooooo`0000?o0000ooooooooool0i?ooool20?mo00Gooooo103oO`0/ooooo`7o
00000Oooool00003o`000?oooooooooo0>?ooooo103oO`04ooooo`@0ogl0;?ooool1o`00007ooooo
00000ol0003oooooooooo`33ooooo`80ogl07_ooool40?mo00Gooooo0P3oO`0]ooooo`7o00000Ooo
ool00003o`000?oooooooooo0<;ooooo103oO`0;o`00oa?ooooo0P3oO`0eooooo`7o00000Oooool0
0003o`000?oooooooooo0<;ooooo1?l00?l;ooooo`;o003oB?ooool1o`00007ooooo00000ol0003o
ooooooooo`2nooooo`Co003o00?ooooo0?mo003oO`003_ooool2o`00odKooooo0Ol00001ooooo`00
00?o0000ooooooooool0^Oooool20?mo00?o003o5oooool2o`00o`Wooooo0P3oO`0iooooo`7o0000
0Oooool00003o`000?oooooooooo0;Oooooo1?l00?l00`3oO`3oooooooooo`0Iooooo`;o003o1_oo
ool40?mo03Sooooo0Ol00001ooooo`0000?o0000ooooooooool0]?ooool3o`00o`03ooooo`3oO`00
ogl00080ogl07?ooool00ol00?ooooooooooo`04ooooo`@0ogl00oooool20?mo03?ooooo0Ol00001
ooooo`0000?o0000ooooooooool0/_ooool2o`00o`<0ogl00_ooool20?mo01?ooooo0P3oO`08oooo
o`03o`00oooooooooooo00Gooooo0P3oO`03ooooo`@0ogl0<_ooool1o`00007ooooo00000ol0003o
ooooooooo`2`ooooo`;o003o00?ooooo0?mo003oO`000P3oO`06ooooo`80ogl03_ooool40?mo00Oo
oooo00?o003oooooooooool02_ooool40?mo03;ooooo0Ol00001ooooo`0000?o0000ooooooooool0
[_ooool2o`00o`Cooooo0P3oO`06ooooo`@0ogl03Oooool40?mo00Oooooo00?o003oooooooooool0
2oooool20?mo03?ooooo0Ol00001ooooo`0000?o0000ooooooooool0Roooool20?mo023ooooo00?o
003oooooooooool01?ooool20?mo00Kooooo103oO`0>ooooo`80ogl02Oooool00ol00?oooooooooo
o`0oooooo`7o00000Oooool00003o`000?oooooooooo08[ooooo103oO`0Mooooo`;o003o1_ooool4
0?mo00Kooooo0P3oO`0Jooooo`03o`00oooooooooooo03oooooo0Ol00001ooooo`0000?o0000oooo
ooooool0R_ooool40?mo01cooooo00?o003oooooooooool01_ooool40?mo02;ooooo00?o003ooooo
ooooool0?oooool1o`00007ooooo00000ol0003oooooooooo`2;ooooo`80ogl06oooool2o`00o`[o
oooo0P3oO`0Sooooo`03o`00oooooooooooo03oooooo0Ol00001ooooo`0000?o0000ooooooooool0
U_ooool20?mo00kooooo0_l00?lZooooo`80ogl01Oooool00ol00?ooooooooooo`0oooooo`7o0000
0Oooool00003o`000?oooooooooo09Gooooo103oO`0<ooooo`04o`00ooooool0ogl00?mo02Sooooo
103oO`03ooooo`03o`00oooooooooooo00oooooo1@3o0?l/ooooo`7o00000Oooool00003o`000?oo
oooooooo09Gooooo103oO`0:ooooo`;o003o00?ooooo0?mo003oO`000P3oO`0Wooooo`@0ogl00ooo
ool00ol00?ooooooooooo`0>ooooo`L0o`3o:oooool1o`00007ooooo00000ol0003oooooooooo`2F
ooooo`80ogl02_ooool01?l00?ooooooooooooooool40?mo02Sooooo0P3oO`04ooooo`03o`00oooo
oooooooo00gooooo2@3o0?lZooooo`7o00000Oooool00003o`000?oooooooooo0:7ooooo00?o003o
ooooooooool00oooool20?mo02kooooo00?o003oooooooooool03Oooool;0?l0obWooooo0Ol00001
ooooo`0000?o0000ooooooooool0X?ooool00ol00?ooooooooooo`0cooooo`03o`00oooooooooooo
00kooooo2`3o0?lYooooo`7o00000Oooool00003o`000?oooooooooo09kooooo0_l00?leooooo`03
o`00oooooooooooo00oooooo2`3o0?lYooooo`7o00000Oooool00003o`000?oooooooooo09gooooo
00?o003oooooooooool05Oooool40000oacooooo00?o003o0?mo003oO`003oooool;0?l0obWooooo
0Ol00001ooooo`0000?o0000ooooooooool0W?ooool00ol00?ooooooooooo`0Eooooo`H0003o6_oo
ool00ol00?l0ogl00?mo00020?mo00kooooo2`3o0?lYooooo`7o00000Oooool00003o`000?oooooo
oooo09_ooooo00?o003oooooooooool05Oooool80000oaSooooo00?o003oooooo`3oO`000`3oO`0?
ooooo`T0o`3o:_ooool1o`00007ooooo00000ol0003oooooooooo`2Kooooo`03o`00oooooooooooo
01Gooooo20000?lGooooo`04o`00ooooooooooooooooo`80ogl04Oooool70?l0ob_ooooo0Ol00001
ooooo`0000?o0000ooooooooool0V_ooool00ol00?ooooooooooo`0Fooooo`P0003o5_ooool00ol0
0?ooooooooooo`0Fooooo`D0o`3o;?ooool1o`00007ooooo00000ol0003oooooooooo`2Iooooo`03
o`00oooooooooooo00cooooo0P3oO`08ooooo`030?mo00000?l0003o00H0003o5Oooool00ol00?oo
ooooooooo`020?mo04Kooooo0Ol00001ooooo`0000?o0000ooooooooool0VOooool00ol00?oooooo
ooooo`0:ooooo`D0ogl01oooool20?mo00H0003o4oooool20?mo0003o`00oooooooooooo00@0ogl0
AOooool1o`00007ooooo00000ol0003oooooooooo`2Hooooo`03o`00oooooooooooo00[ooooo1P3o
O`08ooooo`80ogl010000?lCooooo`80ogl00_l00?l2ooooo`@0ogl0AOooool1o`00007ooooo0000
0ol0003oooooooooo`2Hooooo`03o`00oooooooooooo00[ooooo1@3oO`0Rooooo`040?mo0?l00?l0
ogl00?mo00?ooooo0P3oO`16ooooo`7o00000Oooool00003o`000?oooooooooo07Kooooo0P3oO`0O
ooooo`03o`00oooooooooooo00cooooo0P3oO`0Tooooo`03o`00o`3oO`00ogl004cooooo0Ol00001
ooooo`0000?o0000ooooooooool0MOooool40?mo01kooooo00?o003oooooooooool0<Oooool00ol0
0?ooooooooooo`1=ooooo`7o00000Oooool00003o`000?oooooooooo07Gooooo103oO`0:ooooo`80
ogl04Oooool00ol00?ooooooooooo`0aooooo`03o`00oooooooooooo04kooooo0Ol00001ooooo`00
00?o0000ooooooooool0M_ooool20?mo00[ooooo103oO`0?ooooo`03o`00oooooooooooo01Sooooo
0P3oO`0Gooooo`03o`00oooooooooooo04oooooo0Ol00001ooooo`0000?o0000ooooooooool0P_oo
ool40?mo00oooooo00?o003oooooooooool05oooool40?mo01Cooooo0_l00?mBooooo`7o00000Ooo
ool00003o`000?oooooooooo08?ooooo0P3oO`0?ooooo`03o`00oooooooooooo01;ooooo0P3oO`04
ooooo`@0ogl04Oooool3o`00oeCooooo0Ol00001ooooo`0000?o0000ooooooooool0U?ooool00ol0
0?ooooooooooo`0Aooooo`@0ogl01?ooool20?mo013ooooo0_l00?mGooooo`7o00000Oooool00003
o`000?oooooooooo09Cooooo00?o003oooooooooool04Oooool40?mo01Gooooo00?o003ooooooooo
ool0Eoooool1o`00007ooooo00000ol0003oooooooooo`2Dooooo`03o`00oooooooooooo01;ooooo
0P3oO`0Dooooo`;o003oF_ooool1o`00007ooooo00000ol0003oooooooooo`2Dooooo`03o`00oooo
oooooooo02Kooooo0_l00?mLooooo`7o00000Oooool00003o`000?oooooooooo09Gooooo00?o003o
ooooooooool09?ooool00ol00?ooooooooooo`1Looooo`7o00000Oooool00003o`000?oooooooooo
09Gooooo00?o003oooooooooool08_ooool2o`00oeoooooo0Ol00001ooooo`0000?o0000oooooooo
ool0UOooool00ol00?ooooooooooo`0Pooooo`;o003oHOooool1o`00007ooooo00000ol0003ooooo
ooooo`24ooooo`80ogl03oooool2o`00oaoooooo0_l00?mSooooo`7o00000Oooool00003o`000?oo
oooooooo08?ooooo103oO`0@ooooo`;o003o6_ooool3o`00ofGooooo0Ol00001ooooo`0000?o0000
ooooooooool0Poooool40?mo01;ooooo0_l00?lDooooo`Co003oJ?ooool1o`00007ooooo00000ol0
003oooooooooo`24ooooo`80ogl05Oooool3o`00o`kooooo0ol00?l3ooooo`80ogl0Ioooool1o`00
007ooooo00000ol0003oooooooooo`2Nooooo`?o003o1Oooool6o`00o`Gooooo103oO`1Vooooo`7o
00000Oooool00003o`000?oooooooooo0:7ooooo1Ol00?l;ooooo`@0ogl0I_ooool1o`00007ooooo
00000ol0003oooooooooo`2booooo`80ogl0Ioooool1o`00007ooooo00000ol0003oooooooooo`3o
oooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003
o`000?oooooooooo07_ooooo0P3oO`2Nooooo`7o00000Oooool00003o`000?oooooooooo07[ooooo
103oO`2Mooooo`7o00000Oooool00003o`000?oooooooooo07[ooooo103oO`0Pooooo`80ogl0Nooo
ool1o`00007ooooo00000ol0003oooooooooo`1kooooo`80ogl08?ooool40?mo07[ooooo0Ol00001
ooooo`0000?o0000ooooooooool0WOooool40?mo07[ooooo0Ol00001ooooo`0000?o0000oooooooo
ool0T?ooool20?mo00cooooo0P3oO`1kooooo`7o00000Oooool00003o`000?oooooooooo08oooooo
103oO`28ooooo`7o00000Oooool00003o`000?oooooooooo08oooooo103oO`28ooooo`7o00000Ooo
ool00003o`000?oooooooooo093ooooo0P3oO`0Sooooo`80ogl0I?ooool1o`00007ooooo00000ol0
003oooooooooo`2dooooo`@0ogl0Hoooool1o`00007ooooo00000ol0003oooooooooo`2dooooo`@0
ogl0Hoooool1o`00007ooooo00000ol0003oooooooooo`2eooooo`80ogl0I?ooool1o`00007ooooo
00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolL
ooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003o
ooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o0000
0Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3o
oooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003
o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo
0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oooooo
oooo0?oooooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001oooo
o`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo
7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000
ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00
007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0
oooooolLooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo0000
0ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLoooo
o`7o00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003ooooo
ooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Ooo
ool00003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooo
oacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`00
0?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol0
0001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo
0?oooooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`00
00?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?oo
ool1o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000oooo
ooooool0S_ooool20?mo08_ooooo0Ol00001ooooo`0000?o0000ooooooooool0SOooool40?mo08[o
oooo0Ol00001ooooo`0000?o0000ooooooooool0SOooool40?mo08[ooooo0Ol00001ooooo`0000?o
0000ooooooooool0S_ooool20?mo08_ooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolL
ooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003o
ooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o0000
0Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3o
oooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003
o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo
0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oooooo
oooo0?oooooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001oooo
o`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo
7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000
ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00
007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0
oooooolLooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo0000
0ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`00ool0000Po`00007ooooo0000\
\>"],
  ImageRangeCache->{{{0, 287}, {287, 0}} -> {-1.01089, -1.01089, 0.00704453, \
0.00704453}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.49505 0.5 0.49505 [
[ 0 0 -0.125 0 ]
[ 0 0 -0.125 0 ]
[ 0 1 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
0 0 m
1 0 L
s
0 0 m
0 1 L
s
0 1 m
1 1 L
s
1 0 m
1 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
1 .5 0 r
.015 w
.03175 .1355 Mdot
.03435 .12523 Mdot
.11137 .12765 Mdot
.14107 .18841 Mdot
.16218 .24538 Mdot
.17294 .21053 Mdot
.18267 .18577 Mdot
.18434 .1304 Mdot
.18553 .30956 Mdot
.20401 .239 Mdot
.21247 .27571 Mdot
.21687 .20845 Mdot
.22376 .2799 Mdot
.22832 .27485 Mdot
.29063 .20974 Mdot
.29686 .25079 Mdot
.30487 .22936 Mdot
.30683 .34623 Mdot
.32055 .20902 Mdot
.32574 .21979 Mdot
.34472 .28521 Mdot
.35998 .36393 Mdot
.36335 .24976 Mdot
.3794 .36608 Mdot
.42386 .66992 Mdot
.44391 .74519 Mdot
.45059 .34198 Mdot
.47208 .67586 Mdot
.47436 .71381 Mdot
.49778 .59825 Mdot
.50874 .91643 Mdot
.51516 .76219 Mdot
.53655 .61374 Mdot
.56563 .75219 Mdot
.59189 .65665 Mdot
.59581 .61604 Mdot
.59923 .6556 Mdot
.60292 .68499 Mdot
.62656 .67779 Mdot
.63555 .72451 Mdot
.63919 .652 Mdot
.64169 .6004 Mdot
.64246 .58611 Mdot
.64496 .54267 Mdot
.64608 .77288 Mdot
.65077 .64308 Mdot
.66065 .57816 Mdot
.67474 .59169 Mdot
.69296 .563 Mdot
.72815 .65902 Mdot
.73169 .58879 Mdot
.74669 .61318 Mdot
.74821 .65474 Mdot
.75963 .63781 Mdot
.79673 .57809 Mdot
.80925 .55852 Mdot
.81525 .58444 Mdot
.83417 .62985 Mdot
.83598 .55526 Mdot
.91595 .49319 Mdot
1 0 0 r
.005 w
.16128 .17044 m
.18734 .17269 L
.21339 .17909 L
.2345 .18734 L
.23945 .19126 L
.2655 .20415 L
.27874 .21339 L
.29156 .22295 L
.31204 .23945 L
.31761 .24532 L
.33549 .2655 L
.34367 .28341 L
.34499 .29156 L
.34367 .29798 L
.31761 .3104 L
.29156 .30711 L
.2655 .30014 L
.24507 .29156 L
.23945 .28747 L
.21339 .27402 L
.20155 .2655 L
.18734 .25472 L
.16884 .23945 L
.16128 .2313 L
.14618 .21339 L
.13806 .18734 L
.16128 .17044 L
s
0 0 1 r
.65633 .57701 m
.68239 .56842 L
.70844 .56313 L
.7345 .56168 L
.76055 .5752 L
.76359 .57817 L
.76859 .60422 L
.76055 .62333 L
.75627 .63028 L
.7345 .65485 L
.73298 .65633 L
.70844 .6775 L
.69922 .68239 L
.68239 .69294 L
.65633 .70579 L
.64983 .70844 L
.63028 .71539 L
.60422 .72268 L
.57817 .72651 L
.55211 .7214 L
.53145 .70844 L
.52926 .68239 L
.54239 .65633 L
.55211 .63983 L
.56625 .63028 L
.57817 .6193 L
.60119 .60422 L
.60422 .60227 L
.63028 .58726 L
.65315 .57817 L
.65633 .57701 L
s
1 0 0 r
.03 w
.24141 .24033 Mdot
0 0 1 r
.64872 .64417 Mdot
1 0 0 r
.79703 .00495 m
.79703 .00495 L
.87129 .00495 L
.87129 .00495 L
F
0 0 1 r
.89604 .00495 m
.89604 .25248 L
.9703 .25248 L
.9703 .00495 L
F
1 0 1 r
.04 w
.83598 .55526 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P000182000`400?l00000o`00003oo`3ooolQ
0?ooo`00ool0000Po`000040oooo00000ol00000oooo0?ooo`3o0?oooa`0oooo0Ol000010?ooo`00
00?o00000?ooo`3oool0oP3ooolEo`00o`P0oooo0Ol000010?ooo`0000?o00000?ooo`3oool0oP3o
oolEo`00o`P0oooo0Ol000010?ooo`0000?o00000?ooo`3oool0oP3ooolEo`00o`P0oooo0Ol00001
0?ooo`0000?o00000?ooo`3oool0oP3ooolEo`00o`P0oooo0Ol000010?ooo`0000?o00000?ooo`3o
ool0oP3ooolEo`00o`P0oooo0Ol000010?ooo`0000?o00000?ooo`3oool0oP3ooolEo`00o`P0oooo
0Ol000010?ooo`0000?o00000?ooo`3oool0oP3ooolEo`00o`P0oooo0Ol000010?ooo`0000?o0000
0?ooo`3oool0oP3ooolEo`00o`P0oooo0Ol000010?ooo`0000?o00000?ooo`3oool0oP3ooolEo`00
o`P0oooo0Ol000010?ooo`0000?o00000?ooo`3oool0oP3ooolEo`00o`P0oooo0Ol000010?ooo`00
00?o00000?ooo`3oool0oP3ooolEo`00o`P0oooo0Ol000010?ooo`0000?o00000?ooo`3oool0oP3o
oolEo`00o`P0oooo0Ol000010?ooo`0000?o00000?ooo`3oool0oP3ooolEo`00o`P0oooo0Ol00001
0?ooo`0000?o00000?ooo`3oool0oP3ooolEo`00o`P0oooo0Ol000010?ooo`0000?o00000?ooo`3o
ool0oP3ooolEo`00o`P0oooo0Ol000010?ooo`0000?o00000?ooo`3oool0oP3ooolEo`00o`P0oooo
0Ol000010?ooo`0000?o00000?ooo`3oool0oP3ooolEo`00o`P0oooo0Ol000010?ooo`0000?o0000
0?ooo`3oool0oP3ooolEo`00o`P0oooo0Ol000010?ooo`0000?o00000?ooo`3oool0oP3ooolEo`00
o`P0oooo0Ol000010?ooo`0000?o00000?ooo`3oool0oP3ooolEo`00o`P0oooo0Ol000010?ooo`00
00?o00000?ooo`3oool0oP3ooolEo`00o`P0oooo0Ol000010?ooo`0000?o00000?ooo`3oool0oP3o
oolEo`00o`P0oooo0Ol000010?ooo`0000?o00000?ooo`3oool0oP3ooolEo`00o`P0oooo0Ol00001
0?ooo`0000?o00000?ooo`3oool0oP3ooolEo`00o`P0oooo0Ol000010?ooo`0000?o00000?ooo`3o
ool0oP3ooolEo`00o`P0oooo0Ol000010?ooo`0000?o00000?ooo`3oool0oP3ooolEo`00o`P0oooo
0Ol000010?ooo`0000?o00000?ooo`3oool0oP3ooolEo`00o`P0oooo0Ol000010?ooo`0000?o0000
0?ooo`3oool0oP3ooolEo`00o`P0oooo0Ol000010?ooo`0000?o00000?ooo`3oool0oP3ooolEo`00
o`P0oooo0Ol000010?ooo`0000?o00000?ooo`3oool0oP3ooolEo`00o`P0oooo0Ol000010?ooo`00
00?o00000?ooo`3oool0oP3ooolEo`00o`P0oooo0Ol000010?ooo`0000?o00000?ooo`3oool0oP3o
oolEo`00o`P0oooo0Ol000010?ooo`0000?o00000?ooo`3oool01P3oool20?mo0?H0oooo5Ol00?l8
0?ooo`7o00000@3oool00003o`00003oool0oooo00D0oooo103oO`0C0?ooo`80ogl0h03ooolEo`00
o`P0oooo0Ol000010?ooo`0000?o00000?ooo`3oool01@3oool40?mo0180oooo103oO`0B0?ooo`80
ogl0b`3ooolEo`00o`P0oooo0Ol000010?ooo`0000?o00000?ooo`3oool01@3oool30?mo01<0oooo
103oO`0A0?ooo`@0ogl0bP3ooolEo`00o`P0oooo0Ol000010?ooo`0000?o00000?ooo`3oool0103o
ool40?mo01@0oooo0P3oO`0B0?ooo`@0ogl0bP3ooolEo`00o`P0oooo0Ol000010?ooo`0000?o0000
0?ooo`3oool0103oool40?mo02T0oooo0P3oO`3;0?oooaGo003o203oool1o`000040oooo00000ol0
0000oooo0?ooo`050?ooo`80ogl0m`3ooolEo`00o`P0oooo0Ol000010?ooo`0000?o00000?ooo`3o
ool0oP3ooolEo`00o`P0oooo0Ol000010?ooo`0000?o00000?ooo`3oool0oP3ooolEo`00o`P0oooo
0Ol000010?ooo`0000?o00000?ooo`3oool0oP3ooolEo`00o`P0oooo0Ol000010?ooo`0000?o0000
0?ooo`3oool0oP3ooolEo`00o`P0oooo0Ol000010?ooo`0000?o00000?ooo`3oool0oP3ooolEo`00
o`P0oooo0Ol000010?ooo`0000?o00000?ooo`3oool0oP3ooolEo`00o`P0oooo0Ol000010?ooo`00
00?o00000?ooo`3oool0oP3ooolEo`00o`P0oooo0Ol000010?ooo`0000?o00000?ooo`3oool0:P3o
ool6ool00<h0oooo5Ol00?l80?ooo`7o00000@3oool00003o`00003oool0oooo02T0oooo00?oo`00
0?ooo`3oool0103oool5ool00<T0oooo5Ol00?l80?ooo`7o00000@3oool00003o`00003oool0oooo
02L0oooo0_oo000<0?ooo`Coo`00a@3ooolEo`00o`P0oooo0Ol000010?ooo`0000?o00000?ooo`3o
ool09P3oool00ooo0000oooo0?ooo`0@0?ooo`Coo`00`@3ooolEo`00o`P0oooo0Ol000010?ooo`00
00?o00000?ooo`3oool0903oool00`3oO`3oo`000?ooo`090?ooo`80ogl02`3oool3ool00;h0oooo
5Ol00?l80?ooo`7o00000@3oool00003o`00003oool0oooo02<0oooo00@0ogl0ool0003oO`00ogl0
203oool40?mo00d0oooo00?oo`000?ooo`3oool0^`3ooolEo`00o`P0oooo0Ol000010?ooo`0000?o
00000?ooo`3oool08`3oool0103oO`3oo`000?mo003oO`080?ooo`@0ogl03P3oool2ool00;/0oooo
5Ol00?l80?ooo`7o00000@3oool00003o`00003oool0oooo02@0oooo00<0ogl0ool0003oool02@3o
ool20?mo0140oooo0_oo002i0?oooaGo003o203oool1o`000040oooo00000ol00000oooo0?ooo`0U
0?ooo`03ool0003oool0oooo01d0oooo0_oo002g0?oooaGo003o203oool1o`000040oooo00000ol0
0000oooo0?ooo`0U0?ooo`03ool0003oool0oooo01l0oooo0_oo002e0?oooaGo003o203oool1o`00
0040oooo00000ol00000oooo0?ooo`0V0?ooo`03ool0003oool0oooo0140oooo0P3oO`0=0?ooo`;o
o`00103oool20?mo00L0oooo0P3oO`2T0?oooaGo003o203oool1o`000040oooo00000ol00000oooo
0?ooo`0V0?ooo`03ool0003oool0oooo00D0oooo0P3oO`090?ooo`@0ogl03P3oool00ooo0000oooo
0?ooo`040?mo00D0oooo103oO`2S0?oooaGo003o203oool1o`000040oooo00000ol00000oooo0?oo
o`0V0?ooo`03ool0003oool0oooo00@0oooo103oO`080?ooo`@0ogl03`3oool00ooo0000oooo0?mo
00030?mo00D0oooo103oO`2S0?oooaGo003o203oool1o`000040oooo00000ol00000oooo0?ooo`0W
0?ooo`03ool0003oool0oooo00<0oooo103oO`090?ooo`80ogl04@3oool01?oo0000oooo0?mo003o
O`070?ooo`<0ogl0X`3ooolEo`00o`P0oooo0Ol000010?ooo`0000?o00000?ooo`3oool09`3oool0
0ooo0000oooo0?ooo`040?ooo`80ogl07P3oool00ooo0000oooo0?ooo`070?ooo`@0ogl0XP3ooolE
o`00o`P0oooo0Ol000010?ooo`0000?o00000?ooo`3oool0:03oool00ooo0000oooo0?ooo`0T0?oo
o`03ool0003oool0oooo00H0oooo103oO`2R0?oooaGo003o203oool1o`000040oooo00000ol00000
oooo0?ooo`0Y0?ooo`03ool0003oool0oooo02@0oooo0_oo00000`3oool0ogl00?mo00040?ooo`80
ogl0X`3ooolEo`00o`P0oooo0Ol000010?ooo`0000?o00000?ooo`3oool0:P3oool00ooo0000oooo
0?ooo`0C0?ooo`@0o`003P3oool01?oo0000ogl00?mo003oO`2X0?oooaGo003o203oool1o`000040
oooo00000ol00000oooo0?ooo`0[0?ooo`03ool0003oool0oooo0140oooo1P3o000=0?ooo`040?mo
0?oo003oo`000?mo0:P0oooo5Ol00?l80?ooo`7o00000@3oool00003o`00003oool0oooo02`0oooo
00?oo`000?ooo`3oool0203oool20?mo00D0oooo203o000=0?ooo`80ogl000?oo`000?ooo`3oool0
YP3ooolEo`00o`P0oooo0Ol000010?ooo`0000?o00000?ooo`3oool0;@3oool00ooo0000oooo0?oo
o`060?ooo`@0ogl0103oool80?l00100oooo00?oo`000?ooo`3oool0Y@3ooolEo`00o`P0oooo0Ol0
00010?ooo`0000?o00000?ooo`3oool0:`3oool20?mo00030?oooooo0000oooo00H0oooo103oO`04
0?ooo`P0o`004@3oool00ooo0000oooo0?ooo`2T0?oooaGo003o203oool1o`000040oooo00000ol0
0000oooo0?ooo`0Z0?ooo`@0ogl000<0ooooool0003oool01P3oool20?mo00D0oooo203o000;0?oo
o`80ogl01@3oool00ooo0000oooo0?ooo`090?ooo`80ogl0V03ooolEo`00o`P0oooo0Ol000010?oo
o`0000?o00000?ooo`3oool0:P3oool40?mo0080oooo00?oo`000?ooo`3oool0303oool60?l000/0
oooo103oO`040?ooo`03ool0003oool0oooo00P0oooo103oO`2G0?oooaGo003o203oool1o`000040
oooo00000ol00000oooo0?ooo`0[0?ooo`80ogl0103oool00ooo0000oooo0?ooo`0<0?ooo`@0o`00
303oool40?mo00D0oooo00?oo`000?ooo`3oool01`3oool40?mo09L0oooo5Ol00?l80?ooo`7o0000
0@3oool00003o`00003oool0oooo0380oooo0_oo000M0?ooo`80ogl01`3oool00ooo0000oooo0?oo
o`070?ooo`80ogl0]@3oool1o`000040oooo00000ol00000oooo0?ooo`0d0?ooo`03ool0003oool0
oooo02@0oooo00?oo`000?ooo`3oool0_@3oool1o`000040oooo00000ol00000oooo0?ooo`0e0?oo
o`03ool0003oool0oooo02@0oooo00?oo`000?ooo`3oool0_03oool1o`000040oooo00000ol00000
oooo0?ooo`0f0?ooo`;oo`009@3oool00ooo0000oooo0?ooo`2k0?ooo`7o00000@3oool00003o`00
003oool0oooo03P0oooo0_oo00000`3oO`00oooo0?ooo`020?mo01h0oooo00?oo`000?ooo`3oool0
^`3oool1o`000040oooo00000ol00000oooo0?ooo`0h0?ooo`80ogl00_oo00040?mo01h0oooo00?o
o`000?ooo`3oool0^P3oool1o`000040oooo00000ol00000oooo0?ooo`0h0?ooo`@0ogl00_oo0002
0?mo01h0oooo00?oo`000?ooo`3oool0^P3oool1o`000040oooo00000ol00000oooo0?ooo`0i0?oo
o`D0ogl000?oo`000?ooo`3oool07@3oool00ooo0000ogl00?mo002j0?ooo`7o00000@3oool00003
o`00003oool0oooo03/0oooo103oO`02ool001d0oooo00@0ogl0ool0003oO`00ogl0^@3oool1o`00
0040oooo00000ol00000oooo0?ooo`0l0?ooo`80ogl00`3oool2ool001/0oooo00@0ogl0ool0003o
O`00ogl0^@3oool1o`000040oooo00000ol00000oooo0?ooo`130?ooo`;oo`006P3oool00`3oO`3o
o`000?ooo`2i0?ooo`7o00000@3oool00003o`00003oool0oooo04D0oooo0_oo000I0?ooo`03ool0
003oool0oooo0;P0oooo0Ol000010?ooo`0000?o00000?ooo`3oool0A`3oool2ool001D0oooo0_oo
002k0?ooo`7o00000@3oool00003o`00003oool0oooo04T0oooo0ooo000@0?ooo`;oo`00_@3oool1
o`000040oooo00000ol00000oooo0?ooo`0a0?ooo`80ogl06@3oool3ool000`0oooo00?oo`000?oo
o`3oool0_@3oool1o`000040oooo00000ol00000oooo0?ooo`0`0?ooo`@0ogl06`3oool6ool000@0
oooo0_oo00300?ooo`7o00000@3oool00003o`00003oool0oooo0300oooo103oO`0Q0?ooo`Coo`00
`P3oool1o`000040oooo00000ol00000oooo0?ooo`0a0?ooo`80ogl0j03oool1o`000040oooo0000
0ol00000oooo0?ooo`3o0?oooa`0oooo0Ol000010?ooo`0000?o00000?ooo`3oool0o`3ooolL0?oo
o`7o00000@3oool00003o`00003oool0oooo0?l0oooo703oool1o`000040oooo00000ol00000oooo
0?ooo`3o0?oooa`0oooo0Ol000010?ooo`0000?o00000?ooo`3oool0o`3ooolL0?ooo`7o00000@3o
ool00003o`00003oool0oooo07d0oooo0P3oO`2L0?ooo`7o00000@3oool00003o`00003oool0oooo
07`0oooo103oO`2K0?ooo`7o00000@3oool00003o`00003oool0oooo05@0oooo0P3oO`0V0?ooo`@0
ogl0V`3oool1o`000040oooo00000ol00000oooo0?ooo`1C0?ooo`@0ogl09P3oool20?mo09`0oooo
0Ol000010?ooo`0000?o00000?ooo`3oool0D`3oool40?mo0<@0oooo0Ol000010?ooo`0000?o0000
0?ooo`3oool0E03oool20?mo0<D0oooo0Ol000010?ooo`0000?o00000?ooo`3oool0o`3ooolL0?oo
o`7o00000@3oool00003o`00003oool0oooo06<0oooo0P3oO`040?ooo`80ogl0/03oool1o`000040
oooo00000ol00000oooo0?ooo`1R0?ooo`@0ogl00P3oool40?mo0:l0oooo0Ol000010?ooo`0000?o
00000?ooo`3oool0HP3oool40?mo0080oooo103oO`2_0?ooo`7o00000@3oool00003o`00003oool0
oooo06<0oooo0P3oO`040?ooo`80ogl0/03oool1o`000040oooo00000ol00000oooo0?ooo`3o0?oo
oa`0oooo0Ol000010?ooo`0000?o00000?ooo`3oool0o`3ooolL0?ooo`7o00000@3oool00003o`00
003oool0oooo0?l0oooo703oool1o`000040oooo00000ol00000oooo0?ooo`3o0?oooa`0oooo0Ol0
00010?ooo`0000?o00000?ooo`3oool0o`3ooolL0?ooo`7o00000@3oool00003o`00003oool0oooo
0?l0oooo703oool1o`000040oooo00000ol00000oooo0?ooo`3o0?oooa`0oooo0Ol000010?ooo`00
00?o00000?ooo`3oool0o`3ooolL0?ooo`7o00000@3oool00003o`00003oool0oooo0?l0oooo703o
ool1o`000040oooo00000ol00000oooo0?ooo`3o0?oooa`0oooo0Ol000010?ooo`0000?o00000?oo
o`3oool0o`3ooolL0?ooo`7o00000@3oool00003o`00003oool0oooo0?l0oooo703oool1o`000040
oooo00000ol00000oooo0?ooo`3o0?oooa`0oooo0Ol000010?ooo`0000?o00000?ooo`3oool0o`3o
oolL0?ooo`7o00000@3oool00003o`00003oool0oooo0?l0oooo703oool1o`000040oooo00000ol0
0000oooo0?ooo`3o0?oooa`0oooo0Ol000010?ooo`0000?o00000?ooo`3oool0o`3ooolL0?ooo`7o
00000@3oool00003o`00003oool0oooo0?l0oooo703oool1o`000040oooo00000ol00000oooo0?oo
o`3o0?oooa`0oooo0Ol000010?ooo`0000?o00000?ooo`3oool0o`3ooolL0?ooo`7o00000@3oool0
0003o`00003oool0oooo0?l0oooo703oool1o`000040oooo00000ol00000oooo0?ooo`3o0?oooa`0
oooo0Ol000010?ooo`0000?o00000?ooo`3oool0o`3ooolL0?ooo`7o00000@3oool00003o`00003o
ool0oooo0?l0oooo703oool1o`000040oooo00000ol00000oooo0?ooo`3o0?oooa`0oooo0Ol00001
0?ooo`0000?o00000?ooo`3oool0o`3ooolL0?ooo`7o00000@3oool00003o`00003oool0oooo0?l0
oooo703oool1o`000040oooo00000ol00000oooo0?ooo`3o0?oooa`0oooo0Ol000010?ooo`0000?o
00000?ooo`3oool0o`3ooolL0?ooo`7o00000@3oool00003o`00003oool0oooo0?l0oooo703oool1
o`000040oooo00000ol00000oooo0?ooo`3o0?oooa`0oooo0Ol000010?ooo`0000?o00000?ooo`3o
ool0o`3ooolL0?ooo`7o00000@3oool00003o`00003oool0oooo0?l0oooo703oool1o`000040oooo
00000ol00000oooo0?ooo`3o0?ooo`@0oooo0P3oO`0F0?ooo`7o00000@3oool00003o`00003oool0
oooo0?l0oooo0`3oool40?mo01D0oooo0Ol000010?ooo`0000?o00000?ooo`3oool0o`3oool30?oo
o`@0ogl05@3oool1o`000040oooo00000ol00000oooo0?ooo`3o0?ooo`@0oooo0P3oO`0F0?ooo`7o
00000@3oool00003o`00003oool0oooo0?l0oooo703oool1o`000040oooo00000ol00000oooo0?oo
o`3o0?oooa`0oooo0Ol000010?ooo`0000?o00000?ooo`3oool0o`3ooolL0?ooo`7o00000@3oool0
0003o`00003oool0oooo0?l0oooo703oool1o`000040oooo00000ol00000oooo0?ooo`3o0?oooa`0
oooo0Ol000010?ooo`0000?o00000?ooo`3oool0o`3ooolL0?ooo`7o00000@3oool00003o`00003o
ool0oooo0?l0oooo703oool1o`000040oooo00000ol00000oooo0?ooo`3o0?oooa`0oooo0Ol00001
0?ooo`0000?o00000?ooo`3oool0o`3ooolL0?ooo`7o00000@3oool00003o`00003oool0oooo0?l0
oooo703oool1o`000040oooo00000ol00000oooo0?ooo`2e0?ooo`80ogl0<`3oool50?l0ob`0oooo
0Ol000010?ooo`0000?o00000?ooo`3oool0]03oool40?mo0340oooo1`3o0?l[0?ooo`7o00000@3o
ool00003o`00003oool0oooo0;@0oooo103oO`0`0?ooo`T0o`3o:P3oool1o`000040oooo00000ol0
0000oooo0?ooo`2e0?ooo`80ogl0<03oool;0?l0obT0oooo0Ol000010?ooo`0000?o00000?ooo`3o
ool0i03oool20?mo00030?ooo`3o0?l0o`3o00T0o`3o:@3oool1o`000040oooo00000ol00000oooo
0?ooo`3S0?ooo`@0ogl02`3o0?lY0?ooo`7o00000@3oool00003o`00003oool0oooo0<<0oooo0P3o
O`0N0?ooo`@0ogl02`3o0?lY0?ooo`7o00000@3oool00003o`00003oool0oooo0<80oooo103oO`0;
o`00oa<0oooo0P3oO`000`3oool0o`3o0?l0o`090?l0obT0oooo0Ol000010?ooo`0000?o00000?oo
o`3oool0`P3oool4o`00o`/0oooo0_l00?lE0?ooo`T0o`3o:P3oool1o`000040oooo00000ol00000
oooo0?ooo`2n0?ooo`Co003o00<0oooo0?mo003oO`003P3oool2o`00oa@0oooo1`3o0?l[0?ooo`7o
00000@3oool00003o`00003oool0oooo0;T0oooo0P3oO`03o`00oaL0oooo0_l00?l90?ooo`80ogl0
203oool50?l0ob`0oooo0Ol000010?ooo`0000?o00000?ooo`3oool0]`3oool4o`00o`030?mo003o
ool0oooo01T0oooo0_l00?l60?ooo`@0ogl0>03oool1o`000040oooo00000ol00000oooo0?ooo`2d
0?ooo`?o003o00<0oooo0?mo003oO`000P3oO`0L0?ooo`03o`00o`3oool0oooo00@0oooo103oO`03
0?ooo`80ogl0<`3oool1o`000040oooo00000ol00000oooo0?ooo`2b0?ooo`;o003o0`3oO`020?oo
o`80ogl04`3oool20?mo00P0oooo00?o003o0?ooo`3oool01@3oool20?mo00<0oooo103oO`0b0?oo
o`7o00000@3oool00003o`00003oool0oooo0;00oooo0_l00?l00`3oool0ogl00?mo00020?mo00H0
oooo0P3oO`0>0?ooo`@0ogl01`3oool00ol00?l0oooo0?ooo`0:0?ooo`@0ogl0<P3oool1o`000040
oooo00000ol00000oooo0?ooo`2^0?ooo`;o003o103oool20?mo00H0oooo103oO`0=0?ooo`@0ogl0
1`3oool00ol00?l0oooo0?ooo`0;0?ooo`80ogl0<`3oool1o`000040oooo00000ol00000oooo0?oo
o`2;0?ooo`80ogl0803oool00ol00?l0oooo0?ooo`040?ooo`80ogl01P3oool40?mo00h0oooo0P3o
O`090?ooo`03o`00o`3oool0oooo03l0oooo0Ol000010?ooo`0000?o00000?ooo`3oool0RP3oool4
0?mo01d0oooo0_l00?l60?ooo`@0ogl01P3oool20?mo01X0oooo00?o003o0?ooo`3oool0?`3oool1
o`000040oooo00000ol00000oooo0?ooo`2:0?ooo`@0ogl0703oool00ol00?l0oooo0?ooo`060?oo
o`@0ogl08P3oool00ol00?l0oooo0?ooo`0o0?ooo`7o00000@3oool00003o`00003oool0oooo08/0
oooo0P3oO`0K0?ooo`;o003o2P3oool20?mo02<0oooo00?o003o0?ooo`3oool0?`3oool1o`000040
oooo00000ol00000oooo0?ooo`2F0?ooo`80ogl03P3oool2o`00obX0oooo0P3oO`050?ooo`03o`00
o`3oool0oooo03l0oooo0Ol000010?ooo`0000?o00000?ooo`3oool0U@3oool40?mo00`0oooo00Co
003o0?ooo`3oO`00ogl0:03oool40?mo00<0oooo00?o003o0?ooo`3oool0@03oool1o`000040oooo
00000ol00000oooo0?ooo`2E0?ooo`@0ogl02P3oool2o`00o`030?ooo`3oO`00ogl00080ogl09`3o
ool40?mo00<0oooo00?o003o0?ooo`3oool0@03oool1o`000040oooo00000ol00000oooo0?ooo`2F
0?ooo`80ogl02P3oool01?l00?l0oooo0?ooo`3oool40?mo02P0oooo0P3oO`040?ooo`03o`00o`3o
ool0oooo0400oooo0Ol000010?ooo`0000?o00000?ooo`3oool0X@3oool00ol00?l0oooo0?ooo`03
0?ooo`80ogl0;P3oool00ol00?l0oooo0?ooo`110?ooo`7o00000@3oool00003o`00003oool0oooo
0:00oooo00?o003o0?ooo`3oool0<`3oool00ol00?l0oooo0?ooo`0B0?ooo`80ogl0;P3oool1o`00
0040oooo00000ol00000oooo0?ooo`2N0?ooo`;o003o=@3oool00ol00?l0oooo0?ooo`0B0?ooo`@0
ogl0;@3oool1o`000040oooo00000ol00000oooo0?ooo`2M0?ooo`03o`00o`3oool0oooo01D0oooo
10000?lL0?ooo`03o`00o`3oO`00ogl00180oooo103oO`0]0?ooo`7o00000@3oool00003o`00003o
ool0oooo09`0oooo00?o003o0?ooo`3oool05@3oool60000oaX0oooo00?o003o0?mo003oO`000P3o
O`0B0?ooo`80ogl0;P3oool1o`000040oooo00000ol00000oooo0?ooo`2K0?ooo`03o`00o`3oool0
oooo01D0oooo20000?lH0?ooo`03o`00o`3oool0ogl000<0ogl0@P3oool1o`000040oooo00000ol0
0000oooo0?ooo`2K0?ooo`03o`00o`3oool0oooo01D0oooo20000?lG0?ooo`04o`00o`3oool0oooo
0?ooo`80ogl0@`3oool1o`000040oooo00000ol00000oooo0?ooo`2J0?ooo`03o`00o`3oool0oooo
01H0oooo20000?lF0?ooo`03o`00o`3oool0oooo04L0oooo0Ol000010?ooo`0000?o00000?ooo`3o
ool0V@3oool00ol00?l0oooo0?ooo`0<0?ooo`80ogl0203oool00`3oO`00003o0000o`060000oaD0
oooo00?o003o0?ooo`3oool00P3oO`160?ooo`7o00000@3oool00003o`00003oool0oooo09T0oooo
00?o003o0?ooo`3oool02P3oool50?mo00L0oooo0P3oO`060000oa<0oooo0P3oO`000ol00?l0oooo
0?ooo`040?mo04D0oooo0Ol000010?ooo`0000?o00000?ooo`3oool0V03oool00ol00?l0oooo0?oo
o`0:0?ooo`H0ogl0203oool20?mo00@0003o4`3oool20?mo00;o003o0P3oool40?mo04D0oooo0Ol0
00010?ooo`0000?o00000?ooo`3oool0V03oool00ol00?l0oooo0?ooo`0:0?ooo`D0ogl08P3oool0
103oO`3o003o0?mo003oO`030?ooo`80ogl0AP3oool1o`000040oooo00000ol00000oooo0?ooo`1f
0?ooo`80ogl07`3oool00ol00?l0oooo0?ooo`0<0?ooo`80ogl0903oool00ol00?l0ogl00?mo001<
0?ooo`7o00000@3oool00003o`00003oool0oooo07D0oooo103oO`0N0?ooo`03o`00o`3oool0oooo
0340oooo00?o003o0?ooo`3oool0C@3oool1o`000040oooo00000ol00000oooo0?ooo`1e0?ooo`@0
ogl02P3oool20?mo0140oooo00?o003o0?ooo`3oool0<@3oool00ol00?l0oooo0?ooo`1>0?ooo`7o
00000@3oool00003o`00003oool0oooo07H0oooo0P3oO`0:0?ooo`@0ogl03`3oool00ol00?l0oooo
0?ooo`0H0?ooo`80ogl05`3oool00ol00?l0oooo0?ooo`1?0?ooo`7o00000@3oool00003o`00003o
ool0oooo0880oooo103oO`0?0?ooo`03o`00o`3oool0oooo01L0oooo103oO`0D0?ooo`;o003oDP3o
ool1o`000040oooo00000ol00000oooo0?ooo`230?ooo`80ogl03`3oool00ol00?l0oooo0?ooo`0B
0?ooo`80ogl0103oool40?mo0140oooo0ol00?mD0?ooo`7o00000@3oool00003o`00003oool0oooo
09@0oooo00?o003o0?ooo`3oool04@3oool40?mo00@0oooo0P3oO`0@0?ooo`;o003oE`3oool1o`00
0040oooo00000ol00000oooo0?ooo`2D0?ooo`03o`00o`3oool0oooo0140oooo103oO`0E0?ooo`03
o`00o`3oool0oooo05L0oooo0Ol000010?ooo`0000?o00000?ooo`3oool0U03oool00ol00?l0oooo
0?ooo`0B0?ooo`80ogl0503oool2o`00oeX0oooo0Ol000010?ooo`0000?o00000?ooo`3oool0U03o
ool00ol00?l0oooo0?ooo`0V0?ooo`;o003oG03oool1o`000040oooo00000ol00000oooo0?ooo`2E
0?ooo`03o`00o`3oool0oooo02@0oooo00?o003o0?ooo`3oool0G03oool1o`000040oooo00000ol0
0000oooo0?ooo`2E0?ooo`03o`00o`3oool0oooo0280oooo0_l00?mO0?ooo`7o00000@3oool00003
o`00003oool0oooo09D0oooo00?o003o0?ooo`3oool0803oool2o`00of40oooo0Ol000010?ooo`00
00?o00000?ooo`3oool0Q03oool20?mo00l0oooo0_l00?lO0?ooo`;o003oH`3oool1o`000040oooo
00000ol00000oooo0?ooo`230?ooo`@0ogl0403oool2o`00oaX0oooo0ol00?mU0?ooo`7o00000@3o
ool00003o`00003oool0oooo08<0oooo103oO`0B0?ooo`;o003o503oool4o`00ofP0oooo0Ol00001
0?ooo`0000?o00000?ooo`3oool0Q03oool20?mo01D0oooo0ol00?l>0?ooo`?o003o0`3oool20?mo
06L0oooo0Ol000010?ooo`0000?o00000?ooo`3oool0WP3oool3o`00o`D0oooo1_l00?l50?ooo`@0
ogl0IP3oool1o`000040oooo00000ol00000oooo0?ooo`2Q0?ooo`Go003o2`3oool40?mo06H0oooo
0Ol000010?ooo`0000?o00000?ooo`3oool0/P3oool20?mo06L0oooo0Ol000010?ooo`0000?o0000
0?ooo`3oool0o`3ooolL0?ooo`7o00000@3oool00003o`00003oool0oooo0?l0oooo703oool1o`00
0040oooo00000ol00000oooo0?ooo`1k0?ooo`80ogl0WP3oool1o`000040oooo00000ol00000oooo
0?ooo`1j0?ooo`@0ogl0W@3oool1o`000040oooo00000ol00000oooo0?ooo`1j0?ooo`@0ogl0803o
ool20?mo07/0oooo0Ol000010?ooo`0000?o00000?ooo`3oool0N`3oool20?mo0200oooo103oO`1j
0?ooo`7o00000@3oool00003o`00003oool0oooo09d0oooo103oO`1j0?ooo`7o00000@3oool00003
o`00003oool0oooo0900oooo0P3oO`0<0?ooo`80ogl0N`3oool1o`000040oooo00000ol00000oooo
0?ooo`2?0?ooo`@0ogl0R03oool1o`000040oooo00000ol00000oooo0?ooo`2?0?ooo`@0ogl0R03o
ool1o`000040oooo00000ol00000oooo0?ooo`2@0?ooo`80ogl08`3oool20?mo06@0oooo0Ol00001
0?ooo`0000?o00000?ooo`3oool0]03oool40?mo06<0oooo0Ol000010?ooo`0000?o00000?ooo`3o
ool0]03oool40?mo06<0oooo0Ol000010?ooo`0000?o00000?ooo`3oool0]@3oool20?mo06@0oooo
0Ol000010?ooo`0000?o00000?ooo`3oool0o`3ooolL0?ooo`7o00000@3oool00003o`00003oool0
oooo0?l0oooo703oool1o`000040oooo00000ol00000oooo0?ooo`3o0?oooa`0oooo0Ol000010?oo
o`0000?o00000?ooo`3oool0o`3ooolL0?ooo`7o00000@3oool00003o`00003oool0oooo0?l0oooo
703oool1o`000040oooo00000ol00000oooo0?ooo`3o0?oooa`0oooo0Ol000010?ooo`0000?o0000
0?ooo`3oool0o`3ooolL0?ooo`7o00000@3oool00003o`00003oool0oooo0?l0oooo703oool1o`00
0040oooo00000ol00000oooo0?ooo`3o0?oooa`0oooo0Ol000010?ooo`0000?o00000?ooo`3oool0
o`3ooolL0?ooo`7o00000@3oool00003o`00003oool0oooo0?l0oooo703oool1o`000040oooo0000
0ol00000oooo0?ooo`3o0?oooa`0oooo0Ol000010?ooo`0000?o00000?ooo`3oool0o`3ooolL0?oo
o`7o00000@3oool00003o`00003oool0oooo0?l0oooo703oool1o`000040oooo00000ol00000oooo
0?ooo`3o0?oooa`0oooo0Ol000010?ooo`0000?o00000?ooo`3oool0o`3ooolL0?ooo`7o00000@3o
ool00003o`00003oool0oooo0?l0oooo703oool1o`000040oooo00000ol00000oooo0?ooo`3o0?oo
oa`0oooo0Ol000010?ooo`0000?o00000?ooo`3oool0o`3ooolL0?ooo`7o00000@3oool00003o`00
003oool0oooo0?l0oooo703oool1o`000040oooo00000ol00000oooo0?ooo`3o0?oooa`0oooo0Ol0
00010?ooo`0000?o00000?ooo`3oool0o`3ooolL0?ooo`7o00000@3oool00003o`00003oool0oooo
0?l0oooo703oool1o`000040oooo00000ol00000oooo0?ooo`3o0?oooa`0oooo0Ol000010?ooo`00
00?o00000?ooo`3oool0o`3ooolL0?ooo`7o00000@3oool00003o`00003oool0oooo0?l0oooo703o
ool1o`000040oooo00000ol00000oooo0?ooo`3o0?oooa`0oooo0Ol000010?ooo`0000?o00000?oo
o`3oool0o`3ooolL0?ooo`7o00000@3oool00003o`00003oool0oooo0?l0oooo703oool1o`000040
oooo00000ol00000oooo0?ooo`3o0?oooa`0oooo0Ol000010?ooo`0000?o00000?ooo`3oool0o`3o
oolL0?ooo`7o00000@3oool00003o`00003oool0oooo0?l0oooo703oool1o`000040oooo00000ol0
0000oooo0?ooo`3o0?oooa`0oooo0Ol000010?ooo`0000?o00000?ooo`3oool0o`3ooolL0?ooo`7o
00000@3oool00003o`00003oool0oooo0?l0oooo703oool1o`000040oooo00000ol00000oooo0?oo
o`3o0?oooa`0oooo0Ol000010?ooo`0000?o00000?ooo`3oool0o`3ooolL0?ooo`7o00000@3oool0
0003o`00003oool0oooo08h0oooo0P3oO`2;0?ooo`7o00000@3oool00003o`00003oool0oooo08d0
oooo103oO`2:0?ooo`7o00000@3oool00003o`00003oool0oooo08d0oooo103oO`2:0?ooo`7o0000
0@3oool00003o`00003oool0oooo08h0oooo0P3oO`2;0?ooo`7o00000@3oool00003o`00003oool0
oooo0?l0oooo703oool1o`000040oooo00000ol00000oooo0?ooo`3o0?oooa`0oooo0Ol000010?oo
o`0000?o00000?ooo`3oool0o`3ooolL0?ooo`7o00000@3oool00003o`00003oool0oooo0?l0oooo
703oool1o`000040oooo00000ol00000oooo0?ooo`3o0?oooa`0oooo0Ol000010?ooo`0000?o0000
0?ooo`3oool0o`3ooolL0?ooo`7o00000@3oool00003o`00003oool0oooo0?l0oooo703oool1o`00
0040oooo00000ol00000oooo0?ooo`3o0?oooa`0oooo0Ol000010?ooo`0000?o00000?ooo`3oool0
o`3ooolL0?ooo`7o00000@3oool00003o`00003oool0oooo0?l0oooo703oool1o`000040oooo0000
0ol00000oooo0?ooo`3o0?oooa`0oooo0Ol000010?ooo`0000?o00000?ooo`3oool0o`3ooolL0?oo
o`7o00000@3oool00003o`00003oool0oooo0?l0oooo703oool1o`000040oooo00000ol00000oooo
0?ooo`3o0?oooa`0oooo0Ol000010?ooo`0000?o00000?ooo`3oool0o`3ooolL0?ooo`7o00000@3o
ool00003o`00003oool0oooo0?l0oooo703oool1o`000040oooo00000ol00000oooo0?ooo`3o0?oo
oa`0oooo0Ol000010?ooo`0000?o00000?ooo`3oool0o`3ooolL0?ooo`7o00000@3oool00003o`00
003oool0oooo0?l0oooo703oool1o`000040oooo00000ol00000oooo0?ooo`3o0?oooa`0oooo0Ol0
00010?ooo`0000?o00000?ooo`3oool0o`3ooolL0?ooo`7o00000@3oool00?oo00008?l000010?oo
o`00\
\>"],
  ImageRangeCache->{{{0, 287}, {287, 0}} -> {-1.01089, -1.01089, 0.00704453, \
0.00704453}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.49505 0.5 0.49505 [
[ 0 0 -0.125 0 ]
[ 0 0 -0.125 0 ]
[ 0 1 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
0 0 m
1 0 L
s
0 0 m
0 1 L
s
0 1 m
1 1 L
s
1 0 m
1 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
1 .5 0 r
.015 w
.03175 .1355 Mdot
.03435 .12523 Mdot
.11137 .12765 Mdot
.14107 .18841 Mdot
.16218 .24538 Mdot
.17294 .21053 Mdot
.18267 .18577 Mdot
.18434 .1304 Mdot
.18553 .30956 Mdot
.20401 .239 Mdot
.21247 .27571 Mdot
.21687 .20845 Mdot
.22376 .2799 Mdot
.22832 .27485 Mdot
.29063 .20974 Mdot
.29686 .25079 Mdot
.30487 .22936 Mdot
.30683 .34623 Mdot
.32055 .20902 Mdot
.32574 .21979 Mdot
.34472 .28521 Mdot
.35998 .36393 Mdot
.36335 .24976 Mdot
.3794 .36608 Mdot
.42386 .66992 Mdot
.44391 .74519 Mdot
.45059 .34198 Mdot
.47208 .67586 Mdot
.47436 .71381 Mdot
.49778 .59825 Mdot
.50874 .91643 Mdot
.51516 .76219 Mdot
.53655 .61374 Mdot
.56563 .75219 Mdot
.59189 .65665 Mdot
.59581 .61604 Mdot
.59923 .6556 Mdot
.60292 .68499 Mdot
.62656 .67779 Mdot
.63555 .72451 Mdot
.63919 .652 Mdot
.64169 .6004 Mdot
.64246 .58611 Mdot
.64496 .54267 Mdot
.64608 .77288 Mdot
.65077 .64308 Mdot
.66065 .57816 Mdot
.67474 .59169 Mdot
.69296 .563 Mdot
.72815 .65902 Mdot
.73169 .58879 Mdot
.74669 .61318 Mdot
.74821 .65474 Mdot
.75963 .63781 Mdot
.79673 .57809 Mdot
.80925 .55852 Mdot
.81525 .58444 Mdot
.83417 .62985 Mdot
.83598 .55526 Mdot
.91595 .49319 Mdot
1 0 0 r
.005 w
.16128 .17044 m
.18734 .17269 L
.21339 .17909 L
.2345 .18734 L
.23945 .19126 L
.2655 .20415 L
.27874 .21339 L
.29156 .22295 L
.31204 .23945 L
.31761 .24532 L
.33549 .2655 L
.34367 .28341 L
.34499 .29156 L
.34367 .29798 L
.31761 .3104 L
.29156 .30711 L
.2655 .30014 L
.24507 .29156 L
.23945 .28747 L
.21339 .27402 L
.20155 .2655 L
.18734 .25472 L
.16884 .23945 L
.16128 .2313 L
.14618 .21339 L
.13806 .18734 L
.16128 .17044 L
s
0 0 1 r
.65633 .57701 m
.68239 .56842 L
.70844 .56313 L
.7345 .56168 L
.76055 .5752 L
.76359 .57817 L
.76859 .60422 L
.76055 .62333 L
.75627 .63028 L
.7345 .65485 L
.73298 .65633 L
.70844 .6775 L
.69922 .68239 L
.68239 .69294 L
.65633 .70579 L
.64983 .70844 L
.63028 .71539 L
.60422 .72268 L
.57817 .72651 L
.55211 .7214 L
.53145 .70844 L
.52926 .68239 L
.54239 .65633 L
.55211 .63983 L
.56625 .63028 L
.57817 .6193 L
.60119 .60422 L
.60422 .60227 L
.63028 .58726 L
.65315 .57817 L
.65633 .57701 L
s
1 0 0 r
.03 w
.24141 .24033 Mdot
0 0 1 r
.64872 .64417 Mdot
1 0 0 r
.79703 .00495 m
.79703 .00495 L
.87129 .00495 L
.87129 .00495 L
F
0 0 1 r
.89604 .00495 m
.89604 .25248 L
.9703 .25248 L
.9703 .00495 L
F
1 0 1 r
.04 w
.91595 .49319 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P000182000`400?l00000o`00003ooooooolQ
ooooo`00o`00000P0000007ooooo00000`00003oooooooooo`3ooooooacooooo0@000001ooooo`00
00<00000ooooooooool0o_oooolE0000o`Sooooo0@000001ooooo`0000<00000ooooooooool0o_oo
oolE0000o`Sooooo0@000001ooooo`0000<00000ooooooooool0o_oooolE0000o`Sooooo0@000001
ooooo`0000<00000ooooooooool0o_oooolE0000o`Sooooo0@000001ooooo`0000<00000oooooooo
ool0o_oooolE0000o`Sooooo0@000001ooooo`0000<00000ooooooooool0o_oooolE0000o`Sooooo
0@000001ooooo`0000<00000ooooooooool0o_oooolE0000o`Sooooo0@000001ooooo`0000<00000
ooooooooool0o_oooolE0000o`Sooooo0@000001ooooo`0000<00000ooooooooool0o_oooolE0000
o`Sooooo0@000001ooooo`0000<00000ooooooooool0o_oooolE0000o`Sooooo0@000001ooooo`00
00<00000ooooooooool0o_oooolE0000o`Sooooo0@000001ooooo`0000<00000ooooooooool0o_oo
oolE0000o`Sooooo0@000001ooooo`0000<00000ooooooooool0o_oooolE0000o`Sooooo0@000001
ooooo`0000<00000ooooooooool0o_oooolE0000o`Sooooo0@000001ooooo`0000<00000oooooooo
ool0o_oooolE0000o`Sooooo0@000001ooooo`0000<00000ooooooooool0o_oooolE0000o`Sooooo
0@000001ooooo`0000<00000ooooooooool0o_oooolE0000o`Sooooo0@000001ooooo`0000<00000
ooooooooool0o_oooolE0000o`Sooooo0@000001ooooo`0000<00000ooooooooool0o_oooolE0000
o`Sooooo0@000001ooooo`0000<00000ooooooooool0o_oooolE0000o`Sooooo0@000001ooooo`00
00<00000ooooooooool0o_oooolE0000o`Sooooo0@000001ooooo`0000<00000ooooooooool0o_oo
oolE0000o`Sooooo0@000001ooooo`0000<00000ooooooooool0o_oooolE0000o`Sooooo0@000001
ooooo`0000<00000ooooooooool0o_oooolE0000o`Sooooo0@000001ooooo`0000<00000oooooooo
ool0o_oooolE0000o`Sooooo0@000001ooooo`0000<00000ooooooooool0o_oooolE0000o`Sooooo
0@000001ooooo`0000<00000ooooooooool0o_oooolE0000o`Sooooo0@000001ooooo`0000<00000
ooooooooool0o_oooolE0000o`Sooooo0@000001ooooo`0000<00000ooooooooool0o_oooolE0000
o`Sooooo0@000001ooooo`0000<00000ooooooooool0o_oooolE0000o`Sooooo0@000001ooooo`00
00<00000ooooooooool0o_oooolE0000o`Sooooo0@000001ooooo`0000<00000ooooooooool0o_oo
oolE0000o`Sooooo0@000001ooooo`0000<00000ooooooooool01_ooool2oomo0?Kooooo5@000?l8
ooooo`4000000Oooool0000300000?oooooooooo00Gooooo1?ooO`0Cooooo`;oogl0h?oooolE0000
o`Sooooo0@000001ooooo`0000<00000ooooooooool01Oooool4oomo01;ooooo1?ooO`0Booooo`;o
ogl0booooolE0000o`Sooooo0@000001ooooo`0000<00000ooooooooool01Oooool3oomo01?ooooo
1?ooO`0Aooooo`Coogl0b_oooolE0000o`Sooooo0@000001ooooo`0000<00000ooooooooool01?oo
ool4oomo01Cooooo0_ooO`0Booooo`Coogl0b_oooolE0000o`Sooooo0@000001ooooo`0000<00000
ooooooooool01?ooool4oomo02Wooooo0_ooO`3;oooooaD0003o2?ooool10000007ooooo00000`00
003oooooooooo`05ooooo`;oogl0mooooolE0000o`Sooooo0@000001ooooo`0000<00000oooooooo
ool0o_oooolE0000o`Sooooo0@000001ooooo`0000<00000ooooooooool0o_oooolE0000o`Sooooo
0@000001ooooo`0000<00000ooooooooool0o_oooolE0000o`Sooooo0@000001ooooo`0000<00000
ooooooooool0o_oooolE0000o`Sooooo0@000001ooooo`0000<00000ooooooooool0o_oooolE0000
o`Sooooo0@000001ooooo`0000<00000ooooooooool0o_oooolE0000o`Sooooo0@000001ooooo`00
00<00000ooooooooool0o_oooolE0000o`Sooooo0@000001ooooo`0000<00000ooooooooool0:_oo
ool60?l00<kooooo5@000?l8ooooo`4000000Oooool0000300000?oooooooooo02Wooooo00<0o`00
ooooooooool01?ooool50?l00<Wooooo5@000?l8ooooo`4000000Oooool0000300000?oooooooooo
02Oooooo0P3o000<ooooo`@0o`00aOoooolE0000o`Sooooo0@000001ooooo`0000<00000oooooooo
ool09_ooool00`3o003oooooooooo`0@ooooo`@0o`00`OoooolE0000o`Sooooo0@000001ooooo`00
00<00000ooooooooool09?ooool00oooO`00o`00ooooo`09ooooo`;oogl02oooool30?l00;kooooo
5@000?l8ooooo`4000000Oooool0000300000?oooooooooo02?ooooo00Coogl00?l00?ooO`3oogl0
2?ooool4oomo00gooooo00?oo`00ooooooooool0^ooooolE0000o`Sooooo0@000001ooooo`0000<0
0000ooooooooool08oooool01?ooO`00o`00oomo0?ooO`08ooooo`Coogl03_ooool20?l00;_ooooo
5@000?l8ooooo`4000000Oooool0000300000?oooooooooo02Cooooo00?oogl00?l00?ooool02Ooo
ool2oomo017ooooo0P3o002ioooooaD0003o2?ooool10000007ooooo00000`00003oooooooooo`0U
ooooo`030?l00?oooooooooo01gooooo0P3o002goooooaD0003o2?ooool10000007ooooo00000`00
003oooooooooo`0Uooooo`030?l00?oooooooooo01oooooo0P3o002eoooooaD0003o2?ooool10000
007ooooo00000`00003oooooooooo`0Vooooo`030?l00?oooooooooo017ooooo0_ooO`0=ooooo`80
o`001?ooool2oomo00Oooooo0_ooO`2ToooooaD0003o2?ooool10000007ooooo00000`00003ooooo
ooooo`0Vooooo`030?l00?oooooooooo00Gooooo0_ooO`09ooooo`Coogl03_ooool00`3o003ooooo
ooooo`04oomo00Gooooo1?ooO`2SoooooaD0003o2?ooool10000007ooooo00000`00003ooooooooo
o`0Vooooo`030?l00?oooooooooo00Cooooo1?ooO`08ooooo`Coogl03oooool00`3o003ooooooomo
0003oomo00Gooooo1?ooO`2SoooooaD0003o2?ooool10000007ooooo00000`00003oooooooooo`0W
ooooo`030?l00?oooooooooo00?ooooo1?ooO`09ooooo`;oogl04Oooool0103o003ooooooomo0?oo
O`07ooooo`?oogl0XooooolE0000o`Sooooo0@000001ooooo`0000<00000ooooooooool09oooool0
0`3o003oooooooooo`04ooooo`;oogl07_ooool00`3o003oooooooooo`07ooooo`Coogl0X_oooolE
0000o`Sooooo0@000001ooooo`0000<00000ooooooooool0:?ooool00`3o003oooooooooo`0Toooo
o`030?l00?oooooooooo00Kooooo1?ooO`2RoooooaD0003o2?ooool10000007ooooo00000`00003o
ooooooooo`0Yooooo`030?l00?oooooooooo02Cooooo0P3o00000oooooooogl0oomo0004ooooo`;o
ogl0XooooolE0000o`Sooooo0@000001ooooo`0000<00000ooooooooool0:_ooool00`3o003ooooo
ooooo`0Cooooo`Coo`003_ooool0103o003oogl0oomo0?ooO`2XoooooaD0003o2?ooool10000007o
oooo00000`00003oooooooooo`0[ooooo`030?l00?oooooooooo017ooooo1_oo000=ooooo`04oomo
003o0000o`00oomo0:Sooooo5@000?l8ooooo`4000000Oooool0000300000?oooooooooo02cooooo
00<0o`00ooooooooool02?ooool2oomo00Gooooo2?oo000=ooooo`;oogl000<0o`00ooooooooool0
Y_oooolE0000o`Sooooo0@000001ooooo`0000<00000ooooooooool0;Oooool00`3o003ooooooooo
o`06ooooo`Coogl01?ooool8ool0013ooooo00<0o`00ooooooooool0YOoooolE0000o`Sooooo0@00
0001ooooo`0000<00000ooooooooool0:oooool2oomo0003ooooo`3o003ooooo00Kooooo1?ooO`04
ooooo`Soo`004Oooool00`3o003oooooooooo`2ToooooaD0003o2?ooool10000007ooooo00000`00
003oooooooooo`0Zooooo`Coogl000?ooooo0?l00?ooool01_ooool2oomo00Gooooo2?oo000;oooo
o`;oogl01Oooool00`3o003oooooooooo`09ooooo`;oogl0V?oooolE0000o`Sooooo0@000001oooo
o`0000<00000ooooooooool0:_ooool4oomo00;ooooo00<0o`00ooooooooool03?ooool6ool000_o
oooo1?ooO`04ooooo`030?l00?oooooooooo00Sooooo1?ooO`2GoooooaD0003o2?ooool10000007o
oooo00000`00003oooooooooo`0[ooooo`;oogl01?ooool00`3o003oooooooooo`0<ooooo`Coo`00
3?ooool4oomo00Gooooo00<0o`00ooooooooool01oooool4oomo09Oooooo5@000?l8ooooo`400000
0Oooool0000300000?oooooooooo03;ooooo0P3o000Mooooo`;oogl01oooool00`3o003ooooooooo
o`07ooooo`;oogl0]Oooool10000007ooooo00000`00003oooooooooo`0dooooo`030?l00?oooooo
oooo02Cooooo00<0o`00ooooooooool0_Oooool10000007ooooo00000`00003oooooooooo`0eoooo
o`030?l00?oooooooooo02Cooooo00<0o`00ooooooooool0_?ooool10000007ooooo00000`00003o
ooooooooo`0fooooo`80o`009Oooool00`3o003oooooooooo`2kooooo`4000000Oooool000030000
0?oooooooooo03Sooooo0P3o00000oooO`3oooooooooo`02oomo01kooooo00<0o`00ooooooooool0
^oooool10000007ooooo00000`00003oooooooooo`0hooooo`;oogl00P3o0004oomo01kooooo00<0
o`00ooooooooool0^_ooool10000007ooooo00000`00003oooooooooo`0hooooo`Coogl00P3o0002
oomo01kooooo00<0o`00ooooooooool0^_ooool10000007ooooo00000`00003oooooooooo`0ioooo
o`Googl000<0o`00ooooooooool07Oooool00`3o003oogl0oomo002jooooo`4000000Oooool00003
00000?oooooooooo03_ooooo1?ooO`020?l001gooooo00Coogl00?l00?ooO`3oogl0^Oooool10000
007ooooo00000`00003oooooooooo`0looooo`;oogl00oooool20?l001_ooooo00Coogl00?l00?oo
O`3oogl0^Oooool10000007ooooo00000`00003oooooooooo`13ooooo`80o`006_ooool00oooO`00
o`00ooooo`2iooooo`4000000Oooool0000300000?oooooooooo04Gooooo0P3o000Iooooo`030?l0
0?oooooooooo0;Sooooo0@000001ooooo`0000<00000ooooooooool0Aoooool20?l001Gooooo0P3o
002kooooo`4000000Oooool0000300000?oooooooooo04Wooooo0`3o000@ooooo`80o`00_Oooool1
0000007ooooo00000`00003oooooooooo`0aooooo`;oogl06Oooool30?l000cooooo00<0o`00oooo
ooooool0_Oooool10000007ooooo00000`00003oooooooooo`0`ooooo`Coogl06oooool60?l000Co
oooo0P3o0030ooooo`4000000Oooool0000300000?oooooooooo033ooooo1?ooO`0Qooooo`@0o`00
`_ooool10000007ooooo00000`00003oooooooooo`0aooooo`;oogl0j?ooool10000007ooooo0000
0`00003oooooooooo`3ooooooacooooo0@000001ooooo`0000<00000ooooooooool0oooooolLoooo
o`4000000Oooool0000300000?oooooooooo0?oooooo7?ooool10000007ooooo00000`00003ooooo
ooooo`3ooooooacooooo0@000001ooooo`0000<00000ooooooooool0oooooolLooooo`4000000Ooo
ool0000300000?oooooooooo07gooooo0_ooO`2Looooo`4000000Oooool0000300000?oooooooooo
07cooooo1?ooO`2Kooooo`4000000Oooool0000300000?oooooooooo05Cooooo0_ooO`0Vooooo`Co
ogl0Voooool10000007ooooo00000`00003oooooooooo`1Cooooo`Coogl09_ooool2oomo09cooooo
0@000001ooooo`0000<00000ooooooooool0Doooool4oomo0<Cooooo0@000001ooooo`0000<00000
ooooooooool0E?ooool2oomo0<Gooooo0@000001ooooo`0000<00000ooooooooool0oooooolLoooo
o`4000000Oooool0000300000?oooooooooo06?ooooo0_ooO`04ooooo`;oogl0/?ooool10000007o
oooo00000`00003oooooooooo`1Rooooo`Coogl00_ooool4oomo0:oooooo0@000001ooooo`0000<0
0000ooooooooool0H_ooool4oomo00;ooooo1?ooO`2_ooooo`4000000Oooool0000300000?oooooo
oooo06?ooooo0_ooO`04ooooo`;oogl0/?ooool10000007ooooo00000`00003oooooooooo`3ooooo
oacooooo0@000001ooooo`0000<00000ooooooooool0oooooolLooooo`4000000Oooool000030000
0?oooooooooo0?oooooo7?ooool10000007ooooo00000`00003oooooooooo`3ooooooacooooo0@00
0001ooooo`0000<00000ooooooooool0oooooolLooooo`4000000Oooool0000300000?oooooooooo
0?oooooo7?ooool10000007ooooo00000`00003oooooooooo`3ooooooacooooo0@000001ooooo`00
00<00000ooooooooool0oooooolLooooo`4000000Oooool0000300000?oooooooooo0?oooooo7?oo
ool10000007ooooo00000`00003oooooooooo`3ooooooacooooo0@000001ooooo`0000<00000oooo
ooooool0oooooolLooooo`4000000Oooool0000300000?oooooooooo0?oooooo7?ooool10000007o
oooo00000`00003oooooooooo`3ooooooacooooo0@000001ooooo`0000<00000ooooooooool0oooo
oolLooooo`4000000Oooool0000300000?oooooooooo0?oooooo7?ooool10000007ooooo00000`00
003oooooooooo`3ooooooacooooo0@000001ooooo`0000<00000ooooooooool0oooooolLooooo`40
00000Oooool0000300000?oooooooooo0?oooooo7?ooool10000007ooooo00000`00003ooooooooo
o`3ooooooacooooo0@000001ooooo`0000<00000ooooooooool0oooooolLooooo`4000000Oooool0
000300000?oooooooooo0?oooooo7?ooool10000007ooooo00000`00003oooooooooo`3ooooooaco
oooo0@000001ooooo`0000<00000ooooooooool0oooooolLooooo`4000000Oooool0000300000?oo
oooooooo0?oooooo7?ooool10000007ooooo00000`00003oooooooooo`3ooooooacooooo0@000001
ooooo`0000<00000ooooooooool0oooooolLooooo`4000000Oooool0000300000?oooooooooo0?oo
oooo7?ooool10000007ooooo00000`00003oooooooooo`3ooooooacooooo0@000001ooooo`0000<0
0000ooooooooool0oooooolLooooo`4000000Oooool0000300000?oooooooooo0?oooooo0_ooool5
ool0oaGooooo0@000001ooooo`0000<00000ooooooooool0ooooool1ooooo`Ooo`3o5?ooool10000
007ooooo00000`00003oooooooooo`3oooooo`Woo`3o4oooool10000007ooooo00000`00003ooooo
ooooo`3nooooo`_oo`3o4_ooool10000007ooooo00000`00003oooooooooo`3nooooo`_oo`3o4_oo
ool10000007ooooo00000`00003oooooooooo`3nooooo`_oo`3o4_ooool10000007ooooo00000`00
003oooooooooo`3nooooo`_oo`3o4_ooool10000007ooooo00000`00003oooooooooo`3nooooo`_o
o`3o4_ooool10000007ooooo00000`00003oooooooooo`3oooooo`Woo`3o4oooool10000007ooooo
00000`00003oooooooooo`3oooooo`7ooooo1ooo0?lDooooo`4000000Oooool0000300000?oooooo
oooo0?oooooo0_ooool5ool0oaGooooo0@000001ooooo`0000<00000ooooooooool0oooooolLoooo
o`4000000Oooool0000300000?oooooooooo0?oooooo7?ooool10000007ooooo00000`00003ooooo
ooooo`3ooooooacooooo0@000001ooooo`0000<00000ooooooooool0oooooolLooooo`4000000Ooo
ool0000300000?oooooooooo0?oooooo7?ooool10000007ooooo00000`00003oooooooooo`3ooooo
oacooooo0@000001ooooo`0000<00000ooooooooool0oooooolLooooo`4000000Oooool000030000
0?oooooooooo0;Gooooo0_ooO`1Tooooo`4000000Oooool0000300000?oooooooooo0;Cooooo1?oo
O`1Sooooo`4000000Oooool0000300000?oooooooooo0;Cooooo1?ooO`1Sooooo`4000000Oooool0
000300000?oooooooooo0;Gooooo0_ooO`0eooooo`;oogl0;Oooool10000007ooooo00000`00003o
ooooooooo`3Tooooo`;oogl01Oooool4oomo02cooooo0@000001ooooo`0000<00000ooooooooool0
hoooool4oomo00Cooooo1?ooO`0/ooooo`4000000Oooool0000300000?oooooooooo0<?ooooo0_oo
O`0Nooooo`Coogl01Oooool2oomo02gooooo0@000001ooooo`0000<00000ooooooooool0`_ooool4
oomo00/0003o4oooool2oomo03Gooooo0@000001ooooo`0000<00000ooooooooool0`_ooool40000
o`_ooooo0P000?m8ooooo`4000000Oooool0000300000?oooooooooo0;kooooo10000?l00ooooooo
ogl0oomo000>ooooo`80003oA_ooool10000007ooooo00000`00003oooooooooo`2iooooo`;oogl0
0`000?lGooooo`80003o2Oooool2oomo03Wooooo0@000001ooooo`0000<00000ooooooooool0]ooo
ool01@000?oo003oo`00o`000?ooogl001_ooooo00?o003o0000ooooool01Oooool4oomo03Sooooo
0@000001ooooo`0000<00000ooooooooool0]?ooool30000o`03ooooooooO`3oogl000;oogl07?oo
ool00`000?ooooooooooo`04ooooo`Coogl00oooool2oomo03?ooooo0@000001ooooo`0000<00000
ooooooooool0/_ooool20000o`?oogl00_ooool2oomo01?ooooo0_ooO`08ooooo`030000oooooooo
oooo00Gooooo0_ooO`03ooooo`Coogl0<_ooool10000007ooooo00000`00003oooooooooo`2`oooo
o`80003o00?ooooooomo0?ooO`000_ooO`06ooooo`;oogl03_ooool4oomo00Oooooo00<0003ooooo
ooooool02_ooool4oomo03;ooooo0@000001ooooo`0000<00000ooooooooool0[_ooool20000o`Co
oooo0_ooO`06ooooo`Coogl03Oooool4oomo00Oooooo00<0003oooooooooool02oooool2oomo03?o
oooo0@000001ooooo`0000<00000ooooooooool0Roooool2oomo023ooooo00<0003oooooooooool0
1?ooool2oomo00Kooooo1?ooO`0>ooooo`;oogl02Oooool00`000?ooooooooooo`0oooooo`400000
0Oooool0000300000?oooooooooo08[ooooo1?ooO`0Mooooo`80003o1_ooool4oomo00Kooooo0_oo
O`0Jooooo`030000oooooooooooo03oooooo0@000001ooooo`0000<00000ooooooooool0R_ooool4
oomo01cooooo00<0003oooooooooool01_ooool4oomo02;ooooo00<0003oooooooooool0?oooool1
0000007ooooo00000`00003oooooooooo`2;ooooo`;oogl06oooool00`000?oo003oooooo`09oooo
o`;oogl08oooool00`000?ooooooooooo`0oooooo`4000000Oooool0000300000?oooooooooo09Ko
oooo0_ooO`0>ooooo`80003o:_ooool2oomo00Gooooo00<0003oooooooooool0?oooool10000007o
oooo00000`00003oooooooooo`2Eooooo`Coogl03?ooool010000?oooooooomo0?ooO`0Xooooo`Co
ogl00oooool00`000?ooooooooooo`10ooooo`4000000Oooool0000300000?oooooooooo09Gooooo
1?ooO`0:ooooo`80003o00?ooooooomo0?ooO`000_ooO`0Wooooo`Coogl00oooool00`000?oooooo
ooooo`10ooooo`4000000Oooool0000300000?oooooooooo09Kooooo0_ooO`0:ooooo`040000oooo
ooooooooooooo`Coogl0:?ooool2oomo00Cooooo00<0003oooooooooool0@?ooool10000007ooooo
00000`00003oooooooooo`2Qooooo`030000oooooooooooo00?ooooo0_ooO`0^ooooo`030000oooo
oooooooo047ooooo0@000001ooooo`0000<00000ooooooooool0X?ooool00`000?ooooooooooo`0c
ooooo`030000oooooooooooo01;ooooo0_ooO`0^ooooo`4000000Oooool0000300000?oooooooooo
09kooooo0P000?leooooo`030000oooooooooooo01;ooooo1?ooO`0]ooooo`4000000Oooool00003
00000?oooooooooo09gooooo00<0003oooooooooool05Oooool4o`00oacooooo00<0003ooomo0?oo
O`004_ooool4oomo02gooooo0@000001ooooo`0000<00000ooooooooool0W?ooool00`000?oooooo
ooooo`0Eooooo`Ko003o6_ooool00`000?ooogl0oomo0002oomo01;ooooo0_ooO`0^ooooo`400000
0Oooool0000300000?oooooooooo09_ooooo00<0003oooooooooool05Oooool8o`00oaSooooo00<0
003oooooooooO`000oooO`12ooooo`4000000Oooool0000300000?oooooooooo09_ooooo00<0003o
ooooooooool05Oooool8o`00oaOooooo00@0003ooooooooooooooooo0_ooO`13ooooo`4000000Ooo
ool0000300000?oooooooooo09[ooooo00<0003oooooooooool05_ooool8o`00oaKooooo00<0003o
ooooooooool0Aoooool10000007ooooo00000`00003oooooooooo`2Iooooo`030000oooooooooooo
00cooooo0_ooO`08ooooo`03oomo0?l00?oo003o00Ko003o5Oooool00`000?ooooooooooo`02oomo
04Kooooo0@000001ooooo`0000<00000ooooooooool0VOooool00`000?ooooooooooo`0:ooooo`Go
ogl01oooool2oomo00Ko003o4oooool2oomo0003o`00oooooooooooo00Coogl0AOooool10000007o
oooo00000`00003oooooooooo`2Hooooo`030000oooooooooooo00[ooooo1_ooO`08ooooo`;oogl0
1?l00?lCooooo`;oogl00P000?l2ooooo`Coogl0AOooool10000007ooooo00000`00003ooooooooo
o`2Hooooo`030000oooooooooooo00[ooooo1OooO`0Rooooo`04oomo00000?ooogl0oomo00?ooooo
0_ooO`16ooooo`4000000Oooool0000300000?oooooooooo07Kooooo0_ooO`0Oooooo`030000oooo
oooooooo00cooooo0_ooO`0Tooooo`030000ooooO`3oogl004cooooo0@000001ooooo`0000<00000
ooooooooool0MOooool4oomo01kooooo00<0003oooooooooool0<Oooool00`000?ooooooooooo`1=
ooooo`4000000Oooool0000300000?oooooooooo07Gooooo1?ooO`0:ooooo`;oogl04Oooool00`00
0?ooooooooooo`0aooooo`030000oooooooooooo04kooooo0@000001ooooo`0000<00000oooooooo
ool0M_ooool2oomo00[ooooo1?ooO`0?ooooo`030000oooooooooooo01Sooooo0_ooO`0Gooooo`03
0000oooooooooooo04oooooo0@000001ooooo`0000<00000ooooooooool0P_ooool4oomo00oooooo
00<0003oooooooooool05oooool4oomo01Cooooo0P000?mBooooo`4000000Oooool0000300000?oo
oooooooo08?ooooo0_ooO`0?ooooo`030000oooooooooooo01;ooooo0_ooO`04ooooo`Coogl04Ooo
ool30000oeCooooo0@000001ooooo`0000<00000ooooooooool0U?ooool00`000?ooooooooooo`0A
ooooo`Coogl01?ooool2oomo013ooooo0P000?mGooooo`4000000Oooool0000300000?oooooooooo
09Cooooo00<0003oooooooooool04Oooool4oomo01Gooooo00<0003oooooooooool0Eoooool10000
007ooooo00000`00003oooooooooo`2Dooooo`030000oooooooooooo01;ooooo0_ooO`0Dooooo`80
003oF_ooool10000007ooooo00000`00003oooooooooo`2Dooooo`030000oooooooooooo02Kooooo
0P000?mLooooo`4000000Oooool0000300000?oooooooooo09Gooooo00<0003oooooooooool09?oo
ool00`000?ooooooooooo`1Looooo`4000000Oooool0000300000?oooooooooo09Gooooo00<0003o
ooooooooool08_ooool20000oeoooooo0@000001ooooo`0000<00000ooooooooool0UOooool00`00
0?ooooooooooo`0Pooooo`80003oHOooool10000007ooooo00000`00003oooooooooo`24ooooo`;o
ogl03oooool20000oaoooooo0P000?mSooooo`4000000Oooool0000300000?oooooooooo08?ooooo
1?ooO`0@ooooo`80003o6_ooool30000ofGooooo0@000001ooooo`0000<00000ooooooooool0Pooo
ool4oomo01;ooooo0P000?lDooooo`@0003oJ?ooool10000007ooooo00000`00003oooooooooo`24
ooooo`;oogl05Oooool30000o`kooooo0`000?l3ooooo`;oogl0Ioooool10000007ooooo00000`00
003oooooooooo`2Nooooo`<0003o1Oooool60000o`Gooooo1?ooO`1Vooooo`4000000Oooool00003
00000?oooooooooo0:7ooooo1@000?l;ooooo`Coogl0I_ooool10000007ooooo00000`00003ooooo
ooooo`2booooo`;oogl0Ioooool10000007ooooo00000`00003oooooooooo`3ooooooacooooo0@00
0001ooooo`0000<00000ooooooooool0oooooolLooooo`4000000Oooool0000300000?oooooooooo
07_ooooo0_ooO`2Nooooo`4000000Oooool0000300000?oooooooooo07[ooooo1?ooO`2Mooooo`40
00000Oooool0000300000?oooooooooo07[ooooo1?ooO`0Pooooo`;oogl0Noooool10000007ooooo
00000`00003oooooooooo`1kooooo`;oogl08?ooool4oomo07[ooooo0@000001ooooo`0000<00000
ooooooooool0WOooool4oomo07[ooooo0@000001ooooo`0000<00000ooooooooool0T?ooool2oomo
00cooooo0_ooO`1kooooo`4000000Oooool0000300000?oooooooooo08oooooo1?ooO`28ooooo`40
00000Oooool0000300000?oooooooooo08oooooo1?ooO`28ooooo`4000000Oooool0000300000?oo
oooooooo093ooooo0_ooO`0Sooooo`;oogl0I?ooool10000007ooooo00000`00003oooooooooo`2d
ooooo`Coogl0Hoooool10000007ooooo00000`00003oooooooooo`2dooooo`Coogl0Hoooool10000
007ooooo00000`00003oooooooooo`2eooooo`;oogl0I?ooool10000007ooooo00000`00003ooooo
ooooo`3ooooooacooooo0@000001ooooo`0000<00000ooooooooool0oooooolLooooo`4000000Ooo
ool0000300000?oooooooooo0?oooooo7?ooool10000007ooooo00000`00003oooooooooo`3ooooo
oacooooo0@000001ooooo`0000<00000ooooooooool0oooooolLooooo`4000000Oooool000030000
0?oooooooooo0?oooooo7?ooool10000007ooooo00000`00003oooooooooo`3ooooooacooooo0@00
0001ooooo`0000<00000ooooooooool0oooooolLooooo`4000000Oooool0000300000?oooooooooo
0?oooooo7?ooool10000007ooooo00000`00003oooooooooo`3ooooooacooooo0@000001ooooo`00
00<00000ooooooooool0oooooolLooooo`4000000Oooool0000300000?oooooooooo0?oooooo7?oo
ool10000007ooooo00000`00003oooooooooo`3ooooooacooooo0@000001ooooo`0000<00000oooo
ooooool0oooooolLooooo`4000000Oooool0000300000?oooooooooo0?oooooo7?ooool10000007o
oooo00000`00003oooooooooo`3ooooooacooooo0@000001ooooo`0000<00000ooooooooool0oooo
oolLooooo`4000000Oooool0000300000?oooooooooo0?oooooo7?ooool10000007ooooo00000`00
003oooooooooo`3ooooooacooooo0@000001ooooo`0000<00000ooooooooool0oooooolLooooo`40
00000Oooool0000300000?oooooooooo0?oooooo7?ooool10000007ooooo00000`00003ooooooooo
o`3ooooooacooooo0@000001ooooo`0000<00000ooooooooool0oooooolLooooo`4000000Oooool0
000300000?oooooooooo0?oooooo7?ooool10000007ooooo00000`00003oooooooooo`3ooooooaco
oooo0@000001ooooo`0000<00000ooooooooool0oooooolLooooo`4000000Oooool0000300000?oo
oooooooo0?oooooo7?ooool10000007ooooo00000`00003oooooooooo`3ooooooacooooo0@000001
ooooo`0000<00000ooooooooool0oooooolLooooo`4000000Oooool0000300000?oooooooooo0?oo
oooo7?ooool10000007ooooo00000`00003oooooooooo`3ooooooacooooo0@000001ooooo`0000<0
0000ooooooooool0oooooolLooooo`4000000Oooool0000300000?oooooooooo0?oooooo7?ooool1
0000007ooooo00000`00003oooooooooo`3ooooooacooooo0@000001ooooo`0000<00000oooooooo
ool0oooooolLooooo`4000000Oooool0000300000?oooooooooo0?oooooo7?ooool10000007ooooo
00000`00003oooooooooo`3ooooooacooooo0@000001ooooo`0000<00000ooooooooool0S_ooool2
oomo08_ooooo0@000001ooooo`0000<00000ooooooooool0SOooool4oomo08[ooooo0@000001oooo
o`0000<00000ooooooooool0SOooool4oomo08[ooooo0@000001ooooo`0000<00000ooooooooool0
S_ooool2oomo08_ooooo0@000001ooooo`0000<00000ooooooooool0oooooolLooooo`4000000Ooo
ool0000300000?oooooooooo0?oooooo7?ooool10000007ooooo00000`00003oooooooooo`3ooooo
oacooooo0@000001ooooo`0000<00000ooooooooool0oooooolLooooo`4000000Oooool000030000
0?oooooooooo0?oooooo7?ooool10000007ooooo00000`00003oooooooooo`3ooooooacooooo0@00
0001ooooo`0000<00000ooooooooool0oooooolLooooo`4000000Oooool0000300000?oooooooooo
0?oooooo7?ooool10000007ooooo00000`00003oooooooooo`3ooooooacooooo0@000001ooooo`00
00<00000ooooooooool0oooooolLooooo`4000000Oooool0000300000?oooooooooo0?oooooo7?oo
ool10000007ooooo00000`00003oooooooooo`3ooooooacooooo0@000001ooooo`0000<00000oooo
ooooool0oooooolLooooo`4000000Oooool0000300000?oooooooooo0?oooooo7?ooool10000007o
oooo00000`00003oooooooooo`3ooooooacooooo0@000001ooooo`0000<00000ooooooooool0oooo
oolLooooo`4000000Oooool0000300000?oooooooooo0?oooooo7?ooool10000007ooooo00000`00
003oooooooooo`3ooooooacooooo0@000001ooooo`0000<00000ooooooooool0oooooolLooooo`40
00000Oooool0000300000?oooooooooo0?oooooo7?ooool10000007ooooo00000`00003ooooooooo
o`3ooooooacooooo0@000001ooooo`00o`00000P0000007ooooo0000\
\>"],
  ImageRangeCache->{{{0, 287}, {287, 0}} -> {-1.01089, -1.01089, 0.00704453, \
0.00704453}}]
}, Closed]]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Global visualization", "Subsection"],

Cell[CellGroupData[{

Cell["Computation", "Subsubsection"],

Cell[BoxData[
    \(\(p1\  = \ \(ClassProbabilitiesDataSet[{{x, y}}, tstModel]\  // \ 
            Flatten\)\  // \ First;\)\)], "Input"]
}, Closed]],

Cell[CellGroupData[{

Cell["Visualization", "Subsubsection"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(ContourPlot[p1, {x, \(-1\), 1}, {y, \(-1\), 1}, 
        PlotPoints \[Rule] 25, \ FrameTicks \[Rule] None, 
        ColorFunction \[Rule] \((RGBColor\  @@ \ \((#\ \((List\  @@ \ \ \
colors[\([1]\)])\)\  + \ \((1 - #)\)\ List\  @@ \ 
                        colors[\([2]\)])\) &)\)];\)\)], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% ContourGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.480769 0.5 0.480769 [
[ 0 0 -0.125 0 ]
[ 0 0 -0.125 0 ]
[ 0 1 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
0 0 m
1 0 L
s
0 0 m
0 1 L
s
0 1 m
1 1 L
s
1 0 m
1 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
.2 0 .8 r
.01923 .98077 m
.98077 .98077 L
.98077 .01923 L
.01923 .01923 L
F
0 g
.5 Mabswid
.3 0 .7 r
.01923 .97902 m
.05639 .94071 L
.05929 .93771 L
.09524 .90064 L
.09936 .8964 L
.1341 .86058 L
.13942 .85509 L
.17296 .82051 L
.17949 .81378 L
.21181 .78045 L
.21955 .77247 L
.25067 .74038 L
.25962 .73116 L
.28953 .70032 L
.29968 .68985 L
.32838 .66026 L
.33974 .64854 L
.36724 .62019 L
.37981 .60723 L
.4061 .58013 L
.41987 .56593 L
.44495 .54006 L
.45994 .52462 L
.48381 .5 L
.5 .48331 L
.52267 .45994 L
.54006 .442 L
.56152 .41987 L
.58013 .40069 L
.60038 .37981 L
.62019 .35938 L
.63924 .33974 L
.66026 .31807 L
.6781 .29968 L
.70032 .27677 L
.71695 .25962 L
.74038 .23546 L
.75581 .21955 L
.78045 .19415 L
.79467 .17949 L
.82051 .15284 L
.83353 .13942 L
.86058 .11153 L
.87238 .09936 L
.90064 .07022 L
.91124 .05929 L
.94071 .02893 L
.9501 .01923 L
.01923 .01923 L
F
0 g
.01923 .97902 m
.05639 .94071 L
.05929 .93771 L
.09524 .90064 L
.09936 .8964 L
.1341 .86058 L
.13942 .85509 L
.17296 .82051 L
.17949 .81378 L
.21181 .78045 L
.21955 .77247 L
.25067 .74038 L
.25962 .73116 L
.28953 .70032 L
.29968 .68985 L
.32838 .66026 L
.33974 .64854 L
.36724 .62019 L
.37981 .60723 L
.4061 .58013 L
.41987 .56593 L
.44495 .54006 L
.45994 .52462 L
.48381 .5 L
.5 .48331 L
.52267 .45994 L
.54006 .442 L
.56152 .41987 L
.58013 .40069 L
.60038 .37981 L
.62019 .35938 L
.63924 .33974 L
.66026 .31807 L
.6781 .29968 L
.70032 .27677 L
.71695 .25962 L
.74038 .23546 L
.75581 .21955 L
.78045 .19415 L
.79467 .17949 L
.82051 .15284 L
.83353 .13942 L
.86058 .11153 L
.87238 .09936 L
.90064 .07022 L
.91124 .05929 L
.94071 .02893 L
.9501 .01923 L
s
.4 0 .6 r
.01923 .84546 m
.04343 .82051 L
.05929 .80415 L
.08228 .78045 L
.09936 .76284 L
.12114 .74038 L
.13942 .72153 L
.16 .70032 L
.17949 .68022 L
.19885 .66026 L
.21955 .63892 L
.23771 .62019 L
.25962 .59761 L
.27657 .58013 L
.29968 .5563 L
.31542 .54006 L
.33974 .51499 L
.35428 .5 L
.37981 .47368 L
.39314 .45994 L
.41987 .43237 L
.432 .41987 L
.45994 .39106 L
.47085 .37981 L
.5 .34976 L
.50971 .33974 L
.54006 .30845 L
.54857 .29968 L
.58013 .26714 L
.58743 .25962 L
.62019 .22583 L
.62628 .21955 L
.66026 .18452 L
.66514 .17949 L
.70032 .14321 L
.704 .13942 L
.74038 .10191 L
.74286 .09936 L
.78045 .0606 L
.78171 .05929 L
.82051 .01929 L
.82057 .01923 L
.01923 .01923 L
F
0 g
.01923 .84546 m
.04343 .82051 L
.05929 .80415 L
.08228 .78045 L
.09936 .76284 L
.12114 .74038 L
.13942 .72153 L
.16 .70032 L
.17949 .68022 L
.19885 .66026 L
.21955 .63892 L
.23771 .62019 L
.25962 .59761 L
.27657 .58013 L
.29968 .5563 L
.31542 .54006 L
.33974 .51499 L
.35428 .5 L
.37981 .47368 L
.39314 .45994 L
.41987 .43237 L
.432 .41987 L
.45994 .39106 L
.47085 .37981 L
.5 .34976 L
.50971 .33974 L
.54006 .30845 L
.54857 .29968 L
.58013 .26714 L
.58743 .25962 L
.62019 .22583 L
.62628 .21955 L
.66026 .18452 L
.66514 .17949 L
.70032 .14321 L
.704 .13942 L
.74038 .10191 L
.74286 .09936 L
.78045 .0606 L
.78171 .05929 L
.82051 .01929 L
.82057 .01923 L
s
.5 0 .5 r
.01923 .73093 m
.04892 .70032 L
.05929 .68962 L
.08777 .66026 L
.09936 .64831 L
.12663 .62019 L
.13942 .607 L
.16549 .58013 L
.17949 .56569 L
.20434 .54006 L
.21955 .52439 L
.2432 .5 L
.25962 .48308 L
.28206 .45994 L
.29968 .44177 L
.32092 .41987 L
.33974 .40046 L
.35977 .37981 L
.37981 .35915 L
.39863 .33974 L
.41987 .31784 L
.43749 .29968 L
.45994 .27653 L
.47634 .25962 L
.5 .23523 L
.5152 .21955 L
.54006 .19392 L
.55406 .17949 L
.58013 .15261 L
.59292 .13942 L
.62019 .1113 L
.63177 .09936 L
.66026 .06999 L
.67063 .05929 L
.70032 .02869 L
.70949 .01923 L
.01923 .01923 L
F
0 g
.01923 .73093 m
.04892 .70032 L
.05929 .68962 L
.08777 .66026 L
.09936 .64831 L
.12663 .62019 L
.13942 .607 L
.16549 .58013 L
.17949 .56569 L
.20434 .54006 L
.21955 .52439 L
.2432 .5 L
.25962 .48308 L
.28206 .45994 L
.29968 .44177 L
.32092 .41987 L
.33974 .40046 L
.35977 .37981 L
.37981 .35915 L
.39863 .33974 L
.41987 .31784 L
.43749 .29968 L
.45994 .27653 L
.47634 .25962 L
.5 .23523 L
.5152 .21955 L
.54006 .19392 L
.55406 .17949 L
.58013 .15261 L
.59292 .13942 L
.62019 .1113 L
.63177 .09936 L
.66026 .06999 L
.67063 .05929 L
.70032 .02869 L
.70949 .01923 L
s
.6 0 .4 r
.01923 .62508 m
.02398 .62019 L
.05929 .58378 L
.06283 .58013 L
.09936 .54247 L
.10169 .54006 L
.13942 .50116 L
.14055 .5 L
.1794 .45994 L
.17949 .45985 L
.21826 .41987 L
.21955 .41854 L
.25712 .37981 L
.25962 .37723 L
.29598 .33974 L
.29968 .33592 L
.33483 .29968 L
.33974 .29462 L
.37369 .25962 L
.37981 .25331 L
.41255 .21955 L
.41987 .212 L
.4514 .17949 L
.45994 .17069 L
.49026 .13942 L
.5 .12938 L
.52912 .09936 L
.54006 .08807 L
.56798 .05929 L
.58013 .04677 L
.60683 .01923 L
.01923 .01923 L
F
0 g
.01923 .62508 m
.02398 .62019 L
.05929 .58378 L
.06283 .58013 L
.09936 .54247 L
.10169 .54006 L
.13942 .50116 L
.14055 .5 L
.1794 .45994 L
.17949 .45985 L
.21826 .41987 L
.21955 .41854 L
.25712 .37981 L
.25962 .37723 L
.29598 .33974 L
.29968 .33592 L
.33483 .29968 L
.33974 .29462 L
.37369 .25962 L
.37981 .25331 L
.41255 .21955 L
.41987 .212 L
.4514 .17949 L
.45994 .17069 L
.49026 .13942 L
.5 .12938 L
.52912 .09936 L
.54006 .08807 L
.56798 .05929 L
.58013 .04677 L
.60683 .01923 L
s
.7 0 .3 r
.01923 .52135 m
.03994 .5 L
.05929 .48004 L
.0788 .45994 L
.09936 .43874 L
.11766 .41987 L
.13942 .39743 L
.15651 .37981 L
.17949 .35612 L
.19537 .33974 L
.21955 .31481 L
.23423 .29968 L
.25962 .2735 L
.27308 .25962 L
.29968 .23219 L
.31194 .21955 L
.33974 .19088 L
.3508 .17949 L
.37981 .14958 L
.38966 .13942 L
.41987 .10827 L
.42851 .09936 L
.45994 .06696 L
.46737 .05929 L
.5 .02565 L
.50623 .01923 L
.01923 .01923 L
F
0 g
.01923 .52135 m
.03994 .5 L
.05929 .48004 L
.0788 .45994 L
.09936 .43874 L
.11766 .41987 L
.13942 .39743 L
.15651 .37981 L
.17949 .35612 L
.19537 .33974 L
.21955 .31481 L
.23423 .29968 L
.25962 .2735 L
.27308 .25962 L
.29968 .23219 L
.31194 .21955 L
.33974 .19088 L
.3508 .17949 L
.37981 .14958 L
.38966 .13942 L
.41987 .10827 L
.42851 .09936 L
.45994 .06696 L
.46737 .05929 L
.5 .02565 L
.50623 .01923 L
s
.8 0 .2 r
.01923 .41394 m
.05233 .37981 L
.05929 .37263 L
.09119 .33974 L
.09936 .33132 L
.13005 .29968 L
.13942 .29001 L
.1689 .25962 L
.17949 .2487 L
.20776 .21955 L
.21955 .20739 L
.24662 .17949 L
.25962 .16609 L
.28548 .13942 L
.29968 .12478 L
.32433 .09936 L
.33974 .08347 L
.36319 .05929 L
.37981 .04216 L
.40205 .01923 L
.01923 .01923 L
F
0 g
.01923 .41394 m
.05233 .37981 L
.05929 .37263 L
.09119 .33974 L
.09936 .33132 L
.13005 .29968 L
.13942 .29001 L
.1689 .25962 L
.17949 .2487 L
.20776 .21955 L
.21955 .20739 L
.24662 .17949 L
.25962 .16609 L
.28548 .13942 L
.29968 .12478 L
.32433 .09936 L
.33974 .08347 L
.36319 .05929 L
.37981 .04216 L
.40205 .01923 L
s
.9 0 .1 r
.01923 .29565 m
.05418 .25962 L
.05929 .25434 L
.09304 .21955 L
.09936 .21304 L
.1319 .17949 L
.13942 .17173 L
.17075 .13942 L
.17949 .13042 L
.20961 .09936 L
.21955 .08911 L
.24847 .05929 L
.25962 .0478 L
.28733 .01923 L
.01923 .01923 L
F
0 g
.01923 .29565 m
.05418 .25962 L
.05929 .25434 L
.09304 .21955 L
.09936 .21304 L
.1319 .17949 L
.13942 .17173 L
.17075 .13942 L
.17949 .13042 L
.20961 .09936 L
.21955 .08911 L
.24847 .05929 L
.25962 .0478 L
.28733 .01923 L
s
1 0 0 r
.01923 .15421 m
.03357 .13942 L
.05929 .11291 L
.07243 .09936 L
.09936 .0716 L
.11129 .05929 L
.13942 .03028 L
.15015 .01923 L
.01923 .01923 L
F
0 g
.01923 .15421 m
.03357 .13942 L
.05929 .11291 L
.07243 .09936 L
.09936 .0716 L
.11129 .05929 L
.13942 .03028 L
.15015 .01923 L
s
.1 0 .9 r
.98077 .16283 m
.96463 .17949 L
.94071 .20414 L
.92576 .21955 L
.90064 .24545 L
.8869 .25962 L
.86058 .28676 L
.84805 .29968 L
.82051 .32807 L
.80919 .33974 L
.78045 .36938 L
.77033 .37981 L
.74038 .41069 L
.73148 .41987 L
.70032 .452 L
.69262 .45994 L
.66026 .49331 L
.65376 .5 L
.62019 .53461 L
.61491 .54006 L
.58013 .57592 L
.57605 .58013 L
.54006 .61723 L
.53719 .62019 L
.5 .65854 L
.49834 .66026 L
.45994 .69985 L
.45948 .70032 L
.42062 .74038 L
.41987 .74116 L
.38177 .78045 L
.37981 .78247 L
.34291 .82051 L
.33974 .82377 L
.30405 .86058 L
.29968 .86508 L
.26519 .90064 L
.25962 .90639 L
.22633 .94071 L
.21955 .94771 L
.18748 .98077 L
.98077 .98077 L
F
0 g
.98077 .16283 m
.96463 .17949 L
.94071 .20414 L
.92576 .21955 L
.90064 .24545 L
.8869 .25962 L
.86058 .28676 L
.84805 .29968 L
.82051 .32807 L
.80919 .33974 L
.78045 .36938 L
.77033 .37981 L
.74038 .41069 L
.73148 .41987 L
.70032 .452 L
.69262 .45994 L
.66026 .49331 L
.65376 .5 L
.62019 .53461 L
.61491 .54006 L
.58013 .57592 L
.57605 .58013 L
.54006 .61723 L
.53719 .62019 L
.5 .65854 L
.49834 .66026 L
.45994 .69985 L
.45948 .70032 L
.42062 .74038 L
.41987 .74116 L
.38177 .78045 L
.37981 .78247 L
.34291 .82051 L
.33974 .82377 L
.30405 .86058 L
.29968 .86508 L
.26519 .90064 L
.25962 .90639 L
.22633 .94071 L
.21955 .94771 L
.18748 .98077 L
s
0 0 1 r
.98077 .46214 m
.94406 .5 L
.94071 .50345 L
.90519 .54006 L
.90064 .54476 L
.86633 .58013 L
.86058 .58606 L
.82748 .62019 L
.82051 .62737 L
.78862 .66026 L
.78045 .66868 L
.74976 .70032 L
.74038 .70999 L
.7109 .74038 L
.70032 .7513 L
.67204 .78045 L
.66026 .7926 L
.63319 .82051 L
.62019 .83391 L
.59433 .86058 L
.58013 .87522 L
.55547 .90064 L
.54006 .91653 L
.51661 .94071 L
.5 .95786 L
.47776 .98077 L
.98077 .98077 L
F
0 g
.98077 .46214 m
.94406 .5 L
.94071 .50345 L
.90519 .54006 L
.90064 .54476 L
.86633 .58013 L
.86058 .58606 L
.82748 .62019 L
.82051 .62737 L
.78862 .66026 L
.78045 .66868 L
.74976 .70032 L
.74038 .70999 L
.7109 .74038 L
.70032 .7513 L
.67204 .78045 L
.66026 .7926 L
.63319 .82051 L
.62019 .83391 L
.59433 .86058 L
.58013 .87522 L
.55547 .90064 L
.54006 .91653 L
.51661 .94071 L
.5 .95786 L
.47776 .98077 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P000182000`400?l00000o`00003ooooooolQ
ooooo`00ool0000Po`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`00
00?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?oo
ool1o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000oooo
ooooool0:?ooool00ol0003oooooooooo`0Tooooo`03o`000?oooooooooo01kooooo00?o0000oooo
ooooool06oooool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo01[ooooo00?o0000oooo
ooooool07Oooool00ol0003oooooooooo`0Rooooo`03o`000?oooooooooo00_ooooo0Ol00001oooo
o`0000?o0000ooooooooool00_oooolU0?l00003o`00003V01T0iP0I02@0iP0I00?o00000<`0<`3<
03<07`3<03<00ol00000/`1<0;<0C00J0;<0C003o`00002I06H0V@1V01X0V@1V00?o000007l0O`1o
07l06P1o07l00ol00000IP2I06H0V@0N06H0V@030000001<0;<0C02c0240C02c00?o0000oc<0c?lc
0<`01olc0<`5ooooo`7o00000Oooool00003o`000?oooooooooo00;ooooo903o00000ol00000iP0I
0>H06@0T0>H06@03o`00003<03<0c00c01l0c00c00?o00000;<0C02c04`06P2c04`00ol00000V@1V
09T0IP0J09T0IP03o`00001o07l0O`1o01X0O`1o00?o000006H0V@1V09T07P1V09T00`000000C02c
04`0/`0Q04`0/`03o`000?lc0<co<`3<00So<`3<1Oooool1o`00007ooooo00000ol0003ooooooooo
o`02ooooob<0o`0000?o00000>H06@3V01T0903V01T00ol00000c00c0<`0<`0O0<`0<`03o`00002c
04`0/`1<01/0/`1<00?o000009T0IP2I06H06@2I06H00ol00000O`1o07l0O`0J07l0O`03o`00001V
09T0IP2I01h0IP2I00<0000004`0/`1<0;<08@1<0;<00ol0003o<`3<oc<0c009oc<0c0Gooooo0Ol0
0001ooooo`0000?o0000ooooooooool00_oooolS0?l00003o`00003V01T0iP0I02<0iP0I00?o0000
0<`0<`3<03<07`3<03<00ol00000/`1<0;<0C00K0;<0C003o`00002I06H0V@1V01T0V@1V00?o0000
07l0O`1o07l06`1o07l00ol00000IP2I06H0V@0M06H0V@030000001<0;<0C02c0280C02c00?o0000
oc<0c?lc0<`02Olc0<`5ooooo`7o00000Oooool00003o`000?oooooooooo00;ooooo8P3o00000ol0
0000iP0I0>H06@0S0>H06@03o`00003<03<0c00c01l0c00c00?o00000;<0C02c04`06`2c04`00ol0
0000V@1V09T0IP0I09T0IP03o`00001o07l0O`1o01/0O`1o00?o000006H0V@1V09T07@1V09T00`00
0000C02c04`0/`0R04`0/`03o`000?lc0<co<`3<00[o<`3<1Oooool1o`00007ooooo00000ol0003o
ooooooooo`02ooooob40o`0000?o00000>H06@3V01T08`3V01T00ol00000c00c0<`0<`0O0<`0<`03
o`00002c04`0/`1<01/0/`1<00?o000009T0IP2I06H06@2I06H00ol00000O`1o07l0O`0K07l0O`03
o`00001V09T0IP2I01d0IP2I00<0000004`0/`1<0;<08P1<0;<00ol0003o<`3<oc<0c00;oc<0c0Go
oooo0Ol00001ooooo`0000?o0000ooooooooool00_oooolP0?l00003o`00003V01T0iP0I02<0iP0I
00?o00000<`0<`3<03<07`3<03<00ol00000/`1<0;<0C00K0;<0C003o`00002I06H0V@1V01T0V@1V
00?o000007l0O`1o07l06`1o07l00ol00000IP2I06H0V@0M06H0V@030000001<0;<0C02c0280C02c
00?o0000oc<0c?lc0<`03?lc0<`5ooooo`7o00000Oooool00003o`000?oooooooooo00;ooooo7`3o
00000ol00000iP0I0>H06@0S0>H06@03o`00003<03<0c00c01l0c00c00?o00000;<0C02c04`06`2c
04`00ol00000V@1V09T0IP0I09T0IP03o`00001o07l0O`1o01/0O`1o00?o000006H0V@1V09T07@1V
09T00`000000C02c04`0/`0R04`0/`03o`000?lc0<co<`3<00go<`3<1Oooool1o`00007ooooo0000
0ol0003oooooooooo`02oooooah0o`0000?o00000>H06@3V01T0903V01T00ol00000c00c0<`0<`0N
0<`0<`03o`00002c04`0/`1<01/0/`1<00?o000009T0IP2I06H06@2I06H00ol00000O`1o07l0O`0K
07l0O`03o`00001V09T0IP2I01d0IP2I00<0000004`0/`1<0;<08P1<0;<00ol0003o<`3<oc<0c00>
oc<0c0Gooooo0Ol00001ooooo`0000?o0000ooooooooool00_oooolM0?l00003o`00003V01T0iP0I
02@0iP0I00?o00000<`0<`3<03<07P3<03<00ol00000/`1<0;<0C00K0;<0C003o`00002I06H0V@1V
01T0V@1V00?o000007l0O`1o07l06`1o07l00ol00000IP2I06H0V@0M06H0V@030000001<0;<0C02c
0280C02c00?o0000oc<0c?lc0<`03olc0<`5ooooo`7o00000Oooool00003o`000?oooooooooo00;o
oooo703o00000ol00000iP0I0>H06@0T0>H06@03o`00003<03<0c00c01h0c00c00?o00000;<0C02c
04`06`2c04`00ol00000V@1V09T0IP0I09T0IP03o`00001o07l0O`1o01/0O`1o00?o000006H0V@1V
09T07@1V09T00`000000C02c04`0/`0R04`0/`03o`000?lc0<co<`3<013o<`3<1Oooool1o`00007o
oooo00000ol0003oooooooooo`02oooooaX0o`000_l0000V0>H06@03o`00003<03<0c00c01h0c00c
00?o00000;<0C02c04`06`2c04`00ol00000V@1V09T0IP0I09T0IP03o`00001o07l0O`1o01/0O`1o
00?o000006H0V@1V09T0701V09T00ol00000000004`0/`0S04`0/`03o`000?lc0<co<`3<017o<`3<
1Oooool1o`00007ooooo00000ol0003oooooooooo`02oooooaT0o`0000?o00000>H06@3V01T09@3V
01T00ol00000c00c0<`0<`0N0<`0<`03o`00002c04`0/`1<01/0/`1<00?o000009T0IP2I06H06@2I
06H00ol00000O`1o07l0O`0K07l0O`03o`00001V09T0IP2I01d0IP2I00<0000004`0/`1<0;<08P1<
0;<00ol0003o<`3<oc<0c00Boc<0c0Gooooo0Ol00001ooooo`0000?o0000ooooooooool00_oooolH
0?l00003o`00003V01T0iP0I02D0iP0I00?o00000<`0<`3<03<07P3<03<00ol00000/`1<0;<0C00K
0;<0C003o`00002I06H0V@1V01T0V@1V00?o000007l0O`1o07l06`1o07l00ol00000IP2I06H0V@0M
06H0V@030000001<0;<0C02c0280C02c00?o0000oc<0c?lc0<`04olc0<`5ooooo`7o00000Oooool0
0003o`000?oooooooooo00;ooooo5`3o00000ol00000iP0I0>H06@0U0>H06@03o`00003<03<0c00c
01h0c00c00?o00000;<0C02c04`06`2c04`00ol00000V@1V09T0IP0I09T0IP03o`00001o07l0O`1o
01/0O`1o00?o000006H0V@1V09T07@1V09T00`000000C02c04`0/`0R04`0/`03o`000?lc0<co<`3<
01Co<`3<1Oooool1o`00007ooooo00000ol0003oooooooooo`02oooooaH0o`0000?o00000>H06@3V
01T09@3V01T00ol00000c00c0<`0<`0N0<`0<`03o`00002c04`0/`1<01/0/`1<00?o000009T0IP2I
06H06@2I06H00ol00000O`1o07l0O`0K07l0O`03o`00001V09T0IP2I01d0IP2I00<0000004`0/`1<
0;<08P1<0;<00ol0003o<`3<oc<0c00Eoc<0c0Gooooo0Ol00001ooooo`0000?o0000ooooooooool0
0_oooolE0?l00003o`00003V01T0iP0I02D0iP0I00?o00000<`0<`3<03<07P3<03<00ol00000/`1<
0;<0C00K0;<0C003o`00002I06H0V@1V01T0V@1V00?o000007l0O`1o07l06`1o07l00ol00000IP2I
06H0V@0M06H0V@030000001<0;<0C02c0280C02c00?o0000oc<0c?lc0<`05_lc0<`5ooooo`7o0000
0Oooool00003o`000?oooooooooo00;ooooo503o00000ol00000iP0I0>H06@0U0>H06@03o`00003<
03<0c00c01h0c00c00?o00000;<0C02c04`06`2c04`00ol00000V@1V09T0IP0I09T0IP03o`00001o
07l0O`1o01/0O`1o00?o000006H0V@1V09T07@1V09T00`000000C02c04`0/`0R04`0/`03o`000?lc
0<co<`3<01Oo<`3<1Oooool1o`00007ooooo00000ol0003oooooooooo`02oooooa<0o`0000?o0000
0>H06@3V01T09@3V01T00ol00000c00c0<`0<`0N0<`0<`03o`00002c04`0/`1<01/0/`1<00?o0000
09T0IP2I06H06@2I06H00ol00000O`1o07l0O`0K07l0O`03o`00001V09T0IP2I01d0IP2I00<00000
04`0/`1<0;<08P1<0;<00ol0003o<`3<oc<0c00Hoc<0c0Gooooo0Ol00001ooooo`0000?o0000oooo
ooooool00_oooolB0?l00003o`00003V01T0iP0I02D0iP0I00?o00000<`0<`3<03<07P3<03<00ol0
0000/`1<0;<0C00K0;<0C003o`00002I06H0V@1V01T0V@1V00?o000007l0O`1o07l06`1o07l00ol0
0000IP2I06H0V@0M06H0V@030000001<0;<0C02c0280C02c00?o0000oc<0c?lc0<`06Olc0<`5oooo
o`7o00000Oooool00003o`000?oooooooooo00;ooooo4@3o00000ol00000iP0I0>H06@0U0>H06@03
o`00003<03<0c00c01h0c00c00?o00000;<0C02c04`06`2c04`00ol00000V@1V09T0IP0I09T0IP03
o`00001o07l0O`1o01/0O`1o00?o000006H0V@1V09T07@1V09T00`000000C02c04`0/`0R04`0/`03
o`000?lc0<co<`3<01[o<`3<1Oooool1o`00007ooooo00000ol0003oooooooooo`02oooooa00o`00
00?o00000>H06@3V01T09@3V01T00ol00000c00c0<`0<`0N0<`0<`03o`00002c04`0/`1<01/0/`1<
00?o000009T0IP2I06H06@2I06H00ol00000O`1o07l0O`0K07l0O`03o`00001V09T0IP2I01d0IP2I
00<0000004`0/`1<0;<08P1<0;<00ol0003o<`3<oc<0c00Koc<0c0Gooooo0Ol00001ooooo`0000?o
0000ooooooooool00_ooool?0?l00003o`00003V01T0iP0I02D0iP0I00?o00000<`0<`3<03<07P3<
03<00ol00000/`1<0;<0C00K0;<0C003o`00002I06H0V@1V01T0V@1V00?o000007l0O`1o07l06`1o
07l00ol00000IP2I06H0V@0M06H0V@030000001<0;<0C02c0280C02c00?o0000oc<0c?lc0<`07?lc
0<`5ooooo`7o00000Oooool00003o`000?oooooooooo00;ooooo3`3o00000ol00000iP0I0>H06@0T
0>H06@03o`00003<03<0c00c01h0c00c00?o00000;<0C02c04`06`2c04`00ol00000V@1V09T0IP0J
09T0IP03o`00001o07l0O`1o01X0O`1o00?o000006H0V@1V09T07@1V09T00ol00000C02c04`0/`0R
04`0/`03o`000?lc0<co<`3<01go<`3<1Oooool1o`00007ooooo00000ol0003oooooooooo`02oooo
o`h0o`0000?o00000>H06@3V01T0903V01T00ol00000c00c0<`0<`0N0<`0<`03o`00002c04`0/`1<
01/0/`1<00?o000009T0IP2I06H06P2I06H00ol00000O`1o07l0O`0J07l0O`03o`00001V09T0IP2I
01d0IP2I00<0000004`0/`1<0;<08P1<0;<00ol0003o<`3<oc<0c00Noc<0c0Gooooo0Ol00001oooo
o`0000?o0000ooooooooool00_ooool=0?l00003o`00003V01T0iP0I02@0iP0I00?o00000<`0<`3<
03<07P3<03<00ol00000/`1<0;<0C00K0;<0C003o`00002I06H0V@1V01X0V@1V00?o000007l0O`1o
07l06P1o07l00ol00000IP2I06H0V@0M06H0V@030000001<0;<0C02c0280C02c00?o0000oc<0c?lc
0<`07olc0<`5ooooo`7o00000Oooool00003o`000?oooooooooo00;ooooo303o00000ol00000iP0I
0>H06@0T0>H06@03o`00003<03<0c00c01h0c00c00?o00000;<0C02c04`06`2c04`00ol00000V@1V
09T0IP0J09T0IP03o`00001o07l0O`1o01X0O`1o00?o000006H0V@1V09T07@1V09T00`000000C02c
04`0/`0R04`0/`03o`000?lc0<co<`3<023o<`3<1Oooool1o`00007ooooo00000ol0003ooooooooo
o`02ooooo`/0o`0000?o00000>H06@3V01T0903V01T00ol00000c00c0<`0<`0N0<`0<`03o`00002c
04`0/`1<01/0/`1<00?o000009T0IP2I06H06P2I06H00ol00000O`1o07l0O`0K07l0O`03o`00001V
09T0IP2I01`0IP2I00<0000004`0/`1<0;<08`1<0;<00ol0003o<`3<oc<0c00Poc<0c0Gooooo0Ol0
0001ooooo`0000?o0000ooooooooool00_ooool:0?l00003o`00003V01T0iP0I02@0iP0I00?o0000
0<`0<`3<03<07P3<03<00ol00000/`1<0;<0C00K0;<0C003o`00002I06H0V@1V01X0V@1V00?o0000
07l0O`1o07l06`1o07l00ol00000IP2I06H0V@0L06H0V@030000001<0;<0C02c02<0C02c00?o0000
oc<0c?lc0<`08Olc0<`5ooooo`7o00000Oooool00003o`000?oooooooooo00;ooooo2@3o00000ol0
0000iP0I0>H06@0T0>H06@03o`00003<03<0c00c01h0c00c00?o00000;<0C02c04`06`2c04`00ol0
0000V@1V09T0IP0J09T0IP03o`00001o07l0O`1o01/0O`1o00?o000006H0V@1V09T0701V09T00`00
0000C02c04`0/`0S04`0/`03o`000?lc0<co<`3<02;o<`3<1Oooool1o`00007ooooo00000ol0003o
ooooooooo`02ooooo`P0o`0000?o00000>H06@3V01T0903V01T00ol00000c00c0<`0<`0N0<`0<`03
o`00002c04`0/`1<01/0/`1<00?o000009T0IP2I06H06P2I06H00ol00000O`1o07l0O`0K07l0O`03
o`00001V09T0IP2I01`0IP2I00<0000004`0/`1<0;<08`1<0;<00ol0003o<`3<oc<0c00Soc<0c0Go
oooo0Ol00001ooooo`0000?o0000ooooooooool00_ooool70?l00003o`00003V01T0iP0I02@0iP0I
00?o00000<`0<`3<03<07P3<03<00ol00000/`1<0;<0C00K0;<0C003o`00002I06H0V@1V01X0V@1V
00?o000007l0O`1o07l06`1o07l00ol00000IP2I06H0V@0L06H0V@030000001<0;<0C02c02<0C02c
00?o0000oc<0c?lc0<`09?lc0<`5ooooo`7o00000Oooool00003o`000?oooooooooo00;ooooo1P3o
00000ol00000iP0I0>H06@0U0>H06@03o`00003<03<0c00c01d0c00c00?o00000;<0C02c04`06`2c
04`00ol00000V@1V09T0IP0J09T0IP03o`00001o07l0O`1o01/0O`1o00?o000006H0V@1V09T0701V
09T00`000000C02c04`0/`0S04`0/`03o`000?lc0<co<`3<02Go<`3<1Oooool1o`00007ooooo0000
0ol0003oooooooooo`02ooooo`D0o`0000?o00000>H06@3V01T09@3V01T00ol00000c00c0<`0<`0M
0<`0<`03o`00002c04`0/`1<01/0/`1<00?o000009T0IP2I06H06P2I06H00ol00000O`1o07l0O`0K
07l0O`03o`00001V09T0IP2I01`0IP2I00<0000004`0/`1<0;<08`1<0;<00ol0003o<`3<oc<0c00V
oc<0c0Gooooo0Ol00001ooooo`0000?o0000ooooooooool00_ooool40?l00003o`00003V01T0iP0I
02D0iP0I00?o00000<`0<`3<03<07@3<03<00ol00000/`1<0;<0C00K0;<0C003o`00002I06H0V@1V
01X0V@1V00?o000007l0O`1o07l06P1o07l2o`0001h0IP2I00<0000004`0/`1<0;<08P1<0;<2o`00
02Wo<`3<1Oooool1o`00007ooooo00000ol0003oooooooooo`02ooooo`<0o`0000?o00000>H06@3V
01T09@3V01T00ol00000c00c0<`0<`0M0<`0<`03o`00002c04`0/`1<01`0/`1<00?o000009T0IP2I
06H06P2I06H00ol00000O`1o07l0O`0I07l0O`03o`00001V09T0IP2I01d0IP2I00?o000004`0/`1<
0;<08P1<0;<00ol0003o<`3<oc<0c00Yoc<0c0Gooooo0Ol00001ooooo`0000?o0000ooooooooool0
0_ooool20?l00003o`00003V01T0iP0I02D0iP0I00?o00000<`0<`3<03<07@3<03<00ol00000/`1<
0;<0C00L0;<0C003o`00002I06H0V@1V01X0V@1V00?o000007l0O`1o07l06@1o07l00ol00000IP2I
06H0V@0M06H0V@030000001<0;<0C02c0280C02c00?o0000oc<0c?lc0<`0:_lc0<`5ooooo`7o0000
0Oooool00003o`000?oooooooooo00;ooooo00<0o`00o`00003V01T09P3V01T00ol00000c00c0<`0
<`0M0<`0<`03o`00002c04`0/`1<01/0/`1<0_l0000L09T0IP03o`00001o07l0O`1o01T0O`1o00?o
000006H0V@1V09T07@1V09T00`000000C02c04`0/`0R04`0/`03o`000?lc0<co<`3<02_o<`3<1Ooo
ool1o`00007ooooo00000ol0003oooooooooo`02ooooo`03o`00003V01T0iP0I02D0iP0I00?o0000
0<`0<`3<03<07@3<03<00ol00000/`1<0;<0C00K0;<0C003o`00002I06H0V@1V01/0V@1V00?o0000
07l0O`1o07l06P1o07l00ol00000IP2I06H0V@0L06H0V@030000001<0;<0C02c0280C02c00?o0000
oc<0c?lc0<`0;?lc0<`5ooooo`7o00000Oooool00003o`000?oooooooooo00;ooooo9`3V01T00ol0
0000c00c0<`0<`0M0<`0<`03o`00002c04`0/`1<01/0/`1<00?o000009T0IP2I06H06`2I06H00ol0
0000O`1o07l0O`0J07l0O`03o`00001V09T0IP2I01`0IP2I00<0000004`0/`1<0;<08P1<0;<00ol0
003o<`3<oc<0c00]oc<0c0Gooooo0Ol00001ooooo`0000?o0000ooooooooool00_oooolV0>H06@03
o`00003<03<0c00c01d0c00c00?o00000;<0C02c04`06`2c04`00ol00000V@1V09T0IP0K09T0IP03
o`00001o07l0O`1o01X0O`1o00?o000006H0V@1V09T0701V09T00`000000C02c04`0/`0R04`0/`03
o`000?lc0<co<`3<02ko<`3<00?o0000ooooooooool00_ooool1o`00007ooooo00000ol0003ooooo
ooooo`02ooooobD0iP0I00?o00000<`0<`3<03<07@3<03<00ol00000/`1<0;<0C00K0;<0C003o`00
002I06H0V@1V01/0V@1V00?o000007l0O`1o07l06P1o07l00ol00000IP2I06H0V@0L06H0V@030000
001<0;<0C02c0280C02c00?o0000oc<0c?lc0<`0;_lc0<`00ol0003oooooooooo`03ooooo`7o0000
0Oooool00003o`000?oooooooooo00;ooooo903V01T00ol00000c00c0<`0<`0M0<`0<`03o`00002c
04`0/`1<01/0/`1<00?o000009T0IP2I06H06`2I06H00ol00000O`1o07l0O`0J07l0O`03o`00001V
09T0IP2I01`0IP2I00<0000004`0/`1<0;<08P1<0;<00ol0003o<`3<oc<0c00^oc<0c003o`00000I
0>Kooooo00Cooooo0Ol00001ooooo`0000?o0000ooooooooool00_oooolR0>H06@;o00007`3<03<0
0ol00000/`1<0;<0C00K0;<0C003o`00002I06H0V@1V01X0V@1V0_l0000L07l0O`03o`00001V09T0
IP2I01`0IP2I00<0000004`0/`1<0;<08P1<0;<00ol0003o<`3<oc<0c00^oc<0c003o`00000I0>H0
6@3V00Gooooo0Ol00001ooooo`0000?o0000ooooooooool00_oooolQ0>H06@03o`00003<03<0c00c
01h0c00c00?o00000;<0C02c04`06`2c04`00ol00000V@1V09T0IP0J09T0IP03o`00001o07l0O`1o
01/0O`1o00?o000006H0V@1V09T0701V09T00`000000C02c04`0/`0R04`0/`03o`000?lc0<co<`3<
02ko<`3<00Co000001T0iP0I0>H06@3V1Oooool1o`00007ooooo00000ol0003oooooooooo`02oooo
ob00iP0I00?o00000<`0<`3<03<07P3<03<00ol00000/`1<0;<0C00K0;<0C003o`00002I06H0V@1V
01X0V@1V00?o000007l0O`1o07l06P1o07l2o`0001h0IP2I00<0000004`0/`1<0;<08P1<0;<00ol0
003o<`3<oc<0c00^oc<0c003o`00000I0>H06@3V00806@3V1Oooool1o`00007ooooo00000ol0003o
ooooooooo`02ooooob00iP0I00?o00000<`0<`3<03<07P3<03<00ol00000/`1<0;<0C00J0;<0C003
o`00002I06H0V@1V01X0V@1V00?o000007l0O`1o07l06P1o07l00ol00000IP2I06H0V@0N06H0V@03
0000001<0;<0C02c0240C02c00?o0000oc<0c?lc0<`0;_lc0<`00ol000006@3V01T0iP0301T0iPGo
oooo0Ol00001ooooo`0000?o0000ooooooooool00_oooolO0>H06@03o`00003<03<0c00c01h0c00c
00?o00000;<0C02c04`06P2c04`00ol00000V@1V09T0IP0J09T0IP03o`00001o07l0O`1o01X0O`1o
00?o000006H0V@1V09T07P1V09T00`000000C02c04`0/`0Q04`0/`03o`000?lc0<co<`3<02ko<`3<
00?o000001T0iP0I0>H0100I0>H5ooooo`7o00000Oooool00003o`000?oooooooooo00;ooooo7P3V
01T00ol00000c00c0<`0<`0N0<`0<`03o`00002c04`0/`1<01X0/`1<00?o000009T0IP2I06H06P2I
06H00ol00000O`1o07l0O`0J07l0O`03o`00001V09T0IP2I01h0IP2I00<0000004`0/`1<0;<08@1<
0;<00ol0003o<`3<oc<0c00^oc<0c003o`00000I0>H06@3V00D06@3V1Oooool1o`00007ooooo0000
0ol0003oooooooooo`02oooooad0iP0I00?o00000<`0<`3<03<07P3<03<00ol00000/`1<0;<0C00K
0;<0C003o`00002I06H0V@1V01T0V@1V00?o000007l0O`1o07l06P1o07l00ol00000IP2I06H0V@0N
06H0V@030000001<0;<0C02c0240C02c00?o0000oc<0c?lc0<`0;_lc0<`00ol000006@3V01T0iP06
01T0iPGooooo0Ol00001ooooo`0000?o0000ooooooooool00_oooolL0>H06@03o`00003<03<0c00c
01h0c00c00?o00000;<0C02c04`06`2c04`00ol00000V@1V09T0IP0I09T0IP03o`00001o07l0O`1o
01/0O`1o00?o000006H0V@1V09T07@1V09T00`000000C02c04`0/`0R04`0/`03o`000?lc0<co<`3<
02go<`3<00?o000001T0iP0I0>H01`0I0>H5ooooo`7o00000Oooool00003o`000?oooooooooo00;o
oooo6`3V01T00ol00000c00c0<`0<`0N0<`0<`03o`00002c04`0/`1<01/0/`1<00?o000009T0IP2I
06H06@2I06H00ol00000O`1o07l0O`0K07l0O`03o`00001V09T0IP2I01d0IP2I00<0000004`0/`1<
0;<08P1<0;<00ol0003o<`3<oc<0c00]oc<0c003o`00000I0>H06@3V00P06@3V1Oooool1o`00007o
oooo00000ol0003oooooooooo`02oooooaX0iP0I00?o00000<`0<`3<03<07P3<03<00ol00000/`1<
0;<0C00K0;<0C003o`00002I06H0V@1V01T0V@1V00?o000007l0O`1o07l06`1o07l00ol00000IP2I
06H0V@0M06H0V@030000001<0;<0C02c0280C02c00?o0000oc<0c?lc0<`0;Olc0<`00ol000006@3V
01T0iP0901T0iPGooooo0Ol00001ooooo`0000?o0000ooooooooool00_oooolI0>H06@03o`00003<
03<0c00c01h0c00c00?o00000;<0C02c04`06`2c04`00ol00000V@1V09T0IP0I09T0IP03o`00001o
07l0O`1o01/0O`1o00?o000006H0V@1V09T07@1V09T00`000000C02c04`0/`0R04`0/`03o`000?lc
0<co<`3<02ko<`3<00?o000001T0iP0I0>H02@0I0>H5ooooo`7o00000Oooool00003o`000?oooooo
oooo00;ooooo603V01T00ol00000c00c0<`0<`0N0<`0<`03o`00002c04`0/`1<01/0/`1<00?o0000
09T0IP2I06H06@2I06H00ol00000O`1o07l0O`0K07l0O`03o`00001V09T0IP2I01d0IP2I00<00000
04`0/`1<0;<08P1<0;<00ol0003o<`3<oc<0c00^oc<0c003o`00000I0>H06@3V00X06@3V1Oooool1
o`00007ooooo00000ol0003oooooooooo`02oooooaL0iP0I00?o00000<`0<`3<03<07P3<03<00ol0
0000/`1<0;<0C00K0;<0C003o`00002I06H0V@1V01X0V@1V00?o000007l0O`1o07l06P1o07l00ol0
0000IP2I06H0V@0M06H0V@030000001<0;<0C02c0280C02c00?o0000oc<0c?lc0<`0;_lc0<`00ol0
00006@3V01T0iP0;01T0iPGooooo0Ol00001ooooo`0000?o0000ooooooooool00_oooolF0>H06@03
o`00003<03<0c00c01h0c00c00?o00000;<0C02c04`06`2c04`00ol00000V@1V09T0IP0J09T0IP03
o`00001o07l0O`1o01X0O`1o00?o000006H0V@1V09T07@1V09T00`000000C02c04`0/`0R04`0/`03
o`000?lc0<co<`3<02ko<`3<00?o000001T0iP0I0>H0300I0>H5ooooo`7o00000Oooool00003o`00
0?oooooooooo00;ooooo5@3V01T00ol00000c00c0<`0<`0N0<`0<`03o`00002c04`0/`1<01/0/`1<
00?o000009T0IP2I06H06P2I06H00ol00000O`1o07l0O`0J07l0O`03o`00001V09T0IP2I01`0IP2I
0P00000T04`0/`03o`000?lc0<co<`3<02ko<`3<00?o000001T0iP0I0>H03@0I0>H5ooooo`7o0000
0Oooool00003o`000?oooooooooo00;ooooo5@3V01T00ol00000c00c0<`0<`0M0<`0<`03o`00002c
04`0/`1<01/0/`1<00?o000009T0IP2I06H06P2I06H00ol00000O`1o07l0O`0J07l0O`03o`00001V
09T0IP2I01`0IP2I00<0000004`0/`1<0;<08`1<0;<00ol0003o<`3<oc<0c00^oc<0c003o`00000I
0>H06@3V00h06@3V1Oooool1o`00007ooooo00000ol0003oooooooooo`02oooooa@0iP0I00?o0000
0<`0<`3<03<07@3<03<00ol00000/`1<0;<0C00K0;<0C003o`00002I06H0V@1V01X0V@1V00?o0000
07l0O`1o07l06P1o07l00ol00000IP2I06H0V@0M06H0V@030000001<0;<0C02c0280C02c00?o0000
oc<0c?lc0<`0;_lc0<`00ol000006@3V01T0iP0?01T0iPGooooo0Ol00001ooooo`0000?o0000oooo
ooooool00_oooolC0>H06@03o`00003<03<0c00c01d0c00c00?o00000;<0C02c04`06`2c04`00ol0
0000V@1V09T0IP0J09T0IP03o`00001o07l0O`1o01X0O`1o00?o000006H0V@1V09T07@1V09T00`00
0000C02c04`0/`0R04`0/`03o`000?lc0<co<`3<02ko<`3<00?o000001T0iP0I0>H0400I0>H5oooo
o`7o00000Oooool00003o`000?oooooooooo00;ooooo4P3V01T00ol00000c00c0<`0<`0M0<`0<`03
o`00002c04`0/`1<01/0/`1<00?o000009T0IP2I06H06P2I06H00ol00000O`1o07l0O`0J07l0O`03
o`00001V09T0IP2I01d0IP2I00<0000004`0/`1<0;<08P1<0;<00ol0003o<`3<oc<0c00^oc<0c003
o`00000I0>H06@3V01406@3V1Oooool1o`00007ooooo00000ol0003oooooooooo`02oooooa40iP0I
00?o00000<`0<`3<03<07@3<03<00ol00000/`1<0;<0C00K0;<0C003o`00002I06H0V@1V01X0V@1V
00?o000007l0O`1o07l06P1o07l00ol00000IP2I06H0V@0M06H0V@030000001<0;<0C02c0280C02c
00?o0000oc<0c?lc0<`0;_lc0<`00ol000006@3V01T0iP0B01T0iPGooooo0Ol00001ooooo`0000?o
0000ooooooooool00_ooool@0>H06@03o`00003<03<0c00c01d0c00c00?o00000;<0C02c04`06`2c
04`00ol00000V@1V09T0IP0J09T0IP03o`00001o07l0O`1o01X0O`1o00?o000006H0V@1V09T07@1V
09T00`000000C02c04`0/`0R04`0/`03o`000?lc0<co<`3<02ko<`3<00?o000001T0iP0I0>H04`0I
0>H5ooooo`7o00000Oooool00003o`000?oooooooooo00;ooooo3`3V01T00ol00000c00c0<`0<`0M
0<`0<`03o`00002c04`0/`1<01/0/`1<00?o000009T0IP2I06H06P2I06H00ol00000O`1o07l0O`0J
07l0O`03o`00001V09T0IP2I01d0IP2I00<0000004`0/`1<0;<08P1<0;<00ol0003o<`3<oc<0c00^
oc<0c003o`00000I0>H06@3V01@06@3V1Oooool1o`00007ooooo00000ol0003oooooooooo`02oooo
o`h0iP0I00?o00000<`0<`3<03<07@3<03<00ol00000/`1<0;<0C00K0;<0C003o`00002I06H0V@1V
01X0V@1V00?o000007l0O`1o07l06P1o07l00ol00000IP2I06H0V@0M06H0V@030000001<0;<0C02c
0280C02c00?o0000oc<0c?lc0<`0;_lc0<`00ol000006@3V01T0iP0E01T0iPGooooo0Ol00001oooo
o`0000?o0000ooooooooool00_ooool=0>H06@03o`00003<03<0c00c01d0c00c00?o00000;<0C02c
04`06`2c04`00ol00000V@1V09T0IP0J09T0IP03o`00001o07l0O`1o01X0O`1o00?o000006H0V@1V
09T07@1V09T00`000000C02c04`0/`0R04`0/`03o`000?lc0<co<`3<02ko<`3<00?o000001T0iP0I
0>H05P0I0>H5ooooo`7o00000Oooool00003o`000?oooooooooo00;ooooo2`3V01T2o`0001l0c00c
00?o00000;<0C02c04`06`2c04`00ol00000V@1V09T0IP0J09T0IP03o`00001o07l0O`1o01X0O`1o
00?o000006H0V@1V09T07@1V09T00`000000C02c04`0/`0R04`0/`03o`000?lc0<co<`3<02ko<`3<
00?o000001T0iP0I0>H05`0I0>H5ooooo`7o00000Oooool00003o`000?oooooooooo00;ooooo2P3V
01T00ol00000c00c0<`0<`0N0<`0<`03o`00002c04`0/`1<01/0/`1<00?o000009T0IP2I06H06P2I
06H00ol00000O`1o07l0O`0J07l0O`03o`00001V09T0IP2I01d0IP2I00<0000004`0/`1<0;<08P1<
0;<00ol0003o<`3<oc<0c00^oc<0c003o`00000I0>H06@3V01P06@3V1Oooool1o`00007ooooo0000
0ol0003oooooooooo`02ooooo`T0iP0I00?o00000<`0<`3<03<07`3<03<00ol00000/`1<0;<0C00J
0;<0C003o`00002I06H0V@1V01X0V@1V00?o000007l0O`1o07l06`1o07l00ol00000IP2I06H0V@0L
06H0V@030000001<0;<0C02c0280C02c00?o0000oc<0c?lc0<`0;_lc0<`00ol000006@3V01T0iP0I
01T0iPGooooo0Ol00001ooooo`0000?o0000ooooooooool00_ooool80>H06@03o`00003<03<0c00c
01l0c00c00?o00000;<0C02c04`06P2c04`00ol00000V@1V09T0IP0J09T0IP03o`00001o07l0O`1o
01/0O`1o00?o000006H0V@1V09T0701V09T00`000000C02c04`0/`0R04`0/`03o`000?lc0<co<`3<
02ko<`3<00?o000001T0iP0I0>H06P0I0>H5ooooo`7o00000Oooool00003o`000?oooooooooo00;o
oooo1`3V01T00ol00000c00c0<`0<`0O0<`0<`03o`00002c04`0/`1<01X0/`1<00?o000009T0IP2I
06H06P2I06H00ol00000O`1o07l0O`0K07l0O`03o`00001V09T0IP2I01d0IP2I00<0000004`0/`1<
0;<08@1<0;<00ol0003o<`3<oc<0c00^oc<0c003o`00000I0>H06@3V01/06@3V1Oooool1o`00007o
oooo00000ol0003oooooooooo`02ooooo`H0iP0I00?o00000<`0<`3<03<07`3<03<00ol00000/`1<
0;<0C00J0;<0C003o`00002I06H0V@1V01X0V@1V00?o000007l0O`1o07l06`1o07l00ol00000IP2I
06H0V@0M06H0V@030000001<0;<0C02c0240C02c00?o0000oc<0c?lc0<`0;_lc0<`00ol000006@3V
01T0iP0L01T0iPGooooo0Ol00001ooooo`0000?o0000ooooooooool00_ooool50>H06@03o`00003<
03<0c00c01l0c00c00?o00000;<0C02c04`06`2c04`00ol00000V@1V09T0IP0I09T0IP03o`00001o
07l0O`1o01/0O`1o00?o000006H0V@1V09T07@1V09T00`000000C02c04`0/`0Q04`0/`03o`000?lc
0<co<`3<02ko<`3<00?o000001T0iP0I0>H07@0I0>H5ooooo`7o00000Oooool00003o`000?oooooo
oooo00;ooooo103V01T00ol00000c00c0<`0<`0O0<`0<`03o`00002c04`0/`1<01/0/`1<00?o0000
09T0IP2I06H06@2I06H00ol00000O`1o07l0O`0K07l0O`03o`00001V09T0IP2I01d0IP2I00<00000
04`0/`1<0;<08P1<0;<00ol0003o<`3<oc<0c00]oc<0c003o`00000I0>H06@3V01h06@3V1Oooool1
o`00007ooooo00000ol0003oooooooooo`02ooooo`<0iP0I00?o00000<`0<`3<03<07`3<03<00ol0
0000/`1<0;<0C00K0;<0C003o`00002I06H0V@1V01T0V@1V00?o000007l0O`1o07l06`1o07l00ol0
0000IP2I06H0V@0M06H0V@030000001<0;<0C02c0280C02c00?o0000oc<0c?lc0<`0;Olc0<`00ol0
00006@3V01T0iP0O01T0iPGooooo0Ol00001ooooo`0000?o0000ooooooooool00_ooool20>H06@03
o`00003<03<0c00c01l0c00c00?o00000;<0C02c04`06`2c04`00ol00000V@1V09T0IP0I09T0IP03
o`00001o07l0O`1o01/0O`1o00?o000006H0V@1V09T07@1V09T00`000000C02c04`0/`0R04`0/`03
o`000?lc0<co<`3<02go<`3<00?o000001T0iP0I0>H0800I0>H5ooooo`7o00000Oooool00003o`00
0?oooooooooo00;ooooo00<0iP0Io`00003<03<0803<03<00ol00000/`1<0;<0C00K0;<0C003o`00
002I06H0V@1V01T0V@1V00?o000007l0O`1o07l06`1o07l00ol00000IP2I06H0V@0M06H0V@030000
001<0;<0C02c0280C02c00?o0000oc<0c?lc0<`0;_lc0<`00ol000006@3V01T0iP0P01T0iPGooooo
0Ol00001ooooo`0000?o0000ooooooooool00_ooool00ol00000c00c0<`0<`0O0<`0<`03o`00002c
04`0/`1<01/0/`1<00?o000009T0IP2I06H06@2I06H00ol00000O`1o07l0O`0K07l0O`03o`00001V
09T0IP2I01d0IP2I00<0000004`0/`1<0;<08P1<0;<00ol0003o<`3<oc<0c00^oc<0c003o`00000I
0>H06@3V02406@3V1Oooool1o`00007ooooo00000ol0003oooooooooo`02ooooob40c00c00?o0000
0;<0C02c04`06`2c04`00ol00000V@1V09T0IP0J09T0IP03o`00001o07l0O`1o01X0O`1o00?o0000
06H0V@1V09T07@1V09T00`000000C02c04`0/`0R04`0/`03o`000?lc0<co<`3<02ko<`3<00?o0000
01T0iP0I0>H08P0I0>H5ooooo`7o00000Oooool00003o`000?oooooooooo00;ooooo803<03<00ol0
0000/`1<0;<0C00K0;<0C003o`00002I06H0V@1V01X0V@1V00?o000007l0O`1o07l06P1o07l00ol0
0000IP2I06H0V@0L06H0V@800000901<0;<00ol0003o<`3<oc<0c00^oc<0c003o`00000I0>H06@3V
02<06@3V1Oooool1o`00007ooooo00000ol0003oooooooooo`02oooooal0c00c00?o00000;<0C02c
04`06`2c04`00ol00000V@1V09T0IP0J09T0IP03o`00001o07l0O`1o01X0O`1o00?o000006H0V@1V
09T0701V09T00`000000C02c04`0/`0S04`0/`03o`000?lc0<co<`3<02ko<`3<00?o000001T0iP0I
0>H0900I0>H5ooooo`7o00000Oooool00003o`000?oooooooooo00;ooooo7P3<03<00ol00000/`1<
0;<0C00K0;<0C003o`00002I06H0V@1V01X0V@1V00?o000007l0O`1o07l06P1o07l00ol00000IP2I
06H0V@0L06H0V@030000001<0;<0C02c02<0C02c00?o0000oc<0c?lc0<`0;_lc0<`00ol000006@3V
01T0iP0U01T0iPGooooo0Ol00001ooooo`0000?o0000ooooooooool00_oooolM0<`0<`03o`00002c
04`0/`1<01/0/`1<00?o000009T0IP2I06H06P2I06H00ol00000O`1o07l0O`0J07l0O`03o`00001V
09T0IP2I01d0IP2I00<0000004`0/`1<0;<08P1<0;<00ol0003o<`3<oc<0c00^oc<0c003o`00000I
0>H06@3V02H06@3V1Oooool1o`00007ooooo00000ol0003oooooooooo`02oooooa`0c00c00?o0000
0;<0C02c04`06`2c04`00ol00000V@1V09T0IP0J09T0IP03o`00001o07l0O`1o01X0O`1o00?o0000
06H0V@1V09T07@1V09T00`000000C02c04`0/`0R04`0/`03o`000?lc0<co<`3<02ko<`3<00?o0000
01T0iP0I0>H09`0I0>H5ooooo`7o00000Oooool00003o`000?oooooooooo00;ooooo6`3<03<00ol0
0000/`1<0;<0C00K0;<0C003o`00002I06H0V@1V01X0V@1V00?o000007l0O`1o07l06P1o07l00ol0
0000IP2I06H0V@0M06H0V@030000001<0;<0C02c0280C02c00?o0000oc<0c?lc0<`0;_lc0<`00ol0
00006@3V01T0iP0X01T0iPGooooo0Ol00001ooooo`0000?o0000ooooooooool00_oooolJ0<`0<`03
o`00002c04`0/`1<01/0/`1<00?o000009T0IP2I06H06P2I06H00ol00000O`1o07l0O`0J07l0O`03
o`00001V09T0IP2I01d0IP2I00<0000004`0/`1<0;<08P1<0;<00ol0003o<`3<oc<0c00^oc<0c003
o`00000I0>H06@3V02T06@3V1Oooool1o`00007ooooo00000ol0003oooooooooo`02oooooaT0c00c
00?o00000;<0C02c04`06`2c04`00ol00000V@1V09T0IP0J09T0IP03o`00001o07l0O`1o01X0O`1o
00?o000006H0V@1V09T07@1V09T00`000000C02c04`0/`0R04`0/`03o`000?lc0<co<`3<02ko<`3<
00?o000001T0iP0I0>H0:P0I0>H5ooooo`7o00000Oooool00003o`000?oooooooooo00;ooooo603<
03<00ol00000/`1<0;<0C00K0;<0C003o`00002I06H0V@1V01X0V@1V00?o000007l0O`1o07l06P1o
07l00ol00000IP2I06H0V@0M06H0V@030000001<0;<0C02c0280C02c00?o0000oc<0c?lc0<`0;_lc
0<`00ol000006@3V01T0iP0[01T0iPGooooo0Ol00001ooooo`0000?o0000ooooooooool00_oooolG
0<`0<`03o`00002c04`0/`1<01/0/`1<00?o000009T0IP2I06H06P2I06H00ol00000O`1o07l0O`0J
07l0O`03o`00001V09T0IP2I01d0IP2I00<0000004`0/`1<0;<08P1<0;<00ol0003o<`3<oc<0c00^
oc<0c003o`00000I0>H06@3V02`06@3V1Oooool1o`00007ooooo00000ol0003oooooooooo`02oooo
oaH0c00c00?o00000;<0C02c04`06`2c04`00ol00000V@1V09T0IP0I09T0IP;o0000701o07l00ol0
0000IP2I06H0V@0M06H0V@030000001<0;<0C02c0280C02c00?o0000oc<0c?lc0<`0;_lc0<`00ol0
00006@3V01T0iP0]01T0iPGooooo0Ol00001ooooo`0000?o0000ooooooooool00_oooolE0<`0<`03
o`00002c04`0/`1<01/0/`1<00?o000009T0IP2I06H06@2I06H00ol00000O`1o07l0O`0K07l0O`03
o`00001V09T0IP2I01d0IP2I00<0000004`0/`1<0;<08P1<0;<00ol0003o<`3<oc<0c00^oc<0c003
o`00000I0>H06@3V02h06@3V1Oooool1o`00007ooooo00000ol0003oooooooooo`02oooooa@0c00c
00?o00000;<0C02c04`06`2c04`00ol00000V@1V09T0IP0J09T0IP03o`00001o07l0O`1o01/0O`1o
00?o000006H0V@1V09T0701V09T00`000000C02c04`0/`0R04`0/`03o`000?lc0<co<`3<02ko<`3<
00?o000001T0iP0I0>H0;`0I0>H5ooooo`7o00000Oooool00003o`000?oooooooooo00;ooooo4`3<
03<00ol00000/`1<0;<0C00K0;<0C003o`00002I06H0V@1V01X0V@1V00?o000007l0O`1o07l06`1o
07l00ol00000IP2I06H0V@0L06H0V@030000001<0;<0C02c0280C02c00?o0000oc<0c?lc0<`0;_lc
0<`00ol000006@3V01T0iP0`01T0iPGooooo0Ol00001ooooo`0000?o0000ooooooooool00_oooolB
0<`0<`03o`00002c04`0/`1<01/0/`1<00?o000009T0IP2I06H06P2I06H00ol00000O`1o07l0O`0K
07l0O`03o`00001V09T0IP2I01`0IP2I00<0000004`0/`1<0;<08P1<0;<00ol0003o<`3<oc<0c00^
oc<0c003o`00000I0>H06@3V03406@3V1Oooool1o`00007ooooo00000ol0003oooooooooo`02oooo
oa40c00c00?o00000;<0C02c04`06`2c04`00ol00000V@1V09T0IP0J09T0IP03o`00001o07l0O`1o
01/0O`1o00?o000006H0V@1V09T07@1V09T00`000000C02c04`0/`0Q04`0/`03o`000?lc0<co<`3<
02ko<`3<00?o000001T0iP0I0>H0<P0I0>H5ooooo`7o00000Oooool00003o`000?oooooooooo00;o
oooo403<03<00ol00000/`1<0;<0C00K0;<0C003o`00002I06H0V@1V01X0V@1V00?o000007l0O`1o
07l06`1o07l00ol00000IP2I06H0V@0M06H0V@030000001<0;<0C02c0240C02c00?o0000oc<0c?lc
0<`0;_lc0<`00ol000006@3V01T0iP0c01T0iPGooooo0Ol00001ooooo`0000?o0000ooooooooool0
0_ooool?0<`0<`03o`00002c04`0/`1<01`0/`1<00?o000009T0IP2I06H06@2I06H00ol00000O`1o
07l0O`0K07l0O`03o`00001V09T0IP2I01d0IP2I00<0000004`0/`1<0;<08@1<0;<00ol0003o<`3<
oc<0c00^oc<0c003o`00000I0>H06@3V03@06@3V1Oooool1o`00007ooooo00000ol0003ooooooooo
o`02ooooo`h0c00c00?o00000;<0C02c04`0702c04`00ol00000V@1V09T0IP0I09T0IP03o`00001o
07l0O`1o01/0O`1o00?o000006H0V@1V09T07@1V09T00`000000C02c04`0/`0R04`0/`03o`000?lc
0<co<`3<02go<`3<00?o000001T0iP0I0>H0=@0I0>H5ooooo`7o00000Oooool00003o`000?oooooo
oooo00;ooooo3@3<03<00ol00000/`1<0;<0C00L0;<0C003o`00002I06H0V@1V01T0V@1V00?o0000
07l0O`1o07l06`1o07l00ol00000IP2I06H0V@0M06H0V@030000001<0;<0C02c0280C02c00?o0000
oc<0c?lc0<`0;Olc0<`00ol000006@3V01T0iP0f01T0iPGooooo0Ol00001ooooo`0000?o0000oooo
ooooool00_ooool<0<`0<`03o`00002c04`0/`1<01`0/`1<00?o000009T0IP2I06H06@2I06H00ol0
0000O`1o07l0O`0K07l0O`03o`00001V09T0IP2I01d0IP2I00<0000004`0/`1<0;<08P1<0;<00ol0
003o<`3<oc<0c00]oc<0c003o`00000I0>H06@3V03L06@3V1Oooool1o`00007ooooo00000ol0003o
ooooooooo`02ooooo``0c00c00?o00000;<0C02c04`06`2c04`00ol00000V@1V09T0IP0I09T0IP03
o`00001o07l0O`1o01/0O`1o00?o000006H0V@1V09T07@1V09T00`000000C02c04`0/`0R04`0/`03
o`000?lc0<co<`3<02ko<`3<00?o000001T0iP0I0>H0=`0I0>H5ooooo`7o00000Oooool00003o`00
0?oooooooooo00;ooooo2`3<03<00ol00000/`1<0;<0C00K0;<0C003o`00002I06H0V@1V01T0V@1V
00?o000007l0O`1o07l06`1o07l00ol00000IP2I06H0V@0M06H0V@030000001<0;<0C02c0280C02c
00?o0000oc<0c?lc0<`0;_lc0<`00ol000006@3V01T0iP0h01T0iPGooooo0Ol00001ooooo`0000?o
0000ooooooooool00_ooool90<`0<`;o00007@2c04`00ol00000V@1V09T0IP0I09T0IP03o`00001o
07l0O`1o01X0O`1o0_l0000O06H0V@030000001<0;<0C02c0280C02c00?o0000oc<0c?lc0<`0;Olc
0<`2o`0003/06@3V1Oooool1o`00007ooooo00000ol0003oooooooooo`02ooooo`P0c00c00?o0000
0;<0C02c04`0702c04`00ol00000V@1V09T0IP0J09T0IP03o`00001o07l0O`1o01T0O`1o00?o0000
06H0V@1V09T07P1V09T00`000000C02c04`0/`0R04`0/`03o`000?lc0<co<`3<02go<`3<00?o0000
01T0iP0I0>H0>`0I0>H5ooooo`7o00000Oooool00003o`000?oooooooooo00;ooooo1`3<03<00ol0
0000/`1<0;<0C00L0;<0C003o`00002I06H0V@1V01X0V@1V00?o000007l0O`1o07l06@1o07l00ol0
0000IP2I06H0V@0N06H0V@030000001<0;<0C02c0280C02c00?o0000oc<0c?lc0<`0;Olc0<`00ol0
00006@3V01T0iP0l01T0iPGooooo0Ol00001ooooo`0000?o0000ooooooooool00_ooool60<`0<`03
o`00002c04`0/`1<01`0/`1<00?o000009T0IP2I06H06P2I06H00ol00000O`1o07l0O`0I07l0O`03
o`00001V09T0IP2I01h0IP2I00<0000004`0/`1<0;<08P1<0;<00ol0003o<`3<oc<0c00]oc<0c003
o`00000I0>H06@3V03d06@3V1Oooool1o`00007ooooo00000ol0003oooooooooo`02ooooo`D0c00c
00?o00000;<0C02c04`0702c04`00ol00000V@1V09T0IP0J09T0IP03o`00001o07l0O`1o01T0O`1o
00?o000006H0V@1V09T07P1V09T00`000000C02c04`0/`0R04`0/`03o`000?lc0<co<`3<02go<`3<
00?o000001T0iP0I0>H0?P0I0>H5ooooo`7o00000Oooool00003o`000?oooooooooo00;ooooo103<
03<00ol00000/`1<0;<0C00K0;<0C0;o0000702I06H00ol00000O`1o07l0O`0I07l0O`03o`00001V
09T0IP2I01h0IP2I00<0000004`0/`1<0;<08P1<0;<00ol0003o<`3<oc<0c00]oc<0c003o`00000I
0>H06@3V03l06@3V1Oooool1o`00007ooooo00000ol0003oooooooooo`02ooooo`<0c00c00?o0000
0;<0C02c04`06`2c04`00ol00000V@1V09T0IP0K09T0IP03o`00001o07l0O`1o01X0O`1o00?o0000
06H0V@1V09T07@1V09T00`000000C02c04`0/`0R04`0/`03o`000?lc0<co<`3<02go<`3<00?o0000
01T0iP0I0>H0@00I0>H5ooooo`7o00000Oooool00003o`000?oooooooooo00;ooooo0P3<03<00ol0
0000/`1<0;<0C00K0;<0C003o`00002I06H0V@1V01/0V@1V00?o000007l0O`1o07l06P1o07l00ol0
0000IP2I06H0V@0M06H0V@030000001<0;<0C02c0280C02c00?o0000oc<0c?lc0<`0;Olc0<`00ol0
00006@3V01T0iP1101T0iPGooooo0Ol00001ooooo`0000?o0000ooooooooool00_ooool00`3<03?o
00000;<0C00L0;<0C003o`00002I06H0V@1V01/0V@1V00?o000007l0O`1o07l06P1o07l00ol00000
IP2I06H0V@0M06H0V@030000001<0;<0C02c0280C02c00?o0000oc<0c?lc0<`0;Olc0<`00ol00000
6@3V01T0iP1201T0iPGooooo0Ol00001ooooo`0000?o0000ooooooooool00_ooool00ol00000/`1<
0;<0C00K0;<0C003o`00002I06H0V@1V01/0V@1V00?o000007l0O`1o07l06P1o07l00ol00000IP2I
06H0V@0M06H0V@030000001<0;<0C02c0280C02c00?o0000oc<0c?lc0<`0;Olc0<`00ol000006@3V
01T0iP1301T0iPGooooo0Ol00001ooooo`0000?o0000ooooooooool00_oooolM0;<0C003o`00002I
06H0V@1V01/0V@1V00?o000007l0O`1o07l06P1o07l00ol00000IP2I06H0V@0M06H0V@030000001<
0;<0C02c0280C02c00?o0000oc<0c?lc0<`0;Olc0<`00ol000006@3V01T0iP1401T0iPGooooo0Ol0
0001ooooo`0000?o0000ooooooooool00_oooolL0;<0C003o`00002I06H0V@1V01X0V@1V0_l0000L
07l0O`03o`00001V09T0IP2I01d0IP2I00<0000004`0/`1<0;<08@1<0;<2o`0002oo<`3<00?o0000
01T0iP0I0>H0A@0I0>H5ooooo`7o00000Oooool00003o`000?oooooooooo00;ooooo6`2c04`00ol0
0000V@1V09T0IP0J09T0IP03o`00001o07l0O`1o01/0O`1o00?o000006H0V@1V09T07@1V09T00`00
0000C02c04`0/`0Q04`0/`03o`000?lc0<co<`3<02ko<`3<00?o000001T0iP0I0>H0AP0I0>H5oooo
o`7o00000Oooool00003o`000?oooooooooo00;ooooo6P2c04`00ol00000V@1V09T0IP0J09T0IP03
o`00001o07l0O`1o01/0O`1o00?o000006H0V@1V09T07@1V09T00`000000C02c04`0/`0Q04`0/`03
o`000?lc0<co<`3<02ko<`3<00?o000001T0iP0I0>H0A`0I0>H5ooooo`7o00000Oooool00003o`00
0?oooooooooo00;ooooo6@2c04`00ol00000V@1V09T0IP0J09T0IP03o`00001o07l0O`1o01/0O`1o
00?o000006H0V@1V09T07@1V09T00`000000C02c04`0/`0Q04`0/`03o`000?lc0<co<`3<02ko<`3<
00?o000001T0iP0I0>H0B00I0>H5ooooo`7o00000Oooool00003o`000?oooooooooo00;ooooo602c
04`00ol00000V@1V09T0IP0J09T0IP03o`00001o07l0O`1o01/0O`1o00?o000006H0V@1V09T07@1V
09T00`000000C02c04`0/`0Q04`0/`03o`000?lc0<co<`3<02ko<`3<00?o000001T0iP0I0>H0B@0I
0>H5ooooo`7o00000Oooool00003o`000?oooooooooo00;ooooo5`2c04`00ol00000V@1V09T0IP0J
09T0IP03o`00001o07l0O`1o01/0O`1o00?o000006H0V@1V09T07@1V09T00`000000C02c04`0/`0Q
04`0/`03o`000?lc0<co<`3<02ko<`3<00?o000001T0iP0I0>H0BP0I0>H5ooooo`7o00000Oooool0
0003o`000?oooooooooo00;ooooo5`2c04`00ol00000V@1V09T0IP0I09T0IP03o`00001o07l0O`1o
01/0O`1o00?o000006H0V@1V09T07@1V09T00`000000C02c04`0/`0Q04`0/`03o`000?lc0<co<`3<
02ko<`3<00?o000001T0iP0I0>H0B`0I0>H5ooooo`7o00000Oooool00003o`000?oooooooooo00;o
oooo5P2c04`00ol00000V@1V09T0IP0I09T0IP03o`00001o07l0O`1o01`0O`1o00?o000006H0V@1V
09T0701V09T00`000000C02c04`0/`0R04`0/`03o`000?lc0<co<`3<02go<`3<00?o000001T0iP0I
0>H0C00I0>H5ooooo`7o00000Oooool00003o`000?oooooooooo00;ooooo5@2c04`00ol00000V@1V
09T0IP0I09T0IP03o`00001o07l0O`1o01`0O`1o00?o000006H0V@1V09T0701V09T00`000000C02c
04`0/`0R04`0/`03o`000?lc0<co<`3<02go<`3<00?o000001T0iP0I0>H0C@0I0>H5ooooo`7o0000
0Oooool00003o`000?oooooooooo00;ooooo502c04`00ol00000V@1V09T0IP0I09T0IP03o`00001o
07l0O`1o01`0O`1o00?o000006H0V@1V09T0701V09T00`000000C02c04`0/`0R04`0/`03o`000?lc
0<co<`3<02go<`3<00?o000001T0iP0I0>H0CP0I0>H5ooooo`7o00000Oooool00003o`000?oooooo
oooo00;ooooo4`2c04`00ol00000V@1V09T0IP0I09T0IP03o`00001o07l0O`1o01`0O`1o00?o0000
06H0V@1V09T0701V09T00`000000C02c04`0/`0S04`0/`03o`000?lc0<co<`3<02go<`3<00?o0000
01T0iP0I0>H0CP0I0>H5ooooo`7o00000Oooool00003o`000?oooooooooo00;ooooo4P2c04`00ol0
0000V@1V09T0IP0I09T0IP03o`00001o07l0O`1o01`0O`1o00?o000006H0V@1V09T0701V09T00`00
0000C02c04`0/`0S04`0/`03o`000?lc0<co<`3<02go<`3<00?o000001T0iP0I0>H0C`0I0>H5oooo
o`7o00000Oooool00003o`000?oooooooooo00;ooooo4@2c04`00ol00000V@1V09T0IP0J09T0IP03
o`00001o07l0O`1o01X0O`1o0_l0000N06H0V@030000001<0;<0C02c0280C02c0_l0000_oc<0c003
o`00000I0>H06@3V05006@3V00?o0000ooooooooool00_ooool1o`00007ooooo00000ol0003ooooo
ooooo`02oooooa00/`1<00?o000009T0IP2I06H06P2I06H00ol00000O`1o07l0O`0J07l0O`03o`00
001V09T0IP2I01d0IP2I00<0000004`0/`1<0;<08P1<0;<00ol0003o<`3<oc<0c00^oc<0c003o`00
000I0>H06@3V05006@3V00?o0000ooooooooool00oooool1o`00007ooooo00000ol0003ooooooooo
o`02ooooo`l0/`1<00?o000009T0IP2I06H06P2I06H00ol00000O`1o07l0O`0J07l0O`03o`00001V
09T0IP2I01d0IP2I00<0000004`0/`1<0;<08P1<0;<00ol0003o<`3<oc<0c00^oc<0c003o`00000I
0>H06@3V05006@3V00?o00000000ooooool01?ooool1o`00007ooooo00000ol0003oooooooooo`02
ooooo`h0/`1<00?o000009T0IP2I06H06P2I06H00ol00000O`1o07l0O`0J07l0O`03o`00001V09T0
IP2I01d0IP2I00<0000004`0/`1<0;<08P1<0;<00ol0003o<`3<oc<0c00^oc<0c003o`00000I0>H0
6@3V05006@3V00?o00000000o`000?l01Oooool1o`00007ooooo00000ol0003oooooooooo`02oooo
o`d0/`1<00?o000009T0IP2I06H06P2I06H00ol00000O`1o07l0O`0J07l0O`03o`00001V09T0IP2I
01d0IP2I00<0000004`0/`1<0;<08P1<0;<00ol0003o<`3<oc<0c00^oc<0c003o`00000I0>H06@3V
05006@3V00Co00000000o`000?l0003o1Oooool1o`00007ooooo00000ol0003oooooooooo`02oooo
o``0/`1<00?o000009T0IP2I06H06P2I06H00ol00000O`1o07l0O`0J07l0O`03o`00001V09T0IP2I
01d0IP2I00<0000004`0/`1<0;<08P1<0;<00ol0003o<`3<oc<0c00^oc<0c003o`00000I0>H06@3V
05006@3V00?o00000000o`000?l00P000?l5ooooo`7o00000Oooool00003o`000?oooooooooo00;o
oooo2`2c04`00ol00000V@1V09T0IP0J09T0IP03o`00001o07l0O`1o01X0O`1o00?o000006H0V@1V
09T07@1V09T00`000000C02c04`0/`0R04`0/`03o`000?lc0<co<`3<02ko<`3<00?o000001T0iP0I
0>H0D00I0>H00ol00000003o0000o`030000o`Gooooo0Ol00001ooooo`0000?o0000ooooooooool0
0_ooool:0;<0C003o`00002I06H0V@1V01X0V@1V00?o000007l0O`1o07l06P1o07l00ol00000IP2I
06H0V@0M06H0V@030000001<0;<0C02c0280C02c00?o0000oc<0c?lc0<`0;_lc0<`00ol000006@3V
01T0iP1@01T0iP03o`0000000?l0003o00@0003o1Oooool1o`00007ooooo00000ol0003ooooooooo
o`02ooooo`T0/`1<00?o000009T0IP2I06H06P2I06H00ol00000O`1o07l0O`0J07l0O`03o`00001V
09T0IP2I01d0IP2I00<0000004`0/`1<0;<08P1<0;<00ol0003o<`3<oc<0c00^oc<0c003o`00000I
0>H06@3V05006@3V00?o00000000o`000?l01@000?l5ooooo`7o00000Oooool00003o`000?oooooo
oooo00;ooooo202c04`00ol00000V@1V09T0IP0J09T0IP03o`00001o07l0O`1o01X0O`1o00?o0000
06H0V@1V09T07@1V09T00`000000C02c04`0/`0R04`0/`03o`000?lc0<co<`3<02ko<`3<00?o0000
01T0iP0I0>H0D00I0>H00ol00000003o0000o`060000o`Gooooo0Ol00001ooooo`0000?o0000oooo
ooooool00_ooool70;<0C003o`00002I06H0V@1V01X0V@1V00?o000007l0O`1o07l06P1o07l00ol0
0000IP2I06H0V@0M06H0V@030000001<0;<0C02c0280C02c00?o0000oc<0c?lc0<`0;_lc0<`00ol0
00006@3V01T0iP1@01T0iP03o`0000000?l0003o00L0003o1Oooool1o`00007ooooo00000ol0003o
ooooooooo`02ooooo`H0/`1<00?o000009T0IP2I06H06P2I06H00ol00000O`1o07l0O`0J07l0O`03
o`00001V09T0IP2I01d0IP2I00<0000004`0/`1<0;<08P1<0;<00ol0003o<`3<oc<0c00^oc<0c003
o`00000I0>H06@3V05006@3V00?o00000000o`000?l020000?l5ooooo`7o00000Oooool00003o`00
0?oooooooooo00;ooooo1@2c04`00ol00000V@1V09T0IP0J09T0IP03o`00001o07l0O`1o01/0O`1o
00?o000006H0V@1V09T0701V09T00`000000C02c04`0/`0S04`0/`03o`000?lc0<co<`3<02go<`3<
00?o000001T0iP0I0>H0D00I0>H00ol00000003o0000o`090000o`Gooooo0Ol00001ooooo`0000?o
0000ooooooooool00_ooool40;<0C003o`00002I06H0V@1V01X0V@1V00?o000007l0O`1o07l06`1o
07l00ol00000IP2I06H0V@0L06H0V@030000001<0;<0C02c02<0C02c00?o0000oc<0c?lc0<`0;Olc
0<`00ol000006@3V01T0iP1@01T0iP03o`0000000?l0003o00X0003o1Oooool1o`00007ooooo0000
0ol0003oooooooooo`02ooooo`<0/`1<00?o000009T0IP2I06H06P2I06H00ol00000O`1o07l0O`0K
07l0O`03o`00001V09T0IP2I01`0IP2I00<0000004`0/`1<0;<08`1<0;<00ol0003o<`3<oc<0c00]
oc<0c003o`00000I0>H06@3V05006@3V00?o00000000o`000?l02`000?l5ooooo`7o00000Oooool0
0003o`000?oooooooooo00;ooooo0P2c04`00ol00000V@1V09T0IP0J09T0IP03o`00001o07l0O`1o
01/0O`1o00?o000006H0V@1V09T0701V09T00`000000C02c04`0/`0S04`0/`03o`000?lc0<co<`3<
02go<`3<00?o000001T0iP0I0>H0D00I0>H00ol00000003o0000o`0<0000o`Gooooo0Ol00001oooo
o`0000?o0000ooooooooool00_ooool00`2c04co000009T0IP0K09T0IP03o`00001o07l0O`1o01/0
O`1o00?o000006H0V@1V09T0701V09T00`000000C02c04`0/`0S04`0/`03o`000?lc0<co<`3<02go
<`3<00?o000001T0iP0I0>H0D00I0>H00ol00000003o0000o`0=0000o`Gooooo0Ol00001ooooo`00
00?o0000ooooooooool00_ooool00ol00000V@1V09T0IP0J09T0IP03o`00001o07l0O`1o01/0O`1o
00?o000006H0V@1V09T0701V09T00`000000C02c04`0/`0S04`0/`03o`000?lc0<co<`3<02go<`3<
00?o000001T0iP0I0>H0D00I0>H00ol00000003o0000o`0>0000o`Gooooo0Ol00001ooooo`0000?o
0000ooooooooool00_oooolL09T0IP03o`00001o07l0O`1o01X0O`1o0_l0000N06H0V@030000001<
0;<0C02c0280C02c0_l0000_oc<0c003o`00000I0>H06@3V05006@3V00?o00000000o`000?l03`00
0?l5ooooo`7o00000Oooool00003o`000?oooooooooo00;ooooo6`2I06H00ol00000O`1o07l0O`0J
07l0O`03o`00001V09T0IP2I01d0IP2I00<0000004`0/`1<0;<08P1<0;<00ol0003o<`3<oc<0c00^
oc<0c003o`00000I0>H06@3V05006@3V00?o00000000o`000?l040000?l5ooooo`7o00000Oooool0
0003o`000?oooooooooo00;ooooo6P2I06H00ol00000O`1o07l0O`0J07l0O`03o`00001V09T0IP2I
01d0IP2I00<0000004`0/`1<0;<08P1<0;<00ol0003o<`3<oc<0c00^oc<0c003o`00000I0>H06@3V
05006@3V00?o00000000o`000?l04@000?l5ooooo`7o00000Oooool00003o`000?oooooooooo00;o
oooo6@2I06H00ol00000O`1o07l0O`0J07l0O`03o`00001V09T0IP2I01d0IP2I00<0000004`0/`1<
0;<08P1<0;<00ol0003o<`3<oc<0c00^oc<0c003o`00000I0>H06@3V05006@3V00?o00000000o`00
0?l04P000?l5ooooo`7o00000Oooool00003o`000?oooooooooo00;ooooo602I06H00ol00000O`1o
07l0O`0J07l0O`03o`00001V09T0IP2I01d0IP2I00<0000004`0/`1<0;<08P1<0;<00ol0003o<`3<
oc<0c00^oc<0c003o`00000I0>H06@3V05006@3V00?o00000000o`000?l04`000?l5ooooo`7o0000
0Oooool00003o`000?oooooooooo00;ooooo5`2I06H00ol00000O`1o07l0O`0K07l0O`03o`00001V
09T0IP2I01d0IP2I00<0000004`0/`1<0;<08P1<0;<00ol0003o<`3<oc<0c00^oc<0c003o`00000I
0>H06@3V05006@3V00?o00000000o`000?l04`000?l5ooooo`7o00000Oooool00003o`000?oooooo
oooo00;ooooo5`2I06H00ol00000O`1o07l0O`0J07l0O`03o`00001V09T0IP2I01d0IP2I00<00000
04`0/`1<0;<08P1<0;<00ol0003o<`3<oc<0c00^oc<0c003o`00000I0>H06@3V05006@3V00?o0000
0000o`000?l050000?l5ooooo`7o00000Oooool00003o`000?oooooooooo00;ooooo5P2I06H00ol0
0000O`1o07l0O`0J07l0O`03o`00001V09T0IP2I01d0IP2I00<0000004`0/`1<0;<08P1<0;<00ol0
003o<`3<oc<0c00^oc<0c003o`00000I0>H06@3V05006@3V00?o00000000o`000?l05@000?l5oooo
o`7o00000Oooool00003o`000?oooooooooo00;ooooo5@2I06H00ol00000O`1o07l0O`0J07l0O`03
o`00001V09T0IP2I01d0IP2I00<0000004`0/`1<0;<08P1<0;<00ol0003o<`3<oc<0c00^oc<0c003
o`00000I0>H06@3V05006@3V00?o00000000o`000?l05P000?l5ooooo`7o00000Oooool00003o`00
0?oooooooooo00;ooooo502I06H00ol00000O`1o07l0O`0J07l0O`03o`00001V09T0IP2I01d0IP2I
00<0000004`0/`1<0;<08P1<0;<00ol0003o<`3<oc<0c00^oc<0c003o`00000I0>H06@3V05006@3V
00?o00000000o`000?l05`000?l5ooooo`7o00000Oooool00003o`000?oooooooooo00;ooooo4`2I
06H00ol00000O`1o07l0O`0J07l0O`03o`00001V09T0IP2I01d0IP2I00<0000004`0/`1<0;<08P1<
0;<00ol0003o<`3<oc<0c00^oc<0c003o`00000I0>H06@3V05006@3V00?o00000000o`000?l06000
0?l5ooooo`7o00000Oooool00003o`000?oooooooooo00;ooooo4P2I06H00ol00000O`1o07l0O`0J
07l0O`03o`00001V09T0IP2I01d0IP2I00<0000004`0/`1<0;<08P1<0;<00ol0003o<`3<oc<0c00^
oc<0c003o`00000I0>H06@3V05006@3V00?o00000000o`000?l06@000?l5ooooo`7o00000Oooool0
0003o`000?oooooooooo00;ooooo4@2I06H00ol00000O`1o07l0O`0J07l0O`03o`00001V09T0IP2I
01d0IP2I00<0000004`0/`1<0;<08P1<0;<00ol0003o<`3<oc<0c00^oc<0c003o`00000I0>H06@3V
05006@3V00?o00000000o`000?l06P000?l5ooooo`7o00000Oooool00003o`000?oooooooooo00;o
oooo402I06H00ol00000O`1o07l0O`0J07l0O`03o`00001V09T0IP2I01d0IP2I00<0000004`0/`1<
0;<08P1<0;<00ol0003o<`3<oc<0c00^oc<0c003o`00000I0>H06@3V05006@3V00?o00000000o`00
0?l06`000?l5ooooo`7o00000Oooool00003o`000?oooooooooo00;ooooo3`2I06H00ol00000O`1o
07l0O`0J07l0O`03o`00001V09T0IP2I01d0IP2I00<0000004`0/`1<0;<08P1<0;<00ol0003o<`3<
oc<0c00^oc<0c003o`00000I0>H06@3V05006@3V00?o00000000o`000?l070000?l5ooooo`7o0000
0Oooool00003o`000?oooooooooo00;ooooo3P2I06H00ol00000O`1o07l0O`0J07l0O`03o`00001V
09T0IP2I01d0IP2I00<0000004`0/`1<0;<08P1<0;<00ol0003o<`3<oc<0c00^oc<0c003o`00000I
0>H06@3V05006@3V00?o00000000o`000?l07@000?l5ooooo`7o00000Oooool00003o`000?oooooo
oooo00;ooooo3@2I06H00ol00000O`1o07l0O`0J07l0O`03o`00001V09T0IP2I01d0IP2I00<00000
04`0/`1<0;<08P1<0;<00ol0003o<`3<oc<0c00^oc<0c003o`00000I0>H06@3V05006@3V00?o0000
0000o`000?l07P000?l5ooooo`7o00000Oooool00003o`000?oooooooooo00;ooooo302I06H00ol0
0000O`1o07l0O`0K07l0O`03o`00001V09T0IP2I01`0IP2I00<0000004`0/`1<0;<08`1<0;<00ol0
003o<`3<oc<0c00]oc<0c003o`00000I0>H06@3V05006@3V00?o00000000o`000?l07`000?l5oooo
o`7o00000Oooool00003o`000?oooooooooo00;ooooo2`2I06H00ol00000O`1o07l0O`0K07l0O`03
o`00001V09T0IP2I01`0IP2I00<0000004`0/`1<0;<08`1<0;<00ol0003o<`3<oc<0c00]oc<0c003
o`00000I0>H06@3V05006@3V00?o00000000o`000?l080000?l5ooooo`7o00000Oooool00003o`00
0?oooooooooo00;ooooo2P2I06H00ol00000O`1o07l0O`0K07l0O`03o`00001V09T0IP2I01`0IP2I
00<0000004`0/`1<0;<08`1<0;<00ol0003o<`3<oc<0c00]oc<0c003o`00000I0>H06@3V05006@3V
00?o00000000o`000?l08@000?l5ooooo`7o00000Oooool00003o`000?oooooooooo00;ooooo2@2I
06H00ol00000O`1o07l0O`0K07l0O`03o`00001V09T0IP2I01`0IP2I00<0000004`0/`1<0;<08`1<
0;<00ol0003o<`3<oc<0c00]oc<0c003o`00000I0>H06@3V05006@3V00?o00000000o`000?l08P00
0?l5ooooo`7o00000Oooool00003o`000?oooooooooo00;ooooo202I06H00ol00000O`1o07l0O`0K
07l0O`03o`00001V09T0IP2I01`0IP2I00<0000004`0/`1<0;<08`1<0;<00ol0003o<`3<oc<0c00]
oc<0c003o`00000I0>H06@3V05006@3V00?o00000000o`000?l08`000?l5ooooo`7o00000Oooool0
0003o`000?oooooooooo00;ooooo1`2I06H00ol00000O`1o07l0O`0K07l0O`03o`00001V09T0IP2I
01`0IP2I00<0000004`0/`1<0;<08`1<0;<00ol0003o<`3<oc<0c00]oc<0c003o`00000I0>H06@3V
05006@3V00?o00000000o`000?l090000?l5ooooo`7o00000Oooool00003o`000?oooooooooo00;o
oooo1P2I06H00ol00000O`1o07l0O`0K07l0O`03o`00001V09T0IP2I01`0IP2I00<0000004`0/`1<
0;<08`1<0;<00ol0003o<`3<oc<0c00]oc<0c003o`00000I0>H06@3V05006@3V00?o00000000o`00
0?l09@000?l5ooooo`7o00000Oooool00003o`000?oooooooooo00;ooooo1@2I06H00ol00000O`1o
07l0O`0J07l0O`;o00007P1V09T00`000000C02c04`0/`0R04`0/`;o0000;olc0<`00ol000006@3V
01T0iP1@01T0iP03o`0000000?l0003o02H0003o1Oooool1o`00007ooooo00000ol0003ooooooooo
o`02ooooo`@0V@1V00?o000007l0O`1o07l06P1o07l00ol00000IP2I06H0V@0M06H0V@030000001<
0;<0C02c0280C02c00?o0000oc<0c?lc0<`0;_lc0<`00ol000006@3V01T0iP1@01T0iP03o`000000
0?l0003o02L0003o1Oooool1o`00007ooooo00000ol0003oooooooooo`02ooooo`<0V@1V00?o0000
07l0O`1o07l06P1o07l00ol00000IP2I06H0V@0M06H0V@030000001<0;<0C02c0280C02c00?o0000
oc<0c?lc0<`0;_lc0<`00ol000006@3V01T0iP1@01T0iP03o`0000000?l0003o02P0003o1Oooool1
o`00007ooooo00000ol0003oooooooooo`02ooooo`80V@1V00?o000007l0O`1o07l06P1o07l00ol0
0000IP2I06H0V@0M06H0V@030000001<0;<0C02c0280C02c00?o0000oc<0c?lc0<`0;_lc0<`00ol0
00006@3V01T0iP1@01T0iP03o`0000000?l0003o02T0003o1Oooool1o`00007ooooo00000ol0003o
ooooooooo`02ooooo`0309T0I_l00000O`1o01`0O`1o00?o000006H0V@1V09T07@1V09T00`000000
C02c04`0/`0R04`0/`03o`000?lc0<co<`3<02go<`3<00?o000001T0iP0I0>H0D@0I0>H00ol00000
003o0000o`0Y0000o`Gooooo0Ol00001ooooo`0000?o0000ooooooooool00_ooool00ol00000O`1o
07l0O`0K07l0O`03o`00001V09T0IP2I01d0IP2I00<0000004`0/`1<0;<08P1<0;<00ol0003o<`3<
oc<0c00]oc<0c003o`00000I0>H06@3V05406@3V00?o00000000o`000?l0:P000?l5ooooo`7o0000
0Oooool00003o`000?oooooooooo00;ooooo7@1o07l00ol00000IP2I06H0V@0M06H0V@030000001<
0;<0C02c0280C02c00?o0000oc<0c?lc0<`0;Olc0<`00ol000006@3V01T0iP1A01T0iP03o`000000
0?l0003o02/0003o1Oooool1o`00007ooooo00000ol0003oooooooooo`02oooooa`0O`1o00?o0000
06H0V@1V09T07@1V09T00`000000C02c04`0/`0R04`0/`03o`000?lc0<co<`3<02go<`3<00?o0000
01T0iP0I0>H0D@0I0>H00ol00000003o0000o`0/0000o`Gooooo0Ol00001ooooo`0000?o0000oooo
ooooool00_oooolK07l0O`03o`00001V09T0IP2I01d0IP2I00<0000004`0/`1<0;<08P1<0;<00ol0
003o<`3<oc<0c00]oc<0c003o`00000I0>H06@3V05406@3V00?o00000000o`000?l0;@000?l5oooo
o`7o00000Oooool00003o`000?oooooooooo00;ooooo6P1o07l00ol00000IP2I06H0V@0M06H0V@03
0000001<0;<0C02c0280C02c00?o0000oc<0c?lc0<`0;Olc0<`00ol000006@3V01T0iP1A01T0iP03
o`0000000?l0003o02h0003o1Oooool1o`00007ooooo00000ol0003oooooooooo`02oooooaT0O`1o
00?o000006H0V@1V09T07@1V09T00`000000C02c04`0/`0R04`0/`03o`000?lc0<co<`3<02go<`3<
00?o000001T0iP0I0>H0D@0I0>H00ol00000003o0000o`0_0000o`Gooooo0Ol00001ooooo`0000?o
0000ooooooooool00_oooolH07l0O`03o`00001V09T0IP2I01d0IP2I00<0000004`0/`1<0;<08P1<
0;<00ol0003o<`3<oc<0c00]oc<0c003o`00000I0>H06@3V05406@3V00?o00000000o`000?l0<000
0?l5ooooo`7o00000Oooool00003o`000?oooooooooo00;ooooo5`1o07l00ol00000IP2I06H0V@0M
06H0V@030000001<0;<0C02c0280C02c00?o0000oc<0c?lc0<`0;Olc0<`00ol000006@3V01T0iP1A
01T0iP03o`0000000?l0003o0340003o1Oooool1o`00007ooooo00000ol0003oooooooooo`02oooo
oaH0O`1o00?o000006H0V@1V09T07@1V09T00`000000C02c04`0/`0R04`0/`03o`000?lc0<co<`3<
02go<`3<00?o000001T0iP0I0>H0D@0I0>H00ol00000003o0000o`0b0000o`Gooooo0Ol00001oooo
o`0000?o0000ooooooooool00_oooolE07l0O`03o`00001V09T0IP2I01d0IP2I00<0000004`0/`1<
0;<08P1<0;<00ol0003o<`3<oc<0c00]oc<0c003o`00000I0>H06@3V05406@3V00?o00000000o`00
0?l0<`000?l5ooooo`7o00000Oooool00003o`000?oooooooooo00;ooooo501o07l00ol00000IP2I
06H0V@0M06H0V@030000001<0;<0C02c0280C02c00?o0000oc<0c?lc0<`0;_lc0<`00ol000006@3V
01T0iP1?01T0iP;o0000=P000?l5ooooo`7o00000Oooool00003o`000?oooooooooo00;ooooo4`1o
07l00ol00000IP2I06H0V@0M06H0V@030000001<0;<0C02c0280C02c00?o0000oc<0c?lc0<`0;_lc
0<`00ol000006@3V01T0iP1?01T0iP03o`0000000?l0003o03H0003o1Oooool1o`00007ooooo0000
0ol0003oooooooooo`02oooooa80O`1o00?o000006H0V@1V09T07@1V09T00`000000C02c04`0/`0R
04`0/`03o`000?lc0<co<`3<02ko<`3<00?o000001T0iP0I0>H0C`0I0>H00ol00000003o0000o`0g
0000o`Gooooo0Ol00001ooooo`0000?o0000ooooooooool00_oooolA07l0O`03o`00001V09T0IP2I
01d0IP2I00<0000004`0/`1<0;<08P1<0;<00ol0003o<`3<oc<0c00^oc<0c003o`00000I0>H06@3V
05006@3V00?o00000000o`000?l0=`000?l5ooooo`7o00000Oooool00003o`000?oooooooooo00;o
oooo401o07l00ol00000IP2I06H0V@0M06H0V@030000001<0;<0C02c0280C02c00?o0000oc<0c?lc
0<`0;_lc0<`00ol000006@3V01T0iP1@01T0iP03o`0000000?l0003o03P0003o1Oooool1o`00007o
oooo00000ol0003oooooooooo`02ooooo`l0O`1o00?o000006H0V@1V09T07@1V09T00`000000C02c
04`0/`0R04`0/`03o`000?lc0<co<`3<02ko<`3<00?o000001T0iP0I0>H0D00I0>H00ol00000003o
0000o`0i0000o`Gooooo0Ol00001ooooo`0000?o0000ooooooooool00_ooool>07l0O`03o`00001V
09T0IP2I01d0IP2I00<0000004`0/`1<0;<08P1<0;<00ol0003o<`3<oc<0c00^oc<0c003o`00000I
0>H06@3V05006@3V00?o00000000o`000?l0>P000?l5ooooo`7o00000Oooool00003o`000?oooooo
oooo00;ooooo3@1o07l00ol00000IP2I06H0V@0M06H0V@030000001<0;<0C02c0280C02c00?o0000
oc<0c?lc0<`0;_lc0<`00ol000006@3V01T0iP1@01T0iP03o`0000000?l0003o03/0003o1Oooool1
o`00007ooooo00000ol0003oooooooooo`02ooooo``0O`1o00?o000006H0V@1V09T07@1V09T00`00
0000C02c04`0/`0R04`0/`03o`000?lc0<co<`3<02ko<`3<00?o000001T0iP0I0>H0D00I0>H00ol0
0000003o0000o`0l0000o`Gooooo0Ol00001ooooo`0000?o0000ooooooooool00_ooool;07l0O`03
o`00001V09T0IP2I01d0IP2I00<0000004`0/`1<0;<08P1<0;<00ol0003o<`3<oc<0c00^oc<0c003
o`00000I0>H06@3V05006@3V00?o00000000o`000?l0?@000?l5ooooo`7o00000Oooool00003o`00
0?oooooooooo00;ooooo2P1o07l00ol00000IP2I06H0V@0M06H0V@030000001<0;<0C02c0280C02c
00?o0000oc<0c?lc0<`0;_lc0<`00ol000006@3V01T0iP1@01T0iP03o`0000000?l0003o03h0003o
1Oooool1o`00007ooooo00000ol0003oooooooooo`02ooooo`T0O`1o00?o000006H0V@1V09T07@1V
09T00`000000C02c04`0/`0R04`0/`03o`000?lc0<co<`3<02go<`3<0_l0001B01T0iP03o`000000
0?l0003o03l0003o1Oooool1o`00007ooooo00000ol0003oooooooooo`02ooooo`P0O`1o00?o0000
06H0V@1V09T07P1V09T00`000000C02c04`0/`0Q04`0/`03o`000?lc0<co<`3<02ko<`3<00?o0000
01T0iP0I0>H0D00I0>H00ol00000003o0000o`100000o`Gooooo0Ol00001ooooo`0000?o0000oooo
ooooool00_ooool707l0O`03o`00001V09T0IP2I01h0IP2I00<0000004`0/`1<0;<08@1<0;<00ol0
003o<`3<oc<0c00^oc<0c003o`00000I0>H06@3V05006@3V00?o00000000o`000?l0@@000?l5oooo
o`7o00000Oooool00003o`000?oooooooooo00;ooooo1P1o07l00ol00000IP2I06H0V@0N06H0V@03
0000001<0;<0C02c0240C02c00?o0000oc<0c?lc0<`0;_lc0<`00ol000006@3V01T0iP1@01T0iP03
o`0000000?l0003o0480003o1Oooool1o`00007ooooo00000ol0003oooooooooo`02ooooo`D0O`1o
00?o000006H0V@1V09T07P1V09T00`000000C02c04`0/`0Q04`0/`03o`000?lc0<co<`3<02ko<`3<
00?o000001T0iP0I0>H0D00I0>H00ol00000003o0000o`130000o`Gooooo0Ol00001ooooo`0000?o
0000ooooooooool00_ooool407l0O`03o`00001V09T0IP2I01h0IP2I00<0000004`0/`1<0;<08@1<
0;<00ol0003o<`3<oc<0c00^oc<0c003o`00000I0>H06@3V05006@3V00?o00000000o`000?l0A000
0?l5ooooo`7o00000Oooool00003o`000?oooooooooo00;ooooo0`1o07l00ol00000IP2I06H0V@0N
06H0V@030000001<0;<0C02c0240C02c00?o0000oc<0c?lc0<`0;_lc0<`00ol000006@3V01T0iP1@
01T0iP03o`0000000?l0003o04D0003o1Oooool1o`00007ooooo00000ol0003oooooooooo`02oooo
o`80O`1o00?o000006H0V@1V09T07@1V09T2000002<0C02c00?o0000oc<0c?lc0<`0;_lc0<`00ol0
00006@3V01T0iP1@01T0iP03o`0000000?l0003o04H0003o1Oooool1o`00007ooooo00000ol0003o
ooooooooo`02ooooo`0307l0Ool00000IP2I01h0IP2I00<0000004`0/`1<0;<08P1<0;<00ol0003o
<`3<oc<0c00^oc<0c003o`00000I0>H06@3V05006@3V00?o00000000o`000?l0A`000?l5ooooo`7o
00000Oooool00003o`000?oooooooooo00;ooooo00?o000006H0V@1V09T07@1V09T00`000000C02c
04`0/`0R04`0/`03o`000?lc0<co<`3<02ko<`3<00?o000001T0iP0I0>H0D00I0>H00ol00000003o
0000o`180000o`Gooooo0Ol00001ooooo`0000?o0000ooooooooool00_oooolO06H0V@030000001<
0;<0C02c02<0C02c00?o0000oc<0c?lc0<`0;Olc0<`00ol000006@3V01T0iP1@01T0iP03o`000000
0?l0003o04T0003o1Oooool1o`00007ooooo00000ol0003oooooooooo`02oooooah0IP2I00<00000
04`0/`1<0;<08`1<0;<00ol0003o<`3<oc<0c00]oc<0c003o`00000I0>H06@3V05006@3V00?o0000
0000o`000?l0BP000?l5ooooo`7o00000Oooool00003o`000?oooooooooo00;ooooo7@1V09T00`00
0000C02c04`0/`0S04`0/`03o`000?lc0<co<`3<02go<`3<00?o000001T0iP0I0>H0D00I0>H00ol0
0000003o0000o`1;0000o`Gooooo0Ol00001ooooo`0000?o0000ooooooooool00_oooolL06H0V@03
0000001<0;<0C02c02<0C02c00?o0000oc<0c?lc0<`0;Olc0<`00ol000006@3V01T0iP1@01T0iP03
o`0000000?l0003o04`0003o1Oooool1o`00007ooooo00000ol0003oooooooooo`02oooooa/0IP2I
00<0000004`0/`1<0;<08`1<0;<00ol0003o<`3<oc<0c00]oc<0c003o`00000I0>H06@3V05006@3V
00?o00000000o`000?l0C@000?l5ooooo`7o00000Oooool00003o`000?oooooooooo00;ooooo6P1V
09T00`000000C02c04`0/`0S04`0/`03o`000?lc0<co<`3<02go<`3<00?o000001T0iP0I0>H0D00I
0>H00ol00000003o0000o`1>0000o`Gooooo0Ol00001ooooo`0000?o0000ooooooooool00_oooolI
06H0V@030000001<0;<0C02c02<0C02c00?o0000oc<0c?lc0<`0;Olc0<`00ol000006@3V01T0iP1@
01T0iP03o`0000000?l0003o04l0003o1Oooool1o`00007ooooo00000ol0003oooooooooo`02oooo
oaP0IP2I00<0000004`0/`1<0;<08`1<0;<00ol0003o<`3<oc<0c00]oc<0c003o`00000I0>H06@3V
05006@3V00?o00000000o`000?l0D0000?l5ooooo`7o00000Oooool00003o`000?oooooooooo00;o
oooo5`1V09T00`000000C02c04`0/`0S04`0/`03o`000?lc0<co<`3<02go<`3<00?o000001T0iP0I
0>H0D00I0>H00ol00000003o0000o`1A0000o`Gooooo0Ol00001ooooo`0000?o0000ooooooooool0
0_oooolF06H0V@030000001<0;<0C02c02<0C02c00?o0000oc<0c?lc0<`0;Olc0<`00ol000006@3V
01T0iP1@01T0iP03o`0000000?l0003o0580003o1Oooool1o`00007ooooo00000ol0003ooooooooo
o`02oooooaD0IP2I00<0000004`0/`1<0;<08`1<0;<00ol0003o<`3<oc<0c00]oc<0c003o`00000I
0>H06@3V05006@3V00?o00000000o`000?l0D`000?l5ooooo`7o00000Oooool00003o`000?oooooo
oooo00;ooooo501V09T00`000000C02c04`0/`0R04`0/`;o0000;olc0<`00ol000006@3V01T0iP1@
01T0iP03o`0000000?l0003o05@0003o1Oooool1o`00007ooooo00000ol0003oooooooooo`02oooo
oa<0IP2I00<0000004`0/`1<0;<08P1<0;<00ol0003o<`3<oc<0c00^oc<0c003o`00000I0>H06@3V
05006@3V00?o00000000o`000?l0E@000?l5ooooo`7o00000Oooool00003o`000?oooooooooo00;o
oooo4P1V09T00`000000C02c04`0/`0R04`0/`03o`000?lc0<co<`3<02ko<`3<00?o000001T0iP0I
0>H0D00I0>H00ol00000003o0000o`1F0000o`Gooooo0Ol00001ooooo`0000?o0000ooooooooool0
0_oooolB06H0V@030000001<0;<0C02c0280C02c00?o0000oc<0c?lc0<`0;_lc0<`00ol000006@3V
01T0iP1@01T0iP03o`0000000?l0003o05H0003o1Oooool1o`00007ooooo00000ol0003ooooooooo
o`02oooooa40IP2I00<0000004`0/`1<0;<08P1<0;<00ol0003o<`3<oc<0c00^oc<0c003o`00000I
0>H06@3V05006@3V00?o00000000o`000?l0E`000?l5ooooo`7o00000Oooool00003o`000?oooooo
oooo00;ooooo401V09T00`000000C02c04`0/`0R04`0/`03o`000?lc0<co<`3<02ko<`3<00?o0000
01T0iP0I0>H0D00I0>H00ol00000003o0000o`1H0000o`Gooooo0Ol00001ooooo`0000?o0000oooo
ooooool00_ooool?06H0V@030000001<0;<0C02c0280C02c00?o0000oc<0c?lc0<`0;_lc0<`00ol0
00006@3V01T0iP1@01T0iP03o`0000000?l0003o05T0003o1Oooool1o`00007ooooo00000ol0003o
ooooooooo`02ooooo`h0IP2I00<0000004`0/`1<0;<08P1<0;<00ol0003o<`3<oc<0c00^oc<0c003
o`00000I0>H06@3V05006@3V00?o00000000o`000?l0FP000?l5ooooo`7o00000Oooool00003o`00
0?oooooooooo00;ooooo3@1V09T00`000000C02c04`0/`0R04`0/`03o`000?lc0<co<`3<02ko<`3<
00?o000001T0iP0I0>H0D00I0>H00ol00000003o0000o`1K0000o`Gooooo0Ol00001ooooo`0000?o
0000ooooooooool00_ooool<06H0V@030000001<0;<0C02c0280C02c00?o0000oc<0c?lc0<`0;_lc
0<`00ol000006@3V01T0iP1@01T0iP03o`0000000?l0003o05`0003o1Oooool1o`00007ooooo0000
0ol0003oooooooooo`02ooooo`/0IP2I00<0000004`0/`1<0;<08P1<0;<00ol0003o<`3<oc<0c00^
oc<0c003o`00000I0>H06@3V05006@3V00?o00000000o`000?l0G@000?l5ooooo`7o00000Oooool0
0003o`000?oooooooooo00;ooooo2P1V09T00`000000C02c04`0/`0R04`0/`03o`000?lc0<co<`3<
02ko<`3<00?o000001T0iP0I0>H0D00I0>H00ol00000003o0000o`1N0000o`Gooooo0Ol00001oooo
o`0000?o0000ooooooooool00_ooool906H0V@030000001<0;<0C02c0280C02c00?o0000oc<0c?lc
0<`0;_lc0<`00ol000006@3V01T0iP1@01T0iP03o`0000000?l0003o05l0003o1Oooool1o`00007o
oooo00000ol0003oooooooooo`02ooooo`P0IP2I00<0000004`0/`1<0;<08P1<0;<00ol0003o<`3<
oc<0c00^oc<0c003o`00000I0>H06@3V05006@3V00?o00000000o`000?l0H0000?l5ooooo`7o0000
0Oooool00003o`000?oooooooooo00;ooooo1`1V09T00`000000C02c04`0/`0R04`0/`03o`000?lc
0<co<`3<02ko<`3<00?o000001T0iP0I0>H0D00I0>H00ol00000003o0000o`1Q0000o`Gooooo0Ol0
0001ooooo`0000?o0000ooooooooool00_ooool606H0V@030000001<0;<0C02c02<0C02c00?o0000
oc<0c?lc0<`0;Olc0<`00ol000006@3V01T0iP1@01T0iP03o`0000000?l0003o0680003o1Oooool1
o`00007ooooo00000ol0003oooooooooo`02ooooo`D0IP2I00<0000004`0/`1<0;<08`1<0;<00ol0
003o<`3<oc<0c00]oc<0c003o`00000I0>H06@3V05006@3V00?o00000000o`000?l0H`000?l5oooo
o`7o00000Oooool00003o`000?oooooooooo00;ooooo101V09T00`000000C02c04`0/`0S04`0/`03
o`000?lc0<co<`3<02go<`3<00?o000001T0iP0I0>H0D00I0>H00ol00000003o0000o`1T0000o`Go
oooo0Ol00001ooooo`0000?o0000ooooooooool00_ooool306H0V@030000001<0;<0C02c02<0C02c
00?o0000oc<0c?lc0<`0;Olc0<`00ol000006@3V01T0iP1@01T0iP03o`0000000?l0003o06D0003o
1Oooool1o`00007ooooo00000ol0003oooooooooo`02ooooo`80IP2I00<0000004`0/`1<0;<08`1<
0;<00ol0003o<`3<oc<0c00]oc<0c003o`00000I0>H06@3V05006@3V00?o00000000o`000?l0IP00
0?l5ooooo`7o00000Oooool00003o`000?oooooooooo00;ooooo00<0IP2I0000001<0;<0901<0;<0
0ol0003o<`3<oc<0c00]oc<0c003o`00000I0>H06@3V05006@3V00?o00000000o`000?l0I`000?l5
ooooo`7o00000Oooool00003o`000?oooooooooo00;ooooo00<0000004`0/`1<0;<08`1<0;<00ol0
003o<`3<oc<0c00]oc<0c003o`00000I0>H06@3V05006@3V00?o00000000o`000?l0J0000?l5oooo
o`7o00000Oooool00003o`000?oooooooooo00;ooooo9@1<0;<00ol0003o<`3<oc<0c00]oc<0c003
o`00000I0>H06@3V05006@3V00?o00000000o`000?l0J@000?l5ooooo`7o00000Oooool00003o`00
0?oooooooooo00;ooooo901<0;<00ol0003o<`3<oc<0c00]oc<0c003o`00000I0>H06@3V05006@3V
00?o00000000o`000?l0JP000?l5ooooo`7o00000Oooool00003o`000?oooooooooo00;ooooo8P1<
0;<2o`0002oo<`3<00?o000001T0iP0I0>H0D00I0>H00ol00000003o0000o`1[0000o`Gooooo0Ol0
0001ooooo`0000?o0000ooooooooool00_oooolQ04`0/`03o`000?lc0<co<`3<02ko<`3<00?o0000
01T0iP0I0>H0D00I0>H00ol00000003o0000o`1/0000o`Gooooo0Ol00001ooooo`0000?o0000oooo
ooooool00_oooolQ04`0/`03o`000?lc0<co<`3<02ko<`3<00?o000001T0iP0I0>H0D00I0>H00ol0
0000003o0000o`1/0000o`Gooooo0Ol00001ooooo`0000?o0000ooooooooool00_oooolP04`0/`03
o`000?lc0<co<`3<02ko<`3<00?o000001T0iP0I0>H0D00I0>H00ol00000003o0000o`1]0000o`Go
oooo0Ol00001ooooo`0000?o0000ooooooooool00_oooolO04`0/`03o`000?lc0<co<`3<02ko<`3<
00?o000001T0iP0I0>H0D00I0>H00ol00000003o0000o`1^0000o`Gooooo0Ol00001ooooo`0000?o
0000ooooooooool00_oooolN04`0/`03o`000?lc0<co<`3<02ko<`3<00?o000001T0iP0I0>H0D00I
0>H00ol00000003o0000o`1_0000o`Gooooo0Ol00001ooooo`0000?o0000ooooooooool00_oooolM
04`0/`03o`000?lc0<co<`3<02ko<`3<00?o000001T0iP0I0>H0D00I0>H00ol00000003o0000o`1`
0000o`Gooooo0Ol00001ooooo`0000?o0000ooooooooool00_oooolL04`0/`03o`000?lc0<co<`3<
02ko<`3<00?o000001T0iP0I0>H0D00I0>H00ol00000003o0000o`1a0000o`Gooooo0Ol00001oooo
o`0000?o0000ooooooooool00_oooolK04`0/`03o`000?lc0<co<`3<02ko<`3<00?o000001T0iP0I
0>H0D00I0>H00ol00000003o0000o`1b0000o`Gooooo0Ol00001ooooo`0000?o0000ooooooooool0
0_oooolJ04`0/`03o`000?lc0<co<`3<02ko<`3<00?o000001T0iP0I0>H0D00I0>H00ol00000003o
0000o`1c0000o`Gooooo0Ol00001ooooo`0000?o0000ooooooooool00_oooolI04`0/`03o`000?lc
0<co<`3<02ko<`3<00?o000001T0iP0I0>H0D00I0>H00ol00000003o0000o`1d0000o`Gooooo0Ol0
0001ooooo`0000?o0000ooooooooool00_oooolH04`0/`03o`000?lc0<co<`3<02ko<`3<00?o0000
01T0iP0I0>H0D00I0>H00ol00000003o0000o`1e0000o`Gooooo0Ol00001ooooo`0000?o0000oooo
ooooool00_oooolG04`0/`03o`000?lc0<co<`3<02ko<`3<00?o000001T0iP0I0>H0D00I0>H00ol0
0000003o0000o`1f0000o`Gooooo0Ol00001ooooo`0000?o0000ooooooooool00_oooolF04`0/`03
o`000?lc0<co<`3<02ko<`3<00?o000001T0iP0I0>H0C`0I0>H2o`0007T0003o1Oooool1o`00007o
oooo00000ol0003oooooooooo`02oooooaH0C02c00?o0000oc<0c?lc0<`0;Olc0<`00ol000006@3V
01T0iP1?01T0iP03o`0000000?l0003o07T0003o1Oooool1o`00007ooooo00000ol0003ooooooooo
o`02oooooaD0C02c00?o0000oc<0c?lc0<`0;Olc0<`00ol000006@3V01T0iP1?01T0iP03o`000000
0?l0003o07X0003o1Oooool1o`00007ooooo00000ol0003oooooooooo`02oooooa@0C02c00?o0000
oc<0c?lc0<`0;Olc0<`00ol000006@3V01T0iP1?01T0iP03o`0000000?l0003o07/0003o1Oooool1
o`00007ooooo00000ol0003oooooooooo`02oooooa<0C02c00?o0000oc<0c?lc0<`0;Olc0<`00ol0
00006@3V01T0iP1?01T0iP03o`0000000?l0003o07`0003o1Oooool1o`00007ooooo00000ol0003o
ooooooooo`02oooooa80C02c00?o0000oc<0c?lc0<`0;Olc0<`00ol000006@3V01T0iP1@01T0iP03
o`0000000?l0003o07`0003o1Oooool1o`00007ooooo00000ol0003oooooooooo`02oooooa40C02c
00?o0000oc<0c?lc0<`0;Olc0<`00ol000006@3V01T0iP1@01T0iP03o`0000000?l0003o07d0003o
1Oooool1o`00007ooooo00000ol0003oooooooooo`02oooooa00C02c00?o0000oc<0c?lc0<`0;Olc
0<`00ol000006@3V01T0iP1@01T0iP03o`0000000?l0003o07h0003o1Oooool1o`00007ooooo0000
0ol0003oooooooooo`02ooooo`l0C02c00?o0000oc<0c?lc0<`0;Olc0<`00ol000006@3V01T0iP1@
01T0iP03o`0000000?l0003o07l0003o1Oooool1o`00007ooooo00000ol0003oooooooooo`02oooo
o`h0C02c00?o0000oc<0c?lc0<`0;Olc0<`00ol000006@3V01T0iP1@01T0iP03o`0000000?l0003o
0800003o1Oooool1o`00007ooooo00000ol0003oooooooooo`02ooooo`d0C02c00?o0000oc<0c?lc
0<`0;Olc0<`00ol000006@3V01T0iP1@01T0iP03o`0000000?l0003o0840003o1Oooool1o`00007o
oooo00000ol0003oooooooooo`02ooooo`/0C02c0_l0000_oc<0c003o`00000I0>H06@3V05006@3V
00?o00000000o`000?l0PP000?l5ooooo`7o00000Oooool00003o`000?oooooooooo00;ooooo2P1<
0;<00ol0003o<`3<oc<0c00^oc<0c003o`00000I0>H06@3V05006@3V00?o00000000o`000?l0P`00
0?l5ooooo`7o00000Oooool00003o`000?oooooooooo00;ooooo2@1<0;<00ol0003o<`3<oc<0c00^
oc<0c003o`00000I0>H06@3V05006@3V00?o00000000o`000?l0Q0000?l5ooooo`7o00000Oooool0
0003o`000?oooooooooo00;ooooo201<0;<00ol0003o<`3<oc<0c00^oc<0c003o`00000I0>H06@3V
05006@3V00?o00000000o`000?l0Q@000?l5ooooo`7o00000Oooool00003o`000?oooooooooo00;o
oooo1`1<0;<00ol0003o<`3<oc<0c00^oc<0c003o`00000I0>H06@3V05006@3V00?o00000000o`00
0?l0QP000?l5ooooo`7o00000Oooool00003o`000?oooooooooo00;ooooo1P1<0;<00ol0003o<`3<
oc<0c00^oc<0c003o`00000I0>H06@3V05006@3V00?o00000000o`000?l0Q`000?l5ooooo`7o0000
0Oooool00003o`000?oooooooooo00;ooooo1@1<0;<00ol0003o<`3<oc<0c00^oc<0c003o`00000I
0>H06@3V05406@3V00?o00000000o`000?l0Q`000?l5ooooo`7o00000Oooool00003o`000?oooooo
oooo00;ooooo101<0;<00ol0003o<`3<oc<0c00^oc<0c003o`00000I0>H06@3V05406@3V00?o0000
0000o`000?l0R0000?l5ooooo`7o00000Oooool00003o`000?oooooooooo00;ooooo0`1<0;<00ol0
003o<`3<oc<0c00^oc<0c003o`00000I0>H06@3V05406@3V00?o00000000o`000?l0R@000?l5oooo
o`7o00000Oooool00003o`000?oooooooooo00;ooooo0P1<0;<00ol0003o<`3<oc<0c00^oc<0c003
o`00000I0>H06@3V05406@3V00?o00000000o`000?l0RP000?l5ooooo`7o00000Oooool00003o`00
0?oooooooooo00;ooooo00<0C02co`000?lc0<`0;olc0<`00ol000006@3V01T0iP1A01T0iP03o`00
00000?l0003o08/0003o1Oooool1o`00007ooooo00000ol0003oooooooooo`02ooooo`03o`000?lc
0<co<`3<02ko<`3<00?o000001T0iP0I0>H0D@0I0>H00ol00000003o0000o`2<0000o`Gooooo0Ol0
0001ooooo`0000?o0000ooooooooool00_ooool`oc<0c003o`00000I0>H06@3V05406@3V00?o0000
0000o`000?l0S@000?l5ooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00
007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0
oooooolLooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo003o
o`00023o00000Oooool00001\
\>"],
  ImageRangeCache->{{{0, 287}, {287, 0}} -> {-1.04092, -1.04092, 0.00725378, \
0.00725378}}]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["\<\
A closer look: part #2 (visualization as a function of EM \
trajectory)\
\>", "Section"],

Cell[CellGroupData[{

Cell[TextData[{
  "Plot ",
  Cell[BoxData[
      \(TraditionalForm\`P(\[Omega]\_i | \[Theta], x\_j)\)]],
  " for sample point as a function of EM trajectory"
}], "Subsection"],

Cell[CellGroupData[{

Cell["Individual point", "Subsubsection"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(gbases = \(Show[gdata, PlotMeansTwo[#, \ pr, \ colors, \ nS], \ 
              nS] &\)\  /@ \ em2;\)\), "\n", 
    \(\ \(\(PlotExampleOne[xtst, #[\([1]\)], colors, #[\([2]\)], 1, 
            yS] &\)\  /@ \ Transpose[{em2, \ gbases}];\)\)}], "Input"],

Cell[CellGroupData[{

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.49505 0.5 0.49505 [
[ 0 0 -0.125 0 ]
[ 0 0 -0.125 0 ]
[ 0 1 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
0 0 m
1 0 L
s
0 0 m
0 1 L
s
0 1 m
1 1 L
s
1 0 m
1 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
1 .5 0 r
.015 w
.03175 .1355 Mdot
.03435 .12523 Mdot
.11137 .12765 Mdot
.14107 .18841 Mdot
.16218 .24538 Mdot
.17294 .21053 Mdot
.18267 .18577 Mdot
.18434 .1304 Mdot
.18553 .30956 Mdot
.20401 .239 Mdot
.21247 .27571 Mdot
.21687 .20845 Mdot
.22376 .2799 Mdot
.22832 .27485 Mdot
.29063 .20974 Mdot
.29686 .25079 Mdot
.30487 .22936 Mdot
.30683 .34623 Mdot
.32055 .20902 Mdot
.32574 .21979 Mdot
.34472 .28521 Mdot
.35998 .36393 Mdot
.36335 .24976 Mdot
.3794 .36608 Mdot
.42386 .66992 Mdot
.44391 .74519 Mdot
.45059 .34198 Mdot
.47208 .67586 Mdot
.47436 .71381 Mdot
.49778 .59825 Mdot
.50874 .91643 Mdot
.51516 .76219 Mdot
.53655 .61374 Mdot
.56563 .75219 Mdot
.59189 .65665 Mdot
.59581 .61604 Mdot
.59923 .6556 Mdot
.60292 .68499 Mdot
.62656 .67779 Mdot
.63555 .72451 Mdot
.63919 .652 Mdot
.64169 .6004 Mdot
.64246 .58611 Mdot
.64496 .54267 Mdot
.64608 .77288 Mdot
.65077 .64308 Mdot
.66065 .57816 Mdot
.67474 .59169 Mdot
.69296 .563 Mdot
.72815 .65902 Mdot
.73169 .58879 Mdot
.74669 .61318 Mdot
.74821 .65474 Mdot
.75963 .63781 Mdot
.79673 .57809 Mdot
.80925 .55852 Mdot
.81525 .58444 Mdot
.83417 .62985 Mdot
.83598 .55526 Mdot
.91595 .49319 Mdot
1 0 0 r
.005 w
.00495 .28842 m
.00628 .29156 L
.01857 .31761 L
.03101 .33781 L
.03525 .34367 L
.05706 .36884 L
.05795 .36972 L
.08312 .39115 L
.08963 .39578 L
.10917 .40763 L
.13523 .41964 L
.14074 .42183 L
.16128 .42794 L
.18734 .43294 L
.21339 .43485 L
.23945 .43375 L
.2655 .42959 L
.29156 .42219 L
.29261 .42183 L
.31761 .41124 L
.34367 .39603 L
.34405 .39578 L
.36972 .37551 L
.37582 .36972 L
.39578 .34724 L
.39849 .34367 L
.41525 .31761 L
.42183 .30485 L
.4275 .29156 L
.436 .2655 L
.44117 .23945 L
.44325 .21339 L
.44232 .18734 L
.43834 .16128 L
.43114 .13523 L
.42183 .11212 L
.42037 .10917 L
.40546 .08312 L
.39578 .06961 L
.38528 .05706 L
.36972 .04137 L
.35758 .03101 L
.34367 .02092 L
.31761 .00569 L
.3162 .00495 L
s
.00495 .12854 m
.01344 .10917 L
.02832 .08312 L
.03101 .07912 L
.04848 .05706 L
.05706 .04802 L
.07619 .03101 L
.08312 .02579 L
.10917 .00934 L
.11742 .00495 L
s
0 0 1 r
.29156 .15739 m
.31761 .14824 L
.34367 .14249 L
.36972 .13986 L
.39578 .14025 L
.42183 .14366 L
.44789 .15025 L
.47394 .16034 L
.47599 .16128 L
.5 .17443 L
.51844 .18734 L
.52606 .19355 L
.54662 .21339 L
.55211 .21962 L
.56712 .23945 L
.57817 .25755 L
.58227 .2655 L
.59322 .29156 L
.60058 .31761 L
.60422 .3392 L
.60471 .34367 L
.6058 .36972 L
.60422 .39297 L
.60387 .39578 L
.59886 .42183 L
.59054 .44789 L
.57848 .47394 L
.57817 .47453 L
.562 .5 L
.55211 .51255 L
.53968 .52606 L
.52606 .53862 L
.50853 .55211 L
.5 .55773 L
.47394 .57183 L
.45901 .57817 L
.44789 .5819 L
.42183 .5885 L
.39578 .59192 L
.36972 .59231 L
.34367 .58968 L
.31761 .58392 L
.29972 .57817 L
.29156 .57477 L
.2655 .56178 L
.25025 .55211 L
.23945 .54409 L
.21914 .52606 L
.21339 .52008 L
.19681 .5 L
Mistroke
.18734 .48608 L
.18031 .47394 L
.16827 .44789 L
.16128 .42714 L
.15996 .42183 L
.15493 .39578 L
.153 .36972 L
.15409 .34367 L
.15823 .31761 L
.16128 .3045 L
.16559 .29156 L
.17653 .2655 L
.18734 .24609 L
.19169 .23945 L
.21221 .21339 L
.21339 .21211 L
.23945 .1881 L
.24041 .18734 L
.2655 .17038 L
.28271 .16128 L
.29156 .15739 L
Mfstroke
1 0 0 r
.03 w
.21687 .20845 Mdot
0 0 1 r
.3794 .36608 Mdot
1 0 0 r
.79703 .00495 m
.79703 .19993 L
.87129 .19993 L
.87129 .00495 L
F
0 0 1 r
.89604 .00495 m
.89604 .0575 L
.9703 .0575 L
.9703 .00495 L
F
1 0 1 r
.04 w
.03175 .1355 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  AnimationDisplayTime->0.371293,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P000182000`400?l00000o`00003ooooooolQ
ooooo`00o`00000P0000007ooooo00000`00003oooooooooo`0Mooooo`80o`00>?ooool2ool00003
0?l00?oooooooooo0;oooooo0@000001ooooo`0000<00000ooooooooool06oooool20?l003gooooo
00<0o`00ooooooooool0Q?oooolE0?l000Sooooo5@000?l8ooooo`4000000Oooool0000300000?oo
oooooooo01[ooooo00<0o`00ooooooooool0?_ooool20?l008Cooooo5@3o0008oooooaD0003o2?oo
ool10000007ooooo00000`00003oooooooooo`0Hooooo`80o`00@oooool00`3o003oooooooooo`21
oooooaD0o`002?oooolE0000o`Sooooo0@000001ooooo`0000<00000ooooooooool05_ooool20?l0
04Kooooo00<0o`00ooooooooool0P?oooolE0?l000Sooooo5@000?l8ooooo`4000000Oooool00003
00000?oooooooooo01Gooooo00<0o`00ooooooooool0Aoooool20?l0083ooooo5@3o0008oooooaD0
003o2?ooool10000007ooooo00000`00003oooooooooo`0Dooooo`030?l00?oooooooooo04[ooooo
00<0o`00ooooooooool0OOoooolE0?l000Sooooo5@000?l8ooooo`4000000Oooool0000300000?oo
oooooooo01?ooooo00<0o`00ooooooooool0C?ooool00`3o003oooooooooo`1loooooaD0o`002?oo
oolE0000o`Sooooo0@000001ooooo`0000<00000ooooooooool04Oooool20?l0053ooooo0P3o001l
oooooaD0o`002?oooolE0000o`Sooooo0@000001ooooo`0000<00000ooooooooool04?ooool00`3o
003oooooooooo`1Booooo`80o`00N_oooolE0?l000Sooooo5@000?l8ooooo`4000000Oooool00003
00000?oooooooooo00oooooo00<0o`00ooooooooool0EOooool00`3o003oooooooooo`1goooooaD0
o`002?oooolE0000o`Sooooo0@000001ooooo`0000<00000ooooooooool03_ooool00`3o003ooooo
ooooo`1Fooooo`030?l00?oooooooooo07Oooooo5@3o0008oooooaD0003o2?ooool10000007ooooo
00000`00003oooooooooo`0=ooooo`030?l00?oooooooooo05Sooooo00<0o`00ooooooooool0M_oo
oolE0?l000Sooooo5@000?l8ooooo`4000000Oooool0000300000?oooooooooo00gooooo00<0o`00
ooooooooool0FOooool00`3o003oooooooooo`1eoooooaD0o`002?oooolE0000o`Sooooo0@000001
ooooo`0000<00000ooooooooool03?ooool00`3o003oooooooooo`1Kooooo`030?l00?oooooooooo
07Cooooo5@3o0008oooooaD0003o2?ooool10000007ooooo00000`00003oooooooooo`0;ooooo`03
0?l00?oooooooooo05gooooo00<0o`00ooooooooool0LooooolE0?l000Sooooo5@000?l8ooooo`40
00000Oooool0000300000?oooooooooo00_ooooo00<0o`00ooooooooool0GOooool00`3o003ooooo
ooooo`1coooooaD0o`009Oooool10000007ooooo00000`00003oooooooooo`0:ooooo`030?l00?oo
oooooooo05oooooo00<0o`00ooooooooool0L_oooolE0?l002Gooooo0@000001ooooo`0000<00000
ooooooooool02Oooool00`3o003oooooooooo`1Qooooo`030?l00?oooooooooo077ooooo5@3o000U
ooooo`4000000Oooool0000300000?oooooooooo00Sooooo00<0o`00ooooooooool0Hoooool00`3o
003oooooooooo`1`oooooaD0o`009Oooool10000007ooooo00000`00003oooooooooo`07ooooo`03
0?l00?oooooooooo06Gooooo00<0o`00ooooooooool0KooooolE0?l002Gooooo0@000001ooooo`00
00<00000ooooooooool01_ooool00`3o003oooooooooo`1Wooooo`030?l00?oooooooooo06kooooo
5@3o000Uooooo`4000000Oooool0000300000?oooooooooo00Gooooo00?oo`00ooooooooool0JOoo
ool00`3o003oooooooooo`1]oooooaD0o`009Oooool10000007ooooo00000`00003oooooooooo`05
ooooo`030?l00?oooooooooo06Wooooo00<0o`00ooooooooool0KOoooolE0?l002Gooooo0@000001
ooooo`0000<00000ooooooooool01?ooool00`3o003oooooooooo`1[ooooo`030?l00?oooooooooo
06cooooo5@3o000Uooooo`4000000Oooool0000300000?oooooooooo00?ooooo00<0o`00oooooooo
ool0K?ooool00`3o003oooooooooo`1/oooooaD0o`009Oooool10000007ooooo00000`00003ooooo
ooooo`03ooooo`030?l00?oooooooooo06gooooo00<0o`00ooooooooool0JooooolE0?l002Gooooo
0@000001ooooo`0000<00000ooooooooool00_ooool00`3o003oooooooooo`1^ooooo`030?l00?oo
oooooooo06_ooooo5@3o000Uooooo`4000000Oooool0000300000?oooooooooo00;ooooo00<0o`00
ooooooooool0Koooool00`3o003oooooooooo`1ZoooooaD0o`009Oooool10000007ooooo00001@00
003oooooooooooooool0o`0007;ooooo00<0o`00ooooooooool0J_oooolE0?l002Gooooo0@000001
ooooo`0000@00000ooooooooool0o`00M?ooool00`3o003oooooooooo`1YoooooaD0o`009Oooool1
0000007ooooo00001000003oooooooooo`3o001eooooo`03ool00?oooooooooo06Sooooo5@3o000U
ooooo`4000000Oooool0000300000?ooool0o`0007Kooooo00<0o`00ooooooooool0J?oooolE0?l0
02Gooooo0@000001ooooo`0000<00000ooooo`3o00001?ooool5ool0ofkooooo00<0o`00oooooooo
ool0IooooolE0?l002Gooooo0@000001ooooo`0000<00000ooooo`3o00000oooool7ool0oa;ooooo
0_ooO`1Iooooo`030?l00?oooooooooo06Oooooo5@3o000Uooooo`4000000Oooool000030000003o
003ooooo00;ooooo2Ooo0?l@ooooo`Coogl04_ooool2oomo04Cooooo00<0o`00ooooooooool0Iooo
oolE0?l002Gooooo0@000001ooooo`0000@00000oooooooooooooooo2ooo0?l?ooooo`Coogl04Ooo
ool4oomo04Cooooo00<0o`00ooooooooool0I_oooolE0?l002Gooooo0@000001ooooo`0000@00000
oooooooooooooooo2ooo0?l@ooooo`;oogl04_ooool4oomo04Cooooo00<0o`00ooooooooool0I_oo
oolE0?l002Gooooo0@000001ooooo`0000@00000oooooooooooooooo2ooo0?lUooooo`;oogl0AOoo
ool00`3o003oooooooooo`1VoooooaD0o`009Oooool10000007ooooo00001000003ooooooooooooo
ool;ool0oe7ooooo5_l00?l5ooooo`030?l00?oooooooooo06Kooooo5@3o000Uooooo`4000000Ooo
ool0000400000?ooooooooooooooo`_oo`3oC_ooool3o`00oaKooooo1_l00?l00`3o003ooooooooo
o`1UoooooaD0o`009Oooool10000007ooooo00000`00003oooooooooo`02ooooo`Woo`3oC?ooool3
o`00oaoooooo0ol00?mUoooooaD0o`009Oooool10000007ooooo00000`00003oooooooooo`03oooo
o`Ooo`3oB_ooool3o`00ob;ooooo00<0o`00ooooooooool00ol00?mRoooooaD0o`009Oooool10000
007ooooo00000`00003oooooooooo`04ooooo`Goo`3oB?ooool3o`00obGooooo00<0o`00oooooooo
ool00oooool3o`00oeoooooo5@3o000Uooooo`4000000Oooool0000300000?oooooooooo04oooooo
0P000?lYooooo`030?l00?oooooooooo00Gooooo0ol00?mLoooooaD0o`009Oooool10000007ooooo
00000`00003oooooooooo`1=ooooo`80003o:oooool00`3o003oooooooooo`08ooooo`;o003oF_oo
oolE0?l002Gooooo0@000001ooooo`0000<00000ooooooooool0B_ooool30000obgooooo00<0o`00
ooooooooool02_ooool2o`00oeSooooo5@3o000Uooooo`4000000Oooool0000300000?oooooooooo
04Sooooo0P000?l`ooooo`030?l00?oooooooooo00cooooo00?o003oooooooooool0EOoooolE0?l0
02Gooooo0@000001ooooo`0000<00000ooooooooool0Aoooool00`000?ooooooooooo`0`ooooo`03
0?l00?oooooooooo00gooooo0_l00?mEoooooaD0o`009Oooool10000007ooooo00000`00003ooooo
ooooo`15ooooo`80003o=?ooool00`3o003oooooooooo`0>ooooo`;o003oDooooolE0?l002Gooooo
0@000001ooooo`0000<00000ooooooooool0A?ooool00`000?ooooooooooo`0dooooo`030?l00?oo
oooooooo013ooooo0_l00?mAoooooaD0o`009Oooool10000007ooooo00000`00003oooooooooo`0T
ooooo`;oogl02_ooool2oomo017ooooo00<0003oooooooooool0=Oooool00`3o003oooooooooo`0B
ooooo`03o`00oooooooooooo04kooooo5@3o000Uooooo`4000000Oooool0000300000?oooooooooo
02?ooooo1?ooO`08ooooo`Coogl03oooool00`000?ooooooooooo`0fooooo`030?l00?oooooooooo
01?ooooo00?o003oooooooooool0COoooolE0?l002Gooooo0@000001ooooo`0000<00000oooooooo
ool08oooool4oomo00Sooooo1?ooO`0=ooooo`030000ool00?oooooo03Sooooo00<0o`00oooooooo
ool05?ooool00ol00?ooooooooooo`1<oooooaD0o`009Oooool10000007ooooo00000`00003ooooo
ooooo`0Tooooo`;oogl02_ooool2oomo00gooooo00<0003oooooooooool0>Oooool00`3o003ooooo
ooooo`0Eooooo`03o`00oooooooooooo04_ooooo5@3o000Uooooo`4000000Oooool0000300000?oo
oooooooo03Wooooo1?oo00000oooool0003oooooo`0kooooo`030?l00?oooooooooo01Kooooo00?o
003oooooooooool0B_oooolE0?l002Gooooo0@000001ooooo`0000<00000ooooooooool0>?ooool6
ool003gooooo00<0o`00ooooooooool05oooool00ol00?ooooooooooo`19oooooaD0o`009Oooool1
0000007ooooo00000`00003oooooooooo`0gooooo`Soo`004?ooool2oomo00Oooooo0_ooO`0Roooo
o`030?l00?oooooooooo01Oooooo00?o003oooooooooool0P_ooool10000007ooooo00000`00003o
ooooooooo`0^ooooo`;oogl01oooool8ool000oooooo1?ooO`05ooooo`Coogl08Oooool00`3o003o
ooooooooo`0Hooooo`03o`00oooooooooooo087ooooo0@000001ooooo`0000<00000ooooooooool0
;Oooool4oomo00Kooooo2?oo000?ooooo`Coogl01Oooool4oomo027ooooo00<0o`00ooooooooool0
6Oooool00ol00?ooooooooooo`20ooooo`4000000Oooool0000300000?oooooooooo02gooooo1?oo
O`06ooooo`Soo`004?ooool2oomo00Oooooo0oooO`0Qooooo`030?l00?oooooooooo01[ooooo00?o
003oooooooooool0Ooooool10000007ooooo00000`00003oooooooooo`0^ooooo`;oogl02?ooool6
ool001[ooooo1?ooO`0Pooooo`030?l00?oooooooooo01_ooooo00?o003oooooooooool0O_ooool1
0000007ooooo00000`00003oooooooooo`0hooooo`030000oooo003oo`0000;oo`006oooool4oomo
023ooooo00<0o`00ooooooooool07?ooool00ol00?ooooooooooo`1mooooo`4000000Oooool00003
00000?oooooooooo03Oooooo00<0003oooooooooool06Oooool2oomo00Cooooo0_ooO`0Qooooo`03
0?l00?oooooooooo01cooooo00?o003oooooooooool0OOooool10000007ooooo00000`00003ooooo
ooooo`0fooooo`030000oooooooooooo01Wooooo1?ooO`0Uooooo`030?l00?oooooooooo01kooooo
00?o003oooooooooool0O?ooool10000007ooooo00000`00003oooooooooo`0fooooo`030000oooo
oooooooo01Wooooo1?ooO`0Uooooo`030?l00?oooooooooo01oooooo00?o003oooooooooool0Nooo
ool10000007ooooo00000`00003oooooooooo`0eooooo`040000ooooooooogl0oomo01[ooooo0_oo
O`0Vooooo`030?l00?oooooooooo023ooooo00?o003oooooooooool0N_ooool10000007ooooo0000
0`00003oooooooooo`0dooooo`030000ooooooooogl000?oogl0@Oooool00`3o003oooooooooo`0Q
ooooo`03o`00oooooooooooo07Wooooo0@000001ooooo`0000<00000ooooooooool0:oooool2oomo
00Kooooo00<0003oooooooooool01?ooO`11ooooo`030?l00?oooooooooo027ooooo00?o003ooooo
ooooool0NOooool10000007ooooo00000`00003oooooooooo`0Zooooo`Coogl01?ooool00`000?oo
ooooooooo`02ooooo`;oogl06?ooool2oomo017ooooo0_ooO`0Eooooo`030?l00?oooooooooo02;o
oooo00?o003oooooooooool0N?ooool10000007ooooo00000`00003oooooooooo`0Zooooo`Coogl0
1?ooool00`000?ooooooooooo`0Kooooo`Coogl03oooool4oomo01Cooooo00<0o`00ooooooooool0
8oooool00ol00?ooooooooooo`1gooooo`4000000Oooool0000300000?oooooooooo02_ooooo0_oo
O`04ooooo`030000oooooooooooo01cooooo1?ooO`0?ooooo`Coogl05?ooool00`3o003ooooooooo
o`0Sooooo`03o`00oooooooooooo07Oooooo0@000001ooooo`0000<00000ooooooooool0<Oooool0
0`000?ooooooooooo`0Mooooo`;oogl04Oooool2oomo01Cooooo00<0o`00ooooooooool09Oooool0
0ol00?ooooooooooo`1fooooo`4000000Oooool0000300000?oooooooooo033ooooo00<0003ooooo
ooooool0Aoooool00`3o003oooooooooo`0Uooooo`03o`00oooooooooooo07Kooooo0@000001oooo
o`0000<00000ooooooooool0<?ooool00`000?ooooooooooo`17ooooo`030?l00?oooooooooo02Ko
oooo00?o003oooooooooool0MOooool10000007ooooo00000`00003oooooooooo`0_ooooo`030000
oooooooooooo04Sooooo00<0o`00ooooooooool09oooool00ol00?ooooooooooo`1dooooo`400000
0Oooool0000300000?oooooooooo02oooooo00<0003oooooooooool01oooool2oomo00;ooooo0_oo
O`0kooooo`030?l00?oooooooooo02Oooooo00?o003oooooooooool0M?ooool10000007ooooo0000
0`00003oooooooooo`0^ooooo`030000oooooooooooo00Oooooo2?ooO`0iooooo`030?l00?oooooo
oooo02Wooooo00?o003oooooooooool0Loooool10000007ooooo00000`00003oooooooooo`0^oooo
o`030000oooooooooooo00Oooooo2?ooO`0iooooo`030?l00?oooooooooo02Wooooo00?o003ooooo
ooooool0Loooool10000007ooooo00000`00003oooooooooo`0]ooooo`030000oooooooooooo00Wo
oooo1_ooO`0Pooooo`;oogl05oooool00`3o003oooooooooo`0[ooooo`03o`00oooooooooooo07;o
oooo0@000001ooooo`0000<00000ooooooooool0;Oooool00`000?ooooooooooo`0;ooooo`Coogl0
7oooool4oomo01Kooooo00<0o`00ooooooooool0:oooool00ol00?ooooooooooo`1booooo`400000
0Oooool0000300000?oo003ooooo02gooooo00<0003oooooooooool03?ooool2oomo023ooooo1?oo
O`0Fooooo`030?l00?oooooooooo02_ooooo00?o003oooooooooool0L_ooool10000007ooooo0000
0`000000o`00ooooo`0/ooooo`030000oooooooooooo033ooooo0_ooO`0Fooooo`030?l00?oooooo
oooo02gooooo00?o003oooooooooool0LOooool10000007ooooo00000`000000o`00ooooo`0/oooo
o`030000oooooooooooo04Sooooo00<0o`00ooooooooool0;Oooool00ol00?ooooooooooo`1aoooo
o`4000000Oooool0000300000?ooool0o`0002cooooo00<0003oooooooooool0B?ooool00`3o003o
ooooooooo`0]ooooo`03o`00oooooooooooo077ooooo0@000001ooooo`0000<00000ooooo`3o0000
:oooool00`000?ooooooooooo`18ooooo`030?l00?oooooooooo02oooooo00?o003oooooooooool0
L?ooool10000007ooooo00001000003oooooooooo`3o000Zooooo`030000oooooooooooo00?ooooo
0_ooO`13ooooo`030?l00?oooooooooo02oooooo00?o003oooooooooool0L?ooool10000007ooooo
00001000003oooooooooo`3o000Zooooo`030000oooooooooooo00;ooooo1?ooO`12ooooo`030?l0
0?oooooooooo02oooooo00?o003oooooooooool0L?ooool10000007ooooo00001@00003ooooooooo
ooooool0o`0002Wooooo00<0003oooooooooool00_ooool4oomo047ooooo00<0o`00ooooooooool0
<?ooool00ol00?ooooooooooo`1`ooooo`4000000Oooool0000500000?ooooooooooooooo`3o0000
:?ooool00`000?ooooooooooo`04ooooo`;oogl0@_ooool00`3o003oooooooooo`0aooooo`03o`00
oooooooooooo06oooooo0@000001ooooo`0000<00000ooooooooool00_ooool00`3o003ooooooooo
o`0Uooooo`030000oooooooooooo04Oooooo00<0o`00ooooooooool0<_ooool00ol00?oooooooooo
o`1_ooooo`4000000Oooool0000300000?oooooooooo00;ooooo00<0o`00ooooooooool09Oooool0
0`000?ooooooooooo`17ooooo`030?l00?oooooooooo03;ooooo00?o003oooooooooool0Koooool1
0000007ooooo00000`00003oooooooooo`03ooooo`030?l00?oooooooooo02Cooooo00<0003ooooo
ooooool0A_ooool00`3o003oooooooooo`0cooooo`03o`00oooooooooooo06oooooo0@000001oooo
o`0000<00000ooooooooool01?ooool00`3o003oooooooooo`0Sooooo`030000oooooooooooo04Go
oooo00<0o`00ooooooooool0=?ooool00ol00?ooooooooooo`1_ooooo`4000000Oooool000030000
0?oooooooooo00Gooooo00<0o`00ooooooooool08Oooool00`000?ooooooooooo`15ooooo`030?l0
0?oooooooooo03Kooooo00?o003oooooooooool0K_ooool10000007ooooo00000`00003ooooooooo
o`06ooooo`030?l00?oooooooooo023ooooo00<0003oooooooooool0AOooool00`3o003ooooooooo
o`09ooooo`;oogl0:oooool00ol00?ooooooooooo`1^ooooo`4000000Oooool0000300000?oooooo
oooo00Kooooo00<0o`00ooooooooool08?ooool00`000?ooooooooooo`14ooooo`030?l00?oooooo
oooo00Wooooo1?ooO`0Zooooo`03o`00oooooooooooo06kooooo0@000001ooooo`0000<00000oooo
ooooool01oooool00`3o003oooooooooo`0Oooooo`030000oooooooooooo02Sooooo0_ooO`0Ioooo
o`030?l00?oooooooooo00[ooooo1?ooO`0Zooooo`03o`00oooooooooooo06kooooo0@000001oooo
o`0000<00000ooooooooool01oooool00`3o003oooooooooo`0Oooooo`030000oooooooooooo02Oo
oooo1?ooO`0Gooooo`03ool00?oooooooooo00cooooo0_ooO`0[ooooo`03o`00oooooooooooo06ko
oooo0@000001ooooo`0000<00000ooooooooool02?ooool00`3o003oooooooooo`0Nooooo`030000
oooooooooooo02Oooooo1?ooO`0Gooooo`030?l00?oooooooooo03Wooooo00?o003oooooooooool0
K_ooool10000007ooooo00000`00003oooooooooo`09ooooo`030?l00?oooooooooo01gooooo00<0
003oooooooooool0:?ooool2oomo01;ooooo1?l00?l00oooool0o`00ooooo`0kooooo`03o`00oooo
oooooooo06kooooo0@000001ooooo`0000<00000ooooooooool02_ooool00`3o003oooooooooo`0L
ooooo`030000oooooooooooo03_ooooo1_l00?lmooooo`03o`00oooooooooooo06kooooo0@000001
ooooo`0000<00000ooooooooool02oooool00`3o003oooooooooo`0Kooooo`030000oooooooooooo
03Oooooo0_ooO`000ooooooo003oo`00o`06o`00occooooo00?o003oooooooooool0K_ooool10000
007ooooo00000`00003oooooooooo`0<ooooo`030?l00?oooooooooo01[ooooo00<0003ooooooooo
ool0=_ooool4oomo00So003o??ooool00ol00?ooooooooooo`1^ooooo`4000000Oooool000030000
0?oooooooooo00gooooo00?oo`00ooooooooool06Oooool00`000?ooooooooooo`0fooooo`Coogl0
2?l00?llooooo`03o`00oooooooooooo06kooooo0@000001ooooo`0000<00000ooooooooool03Ooo
ool20?l001[ooooo00<0003oooooooooool0=oooool2oomo0003ooooool00?oo003o00Ko003o??oo
ool00ol00?ooooooooooo`1^ooooo`4000000Oooool0000300000?oooooooooo00oooooo00<0o`00
ooooooooool05oooool00`000?ooooooooooo`0jooooo`030?l00?l00?oo003o00Co003o?Oooool0
0ol00?ooooooooooo`1^ooooo`4000000Oooool0000300000?oooooooooo013ooooo00<0o`00oooo
ooooool05_ooool00`000?ooooooooooo`0iooooo`030?l00?oooooooooo00Co003o?_ooool00ol0
0?ooooooooooo`1^ooooo`4000000Oooool0000300000?oooooooooo017ooooo00<0o`00oooooooo
ool05Oooool00`000?ooooooooooo`0hooooo`030?l00?oooooooooo04?ooooo00?o003ooooooooo
ool0K_ooool10000007ooooo00000`00003oooooooooo`0Booooo`030?l00?oooooooooo01Cooooo
00<0003oooooooooool0=_ooool20?l004Kooooo00?o003oooooooooool0K_ooool10000007ooooo
00000`00003oooooooooo`0Cooooo`030?l00?oooooooooo01?ooooo00<0003oooooooooool0=Ooo
ool00`3o003oooooooooo`16ooooo`03o`00oooooooooooo06kooooo0@000001ooooo`0000<00000
ooooooooool05?ooool20?l001?ooooo00<0003oooooooooool0=?ooool00`3o003oooooooooo`17
ooooo`03o`00oooooooooooo06kooooo0@000001ooooo`0000<00000ooooooooool05_ooool20?l0
017ooooo00<0003oooooooooool0<_ooool20?l004[ooooo00?o003oooooooooool0K_ooool10000
007ooooo00000`00003oooooooooo`0Hooooo`030?l00?oooooooooo00kooooo00<0003ooooooooo
ool0<Oooool00`3o003oooooooooo`1:ooooo`03o`00oooooooooooo06kooooo0@000001ooooo`00
00<00000ooooooooool06Oooool20?l000kooooo00<0003oooooooooool0;oooool20?l004gooooo
00?o003oooooooooool0K_ooool10000007ooooo00000`00003oooooooooo`0Kooooo`030?l00?oo
oooooooo00_ooooo00<0003oooooooooool0;_ooool00`3o003oooooooooo`1<ooooo`03o`00oooo
oooooooo06oooooo0@000001ooooo`0000<00000ooooooooool07?ooool20?l000_ooooo00<0003o
ooooooooool0;Oooool00`3o003oooooooooo`1=ooooo`03o`00oooooooooooo06oooooo0@000001
ooooo`0000<00000ooooooooool07_ooool30?l000Wooooo00<0003oooooooooool0:_ooool20?l0
053ooooo00?o003oooooooooool0Koooool10000007ooooo00000`00003oooooooooo`0Qooooo`80
o`001oooool00`000?ooooooooooo`0Wooooo`<0o`00D_ooool00ol00?ooooooooooo`1_ooooo`40
00000Oooool0000300000?oooooooooo02?ooooo0P3o0005ooooo`030000oooooooooooo02Gooooo
0P3o001Dooooo`03o`00oooooooooooo073ooooo0@000001ooooo`0000<00000ooooooooool09Ooo
ool40?l00003ooooo`000?oooooo02;ooooo0P3o00000ooo0000o`00ooooo`1Eooooo`03o`00oooo
oooooooo073ooooo0@000001ooooo`0000<00000ooooooooool0:Oooool20?l00003o`00o`3o0000
o`0001gooooo0`3o001Jooooo`03o`00oooooooooooo073ooooo0@000001ooooo`0000<00000oooo
ooooool0:oooool00`000?ooooooooooo`030?l001Cooooo1P3o001Mooooo`03o`00oooooooooooo
073ooooo0@000001ooooo`0000<00000ooooooooool0;?ooool00`000?ooooooooooo`02oooooa@0
o`00H_ooool00ol00?ooooooooooo`1aooooo`4000000Oooool0000300000?oooooooooo02cooooo
00<0003oooooooooool0N?ooool00ol00?ooooooooooo`1aooooo`4000000Oooool0000300000?oo
oooooooo02cooooo00<0003oooooooooool0N?ooool00ol00?ooooooooooo`1aooooo`4000000Ooo
ool0000300000?oooooooooo02gooooo00<0003oooooooooool0M_ooool00ol00?ooooooooooo`1b
ooooo`4000000Oooool0000300000?oooooooooo02gooooo00<0003oooooooooool0M_ooool00ol0
0?ooooooooooo`1booooo`4000000Oooool0000300000?oooooooooo02gooooo00<0003ooooooooo
ool0M_ooool00ol00?ooooooooooo`1booooo`4000000Oooool0000300000?oooooooooo02kooooo
00<0003oooooooooool0M?ooool00ol00?ooooooooooo`1cooooo`4000000Oooool0000300000?oo
oooooooo02kooooo00<0003oooooooooool0M?ooool00ol00?ooooooooooo`1cooooo`4000000Ooo
ool0000300000?oooooooooo02kooooo00<0003oooooooooool0M?ooool00ol00?ooooooooooo`1c
ooooo`4000000Oooool0000300000?oooooooooo02oooooo00<0003oooooooooool0L_ooool00ol0
0?ooooooooooo`1dooooo`4000000Oooool0000300000?oooooooooo02oooooo00<0003ooooooooo
ool0L_ooool00ol00?ooooooooooo`1dooooo`4000000Oooool0000300000?oooooooooo02oooooo
00<0003oooooooooool0L_ooool00ol00?ooooooooooo`1dooooo`4000000Oooool0000300000?oo
oooooooo033ooooo00<0003oooooooooool0Koooool2o`00ogOooooo0@000001ooooo`0000<00000
ooooooooool0<?ooool00`000?ooooooooooo`1_ooooo`03o`00oooooooooooo07Kooooo0@000001
ooooo`0000<00000ooooooooool0<Oooool00`000?ooooooooooo`1]ooooo`03o`00oooooooooooo
07Oooooo0@000001ooooo`0000<00000ooooooooool0<_ooool00`000?ooooooooooo`1/ooooo`03
o`00oooooooooooo07Oooooo0@000001ooooo`0000<00000ooooooooool0<_ooool00`000?oooooo
ooooo`1[ooooo`03o`00oooooooooooo063ooooo0_ooO`0Fooooo`4000000Oooool0000300000?oo
oooooooo03?ooooo00<0003oooooooooool0JOooool00ol00?ooooooooooo`1Pooooo`Coogl05Ooo
ool10000007ooooo00000`00003oooooooooo`0dooooo`030000oooooooooooo06Sooooo00?o003o
ooooooooool0H?ooool4oomo01Gooooo0@000001ooooo`0000<00000ooooooooool0=Oooool00`00
0?ooooooooooo`1Vooooo`03o`00oooooooooooo06;ooooo0_ooO`0Fooooo`4000000Oooool00003
00000?oooooooooo03Gooooo00?o003oooooooooool0I_ooool00ol00?ooooooooooo`1jooooo`40
00000Oooool0000300000?oooooooooo03Kooooo00?o003oooooooooool0I?ooool00ol00?oooooo
ooooo`1kooooo`4000000Oooool0000300000?oooooooooo03Oooooo00?o003oooooooooool0H_oo
ool00ol00?ooooooooooo`1looooo`4000000Oooool0000300000?oooooooooo03Sooooo00?o003o
ooooooooool0Goooool2o`00ogoooooo0@000001ooooo`0000<00000ooooooooool0>Oooool00ol0
0?ooooooooooo`1Mooooo`03o`00oooooooooooo07oooooo0@000001ooooo`0000<00000oooooooo
ool0>_ooool00ol00?ooooooooooo`1Kooooo`03o`00oooooooooooo083ooooo0@000001ooooo`00
00<00000ooooooooool0>oooool00ol00?ooooooooooo`1Iooooo`03o`00oooooooooooo087ooooo
0@000001ooooo`0000<00000ooooooooool0??ooool00ol00?ooooooooooo`1Gooooo`03o`00oooo
oooooooo08;ooooo0@000001ooooo`0000<00000ooooooooool0?Oooool00ol00?ooooooooooo`1E
ooooo`03o`00oooooooooooo08?ooooo0@000001ooooo`0000<00000ooooooooool0?_ooool00ol0
0?ooooooooooo`1Cooooo`03o`00oooooooooooo08Cooooo0@000001ooooo`0000<00000oooooooo
ool0?oooool00ol00?ooooooooooo`1@ooooo`;o003o8Oooool2oomo06Cooooo0@000001ooooo`00
00<00000ooooooooool0@?ooool00ol00?ooooooooooo`1>ooooo`03o`00oooooooooooo023ooooo
1?ooO`1Sooooo`4000000Oooool0000300000?oooooooooo047ooooo0_l00?m=ooooo`03o`00oooo
oooooooo027ooooo1?ooO`1Sooooo`4000000Oooool0000300000?oooooooooo04?ooooo00?o003o
ooooooooool0BOooool00ol00?ooooooooooo`0Sooooo`;oogl0=Oooool2oomo02gooooo0@000001
ooooo`0000<00000ooooooooool0A?ooool2o`00odSooooo00?o003oooooooooool0Doooool2oomo
00Gooooo1?ooO`0/ooooo`4000000Oooool0000300000?oooooooooo04Kooooo0_l00?m5ooooo`03
o`00oooooooooooo05?ooooo1?ooO`04ooooo`Coogl0;?ooool10000007ooooo00000`00003ooooo
ooooo`18ooooo`03o`00oooooooooooo043ooooo0_l00?lfooooo`;oogl07_ooool4oomo00Gooooo
0_ooO`0]ooooo`4000000Oooool0000300000?oooooooooo04Wooooo0_l00?lnooooo`;o003o=ooo
ool4oomo01kooooo0_ooO`0eooooo`4000000Oooool0000300000?oooooooooo04_ooooo0ol00?lj
ooooo`03o`00oooooooooooo03Oooooo1?ooO`1Eooooo`4000000Oooool0000300000?oooooooooo
04kooooo0_l00?lfooooo`;o003o>oooool2oomo05Kooooo0@000001ooooo`0000<00000oooooooo
ool0D?ooool3o`00oc3ooooo0ol00?lcooooo`;oogl09Oooool2oomo03Wooooo0@000001ooooo`00
00<00000ooooooooool0Doooool2o`00ob[ooooo1?l00?leooooo`Coogl08oooool4oomo03Sooooo
0@000001ooooo`0000<00000ooooooooool0EOooool3o`00ob?ooooo1?l00?leooooo`;oogl00_oo
ool4oomo02?ooooo1?ooO`03ooooo`;oogl0<oooool10000007ooooo00000`00003oooooooooo`1H
ooooo`?o003o7Oooool3o`00ocSooooo1?ooO`02ooooo`;oogl04oooool2oomo013ooooo0_ooO`03
ooooo`Coogl0<_ooool10000007ooooo00000`00003oooooooooo`1Kooooo`?o003o5?ooool6o`00
oc_ooooo1?ooO`06ooooo`;oogl03_ooool4oomo01Cooooo1?ooO`0booooo`4000000Oooool00003
00000?oooooooooo05kooooo5?l00?m2ooooo`;oogl01_ooool4oomo00gooooo1?ooO`0Eooooo`;o
ogl0<oooool10000007ooooo00000`00003oooooooooo`2;ooooo`;oogl09oooool2oomo00Kooooo
1?ooO`0>ooooo`;oogl0Boooool10000007ooooo00000`00003oooooooooo`2:ooooo`Coogl09Ooo
ool4oomo00Kooooo0_ooO`1Looooo`4000000Oooool0000300000?oooooooooo08[ooooo1?ooO`0U
ooooo`Coogl0I?ooool10000007ooooo00000`00003oooooooooo`2;ooooo`;oogl09oooool2oomo
06Gooooo0@000001ooooo`0000<00000ooooooooool0U_ooool2oomo03[ooooo0_ooO`17ooooo`40
00000Oooool0000300000?oooooooooo09Gooooo1?ooO`0>ooooo`;oogl0:?ooool4oomo04Kooooo
0@000001ooooo`0000<00000ooooooooool0UOooool4oomo00gooooo1?ooO`0Wooooo`Coogl0A_oo
ool10000007ooooo00000`00003oooooooooo`2Fooooo`;oogl03_ooool4oomo02Sooooo0_ooO`17
ooooo`4000000Oooool0000300000?oooooooooo0:Oooooo0_ooO`1booooo`4000000Oooool00003
00000?oooooooooo0>_ooooo0_ooO`0^ooooo`4000000Oooool0000300000?oooooooooo0>[ooooo
1?ooO`0]ooooo`4000000Oooool0000300000?oooooooooo0=Kooooo0_ooO`0Booooo`Coogl0;Ooo
ool10000007ooooo00000`00003oooooooooo`3Eooooo`Coogl04_ooool2oomo02kooooo0@000001
ooooo`0000<00000ooooooooool0]oooool2oomo01cooooo1?ooO`12ooooo`4000000Oooool00003
00000?oooooooooo0;Kooooo1?ooO`0Looooo`;oogl0@oooool10000007ooooo00000`00003ooooo
ooooo`2cooooo`;oogl000?ooooooomo0?ooO`000_ooO`1Qooooo`4000000Oooool0000300000?oo
oooooooo0:Sooooo0_ooO`08ooooo`Coogl000?ooooooomo0?ooO`006_ooool2oomo04Kooooo0@00
0001ooooo`0000<00000ooooooooool0Y_ooool5oomo00Oooooo1?ooO`0Gooooo`;oogl00oooool4
oomo04Gooooo0@000001ooooo`0000<00000ooooooooool0YOooool6oomo00Sooooo0_ooO`0Goooo
o`Coogl00_ooool4oomo04Gooooo0@000001ooooo`0000<00000ooooooooool0YOooool5oomo02;o
oooo1?ooO`03ooooo`;oogl0A_ooool10000007ooooo00000`00003oooooooooo`1fooooo`;oogl0
;_ooool2oomo02Gooooo0_ooO`1<ooooo`4000000Oooool0000300000?oooooooooo07Gooooo1?oo
O`2Rooooo`4000000Oooool0000300000?oooooooooo07Gooooo1?ooO`0:ooooo`;oogl0U_ooool1
0000007ooooo00000`00003oooooooooo`1fooooo`;oogl02_ooool4oomo02[ooooo0_ooO`1Yoooo
o`4000000Oooool0000300000?oooooooooo08;ooooo1?ooO`0Yooooo`Coogl0J?ooool10000007o
oooo00000`00003oooooooooo`23ooooo`;oogl09?ooool2oomo00Cooooo1?ooO`1Xooooo`400000
0Oooool0000300000?oooooooooo0:Sooooo1?ooO`04ooooo`;oogl0JOooool10000007ooooo0000
0`00003oooooooooo`2Xooooo`Coogl0Koooool10000007ooooo00000`00003oooooooooo`2Yoooo
o`;oogl0L?ooool10000007ooooo00000`00003oooooooooo`3ooooooacooooo0@000001ooooo`00
00<00000ooooooooool0oooooolLooooo`4000000Oooool0000300000?oooooooooo0?oooooo7?oo
ool10000007ooooo00000`00003oooooooooo`3ooooooacooooo0@000001ooooo`0000<00000oooo
ooooool0Q?ooool2oomo09Gooooo0@000001ooooo`0000<00000ooooooooool0Poooool4oomo09Co
oooo0@000001ooooo`0000<00000ooooooooool0Poooool4oomo09Cooooo0@000001ooooo`0000<0
0000ooooooooool0Q?ooool2oomo02cooooo0_ooO`1Wooooo`4000000Oooool0000300000?oooooo
oooo0;7ooooo1?ooO`1Vooooo`4000000Oooool0000300000?oooooooooo0;7ooooo1?ooO`1Voooo
o`4000000Oooool0000300000?oooooooooo0;;ooooo0_ooO`1Wooooo`4000000Oooool000030000
0?oooooooooo0?oooooo7?ooool10000007ooooo00000`00003oooooooooo`3ooooooacooooo0@00
0001ooooo`0000<00000ooooooooool0Noooool2oomo09kooooo0@000001ooooo`0000<00000oooo
ooooool0N_ooool4oomo09gooooo0@000001ooooo`0000<00000ooooooooool0N_ooool4oomo023o
oooo0_ooO`1kooooo`4000000Oooool0000300000?oooooooooo07_ooooo0_ooO`0Pooooo`Coogl0
N_ooool10000007ooooo00000`00003oooooooooo`2Mooooo`Coogl0N_ooool10000007ooooo0000
0`00003oooooooooo`2@ooooo`;oogl03?ooool2oomo07_ooooo0@000001ooooo`0000<00000oooo
ooooool0Soooool4oomo08Sooooo0@000001ooooo`0000<00000ooooooooool0Soooool4oomo08So
oooo0@000001ooooo`0000<00000ooooooooool0T?ooool2oomo02?ooooo0_ooO`1Tooooo`400000
0Oooool0000300000?oooooooooo0;Cooooo1?ooO`1Sooooo`4000000Oooool0000300000?oooooo
oooo0;Cooooo1?ooO`1Sooooo`4000000Oooool0000300000?oooooooooo0;Gooooo0_ooO`1Toooo
o`4000000Oooool0000300000?oooooooooo0?oooooo7?ooool10000007ooooo00000`00003ooooo
ooooo`3ooooooacooooo0@000001ooooo`0000<00000ooooooooool0oooooolLooooo`4000000Ooo
ool0000300000?oooooooooo0?oooooo7?ooool10000007ooooo00000`00003oooooooooo`3ooooo
oacooooo0@000001ooooo`0000<00000ooooooooool0oooooolLooooo`4000000Oooool000030000
0?oooooooooo0?oooooo7?ooool10000007ooooo00000`00003oooooooooo`3ooooooacooooo0@00
0001ooooo`0000<00000ooooooooool0oooooolLooooo`4000000Oooool0000300000?oooooooooo
0?oooooo7?ooool10000007ooooo00000`00003oooooooooo`3ooooooacooooo0@000001ooooo`00
00<00000ooooooooool0oooooolLooooo`4000000Oooool0000300000?oooooooooo0?oooooo7?oo
ool10000007ooooo00000`00003oooooooooo`3ooooooacooooo0@000001ooooo`0000<00000oooo
ooooool0oooooolLooooo`4000000Oooool0000300000?oooooooooo0?oooooo7?ooool10000007o
oooo00000`00003oooooooooo`3ooooooacooooo0@000001ooooo`0000<00000ooooooooool0oooo
oolLooooo`4000000Oooool0000300000?oooooooooo0?oooooo7?ooool10000007ooooo00000`00
003oooooooooo`3ooooooacooooo0@000001ooooo`0000<00000ooooooooool0oooooolLooooo`40
00000Oooool0000300000?oooooooooo0?oooooo7?ooool10000007ooooo00000`00003ooooooooo
o`3ooooooacooooo0@000001ooooo`0000<00000ooooooooool0oooooolLooooo`4000000Oooool0
000300000?oooooooooo0?oooooo7?ooool10000007ooooo00000`00003oooooooooo`3ooooooaco
oooo0@000001ooooo`0000<00000ooooooooool0oooooolLooooo`4000000Oooool0000300000?oo
oooooooo0?oooooo7?ooool10000007ooooo00000`00003oooooooooo`3ooooooacooooo0@000001
ooooo`0000<00000ooooooooool0oooooolLooooo`4000000Oooool0000300000?oooooooooo0?oo
oooo7?ooool10000007ooooo00000`00003oooooooooo`3ooooooacooooo0@000001ooooo`0000<0
0000ooooooooool0oooooolLooooo`4000000Oooool0000300000?oooooooooo0?oooooo7?ooool1
0000007ooooo00000`00003oooooooooo`3ooooooacooooo0@000001ooooo`0000<00000oooooooo
ool0oooooolLooooo`4000000Oooool0000300000?oooooooooo0?oooooo7?ooool10000007ooooo
00000`00003oooooooooo`2>ooooo`;oogl0Roooool10000007ooooo00000`00003oooooooooo`2=
ooooo`Coogl0R_ooool10000007ooooo00000`00003oooooooooo`2=ooooo`Coogl0R_ooool10000
007ooooo00000`00003oooooooooo`2>ooooo`;oogl0Roooool10000007ooooo00000`00003ooooo
ooooo`3ooooooacooooo0@000001ooooo`0000<00000ooooooooool0oooooolLooooo`4000000Ooo
ool0000300000?oooooooooo0?oooooo7?ooool10000007ooooo00000`00003oooooooooo`3ooooo
oacooooo0@000001ooooo`0000<00000ooooooooool0oooooolLooooo`4000000Oooool000030000
0?oooooooooo0?oooooo7?ooool10000007ooooo00000`00003oooooooooo`3ooooooacooooo0@00
0001ooooo`0000<00000ooooooooool0oooooolLooooo`4000000Oooool0000300000?oooooooooo
0?oooooo7?ooool10000007ooooo00000`00003oooooooooo`3ooooooacooooo0@000001ooooo`00
00<00000ooooooooool0oooooolLooooo`4000000Oooool0000300000?oooooooooo0?oooooo7?oo
ool10000007ooooo00000`00003oooooooooo`3ooooooacooooo0@000001ooooo`0000<00000oooo
ooooool0oooooolLooooo`4000000Oooool0000300000?oooooooooo0?oooooo7?ooool10000007o
oooo00000`00003oooooooooo`3ooooooacooooo0@000001ooooo`0000<00000ooooooooool0oooo
oolLooooo`4000000Oooool0000300000?oooooooooo0?oooooo7?ooool10000007ooooo00000`00
003oooooooooo`3ooooooacooooo0@000001ooooo`0000<00000ooooooooool0oooooolLooooo`40
00000Oooool0000300000?oooooooooo0?oooooo7?ooool10000007ooooo003o0000020000000Ooo
ool00001\
\>"],
  ImageRangeCache->{{{0, 287}, {287, 0}} -> {-1.01089, -1.01089, 0.00704453, \
0.00704453}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.49505 0.5 0.49505 [
[ 0 0 -0.125 0 ]
[ 0 0 -0.125 0 ]
[ 0 1 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
0 0 m
1 0 L
s
0 0 m
0 1 L
s
0 1 m
1 1 L
s
1 0 m
1 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
1 .5 0 r
.015 w
.03175 .1355 Mdot
.03435 .12523 Mdot
.11137 .12765 Mdot
.14107 .18841 Mdot
.16218 .24538 Mdot
.17294 .21053 Mdot
.18267 .18577 Mdot
.18434 .1304 Mdot
.18553 .30956 Mdot
.20401 .239 Mdot
.21247 .27571 Mdot
.21687 .20845 Mdot
.22376 .2799 Mdot
.22832 .27485 Mdot
.29063 .20974 Mdot
.29686 .25079 Mdot
.30487 .22936 Mdot
.30683 .34623 Mdot
.32055 .20902 Mdot
.32574 .21979 Mdot
.34472 .28521 Mdot
.35998 .36393 Mdot
.36335 .24976 Mdot
.3794 .36608 Mdot
.42386 .66992 Mdot
.44391 .74519 Mdot
.45059 .34198 Mdot
.47208 .67586 Mdot
.47436 .71381 Mdot
.49778 .59825 Mdot
.50874 .91643 Mdot
.51516 .76219 Mdot
.53655 .61374 Mdot
.56563 .75219 Mdot
.59189 .65665 Mdot
.59581 .61604 Mdot
.59923 .6556 Mdot
.60292 .68499 Mdot
.62656 .67779 Mdot
.63555 .72451 Mdot
.63919 .652 Mdot
.64169 .6004 Mdot
.64246 .58611 Mdot
.64496 .54267 Mdot
.64608 .77288 Mdot
.65077 .64308 Mdot
.66065 .57816 Mdot
.67474 .59169 Mdot
.69296 .563 Mdot
.72815 .65902 Mdot
.73169 .58879 Mdot
.74669 .61318 Mdot
.74821 .65474 Mdot
.75963 .63781 Mdot
.79673 .57809 Mdot
.80925 .55852 Mdot
.81525 .58444 Mdot
.83417 .62985 Mdot
.83598 .55526 Mdot
.91595 .49319 Mdot
1 0 0 r
.005 w
.13523 .12963 m
.16128 .13452 L
.16351 .13523 L
.18734 .14391 L
.21339 .15753 L
.22039 .16128 L
.23945 .17299 L
.26091 .18734 L
.2655 .19077 L
.29156 .21032 L
.2955 .21339 L
.31761 .23138 L
.32704 .23945 L
.34367 .25419 L
.35581 .2655 L
.36972 .27885 L
.38227 .29156 L
.39578 .3056 L
.40661 .31761 L
.42183 .33499 L
.42886 .34367 L
.44789 .36834 L
.44886 .36972 L
.46675 .39578 L
.47394 .40387 L
.48125 .42183 L
.49205 .44789 L
.49265 .47394 L
.47394 .48987 L
.44789 .48896 L
.42183 .47934 L
.40687 .47394 L
.39578 .467 L
.36972 .45162 L
.36361 .44789 L
.34367 .43458 L
.32583 .42183 L
.31761 .41554 L
.29292 .39578 L
.29156 .39464 L
.2655 .37218 L
.26277 .36972 L
.23945 .34798 L
.23504 .34367 L
.21339 .32174 L
.20953 .31761 L
.18734 .29299 L
.18613 .29156 L
.16468 .2655 L
.16128 .26171 L
Mistroke
.14551 .23945 L
.13523 .22493 L
.12925 .21339 L
.11602 .18734 L
.10925 .16128 L
.11787 .13523 L
.13523 .12963 L
Mfstroke
0 0 1 r
.39578 .36451 m
.42183 .36132 L
.44789 .36378 L
.47273 .36972 L
.47394 .37008 L
.5 .3793 L
.52606 .39123 L
.53497 .39578 L
.55211 .40548 L
.57773 .42183 L
.57817 .42214 L
.60422 .44107 L
.61285 .44789 L
.63028 .46255 L
.64283 .47394 L
.65633 .48696 L
.66889 .5 L
.68239 .51498 L
.69159 .52606 L
.70844 .54815 L
.71118 .55211 L
.7278 .57817 L
.7345 .58967 L
.74122 .60422 L
.75113 .63028 L
.75669 .65633 L
.75639 .68239 L
.74594 .70844 L
.7345 .71983 L
.70844 .73022 L
.68239 .73184 L
.65633 .72851 L
.63028 .72154 L
.60422 .71161 L
.59684 .70844 L
.57817 .69924 L
.55211 .6844 L
.54883 .68239 L
.52606 .66734 L
.51093 .65633 L
.5 .64785 L
.47906 .63028 L
.47394 .62573 L
.45147 .60422 L
.44789 .60059 L
.4274 .57817 L
.42183 .57168 L
.40649 .55211 L
.39578 .5372 L
.38864 .52606 L
Mistroke
.37387 .5 L
.36972 .49285 L
.36243 .47394 L
.35489 .44789 L
.35243 .42183 L
.35776 .39578 L
.36972 .37737 L
.37974 .36972 L
.39578 .36451 L
Mfstroke
1 0 0 r
.03 w
.30139 .31039 Mdot
0 0 1 r
.55494 .54667 Mdot
1 0 0 r
.79703 .00495 m
.79703 .22561 L
.87129 .22561 L
.87129 .00495 L
F
0 0 1 r
.89604 .00495 m
.89604 .03181 L
.9703 .03181 L
.9703 .00495 L
F
1 0 1 r
.04 w
.03175 .1355 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  AnimationDisplayTime->0.371293,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P000182000`400?l00000o`00003ooooooolQ
ooooo`00ool0000Po`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`00
00?o0000ooooooooool0hOoooolEool000Sooooo5Ol00?l8ooooo`7o00000Oooool00003o`000?oo
oooooooo0>7ooooo5Ooo0008oooooaGo003o2?ooool1o`00007ooooo00000ol0003oooooooooo`3Q
oooooaGoo`002?oooolEo`00o`Sooooo0Ol00001ooooo`0000?o0000ooooooooool0hOoooolEool0
00Sooooo5Ol00?l8ooooo`7o00000Oooool00003o`000?oooooooooo0>7ooooo5Ooo0008oooooaGo
003o2?ooool1o`00007ooooo00000ol0003oooooooooo`3QoooooaGoo`002?oooolEo`00o`Sooooo
0Ol00001ooooo`0000?o0000ooooooooool0hOoooolEool000Sooooo5Ol00?l8ooooo`7o00000Ooo
ool00003o`000?oooooooooo0>7ooooo5Ooo0008oooooaGo003o2?ooool1o`00007ooooo00000ol0
003oooooooooo`3QoooooaGoo`009Oooool1o`00007ooooo00000ol0003oooooooooo`3QoooooaGo
o`009Oooool1o`00007ooooo00000ol0003oooooooooo`3QoooooaGoo`009Oooool1o`00007ooooo
00000ol0003oooooooooo`3QoooooaGoo`009Oooool1o`00007ooooo00000ol0003oooooooooo`3Q
oooooaGoo`009Oooool1o`00007ooooo00000ol0003oooooooooo`3QoooooaGoo`009Oooool1o`00
007ooooo00000ol0003oooooooooo`3QoooooaGoo`009Oooool1o`00007ooooo00000ol0003ooooo
ooooo`3QoooooaGoo`009Oooool1o`00007ooooo00000ol0003oooooooooo`3QoooooaGoo`009Ooo
ool1o`00007ooooo00000ol0003oooooooooo`3QoooooaGoo`009Oooool1o`00007ooooo00000ol0
003oooooooooo`3QoooooaGoo`009Oooool1o`00007ooooo00000ol0003oooooooooo`3QoooooaGo
o`009Oooool1o`00007ooooo00000ol0003oooooooooo`3QoooooaGoo`009Oooool1o`00007ooooo
00000ol0003oooooooooo`3QoooooaGoo`009Oooool1o`00007ooooo00000ol0003oooooooooo`3Q
oooooaGoo`009Oooool1o`00007ooooo00000ol0003oooooooooo`3QoooooaGoo`009Oooool1o`00
007ooooo00000ol0003oooooooooo`3QoooooaGoo`009Oooool1o`00007ooooo00000ol0003ooooo
ooooo`3QoooooaGoo`009Oooool1o`00007ooooo00000ol0003oooooooooo`3QoooooaGoo`009Ooo
ool1o`00007ooooo00000ol0003oooooooooo`3QoooooaGoo`009Oooool1o`00007ooooo00000ol0
003oooooooooo`3QoooooaGoo`009Oooool1o`00007ooooo00000ol0003oooooooooo`3QoooooaGo
o`009Oooool1o`00007ooooo00000ol0003oooooooooo`3QoooooaGoo`009Oooool1o`00007ooooo
00000ol0003oooooooooo`3QoooooaGoo`009Oooool1o`00007ooooo00000ol0003oooooooooo`04
ooooo`Goo`3of?oooolEool002Gooooo0Ol00001ooooo`0000?o0000ooooooooool00oooool7ool0
oa;ooooo0_ooO`33oooooaGoo`009Oooool1o`00007ooooo00000ol0003oooooooooo`02ooooo`Wo
o`3o4?ooool4oomo01;ooooo0_ooO`2^oooooaGoo`009Oooool1o`00007ooooo00001?l0003ooooo
ooooooooool;ool0o`oooooo1?ooO`02ooooo`<0o`001?oo0008ooooo`Coogl0[OoooolEool002Go
oooo0Ol00001ooooo`0000Co0000oooooooooooooooo2ooo0?l@ooooo`;oogl00`3o0007ooooo`Ko
o`000_ooool4oomo0:gooooo5Ooo000Uooooo`7o00000Oooool00004o`000?ooooooooooooooo`_o
o`3o4_ooool00`3o003oooooooooo`0=ooooo`;oo`0000?ooooooomo0?ooO`00[_oooolEool002Go
oooo0Ol00001ooooo`0000Co0000oooooooooooooooo2ooo0?lBooooo`030?l00?oooooooooo00oo
oooo0_oo002_oooooaGoo`009Oooool1o`00007ooooo00001?l0003oooooooooooooool;ool0oa7o
oooo00<0o`00ooooooooool04_ooool2ool00:gooooo5Ooo000Uooooo`7o00000Oooool00003o`00
0?oooooooooo00;ooooo2Ooo0?lBooooo`030?l00?oooooooooo01Cooooo0_oo002[oooooaGoo`00
9Oooool1o`00007ooooo00000ol0003oooooooooo`03ooooo`Ooo`3o4oooool00`3o003ooooooooo
o`0Fooooo`;oo`00ZOoooolEool002Gooooo0Ol00001ooooo`0000?o0000ooooooooool01?ooool5
ool0oaCooooo00<0o`00ooooooooool06?ooool2ool00:Oooooo5Ooo000Uooooo`7o00000Oooool0
0003o`000?oooooooooo01cooooo00<0o`00ooooooooool06oooool2ool00:Gooooo5Ooo000Uoooo
o`7o00000Oooool00003o`000?oooooooooo01cooooo00<0o`00ooooooooool07Oooool2ool00:?o
oooo5Ooo000Uooooo`7o00000Oooool00003o`000?oooooooooo01cooooo00<0o`00ooooooooool0
7oooool2ool00:7ooooo5Ooo000Uooooo`7o00000Oooool00003o`000?oooooooooo01cooooo00<0
o`00ooooooooool08Oooool00ooo003oooooooooo`2NoooooaGoo`009Oooool1o`00007ooooo0000
0ol0003oooooooooo`0Mooooo`030?l00?oooooooooo027ooooo0_oo002NoooooaGoo`009Oooool1
o`00007ooooo00000ol0003oooooooooo`0Mooooo`030?l00?oooooooooo02?ooooo00?oo`00oooo
ooooool0VooooolEool002Gooooo0Ol00001ooooo`0000?o0000ooooooooool07Oooool00`3o003o
ooooooooo`0Tooooo`;oo`00VooooolEool002Gooooo0Ol00001ooooo`0000?o0000ooooooooool0
7_ooool00`3o003oooooooooo`03ooooo`;oogl02_ooool2oomo01Cooooo00?oo`00ooooooooool0
V?oooolEool002Gooooo0Ol00001ooooo`0000?o0000ooooooooool07_ooool00`3o003ooooooooo
o`02ooooo`Coogl02?ooool4oomo01Cooooo0_oo002HoooooaGoo`009Oooool1o`00007ooooo0000
0ol0003oooooooooo`0Nooooo`030?l00?oooooooooo00;ooooo1?ooO`08ooooo`Coogl05_ooool2
ool009Kooooo5Ooo000Uooooo`7o00000Oooool00003o`000?oooooooooo01oooooo00<0o`00oooo
ooooool00_ooool2oomo00[ooooo0_ooO`0Iooooo`03ool00?oooooooooo09?ooooo5Ooo000Uoooo
o`7o00000Oooool00003o`000?oooooooooo01oooooo00<0o`00ooooooooool0:_ooool00ooo003o
ooooooooo`2BoooooaGoo`009Oooool1o`00007ooooo00000ol0003oooooooooo`0Pooooo`030?l0
0?oooooooooo02[ooooo00?oo`00ooooooooool0TOoooolEool002Gooooo0Ol00001ooooo`0000?o
0000ooooooooool08?ooool00`3o003oooooooooo`0Gooooo`;oogl04_ooool00ooo003oogl0oomo
0007ooooo`;oogl0QooooolEool002Gooooo0Ol00001ooooo`0000?o0000ooooooooool08Oooool0
0`3o003oooooooooo`0:ooooo`;oogl02Oooool4oomo017ooooo00Coogl0ool00?ooO`3oogl01Ooo
ool4oomo08Kooooo5Ooo000Uooooo`7o00000Oooool00003o`000?oooooooooo027ooooo00<0o`00
ooooooooool02Oooool4oomo00Sooooo1?ooO`0Aooooo`;oogl000?oo`00oomo0?ooool01?ooool4
oomo08Kooooo5Ooo000Uooooo`7o00000Oooool00003o`000?oooooooooo02;ooooo00<0o`00oooo
ooooool02?ooool4oomo00Wooooo0_ooO`0Cooooo`;oogl00_oo0005ooooo`?oogl0Q_oooolEool0
02Gooooo0Ol00001ooooo`0000?o0000ooooooooool08_ooool00`3o003oooooooooo`09ooooo`;o
ogl08oooool00ooo003oooooooooo`02ooooo`Coogl0QOoooolEool002Gooooo0Ol00001ooooo`00
00?o0000ooooooooool08oooool00`3o003oooooooooo`0^ooooo`;oo`000_ooool4oomo08Gooooo
5Ooo000Uooooo`7o00000Oooool00003o`000?oooooooooo02?ooooo00<0o`00ooooooooool0;Ooo
ool2oomo0004oooooooo003oooooooooo`;oogl0Q_oooolEool002Gooooo0Ol00001ooooo`0000?o
0000ooooooooool08oooool00`3o003oooooooooo`0/ooooo`Coogl000?oooooool00?ooool0`_oo
ool1o`00007ooooo00000ol0003oooooooooo`0Tooooo`030?l00?oooooooooo02_ooooo1?ooO`02
ooooo`03ool00?oooooooooo0<3ooooo0Ol00001ooooo`0000?o0000ooooooooool09Oooool00`3o
003oooooooooo`0?ooooo`;oogl06_ooool2oomo00Cooooo00?oo`00ooooooooool0_oooool1o`00
007ooooo00000ol0003oooooooooo`0Vooooo`030?l00?oooooooooo00gooooo1?ooO`0Pooooo`03
ool00?oooooooooo0;kooooo0Ol00001ooooo`0000?o0000ooooooooool09_ooool00`3o003ooooo
ooooo`02ooooo`;oogl02Oooool4oomo027ooooo00?oo`00ooooooooool0_Oooool1o`00007ooooo
00000ol0003oooooooooo`0Wooooo`030?l00?oooooooooo00Coogl02Oooool2oomo01Sooooo0_oo
O`09ooooo`03ool00?oooooooooo00Gooooo0_ooO`2eooooo`7o00000Oooool00003o`000?oooooo
oooo02Sooooo00<0o`00ooooooooO`000oooO`0Rooooo`Coogl02Oooool00ooo003oooooooooo`03
ooooo`Coogl0]?ooool1o`00007ooooo00000ol0003oooooooooo`0Yooooo`040?l00?ooooooogl0
oomo02?ooooo1?ooO`0:ooooo`03ool00?oooooooooo00;ooooo1?ooO`2dooooo`7o00000Oooool0
0003o`000?oooooooooo02Wooooo00<0o`00ooooooooool09Oooool2oomo00cooooo0_oo0003oooo
o`;oogl0]Oooool1o`00007ooooo00000ol0003oooooooooo`0Zooooo`030?l00?oooooooooo03Co
oooo00?oo`00ooooooooool0]oooool1o`00007ooooo00000ol0003oooooooooo`0[ooooo`030?l0
0?oooooooooo03Cooooo00?oo`00ooooooooool0]_ooool1o`00007ooooo00000ol0003ooooooooo
o`0/ooooo`03ool00?oooooooooo03Cooooo00?oo`00ooooooooool0]Oooool1o`00007ooooo0000
0ol0003oooooooooo`0/ooooo`03ool00?oooooooooo00[ooooo0_ooO`02ooooo`;oogl09Oooool0
0ooo003oooooooooo`2dooooo`7o00000Oooool00003o`000?oooooooooo02gooooo00?oo`00oooo
ooooool02?ooool8oomo02Gooooo00?oo`00ooooooooool0/oooool1o`00007ooooo00000ol0003o
ooooooooo`0^ooooo`03ool00?oooooooooo00Oooooo2?ooO`0Vooooo`03ool00?oooooooooo0;;o
oooo0Ol00001ooooo`0000?o0000ooooooooool0;oooool00ooo003oooooooooo`07ooooo`Koogl0
8?ooool2oomo00Kooooo00?oo`00ooooooooool0/Oooool1o`00007ooooo00000ol0003ooooooooo
o`0`ooooo`03ool00?oooooooooo00Sooooo1?ooO`0Oooooo`Coogl01_ooool00ooo003ooooooooo
o`2`ooooo`7o00000Oooool00003o`000?oooooooooo037ooooo00?oo`00ooooooooool02?ooool2
oomo023ooooo1?ooO`07ooooo`03ool00?oooooooooo0:oooooo0Ol00001ooooo`0000?o0000oooo
ooooool0<_ooool00ooo003oooooooooo`0Zooooo`;oogl02Oooool00ooo003oooooooooo`2^oooo
o`7o00000Oooool00003o`000?oooooooooo03;ooooo00?oo`00ooooooooool0=_ooool00ooo003o
ooooooooo`2]ooooo`7o00000Oooool00003o`000?oooooooooo03?ooooo00?oo`00ooooooooool0
6oooool4ool001Oooooo00?oo`00ooooooooool0[?ooool1o`00007ooooo00000ol0003ooooooooo
o`0dooooo`03ool00?oooooooooo01Wooooo1_oo000Gooooo`03ool00?oooooooooo0:_ooooo0Ol0
0001ooooo`0000?o0000ooooooooool0<Oooool2oomo00;ooooo00?oo`00ooooooooool05oooool8
ool001Oooooo00?oo`00ooooooooool0Z_ooool1o`00007ooooo00000ol0003oooooooooo`0`oooo
o`Coogl00_ooool00ooo003oooooooooo`0Fooooo`Soo`005oooool00ooo003oooooooooo`2Zoooo
o`7o00000Oooool00003o`000?oooooooooo033ooooo1?ooO`03ooooo`03ool00?oooooooooo01Go
oooo2?oo000Hooooo`03ool00?oooooooooo0:Wooooo0Ol00001ooooo`0000?o0000ooooooooool0
<Oooool2oomo00Gooooo00?oo`00ooooooooool05?ooool8ool001Wooooo00?oo`00ooooooooool0
Z?ooool1o`00007ooooo00000ol0003oooooooooo`0iooooo`03ool00?oooooooooo01Cooooo1_oo
000Kooooo`03ool00?oooooooooo0:Oooooo0Ol00001ooooo`0000?o0000ooooooooool0>_ooool0
0ooo003oooooooooo`0Dooooo`Coo`007Oooool00ooo003oooooooooo`2Vooooo`7o00000Oooool0
0003o`000?oooooooooo03_ooooo00?oo`00ooooooooool0=Oooool00ooo003oooooooooo`2Uoooo
o`7o00000Oooool00003o`000?oooooooooo03cooooo00?oo`00ooooooooool0=Oooool00ooo003o
ooooooooo`2Tooooo`7o00000Oooool00003o`000?oooooooooo03gooooo00?oo`00ooooooooool0
=Oooool00ooo003oooooooooo`2Sooooo`7o00000Oooool00003o`000?oooooooooo03kooooo00?o
o`00ooooooooool0=Oooool00ooo003oooooooooo`04ooooo`;oogl0W?ooool1o`00007ooooo0000
0ol0003oooooooooo`0oooooo`03ool00?oooooooooo03Gooooo00?oo`00ooooooooool00_ooool4
oomo09_ooooo0Ol00001ooooo`0000?o0000ooooooooool0@?ooool00ooo003oooooooooo`0Aoooo
o`;oogl08_ooool01?oo003oooooooooooooool4oomo09_ooooo0Ol00001ooooo`0000?o0000oooo
ooooool0@Oooool00ooo003oooooooooo`0?ooooo`Coogl08Oooool00ooo003oooooooooo`02oooo
o`;oogl0W?ooool1o`00007ooooo00000ol0003oooooooooo`12ooooo`03ool00?oooooooooo00ko
oooo1?ooO`0Rooooo`03ool00?oooooooooo09oooooo0Ol00001ooooo`0000?o0000ooooooooool0
@oooool00ooo003oooooooooo`0>ooooo`;oogl09?ooool00ooo003oooooooooo`2Nooooo`7o0000
0Oooool00003o`000?oooooooooo04Cooooo00?oo`00ooooooooool0=?ooool00ooo003ooooooooo
o`2Mooooo`7o00000Oooool00003o`000?oooooooooo04Gooooo00?oo`00ooooooooool06oooool2
oomo00Cooooo0_ooO`07ooooo`T0003o00?oo`00ooooooooool0WOooool1o`00007ooooo00000ol0
003oooooooooo`16ooooo`03ool00?oooooooooo01Wooooo1?ooO`02ooooo`Coogl000?ooooo0000
o`000?l00`000?l9ooooo`D0003oVoooool1o`00007ooooo00000ol0003oooooooooo`17ooooo`03
ool00?oooooooooo01Sooooo1?ooO`02ooooo`?oogl00P000?l@ooooo`03ool00?oooooooooo00<0
003oV?ooool1o`00007ooooo00000ol0003oooooooooo`18ooooo`;oo`006Oooool2oomo00Cooooo
0P000?lBooooo`03ool00?oooooooooo00?ooooo00<0003oo`00o`000?l00P000?nCooooo`7o0000
0Oooool00003o`000?oooooooooo04[ooooo00?oo`00ooooooooool06oooool00`000?oooooooooo
o`0Booooo`03ool00?oooooooooo00Sooooo0`000?n@ooooo`7o00000Oooool00003o`000?oooooo
oooo04_ooooo00?oo`00ooooooooool06Oooool00`000?ooooooooooo`0Dooooo`03ool00?oooooo
oooo00[ooooo0`000?n=ooooo`7o00000Oooool00003o`000?oooooooooo04cooooo00?oo`00oooo
ooooool06?ooool00`000?ooooooooooo`0Eooooo`03ool00?oooooooooo00cooooo0P000?n;oooo
o`7o00000Oooool00003o`000?oooooooooo04gooooo00?oo`00ooooooooool05_ooool00`000?oo
ooooooooo`0Gooooo`03ool00?oooooooooo00gooooo00<0003oooooooooool0R?ooool1o`00007o
oooo00000ol0003oooooooooo`1>ooooo`03ool00?oooooooooo01Cooooo00<0003oooooooooool0
6?ooool00ooo003oooooooooo`0>ooooo`80003oR?ooool1o`00007ooooo00000ol0003ooooooooo
o`1?ooooo`03ool00?oooooooooo01;ooooo00<0003oooooooooool06_ooool00ooo003ooooooooo
o`0?ooooo`<0003oQOooool1o`00007ooooo00000ol0003oooooooooo`1@ooooo`?oo`004?ooool0
0`000?ooooooooooo`0Looooo`;oo`004_ooool20000oh?ooooo0Ol00001ooooo`0000?o0000oooo
ooooool0Doooool00ooo003oooooooooo`0=ooooo`030000oooooooooooo01kooooo00?oo`00oooo
ooooool04Oooool20000oh7ooooo0Ol00001ooooo`0000?o0000ooooooooool0E?ooool00ooo003o
ooooooooo`0<ooooo`030000oooooooooooo01oooooo00?oo`00ooooooooool04_ooool00`000?oo
ooooooooo`1nooooo`7o00000Oooool00003o`000?oooooooooo05Gooooo00?oo`00ooooooooool0
2oooool00`000?ooooooooooo`0Oooooo`03ool00?oooooooooo01?ooooo0P000?mnooooo`7o0000
0Oooool00003o`000?oooooooooo05Kooooo00?oo`00ooooooooool02_ooool00`000?oooooooooo
o`0Pooooo`03ool00?oooooooooo01Cooooo00<0003oooooooooool0Noooool1o`00007ooooo0000
0ol0003oooooooooo`1Gooooo`03ool00?oooooooooo00Sooooo00<0003oooooooooool08Oooool0
0ooo003oooooooooo`0Eooooo`80003oNoooool1o`00007ooooo00000ol0003oooooooooo`1Hoooo
o`03ool00?oooooooooo00Oooooo00<0003oooooooooool08Oooool00ooo003oooooooooo`0Goooo
o`030000oooooooooooo07Sooooo0Ol00001ooooo`0000?o0000ooooooooool0FOooool00ooo003o
ooooooooo`06ooooo`030000oooooooooooo02;ooooo00?oo`00ooooooooool05oooool00`000?oo
ooooooooo`1gooooo`7o00000Oooool00003o`000?oooooooooo05[ooooo0_oo0006ooooo`030000
oooooooooooo02;ooooo00?oo`00ooooooooool06?ooool20000ogOooooo0Ol00001ooooo`0000?o
0000ooooooooool0G?ooool2ool000Cooooo00<0003oooooooooool08_ooool00ooo003ooooooooo
o`0Jooooo`030000oooooooooooo07Cooooo0Ol00001ooooo`0000?o0000ooooooooool0G_ooool0
1Ooo003oooooooooooooool0003o02Gooooo00?oo`00ooooooooool06_ooool20000ogCooooo0Ol0
0001ooooo`0000?o0000ooooooooool0Goooool2ool00003ooooo`000?oooooo02Cooooo00?oo`00
ooooooooool07?ooool20000og;ooooo0Ol00001ooooo`0000?o0000ooooooooool0HOooool00ooo
0000003oooooo`0Uooooo`03ool00?oooooooooo01gooooo00<0003oooooooooool0Koooool1o`00
007ooooo00000ol0003oooooooooo`1Rooooo`030000oooo003ooooo02Cooooo00?oo`00oooooooo
ool07_ooool00`000?ooooooooooo`1^ooooo`7o00000Oooool00003o`000?oooooooooo06;ooooo
00<0003ooooooooo00009?ooool00ooo003oooooooooo`0Oooooo`030000oooooooooooo06gooooo
0Ol00001ooooo`0000?o0000ooooooooool0H_ooool00`000?ooooooooooo`02ool002?ooooo00?o
o`00ooooooooool07oooool20000ofgooooo0Ol00001ooooo`0000?o0000ooooooooool0H_ooool0
0`000?ooooooooooo`02ooooo`;oo`008Oooool00ooo003oooooooooo`0Qooooo`030000oooooooo
oooo06[ooooo0Ol00001ooooo`0000?o0000ooooooooool0Hoooool00`000?ooooooooooo`03oooo
o`03ool00?oooooooooo01kooooo00?oo`00ooooooooool08_ooool00`000?ooooooooooo`1Yoooo
o`7o00000Oooool00003o`000?oooooooooo06?ooooo00<0003oooooooooool01?ooool2ool001ko
oooo00?oo`00ooooooooool08oooool00`000?ooooooooooo`1Xooooo`7o00000Oooool00003o`00
0?oooooooooo06?ooooo00<0003oooooooooool01_ooool00ooo003oooooooooo`0Kooooo`03ool0
0?oooooooooo02Cooooo00<0003oooooooooool0Ioooool1o`00007ooooo00000ol0003ooooooooo
o`1Tooooo`030000oooooooooooo00Kooooo00?oo`00ooooooooool06_ooool00ooo003ooooooooo
o`0Uooooo`030000oooooooooooo06Kooooo0Ol00001ooooo`0000?o0000ooooooooool0I?ooool0
0`000?ooooooooooo`07ooooo`;oo`006_ooool00ooo003oooooooooo`0Vooooo`030000oooooooo
oooo06Gooooo0Ol00001ooooo`0000?o0000ooooooooool0I?ooool00`000?ooooooooooo`09oooo
o`03ool00?oooooooooo01Oooooo00?oo`00ooooooooool09oooool00`000?ooooooooooo`1Toooo
o`7o00000Oooool00003o`000?oooooooooo06Gooooo00<0003oooooooooool02Oooool4ool001Co
oooo0_oo000Zooooo`80003oI?ooool1o`00007ooooo00000ol0003oooooooooo`1Uooooo`030000
oooooooooooo00gooooo0ooo000@ooooo`03ool00?oooooooooo02cooooo00<0003oooooooooool0
HOooool1o`00007ooooo00000ol0003oooooooooo`1Vooooo`030000oooooooooooo00oooooo0ooo
000<ooooo`03ool00?oooooooooo02kooooo00<0003oooooooooool0H?ooool1o`00007ooooo0000
0ol0003oooooooooo`1Vooooo`030000oooooooooooo01;ooooo0_oo0009ooooo`03ool00?oooooo
oooo033ooooo00<0003oooooooooool0Goooool1o`00007ooooo00000ol0003oooooooooo`1Voooo
o`030000oooooooooooo01Cooooo2Ooo000cooooo`030000oooooooooooo04Oooooo0_ooO`0Foooo
o`7o00000Oooool00003o`000?oooooooooo06Oooooo00<0003oooooooooool0D?ooool00`000?oo
ooooooooo`15ooooo`Coogl05Oooool1o`00007ooooo00000ol0003oooooooooo`1Wooooo`030000
oooooooooooo057ooooo00<0003oooooooooool0A?ooool4oomo01Gooooo0Ol00001ooooo`0000?o
0000ooooooooool0J?ooool00`000?ooooooooooo`1Aooooo`030000oooooooooooo04Cooooo0_oo
O`0Fooooo`7o00000Oooool00003o`000?oooooooooo06Sooooo00<0003oooooooooool0D_ooool0
0`000?ooooooooooo`1Kooooo`7o00000Oooool00003o`000?oooooooooo06Wooooo00<0003ooooo
ooooool0D_ooool00`000?ooooooooooo`1Jooooo`7o00000Oooool00003o`000?oooooooooo06Wo
oooo00<0003oooooooooool0Doooool00`000?ooooooooooo`1Iooooo`7o00000Oooool00003o`00
0?oooooooooo06[ooooo00<0003oooooooooool0Doooool00`000?ooooooooooo`1Hooooo`7o0000
0Oooool00003o`000?oooooooooo06_ooooo00<0003oooooooooool0Doooool00`000?oooooooooo
o`1Gooooo`7o00000Oooool00003o`000?oooooooooo06_ooooo00<0003oooooooooool0E?ooool0
0`000?ooooooooooo`1Fooooo`7o00000Oooool00003o`000?oooooooooo06cooooo00<0003ooooo
ooooool0E?ooool00`000?ooooooooooo`1Eooooo`7o00000Oooool00003o`000?oooooooooo06co
oooo00<0003oooooooooool0E?ooool00`000?ooooooooooo`1Eooooo`7o00000Oooool00003o`00
0?oooooooooo06gooooo00<0003oooooooooool0E?ooool00`000?ooooooooooo`1Dooooo`7o0000
0Oooool00003o`000?oooooooooo06gooooo00<0003oooooooooool0:_ooool4o`00obOooooo00<0
003oooooooooool0Doooool1o`00007ooooo00000ol0003oooooooooo`1^ooooo`030000oooooooo
oooo02Sooooo1_l00?lFooooo`;oogl03oooool00`000?ooooooooooo`1Booooo`7o00000Oooool0
0003o`000?oooooooooo06kooooo00<0003oooooooooool09oooool8o`00oaCooooo1?ooO`0>oooo
o`030000oooooooooooo05;ooooo0Ol00001ooooo`0000?o0000ooooooooool0Koooool00`000?oo
ooooooooo`0Vooooo`So003o5?ooool4oomo00oooooo00<0003oooooooooool0DOooool1o`00007o
oooo00000ol0003oooooooooo`1`ooooo`030000oooooooooooo02Gooooo2?l00?lEooooo`;oogl0
4Oooool00ol00?ooooooooooo`0Qooooo`;oogl0;Oooool1o`00007ooooo00000ol0003ooooooooo
o`1aooooo`030000oooooooooooo02Cooooo2?l00?lYooooo`030000oooooooooooo01Sooooo0_oo
O`05ooooo`Coogl0;?ooool1o`00007ooooo00000ol0003oooooooooo`1aooooo`030000oooooooo
oooo02Gooooo1_l00?lZooooo`030000oooooooooooo01Oooooo1?ooO`04ooooo`Coogl0;?ooool1
o`00007ooooo00000ol0003oooooooooo`1booooo`030000oooooooooooo02Gooooo1?l00?lUoooo
o`;oogl01Oooool00`000?ooooooooooo`0Fooooo`Coogl01Oooool2oomo02gooooo0Ol00001oooo
o`0000?o0000ooooooooool0Loooool00`000?ooooooooooo`1<ooooo`Coogl01?ooool00`000?oo
ooooooooo`0Gooooo`;oogl0=Oooool1o`00007ooooo00000ol0003oooooooooo`1dooooo`030000
oooooooooooo04_ooooo1?ooO`05ooooo`030000oooooooooooo04gooooo0Ol00001ooooo`0000?o
0000ooooooooool0MOooool00`000?ooooooooooo`1;ooooo`;oogl01oooool00`000?oooooooooo
o`1<ooooo`7o00000Oooool00003o`000?oooooooooo07Kooooo00<0003oooooooooool0@?ooool2
oomo017ooooo00<0003oooooooooool04Oooool2oomo03Wooooo0Ol00001ooooo`0000?o0000oooo
ooooool0Moooool00ol00?ooooooooooo`0nooooo`Coogl04Oooool00`000?ooooooooooo`0?oooo
o`Coogl0>?ooool1o`00007ooooo00000ol0003oooooooooo`1gooooo`030000oooooooooooo03[o
oooo0_ooO`02ooooo`Coogl04Oooool00`000?ooooooooooo`0?ooooo`Coogl00oooool2oomo03?o
oooo0Ol00001ooooo`0000?o0000ooooooooool0N?ooool00`000?ooooooooooo`0hooooo`Coogl0
0_ooool2oomo01?ooooo00<0003ooomo0?ooool03oooool2oomo00?ooooo1?ooO`0booooo`7o0000
0Oooool00003o`000?oooooooooo07Wooooo00<0003oooooooooool0=oooool4oomo00Kooooo0_oo
O`0>ooooo`04oomo00000?ooogl0oomo01Cooooo1?ooO`0booooo`7o00000Oooool00003o`000?oo
oooooooo07[ooooo00<0003oooooooooool0=oooool2oomo00Kooooo1?ooO`0=ooooo`;oogl000<0
003ooomo0?ooool05?ooool2oomo03?ooooo0Ol00001ooooo`0000?o0000ooooooooool0Noooool0
0`000?ooooooooooo`0=ooooo`;oogl09oooool2oomo00Kooooo1?ooO`0>ooooo`03oomo00000?oo
oooo04[ooooo0Ol00001ooooo`0000?o0000ooooooooool0O?ooool00`000?ooooooooooo`0;oooo
o`Coogl09Oooool4oomo00Kooooo0_ooO`0Aooooo`030000oooooooooooo04Sooooo0Ol00001oooo
o`0000?o0000ooooooooool0OOooool00`000?ooooooooooo`0:ooooo`Coogl09Oooool4oomo01Wo
oooo00<0003oooooooooool0B?ooool1o`00007ooooo00000ol0003oooooooooo`1nooooo`03o`00
o`000?oooooo00[ooooo0_ooO`0Wooooo`;oogl06oooool00`000?ooooooooooo`17ooooo`7o0000
0Oooool00003o`000?oooooooooo083ooooo00<0003oooooooooool04oooool2oomo03Wooooo00<0
003ooomo0?ooO`00Aoooool1o`00007ooooo00000ol0003oooooooooo`21ooooo`030000oooooooo
oooo017ooooo1?ooO`0>ooooo`;oogl0:?ooool01?ooO`00003ooomo0?ooO`16ooooo`7o00000Ooo
ool00003o`000?oooooooooo08;ooooo00<0003oooooooooool04?ooool4oomo00gooooo1?ooO`0W
ooooo`04oomo00000?ooogl0oomo04Kooooo0Ol00001ooooo`0000?o0000ooooooooool0Poooool0
0`000?ooooooooooo`0@ooooo`;oogl03_ooool4oomo02Sooooo00?oogl00000ooooool0A_ooool1
o`00007ooooo00000ol0003oooooooooo`24ooooo`030000oooooooooooo023ooooo0_ooO`0Zoooo
o`030000oooooooooooo04Gooooo0Ol00001ooooo`0000?o0000ooooooooool0QOooool00`000?oo
ooooooooo`1;ooooo`030000oooooooooooo01Gooooo0_ooO`0^ooooo`7o00000Oooool00003o`00
0?oooooooooo08Kooooo00?o003o0000ooooool0Boooool00`000?ooooooooooo`0Cooooo`Coogl0
;Oooool1o`00007ooooo00000ol0003oooooooooo`28ooooo`030000oooooooooooo04Wooooo00@0
003oooooooooO`3oogl04_ooool4oomo02gooooo0Ol00001ooooo`0000?o0000ooooooooool0ROoo
ool00`000?ooooooooooo`18ooooo`030000ooooO`3oogl000;oogl04_ooool2oomo02kooooo0Ol0
0001ooooo`0000?o0000ooooooooool0R_ooool00`000?ooooooooooo`0Zooooo`;oogl07?ooool0
10000?ooogl0oomo0?ooO`12ooooo`7o00000Oooool00003o`000?oooooooooo08_ooooo00<0003o
ooooooooool0:?ooool4oomo01_ooooo00<0003ooomo0?ooO`00@oooool1o`00007ooooo00000ol0
003oooooooooo`2<ooooo`030000oooooooooooo02Cooooo0_ooO`000oooooooogl0oomo0002oomo
01_ooooo00<0003oooooooooool0@oooool1o`00007ooooo00000ol0003oooooooooo`2=ooooo`03
0000oooooooooooo01Sooooo0_ooO`08ooooo`Coogl000?ooooooomo0?ooO`006_ooool2oomo0003
0000oooooooooooo04?ooooo0Ol00001ooooo`0000?o0000ooooooooool0S_ooool00`000?oooooo
ooooo`0Eooooo`Googl01oooool4oomo01Oooooo0_ooO`03ooooo`Coogl000<0003oooooooooool0
@_ooool1o`00007ooooo00000ol0003oooooooooo`2?ooooo`80003o5?ooool6oomo00Sooooo0_oo
O`0Gooooo`Coogl00_ooool4oomo00030000oooooooooooo04;ooooo0Ol00001ooooo`0000?o0000
ooooooooool0TOooool00`000?ooooooooooo`0Aooooo`Googl08_ooool4oomo00?ooooo0_ooO`00
0oooool0003oooooo`13ooooo`7o00000Oooool00003o`000?oooooooooo07Kooooo0_ooO`0Joooo
o`030000oooooooooooo017ooooo0_ooO`0Uooooo`;oogl01oooool00`000?ooooooooooo`12oooo
o`7o00000Oooool00003o`000?oooooooooo07Gooooo1?ooO`0Jooooo`80003o@Oooool00`000?oo
ooooooooo`12ooooo`7o00000Oooool00003o`000?oooooooooo07Gooooo1?ooO`0:ooooo`;oogl0
4?ooool20000ocoooooo00<0003oooooooooool0@_ooool1o`00007ooooo00000ol0003ooooooooo
o`1fooooo`;oogl02_ooool4oomo017ooooo00<0003oooooooooool05_ooool2oomo02Cooooo00<0
003oooooooooool0@_ooool1o`00007ooooo00000ol0003oooooooooo`22ooooo`Coogl04_ooool2
0000oaGooooo1?ooO`0Sooooo`030000oooooooooooo04;ooooo0Ol00001ooooo`0000?o0000oooo
ooooool0Poooool2oomo01Gooooo00<0003oooooooooool03?ooool2oomo00Cooooo1?ooO`0Soooo
o`030000oooooooooooo04;ooooo0Ol00001ooooo`0000?o0000ooooooooool0Voooool00ol00?l0
003oooooo`0:ooooo`Coogl01?ooool2oomo02Cooooo00<0003oooooooooool0@_ooool1o`00007o
oooo00000ol0003oooooooooo`2Mooooo`80003o2Oooool4oomo02Wooooo00<0003oooooooooool0
@oooool1o`00007ooooo00000ol0003oooooooooo`2Oooooo`030000oooooooooooo00Oooooo0_oo
O`0Zooooo`030000oooooooooooo04?ooooo0Ol00001ooooo`0000?o0000ooooooooool0X?ooool2
0000oc?ooooo00<0003oooooooooool0@oooool1o`00007ooooo00000ol0003oooooooooo`2Roooo
o`80003o<?ooool00`000?ooooooooooo`14ooooo`7o00000Oooool00003o`000?oooooooooo0:Co
oooo0P000?l^ooooo`030000oooooooooooo04Cooooo0Ol00001ooooo`0000?o0000ooooooooool0
Y_ooool20000obcooooo00<0003oooooooooool0A?ooool1o`00007ooooo00000ol0003ooooooooo
o`24ooooo`;oogl08_ooool20000obSooooo0P000?m7ooooo`7o00000Oooool00003o`000?oooooo
oooo08?ooooo1?ooO`0Sooooo`80003o9Oooool00`000?ooooooooooo`17ooooo`7o00000Oooool0
0003o`000?oooooooooo08?ooooo1?ooO`0Uooooo`<0003o8Oooool00`000?ooooooooooo`18oooo
o`7o00000Oooool00003o`000?oooooooooo08Cooooo0_ooO`0Yooooo`80003o00?ooooooomo0?oo
O`006_ooool20000od_ooooo0Ol00001ooooo`0000?o0000ooooooooool0/Oooool30000o`03oomo
0?oooooooooo01Cooooo0`000?m=ooooo`7o00000Oooool00003o`000?oooooooooo0;7ooooo0ooo
O`040000oa7ooooo0P000?m@ooooo`7o00000Oooool00003o`000?oooooooooo0;;ooooo0_ooO`04
oooooa40003oD_ooool1o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001oooo
o`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo07_ooooo
0_ooO`2Nooooo`7o00000Oooool00003o`000?oooooooooo07[ooooo1?ooO`2Mooooo`7o00000Ooo
ool00003o`000?oooooooooo07[ooooo1?ooO`0Pooooo`;oogl0Noooool1o`00007ooooo00000ol0
003oooooooooo`1kooooo`;oogl08?ooool4oomo07[ooooo0Ol00001ooooo`0000?o0000oooooooo
ool0WOooool4oomo07[ooooo0Ol00001ooooo`0000?o0000ooooooooool0T?ooool2oomo00cooooo
0_ooO`1kooooo`7o00000Oooool00003o`000?oooooooooo08oooooo1?ooO`28ooooo`7o00000Ooo
ool00003o`000?oooooooooo08oooooo1?ooO`28ooooo`7o00000Oooool00003o`000?oooooooooo
093ooooo0_ooO`0Sooooo`;oogl0I?ooool1o`00007ooooo00000ol0003oooooooooo`2dooooo`Co
ogl0Hoooool1o`00007ooooo00000ol0003oooooooooo`2dooooo`Coogl0Hoooool1o`00007ooooo
00000ol0003oooooooooo`2eooooo`;oogl0I?ooool1o`00007ooooo00000ol0003oooooooooo`3o
oooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003
o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo
0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oooooo
oooo0?oooooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001oooo
o`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo
7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000
ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00
007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0
oooooolLooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo0000
0ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLoooo
o`7o00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003ooooo
ooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Ooo
ool00003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooo
oacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`00
0?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol0
0001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo
0?oooooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`00
00?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?oo
ool1o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000oooo
ooooool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007o
oooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooo
oolLooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0
003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0S_ooool2oomo08_o
oooo0Ol00001ooooo`0000?o0000ooooooooool0SOooool4oomo08[ooooo0Ol00001ooooo`0000?o
0000ooooooooool0SOooool4oomo08[ooooo0Ol00001ooooo`0000?o0000ooooooooool0S_ooool2
oomo08_ooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003
o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo
0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oooooo
oooo0?oooooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001oooo
o`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo
7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000
ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00
007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0
oooooolLooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo0000
0ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLoooo
o`7o00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003ooooo
ooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Ooo
ool00003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooo
oacooooo0Ol00001ooooo`00ool0000Po`00007ooooo0000\
\>"],
  ImageRangeCache->{{{0, 287}, {287, 0}} -> {-1.01089, -1.01089, 0.00704453, \
0.00704453}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.49505 0.5 0.49505 [
[ 0 0 -0.125 0 ]
[ 0 0 -0.125 0 ]
[ 0 1 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
0 0 m
1 0 L
s
0 0 m
0 1 L
s
0 1 m
1 1 L
s
1 0 m
1 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
1 .5 0 r
.015 w
.03175 .1355 Mdot
.03435 .12523 Mdot
.11137 .12765 Mdot
.14107 .18841 Mdot
.16218 .24538 Mdot
.17294 .21053 Mdot
.18267 .18577 Mdot
.18434 .1304 Mdot
.18553 .30956 Mdot
.20401 .239 Mdot
.21247 .27571 Mdot
.21687 .20845 Mdot
.22376 .2799 Mdot
.22832 .27485 Mdot
.29063 .20974 Mdot
.29686 .25079 Mdot
.30487 .22936 Mdot
.30683 .34623 Mdot
.32055 .20902 Mdot
.32574 .21979 Mdot
.34472 .28521 Mdot
.35998 .36393 Mdot
.36335 .24976 Mdot
.3794 .36608 Mdot
.42386 .66992 Mdot
.44391 .74519 Mdot
.45059 .34198 Mdot
.47208 .67586 Mdot
.47436 .71381 Mdot
.49778 .59825 Mdot
.50874 .91643 Mdot
.51516 .76219 Mdot
.53655 .61374 Mdot
.56563 .75219 Mdot
.59189 .65665 Mdot
.59581 .61604 Mdot
.59923 .6556 Mdot
.60292 .68499 Mdot
.62656 .67779 Mdot
.63555 .72451 Mdot
.63919 .652 Mdot
.64169 .6004 Mdot
.64246 .58611 Mdot
.64496 .54267 Mdot
.64608 .77288 Mdot
.65077 .64308 Mdot
.66065 .57816 Mdot
.67474 .59169 Mdot
.69296 .563 Mdot
.72815 .65902 Mdot
.73169 .58879 Mdot
.74669 .61318 Mdot
.74821 .65474 Mdot
.75963 .63781 Mdot
.79673 .57809 Mdot
.80925 .55852 Mdot
.81525 .58444 Mdot
.83417 .62985 Mdot
.83598 .55526 Mdot
.91595 .49319 Mdot
1 0 0 r
.005 w
.13523 .13221 m
.14458 .13523 L
.16128 .13852 L
.18734 .15373 L
.20207 .16128 L
.21339 .16878 L
.23945 .18731 L
.23949 .18734 L
.2655 .20617 L
.27475 .21339 L
.29156 .22672 L
.30634 .23945 L
.31761 .24898 L
.33517 .2655 L
.34367 .27298 L
.36165 .29156 L
.36972 .29883 L
.38581 .31761 L
.39578 .32705 L
.40731 .34367 L
.42183 .36475 L
.42523 .36972 L
.4417 .39578 L
.43862 .42183 L
.42183 .42718 L
.39851 .42183 L
.39578 .42084 L
.36972 .41048 L
.346 .39578 L
.34367 .39481 L
.31761 .37794 L
.30565 .36972 L
.29156 .35957 L
.27125 .34367 L
.2655 .3392 L
.24048 .31761 L
.23945 .31681 L
.21339 .293 L
.2119 .29156 L
.18734 .26739 L
.18557 .2655 L
.16162 .23945 L
.16128 .23898 L
.13972 .21339 L
.13523 .20647 L
.12137 .18734 L
.10955 .16128 L
.11168 .13523 L
.13523 .13221 L
s
0 0 1 r
.44789 .41113 m
.47394 .40667 L
.5 .40755 L
.52606 .41235 L
.55211 .42041 L
.55609 .42183 L
.57817 .43131 L
.60422 .4451 L
.60897 .44789 L
.63028 .46169 L
.64696 .47394 L
.65633 .48144 L
.67729 .5 L
.68239 .50488 L
.70235 .52606 L
.70844 .53309 L
.72311 .55211 L
.7345 .56885 L
.73995 .57817 L
.75305 .60422 L
.76055 .62312 L
.76213 .63028 L
.76676 .65633 L
.7656 .68239 L
.76055 .69909 L
.7558 .70844 L
.7345 .7296 L
.72735 .7345 L
.70844 .73974 L
.68239 .74254 L
.65633 .74048 L
.63028 .73472 L
.62941 .7345 L
.60422 .72593 L
.57817 .71418 L
.56714 .70844 L
.55211 .69967 L
.52638 .68239 L
.52606 .68215 L
.5 .66148 L
.49417 .65633 L
.47394 .63687 L
.46775 .63028 L
.44789 .60686 L
.44588 .60422 L
.42792 .57817 L
.42183 .5683 L
.41377 .55211 L
.4035 .52606 L
.39758 .5 L
Mistroke
.39694 .47394 L
.40375 .44789 L
.42183 .42453 L
.42524 .42183 L
.44789 .41113 L
Mfstroke
1 0 0 r
.03 w
.27425 .27943 Mdot
0 0 1 r
.58177 .57452 Mdot
1 0 0 r
.79703 .00495 m
.79703 .248 L
.87129 .248 L
.87129 .00495 L
F
0 0 1 r
.89604 .00495 m
.89604 .00943 L
.9703 .00943 L
.9703 .00495 L
F
1 0 1 r
.04 w
.03175 .1355 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  AnimationDisplayTime->0.371293,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P000182000`400?l00000o`00003oo`3ooolQ
0?ooo`00ool0000Po`000040oooo00000ol00000oooo0?ooo`3o0?oooa`0oooo0Ol000010?ooo`00
00?o00000?ooo`3oool0h@3ooolE0?l000P0oooo5@000?l80?ooo`7o00000@3oool00003o`00003o
ool0oooo0>40oooo5@3o000U0?ooo`7o00000@3oool00003o`00003oool0oooo0>40oooo5@3o000U
0?ooo`7o00000@3oool00003o`00003oool0oooo0>40oooo5@3o000U0?ooo`7o00000@3oool00003
o`00003oool0oooo0>40oooo5@3o000U0?ooo`7o00000@3oool00003o`00003oool0oooo0>40oooo
5@3o000U0?ooo`7o00000@3oool00003o`00003oool0oooo0>40oooo5@3o000U0?ooo`7o00000@3o
ool00003o`00003oool0oooo0>40oooo5@3o000U0?ooo`7o00000@3oool00003o`00003oool0oooo
0>40oooo5@3o000U0?ooo`7o00000@3oool00003o`00003oool0oooo0>40oooo5@3o000U0?ooo`7o
00000@3oool00003o`00003oool0oooo0>40oooo5@3o000U0?ooo`7o00000@3oool00003o`00003o
ool0oooo0>40oooo5@3o000U0?ooo`7o00000@3oool00003o`00003oool0oooo0>40oooo5@3o000U
0?ooo`7o00000@3oool00003o`00003oool0oooo0>40oooo5@3o000U0?ooo`7o00000@3oool00003
o`00003oool0oooo0>40oooo5@3o000U0?ooo`7o00000@3oool00003o`00003oool0oooo0>40oooo
5@3o000U0?ooo`7o00000@3oool00003o`00003oool0oooo0>40oooo5@3o000U0?ooo`7o00000@3o
ool00003o`00003oool0oooo0>40oooo5@3o000U0?ooo`7o00000@3oool00003o`00003oool0oooo
0>40oooo5@3o000U0?ooo`7o00000@3oool00003o`00003oool0oooo0>40oooo5@3o000U0?ooo`7o
00000@3oool00003o`00003oool0oooo0>40oooo5@3o000U0?ooo`7o00000@3oool00003o`00003o
ool0oooo0>40oooo5@3o000U0?ooo`7o00000@3oool00003o`00003oool0oooo0>40oooo5@3o000U
0?ooo`7o00000@3oool00003o`00003oool0oooo0>40oooo5@3o000U0?ooo`7o00000@3oool00003
o`00003oool0oooo0>40oooo5@3o000U0?ooo`7o00000@3oool00003o`00003oool0oooo0>40oooo
5@3o000U0?ooo`7o00000@3oool00003o`00003oool0oooo0>40oooo5@3o000U0?ooo`7o00000@3o
ool00003o`00003oool0oooo0>40oooo5@3o000U0?ooo`7o00000@3oool00003o`00003oool0oooo
0>40oooo5@3o000U0?ooo`7o00000@3oool00003o`00003oool0oooo0>40oooo5@3o000U0?ooo`7o
00000@3oool00003o`00003oool0oooo0>40oooo5@3o000U0?ooo`7o00000@3oool00003o`00003o
ool0oooo0>40oooo5@3o000U0?ooo`7o00000@3oool00003o`00003oool0oooo00@0oooo1Ooo0?oH
0?oooaD0o`009@3oool1o`000040oooo00000ol00000oooo0?ooo`030?ooo`Ooo`3o4P3oool2oomo
0<<0oooo5@3o000U0?ooo`7o00000@3oool00003o`00003oool0oooo0080oooo2Ooo0?l@0?ooo`Co
ogl04P3oool2oomo0:h0oooo5@3o000U0?ooo`7o00000@3oool00004o`00003oool0oooo0?ooo`_o
o`3o3`3oool4oomo0140oooo1?ooO`2]0?oooaD0o`009@3oool1o`000040oooo00001?l00000oooo
0?ooo`3oool;ool0oa00oooo00?oogl00?l0003o00002`3o00060?ooo`Coogl0[@3ooolE0?l002D0
oooo0Ol000010?ooo`0000Co00000?ooo`3oool0oooo2ooo0?lA0?ooo`030?l0003oool0oooo00X0
oooo0`3o00040?ooo`;oogl0[P3ooolE0?l002D0oooo0Ol000010?ooo`0000Co00000?ooo`3oool0
oooo2ooo0?lA0?ooo`030?l0003oool0oooo00d0oooo00<0o`000?ooo`3oool0/@3ooolE0?l002D0
oooo0Ol000010?ooo`0000Co00000?ooo`3oool0oooo2ooo0?lA0?ooo`030?l0003oool0oooo00h0
oooo0P3o002a0?oooaD0o`009@3oool1o`000040oooo00000ol00000oooo0?ooo`020?ooo`Woo`3o
4P3oool00`3o0000oooo0?ooo`0@0?ooo`030?l0003oool0oooo0:h0oooo5@3o000U0?ooo`7o0000
0@3oool00003o`00003oool0oooo00<0oooo1ooo0?lB0?ooo`030?l0003oool0oooo0180oooo00<0
o`000?ooo`3oool0[@3ooolE0?l002D0oooo0Ol000010?ooo`0000?o00000?ooo`3oool0103oool5
ool0oa<0oooo00<0o`000?ooo`3oool04`3oool20?l00:d0oooo5@3o000U0?ooo`7o00000@3oool0
0003o`00003oool0oooo01`0oooo00<0o`000?ooo`3oool05@3oool30?l00:X0oooo5@3o000U0?oo
o`7o00000@3oool00003o`00003oool0oooo01`0oooo00<0o`000?ooo`3oool0603oool20?l00:P0
oooo5@3o000U0?ooo`7o00000@3oool00003o`00003oool0oooo01`0oooo00<0o`000?ooo`3oool0
6P3oool00`3o0000oooo0?ooo`2U0?oooaD0o`009@3oool1o`000040oooo00000ol00000oooo0?oo
o`0M0?ooo`030?l0003oool0oooo01X0oooo0P3o002U0?oooaD0o`009@3oool1o`000040oooo0000
0ol00000oooo0?ooo`0M0?ooo`030?l0003oool0oooo01`0oooo00<0o`000?ooo`3oool0XP3ooolE
0?l002D0oooo0Ol000010?ooo`0000?o00000?ooo`3oool07P3oool00`3o0000oooo0?ooo`0L0?oo
o`80o`00XP3ooolE0?l002D0oooo0Ol000010?ooo`0000?o00000?ooo`3oool07P3oool00`3o0000
oooo0?ooo`0N0?ooo`030?l0003oool0oooo09l0oooo5@3o000U0?ooo`7o00000@3oool00003o`00
003oool0oooo01h0oooo00<0o`000?ooo`3oool00`3oool2oomo00X0oooo0_ooO`0>0?ooo`030?l0
003oool0oooo09h0oooo5@3o000U0?ooo`7o00000@3oool00003o`00003oool0oooo01l0oooo00@0
o`000?ooo`3oool0oooo1?ooO`080?ooo`Coogl03P3oool20?l009h0oooo5@3o000U0?ooo`7o0000
0@3oool00003o`00003oool0oooo01l0oooo00@0o`000?ooo`3oool0oooo1?ooO`080?ooo`Coogl0
3P3oool00ooo0000oooo0?l0002M0?oooaD0o`009@3oool1o`000040oooo00000ol00000oooo0?oo
o`0P0?ooo`040?l0003oool0oooo0?ooo`;oogl02P3oool2oomo0180oooo00<0o`000?ooo`3oool0
VP3ooolE0?l002D0oooo0Ol000010?ooo`0000?o00000?ooo`3oool08@3oool00`3o0000oooo0?oo
o`0Q0?ooo`80o`00VP3ooolE0?l002D0oooo0Ol000010?ooo`0000?o00000?ooo`3oool08@3oool0
0`3o0000oooo0?ooo`0S0?ooo`030?l0003oool0oooo09L0oooo5@3o000U0?ooo`7o00000@3oool0
0003o`00003oool0oooo0280oooo00<0o`000?ooo`3oool05@3oool2oomo00`0oooo00<0o`000?oo
o`3oool0103oool2oomo00L0oooo0_ooO`270?oooaD0o`009@3oool1o`000040oooo00000ol00000
oooo0?ooo`0S0?ooo`030?l0003oool0oooo00P0oooo0_ooO`090?ooo`Coogl0303oool00`3o0000
oooo0?ooo`020?ooo`Coogl01@3oool4oomo08H0oooo5@3o000U0?ooo`7o00000@3oool00003o`00
003oool0oooo02@0oooo00<0o`000?ooo`3oool01P3oool4oomo00P0oooo1?ooO`0=0?ooo`040?l0
003oool0oooo0?ooo`Coogl01@3oool4oomo08H0oooo5@3o000U0?ooo`7o00000@3oool00003o`00
003oool0oooo02D0oooo00<0o`000?ooo`3oool01@3oool4oomo00T0oooo0_ooO`0?0?ooo`80o`00
0P3oool2oomo00L0oooo0oooO`260?oooaD0o`009@3oool1o`000040oooo00000ol00000oooo0?oo
o`0U0?ooo`030?l0003oool0oooo00H0oooo0_ooO`0M0?ooo`030?l0003oool0oooo00P0oooo1?oo
O`250?oooaD0o`009@3oool1o`000040oooo00000ol00000oooo0?ooo`0V0?ooo`030?l0003oool0
oooo02D0oooo00<0o`000?ooo`3oool01`3oool4oomo08D0oooo5@3o000U0?ooo`7o00000@3oool0
0003o`00003oool0oooo02L0oooo00<0o`000?ooo`3oool09@3oool0103o0000oooo0?ooo`3oool2
oomo00@0oooo0_ooO`260?oooaD0o`009@3oool1o`000040oooo00000ol00000oooo0?ooo`0X0?oo
o`030?l0003oool0oooo02D0oooo0P3o0004oomo08/0oooo5@3o000U0?ooo`7o00000@3oool00003
o`00003oool0oooo02T0oooo00<0o`000?ooo`3oool09P3oool0103o003oogl0oomo0?ooO`2;0?oo
oaD0o`009@3oool1o`000040oooo00000ol00000oooo0?ooo`0Z0?ooo`030?l0003oool0oooo00X0
oooo0_ooO`0J0?ooo`030?l00?ooO`00oooo08/0oooo5@3o000U0?ooo`7o00000@3oool00003o`00
003oool0oooo02/0oooo00<0o`000?ooo`3oool0203oool4oomo01X0oooo0P3o002;0?oooaD0o`00
9@3oool1o`000040oooo00000ol00000oooo0?ooo`0[0?ooo`030?l00?ooO`00oooo00P0oooo1?oo
O`0L0?ooo`030?l0003oool0oooo08P0oooo5@3o000U0?ooo`7o00000@3oool00003o`00003oool0
oooo02X0oooo0_ooO`000`3o003oogl00?ooo`080?ooo`;oogl0603oool2oomo00@0oooo00<0o`00
0?ooo`3oool02P3oool2oomo07/0oooo5@3o000U0?ooo`7o00000@3oool00003o`00003oool0oooo
02X0oooo0oooO`000`3o0000oooo0?ooo`0P0?ooo`Coogl0103oool00`3o0000oooo0?ooo`080?oo
o`Coogl0NP3ooolE0?l002D0oooo0Ol000010?ooo`0000?o00000?ooo`3oool0:`3oool2oomo0003
0?ooo`3o0000oooo0200oooo1?ooO`050?ooo`030?l0003oool0oooo00L0oooo1?ooO`2d0?ooo`7o
00000@3oool00003o`00003oool0oooo02l0oooo00<0o`000?ooo`3oool07`3oool2oomo00L0oooo
00<0o`000?ooo`3oool01`3oool2oomo0;D0oooo0Ol000010?ooo`0000?o00000?ooo`3oool0<03o
ool00`3o0000oooo0?ooo`0X0?ooo`030?l0003oool0oooo0;d0oooo0Ol000010?ooo`0000?o0000
0?ooo`3oool0<@3oool00`3o0000oooo0?ooo`0X0?ooo`030?l0003oool0oooo0;`0oooo0Ol00001
0?ooo`0000?o00000?ooo`3oool0<P3oool00`3o0000oooo0?ooo`0X0?ooo`030?l0003oool0oooo
0;/0oooo0Ol000010?ooo`0000?o00000?ooo`3oool0<`3oool00`3o0000oooo0?ooo`030?ooo`;o
ogl00P3oool2oomo00/0oooo1?oo000@0?ooo`030?l0003oool0oooo0;X0oooo0Ol000010?ooo`00
00?o00000?ooo`3oool0=03oool0103o0000oooo0?ooo`3oool8oomo00T0oooo1_oo000@0?ooo`03
0?l0003oool0oooo0;T0oooo0Ol000010?ooo`0000?o00000?ooo`3oool0=@3oool00`3o0000oooo
0?ooo`08oomo00P0oooo2?oo000@0?ooo`030?l0003oool0oooo0;P0oooo0Ol000010?ooo`0000?o
00000?ooo`3oool0=P3oool00`3o0000oooo0?ooo`06oomo00T0oooo2?oo000?0?ooo`;oogl000<0
o`000?ooo`3oool0]`3oool1o`000040oooo00000ol00000oooo0?ooo`0g0?ooo`040?l0003oool0
oooo0?ooo`Coogl02@3oool8ool000h0oooo1?ooO`000`3o0000oooo0?ooo`2f0?ooo`7o00000@3o
ool00003o`00003oool0oooo03P0oooo00@0o`000?ooo`3oool0oooo0_ooO`0:0?ooo`Soo`003P3o
ool4oomo00030?ooo`3o0000oooo0;H0oooo0Ol000010?ooo`0000?o00000?ooo`3oool0>@3oool0
0`3o0000oooo0?ooo`0=0?ooo`Koo`00403oool2oomo00<0oooo0P3o002e0?ooo`7o00000@3oool0
0003o`00003oool0oooo03X0oooo00?oo`000?l0003oool03@3oool4ool001P0oooo00<0o`000?oo
o`3oool0/P3oool1o`000040oooo00000ol00000oooo0?ooo`0l0?ooo`030?l0003oool0oooo02P0
oooo00<0o`000?ooo`3oool0/@3oool1o`000040oooo00000ol00000oooo0?ooo`0m0?ooo`030?l0
003oool0oooo02L0oooo00<0o`000?ooo`3oool0/@3oool1o`000040oooo00000ol00000oooo0?oo
o`0a0?ooo`;oogl02`3oool00`3o0000oooo0?ooo`0W0?ooo`030?l0003oool0oooo0;00oooo0Ol0
00010?ooo`0000?o00000?ooo`3oool0<03oool4oomo00/0oooo00<0o`000?ooo`3oool09`3oool0
0`3o0000oooo0?ooo`2_0?ooo`7o00000@3oool00003o`00003oool0oooo0300oooo1?ooO`0<0?oo
o`030?l0003oool0oooo02H0oooo00<0o`000?ooo`3oool0[`3oool1o`000040oooo00000ol00000
oooo0?ooo`0a0?ooo`;oogl03P3oool00`3o0000oooo0?ooo`0V0?ooo`030?l0003oool0oooo0:h0
oooo0Ol000010?ooo`0000?o00000?ooo`3oool0@P3oool00ooo0000o`000?ooo`0V0?ooo`80o`00
[P3oool1o`000040oooo00000ol00000oooo0?ooo`140?ooo`030?l0003oool0oooo02H0oooo00<0
o`000?ooo`3oool0Z`3oool1o`000040oooo00000ol00000oooo0?ooo`150?ooo`030?l0003oool0
oooo02H0oooo00<0o`000?ooo`3oool0ZP3oool1o`000040oooo00000ol00000oooo0?ooo`160?oo
o`030?l0003oool0oooo02D0oooo00<0o`000?ooo`3oool0ZP3oool1o`000040oooo00000ol00000
oooo0?ooo`170?ooo`030?l0003oool0oooo02D0oooo00<0o`000?ooo`3oool0Z@3oool1o`000040
oooo00000ol00000oooo0?ooo`180?ooo`030?l0003oool0oooo02D0oooo00<0o`000?ooo`3oool0
2P3oool2oomo09`0oooo0Ol000010?ooo`0000?o00000?ooo`3oool0B@3oool00`3o0000oooo0?oo
o`0T0?ooo`030?l0003oool0oooo00T0oooo1?ooO`2K0?ooo`7o00000@3oool00003o`00003oool0
oooo04X0oooo00?oo`000?l0003oool01`3oool2oomo01/0oooo00<0o`000?ooo`3oool0203oool4
oomo09/0oooo0Ol000010?ooo`0000?o00000?ooo`3oool0C03oool00`3o0000oooo0?ooo`040?oo
o`Coogl06P3oool00`3o0000oooo0?ooo`090?ooo`;oogl0W03oool1o`000040oooo00000ol00000
oooo0?ooo`1=0?ooo`030?l0003oool0oooo00<0oooo1?ooO`0K0?ooo`030?l0003oool0oooo0:H0
oooo0Ol000010?ooo`0000?o00000?ooo`3oool0CP3oool00`3o0000oooo0?ooo`030?ooo`;oogl0
7@3oool00`3o0000oooo0?ooo`2U0?ooo`7o00000@3oool00003o`00003oool0oooo04l0oooo00<0
o`000?ooo`3oool08P3oool00`3o0000oooo0?ooo`2T0?ooo`7o00000@3oool00003o`00003oool0
oooo0500oooo0P3o000A0?ooo`;oogl0103oool2oomo00X0oooo00<0o`000?ooo`3oool0X`3oool1
o`000040oooo00000ol00000oooo0?ooo`1B0?ooo`030?l0003oool0oooo00d0oooo1?ooO`020?oo
o`Coogl02P3oool00`3o0000oooo0?ooo`2R0?ooo`7o00000@3oool00003o`00003oool0oooo05<0
oooo00<0o`000?ooo`3oool0303oool4oomo0080oooo1?ooO`0:0?ooo`030?l0003oool0oooo0:80
oooo0Ol000010?ooo`0000?o00000?ooo`3oool0E03oool20?l000d0oooo0_ooO`040?ooo`;oogl0
303oool00`3o0000oooo0?ooo`2Q0?ooo`7o00000@3oool00003o`00003oool0oooo05H0oooo0P3o
000O0?ooo`030?l0003oool0oooo0:40oooo0Ol000010?ooo`0000?o00000?ooo`3oool0F03oool2
0?l001h0oooo00<0o`000?ooo`3oool0X03oool1o`000040oooo00000ol00000oooo0?ooo`1J0?oo
o`030?l0003oool0oooo01/0oooo00<0o`000?ooo`3oool0X03oool1o`000040oooo00000ol00000
oooo0?ooo`1K0?ooo`80o`00703oool00`3o0000oooo0?ooo`2O0?ooo`7o00000@3oool00003o`00
003oool0oooo05d0oooo00<0o`000?ooo`3oool06P3oool00`3o0000oooo0?ooo`2N0?ooo`7o0000
0@3oool00003o`00003oool0oooo05h0oooo00<0o`000?ooo`3oool06@3oool00`3o0000oooo0?oo
o`2N0?ooo`7o00000@3oool00003o`00003oool0oooo05l0oooo00<0o`00ool0003o00006@3oool0
0`3o0000oooo0?ooo`2M0?ooo`7o00000@3oool00003o`00003oool0oooo0680oooo0P3o000G0?oo
o`030?l0003oool0oooo09d0oooo0Ol000010?ooo`0000?o00000?ooo`3oool0I03oool00`3o0000
oooo0?ooo`0D0?ooo`030?l0003oool0oooo09d0oooo0Ol000010?ooo`0000?o00000?ooo`3oool0
I@3oool20?l001@0oooo00<0o`000?ooo`3oool01@3oool<o`00oh`0oooo0Ol000010?ooo`0000?o
00000?ooo`3oool0I`3oool20?l00180oooo00@0o`000?ooo`3oool0oooo1?l00?l<0?ooo`?o003o
R@3oool1o`000040oooo00000ol00000oooo0?ooo`1Y0?ooo`<0o`003P3oool01@3o0000oooo0000
o`000?oo003o01<0oooo1?l00?n50?ooo`7o00000@3oool00003o`00003oool0oooo06`0oooo0P3o
000<0?ooo`80003o6P3oool4o`00oh40oooo0Ol000010?ooo`0000?o00000?ooo`3oool0KP3oool0
0`3o0000oooo0?ooo`070?ooo`80003o00<0o`000?ooo`3oool07@3oool2o`00ogl0oooo0Ol00001
0?ooo`0000?o00000?ooo`3oool0K`3oool00ooo0000o`000?l000020?l00080oooo00?o003o0000
o`3o00000P3o000Q0?ooo`?o003oO03oool1o`000040oooo00000ol00000oooo0?ooo`1d0?ooo`80
o`0000<0003o0?l0003oool09P3oool3o`00ogT0oooo0Ol000010?ooo`0000?o00000?ooo`3oool0
M@3oool00`000?l0oooo0?ooo`0Z0?ooo`;o003oM`3oool1o`000040oooo00000ol00000oooo0?oo
o`1d0?ooo`030000o`3oool0oooo02d0oooo0_l00?me0?ooo`7o00000@3oool00003o`00003oool0
oooo07<0oooo00<0003o0?ooo`3oool0<03oool2o`00og<0oooo0Ol000010?ooo`0000?o00000?oo
o`3oool0LP3oool00`000?l0oooo0?ooo`0c0?ooo`;o003oL@3oool1o`000040oooo00000ol00000
oooo0?ooo`1a0?ooo`030000o`3oool0oooo03H0oooo00?o003o0?ooo`3oool0KP3oool1o`000040
oooo00000ol00000oooo0?ooo`1`0?ooo`030000o`3oool0oooo03P0oooo0_l00?m^0?ooo`7o0000
0@3oool00003o`00003oool0oooo0700oooo00<0003o0?ooo`3oool0>P3oool00ol00?l0oooo0?oo
o`1[0?ooo`7o00000@3oool00003o`00003oool0oooo0700oooo00<0003o0?ooo`3oool0>`3oool2
o`00of/0oooo0Ol000010?ooo`0000?o00000?ooo`3oool0K`3oool00`000?l0oooo0?ooo`0n0?oo
o`03o`00o`3oool0oooo06P0oooo0Ol000010?ooo`0000?o00000?ooo`3oool0K`3oool00`000?l0
oooo0?ooo`0o0?ooo`;o003oJ03oool1o`000040oooo00000ol00000oooo0?ooo`1_0?ooo`030000
o`3oool0oooo0440oooo00?o003o0?ooo`3oool0I@3oool1o`000040oooo00000ol00000oooo0?oo
o`1_0?ooo`030000o`3oool0oooo0480oooo00?o003o0?ooo`3oool0I03oool1o`000040oooo0000
0ol00000oooo0?ooo`1^0?ooo`030000o`3oool0oooo04@0oooo00?o003o0?ooo`3oool0H`3oool1
o`000040oooo00000ol00000oooo0?ooo`1^0?ooo`030000o`3oool0oooo04D0oooo0_l00?mS0?oo
o`7o00000@3oool00003o`00003oool0oooo06h0oooo00<0003o0?ooo`3oool0A`3oool00ol00?l0
oooo0?ooo`1P0?ooo`7o00000@3oool00003o`00003oool0oooo06h0oooo00<0003o0?ooo`3oool0
B03oool2o`00of00oooo0Ol000010?ooo`0000?o00000?ooo`3oool0KP3oool00`000?l0oooo0?oo
o`1:0?ooo`03o`00o`3oool0oooo05d0oooo0Ol000010?ooo`0000?o00000?ooo`3oool0K`3oool0
0`000?l0oooo0?ooo`1:0?ooo`03o`00o`3oool0oooo04@0oooo0_ooO`0F0?ooo`7o00000@3oool0
0003o`00003oool0oooo06l0oooo00<0003o0?ooo`3oool0B`3oool00ol00?l0oooo0?ooo`120?oo
o`Coogl05@3oool1o`000040oooo00000ol00000oooo0?ooo`1_0?ooo`030000o`3oool0oooo04`0
oooo00?o003o0?ooo`3oool0@@3oool4oomo01D0oooo0Ol000010?ooo`0000?o00000?ooo`3oool0
K`3oool00`000?l0oooo0?ooo`1=0?ooo`03o`00o`3oool0oooo0440oooo0_ooO`0F0?ooo`7o0000
0@3oool00003o`00003oool0oooo06l0oooo00?o003o0?ooo`3oool0CP3oool00ol00?l0oooo0?oo
o`1H0?ooo`7o00000@3oool00003o`00003oool0oooo06l0oooo00?o003o0?ooo`3oool0C`3oool0
0ol00?l0oooo0?ooo`1G0?ooo`7o00000@3oool00003o`00003oool0oooo06l0oooo00?o003o0?oo
o`3oool0D03oool00ol00?l0oooo0?ooo`1F0?ooo`7o00000@3oool00003o`00003oool0oooo0700
oooo00?o003o0?ooo`3oool0D03oool00ol00?l0oooo0?ooo`1E0?ooo`7o00000@3oool00003o`00
003oool0oooo0700oooo00?o003o0?ooo`3oool0D@3oool00ol00?l0oooo0?ooo`1D0?ooo`7o0000
0@3oool00003o`00003oool0oooo0700oooo00?o003o0?ooo`3oool0DP3oool00ol00?l0oooo0?oo
o`1C0?ooo`7o00000@3oool00003o`00003oool0oooo0700oooo00?o003o0?ooo`3oool0D`3oool0
0ol00?l0oooo0?ooo`1B0?ooo`7o00000@3oool00003o`00003oool0oooo0700oooo00?o003o0?oo
o`3oool0E03oool00ol00?l0oooo0?ooo`1A0?ooo`7o00000@3oool00003o`00003oool0oooo0740
oooo00?o003o0?ooo`3oool0E03oool00ol00?l0oooo0?ooo`1@0?ooo`7o00000@3oool00003o`00
003oool0oooo0740oooo00?o003o0?ooo`3oool0E03oool00ol00?l0oooo0?ooo`1@0?ooo`7o0000
0@3oool00003o`00003oool0oooo0740oooo00?o003o0?ooo`3oool0@@3oool2oomo0180oooo00?o
003o0?ooo`3oool0C`3oool1o`000040oooo00000ol00000oooo0?ooo`1b0?ooo`03o`00o`3oool0
oooo03l0oooo1?ooO`0B0?ooo`03o`00o`3oool0oooo04h0oooo0Ol000010?ooo`0000?o00000?oo
o`3oool0LP3oool00ol00?l0oooo0?ooo`0o0?ooo`Coogl04P3oool00ol00?l0oooo0?ooo`1>0?oo
o`7o00000@3oool00003o`00003oool0oooo0780oooo00?o003o0?ooo`3oool0@03oool2oomo01@0
oooo00?o003o0?ooo`3oool07P3oool2oomo02d0oooo0Ol000010?ooo`0000?o00000?ooo`3oool0
L`3oool00ol00?l0oooo0?ooo`1F0?ooo`03o`00o`3oool0oooo01D0oooo0_ooO`050?ooo`Coogl0
;03oool1o`000040oooo00000ol00000oooo0?ooo`1c0?ooo`03o`00o`3oool0oooo05H0oooo00?o
003o0?ooo`3oool0503oool4oomo00@0oooo1?ooO`0/0?ooo`7o00000@3oool00003o`00003oool0
oooo07@0oooo00?o003o0?ooo`3oool0C03oool2oomo00P0oooo00?o003o0?ooo`3oool04`3oool4
oomo00D0oooo0_ooO`0]0?ooo`7o00000@3oool00003o`00003oool0oooo07D0oooo00?o003o0?oo
o`3oool0:P3oool4o`00oa`0oooo1?ooO`080?ooo`03o`00o`3oool0oooo01<0oooo0_ooO`0e0?oo
o`7o00000@3oool00003o`00003oool0oooo07D0oooo00?o003o0?ooo`3oool0:@3oool6o`00oa/0
oooo1?ooO`080?ooo`03o`00o`3oool0oooo04X0oooo0Ol000010?ooo`0000?o00000?ooo`3oool0
MP3oool00ol00?l0oooo0?ooo`0W0?ooo`So003o6`3oool2oomo00X0oooo00?o003o0?ooo`3oool0
B@3oool1o`000040oooo00000ol00000oooo0?ooo`1f0?ooo`03o`00o`3oool0oooo02L0oooo2?l0
0?lA0?ooo`;oogl05@3oool00ol00?l0oooo0?ooo`0=0?ooo`;oogl0>@3oool1o`000040oooo0000
0ol00000oooo0?ooo`1g0?ooo`03o`00o`3oool0oooo02H0oooo2?l00?l@0?ooo`Coogl05@3oool0
0ol00?l0oooo0?ooo`0;0?ooo`Coogl0>03oool1o`000040oooo00000ol00000oooo0?ooo`1g0?oo
o`03o`00o`3oool0oooo02H0oooo2?l00?l<0?ooo`;oogl00P3oool4oomo01D0oooo00?o003o0?oo
o`3oool02`3oool4oomo00<0oooo0_ooO`0c0?ooo`7o00000@3oool00003o`00003oool0oooo07P0
oooo00?o003o0?ooo`3oool09P3oool6o`00o``0oooo1?ooO`020?ooo`;oogl04`3oool2oomo0080
oooo00?o003o0?ooo`3oool02`3oool2oomo00<0oooo1?ooO`0b0?ooo`7o00000@3oool00003o`00
003oool0oooo07T0oooo00?o003o0?ooo`3oool09P3oool4o`00o`d0oooo1?ooO`060?ooo`;oogl0
3P3oool4oomo00030?ooool00?l0oooo0140oooo1?ooO`0b0?ooo`7o00000@3oool00003o`00003o
ool0oooo07T0oooo00?o003o0?ooo`3oool0>03oool2oomo00H0oooo1?ooO`0=0?ooo`Coogl00P3o
ool00ol00?l0oooo0?ooo`0@0?ooo`;oogl0<`3oool1o`000040oooo00000ol00000oooo0?ooo`1j
0?ooo`03o`00o`3oool0oooo00h0oooo0_ooO`0W0?ooo`;oogl01P3oool4oomo00h0oooo0_ooO`03
0?ooo`03o`00o`3oool0oooo04D0oooo0Ol000010?ooo`0000?o00000?ooo`3oool0NP3oool00ol0
0?l0oooo0?ooo`0=0?ooo`Coogl09@3oool4oomo00H0oooo0_ooO`0E0?ooo`03o`00o`3oool0oooo
04@0oooo0Ol000010?ooo`0000?o00000?ooo`3oool0N`3oool00ol00?l0oooo0?ooo`0<0?ooo`Co
ogl09@3oool4oomo01d0oooo00?o003o0?ooo`3oool0A03oool1o`000040oooo00000ol00000oooo
0?ooo`1l0?ooo`03o`00o`3oool0oooo00`0oooo0_ooO`0W0?ooo`;oogl07`3oool00ol00?l0oooo
0?ooo`130?ooo`7o00000@3oool00003o`00003oool0oooo07d0oooo00?o003o0?ooo`3oool05P3o
ool2oomo03X0oooo0_ooO`000`3ooooo003o0?ooo`140?ooo`7o00000@3oool00003o`00003oool0
oooo07h0oooo00?o003o0?ooo`3oool0503oool4oomo00h0oooo0_ooO`0X0?ooo`Coogl000<0oooo
o`00o`3oool0@`3oool1o`000040oooo00000ol00000oooo0?ooo`1o0?ooo`03o`00o`3oool0oooo
01<0oooo1?ooO`0=0?ooo`Coogl09`3oool4oomo00030?ooool00?l0oooo04<0oooo0Ol000010?oo
o`0000?o00000?ooo`3oool0P03oool00ol00?l0oooo0?ooo`0C0?ooo`;oogl03P3oool4oomo02P0
oooo0_ooO`020?ooo`03o`00o`3oool0oooo0480oooo0Ol000010?ooo`0000?o00000?ooo`3oool0
P@3oool00ol00?l0oooo0?ooo`0S0?ooo`;oogl0;P3oool00ol00?l0oooo0?ooo`110?ooo`7o0000
0@3oool00003o`00003oool0oooo0880oooo00?o003o0?ooo`3oool0DP3oool00ol00?l0oooo0?oo
o`0A0?ooo`;oogl0;P3oool1o`000040oooo00000ol00000oooo0?ooo`230?ooo`03o`00o`3oool0
oooo0540oooo00?o003o0?ooo`3oool0403oool4oomo02d0oooo0Ol000010?ooo`0000?o00000?oo
o`3oool0Q03oool00ol00?l0oooo0?ooo`1?0?ooo`03oomo0?l00?l0oooo0140oooo1?ooO`0]0?oo
o`7o00000@3oool00003o`00003oool0oooo08D0oooo00?o003o0?ooo`3oool0C@3oool2oomo0003
o`00ooooO`00oooo0140oooo0_ooO`0^0?ooo`7o00000@3oool00003o`00003oool0oooo08D0oooo
00?o003o0?ooo`3oool0;`3oool2oomo01`0oooo0_ooO`000ol00?ooogl00?ooo`110?ooo`7o0000
0@3oool00003o`00003oool0oooo08H0oooo00?o003o0?ooo`3oool0;@3oool4oomo01`0oooo00?o
ogl0o`00o`3oool0@P3oool1o`000040oooo00000ol00000oooo0?ooo`270?ooo`03o`00o`3oool0
oooo02T0oooo0_ooO`000`3oooooogl0oomo0002oomo01h0oooo00?o003o0?ooo`3oool0@03oool1
o`000040oooo00000ol00000oooo0?ooo`280?ooo`03o`00o`3oool0oooo01d0oooo0_ooO`080?oo
o`Coogl000<0oooooomo0?ooO`006P3oool2oomo00<0oooo00?o003o0?ooo`3oool0@03oool1o`00
0040oooo00000ol00000oooo0?ooo`290?ooo`03o`00o`3oool0oooo01X0oooo1OooO`070?ooo`Co
ogl05`3oool2oomo00<0oooo1?ooO`020?ooo`03o`00o`3oool0oooo0400oooo0Ol000010?ooo`00
00?o00000?ooo`3oool0RP3oool2o`00oaT0oooo1_ooO`080?ooo`;oogl05`3oool4oomo0080oooo
1?ooO`020?ooo`03o`00o`3oool0oooo0400oooo0Ol000010?ooo`0000?o00000?ooo`3oool0S03o
ool2o`00oaL0oooo1OooO`0R0?ooo`Coogl00`3oool2oomo00<0oooo00?o003o0?ooo`3oool0@03o
ool1o`000040oooo00000ol00000oooo0?ooo`1f0?ooo`;oogl05P3oool00ol00?l0oooo0?ooo`0E
0?ooo`;oogl09@3oool2oomo00T0oooo00?o003o0?ooo`3oool0@03oool1o`000040oooo00000ol0
0000oooo0?ooo`1e0?ooo`Coogl05P3oool00ol00?l0oooo0?ooo`160?ooo`03o`00o`3oool0oooo
0400oooo0Ol000010?ooo`0000?o00000?ooo`3oool0M@3oool4oomo00X0oooo0_ooO`0;0?ooo`03
o`00o`3oool0oooo04D0oooo00?o003o0?ooo`3oool0@03oool1o`000040oooo00000ol00000oooo
0?ooo`1f0?ooo`;oogl02P3oool4oomo00/0oooo00?o003o0?ooo`3oool0703oool2oomo02H0oooo
00?o003o0?ooo`3oool0@03oool1o`000040oooo00000ol00000oooo0?ooo`220?ooo`Coogl0303o
ool00ol00?l0oooo0?ooo`0J0?ooo`Coogl09@3oool00ol00?l0oooo0?ooo`100?ooo`7o00000@3o
ool00003o`00003oool0oooo08<0oooo0_ooO`0>0?ooo`?o003o4`3oool2oomo00@0oooo1?ooO`0U
0?ooo`03o`00o`3oool0oooo0400oooo0Ol000010?ooo`0000?o00000?ooo`3oool0UP3oool00ol0
0?l0oooo0?ooo`0?0?ooo`Coogl0103oool2oomo02H0oooo00?o003o0?ooo`3oool0@03oool1o`00
0040oooo00000ol00000oooo0?ooo`2G0?ooo`;o003o3`3oool4oomo02`0oooo00?o003o0?ooo`3o
ool0@03oool1o`000040oooo00000ol00000oooo0?ooo`2I0?ooo`03o`00o`3oool0oooo00d0oooo
0_ooO`0/0?ooo`03o`00o`3oool0oooo0440oooo0Ol000010?ooo`0000?o00000?ooo`3oool0VP3o
ool00ol00?l0oooo0?ooo`0j0?ooo`03o`00o`3oool0oooo0440oooo0Ol000010?ooo`0000?o0000
0?ooo`3oool0V`3oool2o`00ocX0oooo00?o003o0?ooo`3oool0@@3oool1o`000040oooo00000ol0
0000oooo0?ooo`2M0?ooo`03o`00o`3oool0oooo03L0oooo00?o003o0?ooo`3oool0@@3oool1o`00
0040oooo00000ol00000oooo0?ooo`2N0?ooo`03o`00o`3oool0oooo03D0oooo00?o003o0?ooo`3o
ool0@P3oool1o`000040oooo00000ol00000oooo0?ooo`240?ooo`;oogl06@3oool3o`00oc<0oooo
00?o003o0?ooo`3oool0@`3oool1o`000040oooo00000ol00000oooo0?ooo`230?ooo`Coogl06`3o
ool2o`00oc00oooo00?o003o0?ooo`3oool0A03oool1o`000040oooo00000ol00000oooo0?ooo`23
0?ooo`Coogl07@3oool2o`00obd0oooo00?o003o0?ooo`3oool0A@3oool1o`000040oooo00000ol0
0000oooo0?ooo`240?ooo`;oogl0803oool2o`00o`X0oooo0_ooO`0N0?ooo`03o`00o`3oool0oooo
04H0oooo0Ol000010?ooo`0000?o00000?ooo`3oool0Z03oool2o`00o`L0oooo1?ooO`0L0?ooo`03
o`00o`3oool0oooo04L0oooo0Ol000010?ooo`0000?o00000?ooo`3oool0ZP3oool3o`00o`@0oooo
1?ooO`0K0?ooo`03o`00o`3oool0oooo04P0oooo0Ol000010?ooo`0000?o00000?ooo`3oool0[@3o
ool3o`00o`80oooo0_ooO`0J0?ooo`;o003oB`3oool1o`000040oooo00000ol00000oooo0?ooo`2`
0?ooo`Co003o603oool2o`00odd0oooo0Ol000010?ooo`0000?o00000?ooo`3oool0]03oool4o`00
oa40oooo0ol00?m?0?ooo`7o00000@3oool00003o`00003oool0oooo07/0oooo0_ooO`0k0?ooo`Ko
003o1P3oool5o`00oe80oooo0Ol000010?ooo`0000?o00000?ooo`3oool0NP3oool4oomo0400oooo
1_l00?mG0?ooo`7o00000@3oool00003o`00003oool0oooo07X0oooo1?ooO`0P0?ooo`;oogl0N`3o
ool1o`000040oooo00000ol00000oooo0?ooo`1k0?ooo`;oogl0803oool4oomo07X0oooo0Ol00001
0?ooo`0000?o00000?ooo`3oool0W@3oool4oomo07X0oooo0Ol000010?ooo`0000?o00000?ooo`3o
ool0T03oool2oomo00`0oooo0_ooO`1k0?ooo`7o00000@3oool00003o`00003oool0oooo08l0oooo
1?ooO`280?ooo`7o00000@3oool00003o`00003oool0oooo08l0oooo1?ooO`280?ooo`7o00000@3o
ool00003o`00003oool0oooo0900oooo0_ooO`0S0?ooo`;oogl0I03oool1o`000040oooo00000ol0
0000oooo0?ooo`2d0?ooo`Coogl0H`3oool1o`000040oooo00000ol00000oooo0?ooo`2d0?ooo`Co
ogl0H`3oool1o`000040oooo00000ol00000oooo0?ooo`2e0?ooo`;oogl0I03oool1o`000040oooo
00000ol00000oooo0?ooo`3o0?oooa`0oooo0Ol000010?ooo`0000?o00000?ooo`3oool0o`3ooolL
0?ooo`7o00000@3oool00003o`00003oool0oooo0?l0oooo703oool1o`000040oooo00000ol00000
oooo0?ooo`3o0?oooa`0oooo0Ol000010?ooo`0000?o00000?ooo`3oool0o`3ooolL0?ooo`7o0000
0@3oool00003o`00003oool0oooo0?l0oooo703oool1o`000040oooo00000ol00000oooo0?ooo`3o
0?oooa`0oooo0Ol000010?ooo`0000?o00000?ooo`3oool0o`3ooolL0?ooo`7o00000@3oool00003
o`00003oool0oooo0?l0oooo703oool1o`000040oooo00000ol00000oooo0?ooo`3o0?oooa`0oooo
0Ol000010?ooo`0000?o00000?ooo`3oool0o`3ooolL0?ooo`7o00000@3oool00003o`00003oool0
oooo0?l0oooo703oool1o`000040oooo00000ol00000oooo0?ooo`3o0?oooa`0oooo0Ol000010?oo
o`0000?o00000?ooo`3oool0o`3ooolL0?ooo`7o00000@3oool00003o`00003oool0oooo0?l0oooo
703oool1o`000040oooo00000ol00000oooo0?ooo`3o0?oooa`0oooo0Ol000010?ooo`0000?o0000
0?ooo`3oool0o`3ooolL0?ooo`7o00000@3oool00003o`00003oool0oooo0?l0oooo703oool1o`00
0040oooo00000ol00000oooo0?ooo`3o0?oooa`0oooo0Ol000010?ooo`0000?o00000?ooo`3oool0
o`3ooolL0?ooo`7o00000@3oool00003o`00003oool0oooo0?l0oooo703oool1o`000040oooo0000
0ol00000oooo0?ooo`3o0?oooa`0oooo0Ol000010?ooo`0000?o00000?ooo`3oool0o`3ooolL0?oo
o`7o00000@3oool00003o`00003oool0oooo0?l0oooo703oool1o`000040oooo00000ol00000oooo
0?ooo`3o0?oooa`0oooo0Ol000010?ooo`0000?o00000?ooo`3oool0o`3ooolL0?ooo`7o00000@3o
ool00003o`00003oool0oooo0?l0oooo703oool1o`000040oooo00000ol00000oooo0?ooo`3o0?oo
oa`0oooo0Ol000010?ooo`0000?o00000?ooo`3oool0o`3ooolL0?ooo`7o00000@3oool00003o`00
003oool0oooo0?l0oooo703oool1o`000040oooo00000ol00000oooo0?ooo`3o0?oooa`0oooo0Ol0
00010?ooo`0000?o00000?ooo`3oool0o`3ooolL0?ooo`7o00000@3oool00003o`00003oool0oooo
0?l0oooo703oool1o`000040oooo00000ol00000oooo0?ooo`3o0?oooa`0oooo0Ol000010?ooo`00
00?o00000?ooo`3oool0o`3ooolL0?ooo`7o00000@3oool00003o`00003oool0oooo0?l0oooo703o
ool1o`000040oooo00000ol00000oooo0?ooo`3o0?oooa`0oooo0Ol000010?ooo`0000?o00000?oo
o`3oool0SP3oool2oomo08/0oooo0Ol000010?ooo`0000?o00000?ooo`3oool0S@3oool4oomo08X0
oooo0Ol000010?ooo`0000?o00000?ooo`3oool0S@3oool4oomo08X0oooo0Ol000010?ooo`0000?o
00000?ooo`3oool0SP3oool2oomo08/0oooo0Ol000010?ooo`0000?o00000?ooo`3oool0o`3ooolL
0?ooo`7o00000@3oool00003o`00003oool0oooo0?l0oooo703oool1o`000040oooo00000ol00000
oooo0?ooo`3o0?oooa`0oooo0Ol000010?ooo`0000?o00000?ooo`3oool0o`3ooolL0?ooo`7o0000
0@3oool00003o`00003oool0oooo0?l0oooo703oool1o`000040oooo00000ol00000oooo0?ooo`3o
0?oooa`0oooo0Ol000010?ooo`0000?o00000?ooo`3oool0o`3ooolL0?ooo`7o00000@3oool00003
o`00003oool0oooo0?l0oooo703oool1o`000040oooo00000ol00000oooo0?ooo`3o0?oooa`0oooo
0Ol000010?ooo`0000?o00000?ooo`3oool0o`3ooolL0?ooo`7o00000@3oool00003o`00003oool0
oooo0?l0oooo703oool1o`000040oooo00000ol00000oooo0?ooo`3o0?oooa`0oooo0Ol000010?oo
o`0000?o00000?ooo`3oool0o`3ooolL0?ooo`7o00000@3oool00003o`00003oool0oooo0?l0oooo
703oool1o`000040oooo00000ol00000oooo0?ooo`3o0?oooa`0oooo0Ol000010?ooo`0000?o0000
0?ooo`3oool0o`3ooolL0?ooo`7o00000@3oool00003o`00003oool0oooo0?l0oooo703oool1o`00
0040oooo00000ol00000oooo0?ooo`3o0?oooa`0oooo0Ol000010?ooo`0000?o00000?ooo`3oool0
o`3ooolL0?ooo`7o00000@3oool00003o`00003oool0oooo0?l0oooo703oool1o`000040oooo0000
0ol00000oooo0?ooo`3o0?oooa`0oooo0Ol000010?ooo`00ool0000Po`000040oooo0000\
\>"],
  ImageRangeCache->{{{0, 287}, {287, 0}} -> {-1.01089, -1.01089, 0.00704453, \
0.00704453}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.49505 0.5 0.49505 [
[ 0 0 -0.125 0 ]
[ 0 0 -0.125 0 ]
[ 0 1 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
0 0 m
1 0 L
s
0 0 m
0 1 L
s
0 1 m
1 1 L
s
1 0 m
1 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
1 .5 0 r
.015 w
.03175 .1355 Mdot
.03435 .12523 Mdot
.11137 .12765 Mdot
.14107 .18841 Mdot
.16218 .24538 Mdot
.17294 .21053 Mdot
.18267 .18577 Mdot
.18434 .1304 Mdot
.18553 .30956 Mdot
.20401 .239 Mdot
.21247 .27571 Mdot
.21687 .20845 Mdot
.22376 .2799 Mdot
.22832 .27485 Mdot
.29063 .20974 Mdot
.29686 .25079 Mdot
.30487 .22936 Mdot
.30683 .34623 Mdot
.32055 .20902 Mdot
.32574 .21979 Mdot
.34472 .28521 Mdot
.35998 .36393 Mdot
.36335 .24976 Mdot
.3794 .36608 Mdot
.42386 .66992 Mdot
.44391 .74519 Mdot
.45059 .34198 Mdot
.47208 .67586 Mdot
.47436 .71381 Mdot
.49778 .59825 Mdot
.50874 .91643 Mdot
.51516 .76219 Mdot
.53655 .61374 Mdot
.56563 .75219 Mdot
.59189 .65665 Mdot
.59581 .61604 Mdot
.59923 .6556 Mdot
.60292 .68499 Mdot
.62656 .67779 Mdot
.63555 .72451 Mdot
.63919 .652 Mdot
.64169 .6004 Mdot
.64246 .58611 Mdot
.64496 .54267 Mdot
.64608 .77288 Mdot
.65077 .64308 Mdot
.66065 .57816 Mdot
.67474 .59169 Mdot
.69296 .563 Mdot
.72815 .65902 Mdot
.73169 .58879 Mdot
.74669 .61318 Mdot
.74821 .65474 Mdot
.75963 .63781 Mdot
.79673 .57809 Mdot
.80925 .55852 Mdot
.81525 .58444 Mdot
.83417 .62985 Mdot
.83598 .55526 Mdot
.91595 .49319 Mdot
1 0 0 r
.005 w
.13523 .14586 m
.16128 .14788 L
.18734 .16098 L
.18807 .16128 L
.21339 .17292 L
.23652 .18734 L
.23945 .18896 L
.2655 .20753 L
.27319 .21339 L
.29156 .22673 L
.30572 .23945 L
.31761 .24793 L
.33374 .2655 L
.34367 .27656 L
.35741 .29156 L
.36972 .30927 L
.37525 .31761 L
.38301 .34367 L
.36972 .35726 L
.34367 .35861 L
.31761 .3456 L
.31237 .34367 L
.29156 .33447 L
.2656 .31761 L
.2655 .31755 L
.23945 .30089 L
.22704 .29156 L
.21339 .28226 L
.19447 .2655 L
.18734 .26157 L
.16634 .23945 L
.16128 .23368 L
.14228 .21339 L
.13523 .20329 L
.12365 .18734 L
.11565 .16128 L
.13523 .14586 L
s
0 0 1 r
.52606 .48629 m
.55211 .47935 L
.57817 .47739 L
.60422 .47947 L
.63028 .48527 L
.65633 .49488 L
.66732 .5 L
.68239 .50847 L
.70701 .52606 L
.70844 .52723 L
.73352 .55211 L
.7345 .5532 L
.752 .57817 L
.76055 .59387 L
.76405 .60422 L
.77038 .63028 L
.77071 .65633 L
.76399 .68239 L
.76055 .69068 L
.74742 .70844 L
.7345 .72032 L
.70844 .73448 L
.70842 .7345 L
.68239 .74166 L
.65633 .74374 L
.63028 .74171 L
.60422 .73592 L
.59918 .7345 L
.57817 .72651 L
.55211 .71289 L
.54506 .70844 L
.52606 .69441 L
.51282 .68239 L
.5 .66872 L
.49061 .65633 L
.47542 .63028 L
.47394 .62698 L
.46615 .60422 L
.46267 .57817 L
.46555 .55211 L
.47394 .52757 L
.47652 .52606 L
.5 .50066 L
.50089 .5 L
.52606 .48629 L
s
1 0 0 r
.03 w
.24935 .25181 Mdot
0 0 1 r
.617 .61056 Mdot
1 0 0 r
.79703 .00495 m
.79703 .25246 L
.87129 .25246 L
.87129 .00495 L
F
0 0 1 r
.89604 .00495 m
.89604 .00496 L
.9703 .00496 L
.9703 .00495 L
F
1 0 1 r
.04 w
.03175 .1355 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  AnimationDisplayTime->0.371293,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P000182000`400?l00000o`00003ooooooolQ
ooooo`00ool0000Po`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`00
00?o0000ooooooooool0hOoooolE0?l002Gooooo0Ol00001ooooo`0000?o0000ooooooooool0hOoo
oolE0?l002Gooooo0Ol00001ooooo`0000?o0000ooooooooool0hOoooolE0?l002Gooooo0Ol00001
ooooo`0000?o0000ooooooooool0hOoooolE0?l002Gooooo0Ol00001ooooo`0000?o0000oooooooo
ool0hOoooolE0?l002Gooooo0Ol00001ooooo`0000?o0000ooooooooool0hOoooolE0?l002Gooooo
0Ol00001ooooo`0000?o0000ooooooooool0hOoooolE0?l002Gooooo0Ol00001ooooo`0000?o0000
ooooooooool0hOoooolE0?l002Gooooo0Ol00001ooooo`0000?o0000ooooooooool0hOoooolE0?l0
02Gooooo0Ol00001ooooo`0000?o0000ooooooooool0hOoooolE0?l002Gooooo0Ol00001ooooo`00
00?o0000ooooooooool0hOoooolE0?l002Gooooo0Ol00001ooooo`0000?o0000ooooooooool0hOoo
oolE0?l002Gooooo0Ol00001ooooo`0000?o0000ooooooooool0hOoooolE0?l002Gooooo0Ol00001
ooooo`0000?o0000ooooooooool0hOoooolE0?l002Gooooo0Ol00001ooooo`0000?o0000oooooooo
ool0hOoooolE0?l002Gooooo0Ol00001ooooo`0000?o0000ooooooooool0hOoooolE0?l002Gooooo
0Ol00001ooooo`0000?o0000ooooooooool0hOoooolE0?l002Gooooo0Ol00001ooooo`0000?o0000
ooooooooool0hOoooolE0?l002Gooooo0Ol00001ooooo`0000?o0000ooooooooool0hOoooolE0?l0
02Gooooo0Ol00001ooooo`0000?o0000ooooooooool0hOoooolE0?l002Gooooo0Ol00001ooooo`00
00?o0000ooooooooool0hOoooolE0?l002Gooooo0Ol00001ooooo`0000?o0000ooooooooool0hOoo
oolE0?l002Gooooo0Ol00001ooooo`0000?o0000ooooooooool0hOoooolE0?l002Gooooo0Ol00001
ooooo`0000?o0000ooooooooool0hOoooolE0?l002Gooooo0Ol00001ooooo`0000?o0000oooooooo
ool0hOoooolE0?l002Gooooo0Ol00001ooooo`0000?o0000ooooooooool0hOoooolE0?l002Gooooo
0Ol00001ooooo`0000?o0000ooooooooool0hOoooolE0?l002Gooooo0Ol00001ooooo`0000?o0000
ooooooooool0hOoooolE0?l002Gooooo0Ol00001ooooo`0000?o0000ooooooooool0hOoooolE0?l0
02Gooooo0Ol00001ooooo`0000?o0000ooooooooool0hOoooolE0?l002Gooooo0Ol00001ooooo`00
00?o0000ooooooooool0hOoooolE0?l002Gooooo0Ol00001ooooo`0000?o0000ooooooooool0hOoo
oolE0?l002Gooooo0Ol00001ooooo`0000?o0000ooooooooool01?ooool5ool0omSooooo5@3o000U
ooooo`7o00000Oooool00003o`000?oooooooooo00?ooooo1ooo0?lBooooo`;oogl0`ooooolE0?l0
02Gooooo0Ol00001ooooo`0000?o0000ooooooooool00_ooool9ool0oa3ooooo1?ooO`0Booooo`;o
ogl0[_oooolE0?l002Gooooo0Ol00001ooooo`0000Co0000oooooooooooooooo2ooo0?l?ooooo`Co
ogl04Oooool4oomo0:gooooo5@3o000Uooooo`7o00000Oooool00004o`000?ooooooooooooooo`_o
o`3o4?ooool2oomo01;ooooo1?ooO`2]oooooaD0o`009Oooool1o`00007ooooo00001?l0003ooooo
ooooooooool;ool0obGooooo0_ooO`2^oooooaD0o`009Oooool1o`00007ooooo00001?l0003ooooo
ooooooooool;ool0omGooooo5@3o000Uooooo`7o00000Oooool00004o`000?ooooooooooooooo`_o
o`3o5oooool5ool00;Wooooo5@3o000Uooooo`7o00000Oooool00003o`000?oooooooooo00;ooooo
2Ooo0?lGooooo`03ool00?oooooooooo00?ooooo1Ooo002doooooaD0o`009Oooool1o`00007ooooo
00000ol0003oooooooooo`03ooooo`Ooo`3o5oooool00ooo003oooooooooo`09ooooo`;oo`00/_oo
oolE0?l002Gooooo0Ol00001ooooo`0000?o0000ooooooooool01?ooool5ool0oaOooooo00?oo`00
ooooooooool03?ooool00ooo003oooooooooo`2_oooooaD0o`009Oooool1o`00007ooooo00000ol0
003oooooooooo`0Oooooo`03ool00?oooooooooo00kooooo0_oo002_oooooaD0o`009Oooool1o`00
007ooooo00000ol0003oooooooooo`0Nooooo`03ool00?oooooooooo017ooooo0ooo002/oooooaD0
o`009Oooool1o`00007ooooo00000ol0003oooooooooo`0Nooooo`03ool00?oooooooooo01Cooooo
0ooo002YoooooaD0o`009Oooool1o`00007ooooo00000ol0003oooooooooo`0Nooooo`03ool00?oo
oooooooo01Oooooo0_oo002WoooooaD0o`009Oooool1o`00007ooooo00000ol0003oooooooooo`0O
ooooo`03ool00?oooooooooo01Sooooo0_oo002UoooooaD0o`009Oooool1o`00007ooooo00000ol0
003oooooooooo`0Oooooo`03ool00?oooooooooo01[ooooo00?oo`00ooooooooool0X_oooolE0?l0
02Gooooo0Ol00001ooooo`0000?o0000ooooooooool07oooool00ooo003oooooooooo`0Kooooo`;o
o`00X_oooolE0?l002Gooooo0Ol00001ooooo`0000?o0000ooooooooool08?ooool01?oo003ooooo
ooooooooool2oomo00[ooooo0_ooO`0=ooooo`03ool00?oooooooooo09oooooo5@3o000Uooooo`7o
00000Oooool00003o`000?oooooooooo023ooooo00?oo`00ooooooooool01?ooO`08ooooo`Coogl0
3Oooool00ooo003oooooooooo`2NoooooaD0o`009Oooool1o`00007ooooo00000ol0003ooooooooo
o`0Pooooo`03ool00?oooooooooo00Coogl02?ooool4oomo00kooooo0_oo002NoooooaD0o`009Ooo
ool1o`00007ooooo00000ol0003oooooooooo`0Qooooo`03ool00?oooooooooo00;oogl02_ooool2
oomo017ooooo00?oo`00ooooooooool0VooooolE0?l002Gooooo0Ol00001ooooo`0000?o0000oooo
ooooool08_ooool00ooo003oooooooooo`0Oooooo`;oo`00VooooolE0?l002Gooooo0Ol00001oooo
o`0000?o0000ooooooooool08_ooool00ooo003oooooooooo`0Qooooo`;oo`00VOoooolE0?l002Go
oooo0Ol00001ooooo`0000?o0000ooooooooool08oooool00ooo003oooooooooo`0Dooooo`;oogl0
3?ooool00ooo003oooooooooo`04ooooo`;oogl01oooool2oomo08Oooooo5@3o000Uooooo`7o0000
0Oooool00003o`000?oooooooooo02?ooooo00?oo`00ooooooooool02?ooool2oomo00Wooooo1?oo
O`0<ooooo`03ool00?oooooooooo00;ooooo1?ooO`05ooooo`Coogl0Q_oooolE0?l002Gooooo0Ol0
0001ooooo`0000?o0000ooooooooool09?ooool00ooo003oooooooooo`06ooooo`Coogl02?ooool4
oomo00gooooo00Coo`00oooooooooooooooo1?ooO`05ooooo`Coogl0Q_oooolE0?l002Gooooo0Ol0
0001ooooo`0000?o0000ooooooooool09Oooool00ooo003oooooooooo`05ooooo`Coogl02Oooool2
oomo00oooooo0_oo0002ooooo`;oogl01oooool3oomo08Kooooo5@3o000Uooooo`7o00000Oooool0
0003o`000?oooooooooo02Kooooo00?oo`00ooooooooool01Oooool2oomo01gooooo00?oo`00oooo
ooooool02?ooool4oomo08Gooooo5@3o000Uooooo`7o00000Oooool00003o`000?oooooooooo02Oo
oooo00?oo`00ooooooooool09?ooool00ooo003oooooooooo`07ooooo`Coogl0QOoooolE0?l002Go
oooo0Ol00001ooooo`0000?o0000ooooooooool0:?ooool00ooo003oooooooooo`0Tooooo`04ool0
0?ooooooooooooooo`;oogl01?ooool2oomo08Kooooo5@3o000Uooooo`7o00000Oooool00003o`00
0?oooooooooo02Wooooo00?oo`00ooooooooool09?ooool2ool000Coogl0RooooolE0?l002Gooooo
0Ol00001ooooo`0000?o0000ooooooooool0:_ooool00ooo003oooooooooo`0Uooooo`04ool00?oo
O`3oogl0oomo08_ooooo5@3o000Uooooo`7o00000Oooool00003o`000?oooooooooo02_ooooo00?o
o`00ooooooooool02Oooool2oomo01[ooooo00?oo`00oomo0?ooool0RooooolE0?l002Gooooo0Ol0
0001ooooo`0000?o0000ooooooooool0;?ooool00ooo003oooooooooo`07ooooo`Coogl06_ooool2
ool008_ooooo5@3o000Uooooo`7o00000Oooool00003o`000?oooooooooo02_ooooo00?oogl0ool0
0?ooool02?ooool4oomo00Sooooo1?oo000@ooooo`03ool00?oooooooooo08Sooooo5@3o000Uoooo
o`7o00000Oooool00003o`000?oooooooooo02[ooooo0oooO`000ooo003oooooooooo`07ooooo`;o
ogl02?ooool6ool000[ooooo0_ooO`04ooooo`03ool00?oooooooooo00[ooooo0_ooO`1koooooaD0
o`009Oooool1o`00007ooooo00000ol0003oooooooooo`0Zooooo`Coogl000?oo`00ooooooooool0
3oooool8ool000Sooooo1?ooO`04ooooo`03ool00?oooooooooo00Sooooo1?ooO`1joooooaD0o`00
9Oooool1o`00007ooooo00000ol0003oooooooooo`0[ooooo`;oogl00_ooool00ooo003ooooooooo
o`0>ooooo`Soo`002?ooool4oomo00Cooooo00?oo`00ooooooooool02?ooool4oomo07[ooooo5@3o
000Uooooo`7o00000Oooool00003o`000?oooooooooo033ooooo00?oo`00ooooooooool03Oooool8
ool000Wooooo0_ooO`06ooooo`03ool00?oooooooooo00Sooooo0_ooO`2eooooo`7o00000Oooool0
0003o`000?oooooooooo037ooooo00?oo`00ooooooooool03?ooool8ool001;ooooo00?oo`00oooo
ooooool0__ooool1o`00007ooooo00000ol0003oooooooooo`0booooo`;oo`003Oooool6ool001Co
oooo00?oo`00ooooooooool0_Oooool1o`00007ooooo00000ol0003oooooooooo`0dooooo`;oo`00
3?ooool4ool001Kooooo00?oo`00ooooooooool0_?ooool1o`00007ooooo00000ol0003ooooooooo
o`0fooooo`03ool00?oooooooooo00;oogl00_ooool2oomo01kooooo00?oo`00ooooooooool0^ooo
ool1o`00007ooooo00000ol0003oooooooooo`0gooooo`03ool00?ooO`3oogl000Koogl07_ooool0
0ooo003oooooooooo`2jooooo`7o00000Oooool00003o`000?oooooooooo03Sooooo00?oo`00oomo
0?ooO`001OooO`0Oooooo`03ool00?oooooooooo0;Wooooo0Ol00001ooooo`0000?o0000oooooooo
ool0>Oooool00ooo003oogl0oomo0003oomo023ooooo00?oogl0ool00?ooool0^Oooool1o`00007o
oooo00000ol0003oooooooooo`0jooooo`;oo`000oooO`0Oooooo`?oogl000?oo`00ooooooooool0
]oooool1o`00007ooooo00000ol0003oooooooooo`0looooo`;oo`008?ooool4oomo0003ool00?oo
oooooooo0;Kooooo0Ol00001ooooo`0000?o0000ooooooooool0?_ooool00ooo003oooooooooo`0N
ooooo`;oogl00_ooool00ooo003oooooooooo`2eooooo`7o00000Oooool00003o`000?oooooooooo
03oooooo00?oo`00ooooooooool08Oooool00ooo003oooooooooo`2eooooo`7o00000Oooool00003
o`000?oooooooooo043ooooo00?oo`00ooooooooool08Oooool00ooo003oooooooooo`2dooooo`7o
00000Oooool00003o`000?oooooooooo047ooooo0_oo000Rooooo`03ool00?oooooooooo0;?ooooo
0Ol00001ooooo`0000?o0000ooooooooool0<Oooool2oomo013ooooo00?oo`00ooooooooool08?oo
ool00ooo003oooooooooo`2booooo`7o00000Oooool00003o`000?oooooooooo033ooooo1?ooO`0@
ooooo`;oo`008Oooool00ooo003oooooooooo`2aooooo`7o00000Oooool00003o`000?oooooooooo
033ooooo1?ooO`0Booooo`;oo`007oooool00ooo003oooooooooo`2aooooo`7o00000Oooool00003
o`000?oooooooooo037ooooo0_ooO`0Eooooo`03ool00?oooooooooo01gooooo00?oo`00oooooooo
ool0/?ooool1o`00007ooooo00000ol0003oooooooooo`19ooooo`;oo`007Oooool00ooo003ooooo
ooooo`2`ooooo`7o00000Oooool00003o`000?oooooooooo04_ooooo00?oo`00ooooooooool06_oo
ool00ooo003oooooooooo`2`ooooo`7o00000Oooool00003o`000?oooooooooo04cooooo0_oo000J
ooooo`03ool00?oooooooooo0;3ooooo0Ol00001ooooo`0000?o0000ooooooooool0C_ooool00ooo
003oooooooooo`0Hooooo`03ool00?oooooooooo0:oooooo0Ol00001ooooo`0000?o0000oooooooo
ool0Coooool00ooo003oooooooooo`0Gooooo`03ool00?oooooooooo0:oooooo0Ol00001ooooo`00
00?o0000ooooooooool0D?ooool3ool001Kooooo00?oo`00ooooooooool04Oooool2oomo09cooooo
0Ol00001ooooo`0000?o0000ooooooooool0Doooool3ool001Cooooo00?oo`00ooooooooool03ooo
ool4oomo09_ooooo0Ol00001ooooo`0000?o0000ooooooooool0E?ooool2oomo00;oo`004_ooool0
0ooo003oooooooooo`0?ooooo`Coogl0Voooool1o`00007ooooo00000ol0003oooooooooo`1Coooo
o`Coogl000?oooooool00?oo00004?ooool00ooo003oooooooooo`0@ooooo`;oogl0W?ooool1o`00
007ooooo00000ol0003oooooooooo`1Cooooo`Coogl00oooool3ool000cooooo00?oo`00oooooooo
ool0[oooool1o`00007ooooo00000ol0003oooooooooo`1Dooooo`;oogl01oooool2ool000Wooooo
00?oo`00ooooooooool0/?ooool1o`00007ooooo00000ol0003oooooooooo`1Oooooo`Woo`00/ooo
ool1o`00007ooooo00000ol0003oooooooooo`1Sooooo`;oogl01?ooool2oomo0;3ooooo0Ol00001
ooooo`0000?o0000ooooooooool0H_ooool4oomo00;ooooo1?ooO`2_ooooo`7o00000Oooool00003
o`000?oooooooooo06;ooooo1?ooO`02ooooo`Coogl0[oooool1o`00007ooooo00000ol0003ooooo
ooooo`1Sooooo`;oogl01?ooool2oomo0;3ooooo0Ol00001ooooo`0000?o0000ooooooooool0oooo
oolLooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0
003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o
00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003ooooooooo
o`3ooooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool0
0003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooooaco
oooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oo
oooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001
ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo0?oo
oooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o
0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1
o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000oooooooo
ool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo
00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolL
ooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003o
ooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o0000
0Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3o
oooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003
o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo
0Ol00001ooooo`0000?o0000ooooooooool0VOoooolD0000ofkooooo0Ol00001ooooo`0000?o0000
ooooooooool0UOooool40000oaCooooo0`000?m[ooooo`7o00000Oooool00003o`000?oooooooooo
09;ooooo0`000?lKooooo`<0003oJ?ooool1o`00007ooooo00000ol0003oooooooooo`2@ooooo`80
003o8Oooool30000odgooooo0_ooO`0Fooooo`7o00000Oooool00003o`000?oooooooooo08oooooo
00<0003oooooooooool09?ooool30000odWooooo1?ooO`0Eooooo`7o00000Oooool00003o`000?oo
oooooooo08gooooo0P000?lZooooo`<0003oA_ooool4oomo01Gooooo0Ol00001ooooo`0000?o0000
ooooooooool0S?ooool00`000?ooooooooooo`0]ooooo`80003oAOooool2oomo01Kooooo0Ol00001
ooooo`0000?o0000ooooooooool0Roooool00`000?ooooooooooo`0`ooooo`80003oFoooool1o`00
007ooooo00000ol0003oooooooooo`2:ooooo`030000oooooooooooo03?ooooo0P000?mIooooo`7o
00000Oooool00003o`000?oooooooooo08Wooooo00<0003oooooooooool0=_ooool00`000?oooooo
ooooo`1Fooooo`7o00000Oooool00003o`000?oooooooooo08Sooooo00<0003oooooooooool0>?oo
ool20000oeKooooo0Ol00001ooooo`0000?o0000ooooooooool0Qoooool00`000?ooooooooooo`0k
ooooo`030000oooooooooooo05?ooooo0Ol00001ooooo`0000?o0000ooooooooool0Q_ooool00`00
0?ooooooooooo`0mooooo`030000oooooooooooo05;ooooo0Ol00001ooooo`0000?o0000oooooooo
ool0QOooool00`000?ooooooooooo`0oooooo`03o`00oooooooooooo057ooooo0Ol00001ooooo`00
00?o0000ooooooooool0QOooool00ol00?ooooooooooo`10ooooo`030000oooooooooooo053ooooo
0Ol00001ooooo`0000?o0000ooooooooool0QOooool00`000?ooooooooooo`11ooooo`030000oooo
oooooooo04oooooo0Ol00001ooooo`0000?o0000ooooooooool0Q?ooool00`000?ooooooooooo`13
ooooo`030000oooooooooooo04kooooo0Ol00001ooooo`0000?o0000ooooooooool0Q?ooool00`00
0?ooooooooooo`0^ooooo`;oogl05?ooool00`000?ooooooooooo`1=ooooo`7o00000Oooool00003
o`000?oooooooooo08?ooooo00<0003oooooooooool0;_ooool4oomo01Cooooo00<0003ooooooooo
ool0C?ooool1o`00007ooooo00000ol0003oooooooooo`23ooooo`030000oooooooooooo02kooooo
1?ooO`0Eooooo`030000oooooooooooo04_ooooo0Ol00001ooooo`0000?o0000ooooooooool0Pooo
ool00`000?ooooooooooo`0_ooooo`;oogl05oooool00`000?ooooooooooo`0Kooooo`;oogl0;Ooo
ool1o`00007ooooo00000ol0003oooooooooo`22ooooo`030000oooooooooooo04[ooooo00<0003o
ooooooooool04_ooool2oomo00Gooooo1?ooO`0/ooooo`7o00000Oooool00003o`000?oooooooooo
08;ooooo00<0003oooooooooool0B_ooool00`000?ooooooooooo`0Aooooo`Coogl01?ooool4oomo
02cooooo0Ol00001ooooo`0000?o0000ooooooooool0P_ooool00`000?ooooooooooo`0nooooo`;o
ogl02oooool00`000?ooooooooooo`0@ooooo`Coogl01Oooool2oomo02gooooo0Ol00001ooooo`00
00?o0000ooooooooool0P_ooool00`000?ooooooooooo`0mooooo`Coogl02oooool00`000?oooooo
ooooo`0@ooooo`;oogl0=Oooool1o`00007ooooo00000ol0003oooooooooo`21ooooo`030000oooo
oooooooo03kooooo1?ooO`0<ooooo`030000oooooooooooo04Kooooo0Ol00001ooooo`0000?o0000
ooooooooool0POooool00`000?ooooooooooo`0oooooo`;oogl03Oooool00`000?ooooooooooo`16
ooooo`7o00000Oooool00003o`000?oooooooooo087ooooo00<0003oooooooooool0=Oooool2oomo
01Sooooo00<0003oooooooooool02_ooool2oomo03Wooooo0Ol00001ooooo`0000?o0000oooooooo
ool0POooool00`000?ooooooooooo`0dooooo`Coogl06?ooool00`000?ooooooooooo`08ooooo`Co
ogl0>?ooool1o`00007ooooo00000ol0003oooooooooo`21ooooo`030000oooooooooooo033ooooo
0_ooO`02ooooo`Coogl06?ooool00`000?ooooooooooo`08ooooo`Coogl00oooool2oomo03?ooooo
0Ol00001ooooo`0000?o0000ooooooooool0POooool00`000?ooooooooooo`0_ooooo`Coogl00_oo
ool2oomo01?ooooo0_ooO`05ooooo`030000oooooooooooo00Sooooo0_ooO`03ooooo`Coogl0<_oo
ool1o`00007ooooo00000ol0003oooooooooo`21ooooo`030000oooooooooooo02oooooo1?ooO`06
ooooo`;oogl03_ooool4oomo00Gooooo00<0003oooooooooool03?ooool4oomo03;ooooo0Ol00001
ooooo`0000?o0000ooooooooool0POooool00`000?ooooooooooo`0`ooooo`;oogl01_ooool4oomo
00gooooo1?ooO`05ooooo`030000oooooooooooo00gooooo0_ooO`0cooooo`7o00000Oooool00003
o`000?oooooooooo08;ooooo00<0003oooooooooool01_ooool2oomo02Oooooo0_ooO`06ooooo`Co
ogl03_ooool2oomo00Oooooo00<0003oooooooooool0@Oooool1o`00007ooooo00000ol0003ooooo
ooooo`22ooooo`030000oooooooooooo00Gooooo1?ooO`0Nooooo`Co003o0oooool4oomo00Kooooo
0_ooO`0Hooooo`030000oooooooooooo047ooooo0Ol00001ooooo`0000?o0000ooooooooool0P_oo
ool00`000?ooooooooooo`05ooooo`Coogl07Oooool6o`00o`;ooooo1?ooO`0Qooooo`030000oooo
oooooooo043ooooo0Ol00001ooooo`0000?o0000ooooooooool0P_ooool00`000?ooooooooooo`06
ooooo`;oogl07Oooool8o`00o`;ooooo0_ooO`0Rooooo`030000oooooooooooo043ooooo0Ol00001
ooooo`0000?o0000ooooooooool0P_ooool00`000?ooooooooooo`0Aooooo`;oogl04_ooool8o`00
ob3ooooo0_ooO`04ooooo`030000oooooooooooo043ooooo0Ol00001ooooo`0000?o0000oooooooo
ool0Poooool00`000?ooooooooooo`0?ooooo`Coogl03_ooool2oomo0003ooooool00?oo003o00Ko
003o7oooool4oomo00?ooooo00<0003oooooooooool0@?ooool1o`00007ooooo00000ol0003ooooo
ooooo`23ooooo`030000oooooooooooo00oooooo1?ooO`0=ooooo`Coogl02?l00?lOooooo`Coogl0
1?ooool00`000?ooooooooooo`0oooooo`7o00000Oooool00003o`000?oooooooooo08Cooooo00<0
003oooooooooool03oooool2oomo00kooooo1?ooO`000ooooooo003oo`00o`04o`00ob7ooooo0_oo
O`05ooooo`030000oooooooooooo03oooooo0Ol00001ooooo`0000?o0000ooooooooool0Q?ooool0
0`000?ooooooooooo`0Pooooo`;oogl00oooool4o`00obWooooo00<0003oooooooooool0?oooool1
o`00007ooooo00000ol0003oooooooooo`25ooooo`030000oooooooooooo05;ooooo00<0003ooooo
ooooool03_ooool2oomo02kooooo0Ol00001ooooo`0000?o0000ooooooooool0QOooool00ol00?oo
ooooooooo`1Booooo`030000oooooooooooo00gooooo1?ooO`0]ooooo`7o00000Oooool00003o`00
0?oooooooooo08Gooooo00<0003oooooooooool0C_ooool2oomo00;ooooo00<0003oooooooooool0
3Oooool4oomo02gooooo0Ol00001ooooo`0000?o0000ooooooooool0Q_ooool00`000?oooooooooo
o`1<ooooo`Coogl000?ooooo0000ooooool03oooool2oomo02kooooo0Ol00001ooooo`0000?o0000
ooooooooool0Q_ooool00`000?ooooooooooo`0^ooooo`;oogl07?ooool4oomo0003ooooo`000?oo
oooo03oooooo0Ol00001ooooo`0000?o0000ooooooooool0Qoooool00`000?ooooooooooo`0/oooo
o`Coogl07?ooool2oomo00;ooooo00<0003oooooooooool0?_ooool1o`00007ooooo00000ol0003o
ooooooooo`27ooooo`030000oooooooooooo02Wooooo0_ooO`000oooooooogl0oomo0002oomo023o
oooo00<0003oooooooooool0?_ooool1o`00007ooooo00000ol0003oooooooooo`28ooooo`030000
oooooooooooo01gooooo0_ooO`08ooooo`Coogl000?ooooooomo0?ooO`006_ooool2oomo00Gooooo
00<0003oooooooooool0?_ooool1o`00007ooooo00000ol0003oooooooooo`28ooooo`030000oooo
oooooooo01_ooooo1OooO`07ooooo`Coogl05oooool2oomo00?ooooo1?ooO`04ooooo`030000oooo
oooooooo03kooooo0Ol00001ooooo`0000?o0000ooooooooool0ROooool00`000?ooooooooooo`0I
ooooo`Koogl02?ooool2oomo01Oooooo1?ooO`02ooooo`Coogl01?ooool00`000?ooooooooooo`0n
ooooo`7o00000Oooool00003o`000?oooooooooo08[ooooo00<0003oooooooooool06?ooool5oomo
02;ooooo1?ooO`03ooooo`;oogl01Oooool00`000?ooooooooooo`0nooooo`7o00000Oooool00003
o`000?oooooooooo07Kooooo0_ooO`0Cooooo`030000oooooooooooo01Sooooo0_ooO`0Uooooo`;o
ogl02oooool00`000?ooooooooooo`0nooooo`7o00000Oooool00003o`000?oooooooooo07Gooooo
1?ooO`0Cooooo`030000oooooooooooo04[ooooo00<0003oooooooooool0?oooool1o`00007ooooo
00000ol0003oooooooooo`1eooooo`Coogl02_ooool2oomo00Sooooo00<0003oooooooooool0BOoo
ool00`000?ooooooooooo`0oooooo`7o00000Oooool00003o`000?oooooooooo07Kooooo0_ooO`0:
ooooo`Coogl02?ooool00`000?ooooooooooo`0Oooooo`;oogl09oooool00`000?ooooooooooo`0o
ooooo`7o00000Oooool00003o`000?oooooooooo08;ooooo1?ooO`09ooooo`030000oooooooooooo
01gooooo1?ooO`0Uooooo`030000oooooooooooo043ooooo0Ol00001ooooo`0000?o0000oooooooo
ool0Poooool2oomo00_ooooo00<0003oooooooooool05_ooool2oomo00Cooooo1?ooO`0Uooooo`03
0000oooooooooooo043ooooo0Ol00001ooooo`0000?o0000ooooooooool0T?ooool00`000?oooooo
ooooo`0Eooooo`Coogl01?ooool2oomo02Kooooo00<0003oooooooooool0@?ooool1o`00007ooooo
00000ol0003oooooooooo`2Aooooo`030000oooooooooooo01Cooooo1?ooO`0[ooooo`030000oooo
oooooooo047ooooo0Ol00001ooooo`0000?o0000ooooooooool0T_ooool00`000?ooooooooooo`0D
ooooo`;oogl0;?ooool00`000?ooooooooooo`11ooooo`7o00000Oooool00003o`000?oooooooooo
09?ooooo0P000?m2ooooo`030000oooooooooooo047ooooo0Ol00001ooooo`0000?o0000oooooooo
ool0UOooool00`000?ooooooooooo`0nooooo`030000oooooooooooo04;ooooo0Ol00001ooooo`00
00?o0000ooooooooool0U_ooool20000ocgooooo00<0003oooooooooool0@oooool1o`00007ooooo
00000ol0003oooooooooo`2Hooooo`030000oooooooooooo03Wooooo00<0003oooooooooool0A?oo
ool1o`00007ooooo00000ol0003oooooooooo`24ooooo`;oogl04oooool20000ocOooooo0P000?m7
ooooo`7o00000Oooool00003o`000?oooooooooo08?ooooo1?ooO`0Dooooo`80003o=?ooool00`00
0?ooooooooooo`17ooooo`7o00000Oooool00003o`000?oooooooooo08?ooooo1?ooO`0Fooooo`80
003o<Oooool00`000?ooooooooooo`18ooooo`7o00000Oooool00003o`000?oooooooooo08Cooooo
0_ooO`0Iooooo`030000oooooooooooo013ooooo0_ooO`0Jooooo`80003oBoooool1o`00007ooooo
00000ol0003oooooooooo`2Pooooo`80003o3oooool4oomo01Oooooo0P000?m=ooooo`7o00000Ooo
ool00003o`000?oooooooooo0:;ooooo0`000?l<ooooo`Coogl05_ooool00`000?ooooooooooo`1=
ooooo`7o00000Oooool00003o`000?oooooooooo0:Gooooo0`000?l:ooooo`;oogl05Oooool20000
oe3ooooo0Ol00001ooooo`0000?o0000ooooooooool0Z?ooool20000oacooooo0`000?mBooooo`7o
00000Oooool00003o`000?oooooooooo0:[ooooo1@000?lCooooo`@0003oEOooool1o`00007ooooo
00000ol0003oooooooooo`1kooooo`;oogl0<_ooool70000o`Oooooo1@000?mIooooo`7o00000Ooo
ool00003o`000?oooooooooo07[ooooo1?ooO`0hooooo`L0003oG_ooool1o`00007ooooo00000ol0
003oooooooooo`1jooooo`Coogl08?ooool2oomo07_ooooo0Ol00001ooooo`0000?o0000oooooooo
ool0Noooool2oomo023ooooo1?ooO`1jooooo`7o00000Oooool00003o`000?oooooooooo09gooooo
1?ooO`1jooooo`7o00000Oooool00003o`000?oooooooooo093ooooo0_ooO`0<ooooo`;oogl0Nooo
ool1o`00007ooooo00000ol0003oooooooooo`2?ooooo`Coogl0R?ooool1o`00007ooooo00000ol0
003oooooooooo`2?ooooo`Coogl0R?ooool1o`00007ooooo00000ol0003oooooooooo`2@ooooo`;o
ogl08oooool2oomo06Cooooo0Ol00001ooooo`0000?o0000ooooooooool0]?ooool4oomo06?ooooo
0Ol00001ooooo`0000?o0000ooooooooool0]?ooool4oomo06?ooooo0Ol00001ooooo`0000?o0000
ooooooooool0]Oooool2oomo06Cooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLoooo
o`7o00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003ooooo
ooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Ooo
ool00003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooo
oacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`00
0?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol0
0001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo
0?oooooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`00
00?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?oo
ool1o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000oooo
ooooool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007o
oooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooo
oolLooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0
003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o
00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003ooooooooo
o`3ooooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool0
0003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooooaco
oooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oo
oooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001
ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo0?oo
oooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o
0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1
o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000oooooooo
ool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo08kooooo0_ooO`2;ooooo`7o0000
0Oooool00003o`000?oooooooooo08gooooo1?ooO`2:ooooo`7o00000Oooool00003o`000?oooooo
oooo08gooooo1?ooO`2:ooooo`7o00000Oooool00003o`000?oooooooooo08kooooo0_ooO`2;oooo
o`7o00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003ooooo
ooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Ooo
ool00003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooo
oacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`00
0?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol0
0001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo
0?oooooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`00
00?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?oo
ool1o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000oooo
ooooool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007o
oooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooo
oolLooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0
003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o
00000Oooool00?oo00008?l00001ooooo`00\
\>"],
  ImageRangeCache->{{{0, 287}, {287, 0}} -> {-1.01089, -1.01089, 0.00704453, \
0.00704453}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.49505 0.5 0.49505 [
[ 0 0 -0.125 0 ]
[ 0 0 -0.125 0 ]
[ 0 1 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
0 0 m
1 0 L
s
0 0 m
0 1 L
s
0 1 m
1 1 L
s
1 0 m
1 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
1 .5 0 r
.015 w
.03175 .1355 Mdot
.03435 .12523 Mdot
.11137 .12765 Mdot
.14107 .18841 Mdot
.16218 .24538 Mdot
.17294 .21053 Mdot
.18267 .18577 Mdot
.18434 .1304 Mdot
.18553 .30956 Mdot
.20401 .239 Mdot
.21247 .27571 Mdot
.21687 .20845 Mdot
.22376 .2799 Mdot
.22832 .27485 Mdot
.29063 .20974 Mdot
.29686 .25079 Mdot
.30487 .22936 Mdot
.30683 .34623 Mdot
.32055 .20902 Mdot
.32574 .21979 Mdot
.34472 .28521 Mdot
.35998 .36393 Mdot
.36335 .24976 Mdot
.3794 .36608 Mdot
.42386 .66992 Mdot
.44391 .74519 Mdot
.45059 .34198 Mdot
.47208 .67586 Mdot
.47436 .71381 Mdot
.49778 .59825 Mdot
.50874 .91643 Mdot
.51516 .76219 Mdot
.53655 .61374 Mdot
.56563 .75219 Mdot
.59189 .65665 Mdot
.59581 .61604 Mdot
.59923 .6556 Mdot
.60292 .68499 Mdot
.62656 .67779 Mdot
.63555 .72451 Mdot
.63919 .652 Mdot
.64169 .6004 Mdot
.64246 .58611 Mdot
.64496 .54267 Mdot
.64608 .77288 Mdot
.65077 .64308 Mdot
.66065 .57816 Mdot
.67474 .59169 Mdot
.69296 .563 Mdot
.72815 .65902 Mdot
.73169 .58879 Mdot
.74669 .61318 Mdot
.74821 .65474 Mdot
.75963 .63781 Mdot
.79673 .57809 Mdot
.80925 .55852 Mdot
.81525 .58444 Mdot
.83417 .62985 Mdot
.83598 .55526 Mdot
.91595 .49319 Mdot
1 0 0 r
.005 w
.13523 .18197 m
.16128 .16731 L
.18734 .17066 L
.21339 .17762 L
.23565 .18734 L
.23945 .19061 L
.2655 .2041 L
.27839 .21339 L
.29156 .22348 L
.31098 .23945 L
.31761 .24653 L
.33421 .2655 L
.34367 .28741 L
.34421 .29156 L
.34367 .29696 L
.31761 .31142 L
.29156 .30806 L
.2655 .30106 L
.24359 .29156 L
.23945 .28811 L
.21339 .27457 L
.20079 .2655 L
.18734 .25522 L
.16813 .23945 L
.16128 .23216 L
.14485 .21339 L
.13523 .19108 L
.13475 .18734 L
.13523 .18197 L
s
0 0 1 r
.68239 .54895 m
.70844 .54974 L
.72083 .55211 L
.7345 .55541 L
.76055 .5761 L
.76156 .57817 L
.76928 .60422 L
.76388 .63028 L
.76055 .63751 L
.74858 .65633 L
.7345 .67305 L
.72268 .68239 L
.70844 .69318 L
.68239 .70779 L
.68107 .70844 L
.65633 .71868 L
.63028 .72576 L
.60422 .72905 L
.57817 .72822 L
.55211 .72152 L
.53336 .70844 L
.52606 .69886 L
.51957 .68239 L
.52107 .65633 L
.52606 .64298 L
.53303 .63028 L
.55211 .60617 L
.55513 .60422 L
.57817 .58524 L
.58996 .57817 L
.60422 .57038 L
.63028 .55937 L
.65633 .55249 L
.65837 .55211 L
.68239 .54895 L
s
1 0 0 r
.03 w
.23947 .23937 Mdot
0 0 1 r
.64399 .63883 Mdot
1 0 0 r
.79703 .00495 m
.79703 .25248 L
.87129 .25248 L
.87129 .00495 L
F
0 0 1 r
.89604 .00495 m
.89604 .00495 L
.9703 .00495 L
.9703 .00495 L
F
1 0 1 r
.04 w
.03175 .1355 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  AnimationDisplayTime->0.371293,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P000182000`400?l00000o`00003ooooooolQ
ooooo`00ool0000Po`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`00
00?o0000ooooooooool0hOoooolEool002Gooooo0Ol00001ooooo`0000?o0000ooooooooool0hOoo
oolEool002Gooooo0Ol00001ooooo`0000?o0000ooooooooool0hOoooolEool002Gooooo0Ol00001
ooooo`0000?o0000ooooooooool0hOoooolEool002Gooooo0Ol00001ooooo`0000?o0000oooooooo
ool0hOoooolEool002Gooooo0Ol00001ooooo`0000?o0000ooooooooool0hOoooolEool002Gooooo
0Ol00001ooooo`0000?o0000ooooooooool0hOoooolEool002Gooooo0Ol00001ooooo`0000?o0000
ooooooooool0hOoooolEool002Gooooo0Ol00001ooooo`0000?o0000ooooooooool0hOoooolEool0
02Gooooo0Ol00001ooooo`0000?o0000ooooooooool0hOoooolEool002Gooooo0Ol00001ooooo`00
00?o0000ooooooooool0hOoooolEool002Gooooo0Ol00001ooooo`0000?o0000ooooooooool0hOoo
oolEool002Gooooo0Ol00001ooooo`0000?o0000ooooooooool0hOoooolEool002Gooooo0Ol00001
ooooo`0000?o0000ooooooooool0hOoooolEool002Gooooo0Ol00001ooooo`0000?o0000oooooooo
ool0hOoooolEool002Gooooo0Ol00001ooooo`0000?o0000ooooooooool0hOoooolEool002Gooooo
0Ol00001ooooo`0000?o0000ooooooooool0hOoooolEool002Gooooo0Ol00001ooooo`0000?o0000
ooooooooool0hOoooolEool002Gooooo0Ol00001ooooo`0000?o0000ooooooooool0hOoooolEool0
02Gooooo0Ol00001ooooo`0000?o0000ooooooooool0hOoooolEool002Gooooo0Ol00001ooooo`00
00?o0000ooooooooool0hOoooolEool002Gooooo0Ol00001ooooo`0000?o0000ooooooooool0hOoo
oolEool002Gooooo0Ol00001ooooo`0000?o0000ooooooooool0hOoooolEool002Gooooo0Ol00001
ooooo`0000?o0000ooooooooool0hOoooolEool002Gooooo0Ol00001ooooo`0000?o0000oooooooo
ool0hOoooolEool002Gooooo0Ol00001ooooo`0000?o0000ooooooooool0hOoooolEool002Gooooo
0Ol00001ooooo`0000?o0000ooooooooool0hOoooolEool002Gooooo0Ol00001ooooo`0000?o0000
ooooooooool0hOoooolEool002Gooooo0Ol00001ooooo`0000?o0000ooooooooool0hOoooolEool0
02Gooooo0Ol00001ooooo`0000?o0000ooooooooool0hOoooolEool002Gooooo0Ol00001ooooo`00
00?o0000ooooooooool0hOoooolEool002Gooooo0Ol00001ooooo`0000?o0000ooooooooool0hOoo
oolEool002Gooooo0Ol00001ooooo`0000?o0000ooooooooool01?ooool50?l0omSooooo5Ooo000U
ooooo`7o00000Oooool00003o`000?oooooooooo00?ooooo1`3o0?lBooooo`80ogl0`ooooolEool0
02Gooooo0Ol00001ooooo`0000?o0000ooooooooool00_ooool90?l0oa3ooooo103oO`0Booooo`80
ogl0[_oooolEool002Gooooo0Ol00001ooooo`0000Co0000oooooooooooooooo2`3o0?l?ooooo`@0
ogl04Oooool40?mo0:gooooo5Ooo000Uooooo`7o00000Oooool00004o`000?ooooooooooooooo`/0
o`3o4?ooool20?mo01;ooooo103oO`2]oooooaGoo`009Oooool1o`00007ooooo00001?l0003ooooo
ooooooooool;0?l0obGooooo0P3oO`2^oooooaGoo`009Oooool1o`00007ooooo00001?l0003ooooo
ooooooooool;0?l0omGooooo5Ooo000Uooooo`7o00000Oooool00004o`000?ooooooooooooooo`/0
o`3oeOoooolEool002Gooooo0Ol00001ooooo`0000?o0000ooooooooool00_ooool90?l0omKooooo
5Ooo000Uooooo`7o00000Oooool00003o`000?oooooooooo00?ooooo1`3o0?oGoooooaGoo`009Ooo
ool1o`00007ooooo00000ol0003oooooooooo`04ooooo`D0o`3of?oooolEool002Gooooo0Ol00001
ooooo`0000?o0000ooooooooool0hOoooolEool002Gooooo0Ol00001ooooo`0000?o0000oooooooo
ool0hOoooolEool002Gooooo0Ol00001ooooo`0000?o0000ooooooooool0hOoooolEool002Gooooo
0Ol00001ooooo`0000?o0000ooooooooool0:_ooool6ool00;7ooooo5Ooo000Uooooo`7o00000Ooo
ool00003o`000?oooooooooo02Sooooo0_oo0006ooooo`Goo`00[?oooolEool002Gooooo0Ol00001
ooooo`0000?o0000ooooooooool09_ooool2ool000gooooo1?oo002XoooooaGoo`009Oooool1o`00
007ooooo00000ol0003oooooooooo`0Tooooo`;oo`004oooool4ool00:Cooooo5Ooo000Uooooo`7o
00000Oooool00003o`000?oooooooooo02?ooooo00?oo`000?mo003oO`002_ooool20?mo00_ooooo
0ooo002QoooooaGoo`009Oooool1o`00007ooooo00000ol0003oooooooooo`0Sooooo`04ool0003o
O`00ogl00?mo00Sooooo103oO`0=ooooo`03ool00?oooooooooo09kooooo5Ooo000Uooooo`7o0000
0Oooool00003o`000?oooooooooo02?ooooo00Coo`000?mo003oO`00ogl02?ooool40?mo00kooooo
0_oo002NoooooaGoo`009Oooool1o`00007ooooo00000ol0003oooooooooo`0Sooooo`03ool0003o
O`00ogl000[ooooo0P3oO`0Aooooo`;oo`00W?oooolEool002Gooooo0Ol00001ooooo`0000?o0000
ooooooooool09?ooool00ooo003oooooooooo`0Nooooo`;oo`00V_oooolEool002Gooooo0Ol00001
ooooo`0000?o0000ooooooooool09?ooool00ooo003oooooooooo`0Pooooo`;oo`00V?oooolEool0
02Gooooo0Ol00001ooooo`0000?o0000ooooooooool09Oooool00ooo003oooooooooo`0Booooo`80
ogl03Oooool00ooo003oooooooooo`03ooooo`80ogl01oooool20?mo08Oooooo5Ooo000Uooooo`7o
00000Oooool00003o`000?oooooooooo02Gooooo00?oo`00ooooooooool01_ooool20?mo00Wooooo
103oO`0=ooooo`04ool00?ooooooooooooooo`@0ogl01Oooool40?mo08Kooooo5Ooo000Uooooo`7o
00000Oooool00003o`000?oooooooooo02Gooooo00?oo`00ooooooooool01Oooool40?mo00Sooooo
103oO`0>ooooo`03ool00?oooooooooo00@0ogl01Oooool40?mo08Kooooo5Ooo000Uooooo`7o0000
0Oooool00003o`000?oooooooooo02Kooooo00?oo`00ooooooooool01?ooool40?mo00Wooooo0P3o
O`0@ooooo`;oo`0000?ooooo0?mo003oO`001oooool30?mo08Kooooo5Ooo000Uooooo`7o00000Ooo
ool00003o`000?oooooooooo02Oooooo00?oo`00ooooooooool01?ooool20?mo01kooooo00?oo`00
ooooooooool01oooool40?mo08Gooooo5Ooo000Uooooo`7o00000Oooool00003o`000?oooooooooo
02Sooooo00?oo`00ooooooooool09?ooool00ooo003oooooooooo`06ooooo`@0ogl0QOoooolEool0
02Gooooo0Ol00001ooooo`0000?o0000ooooooooool0:Oooool00ooo003oooooooooo`0Tooooo`;o
o`0000?ooooo0?mo003oO`001?ooool20?mo08Kooooo5Ooo000Uooooo`7o00000Oooool00003o`00
0?oooooooooo02[ooooo00?oo`00ooooooooool04oooool40?l000kooooo00Coo`000?mo003oO`00
ogl0RooooolEool002Gooooo0Ol00001ooooo`0000?o0000ooooooooool0:oooool00ooo003ooooo
ooooo`0Aooooo`H0o`003Oooool0103oO`3oo`00ool0003oO`2;oooooaGoo`009Oooool1o`00007o
oooo00000ol0003oooooooooo`0/ooooo`03ool00?oooooooooo00Sooooo0P3oO`05ooooo`P0o`00
3Oooool20?mo0003ool00?oooooooooo08Wooooo5Ooo000Uooooo`7o00000Oooool00003o`000?oo
oooooooo02gooooo00?oo`00ooooooooool01_ooool40?mo00Cooooo203o000@ooooo`03ool00?oo
oooooooo08Sooooo5Ooo000Uooooo`7o00000Oooool00003o`000?oooooooooo02_ooooo0P3oO`00
0oooooooo`00ooooo`06ooooo`@0ogl01?ooool80?l0017ooooo00?oo`00ooooooooool0QooooolE
ool002Gooooo0Ol00001ooooo`0000?o0000ooooooooool0:_ooool40?mo0003oooooooo003ooooo
00Kooooo0P3oO`05ooooo`P0o`002oooool20?mo00Gooooo00?oo`00ooooooooool02Oooool20?mo
07_ooooo5Ooo000Uooooo`7o00000Oooool00003o`000?oooooooooo02[ooooo103oO`02ooooo`03
ool00?oooooooooo00cooooo1P3o000;ooooo`@0ogl01?ooool00ooo003oooooooooo`08ooooo`@0
ogl0N_oooolEool002Gooooo0Ol00001ooooo`0000?o0000ooooooooool0:oooool20?mo00Cooooo
00?oo`00ooooooooool03?ooool40?l000cooooo103oO`05ooooo`03ool00?oooooooooo00Oooooo
103oO`1joooooaGoo`009Oooool1o`00007ooooo00000ol0003oooooooooo`0booooo`;oo`007Ooo
ool20?mo00Oooooo00?oo`00ooooooooool01oooool20?mo0;Gooooo0Ol00001ooooo`0000?o0000
ooooooooool0=?ooool00ooo003oooooooooo`0Sooooo`03ool00?oooooooooo0;kooooo0Ol00001
ooooo`0000?o0000ooooooooool0=Oooool00ooo003oooooooooo`0Sooooo`03ool00?oooooooooo
0;gooooo0Ol00001ooooo`0000?o0000ooooooooool0=_ooool2ool002Cooooo00?oo`00oooooooo
ool0_?ooool1o`00007ooooo00000ol0003oooooooooo`0hooooo`;oo`0000<0ogl0ooooooooool0
0P3oO`0Mooooo`03ool00?oooooooooo0;cooooo0Ol00001ooooo`0000?o0000ooooooooool0>?oo
ool20?mo00;oo`00103oO`0Mooooo`03ool00?oooooooooo0;_ooooo0Ol00001ooooo`0000?o0000
ooooooooool0>?ooool40?mo00;oo`000P3oO`0Mooooo`03ool00?oooooooooo0;_ooooo0Ol00001
ooooo`0000?o0000ooooooooool0>Oooool50?mo0003ool00?oooooooooo01gooooo00?oo`000?mo
003oO`00^_ooool1o`00007ooooo00000ol0003oooooooooo`0kooooo`@0ogl00_oo000Mooooo`04
ool0003oO`00ogl00?mo0;Wooooo0Ol00001ooooo`0000?o0000ooooooooool0??ooool20?mo00?o
oooo00?oo`00ooooooooool06_ooool0103oO`3oo`000?mo003oO`2iooooo`7o00000Oooool00003
o`000?oooooooooo04;ooooo0_oo000Kooooo`03ool0003oO`3ooooo0;Wooooo0Ol00001ooooo`00
00?o0000ooooooooool0A?ooool3ool001Sooooo00?oo`00ooooooooool0^Oooool1o`00007ooooo
00000ol0003oooooooooo`17ooooo`;oo`005Oooool2ool00;_ooooo0Ol00001ooooo`0000?o0000
ooooooooool0BOooool3ool0013ooooo0_oo002mooooo`7o00000Oooool00003o`000?oooooooooo
037ooooo0P3oO`0Iooooo`?oo`003?ooool00ooo003oooooooooo`2mooooo`7o00000Oooool00003
o`000?oooooooooo033ooooo103oO`0Kooooo`Koo`001?ooool2ool00<3ooooo0Ol00001ooooo`00
00?o0000ooooooooool0<?ooool40?mo027ooooo1?oo0032ooooo`7o00000Oooool00003o`000?oo
oooooooo037ooooo0P3oO`3Xooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1
o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000oooooooo
ool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo
00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0OOooool2
0?mo09cooooo0Ol00001ooooo`0000?o0000ooooooooool0O?ooool40?mo09_ooooo0Ol00001oooo
o`0000?o0000ooooooooool0E?ooool20?mo02Kooooo103oO`2Kooooo`7o00000Oooool00003o`00
0?oooooooooo05?ooooo103oO`0Vooooo`80ogl0W?ooool1o`00007ooooo00000ol0003ooooooooo
o`1Cooooo`@0ogl0a?ooool1o`00007ooooo00000ol0003oooooooooo`1Dooooo`80ogl0aOooool1
o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000oooooooo
ool0Hoooool20?mo00Cooooo0P3oO`2`ooooo`7o00000Oooool00003o`000?oooooooooo06;ooooo
103oO`02ooooo`@0ogl0[oooool1o`00007ooooo00000ol0003oooooooooo`1Rooooo`@0ogl00_oo
ool40?mo0:oooooo0Ol00001ooooo`0000?o0000ooooooooool0Hoooool20?mo00Cooooo0P3oO`2`
ooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003o
ooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o0000
0Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3o
oooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003
o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo
0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oooooo
oooo0?oooooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001oooo
o`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo
7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000
ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00
007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0
oooooolLooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo0000
0ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLoooo
o`7o00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003ooooo
ooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Ooo
ool00003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooo
oacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`00
0?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol0
0001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo
0?oooooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`00
00?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo1?oo
ool20?mo01Kooooo0Ol00001ooooo`0000?o0000ooooooooool0ooooool3ooooo`@0ogl05Oooool1
o`00007ooooo00000ol0003oooooooooo`3oooooo`?ooooo103oO`0Eooooo`7o00000Oooool00003
o`000?oooooooooo0?oooooo1?ooool20?mo01Kooooo0Ol00001ooooo`0000?o0000ooooooooool0
oooooolLooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo0000
0ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLoooo
o`7o00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003ooooo
ooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Ooo
ool00003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooo
oacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`00
0?oooooooooo0;Gooooo0P3oO`1Tooooo`7o00000Oooool00003o`000?oooooooooo0;Cooooo103o
O`1Sooooo`7o00000Oooool00003o`000?oooooooooo0;Cooooo103oO`1Sooooo`7o00000Oooool0
0003o`000?oooooooooo0;Gooooo0P3oO`06ooooo`ko003o8Oooool20?mo02gooooo0Ol00001oooo
o`0000?o0000ooooooooool0]oooool6o`00o`kooooo0ol00?lFooooo`80ogl01Oooool40?mo02co
oooo0Ol00001ooooo`0000?o0000ooooooooool0/oooool4o`00oaOooooo0ol00?lBooooo`@0ogl0
1?ooool40?mo02cooooo0Ol00001ooooo`0000?o0000ooooooooool0/?ooool3o`00oa3ooooo0P3o
O`0<ooooo`03o`00oooooooooooo00oooooo103oO`05ooooo`80ogl0;Oooool1o`00007ooooo0000
0ol0003oooooooooo`2]ooooo`?o003o4_ooool40?mo00cooooo00?o003oooooooooool03oooool2
0?mo03Gooooo0Ol00001ooooo`0000?o0000ooooooooool0Zoooool2o`00oaGooooo103oO`0=oooo
o`;o003oA_ooool1o`00007ooooo00000ol0003oooooooooo`2Yooooo`;o003o6?ooool20?mo013o
oooo00?o003oooooooooool0@oooool1o`00007ooooo00000ol0003oooooooooo`2Wooooo`;o003o
4?ooool20?mo01_ooooo00?o003oooooooooool01oooool20?mo03Wooooo0Ol00001ooooo`0000?o
0000ooooooooool0YOooool2o`00oa7ooooo103oO`0Kooooo`03o`00oooooooooooo00Gooooo103o
O`0hooooo`7o00000Oooool00003o`000?oooooooooo0:?ooooo0_l00?l?ooooo`80ogl00_ooool4
0?mo01_ooooo00?o003oooooooooool01Oooool40?mo00?ooooo0P3oO`0cooooo`7o00000Oooool0
0003o`000?oooooooooo0:;ooooo00?o003oooooooooool03_ooool40?mo00;ooooo0P3oO`0Coooo
o`80ogl01oooool00ol00?ooooooooooo`06ooooo`80ogl00oooool40?mo03;ooooo0Ol00001oooo
o`0000?o0000ooooooooool0XOooool00ol00?ooooooooooo`0?ooooo`@0ogl01_ooool20?mo00ko
oooo103oO`07ooooo`03o`00oooooooooooo00[ooooo103oO`0booooo`7o00000Oooool00003o`00
0?oooooooooo0:3ooooo00?o003oooooooooool04Oooool20?mo00Kooooo103oO`0=ooooo`@0ogl0
1oooool00ol00?ooooooooooo`0;ooooo`80ogl0<oooool1o`00007ooooo00000ol0003ooooooooo
o`2;ooooo`80ogl04_ooool00ol00?ooooooooooo`0Booooo`80ogl01_ooool40?mo00kooooo0P3o
O`08ooooo`03o`00oooooooooooo043ooooo0Ol00001ooooo`0000?o0000ooooooooool0R_ooool4
0?mo013ooooo00?o003oooooooooool04_ooool40?mo00Kooooo0P3oO`0Iooooo`03o`00oooooooo
oooo043ooooo0Ol00001ooooo`0000?o0000ooooooooool0R_ooool40?mo00oooooo00?o003ooooo
ooooool04oooool40?mo02;ooooo00?o003oooooooooool0?oooool1o`00007ooooo00000ol0003o
ooooooooo`2;ooooo`80ogl03_ooool2o`00oaOooooo0P3oO`0Sooooo`03o`00oooooooooooo03oo
oooo0Ol00001ooooo`0000?o0000ooooooooool0U_ooool20?mo00?ooooo00?o003oooooooooool0
=?ooool20?mo00Gooooo00?o003oooooooooool0?oooool1o`00007ooooo00000ol0003ooooooooo
o`2Eooooo`@0ogl000?oooooo`00ooooool02oooool20?mo02Sooooo103oO`04ooooo`03o`00oooo
oooooooo03oooooo0Ol00001ooooo`0000?o0000ooooooooool0UOooool40?mo0003o`00oooooooo
oooo00[ooooo103oO`0Wooooo`@0ogl01?ooool00ol00?ooooooooooo`0oooooo`7o00000Oooool0
0003o`000?oooooooooo09Kooooo0P3oO`000ol00?ooooooooooo`0;ooooo`@0ogl0:?ooool20?mo
00Cooooo00?o003oooooooooool0@?ooool1o`00007ooooo00000ol0003oooooooooo`2Gooooo`03
o`00oooooooooooo00gooooo0P3oO`0_ooooo`03o`00oooooooooooo043ooooo0Ol00001ooooo`00
00?o0000ooooooooool0U_ooool00ol00?ooooooooooo`0oooooo`03o`00oooooooooooo013ooooo
0P3oO`0^ooooo`7o00000Oooool00003o`000?oooooooooo09Gooooo00?o003oooooooooool07?oo
ool40000ob3ooooo00?o003oooooooooool03oooool40?mo02gooooo0Ol00001ooooo`0000?o0000
ooooooooool0UOooool00ol00?ooooooooooo`0Kooooo`H0003o7Oooool20?mo0003o`00oooooooo
oooo00oooooo103oO`0]ooooo`7o00000Oooool00003o`000?oooooooooo09Cooooo00?o003ooooo
ooooool06oooool80000oa_ooooo0P3oO`000ol00?l0ogl0ooooo`0Aooooo`80ogl0;_ooool1o`00
007ooooo00000ol0003oooooooooo`2Dooooo`03o`00oooooooooooo01_ooooo20000?lKooooo`80
ogl000?o003o0?mo0?ooool0@Oooool1o`00007ooooo00000ol0003oooooooooo`2Cooooo`03o`00
oooooooooooo01cooooo20000?lLooooo`03o`00o`3oO`3ooooo04;ooooo0Ol00001ooooo`0000?o
0000ooooooooool0Toooool00ol00?ooooooooooo`0Looooo`P0003o6oooool00ol00?oooooooooo
o`13ooooo`7o00000Oooool00003o`000?oooooooooo09?ooooo00?o003oooooooooool04_ooool2
0?mo00Sooooo00<0ogl00000o`000?l010000?lJooooo`80ogl000?o003oooooooooool0@oooool1
o`00007ooooo00000ol0003oooooooooo`2Booooo`03o`00oooooooooooo017ooooo1@3oO`07oooo
o`80ogl010000?lEooooo`80ogl00oooool20?mo0003o`00o`3oO`3ooooo04Cooooo0Ol00001oooo
o`0000?o0000ooooooooool0T_ooool00ol00?ooooooooooo`0@ooooo`H0ogl02?ooool20?mo01Oo
oooo103oO`02ooooo`040?mo0?l00?l0ogl00?mo04Gooooo0Ol00001ooooo`0000?o0000oooooooo
ool0T_ooool00ol00?ooooooooooo`0@ooooo`D0ogl08_ooool40?mo00?ooooo00?o003o0?mo0?oo
ool0AOooool1o`00007ooooo00000ol0003oooooooooo`1fooooo`80ogl06_ooool00ol00?oooooo
ooooo`0Aooooo`80ogl09Oooool20?mo00?ooooo00?o003oooooooooool0A_ooool1o`00007ooooo
00000ol0003oooooooooo`1eooooo`@0ogl06Oooool00ol00?ooooooooooo`0looooo`03o`00oooo
oooooooo04Oooooo0Ol00001ooooo`0000?o0000ooooooooool0MOooool40?mo00[ooooo0P3oO`0=
ooooo`03o`00oooooooooooo03_ooooo00?o003oooooooooool0B?ooool1o`00007ooooo00000ol0
003oooooooooo`1fooooo`80ogl02_ooool40?mo00cooooo00?o003oooooooooool06oooool20?mo
01cooooo0_l00?m;ooooo`7o00000Oooool00003o`000?oooooooooo08;ooooo103oO`0<ooooo`03
o`00oooooooooooo01[ooooo103oO`0Jooooo`03o`00oooooooooooo04_ooooo0Ol00001ooooo`00
00?o0000ooooooooool0Poooool20?mo00gooooo00?o003oooooooooool05?ooool20?mo00Cooooo
103oO`0Hooooo`;o003oC_ooool1o`00007ooooo00000ol0003oooooooooo`2Booooo`03o`00oooo
oooooooo01?ooooo103oO`04ooooo`80ogl06?ooool00ol00?ooooooooooo`1>ooooo`7o00000Ooo
ool00003o`000?oooooooooo09;ooooo00?o003oooooooooool04oooool40?mo01gooooo00?o003o
ooooooooool0Coooool1o`00007ooooo00000ol0003oooooooooo`2Cooooo`03o`00oooooooooooo
01?ooooo0P3oO`0Looooo`;o003oD_ooool1o`00007ooooo00000ol0003oooooooooo`2Cooooo`03
o`00oooooooooooo033ooooo00?o003oooooooooool0D_ooool1o`00007ooooo00000ol0003ooooo
ooooo`2Cooooo`03o`00oooooooooooo02kooooo0_l00?mEooooo`7o00000Oooool00003o`000?oo
oooooooo09Cooooo00?o003oooooooooool0:oooool2o`00oeOooooo0Ol00001ooooo`0000?o0000
ooooooooool0UOooool00ol00?ooooooooooo`0Yooooo`03o`00oooooooooooo05Oooooo0Ol00001
ooooo`0000?o0000ooooooooool0Q?ooool20?mo013ooooo0_l00?lWooooo`;o003oF_ooool1o`00
007ooooo00000ol0003oooooooooo`23ooooo`@0ogl04Oooool00ol00?ooooooooooo`0Qooooo`?o
003oG?ooool1o`00007ooooo00000ol0003oooooooooo`23ooooo`@0ogl04_ooool00ol00?oooooo
ooooo`0Nooooo`;o003oGoooool1o`00007ooooo00000ol0003oooooooooo`24ooooo`80ogl05?oo
ool00ol00?ooooooooooo`0Eooooo`80ogl00oooool3o`00of7ooooo0Ol00001ooooo`0000?o0000
ooooooooool0Voooool5o`00oa7ooooo0P3oO`04o`00ofCooooo0Ol00001ooooo`0000?o0000oooo
ooooool0X?ooool7o`00o`Oooooo1Ol00?l20?mo06Kooooo0Ol00001ooooo`0000?o0000oooooooo
ool0Yoooool7o`00o`Cooooo0P3oO`1Wooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo
7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000
ooooooooool0Noooool20?mo09kooooo0Ol00001ooooo`0000?o0000ooooooooool0N_ooool40?mo
09gooooo0Ol00001ooooo`0000?o0000ooooooooool0N_ooool40?mo023ooooo0P3oO`1kooooo`7o
00000Oooool00003o`000?oooooooooo07_ooooo0P3oO`0Pooooo`@0ogl0N_ooool1o`00007ooooo
00000ol0003oooooooooo`2Mooooo`@0ogl0N_ooool1o`00007ooooo00000ol0003oooooooooo`2@
ooooo`80ogl03?ooool20?mo07_ooooo0Ol00001ooooo`0000?o0000ooooooooool0Soooool40?mo
08Sooooo0Ol00001ooooo`0000?o0000ooooooooool0Soooool40?mo08Sooooo0Ol00001ooooo`00
00?o0000ooooooooool0T?ooool20?mo02?ooooo0P3oO`1Tooooo`7o00000Oooool00003o`000?oo
oooooooo0;Cooooo103oO`1Sooooo`7o00000Oooool00003o`000?oooooooooo0;Cooooo103oO`1S
ooooo`7o00000Oooool00003o`000?oooooooooo0;Gooooo0P3oO`1Tooooo`7o00000Oooool00003
o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo
0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oooooo
oooo0?oooooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001oooo
o`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo
7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000
ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00
007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0
oooooolLooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo0000
0ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLoooo
o`7o00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003ooooo
ooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Ooo
ool00003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooo
oacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`00
0?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol0
0001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo
0?oooooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`00
00?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?oo
ool1o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000oooo
ooooool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007o
oooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooo
oolLooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0
003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o
00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003ooooooooo
o`2>ooooo`80ogl0Roooool1o`00007ooooo00000ol0003oooooooooo`2=ooooo`@0ogl0R_ooool1
o`00007ooooo00000ol0003oooooooooo`2=ooooo`@0ogl0R_ooool1o`00007ooooo00000ol0003o
ooooooooo`2>ooooo`80ogl0Roooool1o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo
0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oooooo
oooo0?oooooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001oooo
o`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo
7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000
ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00
007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0
oooooolLooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo0000
0ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLoooo
o`7o00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003ooooo
ooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Ooo
ool00003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooo
oacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`00
0?oooooooooo0?oooooo7?ooool1o`00007ooooo003oo`00023o00000Oooool00001\
\>"],
  ImageRangeCache->{{{0, 287}, {287, 0}} -> {-1.01089, -1.01089, 0.00704453, \
0.00704453}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.49505 0.5 0.49505 [
[ 0 0 -0.125 0 ]
[ 0 0 -0.125 0 ]
[ 0 1 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
0 0 m
1 0 L
s
0 0 m
0 1 L
s
0 1 m
1 1 L
s
1 0 m
1 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
1 .5 0 r
.015 w
.03175 .1355 Mdot
.03435 .12523 Mdot
.11137 .12765 Mdot
.14107 .18841 Mdot
.16218 .24538 Mdot
.17294 .21053 Mdot
.18267 .18577 Mdot
.18434 .1304 Mdot
.18553 .30956 Mdot
.20401 .239 Mdot
.21247 .27571 Mdot
.21687 .20845 Mdot
.22376 .2799 Mdot
.22832 .27485 Mdot
.29063 .20974 Mdot
.29686 .25079 Mdot
.30487 .22936 Mdot
.30683 .34623 Mdot
.32055 .20902 Mdot
.32574 .21979 Mdot
.34472 .28521 Mdot
.35998 .36393 Mdot
.36335 .24976 Mdot
.3794 .36608 Mdot
.42386 .66992 Mdot
.44391 .74519 Mdot
.45059 .34198 Mdot
.47208 .67586 Mdot
.47436 .71381 Mdot
.49778 .59825 Mdot
.50874 .91643 Mdot
.51516 .76219 Mdot
.53655 .61374 Mdot
.56563 .75219 Mdot
.59189 .65665 Mdot
.59581 .61604 Mdot
.59923 .6556 Mdot
.60292 .68499 Mdot
.62656 .67779 Mdot
.63555 .72451 Mdot
.63919 .652 Mdot
.64169 .6004 Mdot
.64246 .58611 Mdot
.64496 .54267 Mdot
.64608 .77288 Mdot
.65077 .64308 Mdot
.66065 .57816 Mdot
.67474 .59169 Mdot
.69296 .563 Mdot
.72815 .65902 Mdot
.73169 .58879 Mdot
.74669 .61318 Mdot
.74821 .65474 Mdot
.75963 .63781 Mdot
.79673 .57809 Mdot
.80925 .55852 Mdot
.81525 .58444 Mdot
.83417 .62985 Mdot
.83598 .55526 Mdot
.91595 .49319 Mdot
1 0 0 r
.005 w
.16128 .17044 m
.18734 .17269 L
.21339 .17909 L
.2345 .18734 L
.23945 .19126 L
.2655 .20415 L
.27874 .21339 L
.29156 .22295 L
.31204 .23945 L
.31761 .24533 L
.33549 .2655 L
.34367 .28342 L
.34499 .29156 L
.34367 .29797 L
.31761 .3104 L
.29156 .30711 L
.2655 .30014 L
.24507 .29156 L
.23945 .28747 L
.21339 .27402 L
.20155 .2655 L
.18734 .25472 L
.16884 .23945 L
.16128 .2313 L
.14618 .21339 L
.13806 .18734 L
.16128 .17044 L
s
0 0 1 r
.65633 .57699 m
.68239 .5684 L
.70844 .56312 L
.7345 .56167 L
.76055 .5752 L
.76359 .57817 L
.76859 .60422 L
.76055 .62333 L
.75628 .63028 L
.7345 .65486 L
.73299 .65633 L
.70844 .6775 L
.69924 .68239 L
.68239 .69295 L
.65633 .7058 L
.64985 .70844 L
.63028 .7154 L
.60422 .72268 L
.57817 .72651 L
.55211 .7214 L
.53145 .70844 L
.52926 .68239 L
.54238 .65633 L
.55211 .63981 L
.56623 .63028 L
.57817 .61928 L
.60117 .60422 L
.60422 .60225 L
.63028 .58724 L
.6531 .57817 L
.65633 .57699 L
s
1 0 0 r
.03 w
.24141 .24033 Mdot
0 0 1 r
.64872 .64417 Mdot
1 0 0 r
.79703 .00495 m
.79703 .25248 L
.87129 .25248 L
.87129 .00495 L
F
0 0 1 r
.89604 .00495 m
.89604 .00495 L
.9703 .00495 L
.9703 .00495 L
F
1 0 1 r
.04 w
.03175 .1355 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  AnimationDisplayTime->0.371293,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P000182000`400?l00000o`00003ooooooolQ
ooooo`00ool0000Po`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`00
00?o0000ooooooooool0hOoooolEool002Gooooo0Ol00001ooooo`0000?o0000ooooooooool0hOoo
oolEool002Gooooo0Ol00001ooooo`0000?o0000ooooooooool0hOoooolEool002Gooooo0Ol00001
ooooo`0000?o0000ooooooooool0hOoooolEool002Gooooo0Ol00001ooooo`0000?o0000oooooooo
ool0hOoooolEool002Gooooo0Ol00001ooooo`0000?o0000ooooooooool0hOoooolEool002Gooooo
0Ol00001ooooo`0000?o0000ooooooooool0hOoooolEool002Gooooo0Ol00001ooooo`0000?o0000
ooooooooool0hOoooolEool002Gooooo0Ol00001ooooo`0000?o0000ooooooooool0hOoooolEool0
02Gooooo0Ol00001ooooo`0000?o0000ooooooooool0hOoooolEool002Gooooo0Ol00001ooooo`00
00?o0000ooooooooool0hOoooolEool002Gooooo0Ol00001ooooo`0000?o0000ooooooooool0hOoo
oolEool002Gooooo0Ol00001ooooo`0000?o0000ooooooooool0hOoooolEool002Gooooo0Ol00001
ooooo`0000?o0000ooooooooool0hOoooolEool002Gooooo0Ol00001ooooo`0000?o0000oooooooo
ool0hOoooolEool002Gooooo0Ol00001ooooo`0000?o0000ooooooooool0hOoooolEool002Gooooo
0Ol00001ooooo`0000?o0000ooooooooool0hOoooolEool002Gooooo0Ol00001ooooo`0000?o0000
ooooooooool0hOoooolEool002Gooooo0Ol00001ooooo`0000?o0000ooooooooool0hOoooolEool0
02Gooooo0Ol00001ooooo`0000?o0000ooooooooool0hOoooolEool002Gooooo0Ol00001ooooo`00
00?o0000ooooooooool0hOoooolEool002Gooooo0Ol00001ooooo`0000?o0000ooooooooool0hOoo
oolEool002Gooooo0Ol00001ooooo`0000?o0000ooooooooool0hOoooolEool002Gooooo0Ol00001
ooooo`0000?o0000ooooooooool0hOoooolEool002Gooooo0Ol00001ooooo`0000?o0000oooooooo
ool0hOoooolEool002Gooooo0Ol00001ooooo`0000?o0000ooooooooool0hOoooolEool002Gooooo
0Ol00001ooooo`0000?o0000ooooooooool0hOoooolEool002Gooooo0Ol00001ooooo`0000?o0000
ooooooooool0hOoooolEool002Gooooo0Ol00001ooooo`0000?o0000ooooooooool0hOoooolEool0
02Gooooo0Ol00001ooooo`0000?o0000ooooooooool0hOoooolEool002Gooooo0Ol00001ooooo`00
00?o0000ooooooooool0hOoooolEool002Gooooo0Ol00001ooooo`0000?o0000ooooooooool0hOoo
oolEool002Gooooo0Ol00001ooooo`0000?o0000ooooooooool01?ooool5ool0omSooooo5Ooo000U
ooooo`7o00000Oooool00003o`000?oooooooooo00?ooooo1ooo0?lBooooo`;oogl0`ooooolEool0
02Gooooo0Ol00001ooooo`0000?o0000ooooooooool00_ooool9ool0oa3ooooo1?ooO`0Booooo`;o
ogl0[_oooolEool002Gooooo0Ol00001ooooo`0000Co0000oooooooooooooooo2ooo0?l?ooooo`Co
ogl04Oooool4oomo0:gooooo5Ooo000Uooooo`7o00000Oooool00004o`000?ooooooooooooooo`_o
o`3o4?ooool2oomo01;ooooo1?ooO`2]oooooaGoo`009Oooool1o`00007ooooo00001?l0003ooooo
ooooooooool;ool0obGooooo0_ooO`2^oooooaGoo`009Oooool1o`00007ooooo00001?l0003ooooo
ooooooooool;ool0omGooooo5Ooo000Uooooo`7o00000Oooool00004o`000?ooooooooooooooo`_o
o`3oeOoooolEool002Gooooo0Ol00001ooooo`0000?o0000ooooooooool00_ooool9ool0omKooooo
5Ooo000Uooooo`7o00000Oooool00003o`000?oooooooooo00?ooooo1ooo0?oGoooooaGoo`009Ooo
ool1o`00007ooooo00000ol0003oooooooooo`04ooooo`Goo`3of?oooolEool002Gooooo0Ol00001
ooooo`0000?o0000ooooooooool0hOoooolEool002Gooooo0Ol00001ooooo`0000?o0000oooooooo
ool0hOoooolEool002Gooooo0Ol00001ooooo`0000?o0000ooooooooool0hOoooolEool002Gooooo
0Ol00001ooooo`0000?o0000ooooooooool0:_ooool6ool00;7ooooo5Ooo000Uooooo`7o00000Ooo
ool00003o`000?oooooooooo02Wooooo00?oo`00ooooooooool01?ooool5ool00:cooooo5Ooo000U
ooooo`7o00000Oooool00003o`000?oooooooooo02Oooooo0_oo000<ooooo`Coo`00Z?oooolEool0
02Gooooo0Ol00001ooooo`0000?o0000ooooooooool09_ooool00ooo003oooooooooo`0@ooooo`Co
o`00Y?oooolEool002Gooooo0Ol00001ooooo`0000?o0000ooooooooool09?ooool00oooO`3oo`00
ooooo`09ooooo`;oogl02oooool3ool00:7ooooo5Ooo000Uooooo`7o00000Oooool00003o`000?oo
oooooooo02?ooooo00Coogl0ool00?ooO`3oogl02?ooool4oomo00gooooo00?oo`00ooooooooool0
W_oooolEool002Gooooo0Ol00001ooooo`0000?o0000ooooooooool08oooool01?ooO`3oo`00oomo
0?ooO`08ooooo`Coogl03_ooool2ool009kooooo5Ooo000Uooooo`7o00000Oooool00003o`000?oo
oooooooo02Cooooo00?oogl0ool00?ooool02Oooool2oomo017ooooo0_oo002LoooooaGoo`009Ooo
ool1o`00007ooooo00000ol0003oooooooooo`0Uooooo`03ool00?oooooooooo01gooooo0_oo002J
oooooaGoo`009Oooool1o`00007ooooo00000ol0003oooooooooo`0Uooooo`03ool00?oooooooooo
01oooooo0_oo002HoooooaGoo`009Oooool1o`00007ooooo00000ol0003oooooooooo`0Vooooo`03
ool00?oooooooooo017ooooo0_ooO`0=ooooo`;oo`001?ooool2oomo00Oooooo0_ooO`27oooooaGo
o`009Oooool1o`00007ooooo00000ol0003oooooooooo`0Vooooo`03ool00?oooooooooo00Gooooo
0_ooO`09ooooo`Coogl03_ooool00ooo003oooooooooo`04oomo00Gooooo1?ooO`26oooooaGoo`00
9Oooool1o`00007ooooo00000ol0003oooooooooo`0Vooooo`03ool00?oooooooooo00Cooooo1?oo
O`08ooooo`Coogl03oooool00ooo003ooooooomo0003oomo00Gooooo1?ooO`26oooooaGoo`009Ooo
ool1o`00007ooooo00000ol0003oooooooooo`0Wooooo`03ool00?oooooooooo00?ooooo1?ooO`09
ooooo`;oogl04Oooool01?oo003ooooooomo0?ooO`07ooooo`?oogl0Q_oooolEool002Gooooo0Ol0
0001ooooo`0000?o0000ooooooooool09oooool00ooo003oooooooooo`04ooooo`;oogl07_ooool0
0ooo003oooooooooo`07ooooo`Coogl0QOoooolEool002Gooooo0Ol00001ooooo`0000?o0000oooo
ooooool0:?ooool00ooo003oooooooooo`0Tooooo`03ool00?oooooooooo00Kooooo1?ooO`25oooo
oaGoo`009Oooool1o`00007ooooo00000ol0003oooooooooo`0Yooooo`03ool00?oooooooooo02Co
oooo0_oo00000oooooooogl0oomo0004ooooo`;oogl0Q_oooolEool002Gooooo0Ol00001ooooo`00
00?o0000ooooooooool0:_ooool00ooo003oooooooooo`0Cooooo`Coo`003_ooool01?oo003oogl0
oomo0?ooO`2;oooooaGoo`009Oooool1o`00007ooooo00000ol0003oooooooooo`0[ooooo`03ool0
0?oooooooooo017ooooo1_oo000=ooooo`04oomo0?oo003oo`00oomo08_ooooo5Ooo000Uooooo`7o
00000Oooool00003o`000?oooooooooo02cooooo00?oo`00ooooooooool02?ooool2oomo00Gooooo
2?oo000=ooooo`;oogl000?oo`00ooooooooool0ROoooolEool002Gooooo0Ol00001ooooo`0000?o
0000ooooooooool0;Oooool00ooo003oooooooooo`06ooooo`Coogl01?ooool8ool0013ooooo00?o
o`00ooooooooool0R?oooolEool002Gooooo0Ol00001ooooo`0000?o0000ooooooooool0:oooool2
oomo0003oooooooo003ooooo00Kooooo1?ooO`04ooooo`Soo`004Oooool00ooo003oooooooooo`27
oooooaGoo`009Oooool1o`00007ooooo00000ol0003oooooooooo`0Zooooo`Coogl000?oooooool0
0?ooool01_ooool2oomo00Gooooo2?oo000;ooooo`;oogl01Oooool00ooo003oooooooooo`09oooo
o`;oogl0NooooolEool002Gooooo0Ol00001ooooo`0000?o0000ooooooooool0:_ooool4oomo00;o
oooo00?oo`00ooooooooool03?ooool6ool000_ooooo1?ooO`04ooooo`03ool00?oooooooooo00So
oooo1?ooO`1joooooaGoo`009Oooool1o`00007ooooo00000ol0003oooooooooo`0[ooooo`;oogl0
1?ooool00ooo003oooooooooo`0<ooooo`Coo`003?ooool4oomo00Gooooo00?oo`00ooooooooool0
1oooool4oomo07[ooooo5Ooo000Uooooo`7o00000Oooool00003o`000?oooooooooo03;ooooo0_oo
000Mooooo`;oogl01oooool00ooo003oooooooooo`07ooooo`;oogl0]Oooool1o`00007ooooo0000
0ol0003oooooooooo`0dooooo`03ool00?oooooooooo02Cooooo00?oo`00ooooooooool0_Oooool1
o`00007ooooo00000ol0003oooooooooo`0eooooo`03ool00?oooooooooo02Cooooo00?oo`00oooo
ooooool0_?ooool1o`00007ooooo00000ol0003oooooooooo`0fooooo`;oo`009Oooool00ooo003o
ooooooooo`2kooooo`7o00000Oooool00003o`000?oooooooooo03Sooooo0_oo00000oooO`3ooooo
ooooo`02oomo01kooooo00?oo`00ooooooooool0^oooool1o`00007ooooo00000ol0003ooooooooo
o`0hooooo`;oogl00_oo0004oomo01kooooo00?oo`00ooooooooool0^_ooool1o`00007ooooo0000
0ol0003oooooooooo`0hooooo`Coogl00_oo0002oomo01kooooo00?oo`00ooooooooool0^_ooool1
o`00007ooooo00000ol0003oooooooooo`0iooooo`Googl000?oo`00ooooooooool07Oooool00ooo
003oogl0oomo002jooooo`7o00000Oooool00003o`000?oooooooooo03_ooooo1?ooO`02ool001go
oooo00Coogl0ool00?ooO`3oogl0^Oooool1o`00007ooooo00000ol0003oooooooooo`0looooo`;o
ogl00oooool2ool001_ooooo00Coogl0ool00?ooO`3oogl0^Oooool1o`00007ooooo00000ol0003o
ooooooooo`13ooooo`;oo`006_ooool00oooO`3oo`00ooooo`2iooooo`7o00000Oooool00003o`00
0?oooooooooo04Gooooo0_oo000Iooooo`03ool00?oooooooooo0;Sooooo0Ol00001ooooo`0000?o
0000ooooooooool0Aoooool2ool001Gooooo0_oo002kooooo`7o00000Oooool00003o`000?oooooo
oooo04Wooooo0ooo000@ooooo`;oo`00_Oooool1o`00007ooooo00000ol0003oooooooooo`0aoooo
o`;oogl06Oooool3ool000cooooo00?oo`00ooooooooool0_Oooool1o`00007ooooo00000ol0003o
ooooooooo`0`ooooo`Coogl06oooool6ool000Cooooo0_oo0030ooooo`7o00000Oooool00003o`00
0?oooooooooo033ooooo1?ooO`0Qooooo`Coo`00`_ooool1o`00007ooooo00000ol0003ooooooooo
o`0aooooo`;oogl0j?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001
ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo0?oo
oooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o
0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo07gooooo0_ooO`2L
ooooo`7o00000Oooool00003o`000?oooooooooo07cooooo1?ooO`2Kooooo`7o00000Oooool00003
o`000?oooooooooo05Cooooo0_ooO`0Vooooo`Coogl0Voooool1o`00007ooooo00000ol0003ooooo
ooooo`1Cooooo`Coogl09_ooool2oomo09cooooo0Ol00001ooooo`0000?o0000ooooooooool0Dooo
ool4oomo0<Cooooo0Ol00001ooooo`0000?o0000ooooooooool0E?ooool2oomo0<Gooooo0Ol00001
ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo06?o
oooo0_ooO`04ooooo`;oogl0/?ooool1o`00007ooooo00000ol0003oooooooooo`1Rooooo`Coogl0
0_ooool4oomo0:oooooo0Ol00001ooooo`0000?o0000ooooooooool0H_ooool4oomo00;ooooo1?oo
O`2_ooooo`7o00000Oooool00003o`000?oooooooooo06?ooooo0_ooO`04ooooo`;oogl0/?ooool1
o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000oooooooo
ool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo
00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolL
ooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003o
ooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o0000
0Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3o
oooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003
o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo
0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oooooo
oooo0?oooooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001oooo
o`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo
7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000
ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00
007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0
oooooolLooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo0000
0ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLoooo
o`7o00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003ooooo
ooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Ooo
ool00003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooo
oacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`00
0?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3oooooo`Cooooo0_oo
O`0Fooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo0oooool4oomo01Gooooo0Ol00001
ooooo`0000?o0000ooooooooool0ooooool3ooooo`Coogl05Oooool1o`00007ooooo00000ol0003o
ooooooooo`3oooooo`Cooooo0_ooO`0Fooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo
7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000
ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00
007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0
oooooolLooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo0000
0ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLoooo
o`7o00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003ooooo
ooooo`2eooooo`;oogl0I?ooool1o`00007ooooo00000ol0003oooooooooo`2dooooo`Coogl0Hooo
ool1o`00007ooooo00000ol0003oooooooooo`2dooooo`Coogl0Hoooool1o`00007ooooo00000ol0
003oooooooooo`2eooooo`;oogl0=Oooool2oomo02gooooo0Ol00001ooooo`0000?o0000oooooooo
ool0i?ooool2oomo00Gooooo1?ooO`0/ooooo`7o00000Oooool00003o`000?oooooooooo0>?ooooo
1?ooO`04ooooo`Coogl0;?ooool1o`00007ooooo00000ol0003oooooooooo`33ooooo`;oogl07_oo
ool4oomo00Gooooo0_ooO`0]ooooo`7o00000Oooool00003o`000?oooooooooo0<;ooooo1?ooO`0;
o`00oa?ooooo0_ooO`0eooooo`7o00000Oooool00003o`000?oooooooooo0<;ooooo1?l00?l;oooo
o`;o003oB?ooool1o`00007ooooo00000ol0003oooooooooo`2nooooo`Co003o00?ooooooomo0?oo
O`003_ooool2o`00odKooooo0Ol00001ooooo`0000?o0000ooooooooool0^Oooool2oomo00?o003o
5oooool2o`00o`Wooooo0_ooO`0iooooo`7o00000Oooool00003o`000?oooooooooo0;Oooooo1?l0
0?l00oooO`3oooooooooo`0Iooooo`;o003o1_ooool4oomo03Sooooo0Ol00001ooooo`0000?o0000
ooooooooool0]?ooool3o`00o`03ooooooooO`3oogl000;oogl07?ooool00ol00?ooooooooooo`04
ooooo`Coogl00oooool2oomo03?ooooo0Ol00001ooooo`0000?o0000ooooooooool0/_ooool2o`00
o`?oogl00_ooool2oomo01?ooooo0_ooO`08ooooo`03o`00oooooooooooo00Gooooo0_ooO`03oooo
o`Coogl0<_ooool1o`00007ooooo00000ol0003oooooooooo`2`ooooo`;o003o00?ooooooomo0?oo
O`000_ooO`06ooooo`;oogl03_ooool4oomo00Oooooo00?o003oooooooooool02_ooool4oomo03;o
oooo0Ol00001ooooo`0000?o0000ooooooooool0[_ooool2o`00o`Cooooo0_ooO`06ooooo`Coogl0
3Oooool4oomo00Oooooo00?o003oooooooooool02oooool2oomo03?ooooo0Ol00001ooooo`0000?o
0000ooooooooool0Roooool2oomo023ooooo00?o003oooooooooool01?ooool2oomo00Kooooo1?oo
O`0>ooooo`;oogl02Oooool00ol00?ooooooooooo`0oooooo`7o00000Oooool00003o`000?oooooo
oooo08[ooooo1?ooO`0Mooooo`;o003o1_ooool4oomo00Kooooo0_ooO`0Jooooo`03o`00oooooooo
oooo03oooooo0Ol00001ooooo`0000?o0000ooooooooool0R_ooool4oomo01cooooo00?o003ooooo
ooooool01_ooool4oomo02;ooooo00?o003oooooooooool0?oooool1o`00007ooooo00000ol0003o
ooooooooo`2;ooooo`;oogl06oooool2o`00o`[ooooo0_ooO`0Sooooo`03o`00oooooooooooo03oo
oooo0Ol00001ooooo`0000?o0000ooooooooool0U_ooool2oomo00kooooo0_l00?lZooooo`;oogl0
1Oooool00ol00?ooooooooooo`0oooooo`7o00000Oooool00003o`000?oooooooooo09Gooooo1?oo
O`0<ooooo`04o`00ooooooooogl0oomo02Sooooo1?ooO`03ooooo`03o`00oooooooooooo043ooooo
0Ol00001ooooo`0000?o0000ooooooooool0UOooool4oomo00[ooooo0_l00?l00oooooooogl0oomo
0002oomo02Oooooo1?ooO`03ooooo`03o`00oooooooooooo043ooooo0Ol00001ooooo`0000?o0000
ooooooooool0U_ooool2oomo00[ooooo00Co003ooooooooooooooooo1?ooO`0Xooooo`;oogl01?oo
ool00ol00?ooooooooooo`10ooooo`7o00000Oooool00003o`000?oooooooooo0:7ooooo00?o003o
ooooooooool00oooool2oomo02kooooo00?o003oooooooooool0@Oooool1o`00007ooooo00000ol0
003oooooooooo`2Pooooo`03o`00oooooooooooo03?ooooo00?o003oooooooooool04_ooool2oomo
02kooooo0Ol00001ooooo`0000?o0000ooooooooool0W_ooool2o`00ocGooooo00?o003ooooooooo
ool04_ooool4oomo02gooooo0Ol00001ooooo`0000?o0000ooooooooool0WOooool00ol00?oooooo
ooooo`0Eooooo`Co003o7?ooool00ol00?ooogl0oomo000Booooo`Coogl0;Oooool1o`00007ooooo
00000ol0003oooooooooo`2Looooo`03o`00oooooooooooo01Gooooo1_l00?lJooooo`03o`00oooo
O`3oogl000;oogl04_ooool2oomo02kooooo0Ol00001ooooo`0000?o0000ooooooooool0Voooool0
0ol00?ooooooooooo`0Eooooo`So003o6?ooool00ol00?oooooooomo0003oomo04;ooooo0Ol00001
ooooo`0000?o0000ooooooooool0Voooool00ol00?ooooooooooo`0Eooooo`So003o5oooool01?l0
0?ooooooooooooooool2oomo04?ooooo0Ol00001ooooo`0000?o0000ooooooooool0V_ooool00ol0
0?ooooooooooo`0Fooooo`So003o5_ooool00ol00?ooooooooooo`17ooooo`7o00000Oooool00003
o`000?oooooooooo09Wooooo00?o003oooooooooool03?ooool2oomo00Sooooo00?oogl0o`00ool0
0?l01_l00?lEooooo`03o`00oooooooooooo00;oogl0A_ooool1o`00007ooooo00000ol0003ooooo
ooooo`2Iooooo`03o`00oooooooooooo00[ooooo1OooO`07ooooo`;oogl01_l00?lCooooo`;oogl0
00?o003oooooooooool01?ooO`15ooooo`7o00000Oooool00003o`000?oooooooooo09Sooooo00?o
003oooooooooool02_ooool6oomo00Sooooo0_ooO`04o`00oa?ooooo0_ooO`02o`00o`;ooooo1?oo
O`15ooooo`7o00000Oooool00003o`000?oooooooooo09Sooooo00?o003oooooooooool02_ooool5
oomo02;ooooo00Coogl0o`00ooooO`3oogl00oooool2oomo04Kooooo0Ol00001ooooo`0000?o0000
ooooooooool0M_ooool2oomo01oooooo00?o003oooooooooool03?ooool2oomo02Cooooo00?o003o
oomo0?ooO`00C?ooool1o`00007ooooo00000ol0003oooooooooo`1eooooo`Coogl07_ooool00ol0
0?ooooooooooo`0aooooo`03o`00oooooooooooo04gooooo0Ol00001ooooo`0000?o0000oooooooo
ool0MOooool4oomo00[ooooo0_ooO`0Aooooo`03o`00oooooooooooo037ooooo00?o003ooooooooo
ool0C_ooool1o`00007ooooo00000ol0003oooooooooo`1fooooo`;oogl02_ooool4oomo00oooooo
00?o003oooooooooool06?ooool2oomo01Oooooo00?o003oooooooooool0Coooool1o`00007ooooo
00000ol0003oooooooooo`22ooooo`Coogl03oooool00ol00?ooooooooooo`0Gooooo`Coogl05?oo
ool2o`00oe;ooooo0Ol00001ooooo`0000?o0000ooooooooool0Poooool2oomo00oooooo00?o003o
ooooooooool04_ooool2oomo00Cooooo1?ooO`0Aooooo`?o003oE?ooool1o`00007ooooo00000ol0
003oooooooooo`2Dooooo`03o`00oooooooooooo017ooooo1?ooO`04ooooo`;oogl04?ooool2o`00
oeOooooo0Ol00001ooooo`0000?o0000ooooooooool0U?ooool00ol00?ooooooooooo`0Aooooo`Co
ogl05Oooool00ol00?ooooooooooo`1Gooooo`7o00000Oooool00003o`000?oooooooooo09Cooooo
00?o003oooooooooool04_ooool2oomo01Cooooo0_l00?mJooooo`7o00000Oooool00003o`000?oo
oooooooo09Cooooo00?o003oooooooooool09_ooool2o`00oecooooo0Ol00001ooooo`0000?o0000
ooooooooool0UOooool00ol00?ooooooooooo`0Tooooo`03o`00oooooooooooo05cooooo0Ol00001
ooooo`0000?o0000ooooooooool0UOooool00ol00?ooooooooooo`0Rooooo`;o003oGoooool1o`00
007ooooo00000ol0003oooooooooo`2Eooooo`03o`00oooooooooooo023ooooo0_l00?mQooooo`7o
00000Oooool00003o`000?oooooooooo08Cooooo0_ooO`0?ooooo`;o003o7oooool2o`00of?ooooo
0Ol00001ooooo`0000?o0000ooooooooool0Poooool4oomo013ooooo0_l00?lJooooo`?o003oIOoo
ool1o`00007ooooo00000ol0003oooooooooo`23ooooo`Coogl04_ooool2o`00oaCooooo1?l00?mX
ooooo`7o00000Oooool00003o`000?oooooooooo08Cooooo0_ooO`0Eooooo`?o003o3_ooool3o`00
o`?ooooo0_ooO`1Wooooo`7o00000Oooool00003o`000?oooooooooo09kooooo0ol00?l5ooooo`Ko
003o1Oooool4oomo06Kooooo0Ol00001ooooo`0000?o0000ooooooooool0XOooool5o`00o`_ooooo
1?ooO`1Vooooo`7o00000Oooool00003o`000?oooooooooo0;;ooooo0_ooO`1Wooooo`7o00000Ooo
ool00003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooo
oacooooo0Ol00001ooooo`0000?o0000ooooooooool0Noooool2oomo09kooooo0Ol00001ooooo`00
00?o0000ooooooooool0N_ooool4oomo09gooooo0Ol00001ooooo`0000?o0000ooooooooool0N_oo
ool4oomo023ooooo0_ooO`1kooooo`7o00000Oooool00003o`000?oooooooooo07_ooooo0_ooO`0P
ooooo`Coogl0N_ooool1o`00007ooooo00000ol0003oooooooooo`2Mooooo`Coogl0N_ooool1o`00
007ooooo00000ol0003oooooooooo`2@ooooo`;oogl03?ooool2oomo07_ooooo0Ol00001ooooo`00
00?o0000ooooooooool0Soooool4oomo08Sooooo0Ol00001ooooo`0000?o0000ooooooooool0Sooo
ool4oomo08Sooooo0Ol00001ooooo`0000?o0000ooooooooool0T?ooool2oomo02?ooooo0_ooO`1T
ooooo`7o00000Oooool00003o`000?oooooooooo0;Cooooo1?ooO`1Sooooo`7o00000Oooool00003
o`000?oooooooooo0;Cooooo1?ooO`1Sooooo`7o00000Oooool00003o`000?oooooooooo0;Gooooo
0_ooO`1Tooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo0000
0ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLoooo
o`7o00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003ooooo
ooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Ooo
ool00003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooo
oacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`00
0?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol0
0001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo
0?oooooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`00
00?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?oo
ool1o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000oooo
ooooool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007o
oooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooo
oolLooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0
003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o
00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003ooooooooo
o`3ooooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool0
0003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooooaco
oooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oo
oooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001
ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo0?oo
oooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o
0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1
o`00007ooooo00000ol0003oooooooooo`2>ooooo`;oogl0Roooool1o`00007ooooo00000ol0003o
ooooooooo`2=ooooo`Coogl0R_ooool1o`00007ooooo00000ol0003oooooooooo`2=ooooo`Coogl0
R_ooool1o`00007ooooo00000ol0003oooooooooo`2>ooooo`;oogl0Roooool1o`00007ooooo0000
0ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLoooo
o`7o00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003ooooo
ooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Ooo
ool00003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooo
oacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`00
0?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol0
0001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo
0?oooooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`00
00?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?oo
ool1o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000oooo
ooooool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007o
oooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooo
oolLooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo003oo`00
023o00000Oooool00001\
\>"],
  ImageRangeCache->{{{0, 287}, {287, 0}} -> {-1.01089, -1.01089, 0.00704453, \
0.00704453}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.49505 0.5 0.49505 [
[ 0 0 -0.125 0 ]
[ 0 0 -0.125 0 ]
[ 0 1 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
0 0 m
1 0 L
s
0 0 m
0 1 L
s
0 1 m
1 1 L
s
1 0 m
1 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
1 .5 0 r
.015 w
.03175 .1355 Mdot
.03435 .12523 Mdot
.11137 .12765 Mdot
.14107 .18841 Mdot
.16218 .24538 Mdot
.17294 .21053 Mdot
.18267 .18577 Mdot
.18434 .1304 Mdot
.18553 .30956 Mdot
.20401 .239 Mdot
.21247 .27571 Mdot
.21687 .20845 Mdot
.22376 .2799 Mdot
.22832 .27485 Mdot
.29063 .20974 Mdot
.29686 .25079 Mdot
.30487 .22936 Mdot
.30683 .34623 Mdot
.32055 .20902 Mdot
.32574 .21979 Mdot
.34472 .28521 Mdot
.35998 .36393 Mdot
.36335 .24976 Mdot
.3794 .36608 Mdot
.42386 .66992 Mdot
.44391 .74519 Mdot
.45059 .34198 Mdot
.47208 .67586 Mdot
.47436 .71381 Mdot
.49778 .59825 Mdot
.50874 .91643 Mdot
.51516 .76219 Mdot
.53655 .61374 Mdot
.56563 .75219 Mdot
.59189 .65665 Mdot
.59581 .61604 Mdot
.59923 .6556 Mdot
.60292 .68499 Mdot
.62656 .67779 Mdot
.63555 .72451 Mdot
.63919 .652 Mdot
.64169 .6004 Mdot
.64246 .58611 Mdot
.64496 .54267 Mdot
.64608 .77288 Mdot
.65077 .64308 Mdot
.66065 .57816 Mdot
.67474 .59169 Mdot
.69296 .563 Mdot
.72815 .65902 Mdot
.73169 .58879 Mdot
.74669 .61318 Mdot
.74821 .65474 Mdot
.75963 .63781 Mdot
.79673 .57809 Mdot
.80925 .55852 Mdot
.81525 .58444 Mdot
.83417 .62985 Mdot
.83598 .55526 Mdot
.91595 .49319 Mdot
1 0 0 r
.005 w
.16128 .17044 m
.18734 .17269 L
.21339 .17909 L
.2345 .18734 L
.23945 .19126 L
.2655 .20415 L
.27874 .21339 L
.29156 .22295 L
.31204 .23945 L
.31761 .24532 L
.33549 .2655 L
.34367 .28341 L
.34499 .29156 L
.34367 .29798 L
.31761 .3104 L
.29156 .30711 L
.2655 .30014 L
.24507 .29156 L
.23945 .28747 L
.21339 .27402 L
.20155 .2655 L
.18734 .25472 L
.16884 .23945 L
.16128 .2313 L
.14618 .21339 L
.13806 .18734 L
.16128 .17044 L
s
0 0 1 r
.65633 .57701 m
.68239 .56842 L
.70844 .56313 L
.7345 .56168 L
.76055 .5752 L
.76359 .57817 L
.76859 .60422 L
.76055 .62333 L
.75627 .63028 L
.7345 .65485 L
.73298 .65633 L
.70844 .6775 L
.69922 .68239 L
.68239 .69294 L
.65633 .70579 L
.64983 .70844 L
.63028 .71539 L
.60422 .72268 L
.57817 .72651 L
.55211 .7214 L
.53145 .70844 L
.52926 .68239 L
.54239 .65633 L
.55211 .63983 L
.56625 .63028 L
.57817 .6193 L
.60119 .60422 L
.60422 .60227 L
.63028 .58726 L
.65315 .57817 L
.65633 .57701 L
s
1 0 0 r
.03 w
.24141 .24033 Mdot
0 0 1 r
.64872 .64417 Mdot
1 0 0 r
.79703 .00495 m
.79703 .25248 L
.87129 .25248 L
.87129 .00495 L
F
0 0 1 r
.89604 .00495 m
.89604 .00495 L
.9703 .00495 L
.9703 .00495 L
F
1 0 1 r
.04 w
.03175 .1355 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  AnimationDisplayTime->0.371293,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P000182000`400?l00000o`00003ooooooolQ
ooooo`00ool0000Po`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`00
00?o0000ooooooooool0hOoooolEool002Gooooo0Ol00001ooooo`0000?o0000ooooooooool0hOoo
oolEool002Gooooo0Ol00001ooooo`0000?o0000ooooooooool0hOoooolEool002Gooooo0Ol00001
ooooo`0000?o0000ooooooooool0hOoooolEool002Gooooo0Ol00001ooooo`0000?o0000oooooooo
ool0hOoooolEool002Gooooo0Ol00001ooooo`0000?o0000ooooooooool0hOoooolEool002Gooooo
0Ol00001ooooo`0000?o0000ooooooooool0hOoooolEool002Gooooo0Ol00001ooooo`0000?o0000
ooooooooool0hOoooolEool002Gooooo0Ol00001ooooo`0000?o0000ooooooooool0hOoooolEool0
02Gooooo0Ol00001ooooo`0000?o0000ooooooooool0hOoooolEool002Gooooo0Ol00001ooooo`00
00?o0000ooooooooool0hOoooolEool002Gooooo0Ol00001ooooo`0000?o0000ooooooooool0hOoo
oolEool002Gooooo0Ol00001ooooo`0000?o0000ooooooooool0hOoooolEool002Gooooo0Ol00001
ooooo`0000?o0000ooooooooool0hOoooolEool002Gooooo0Ol00001ooooo`0000?o0000oooooooo
ool0hOoooolEool002Gooooo0Ol00001ooooo`0000?o0000ooooooooool0hOoooolEool002Gooooo
0Ol00001ooooo`0000?o0000ooooooooool0hOoooolEool002Gooooo0Ol00001ooooo`0000?o0000
ooooooooool0hOoooolEool002Gooooo0Ol00001ooooo`0000?o0000ooooooooool0hOoooolEool0
02Gooooo0Ol00001ooooo`0000?o0000ooooooooool0hOoooolEool002Gooooo0Ol00001ooooo`00
00?o0000ooooooooool0hOoooolEool002Gooooo0Ol00001ooooo`0000?o0000ooooooooool0hOoo
oolEool002Gooooo0Ol00001ooooo`0000?o0000ooooooooool0hOoooolEool002Gooooo0Ol00001
ooooo`0000?o0000ooooooooool0hOoooolEool002Gooooo0Ol00001ooooo`0000?o0000oooooooo
ool0hOoooolEool002Gooooo0Ol00001ooooo`0000?o0000ooooooooool0hOoooolEool002Gooooo
0Ol00001ooooo`0000?o0000ooooooooool0hOoooolEool002Gooooo0Ol00001ooooo`0000?o0000
ooooooooool0hOoooolEool002Gooooo0Ol00001ooooo`0000?o0000ooooooooool0hOoooolEool0
02Gooooo0Ol00001ooooo`0000?o0000ooooooooool0hOoooolEool002Gooooo0Ol00001ooooo`00
00?o0000ooooooooool0hOoooolEool002Gooooo0Ol00001ooooo`0000?o0000ooooooooool0hOoo
oolEool002Gooooo0Ol00001ooooo`0000?o0000ooooooooool01?ooool5ool0omSooooo5Ooo000U
ooooo`7o00000Oooool00003o`000?oooooooooo00?ooooo1ooo0?lBooooo`;oogl0`ooooolEool0
02Gooooo0Ol00001ooooo`0000?o0000ooooooooool00_ooool9ool0oa3ooooo1?ooO`0Booooo`;o
ogl0[_oooolEool002Gooooo0Ol00001ooooo`0000Co0000oooooooooooooooo2ooo0?l?ooooo`Co
ogl04Oooool4oomo0:gooooo5Ooo000Uooooo`7o00000Oooool00004o`000?ooooooooooooooo`_o
o`3o4?ooool2oomo01;ooooo1?ooO`2]oooooaGoo`009Oooool1o`00007ooooo00001?l0003ooooo
ooooooooool;ool0obGooooo0_ooO`2^oooooaGoo`009Oooool1o`00007ooooo00001?l0003ooooo
ooooooooool;ool0omGooooo5Ooo000Uooooo`7o00000Oooool00004o`000?ooooooooooooooo`_o
o`3oeOoooolEool002Gooooo0Ol00001ooooo`0000?o0000ooooooooool00_ooool9ool0omKooooo
5Ooo000Uooooo`7o00000Oooool00003o`000?oooooooooo00?ooooo1ooo0?oGoooooaGoo`009Ooo
ool1o`00007ooooo00000ol0003oooooooooo`04ooooo`Goo`3of?oooolEool002Gooooo0Ol00001
ooooo`0000?o0000ooooooooool0hOoooolEool002Gooooo0Ol00001ooooo`0000?o0000oooooooo
ool0hOoooolEool002Gooooo0Ol00001ooooo`0000?o0000ooooooooool0hOoooolEool002Gooooo
0Ol00001ooooo`0000?o0000ooooooooool0:_ooool6ool00;7ooooo5Ooo000Uooooo`7o00000Ooo
ool00003o`000?oooooooooo02Wooooo00?oo`00ooooooooool01?ooool5ool00:cooooo5Ooo000U
ooooo`7o00000Oooool00003o`000?oooooooooo02Oooooo0_oo000<ooooo`Coo`00Z?oooolEool0
02Gooooo0Ol00001ooooo`0000?o0000ooooooooool09_ooool00ooo003oooooooooo`0@ooooo`Co
o`00Y?oooolEool002Gooooo0Ol00001ooooo`0000?o0000ooooooooool09?ooool00oooO`3oo`00
ooooo`09ooooo`;oogl02oooool3ool00:7ooooo5Ooo000Uooooo`7o00000Oooool00003o`000?oo
oooooooo02?ooooo00Coogl0ool00?ooO`3oogl02?ooool4oomo00gooooo00?oo`00ooooooooool0
W_oooolEool002Gooooo0Ol00001ooooo`0000?o0000ooooooooool08oooool01?ooO`3oo`00oomo
0?ooO`08ooooo`Coogl03_ooool2ool009kooooo5Ooo000Uooooo`7o00000Oooool00003o`000?oo
oooooooo02Cooooo00?oogl0ool00?ooool02Oooool2oomo017ooooo0_oo002LoooooaGoo`009Ooo
ool1o`00007ooooo00000ol0003oooooooooo`0Uooooo`03ool00?oooooooooo01gooooo0_oo002J
oooooaGoo`009Oooool1o`00007ooooo00000ol0003oooooooooo`0Uooooo`03ool00?oooooooooo
01oooooo0_oo002HoooooaGoo`009Oooool1o`00007ooooo00000ol0003oooooooooo`0Vooooo`03
ool00?oooooooooo017ooooo0_ooO`0=ooooo`;oo`001?ooool2oomo00Oooooo0_ooO`27oooooaGo
o`009Oooool1o`00007ooooo00000ol0003oooooooooo`0Vooooo`03ool00?oooooooooo00Gooooo
0_ooO`09ooooo`Coogl03_ooool00ooo003oooooooooo`04oomo00Gooooo1?ooO`26oooooaGoo`00
9Oooool1o`00007ooooo00000ol0003oooooooooo`0Vooooo`03ool00?oooooooooo00Cooooo1?oo
O`08ooooo`Coogl03oooool00ooo003ooooooomo0003oomo00Gooooo1?ooO`26oooooaGoo`009Ooo
ool1o`00007ooooo00000ol0003oooooooooo`0Wooooo`03ool00?oooooooooo00?ooooo1?ooO`09
ooooo`;oogl04Oooool01?oo003ooooooomo0?ooO`07ooooo`?oogl0Q_oooolEool002Gooooo0Ol0
0001ooooo`0000?o0000ooooooooool09oooool00ooo003oooooooooo`04ooooo`;oogl07_ooool0
0ooo003oooooooooo`07ooooo`Coogl0QOoooolEool002Gooooo0Ol00001ooooo`0000?o0000oooo
ooooool0:?ooool00ooo003oooooooooo`0Tooooo`03ool00?oooooooooo00Kooooo1?ooO`25oooo
oaGoo`009Oooool1o`00007ooooo00000ol0003oooooooooo`0Yooooo`03ool00?oooooooooo02Co
oooo0_oo00000oooooooogl0oomo0004ooooo`;oogl0Q_oooolEool002Gooooo0Ol00001ooooo`00
00?o0000ooooooooool0:_ooool00ooo003oooooooooo`0Cooooo`Coo`003_ooool01?oo003oogl0
oomo0?ooO`2;oooooaGoo`009Oooool1o`00007ooooo00000ol0003oooooooooo`0[ooooo`03ool0
0?oooooooooo017ooooo1_oo000=ooooo`04oomo0?oo003oo`00oomo08_ooooo5Ooo000Uooooo`7o
00000Oooool00003o`000?oooooooooo02cooooo00?oo`00ooooooooool02?ooool2oomo00Gooooo
2?oo000=ooooo`;oogl000?oo`00ooooooooool0ROoooolEool002Gooooo0Ol00001ooooo`0000?o
0000ooooooooool0;Oooool00ooo003oooooooooo`06ooooo`Coogl01?ooool8ool0013ooooo00?o
o`00ooooooooool0R?oooolEool002Gooooo0Ol00001ooooo`0000?o0000ooooooooool0:oooool2
oomo0003oooooooo003ooooo00Kooooo1?ooO`04ooooo`Soo`004Oooool00ooo003oooooooooo`27
oooooaGoo`009Oooool1o`00007ooooo00000ol0003oooooooooo`0Zooooo`Coogl000?oooooool0
0?ooool01_ooool2oomo00Gooooo2?oo000;ooooo`;oogl01Oooool00ooo003oooooooooo`09oooo
o`;oogl0NooooolEool002Gooooo0Ol00001ooooo`0000?o0000ooooooooool0:_ooool4oomo00;o
oooo00?oo`00ooooooooool03?ooool6ool000_ooooo1?ooO`04ooooo`03ool00?oooooooooo00So
oooo1?ooO`1joooooaGoo`009Oooool1o`00007ooooo00000ol0003oooooooooo`0[ooooo`;oogl0
1?ooool00ooo003oooooooooo`0<ooooo`Coo`003?ooool4oomo00Gooooo00?oo`00ooooooooool0
1oooool4oomo07[ooooo5Ooo000Uooooo`7o00000Oooool00003o`000?oooooooooo03;ooooo0_oo
000Mooooo`;oogl01oooool00ooo003oooooooooo`07ooooo`;oogl0]Oooool1o`00007ooooo0000
0ol0003oooooooooo`0dooooo`03ool00?oooooooooo02Cooooo00?oo`00ooooooooool0_Oooool1
o`00007ooooo00000ol0003oooooooooo`0eooooo`03ool00?oooooooooo02Cooooo00?oo`00oooo
ooooool0_?ooool1o`00007ooooo00000ol0003oooooooooo`0fooooo`;oo`009Oooool00ooo003o
ooooooooo`2kooooo`7o00000Oooool00003o`000?oooooooooo03Sooooo0_oo00000oooO`3ooooo
ooooo`02oomo01kooooo00?oo`00ooooooooool0^oooool1o`00007ooooo00000ol0003ooooooooo
o`0hooooo`;oogl00_oo0004oomo01kooooo00?oo`00ooooooooool0^_ooool1o`00007ooooo0000
0ol0003oooooooooo`0hooooo`Coogl00_oo0002oomo01kooooo00?oo`00ooooooooool0^_ooool1
o`00007ooooo00000ol0003oooooooooo`0iooooo`Googl000?oo`00ooooooooool07Oooool00ooo
003oogl0oomo002jooooo`7o00000Oooool00003o`000?oooooooooo03_ooooo1?ooO`02ool001go
oooo00Coogl0ool00?ooO`3oogl0^Oooool1o`00007ooooo00000ol0003oooooooooo`0looooo`;o
ogl00oooool2ool001_ooooo00Coogl0ool00?ooO`3oogl0^Oooool1o`00007ooooo00000ol0003o
ooooooooo`13ooooo`;oo`006_ooool00oooO`3oo`00ooooo`2iooooo`7o00000Oooool00003o`00
0?oooooooooo04Gooooo0_oo000Iooooo`03ool00?oooooooooo0;Sooooo0Ol00001ooooo`0000?o
0000ooooooooool0Aoooool2ool001Gooooo0_oo002kooooo`7o00000Oooool00003o`000?oooooo
oooo04Wooooo0ooo000@ooooo`;oo`00_Oooool1o`00007ooooo00000ol0003oooooooooo`0aoooo
o`;oogl06Oooool3ool000cooooo00?oo`00ooooooooool0_Oooool1o`00007ooooo00000ol0003o
ooooooooo`0`ooooo`Coogl06oooool6ool000Cooooo0_oo0030ooooo`7o00000Oooool00003o`00
0?oooooooooo033ooooo1?ooO`0Qooooo`Coo`00`_ooool1o`00007ooooo00000ol0003ooooooooo
o`0aooooo`;oogl0j?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001
ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo0?oo
oooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o
0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo07gooooo0_ooO`2L
ooooo`7o00000Oooool00003o`000?oooooooooo07cooooo1?ooO`2Kooooo`7o00000Oooool00003
o`000?oooooooooo05Cooooo0_ooO`0Vooooo`Coogl0Voooool1o`00007ooooo00000ol0003ooooo
ooooo`1Cooooo`Coogl09_ooool2oomo09cooooo0Ol00001ooooo`0000?o0000ooooooooool0Dooo
ool4oomo0<Cooooo0Ol00001ooooo`0000?o0000ooooooooool0E?ooool2oomo0<Gooooo0Ol00001
ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo06?o
oooo0_ooO`04ooooo`;oogl0/?ooool1o`00007ooooo00000ol0003oooooooooo`1Rooooo`Coogl0
0_ooool4oomo0:oooooo0Ol00001ooooo`0000?o0000ooooooooool0H_ooool4oomo00;ooooo1?oo
O`2_ooooo`7o00000Oooool00003o`000?oooooooooo06?ooooo0_ooO`04ooooo`;oogl0/?ooool1
o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000oooooooo
ool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo
00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolL
ooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003o
ooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o0000
0Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3o
oooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003
o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo
0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oooooo
oooo0?oooooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001oooo
o`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo
7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000
ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00
007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0
oooooolLooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo0000
0ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLoooo
o`7o00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003ooooo
ooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Ooo
ool00003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooo
oacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`00
0?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3oooooo`Cooooo0_oo
O`0Fooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo0oooool4oomo01Gooooo0Ol00001
ooooo`0000?o0000ooooooooool0ooooool3ooooo`Coogl05Oooool1o`00007ooooo00000ol0003o
ooooooooo`3oooooo`Cooooo0_ooO`0Fooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo
7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000
ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00
007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0
oooooolLooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo0000
0ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLoooo
o`7o00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003ooooo
ooooo`2eooooo`;oogl0I?ooool1o`00007ooooo00000ol0003oooooooooo`2dooooo`Coogl0Hooo
ool1o`00007ooooo00000ol0003oooooooooo`2dooooo`Coogl0Hoooool1o`00007ooooo00000ol0
003oooooooooo`2eooooo`;oogl0=Oooool2oomo02gooooo0Ol00001ooooo`0000?o0000oooooooo
ool0i?ooool2oomo00Gooooo1?ooO`0/ooooo`7o00000Oooool00003o`000?oooooooooo0>?ooooo
1?ooO`04ooooo`Coogl0;?ooool1o`00007ooooo00000ol0003oooooooooo`33ooooo`;oogl07_oo
ool4oomo00Gooooo0_ooO`0]ooooo`7o00000Oooool00003o`000?oooooooooo0<;ooooo1?ooO`0;
o`00oa?ooooo0_ooO`0eooooo`7o00000Oooool00003o`000?oooooooooo0<;ooooo1?l00?l;oooo
o`;o003oB?ooool1o`00007ooooo00000ol0003oooooooooo`2nooooo`Co003o00?ooooooomo0?oo
O`003_ooool2o`00odKooooo0Ol00001ooooo`0000?o0000ooooooooool0^Oooool2oomo00?o003o
5oooool2o`00o`Wooooo0_ooO`0iooooo`7o00000Oooool00003o`000?oooooooooo0;Oooooo1?l0
0?l00oooO`3oooooooooo`0Iooooo`;o003o1_ooool4oomo03Sooooo0Ol00001ooooo`0000?o0000
ooooooooool0]?ooool3o`00o`03ooooooooO`3oogl000;oogl07?ooool00ol00?ooooooooooo`04
ooooo`Coogl00oooool2oomo03?ooooo0Ol00001ooooo`0000?o0000ooooooooool0/_ooool2o`00
o`?oogl00_ooool2oomo01?ooooo0_ooO`08ooooo`03o`00oooooooooooo00Gooooo0_ooO`03oooo
o`Coogl0<_ooool1o`00007ooooo00000ol0003oooooooooo`2`ooooo`;o003o00?ooooooomo0?oo
O`000_ooO`06ooooo`;oogl03_ooool4oomo00Oooooo00?o003oooooooooool02_ooool4oomo03;o
oooo0Ol00001ooooo`0000?o0000ooooooooool0[_ooool2o`00o`Cooooo0_ooO`06ooooo`Coogl0
3Oooool4oomo00Oooooo00?o003oooooooooool02oooool2oomo03?ooooo0Ol00001ooooo`0000?o
0000ooooooooool0Roooool2oomo023ooooo00?o003oooooooooool01?ooool2oomo00Kooooo1?oo
O`0>ooooo`;oogl02Oooool00ol00?ooooooooooo`0oooooo`7o00000Oooool00003o`000?oooooo
oooo08[ooooo1?ooO`0Mooooo`;o003o1_ooool4oomo00Kooooo0_ooO`0Jooooo`03o`00oooooooo
oooo03oooooo0Ol00001ooooo`0000?o0000ooooooooool0R_ooool4oomo01cooooo00?o003ooooo
ooooool01_ooool4oomo02;ooooo00?o003oooooooooool0?oooool1o`00007ooooo00000ol0003o
ooooooooo`2;ooooo`;oogl06oooool2o`00o`[ooooo0_ooO`0Sooooo`03o`00oooooooooooo03oo
oooo0Ol00001ooooo`0000?o0000ooooooooool0U_ooool2oomo00kooooo0_l00?lZooooo`;oogl0
1Oooool00ol00?ooooooooooo`0oooooo`7o00000Oooool00003o`000?oooooooooo09Gooooo1?oo
O`0<ooooo`04o`00ooooooooogl0oomo02Sooooo1?ooO`03ooooo`03o`00oooooooooooo043ooooo
0Ol00001ooooo`0000?o0000ooooooooool0UOooool4oomo00[ooooo0_l00?l00oooooooogl0oomo
0002oomo02Oooooo1?ooO`03ooooo`03o`00oooooooooooo043ooooo0Ol00001ooooo`0000?o0000
ooooooooool0U_ooool2oomo00[ooooo00Co003ooooooooooooooooo1?ooO`0Xooooo`;oogl01?oo
ool00ol00?ooooooooooo`10ooooo`7o00000Oooool00003o`000?oooooooooo0:7ooooo00?o003o
ooooooooool00oooool2oomo02kooooo00?o003oooooooooool0@Oooool1o`00007ooooo00000ol0
003oooooooooo`2Pooooo`03o`00oooooooooooo03?ooooo00?o003oooooooooool04_ooool2oomo
02kooooo0Ol00001ooooo`0000?o0000ooooooooool0W_ooool2o`00ocGooooo00?o003ooooooooo
ool04_ooool4oomo02gooooo0Ol00001ooooo`0000?o0000ooooooooool0WOooool00ol00?oooooo
ooooo`0Eooooo`Co003o7?ooool00ol00?ooogl0oomo000Booooo`Coogl0;Oooool1o`00007ooooo
00000ol0003oooooooooo`2Looooo`03o`00oooooooooooo01Gooooo1_l00?lJooooo`03o`00oooo
O`3oogl000;oogl04_ooool2oomo02kooooo0Ol00001ooooo`0000?o0000ooooooooool0Voooool0
0ol00?ooooooooooo`0Eooooo`So003o6?ooool00ol00?oooooooomo0003oomo04;ooooo0Ol00001
ooooo`0000?o0000ooooooooool0Voooool00ol00?ooooooooooo`0Eooooo`So003o5oooool01?l0
0?ooooooooooooooool2oomo04?ooooo0Ol00001ooooo`0000?o0000ooooooooool0V_ooool00ol0
0?ooooooooooo`0Fooooo`So003o5_ooool00ol00?ooooooooooo`17ooooo`7o00000Oooool00003
o`000?oooooooooo09Wooooo00?o003oooooooooool03?ooool2oomo00Sooooo00?oogl0o`00ool0
0?l01_l00?lEooooo`03o`00oooooooooooo00;oogl0A_ooool1o`00007ooooo00000ol0003ooooo
ooooo`2Iooooo`03o`00oooooooooooo00[ooooo1OooO`07ooooo`;oogl01_l00?lCooooo`;oogl0
00?o003oooooooooool01?ooO`15ooooo`7o00000Oooool00003o`000?oooooooooo09Sooooo00?o
003oooooooooool02_ooool6oomo00Sooooo0_ooO`04o`00oa?ooooo0_ooO`02o`00o`;ooooo1?oo
O`15ooooo`7o00000Oooool00003o`000?oooooooooo09Sooooo00?o003oooooooooool02_ooool5
oomo02;ooooo00Coogl0o`00ooooO`3oogl00oooool2oomo04Kooooo0Ol00001ooooo`0000?o0000
ooooooooool0M_ooool2oomo01oooooo00?o003oooooooooool03?ooool2oomo02Cooooo00?o003o
oomo0?ooO`00C?ooool1o`00007ooooo00000ol0003oooooooooo`1eooooo`Coogl07_ooool00ol0
0?ooooooooooo`0aooooo`03o`00oooooooooooo04gooooo0Ol00001ooooo`0000?o0000oooooooo
ool0MOooool4oomo00[ooooo0_ooO`0Aooooo`03o`00oooooooooooo037ooooo00?o003ooooooooo
ool0C_ooool1o`00007ooooo00000ol0003oooooooooo`1fooooo`;oogl02_ooool4oomo00oooooo
00?o003oooooooooool06?ooool2oomo01Oooooo00?o003oooooooooool0Coooool1o`00007ooooo
00000ol0003oooooooooo`22ooooo`Coogl03oooool00ol00?ooooooooooo`0Gooooo`Coogl05?oo
ool2o`00oe;ooooo0Ol00001ooooo`0000?o0000ooooooooool0Poooool2oomo00oooooo00?o003o
ooooooooool04_ooool2oomo00Cooooo1?ooO`0Aooooo`?o003oE?ooool1o`00007ooooo00000ol0
003oooooooooo`2Dooooo`03o`00oooooooooooo017ooooo1?ooO`04ooooo`;oogl04?ooool2o`00
oeOooooo0Ol00001ooooo`0000?o0000ooooooooool0U?ooool00ol00?ooooooooooo`0Aooooo`Co
ogl05Oooool00ol00?ooooooooooo`1Gooooo`7o00000Oooool00003o`000?oooooooooo09Cooooo
00?o003oooooooooool04_ooool2oomo01Cooooo0_l00?mJooooo`7o00000Oooool00003o`000?oo
oooooooo09Cooooo00?o003oooooooooool09_ooool2o`00oecooooo0Ol00001ooooo`0000?o0000
ooooooooool0UOooool00ol00?ooooooooooo`0Tooooo`03o`00oooooooooooo05cooooo0Ol00001
ooooo`0000?o0000ooooooooool0UOooool00ol00?ooooooooooo`0Rooooo`;o003oGoooool1o`00
007ooooo00000ol0003oooooooooo`2Eooooo`03o`00oooooooooooo023ooooo0_l00?mQooooo`7o
00000Oooool00003o`000?oooooooooo08Cooooo0_ooO`0?ooooo`;o003o7oooool2o`00of?ooooo
0Ol00001ooooo`0000?o0000ooooooooool0Poooool4oomo013ooooo0_l00?lJooooo`?o003oIOoo
ool1o`00007ooooo00000ol0003oooooooooo`23ooooo`Coogl04_ooool2o`00oaCooooo1?l00?mX
ooooo`7o00000Oooool00003o`000?oooooooooo08Cooooo0_ooO`0Eooooo`?o003o3_ooool3o`00
o`?ooooo0_ooO`1Wooooo`7o00000Oooool00003o`000?oooooooooo09kooooo0ol00?l5ooooo`Ko
003o1Oooool4oomo06Kooooo0Ol00001ooooo`0000?o0000ooooooooool0XOooool5o`00o`_ooooo
1?ooO`1Vooooo`7o00000Oooool00003o`000?oooooooooo0;;ooooo0_ooO`1Wooooo`7o00000Ooo
ool00003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooo
oacooooo0Ol00001ooooo`0000?o0000ooooooooool0Noooool2oomo09kooooo0Ol00001ooooo`00
00?o0000ooooooooool0N_ooool4oomo09gooooo0Ol00001ooooo`0000?o0000ooooooooool0N_oo
ool4oomo023ooooo0_ooO`1kooooo`7o00000Oooool00003o`000?oooooooooo07_ooooo0_ooO`0P
ooooo`Coogl0N_ooool1o`00007ooooo00000ol0003oooooooooo`2Mooooo`Coogl0N_ooool1o`00
007ooooo00000ol0003oooooooooo`2@ooooo`;oogl03?ooool2oomo07_ooooo0Ol00001ooooo`00
00?o0000ooooooooool0Soooool4oomo08Sooooo0Ol00001ooooo`0000?o0000ooooooooool0Sooo
ool4oomo08Sooooo0Ol00001ooooo`0000?o0000ooooooooool0T?ooool2oomo02?ooooo0_ooO`1T
ooooo`7o00000Oooool00003o`000?oooooooooo0;Cooooo1?ooO`1Sooooo`7o00000Oooool00003
o`000?oooooooooo0;Cooooo1?ooO`1Sooooo`7o00000Oooool00003o`000?oooooooooo0;Gooooo
0_ooO`1Tooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo0000
0ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLoooo
o`7o00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003ooooo
ooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Ooo
ool00003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooo
oacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`00
0?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol0
0001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo
0?oooooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`00
00?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?oo
ool1o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000oooo
ooooool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007o
oooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooo
oolLooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0
003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o
00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003ooooooooo
o`3ooooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool0
0003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooooaco
oooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oo
oooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001
ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo0?oo
oooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o
0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1
o`00007ooooo00000ol0003oooooooooo`2>ooooo`;oogl0Roooool1o`00007ooooo00000ol0003o
ooooooooo`2=ooooo`Coogl0R_ooool1o`00007ooooo00000ol0003oooooooooo`2=ooooo`Coogl0
R_ooool1o`00007ooooo00000ol0003oooooooooo`2>ooooo`;oogl0Roooool1o`00007ooooo0000
0ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLoooo
o`7o00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003ooooo
ooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Ooo
ool00003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooo
oacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`00
0?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol0
0001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo
0?oooooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`00
00?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?oo
ool1o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000oooo
ooooool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007o
oooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooo
oolLooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo003oo`00
023o00000Oooool00001\
\>"],
  ImageRangeCache->{{{0, 287}, {287, 0}} -> {-1.01089, -1.01089, 0.00704453, \
0.00704453}}]
}, Closed]]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Global visualization as a function of EM trajectory", "Subsection"],

Cell[CellGroupData[{

Cell["Initial computation", "Subsubsection"],

Cell[BoxData[
    \(\(fncs\  = \ \(\((\(ClassProbabilitiesDataSet[{{x, y}}, #]\  // \ 
                  Flatten\)\  // \ First)\) &\)\  /@ \ em2;\)\)], "Input"]
}, Closed]],

Cell[CellGroupData[{

Cell["Computation and visualization", "Subsubsection"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(Table[
        ContourPlot[fncs[\([i]\)], {x, \(-1\), 1}, {y, \(-1\), 1}, 
          PlotPoints \[Rule] 25, \ FrameTicks \[Rule] None, 
          ColorFunction \[Rule] \((RGBColor\  @@ \ \((#\ \((List\  @@ \ \ \
colors[\([1]\)])\)\  + \ \((1 - #)\)\ List\  @@ \ 
                          colors[\([2]\)])\) &)\)], {i, 1, 
          Length[fncs]}];\)\)], "Input"],

Cell[CellGroupData[{

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% ContourGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.480769 0.5 0.480769 [
[ 0 0 -0.125 0 ]
[ 0 0 -0.125 0 ]
[ 0 1 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
0 0 m
1 0 L
s
0 0 m
0 1 L
s
0 1 m
1 1 L
s
1 0 m
1 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
.2 0 .8 r
.01923 .98077 m
.98077 .98077 L
.98077 .01923 L
.01923 .01923 L
F
0 g
.5 Mabswid
.3 0 .7 r
.01923 .97902 m
.05639 .94071 L
.05929 .93771 L
.09524 .90064 L
.09936 .8964 L
.1341 .86058 L
.13942 .85509 L
.17296 .82051 L
.17949 .81378 L
.21181 .78045 L
.21955 .77247 L
.25067 .74038 L
.25962 .73116 L
.28953 .70032 L
.29968 .68985 L
.32838 .66026 L
.33974 .64854 L
.36724 .62019 L
.37981 .60723 L
.4061 .58013 L
.41987 .56593 L
.44495 .54006 L
.45994 .52462 L
.48381 .5 L
.5 .48331 L
.52267 .45994 L
.54006 .442 L
.56152 .41987 L
.58013 .40069 L
.60038 .37981 L
.62019 .35938 L
.63924 .33974 L
.66026 .31807 L
.6781 .29968 L
.70032 .27677 L
.71695 .25962 L
.74038 .23546 L
.75581 .21955 L
.78045 .19415 L
.79467 .17949 L
.82051 .15284 L
.83353 .13942 L
.86058 .11153 L
.87238 .09936 L
.90064 .07022 L
.91124 .05929 L
.94071 .02893 L
.9501 .01923 L
.01923 .01923 L
F
0 g
.01923 .97902 m
.05639 .94071 L
.05929 .93771 L
.09524 .90064 L
.09936 .8964 L
.1341 .86058 L
.13942 .85509 L
.17296 .82051 L
.17949 .81378 L
.21181 .78045 L
.21955 .77247 L
.25067 .74038 L
.25962 .73116 L
.28953 .70032 L
.29968 .68985 L
.32838 .66026 L
.33974 .64854 L
.36724 .62019 L
.37981 .60723 L
.4061 .58013 L
.41987 .56593 L
.44495 .54006 L
.45994 .52462 L
.48381 .5 L
.5 .48331 L
.52267 .45994 L
.54006 .442 L
.56152 .41987 L
.58013 .40069 L
.60038 .37981 L
.62019 .35938 L
.63924 .33974 L
.66026 .31807 L
.6781 .29968 L
.70032 .27677 L
.71695 .25962 L
.74038 .23546 L
.75581 .21955 L
.78045 .19415 L
.79467 .17949 L
.82051 .15284 L
.83353 .13942 L
.86058 .11153 L
.87238 .09936 L
.90064 .07022 L
.91124 .05929 L
.94071 .02893 L
.9501 .01923 L
s
.4 0 .6 r
.01923 .84546 m
.04343 .82051 L
.05929 .80415 L
.08228 .78045 L
.09936 .76284 L
.12114 .74038 L
.13942 .72153 L
.16 .70032 L
.17949 .68022 L
.19885 .66026 L
.21955 .63892 L
.23771 .62019 L
.25962 .59761 L
.27657 .58013 L
.29968 .5563 L
.31542 .54006 L
.33974 .51499 L
.35428 .5 L
.37981 .47368 L
.39314 .45994 L
.41987 .43237 L
.432 .41987 L
.45994 .39106 L
.47085 .37981 L
.5 .34976 L
.50971 .33974 L
.54006 .30845 L
.54857 .29968 L
.58013 .26714 L
.58743 .25962 L
.62019 .22583 L
.62628 .21955 L
.66026 .18452 L
.66514 .17949 L
.70032 .14321 L
.704 .13942 L
.74038 .10191 L
.74286 .09936 L
.78045 .0606 L
.78171 .05929 L
.82051 .01929 L
.82057 .01923 L
.01923 .01923 L
F
0 g
.01923 .84546 m
.04343 .82051 L
.05929 .80415 L
.08228 .78045 L
.09936 .76284 L
.12114 .74038 L
.13942 .72153 L
.16 .70032 L
.17949 .68022 L
.19885 .66026 L
.21955 .63892 L
.23771 .62019 L
.25962 .59761 L
.27657 .58013 L
.29968 .5563 L
.31542 .54006 L
.33974 .51499 L
.35428 .5 L
.37981 .47368 L
.39314 .45994 L
.41987 .43237 L
.432 .41987 L
.45994 .39106 L
.47085 .37981 L
.5 .34976 L
.50971 .33974 L
.54006 .30845 L
.54857 .29968 L
.58013 .26714 L
.58743 .25962 L
.62019 .22583 L
.62628 .21955 L
.66026 .18452 L
.66514 .17949 L
.70032 .14321 L
.704 .13942 L
.74038 .10191 L
.74286 .09936 L
.78045 .0606 L
.78171 .05929 L
.82051 .01929 L
.82057 .01923 L
s
.5 0 .5 r
.01923 .73093 m
.04892 .70032 L
.05929 .68962 L
.08777 .66026 L
.09936 .64831 L
.12663 .62019 L
.13942 .607 L
.16549 .58013 L
.17949 .56569 L
.20434 .54006 L
.21955 .52439 L
.2432 .5 L
.25962 .48308 L
.28206 .45994 L
.29968 .44177 L
.32092 .41987 L
.33974 .40046 L
.35977 .37981 L
.37981 .35915 L
.39863 .33974 L
.41987 .31784 L
.43749 .29968 L
.45994 .27653 L
.47634 .25962 L
.5 .23523 L
.5152 .21955 L
.54006 .19392 L
.55406 .17949 L
.58013 .15261 L
.59292 .13942 L
.62019 .1113 L
.63177 .09936 L
.66026 .06999 L
.67063 .05929 L
.70032 .02869 L
.70949 .01923 L
.01923 .01923 L
F
0 g
.01923 .73093 m
.04892 .70032 L
.05929 .68962 L
.08777 .66026 L
.09936 .64831 L
.12663 .62019 L
.13942 .607 L
.16549 .58013 L
.17949 .56569 L
.20434 .54006 L
.21955 .52439 L
.2432 .5 L
.25962 .48308 L
.28206 .45994 L
.29968 .44177 L
.32092 .41987 L
.33974 .40046 L
.35977 .37981 L
.37981 .35915 L
.39863 .33974 L
.41987 .31784 L
.43749 .29968 L
.45994 .27653 L
.47634 .25962 L
.5 .23523 L
.5152 .21955 L
.54006 .19392 L
.55406 .17949 L
.58013 .15261 L
.59292 .13942 L
.62019 .1113 L
.63177 .09936 L
.66026 .06999 L
.67063 .05929 L
.70032 .02869 L
.70949 .01923 L
s
.6 0 .4 r
.01923 .62508 m
.02398 .62019 L
.05929 .58378 L
.06283 .58013 L
.09936 .54247 L
.10169 .54006 L
.13942 .50116 L
.14055 .5 L
.1794 .45994 L
.17949 .45985 L
.21826 .41987 L
.21955 .41854 L
.25712 .37981 L
.25962 .37723 L
.29598 .33974 L
.29968 .33592 L
.33483 .29968 L
.33974 .29462 L
.37369 .25962 L
.37981 .25331 L
.41255 .21955 L
.41987 .212 L
.4514 .17949 L
.45994 .17069 L
.49026 .13942 L
.5 .12938 L
.52912 .09936 L
.54006 .08807 L
.56798 .05929 L
.58013 .04677 L
.60683 .01923 L
.01923 .01923 L
F
0 g
.01923 .62508 m
.02398 .62019 L
.05929 .58378 L
.06283 .58013 L
.09936 .54247 L
.10169 .54006 L
.13942 .50116 L
.14055 .5 L
.1794 .45994 L
.17949 .45985 L
.21826 .41987 L
.21955 .41854 L
.25712 .37981 L
.25962 .37723 L
.29598 .33974 L
.29968 .33592 L
.33483 .29968 L
.33974 .29462 L
.37369 .25962 L
.37981 .25331 L
.41255 .21955 L
.41987 .212 L
.4514 .17949 L
.45994 .17069 L
.49026 .13942 L
.5 .12938 L
.52912 .09936 L
.54006 .08807 L
.56798 .05929 L
.58013 .04677 L
.60683 .01923 L
s
.7 0 .3 r
.01923 .52135 m
.03994 .5 L
.05929 .48004 L
.0788 .45994 L
.09936 .43874 L
.11766 .41987 L
.13942 .39743 L
.15651 .37981 L
.17949 .35612 L
.19537 .33974 L
.21955 .31481 L
.23423 .29968 L
.25962 .2735 L
.27308 .25962 L
.29968 .23219 L
.31194 .21955 L
.33974 .19088 L
.3508 .17949 L
.37981 .14958 L
.38966 .13942 L
.41987 .10827 L
.42851 .09936 L
.45994 .06696 L
.46737 .05929 L
.5 .02565 L
.50623 .01923 L
.01923 .01923 L
F
0 g
.01923 .52135 m
.03994 .5 L
.05929 .48004 L
.0788 .45994 L
.09936 .43874 L
.11766 .41987 L
.13942 .39743 L
.15651 .37981 L
.17949 .35612 L
.19537 .33974 L
.21955 .31481 L
.23423 .29968 L
.25962 .2735 L
.27308 .25962 L
.29968 .23219 L
.31194 .21955 L
.33974 .19088 L
.3508 .17949 L
.37981 .14958 L
.38966 .13942 L
.41987 .10827 L
.42851 .09936 L
.45994 .06696 L
.46737 .05929 L
.5 .02565 L
.50623 .01923 L
s
.8 0 .2 r
.01923 .41394 m
.05233 .37981 L
.05929 .37263 L
.09119 .33974 L
.09936 .33132 L
.13005 .29968 L
.13942 .29001 L
.1689 .25962 L
.17949 .2487 L
.20776 .21955 L
.21955 .20739 L
.24662 .17949 L
.25962 .16609 L
.28548 .13942 L
.29968 .12478 L
.32433 .09936 L
.33974 .08347 L
.36319 .05929 L
.37981 .04216 L
.40205 .01923 L
.01923 .01923 L
F
0 g
.01923 .41394 m
.05233 .37981 L
.05929 .37263 L
.09119 .33974 L
.09936 .33132 L
.13005 .29968 L
.13942 .29001 L
.1689 .25962 L
.17949 .2487 L
.20776 .21955 L
.21955 .20739 L
.24662 .17949 L
.25962 .16609 L
.28548 .13942 L
.29968 .12478 L
.32433 .09936 L
.33974 .08347 L
.36319 .05929 L
.37981 .04216 L
.40205 .01923 L
s
.9 0 .1 r
.01923 .29565 m
.05418 .25962 L
.05929 .25434 L
.09304 .21955 L
.09936 .21304 L
.1319 .17949 L
.13942 .17173 L
.17075 .13942 L
.17949 .13042 L
.20961 .09936 L
.21955 .08911 L
.24847 .05929 L
.25962 .0478 L
.28733 .01923 L
.01923 .01923 L
F
0 g
.01923 .29565 m
.05418 .25962 L
.05929 .25434 L
.09304 .21955 L
.09936 .21304 L
.1319 .17949 L
.13942 .17173 L
.17075 .13942 L
.17949 .13042 L
.20961 .09936 L
.21955 .08911 L
.24847 .05929 L
.25962 .0478 L
.28733 .01923 L
s
1 0 0 r
.01923 .15421 m
.03357 .13942 L
.05929 .11291 L
.07243 .09936 L
.09936 .0716 L
.11129 .05929 L
.13942 .03028 L
.15015 .01923 L
.01923 .01923 L
F
0 g
.01923 .15421 m
.03357 .13942 L
.05929 .11291 L
.07243 .09936 L
.09936 .0716 L
.11129 .05929 L
.13942 .03028 L
.15015 .01923 L
s
.1 0 .9 r
.98077 .16283 m
.96463 .17949 L
.94071 .20414 L
.92576 .21955 L
.90064 .24545 L
.8869 .25962 L
.86058 .28676 L
.84805 .29968 L
.82051 .32807 L
.80919 .33974 L
.78045 .36938 L
.77033 .37981 L
.74038 .41069 L
.73148 .41987 L
.70032 .452 L
.69262 .45994 L
.66026 .49331 L
.65376 .5 L
.62019 .53461 L
.61491 .54006 L
.58013 .57592 L
.57605 .58013 L
.54006 .61723 L
.53719 .62019 L
.5 .65854 L
.49834 .66026 L
.45994 .69985 L
.45948 .70032 L
.42062 .74038 L
.41987 .74116 L
.38177 .78045 L
.37981 .78247 L
.34291 .82051 L
.33974 .82377 L
.30405 .86058 L
.29968 .86508 L
.26519 .90064 L
.25962 .90639 L
.22633 .94071 L
.21955 .94771 L
.18748 .98077 L
.98077 .98077 L
F
0 g
.98077 .16283 m
.96463 .17949 L
.94071 .20414 L
.92576 .21955 L
.90064 .24545 L
.8869 .25962 L
.86058 .28676 L
.84805 .29968 L
.82051 .32807 L
.80919 .33974 L
.78045 .36938 L
.77033 .37981 L
.74038 .41069 L
.73148 .41987 L
.70032 .452 L
.69262 .45994 L
.66026 .49331 L
.65376 .5 L
.62019 .53461 L
.61491 .54006 L
.58013 .57592 L
.57605 .58013 L
.54006 .61723 L
.53719 .62019 L
.5 .65854 L
.49834 .66026 L
.45994 .69985 L
.45948 .70032 L
.42062 .74038 L
.41987 .74116 L
.38177 .78045 L
.37981 .78247 L
.34291 .82051 L
.33974 .82377 L
.30405 .86058 L
.29968 .86508 L
.26519 .90064 L
.25962 .90639 L
.22633 .94071 L
.21955 .94771 L
.18748 .98077 L
s
0 0 1 r
.98077 .46214 m
.94406 .5 L
.94071 .50345 L
.90519 .54006 L
.90064 .54476 L
.86633 .58013 L
.86058 .58606 L
.82748 .62019 L
.82051 .62737 L
.78862 .66026 L
.78045 .66868 L
.74976 .70032 L
.74038 .70999 L
.7109 .74038 L
.70032 .7513 L
.67204 .78045 L
.66026 .7926 L
.63319 .82051 L
.62019 .83391 L
.59433 .86058 L
.58013 .87522 L
.55547 .90064 L
.54006 .91653 L
.51661 .94071 L
.5 .95786 L
.47776 .98077 L
.98077 .98077 L
F
0 g
.98077 .46214 m
.94406 .5 L
.94071 .50345 L
.90519 .54006 L
.90064 .54476 L
.86633 .58013 L
.86058 .58606 L
.82748 .62019 L
.82051 .62737 L
.78862 .66026 L
.78045 .66868 L
.74976 .70032 L
.74038 .70999 L
.7109 .74038 L
.70032 .7513 L
.67204 .78045 L
.66026 .7926 L
.63319 .82051 L
.62019 .83391 L
.59433 .86058 L
.58013 .87522 L
.55547 .90064 L
.54006 .91653 L
.51661 .94071 L
.5 .95786 L
.47776 .98077 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P000182000`400?l00000o`00003ooooooolQ
ooooo`00o`00000P0000007ooooo00000`00003oooooooooo`3ooooooacooooo0@000001ooooo`00
00<00000ooooooooool0oooooolLooooo`4000000Oooool0000300000?oooooooooo0?oooooo7?oo
ool10000007ooooo00000`00003oooooooooo`3ooooooacooooo0@000001ooooo`0000<00000oooo
ooooool0:?ooool00ol0003oooooooooo`0Tooooo`03o`000?oooooooooo01kooooo00?o0000oooo
ooooool06oooool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo01[ooooo00?o0000oooo
ooooool07Oooool00ol0003oooooooooo`0Rooooo`03o`000?oooooooooo00_ooooo0@000001oooo
o`0000<00000ooooooooool00_oooolU0?l00003o`00003V01T0iP0I02@0iP0I00?o00000<`0<`3<
03<07`3<03<00ol00000/`1<0;<0C00J0;<0C003o`00002I06H0V@1V01X0V@1V00?o000007l0O`1o
07l06P1o07l00ol00000IP2I06H0V@0N06H0V@030000001<0;<0C02c0240C02c00?o000003<0c00c
0<`01`0c0<`5ooooo`4000000Oooool0000300000?oooooooooo00;ooooo903o00000ol00000iP0I
0>H06@0T0>H06@03o`00003<03<0c00c01l0c00c00?o00000;<0C02c04`06P2c04`00ol00000V@1V
09T0IP0J09T0IP03o`00001o07l0O`1o01X0O`1o00?o000006H0V@1V09T07P1V09T00`000000C02c
04`0/`0Q04`0/`03o`00000c0<`0<`3<00P0<`3<1Oooool10000007ooooo00000`00003ooooooooo
o`02ooooob<0o`0000?o00000>H06@3V01T0903V01T00ol00000c00c0<`0<`0O0<`0<`03o`00002c
04`0/`1<01/0/`1<00?o000009T0IP2I06H06@2I06H00ol00000O`1o07l0O`0J07l0O`03o`00001V
09T0IP2I01h0IP2I00<0000004`0/`1<0;<08@1<0;<00ol00000<`3<03<0c00903<0c0Gooooo0@00
0001ooooo`0000<00000ooooooooool00_oooolS0?l00003o`00003V01T0iP0I02<0iP0I00?o0000
0<`0<`3<03<07`3<03<00ol00000/`1<0;<0C00K0;<0C003o`00002I06H0V@1V01T0V@1V00?o0000
07l0O`1o07l06`1o07l00ol00000IP2I06H0V@0M06H0V@030000001<0;<0C02c0280C02c00?o0000
03<0c00c0<`02@0c0<`5ooooo`4000000Oooool0000300000?oooooooooo00;ooooo8P3o00000ol0
0000iP0I0>H06@0S0>H06@03o`00003<03<0c00c01l0c00c00?o00000;<0C02c04`06`2c04`00ol0
0000V@1V09T0IP0I09T0IP03o`00001o07l0O`1o01/0O`1o00?o000006H0V@1V09T07@1V09T00`00
0000C02c04`0/`0R04`0/`03o`00000c0<`0<`3<00X0<`3<1Oooool10000007ooooo00000`00003o
ooooooooo`02ooooob40o`0000?o00000>H06@3V01T08`3V01T00ol00000c00c0<`0<`0O0<`0<`03
o`00002c04`0/`1<01/0/`1<00?o000009T0IP2I06H06@2I06H00ol00000O`1o07l0O`0K07l0O`03
o`00001V09T0IP2I01d0IP2I00<0000004`0/`1<0;<08P1<0;<00ol00000<`3<03<0c00;03<0c0Go
oooo0@000001ooooo`0000<00000ooooooooool00_oooolP0?l00003o`00003V01T0iP0I02<0iP0I
00?o00000<`0<`3<03<07`3<03<00ol00000/`1<0;<0C00K0;<0C003o`00002I06H0V@1V01T0V@1V
00?o000007l0O`1o07l06`1o07l00ol00000IP2I06H0V@0M06H0V@030000001<0;<0C02c0280C02c
00?o000003<0c00c0<`0300c0<`5ooooo`4000000Oooool0000300000?oooooooooo00;ooooo7`3o
00000ol00000iP0I0>H06@0S0>H06@03o`00003<03<0c00c01l0c00c00?o00000;<0C02c04`06`2c
04`00ol00000V@1V09T0IP0I09T0IP03o`00001o07l0O`1o01/0O`1o00?o000006H0V@1V09T07@1V
09T00`000000C02c04`0/`0R04`0/`03o`00000c0<`0<`3<00d0<`3<1Oooool10000007ooooo0000
0`00003oooooooooo`02oooooah0o`0000?o00000>H06@3V01T0903V01T00ol00000c00c0<`0<`0N
0<`0<`03o`00002c04`0/`1<01/0/`1<00?o000009T0IP2I06H06@2I06H00ol00000O`1o07l0O`0K
07l0O`03o`00001V09T0IP2I01d0IP2I00<0000004`0/`1<0;<08P1<0;<00ol00000<`3<03<0c00>
03<0c0Gooooo0@000001ooooo`0000<00000ooooooooool00_oooolM0?l00003o`00003V01T0iP0I
02@0iP0I00?o00000<`0<`3<03<07P3<03<00ol00000/`1<0;<0C00K0;<0C003o`00002I06H0V@1V
01T0V@1V00?o000007l0O`1o07l06`1o07l00ol00000IP2I06H0V@0M06H0V@030000001<0;<0C02c
0280C02c00?o000003<0c00c0<`03`0c0<`5ooooo`4000000Oooool0000300000?oooooooooo00;o
oooo703o00000ol00000iP0I0>H06@0T0>H06@03o`00003<03<0c00c01h0c00c00?o00000;<0C02c
04`06`2c04`00ol00000V@1V09T0IP0I09T0IP03o`00001o07l0O`1o01/0O`1o00?o000006H0V@1V
09T07@1V09T00`000000C02c04`0/`0R04`0/`03o`00000c0<`0<`3<0100<`3<1Oooool10000007o
oooo00000`00003oooooooooo`02oooooaX0o`000_l0000V0>H06@03o`00003<03<0c00c01h0c00c
00?o00000;<0C02c04`06`2c04`00ol00000V@1V09T0IP0I09T0IP03o`00001o07l0O`1o01/0O`1o
00?o000006H0V@1V09T0701V09T00ol00000000004`0/`0S04`0/`03o`00000c0<`0<`3<0140<`3<
1Oooool10000007ooooo00000`00003oooooooooo`02oooooaT0o`0000?o00000>H06@3V01T09@3V
01T00ol00000c00c0<`0<`0N0<`0<`03o`00002c04`0/`1<01/0/`1<00?o000009T0IP2I06H06@2I
06H00ol00000O`1o07l0O`0K07l0O`03o`00001V09T0IP2I01d0IP2I00<0000004`0/`1<0;<08P1<
0;<00ol00000<`3<03<0c00B03<0c0Gooooo0@000001ooooo`0000<00000ooooooooool00_oooolH
0?l00003o`00003V01T0iP0I02D0iP0I00?o00000<`0<`3<03<07P3<03<00ol00000/`1<0;<0C00K
0;<0C003o`00002I06H0V@1V01T0V@1V00?o000007l0O`1o07l06`1o07l00ol00000IP2I06H0V@0M
06H0V@030000001<0;<0C02c0280C02c00?o000003<0c00c0<`04`0c0<`5ooooo`4000000Oooool0
000300000?oooooooooo00;ooooo5`3o00000ol00000iP0I0>H06@0U0>H06@03o`00003<03<0c00c
01h0c00c00?o00000;<0C02c04`06`2c04`00ol00000V@1V09T0IP0I09T0IP03o`00001o07l0O`1o
01/0O`1o00?o000006H0V@1V09T07@1V09T00`000000C02c04`0/`0R04`0/`03o`00000c0<`0<`3<
01@0<`3<1Oooool10000007ooooo00000`00003oooooooooo`02oooooaH0o`0000?o00000>H06@3V
01T09@3V01T00ol00000c00c0<`0<`0N0<`0<`03o`00002c04`0/`1<01/0/`1<00?o000009T0IP2I
06H06@2I06H00ol00000O`1o07l0O`0K07l0O`03o`00001V09T0IP2I01d0IP2I00<0000004`0/`1<
0;<08P1<0;<00ol00000<`3<03<0c00E03<0c0Gooooo0@000001ooooo`0000<00000ooooooooool0
0_oooolE0?l00003o`00003V01T0iP0I02D0iP0I00?o00000<`0<`3<03<07P3<03<00ol00000/`1<
0;<0C00K0;<0C003o`00002I06H0V@1V01T0V@1V00?o000007l0O`1o07l06`1o07l00ol00000IP2I
06H0V@0M06H0V@030000001<0;<0C02c0280C02c00?o000003<0c00c0<`05P0c0<`5ooooo`400000
0Oooool0000300000?oooooooooo00;ooooo503o00000ol00000iP0I0>H06@0U0>H06@03o`00003<
03<0c00c01h0c00c00?o00000;<0C02c04`06`2c04`00ol00000V@1V09T0IP0I09T0IP03o`00001o
07l0O`1o01/0O`1o00?o000006H0V@1V09T07@1V09T00`000000C02c04`0/`0R04`0/`03o`00000c
0<`0<`3<01L0<`3<1Oooool10000007ooooo00000`00003oooooooooo`02oooooa<0o`0000?o0000
0>H06@3V01T09@3V01T00ol00000c00c0<`0<`0N0<`0<`03o`00002c04`0/`1<01/0/`1<00?o0000
09T0IP2I06H06@2I06H00ol00000O`1o07l0O`0K07l0O`03o`00001V09T0IP2I01d0IP2I00<00000
04`0/`1<0;<08P1<0;<00ol00000<`3<03<0c00H03<0c0Gooooo0@000001ooooo`0000<00000oooo
ooooool00_oooolB0?l00003o`00003V01T0iP0I02D0iP0I00?o00000<`0<`3<03<07P3<03<00ol0
0000/`1<0;<0C00K0;<0C003o`00002I06H0V@1V01T0V@1V00?o000007l0O`1o07l06`1o07l00ol0
0000IP2I06H0V@0M06H0V@030000001<0;<0C02c0280C02c00?o000003<0c00c0<`06@0c0<`5oooo
o`4000000Oooool0000300000?oooooooooo00;ooooo4@3o00000ol00000iP0I0>H06@0U0>H06@03
o`00003<03<0c00c01h0c00c00?o00000;<0C02c04`06`2c04`00ol00000V@1V09T0IP0I09T0IP03
o`00001o07l0O`1o01/0O`1o00?o000006H0V@1V09T07@1V09T00`000000C02c04`0/`0R04`0/`03
o`00000c0<`0<`3<01X0<`3<1Oooool10000007ooooo00000`00003oooooooooo`02oooooa00o`00
00?o00000>H06@3V01T09@3V01T00ol00000c00c0<`0<`0N0<`0<`03o`00002c04`0/`1<01/0/`1<
00?o000009T0IP2I06H06@2I06H00ol00000O`1o07l0O`0K07l0O`03o`00001V09T0IP2I01d0IP2I
00<0000004`0/`1<0;<08P1<0;<00ol00000<`3<03<0c00K03<0c0Gooooo0@000001ooooo`0000<0
0000ooooooooool00_ooool?0?l00003o`00003V01T0iP0I02D0iP0I00?o00000<`0<`3<03<07P3<
03<00ol00000/`1<0;<0C00K0;<0C003o`00002I06H0V@1V01T0V@1V00?o000007l0O`1o07l06`1o
07l00ol00000IP2I06H0V@0M06H0V@030000001<0;<0C02c0280C02c00?o000003<0c00c0<`0700c
0<`5ooooo`4000000Oooool0000300000?oooooooooo00;ooooo3`3o00000ol00000iP0I0>H06@0T
0>H06@03o`00003<03<0c00c01h0c00c00?o00000;<0C02c04`06`2c04`00ol00000V@1V09T0IP0J
09T0IP03o`00001o07l0O`1o01X0O`1o00?o000006H0V@1V09T07@1V09T00ol00000C02c04`0/`0R
04`0/`03o`00000c0<`0<`3<01d0<`3<1Oooool10000007ooooo00000`00003oooooooooo`02oooo
o`h0o`0000?o00000>H06@3V01T0903V01T00ol00000c00c0<`0<`0N0<`0<`03o`00002c04`0/`1<
01/0/`1<00?o000009T0IP2I06H06P2I06H00ol00000O`1o07l0O`0J07l0O`03o`00001V09T0IP2I
01d0IP2I00<0000004`0/`1<0;<08P1<0;<00ol00000<`3<03<0c00N03<0c0Gooooo0@000001oooo
o`0000<00000ooooooooool00_ooool=0?l00003o`00003V01T0iP0I02@0iP0I00?o00000<`0<`3<
03<07P3<03<00ol00000/`1<0;<0C00K0;<0C003o`00002I06H0V@1V01X0V@1V00?o000007l0O`1o
07l06P1o07l00ol00000IP2I06H0V@0M06H0V@030000001<0;<0C02c0280C02c00?o000003<0c00c
0<`07`0c0<`5ooooo`4000000Oooool0000300000?oooooooooo00;ooooo303o00000ol00000iP0I
0>H06@0T0>H06@03o`00003<03<0c00c01h0c00c00?o00000;<0C02c04`06`2c04`00ol00000V@1V
09T0IP0J09T0IP03o`00001o07l0O`1o01X0O`1o00?o000006H0V@1V09T07@1V09T00`000000C02c
04`0/`0R04`0/`03o`00000c0<`0<`3<0200<`3<1Oooool10000007ooooo00000`00003ooooooooo
o`02ooooo`/0o`0000?o00000>H06@3V01T0903V01T00ol00000c00c0<`0<`0N0<`0<`03o`00002c
04`0/`1<01/0/`1<00?o000009T0IP2I06H06P2I06H00ol00000O`1o07l0O`0K07l0O`03o`00001V
09T0IP2I01`0IP2I00<0000004`0/`1<0;<08`1<0;<00ol00000<`3<03<0c00P03<0c0Gooooo0@00
0001ooooo`0000<00000ooooooooool00_ooool:0?l00003o`00003V01T0iP0I02@0iP0I00?o0000
0<`0<`3<03<07P3<03<00ol00000/`1<0;<0C00K0;<0C003o`00002I06H0V@1V01X0V@1V00?o0000
07l0O`1o07l06`1o07l00ol00000IP2I06H0V@0L06H0V@030000001<0;<0C02c02<0C02c00?o0000
03<0c00c0<`08@0c0<`5ooooo`4000000Oooool0000300000?oooooooooo00;ooooo2@3o00000ol0
0000iP0I0>H06@0T0>H06@03o`00003<03<0c00c01h0c00c00?o00000;<0C02c04`06`2c04`00ol0
0000V@1V09T0IP0J09T0IP03o`00001o07l0O`1o01/0O`1o00?o000006H0V@1V09T0701V09T00`00
0000C02c04`0/`0S04`0/`03o`00000c0<`0<`3<0280<`3<1Oooool10000007ooooo00000`00003o
ooooooooo`02ooooo`P0o`0000?o00000>H06@3V01T0903V01T00ol00000c00c0<`0<`0N0<`0<`03
o`00002c04`0/`1<01/0/`1<00?o000009T0IP2I06H06P2I06H00ol00000O`1o07l0O`0K07l0O`03
o`00001V09T0IP2I01`0IP2I00<0000004`0/`1<0;<08`1<0;<00ol00000<`3<03<0c00S03<0c0Go
oooo0@000001ooooo`0000<00000ooooooooool00_ooool70?l00003o`00003V01T0iP0I02@0iP0I
00?o00000<`0<`3<03<07P3<03<00ol00000/`1<0;<0C00K0;<0C003o`00002I06H0V@1V01X0V@1V
00?o000007l0O`1o07l06`1o07l00ol00000IP2I06H0V@0L06H0V@030000001<0;<0C02c02<0C02c
00?o000003<0c00c0<`0900c0<`5ooooo`4000000Oooool0000300000?oooooooooo00;ooooo1P3o
00000ol00000iP0I0>H06@0U0>H06@03o`00003<03<0c00c01d0c00c00?o00000;<0C02c04`06`2c
04`00ol00000V@1V09T0IP0J09T0IP03o`00001o07l0O`1o01/0O`1o00?o000006H0V@1V09T0701V
09T00`000000C02c04`0/`0S04`0/`03o`00000c0<`0<`3<02D0<`3<1Oooool10000007ooooo0000
0`00003oooooooooo`02ooooo`D0o`0000?o00000>H06@3V01T09@3V01T00ol00000c00c0<`0<`0M
0<`0<`03o`00002c04`0/`1<01/0/`1<00?o000009T0IP2I06H06P2I06H00ol00000O`1o07l0O`0K
07l0O`03o`00001V09T0IP2I01`0IP2I00<0000004`0/`1<0;<08`1<0;<00ol00000<`3<03<0c00V
03<0c0Gooooo0@000001ooooo`0000<00000ooooooooool00_ooool40?l00003o`00003V01T0iP0I
02D0iP0I00?o00000<`0<`3<03<07@3<03<00ol00000/`1<0;<0C00K0;<0C003o`00002I06H0V@1V
01X0V@1V00?o000007l0O`1o07l06P1o07l2o`0001h0IP2I00<0000004`0/`1<0;<08P1<0;<2o`00
02T0<`3<1Oooool10000007ooooo00000`00003oooooooooo`02ooooo`<0o`0000?o00000>H06@3V
01T09@3V01T00ol00000c00c0<`0<`0M0<`0<`03o`00002c04`0/`1<01`0/`1<00?o000009T0IP2I
06H06P2I06H00ol00000O`1o07l0O`0I07l0O`03o`00001V09T0IP2I01d0IP2I00?o000004`0/`1<
0;<08P1<0;<00ol00000<`3<03<0c00Y03<0c0Gooooo0@000001ooooo`0000<00000ooooooooool0
0_ooool20?l00003o`00003V01T0iP0I02D0iP0I00?o00000<`0<`3<03<07@3<03<00ol00000/`1<
0;<0C00L0;<0C003o`00002I06H0V@1V01X0V@1V00?o000007l0O`1o07l06@1o07l00ol00000IP2I
06H0V@0M06H0V@030000001<0;<0C02c0280C02c00?o000003<0c00c0<`0:P0c0<`5ooooo`400000
0Oooool0000300000?oooooooooo00;ooooo00<0o`00o`00003V01T09P3V01T00ol00000c00c0<`0
<`0M0<`0<`03o`00002c04`0/`1<01/0/`1<0_l0000L09T0IP03o`00001o07l0O`1o01T0O`1o00?o
000006H0V@1V09T07@1V09T00`000000C02c04`0/`0R04`0/`03o`00000c0<`0<`3<02/0<`3<1Ooo
ool10000007ooooo00000`00003oooooooooo`02ooooo`03o`00003V01T0iP0I02D0iP0I00?o0000
0<`0<`3<03<07@3<03<00ol00000/`1<0;<0C00K0;<0C003o`00002I06H0V@1V01/0V@1V00?o0000
07l0O`1o07l06P1o07l00ol00000IP2I06H0V@0L06H0V@030000001<0;<0C02c0280C02c00?o0000
03<0c00c0<`0;00c0<`5ooooo`4000000Oooool0000300000?oooooooooo00;ooooo9`3V01T00ol0
0000c00c0<`0<`0M0<`0<`03o`00002c04`0/`1<01/0/`1<00?o000009T0IP2I06H06`2I06H00ol0
0000O`1o07l0O`0J07l0O`03o`00001V09T0IP2I01`0IP2I00<0000004`0/`1<0;<08P1<0;<00ol0
0000<`3<03<0c00]03<0c0Gooooo0@000001ooooo`0000<00000ooooooooool00_oooolV0>H06@03
o`00003<03<0c00c01d0c00c00?o00000;<0C02c04`06`2c04`00ol00000V@1V09T0IP0K09T0IP03
o`00001o07l0O`1o01X0O`1o00?o000006H0V@1V09T0701V09T00`000000C02c04`0/`0R04`0/`03
o`00000c0<`0<`3<02h0<`3<00?o0000ooooooooool00_ooool10000007ooooo00000`00003ooooo
ooooo`02ooooobD0iP0I00?o00000<`0<`3<03<07@3<03<00ol00000/`1<0;<0C00K0;<0C003o`00
002I06H0V@1V01/0V@1V00?o000007l0O`1o07l06P1o07l00ol00000IP2I06H0V@0L06H0V@030000
001<0;<0C02c0280C02c00?o000003<0c00c0<`0;P0c0<`00ol0003oooooooooo`03ooooo`400000
0Oooool0000300000?oooooooooo00;ooooo903V01T00ol00000c00c0<`0<`0M0<`0<`03o`00002c
04`0/`1<01/0/`1<00?o000009T0IP2I06H06`2I06H00ol00000O`1o07l0O`0J07l0O`03o`00001V
09T0IP2I01`0IP2I00<0000004`0/`1<0;<08P1<0;<00ol00000<`3<03<0c00^03<0c003o`00000I
0>Kooooo00Cooooo0@000001ooooo`0000<00000ooooooooool00_oooolR0>H06@;o00007`3<03<0
0ol00000/`1<0;<0C00K0;<0C003o`00002I06H0V@1V01X0V@1V0_l0000L07l0O`03o`00001V09T0
IP2I01`0IP2I00<0000004`0/`1<0;<08P1<0;<00ol00000<`3<03<0c00^03<0c003o`00000I0>H0
6@3V00Gooooo0@000001ooooo`0000<00000ooooooooool00_oooolQ0>H06@03o`00003<03<0c00c
01h0c00c00?o00000;<0C02c04`06`2c04`00ol00000V@1V09T0IP0J09T0IP03o`00001o07l0O`1o
01/0O`1o00?o000006H0V@1V09T0701V09T00`000000C02c04`0/`0R04`0/`03o`00000c0<`0<`3<
02h0<`3<00Co000001T0iP0I0>H06@3V1Oooool10000007ooooo00000`00003oooooooooo`02oooo
ob00iP0I00?o00000<`0<`3<03<07P3<03<00ol00000/`1<0;<0C00K0;<0C003o`00002I06H0V@1V
01X0V@1V00?o000007l0O`1o07l06P1o07l2o`0001h0IP2I00<0000004`0/`1<0;<08P1<0;<00ol0
0000<`3<03<0c00^03<0c003o`00000I0>H06@3V00806@3V1Oooool10000007ooooo00000`00003o
ooooooooo`02ooooob00iP0I00?o00000<`0<`3<03<07P3<03<00ol00000/`1<0;<0C00J0;<0C003
o`00002I06H0V@1V01X0V@1V00?o000007l0O`1o07l06P1o07l00ol00000IP2I06H0V@0N06H0V@03
0000001<0;<0C02c0240C02c00?o000003<0c00c0<`0;P0c0<`00ol000006@3V01T0iP0301T0iPGo
oooo0@000001ooooo`0000<00000ooooooooool00_oooolO0>H06@03o`00003<03<0c00c01h0c00c
00?o00000;<0C02c04`06P2c04`00ol00000V@1V09T0IP0J09T0IP03o`00001o07l0O`1o01X0O`1o
00?o000006H0V@1V09T07P1V09T00`000000C02c04`0/`0Q04`0/`03o`00000c0<`0<`3<02h0<`3<
00?o000001T0iP0I0>H0100I0>H5ooooo`4000000Oooool0000300000?oooooooooo00;ooooo7P3V
01T00ol00000c00c0<`0<`0N0<`0<`03o`00002c04`0/`1<01X0/`1<00?o000009T0IP2I06H06P2I
06H00ol00000O`1o07l0O`0J07l0O`03o`00001V09T0IP2I01h0IP2I00<0000004`0/`1<0;<08@1<
0;<00ol00000<`3<03<0c00^03<0c003o`00000I0>H06@3V00D06@3V1Oooool10000007ooooo0000
0`00003oooooooooo`02oooooad0iP0I00?o00000<`0<`3<03<07P3<03<00ol00000/`1<0;<0C00K
0;<0C003o`00002I06H0V@1V01T0V@1V00?o000007l0O`1o07l06P1o07l00ol00000IP2I06H0V@0N
06H0V@030000001<0;<0C02c0240C02c00?o000003<0c00c0<`0;P0c0<`00ol000006@3V01T0iP06
01T0iPGooooo0@000001ooooo`0000<00000ooooooooool00_oooolL0>H06@03o`00003<03<0c00c
01h0c00c00?o00000;<0C02c04`06`2c04`00ol00000V@1V09T0IP0I09T0IP03o`00001o07l0O`1o
01/0O`1o00?o000006H0V@1V09T07@1V09T00`000000C02c04`0/`0R04`0/`03o`00000c0<`0<`3<
02d0<`3<00?o000001T0iP0I0>H01`0I0>H5ooooo`4000000Oooool0000300000?oooooooooo00;o
oooo6`3V01T00ol00000c00c0<`0<`0N0<`0<`03o`00002c04`0/`1<01/0/`1<00?o000009T0IP2I
06H06@2I06H00ol00000O`1o07l0O`0K07l0O`03o`00001V09T0IP2I01d0IP2I00<0000004`0/`1<
0;<08P1<0;<00ol00000<`3<03<0c00]03<0c003o`00000I0>H06@3V00P06@3V1Oooool10000007o
oooo00000`00003oooooooooo`02oooooaX0iP0I00?o00000<`0<`3<03<07P3<03<00ol00000/`1<
0;<0C00K0;<0C003o`00002I06H0V@1V01T0V@1V00?o000007l0O`1o07l06`1o07l00ol00000IP2I
06H0V@0M06H0V@030000001<0;<0C02c0280C02c00?o000003<0c00c0<`0;@0c0<`00ol000006@3V
01T0iP0901T0iPGooooo0@000001ooooo`0000<00000ooooooooool00_oooolI0>H06@03o`00003<
03<0c00c01h0c00c00?o00000;<0C02c04`06`2c04`00ol00000V@1V09T0IP0I09T0IP03o`00001o
07l0O`1o01/0O`1o00?o000006H0V@1V09T07@1V09T00`000000C02c04`0/`0R04`0/`03o`00000c
0<`0<`3<02h0<`3<00?o000001T0iP0I0>H02@0I0>H5ooooo`4000000Oooool0000300000?oooooo
oooo00;ooooo603V01T00ol00000c00c0<`0<`0N0<`0<`03o`00002c04`0/`1<01/0/`1<00?o0000
09T0IP2I06H06@2I06H00ol00000O`1o07l0O`0K07l0O`03o`00001V09T0IP2I01d0IP2I00<00000
04`0/`1<0;<08P1<0;<00ol00000<`3<03<0c00^03<0c003o`00000I0>H06@3V00X06@3V1Oooool1
0000007ooooo00000`00003oooooooooo`02oooooaL0iP0I00?o00000<`0<`3<03<07P3<03<00ol0
0000/`1<0;<0C00K0;<0C003o`00002I06H0V@1V01X0V@1V00?o000007l0O`1o07l06P1o07l00ol0
0000IP2I06H0V@0M06H0V@030000001<0;<0C02c0280C02c00?o000003<0c00c0<`0;P0c0<`00ol0
00006@3V01T0iP0;01T0iPGooooo0@000001ooooo`0000<00000ooooooooool00_oooolF0>H06@03
o`00003<03<0c00c01h0c00c00?o00000;<0C02c04`06`2c04`00ol00000V@1V09T0IP0J09T0IP03
o`00001o07l0O`1o01X0O`1o00?o000006H0V@1V09T07@1V09T00`000000C02c04`0/`0R04`0/`03
o`00000c0<`0<`3<02h0<`3<00?o000001T0iP0I0>H0300I0>H5ooooo`4000000Oooool000030000
0?oooooooooo00;ooooo5@3V01T00ol00000c00c0<`0<`0N0<`0<`03o`00002c04`0/`1<01/0/`1<
00?o000009T0IP2I06H06P2I06H00ol00000O`1o07l0O`0J07l0O`03o`00001V09T0IP2I01`0IP2I
0P00000T04`0/`03o`00000c0<`0<`3<02h0<`3<00?o000001T0iP0I0>H03@0I0>H5ooooo`400000
0Oooool0000300000?oooooooooo00;ooooo5@3V01T00ol00000c00c0<`0<`0M0<`0<`03o`00002c
04`0/`1<01/0/`1<00?o000009T0IP2I06H06P2I06H00ol00000O`1o07l0O`0J07l0O`03o`00001V
09T0IP2I01`0IP2I00<0000004`0/`1<0;<08`1<0;<00ol00000<`3<03<0c00^03<0c003o`00000I
0>H06@3V00h06@3V1Oooool10000007ooooo00000`00003oooooooooo`02oooooa@0iP0I00?o0000
0<`0<`3<03<07@3<03<00ol00000/`1<0;<0C00K0;<0C003o`00002I06H0V@1V01X0V@1V00?o0000
07l0O`1o07l06P1o07l00ol00000IP2I06H0V@0M06H0V@030000001<0;<0C02c0280C02c00?o0000
03<0c00c0<`0;P0c0<`00ol000006@3V01T0iP0?01T0iPGooooo0@000001ooooo`0000<00000oooo
ooooool00_oooolC0>H06@03o`00003<03<0c00c01d0c00c00?o00000;<0C02c04`06`2c04`00ol0
0000V@1V09T0IP0J09T0IP03o`00001o07l0O`1o01X0O`1o00?o000006H0V@1V09T07@1V09T00`00
0000C02c04`0/`0R04`0/`03o`00000c0<`0<`3<02h0<`3<00?o000001T0iP0I0>H0400I0>H5oooo
o`4000000Oooool0000300000?oooooooooo00;ooooo4P3V01T00ol00000c00c0<`0<`0M0<`0<`03
o`00002c04`0/`1<01/0/`1<00?o000009T0IP2I06H06P2I06H00ol00000O`1o07l0O`0J07l0O`03
o`00001V09T0IP2I01d0IP2I00<0000004`0/`1<0;<08P1<0;<00ol00000<`3<03<0c00^03<0c003
o`00000I0>H06@3V01406@3V1Oooool10000007ooooo00000`00003oooooooooo`02oooooa40iP0I
00?o00000<`0<`3<03<07@3<03<00ol00000/`1<0;<0C00K0;<0C003o`00002I06H0V@1V01X0V@1V
00?o000007l0O`1o07l06P1o07l00ol00000IP2I06H0V@0M06H0V@030000001<0;<0C02c0280C02c
00?o000003<0c00c0<`0;P0c0<`00ol000006@3V01T0iP0B01T0iPGooooo0@000001ooooo`0000<0
0000ooooooooool00_ooool@0>H06@03o`00003<03<0c00c01d0c00c00?o00000;<0C02c04`06`2c
04`00ol00000V@1V09T0IP0J09T0IP03o`00001o07l0O`1o01X0O`1o00?o000006H0V@1V09T07@1V
09T00`000000C02c04`0/`0R04`0/`03o`00000c0<`0<`3<02h0<`3<00?o000001T0iP0I0>H04`0I
0>H5ooooo`4000000Oooool0000300000?oooooooooo00;ooooo3`3V01T00ol00000c00c0<`0<`0M
0<`0<`03o`00002c04`0/`1<01/0/`1<00?o000009T0IP2I06H06P2I06H00ol00000O`1o07l0O`0J
07l0O`03o`00001V09T0IP2I01d0IP2I00<0000004`0/`1<0;<08P1<0;<00ol00000<`3<03<0c00^
03<0c003o`00000I0>H06@3V01@06@3V1Oooool10000007ooooo00000`00003oooooooooo`02oooo
o`h0iP0I00?o00000<`0<`3<03<07@3<03<00ol00000/`1<0;<0C00K0;<0C003o`00002I06H0V@1V
01X0V@1V00?o000007l0O`1o07l06P1o07l00ol00000IP2I06H0V@0M06H0V@030000001<0;<0C02c
0280C02c00?o000003<0c00c0<`0;P0c0<`00ol000006@3V01T0iP0E01T0iPGooooo0@000001oooo
o`0000<00000ooooooooool00_ooool=0>H06@03o`00003<03<0c00c01d0c00c00?o00000;<0C02c
04`06`2c04`00ol00000V@1V09T0IP0J09T0IP03o`00001o07l0O`1o01X0O`1o00?o000006H0V@1V
09T07@1V09T00`000000C02c04`0/`0R04`0/`03o`00000c0<`0<`3<02h0<`3<00?o000001T0iP0I
0>H05P0I0>H5ooooo`4000000Oooool0000300000?oooooooooo00;ooooo2`3V01T2o`0001l0c00c
00?o00000;<0C02c04`06`2c04`00ol00000V@1V09T0IP0J09T0IP03o`00001o07l0O`1o01X0O`1o
00?o000006H0V@1V09T07@1V09T00`000000C02c04`0/`0R04`0/`03o`00000c0<`0<`3<02h0<`3<
00?o000001T0iP0I0>H05`0I0>H5ooooo`4000000Oooool0000300000?oooooooooo00;ooooo2P3V
01T00ol00000c00c0<`0<`0N0<`0<`03o`00002c04`0/`1<01/0/`1<00?o000009T0IP2I06H06P2I
06H00ol00000O`1o07l0O`0J07l0O`03o`00001V09T0IP2I01d0IP2I00<0000004`0/`1<0;<08P1<
0;<00ol00000<`3<03<0c00^03<0c003o`00000I0>H06@3V01P06@3V1Oooool10000007ooooo0000
0`00003oooooooooo`02ooooo`T0iP0I00?o00000<`0<`3<03<07`3<03<00ol00000/`1<0;<0C00J
0;<0C003o`00002I06H0V@1V01X0V@1V00?o000007l0O`1o07l06`1o07l00ol00000IP2I06H0V@0L
06H0V@030000001<0;<0C02c0280C02c00?o000003<0c00c0<`0;P0c0<`00ol000006@3V01T0iP0I
01T0iPGooooo0@000001ooooo`0000<00000ooooooooool00_ooool80>H06@03o`00003<03<0c00c
01l0c00c00?o00000;<0C02c04`06P2c04`00ol00000V@1V09T0IP0J09T0IP03o`00001o07l0O`1o
01/0O`1o00?o000006H0V@1V09T0701V09T00`000000C02c04`0/`0R04`0/`03o`00000c0<`0<`3<
02h0<`3<00?o000001T0iP0I0>H06P0I0>H5ooooo`4000000Oooool0000300000?oooooooooo00;o
oooo1`3V01T00ol00000c00c0<`0<`0O0<`0<`03o`00002c04`0/`1<01X0/`1<00?o000009T0IP2I
06H06P2I06H00ol00000O`1o07l0O`0K07l0O`03o`00001V09T0IP2I01d0IP2I00<0000004`0/`1<
0;<08@1<0;<00ol00000<`3<03<0c00^03<0c003o`00000I0>H06@3V01/06@3V1Oooool10000007o
oooo00000`00003oooooooooo`02ooooo`H0iP0I00?o00000<`0<`3<03<07`3<03<00ol00000/`1<
0;<0C00J0;<0C003o`00002I06H0V@1V01X0V@1V00?o000007l0O`1o07l06`1o07l00ol00000IP2I
06H0V@0M06H0V@030000001<0;<0C02c0240C02c00?o000003<0c00c0<`0;P0c0<`00ol000006@3V
01T0iP0L01T0iPGooooo0@000001ooooo`0000<00000ooooooooool00_ooool50>H06@03o`00003<
03<0c00c01l0c00c00?o00000;<0C02c04`06`2c04`00ol00000V@1V09T0IP0I09T0IP03o`00001o
07l0O`1o01/0O`1o00?o000006H0V@1V09T07@1V09T00`000000C02c04`0/`0Q04`0/`03o`00000c
0<`0<`3<02h0<`3<00?o000001T0iP0I0>H07@0I0>H5ooooo`4000000Oooool0000300000?oooooo
oooo00;ooooo103V01T00ol00000c00c0<`0<`0O0<`0<`03o`00002c04`0/`1<01/0/`1<00?o0000
09T0IP2I06H06@2I06H00ol00000O`1o07l0O`0K07l0O`03o`00001V09T0IP2I01d0IP2I00<00000
04`0/`1<0;<08P1<0;<00ol00000<`3<03<0c00]03<0c003o`00000I0>H06@3V01h06@3V1Oooool1
0000007ooooo00000`00003oooooooooo`02ooooo`<0iP0I00?o00000<`0<`3<03<07`3<03<00ol0
0000/`1<0;<0C00K0;<0C003o`00002I06H0V@1V01T0V@1V00?o000007l0O`1o07l06`1o07l00ol0
0000IP2I06H0V@0M06H0V@030000001<0;<0C02c0280C02c00?o000003<0c00c0<`0;@0c0<`00ol0
00006@3V01T0iP0O01T0iPGooooo0@000001ooooo`0000<00000ooooooooool00_ooool20>H06@03
o`00003<03<0c00c01l0c00c00?o00000;<0C02c04`06`2c04`00ol00000V@1V09T0IP0I09T0IP03
o`00001o07l0O`1o01/0O`1o00?o000006H0V@1V09T07@1V09T00`000000C02c04`0/`0R04`0/`03
o`00000c0<`0<`3<02d0<`3<00?o000001T0iP0I0>H0800I0>H5ooooo`4000000Oooool000030000
0?oooooooooo00;ooooo00<0iP0Io`00003<03<0803<03<00ol00000/`1<0;<0C00K0;<0C003o`00
002I06H0V@1V01T0V@1V00?o000007l0O`1o07l06`1o07l00ol00000IP2I06H0V@0M06H0V@030000
001<0;<0C02c0280C02c00?o000003<0c00c0<`0;P0c0<`00ol000006@3V01T0iP0P01T0iPGooooo
0@000001ooooo`0000<00000ooooooooool00_ooool00ol00000c00c0<`0<`0O0<`0<`03o`00002c
04`0/`1<01/0/`1<00?o000009T0IP2I06H06@2I06H00ol00000O`1o07l0O`0K07l0O`03o`00001V
09T0IP2I01d0IP2I00<0000004`0/`1<0;<08P1<0;<00ol00000<`3<03<0c00^03<0c003o`00000I
0>H06@3V02406@3V1Oooool10000007ooooo00000`00003oooooooooo`02ooooob40c00c00?o0000
0;<0C02c04`06`2c04`00ol00000V@1V09T0IP0J09T0IP03o`00001o07l0O`1o01X0O`1o00?o0000
06H0V@1V09T07@1V09T00`000000C02c04`0/`0R04`0/`03o`00000c0<`0<`3<02h0<`3<00?o0000
01T0iP0I0>H08P0I0>H5ooooo`4000000Oooool0000300000?oooooooooo00;ooooo803<03<00ol0
0000/`1<0;<0C00K0;<0C003o`00002I06H0V@1V01X0V@1V00?o000007l0O`1o07l06P1o07l00ol0
0000IP2I06H0V@0L06H0V@800000901<0;<00ol00000<`3<03<0c00^03<0c003o`00000I0>H06@3V
02<06@3V1Oooool10000007ooooo00000`00003oooooooooo`02oooooal0c00c00?o00000;<0C02c
04`06`2c04`00ol00000V@1V09T0IP0J09T0IP03o`00001o07l0O`1o01X0O`1o00?o000006H0V@1V
09T0701V09T00`000000C02c04`0/`0S04`0/`03o`00000c0<`0<`3<02h0<`3<00?o000001T0iP0I
0>H0900I0>H5ooooo`4000000Oooool0000300000?oooooooooo00;ooooo7P3<03<00ol00000/`1<
0;<0C00K0;<0C003o`00002I06H0V@1V01X0V@1V00?o000007l0O`1o07l06P1o07l00ol00000IP2I
06H0V@0L06H0V@030000001<0;<0C02c02<0C02c00?o000003<0c00c0<`0;P0c0<`00ol000006@3V
01T0iP0U01T0iPGooooo0@000001ooooo`0000<00000ooooooooool00_oooolM0<`0<`03o`00002c
04`0/`1<01/0/`1<00?o000009T0IP2I06H06P2I06H00ol00000O`1o07l0O`0J07l0O`03o`00001V
09T0IP2I01d0IP2I00<0000004`0/`1<0;<08P1<0;<00ol00000<`3<03<0c00^03<0c003o`00000I
0>H06@3V02H06@3V1Oooool10000007ooooo00000`00003oooooooooo`02oooooa`0c00c00?o0000
0;<0C02c04`06`2c04`00ol00000V@1V09T0IP0J09T0IP03o`00001o07l0O`1o01X0O`1o00?o0000
06H0V@1V09T07@1V09T00`000000C02c04`0/`0R04`0/`03o`00000c0<`0<`3<02h0<`3<00?o0000
01T0iP0I0>H09`0I0>H5ooooo`4000000Oooool0000300000?oooooooooo00;ooooo6`3<03<00ol0
0000/`1<0;<0C00K0;<0C003o`00002I06H0V@1V01X0V@1V00?o000007l0O`1o07l06P1o07l00ol0
0000IP2I06H0V@0M06H0V@030000001<0;<0C02c0280C02c00?o000003<0c00c0<`0;P0c0<`00ol0
00006@3V01T0iP0X01T0iPGooooo0@000001ooooo`0000<00000ooooooooool00_oooolJ0<`0<`03
o`00002c04`0/`1<01/0/`1<00?o000009T0IP2I06H06P2I06H00ol00000O`1o07l0O`0J07l0O`03
o`00001V09T0IP2I01d0IP2I00<0000004`0/`1<0;<08P1<0;<00ol00000<`3<03<0c00^03<0c003
o`00000I0>H06@3V02T06@3V1Oooool10000007ooooo00000`00003oooooooooo`02oooooaT0c00c
00?o00000;<0C02c04`06`2c04`00ol00000V@1V09T0IP0J09T0IP03o`00001o07l0O`1o01X0O`1o
00?o000006H0V@1V09T07@1V09T00`000000C02c04`0/`0R04`0/`03o`00000c0<`0<`3<02h0<`3<
00?o000001T0iP0I0>H0:P0I0>H5ooooo`4000000Oooool0000300000?oooooooooo00;ooooo603<
03<00ol00000/`1<0;<0C00K0;<0C003o`00002I06H0V@1V01X0V@1V00?o000007l0O`1o07l06P1o
07l00ol00000IP2I06H0V@0M06H0V@030000001<0;<0C02c0280C02c00?o000003<0c00c0<`0;P0c
0<`00ol000006@3V01T0iP0[01T0iPGooooo0@000001ooooo`0000<00000ooooooooool00_oooolG
0<`0<`03o`00002c04`0/`1<01/0/`1<00?o000009T0IP2I06H06P2I06H00ol00000O`1o07l0O`0J
07l0O`03o`00001V09T0IP2I01d0IP2I00<0000004`0/`1<0;<08P1<0;<00ol00000<`3<03<0c00^
03<0c003o`00000I0>H06@3V02`06@3V1Oooool10000007ooooo00000`00003oooooooooo`02oooo
oaH0c00c00?o00000;<0C02c04`06`2c04`00ol00000V@1V09T0IP0I09T0IP;o0000701o07l00ol0
0000IP2I06H0V@0M06H0V@030000001<0;<0C02c0280C02c00?o000003<0c00c0<`0;P0c0<`00ol0
00006@3V01T0iP0]01T0iPGooooo0@000001ooooo`0000<00000ooooooooool00_oooolE0<`0<`03
o`00002c04`0/`1<01/0/`1<00?o000009T0IP2I06H06@2I06H00ol00000O`1o07l0O`0K07l0O`03
o`00001V09T0IP2I01d0IP2I00<0000004`0/`1<0;<08P1<0;<00ol00000<`3<03<0c00^03<0c003
o`00000I0>H06@3V02h06@3V1Oooool10000007ooooo00000`00003oooooooooo`02oooooa@0c00c
00?o00000;<0C02c04`06`2c04`00ol00000V@1V09T0IP0J09T0IP03o`00001o07l0O`1o01/0O`1o
00?o000006H0V@1V09T0701V09T00`000000C02c04`0/`0R04`0/`03o`00000c0<`0<`3<02h0<`3<
00?o000001T0iP0I0>H0;`0I0>H5ooooo`4000000Oooool0000300000?oooooooooo00;ooooo4`3<
03<00ol00000/`1<0;<0C00K0;<0C003o`00002I06H0V@1V01X0V@1V00?o000007l0O`1o07l06`1o
07l00ol00000IP2I06H0V@0L06H0V@030000001<0;<0C02c0280C02c00?o000003<0c00c0<`0;P0c
0<`00ol000006@3V01T0iP0`01T0iPGooooo0@000001ooooo`0000<00000ooooooooool00_oooolB
0<`0<`03o`00002c04`0/`1<01/0/`1<00?o000009T0IP2I06H06P2I06H00ol00000O`1o07l0O`0K
07l0O`03o`00001V09T0IP2I01`0IP2I00<0000004`0/`1<0;<08P1<0;<00ol00000<`3<03<0c00^
03<0c003o`00000I0>H06@3V03406@3V1Oooool10000007ooooo00000`00003oooooooooo`02oooo
oa40c00c00?o00000;<0C02c04`06`2c04`00ol00000V@1V09T0IP0J09T0IP03o`00001o07l0O`1o
01/0O`1o00?o000006H0V@1V09T07@1V09T00`000000C02c04`0/`0Q04`0/`03o`00000c0<`0<`3<
02h0<`3<00?o000001T0iP0I0>H0<P0I0>H5ooooo`4000000Oooool0000300000?oooooooooo00;o
oooo403<03<00ol00000/`1<0;<0C00K0;<0C003o`00002I06H0V@1V01X0V@1V00?o000007l0O`1o
07l06`1o07l00ol00000IP2I06H0V@0M06H0V@030000001<0;<0C02c0240C02c00?o000003<0c00c
0<`0;P0c0<`00ol000006@3V01T0iP0c01T0iPGooooo0@000001ooooo`0000<00000ooooooooool0
0_ooool?0<`0<`03o`00002c04`0/`1<01`0/`1<00?o000009T0IP2I06H06@2I06H00ol00000O`1o
07l0O`0K07l0O`03o`00001V09T0IP2I01d0IP2I00<0000004`0/`1<0;<08@1<0;<00ol00000<`3<
03<0c00^03<0c003o`00000I0>H06@3V03@06@3V1Oooool10000007ooooo00000`00003ooooooooo
o`02ooooo`h0c00c00?o00000;<0C02c04`0702c04`00ol00000V@1V09T0IP0I09T0IP03o`00001o
07l0O`1o01/0O`1o00?o000006H0V@1V09T07@1V09T00`000000C02c04`0/`0R04`0/`03o`00000c
0<`0<`3<02d0<`3<00?o000001T0iP0I0>H0=@0I0>H5ooooo`4000000Oooool0000300000?oooooo
oooo00;ooooo3@3<03<00ol00000/`1<0;<0C00L0;<0C003o`00002I06H0V@1V01T0V@1V00?o0000
07l0O`1o07l06`1o07l00ol00000IP2I06H0V@0M06H0V@030000001<0;<0C02c0280C02c00?o0000
03<0c00c0<`0;@0c0<`00ol000006@3V01T0iP0f01T0iPGooooo0@000001ooooo`0000<00000oooo
ooooool00_ooool<0<`0<`03o`00002c04`0/`1<01`0/`1<00?o000009T0IP2I06H06@2I06H00ol0
0000O`1o07l0O`0K07l0O`03o`00001V09T0IP2I01d0IP2I00<0000004`0/`1<0;<08P1<0;<00ol0
0000<`3<03<0c00]03<0c003o`00000I0>H06@3V03L06@3V1Oooool10000007ooooo00000`00003o
ooooooooo`02ooooo``0c00c00?o00000;<0C02c04`06`2c04`00ol00000V@1V09T0IP0I09T0IP03
o`00001o07l0O`1o01/0O`1o00?o000006H0V@1V09T07@1V09T00`000000C02c04`0/`0R04`0/`03
o`00000c0<`0<`3<02h0<`3<00?o000001T0iP0I0>H0=`0I0>H5ooooo`4000000Oooool000030000
0?oooooooooo00;ooooo2`3<03<00ol00000/`1<0;<0C00K0;<0C003o`00002I06H0V@1V01T0V@1V
00?o000007l0O`1o07l06`1o07l00ol00000IP2I06H0V@0M06H0V@030000001<0;<0C02c0280C02c
00?o000003<0c00c0<`0;P0c0<`00ol000006@3V01T0iP0h01T0iPGooooo0@000001ooooo`0000<0
0000ooooooooool00_ooool90<`0<`;o00007@2c04`00ol00000V@1V09T0IP0I09T0IP03o`00001o
07l0O`1o01X0O`1o0_l0000O06H0V@030000001<0;<0C02c0280C02c00?o000003<0c00c0<`0;@0c
0<`2o`0003/06@3V1Oooool10000007ooooo00000`00003oooooooooo`02ooooo`P0c00c00?o0000
0;<0C02c04`0702c04`00ol00000V@1V09T0IP0J09T0IP03o`00001o07l0O`1o01T0O`1o00?o0000
06H0V@1V09T07P1V09T00`000000C02c04`0/`0R04`0/`03o`00000c0<`0<`3<02d0<`3<00?o0000
01T0iP0I0>H0>`0I0>H5ooooo`4000000Oooool0000300000?oooooooooo00;ooooo1`3<03<00ol0
0000/`1<0;<0C00L0;<0C003o`00002I06H0V@1V01X0V@1V00?o000007l0O`1o07l06@1o07l00ol0
0000IP2I06H0V@0N06H0V@030000001<0;<0C02c0280C02c00?o000003<0c00c0<`0;@0c0<`00ol0
00006@3V01T0iP0l01T0iPGooooo0@000001ooooo`0000<00000ooooooooool00_ooool60<`0<`03
o`00002c04`0/`1<01`0/`1<00?o000009T0IP2I06H06P2I06H00ol00000O`1o07l0O`0I07l0O`03
o`00001V09T0IP2I01h0IP2I00<0000004`0/`1<0;<08P1<0;<00ol00000<`3<03<0c00]03<0c003
o`00000I0>H06@3V03d06@3V1Oooool10000007ooooo00000`00003oooooooooo`02ooooo`D0c00c
00?o00000;<0C02c04`0702c04`00ol00000V@1V09T0IP0J09T0IP03o`00001o07l0O`1o01T0O`1o
00?o000006H0V@1V09T07P1V09T00`000000C02c04`0/`0R04`0/`03o`00000c0<`0<`3<02d0<`3<
00?o000001T0iP0I0>H0?P0I0>H5ooooo`4000000Oooool0000300000?oooooooooo00;ooooo103<
03<00ol00000/`1<0;<0C00K0;<0C0;o0000702I06H00ol00000O`1o07l0O`0I07l0O`03o`00001V
09T0IP2I01h0IP2I00<0000004`0/`1<0;<08P1<0;<00ol00000<`3<03<0c00]03<0c003o`00000I
0>H06@3V03l06@3V1Oooool10000007ooooo00000`00003oooooooooo`02ooooo`<0c00c00?o0000
0;<0C02c04`06`2c04`00ol00000V@1V09T0IP0K09T0IP03o`00001o07l0O`1o01X0O`1o00?o0000
06H0V@1V09T07@1V09T00`000000C02c04`0/`0R04`0/`03o`00000c0<`0<`3<02d0<`3<00?o0000
01T0iP0I0>H0@00I0>H5ooooo`4000000Oooool0000300000?oooooooooo00;ooooo0P3<03<00ol0
0000/`1<0;<0C00K0;<0C003o`00002I06H0V@1V01/0V@1V00?o000007l0O`1o07l06P1o07l00ol0
0000IP2I06H0V@0M06H0V@030000001<0;<0C02c0280C02c00?o000003<0c00c0<`0;@0c0<`00ol0
00006@3V01T0iP1101T0iPGooooo0@000001ooooo`0000<00000ooooooooool00_ooool00`3<03?o
00000;<0C00L0;<0C003o`00002I06H0V@1V01/0V@1V00?o000007l0O`1o07l06P1o07l00ol00000
IP2I06H0V@0M06H0V@030000001<0;<0C02c0280C02c00?o000003<0c00c0<`0;@0c0<`00ol00000
6@3V01T0iP1201T0iPGooooo0@000001ooooo`0000<00000ooooooooool00_ooool00ol00000/`1<
0;<0C00K0;<0C003o`00002I06H0V@1V01/0V@1V00?o000007l0O`1o07l06P1o07l00ol00000IP2I
06H0V@0M06H0V@030000001<0;<0C02c0280C02c00?o000003<0c00c0<`0;@0c0<`00ol000006@3V
01T0iP1301T0iPGooooo0@000001ooooo`0000<00000ooooooooool00_oooolM0;<0C003o`00002I
06H0V@1V01/0V@1V00?o000007l0O`1o07l06P1o07l00ol00000IP2I06H0V@0M06H0V@030000001<
0;<0C02c0280C02c00?o000003<0c00c0<`0;@0c0<`00ol000006@3V01T0iP1401T0iPGooooo0@00
0001ooooo`0000<00000ooooooooool00_oooolL0;<0C003o`00002I06H0V@1V01X0V@1V0_l0000L
07l0O`03o`00001V09T0IP2I01d0IP2I00<0000004`0/`1<0;<08@1<0;<2o`0002l0<`3<00?o0000
01T0iP0I0>H0A@0I0>H5ooooo`4000000Oooool0000300000?oooooooooo00;ooooo6`2c04`00ol0
0000V@1V09T0IP0J09T0IP03o`00001o07l0O`1o01/0O`1o00?o000006H0V@1V09T07@1V09T00`00
0000C02c04`0/`0Q04`0/`03o`00000c0<`0<`3<02h0<`3<00?o000001T0iP0I0>H0AP0I0>H5oooo
o`4000000Oooool0000300000?oooooooooo00;ooooo6P2c04`00ol00000V@1V09T0IP0J09T0IP03
o`00001o07l0O`1o01/0O`1o00?o000006H0V@1V09T07@1V09T00`000000C02c04`0/`0Q04`0/`03
o`00000c0<`0<`3<02h0<`3<00?o000001T0iP0I0>H0A`0I0>H5ooooo`4000000Oooool000030000
0?oooooooooo00;ooooo6@2c04`00ol00000V@1V09T0IP0J09T0IP03o`00001o07l0O`1o01/0O`1o
00?o000006H0V@1V09T07@1V09T00`000000C02c04`0/`0Q04`0/`03o`00000c0<`0<`3<02h0<`3<
00?o000001T0iP0I0>H0B00I0>H5ooooo`4000000Oooool0000300000?oooooooooo00;ooooo602c
04`00ol00000V@1V09T0IP0J09T0IP03o`00001o07l0O`1o01/0O`1o00?o000006H0V@1V09T07@1V
09T00`000000C02c04`0/`0Q04`0/`03o`00000c0<`0<`3<02h0<`3<00?o000001T0iP0I0>H0B@0I
0>H5ooooo`4000000Oooool0000300000?oooooooooo00;ooooo5`2c04`00ol00000V@1V09T0IP0J
09T0IP03o`00001o07l0O`1o01/0O`1o00?o000006H0V@1V09T07@1V09T00`000000C02c04`0/`0Q
04`0/`03o`00000c0<`0<`3<02h0<`3<00?o000001T0iP0I0>H0BP0I0>H5ooooo`4000000Oooool0
000300000?oooooooooo00;ooooo5`2c04`00ol00000V@1V09T0IP0I09T0IP03o`00001o07l0O`1o
01/0O`1o00?o000006H0V@1V09T07@1V09T00`000000C02c04`0/`0Q04`0/`03o`00000c0<`0<`3<
02h0<`3<00?o000001T0iP0I0>H0B`0I0>H5ooooo`4000000Oooool0000300000?oooooooooo00;o
oooo5P2c04`00ol00000V@1V09T0IP0I09T0IP03o`00001o07l0O`1o01`0O`1o00?o000006H0V@1V
09T0701V09T00`000000C02c04`0/`0R04`0/`03o`00000c0<`0<`3<02d0<`3<00?o000001T0iP0I
0>H0C00I0>H5ooooo`4000000Oooool0000300000?oooooooooo00;ooooo5@2c04`00ol00000V@1V
09T0IP0I09T0IP03o`00001o07l0O`1o01`0O`1o00?o000006H0V@1V09T0701V09T00`000000C02c
04`0/`0R04`0/`03o`00000c0<`0<`3<02d0<`3<00?o000001T0iP0I0>H0C@0I0>H5ooooo`400000
0Oooool0000300000?oooooooooo00;ooooo502c04`00ol00000V@1V09T0IP0I09T0IP03o`00001o
07l0O`1o01`0O`1o00?o000006H0V@1V09T0701V09T00`000000C02c04`0/`0R04`0/`03o`00000c
0<`0<`3<02d0<`3<00?o000001T0iP0I0>H0CP0I0>H5ooooo`4000000Oooool0000300000?oooooo
oooo00;ooooo4`2c04`00ol00000V@1V09T0IP0I09T0IP03o`00001o07l0O`1o01`0O`1o00?o0000
06H0V@1V09T0701V09T00`000000C02c04`0/`0S04`0/`03o`00000c0<`0<`3<02d0<`3<00?o0000
01T0iP0I0>H0CP0I0>H5ooooo`4000000Oooool0000300000?oooooooooo00;ooooo4P2c04`00ol0
0000V@1V09T0IP0I09T0IP03o`00001o07l0O`1o01`0O`1o00?o000006H0V@1V09T0701V09T00`00
0000C02c04`0/`0S04`0/`03o`00000c0<`0<`3<02d0<`3<00?o000001T0iP0I0>H0C`0I0>H5oooo
o`4000000Oooool0000300000?oooooooooo00;ooooo4@2c04`00ol00000V@1V09T0IP0J09T0IP03
o`00001o07l0O`1o01X0O`1o0_l0000N06H0V@030000001<0;<0C02c0280C02c0_l0000_03<0c003
o`00000I0>H06@3V05006@3V00?o0000ooooooooool00_ooool10000007ooooo00000`00003ooooo
ooooo`02oooooa00/`1<00?o000009T0IP2I06H06P2I06H00ol00000O`1o07l0O`0J07l0O`03o`00
001V09T0IP2I01d0IP2I00<0000004`0/`1<0;<08P1<0;<00ol00000<`3<03<0c00^03<0c003o`00
000I0>H06@3V05006@3V00?o0000ooooooooool00oooool10000007ooooo00000`00003ooooooooo
o`02ooooo`l0/`1<00?o000009T0IP2I06H06P2I06H00ol00000O`1o07l0O`0J07l0O`03o`00001V
09T0IP2I01d0IP2I00<0000004`0/`1<0;<08P1<0;<00ol00000<`3<03<0c00^03<0c003o`00000I
0>H06@3V05006@3V00?o00000000ooooool01?ooool10000007ooooo00000`00003oooooooooo`02
ooooo`h0/`1<00?o000009T0IP2I06H06P2I06H00ol00000O`1o07l0O`0J07l0O`03o`00001V09T0
IP2I01d0IP2I00<0000004`0/`1<0;<08P1<0;<00ol00000<`3<03<0c00^03<0c003o`00000I0>H0
6@3V05006@3V00?o00000000o`000?l01Oooool10000007ooooo00000`00003oooooooooo`02oooo
o`d0/`1<00?o000009T0IP2I06H06P2I06H00ol00000O`1o07l0O`0J07l0O`03o`00001V09T0IP2I
01d0IP2I00<0000004`0/`1<0;<08P1<0;<00ol00000<`3<03<0c00^03<0c003o`00000I0>H06@3V
05006@3V00Co00000000o`000?l0003o1Oooool10000007ooooo00000`00003oooooooooo`02oooo
o``0/`1<00?o000009T0IP2I06H06P2I06H00ol00000O`1o07l0O`0J07l0O`03o`00001V09T0IP2I
01d0IP2I00<0000004`0/`1<0;<08P1<0;<00ol00000<`3<03<0c00^03<0c003o`00000I0>H06@3V
05006@3V00?o00000000o`000?l00P000?l5ooooo`4000000Oooool0000300000?oooooooooo00;o
oooo2`2c04`00ol00000V@1V09T0IP0J09T0IP03o`00001o07l0O`1o01X0O`1o00?o000006H0V@1V
09T07@1V09T00`000000C02c04`0/`0R04`0/`03o`00000c0<`0<`3<02h0<`3<00?o000001T0iP0I
0>H0D00I0>H00ol00000003o0000o`030000o`Gooooo0@000001ooooo`0000<00000ooooooooool0
0_ooool:0;<0C003o`00002I06H0V@1V01X0V@1V00?o000007l0O`1o07l06P1o07l00ol00000IP2I
06H0V@0M06H0V@030000001<0;<0C02c0280C02c00?o000003<0c00c0<`0;P0c0<`00ol000006@3V
01T0iP1@01T0iP03o`0000000?l0003o00@0003o1Oooool10000007ooooo00000`00003ooooooooo
o`02ooooo`T0/`1<00?o000009T0IP2I06H06P2I06H00ol00000O`1o07l0O`0J07l0O`03o`00001V
09T0IP2I01d0IP2I00<0000004`0/`1<0;<08P1<0;<00ol00000<`3<03<0c00^03<0c003o`00000I
0>H06@3V05006@3V00?o00000000o`000?l01@000?l5ooooo`4000000Oooool0000300000?oooooo
oooo00;ooooo202c04`00ol00000V@1V09T0IP0J09T0IP03o`00001o07l0O`1o01X0O`1o00?o0000
06H0V@1V09T07@1V09T00`000000C02c04`0/`0R04`0/`03o`00000c0<`0<`3<02h0<`3<00?o0000
01T0iP0I0>H0D00I0>H00ol00000003o0000o`060000o`Gooooo0@000001ooooo`0000<00000oooo
ooooool00_ooool70;<0C003o`00002I06H0V@1V01X0V@1V00?o000007l0O`1o07l06P1o07l00ol0
0000IP2I06H0V@0M06H0V@030000001<0;<0C02c0280C02c00?o000003<0c00c0<`0;P0c0<`00ol0
00006@3V01T0iP1@01T0iP03o`0000000?l0003o00L0003o1Oooool10000007ooooo00000`00003o
ooooooooo`02ooooo`H0/`1<00?o000009T0IP2I06H06P2I06H00ol00000O`1o07l0O`0J07l0O`03
o`00001V09T0IP2I01d0IP2I00<0000004`0/`1<0;<08P1<0;<00ol00000<`3<03<0c00^03<0c003
o`00000I0>H06@3V05006@3V00?o00000000o`000?l020000?l5ooooo`4000000Oooool000030000
0?oooooooooo00;ooooo1@2c04`00ol00000V@1V09T0IP0J09T0IP03o`00001o07l0O`1o01/0O`1o
00?o000006H0V@1V09T0701V09T00`000000C02c04`0/`0S04`0/`03o`00000c0<`0<`3<02d0<`3<
00?o000001T0iP0I0>H0D00I0>H00ol00000003o0000o`090000o`Gooooo0@000001ooooo`0000<0
0000ooooooooool00_ooool40;<0C003o`00002I06H0V@1V01X0V@1V00?o000007l0O`1o07l06`1o
07l00ol00000IP2I06H0V@0L06H0V@030000001<0;<0C02c02<0C02c00?o000003<0c00c0<`0;@0c
0<`00ol000006@3V01T0iP1@01T0iP03o`0000000?l0003o00X0003o1Oooool10000007ooooo0000
0`00003oooooooooo`02ooooo`<0/`1<00?o000009T0IP2I06H06P2I06H00ol00000O`1o07l0O`0K
07l0O`03o`00001V09T0IP2I01`0IP2I00<0000004`0/`1<0;<08`1<0;<00ol00000<`3<03<0c00]
03<0c003o`00000I0>H06@3V05006@3V00?o00000000o`000?l02`000?l5ooooo`4000000Oooool0
000300000?oooooooooo00;ooooo0P2c04`00ol00000V@1V09T0IP0J09T0IP03o`00001o07l0O`1o
01/0O`1o00?o000006H0V@1V09T0701V09T00`000000C02c04`0/`0S04`0/`03o`00000c0<`0<`3<
02d0<`3<00?o000001T0iP0I0>H0D00I0>H00ol00000003o0000o`0<0000o`Gooooo0@000001oooo
o`0000<00000ooooooooool00_ooool00`2c04co000009T0IP0K09T0IP03o`00001o07l0O`1o01/0
O`1o00?o000006H0V@1V09T0701V09T00`000000C02c04`0/`0S04`0/`03o`00000c0<`0<`3<02d0
<`3<00?o000001T0iP0I0>H0D00I0>H00ol00000003o0000o`0=0000o`Gooooo0@000001ooooo`00
00<00000ooooooooool00_ooool00ol00000V@1V09T0IP0J09T0IP03o`00001o07l0O`1o01/0O`1o
00?o000006H0V@1V09T0701V09T00`000000C02c04`0/`0S04`0/`03o`00000c0<`0<`3<02d0<`3<
00?o000001T0iP0I0>H0D00I0>H00ol00000003o0000o`0>0000o`Gooooo0@000001ooooo`0000<0
0000ooooooooool00_oooolL09T0IP03o`00001o07l0O`1o01X0O`1o0_l0000N06H0V@030000001<
0;<0C02c0280C02c0_l0000_03<0c003o`00000I0>H06@3V05006@3V00?o00000000o`000?l03`00
0?l5ooooo`4000000Oooool0000300000?oooooooooo00;ooooo6`2I06H00ol00000O`1o07l0O`0J
07l0O`03o`00001V09T0IP2I01d0IP2I00<0000004`0/`1<0;<08P1<0;<00ol00000<`3<03<0c00^
03<0c003o`00000I0>H06@3V05006@3V00?o00000000o`000?l040000?l5ooooo`4000000Oooool0
000300000?oooooooooo00;ooooo6P2I06H00ol00000O`1o07l0O`0J07l0O`03o`00001V09T0IP2I
01d0IP2I00<0000004`0/`1<0;<08P1<0;<00ol00000<`3<03<0c00^03<0c003o`00000I0>H06@3V
05006@3V00?o00000000o`000?l04@000?l5ooooo`4000000Oooool0000300000?oooooooooo00;o
oooo6@2I06H00ol00000O`1o07l0O`0J07l0O`03o`00001V09T0IP2I01d0IP2I00<0000004`0/`1<
0;<08P1<0;<00ol00000<`3<03<0c00^03<0c003o`00000I0>H06@3V05006@3V00?o00000000o`00
0?l04P000?l5ooooo`4000000Oooool0000300000?oooooooooo00;ooooo602I06H00ol00000O`1o
07l0O`0J07l0O`03o`00001V09T0IP2I01d0IP2I00<0000004`0/`1<0;<08P1<0;<00ol00000<`3<
03<0c00^03<0c003o`00000I0>H06@3V05006@3V00?o00000000o`000?l04`000?l5ooooo`400000
0Oooool0000300000?oooooooooo00;ooooo5`2I06H00ol00000O`1o07l0O`0K07l0O`03o`00001V
09T0IP2I01d0IP2I00<0000004`0/`1<0;<08P1<0;<00ol00000<`3<03<0c00^03<0c003o`00000I
0>H06@3V05006@3V00?o00000000o`000?l04`000?l5ooooo`4000000Oooool0000300000?oooooo
oooo00;ooooo5`2I06H00ol00000O`1o07l0O`0J07l0O`03o`00001V09T0IP2I01d0IP2I00<00000
04`0/`1<0;<08P1<0;<00ol00000<`3<03<0c00^03<0c003o`00000I0>H06@3V05006@3V00?o0000
0000o`000?l050000?l5ooooo`4000000Oooool0000300000?oooooooooo00;ooooo5P2I06H00ol0
0000O`1o07l0O`0J07l0O`03o`00001V09T0IP2I01d0IP2I00<0000004`0/`1<0;<08P1<0;<00ol0
0000<`3<03<0c00^03<0c003o`00000I0>H06@3V05006@3V00?o00000000o`000?l05@000?l5oooo
o`4000000Oooool0000300000?oooooooooo00;ooooo5@2I06H00ol00000O`1o07l0O`0J07l0O`03
o`00001V09T0IP2I01d0IP2I00<0000004`0/`1<0;<08P1<0;<00ol00000<`3<03<0c00^03<0c003
o`00000I0>H06@3V05006@3V00?o00000000o`000?l05P000?l5ooooo`4000000Oooool000030000
0?oooooooooo00;ooooo502I06H00ol00000O`1o07l0O`0J07l0O`03o`00001V09T0IP2I01d0IP2I
00<0000004`0/`1<0;<08P1<0;<00ol00000<`3<03<0c00^03<0c003o`00000I0>H06@3V05006@3V
00?o00000000o`000?l05`000?l5ooooo`4000000Oooool0000300000?oooooooooo00;ooooo4`2I
06H00ol00000O`1o07l0O`0J07l0O`03o`00001V09T0IP2I01d0IP2I00<0000004`0/`1<0;<08P1<
0;<00ol00000<`3<03<0c00^03<0c003o`00000I0>H06@3V05006@3V00?o00000000o`000?l06000
0?l5ooooo`4000000Oooool0000300000?oooooooooo00;ooooo4P2I06H00ol00000O`1o07l0O`0J
07l0O`03o`00001V09T0IP2I01d0IP2I00<0000004`0/`1<0;<08P1<0;<00ol00000<`3<03<0c00^
03<0c003o`00000I0>H06@3V05006@3V00?o00000000o`000?l06@000?l5ooooo`4000000Oooool0
000300000?oooooooooo00;ooooo4@2I06H00ol00000O`1o07l0O`0J07l0O`03o`00001V09T0IP2I
01d0IP2I00<0000004`0/`1<0;<08P1<0;<00ol00000<`3<03<0c00^03<0c003o`00000I0>H06@3V
05006@3V00?o00000000o`000?l06P000?l5ooooo`4000000Oooool0000300000?oooooooooo00;o
oooo402I06H00ol00000O`1o07l0O`0J07l0O`03o`00001V09T0IP2I01d0IP2I00<0000004`0/`1<
0;<08P1<0;<00ol00000<`3<03<0c00^03<0c003o`00000I0>H06@3V05006@3V00?o00000000o`00
0?l06`000?l5ooooo`4000000Oooool0000300000?oooooooooo00;ooooo3`2I06H00ol00000O`1o
07l0O`0J07l0O`03o`00001V09T0IP2I01d0IP2I00<0000004`0/`1<0;<08P1<0;<00ol00000<`3<
03<0c00^03<0c003o`00000I0>H06@3V05006@3V00?o00000000o`000?l070000?l5ooooo`400000
0Oooool0000300000?oooooooooo00;ooooo3P2I06H00ol00000O`1o07l0O`0J07l0O`03o`00001V
09T0IP2I01d0IP2I00<0000004`0/`1<0;<08P1<0;<00ol00000<`3<03<0c00^03<0c003o`00000I
0>H06@3V05006@3V00?o00000000o`000?l07@000?l5ooooo`4000000Oooool0000300000?oooooo
oooo00;ooooo3@2I06H00ol00000O`1o07l0O`0J07l0O`03o`00001V09T0IP2I01d0IP2I00<00000
04`0/`1<0;<08P1<0;<00ol00000<`3<03<0c00^03<0c003o`00000I0>H06@3V05006@3V00?o0000
0000o`000?l07P000?l5ooooo`4000000Oooool0000300000?oooooooooo00;ooooo302I06H00ol0
0000O`1o07l0O`0K07l0O`03o`00001V09T0IP2I01`0IP2I00<0000004`0/`1<0;<08`1<0;<00ol0
0000<`3<03<0c00]03<0c003o`00000I0>H06@3V05006@3V00?o00000000o`000?l07`000?l5oooo
o`4000000Oooool0000300000?oooooooooo00;ooooo2`2I06H00ol00000O`1o07l0O`0K07l0O`03
o`00001V09T0IP2I01`0IP2I00<0000004`0/`1<0;<08`1<0;<00ol00000<`3<03<0c00]03<0c003
o`00000I0>H06@3V05006@3V00?o00000000o`000?l080000?l5ooooo`4000000Oooool000030000
0?oooooooooo00;ooooo2P2I06H00ol00000O`1o07l0O`0K07l0O`03o`00001V09T0IP2I01`0IP2I
00<0000004`0/`1<0;<08`1<0;<00ol00000<`3<03<0c00]03<0c003o`00000I0>H06@3V05006@3V
00?o00000000o`000?l08@000?l5ooooo`4000000Oooool0000300000?oooooooooo00;ooooo2@2I
06H00ol00000O`1o07l0O`0K07l0O`03o`00001V09T0IP2I01`0IP2I00<0000004`0/`1<0;<08`1<
0;<00ol00000<`3<03<0c00]03<0c003o`00000I0>H06@3V05006@3V00?o00000000o`000?l08P00
0?l5ooooo`4000000Oooool0000300000?oooooooooo00;ooooo202I06H00ol00000O`1o07l0O`0K
07l0O`03o`00001V09T0IP2I01`0IP2I00<0000004`0/`1<0;<08`1<0;<00ol00000<`3<03<0c00]
03<0c003o`00000I0>H06@3V05006@3V00?o00000000o`000?l08`000?l5ooooo`4000000Oooool0
000300000?oooooooooo00;ooooo1`2I06H00ol00000O`1o07l0O`0K07l0O`03o`00001V09T0IP2I
01`0IP2I00<0000004`0/`1<0;<08`1<0;<00ol00000<`3<03<0c00]03<0c003o`00000I0>H06@3V
05006@3V00?o00000000o`000?l090000?l5ooooo`4000000Oooool0000300000?oooooooooo00;o
oooo1P2I06H00ol00000O`1o07l0O`0K07l0O`03o`00001V09T0IP2I01`0IP2I00<0000004`0/`1<
0;<08`1<0;<00ol00000<`3<03<0c00]03<0c003o`00000I0>H06@3V05006@3V00?o00000000o`00
0?l09@000?l5ooooo`4000000Oooool0000300000?oooooooooo00;ooooo1@2I06H00ol00000O`1o
07l0O`0J07l0O`;o00007P1V09T00`000000C02c04`0/`0R04`0/`;o0000;`0c0<`00ol000006@3V
01T0iP1@01T0iP03o`0000000?l0003o02H0003o1Oooool10000007ooooo00000`00003ooooooooo
o`02ooooo`@0V@1V00?o000007l0O`1o07l06P1o07l00ol00000IP2I06H0V@0M06H0V@030000001<
0;<0C02c0280C02c00?o000003<0c00c0<`0;P0c0<`00ol000006@3V01T0iP1@01T0iP03o`000000
0?l0003o02L0003o1Oooool10000007ooooo00000`00003oooooooooo`02ooooo`<0V@1V00?o0000
07l0O`1o07l06P1o07l00ol00000IP2I06H0V@0M06H0V@030000001<0;<0C02c0280C02c00?o0000
03<0c00c0<`0;P0c0<`00ol000006@3V01T0iP1@01T0iP03o`0000000?l0003o02P0003o1Oooool1
0000007ooooo00000`00003oooooooooo`02ooooo`80V@1V00?o000007l0O`1o07l06P1o07l00ol0
0000IP2I06H0V@0M06H0V@030000001<0;<0C02c0280C02c00?o000003<0c00c0<`0;P0c0<`00ol0
00006@3V01T0iP1@01T0iP03o`0000000?l0003o02T0003o1Oooool10000007ooooo00000`00003o
ooooooooo`02ooooo`0309T0I_l00000O`1o01`0O`1o00?o000006H0V@1V09T07@1V09T00`000000
C02c04`0/`0R04`0/`03o`00000c0<`0<`3<02d0<`3<00?o000001T0iP0I0>H0D@0I0>H00ol00000
003o0000o`0Y0000o`Gooooo0@000001ooooo`0000<00000ooooooooool00_ooool00ol00000O`1o
07l0O`0K07l0O`03o`00001V09T0IP2I01d0IP2I00<0000004`0/`1<0;<08P1<0;<00ol00000<`3<
03<0c00]03<0c003o`00000I0>H06@3V05406@3V00?o00000000o`000?l0:P000?l5ooooo`400000
0Oooool0000300000?oooooooooo00;ooooo7@1o07l00ol00000IP2I06H0V@0M06H0V@030000001<
0;<0C02c0280C02c00?o000003<0c00c0<`0;@0c0<`00ol000006@3V01T0iP1A01T0iP03o`000000
0?l0003o02/0003o1Oooool10000007ooooo00000`00003oooooooooo`02oooooa`0O`1o00?o0000
06H0V@1V09T07@1V09T00`000000C02c04`0/`0R04`0/`03o`00000c0<`0<`3<02d0<`3<00?o0000
01T0iP0I0>H0D@0I0>H00ol00000003o0000o`0/0000o`Gooooo0@000001ooooo`0000<00000oooo
ooooool00_oooolK07l0O`03o`00001V09T0IP2I01d0IP2I00<0000004`0/`1<0;<08P1<0;<00ol0
0000<`3<03<0c00]03<0c003o`00000I0>H06@3V05406@3V00?o00000000o`000?l0;@000?l5oooo
o`4000000Oooool0000300000?oooooooooo00;ooooo6P1o07l00ol00000IP2I06H0V@0M06H0V@03
0000001<0;<0C02c0280C02c00?o000003<0c00c0<`0;@0c0<`00ol000006@3V01T0iP1A01T0iP03
o`0000000?l0003o02h0003o1Oooool10000007ooooo00000`00003oooooooooo`02oooooaT0O`1o
00?o000006H0V@1V09T07@1V09T00`000000C02c04`0/`0R04`0/`03o`00000c0<`0<`3<02d0<`3<
00?o000001T0iP0I0>H0D@0I0>H00ol00000003o0000o`0_0000o`Gooooo0@000001ooooo`0000<0
0000ooooooooool00_oooolH07l0O`03o`00001V09T0IP2I01d0IP2I00<0000004`0/`1<0;<08P1<
0;<00ol00000<`3<03<0c00]03<0c003o`00000I0>H06@3V05406@3V00?o00000000o`000?l0<000
0?l5ooooo`4000000Oooool0000300000?oooooooooo00;ooooo5`1o07l00ol00000IP2I06H0V@0M
06H0V@030000001<0;<0C02c0280C02c00?o000003<0c00c0<`0;@0c0<`00ol000006@3V01T0iP1A
01T0iP03o`0000000?l0003o0340003o1Oooool10000007ooooo00000`00003oooooooooo`02oooo
oaH0O`1o00?o000006H0V@1V09T07@1V09T00`000000C02c04`0/`0R04`0/`03o`00000c0<`0<`3<
02d0<`3<00?o000001T0iP0I0>H0D@0I0>H00ol00000003o0000o`0b0000o`Gooooo0@000001oooo
o`0000<00000ooooooooool00_oooolE07l0O`03o`00001V09T0IP2I01d0IP2I00<0000004`0/`1<
0;<08P1<0;<00ol00000<`3<03<0c00]03<0c003o`00000I0>H06@3V05406@3V00?o00000000o`00
0?l0<`000?l5ooooo`4000000Oooool0000300000?oooooooooo00;ooooo501o07l00ol00000IP2I
06H0V@0M06H0V@030000001<0;<0C02c0280C02c00?o000003<0c00c0<`0;P0c0<`00ol000006@3V
01T0iP1?01T0iP;o0000=P000?l5ooooo`4000000Oooool0000300000?oooooooooo00;ooooo4`1o
07l00ol00000IP2I06H0V@0M06H0V@030000001<0;<0C02c0280C02c00?o000003<0c00c0<`0;P0c
0<`00ol000006@3V01T0iP1?01T0iP03o`0000000?l0003o03H0003o1Oooool10000007ooooo0000
0`00003oooooooooo`02oooooa80O`1o00?o000006H0V@1V09T07@1V09T00`000000C02c04`0/`0R
04`0/`03o`00000c0<`0<`3<02h0<`3<00?o000001T0iP0I0>H0C`0I0>H00ol00000003o0000o`0g
0000o`Gooooo0@000001ooooo`0000<00000ooooooooool00_oooolA07l0O`03o`00001V09T0IP2I
01d0IP2I00<0000004`0/`1<0;<08P1<0;<00ol00000<`3<03<0c00^03<0c003o`00000I0>H06@3V
05006@3V00?o00000000o`000?l0=`000?l5ooooo`4000000Oooool0000300000?oooooooooo00;o
oooo401o07l00ol00000IP2I06H0V@0M06H0V@030000001<0;<0C02c0280C02c00?o000003<0c00c
0<`0;P0c0<`00ol000006@3V01T0iP1@01T0iP03o`0000000?l0003o03P0003o1Oooool10000007o
oooo00000`00003oooooooooo`02ooooo`l0O`1o00?o000006H0V@1V09T07@1V09T00`000000C02c
04`0/`0R04`0/`03o`00000c0<`0<`3<02h0<`3<00?o000001T0iP0I0>H0D00I0>H00ol00000003o
0000o`0i0000o`Gooooo0@000001ooooo`0000<00000ooooooooool00_ooool>07l0O`03o`00001V
09T0IP2I01d0IP2I00<0000004`0/`1<0;<08P1<0;<00ol00000<`3<03<0c00^03<0c003o`00000I
0>H06@3V05006@3V00?o00000000o`000?l0>P000?l5ooooo`4000000Oooool0000300000?oooooo
oooo00;ooooo3@1o07l00ol00000IP2I06H0V@0M06H0V@030000001<0;<0C02c0280C02c00?o0000
03<0c00c0<`0;P0c0<`00ol000006@3V01T0iP1@01T0iP03o`0000000?l0003o03/0003o1Oooool1
0000007ooooo00000`00003oooooooooo`02ooooo``0O`1o00?o000006H0V@1V09T07@1V09T00`00
0000C02c04`0/`0R04`0/`03o`00000c0<`0<`3<02h0<`3<00?o000001T0iP0I0>H0D00I0>H00ol0
0000003o0000o`0l0000o`Gooooo0@000001ooooo`0000<00000ooooooooool00_ooool;07l0O`03
o`00001V09T0IP2I01d0IP2I00<0000004`0/`1<0;<08P1<0;<00ol00000<`3<03<0c00^03<0c003
o`00000I0>H06@3V05006@3V00?o00000000o`000?l0?@000?l5ooooo`4000000Oooool000030000
0?oooooooooo00;ooooo2P1o07l00ol00000IP2I06H0V@0M06H0V@030000001<0;<0C02c0280C02c
00?o000003<0c00c0<`0;P0c0<`00ol000006@3V01T0iP1@01T0iP03o`0000000?l0003o03h0003o
1Oooool10000007ooooo00000`00003oooooooooo`02ooooo`T0O`1o00?o000006H0V@1V09T07@1V
09T00`000000C02c04`0/`0R04`0/`03o`00000c0<`0<`3<02d0<`3<0_l0001B01T0iP03o`000000
0?l0003o03l0003o1Oooool10000007ooooo00000`00003oooooooooo`02ooooo`P0O`1o00?o0000
06H0V@1V09T07P1V09T00`000000C02c04`0/`0Q04`0/`03o`00000c0<`0<`3<02h0<`3<00?o0000
01T0iP0I0>H0D00I0>H00ol00000003o0000o`100000o`Gooooo0@000001ooooo`0000<00000oooo
ooooool00_ooool707l0O`03o`00001V09T0IP2I01h0IP2I00<0000004`0/`1<0;<08@1<0;<00ol0
0000<`3<03<0c00^03<0c003o`00000I0>H06@3V05006@3V00?o00000000o`000?l0@@000?l5oooo
o`4000000Oooool0000300000?oooooooooo00;ooooo1P1o07l00ol00000IP2I06H0V@0N06H0V@03
0000001<0;<0C02c0240C02c00?o000003<0c00c0<`0;P0c0<`00ol000006@3V01T0iP1@01T0iP03
o`0000000?l0003o0480003o1Oooool10000007ooooo00000`00003oooooooooo`02ooooo`D0O`1o
00?o000006H0V@1V09T07P1V09T00`000000C02c04`0/`0Q04`0/`03o`00000c0<`0<`3<02h0<`3<
00?o000001T0iP0I0>H0D00I0>H00ol00000003o0000o`130000o`Gooooo0@000001ooooo`0000<0
0000ooooooooool00_ooool407l0O`03o`00001V09T0IP2I01h0IP2I00<0000004`0/`1<0;<08@1<
0;<00ol00000<`3<03<0c00^03<0c003o`00000I0>H06@3V05006@3V00?o00000000o`000?l0A000
0?l5ooooo`4000000Oooool0000300000?oooooooooo00;ooooo0`1o07l00ol00000IP2I06H0V@0N
06H0V@030000001<0;<0C02c0240C02c00?o000003<0c00c0<`0;P0c0<`00ol000006@3V01T0iP1@
01T0iP03o`0000000?l0003o04D0003o1Oooool10000007ooooo00000`00003oooooooooo`02oooo
o`80O`1o00?o000006H0V@1V09T07@1V09T2000002<0C02c00?o000003<0c00c0<`0;P0c0<`00ol0
00006@3V01T0iP1@01T0iP03o`0000000?l0003o04H0003o1Oooool10000007ooooo00000`00003o
ooooooooo`02ooooo`0307l0Ool00000IP2I01h0IP2I00<0000004`0/`1<0;<08P1<0;<00ol00000
<`3<03<0c00^03<0c003o`00000I0>H06@3V05006@3V00?o00000000o`000?l0A`000?l5ooooo`40
00000Oooool0000300000?oooooooooo00;ooooo00?o000006H0V@1V09T07@1V09T00`000000C02c
04`0/`0R04`0/`03o`00000c0<`0<`3<02h0<`3<00?o000001T0iP0I0>H0D00I0>H00ol00000003o
0000o`180000o`Gooooo0@000001ooooo`0000<00000ooooooooool00_oooolO06H0V@030000001<
0;<0C02c02<0C02c00?o000003<0c00c0<`0;@0c0<`00ol000006@3V01T0iP1@01T0iP03o`000000
0?l0003o04T0003o1Oooool10000007ooooo00000`00003oooooooooo`02oooooah0IP2I00<00000
04`0/`1<0;<08`1<0;<00ol00000<`3<03<0c00]03<0c003o`00000I0>H06@3V05006@3V00?o0000
0000o`000?l0BP000?l5ooooo`4000000Oooool0000300000?oooooooooo00;ooooo7@1V09T00`00
0000C02c04`0/`0S04`0/`03o`00000c0<`0<`3<02d0<`3<00?o000001T0iP0I0>H0D00I0>H00ol0
0000003o0000o`1;0000o`Gooooo0@000001ooooo`0000<00000ooooooooool00_oooolL06H0V@03
0000001<0;<0C02c02<0C02c00?o000003<0c00c0<`0;@0c0<`00ol000006@3V01T0iP1@01T0iP03
o`0000000?l0003o04`0003o1Oooool10000007ooooo00000`00003oooooooooo`02oooooa/0IP2I
00<0000004`0/`1<0;<08`1<0;<00ol00000<`3<03<0c00]03<0c003o`00000I0>H06@3V05006@3V
00?o00000000o`000?l0C@000?l5ooooo`4000000Oooool0000300000?oooooooooo00;ooooo6P1V
09T00`000000C02c04`0/`0S04`0/`03o`00000c0<`0<`3<02d0<`3<00?o000001T0iP0I0>H0D00I
0>H00ol00000003o0000o`1>0000o`Gooooo0@000001ooooo`0000<00000ooooooooool00_oooolI
06H0V@030000001<0;<0C02c02<0C02c00?o000003<0c00c0<`0;@0c0<`00ol000006@3V01T0iP1@
01T0iP03o`0000000?l0003o04l0003o1Oooool10000007ooooo00000`00003oooooooooo`02oooo
oaP0IP2I00<0000004`0/`1<0;<08`1<0;<00ol00000<`3<03<0c00]03<0c003o`00000I0>H06@3V
05006@3V00?o00000000o`000?l0D0000?l5ooooo`4000000Oooool0000300000?oooooooooo00;o
oooo5`1V09T00`000000C02c04`0/`0S04`0/`03o`00000c0<`0<`3<02d0<`3<00?o000001T0iP0I
0>H0D00I0>H00ol00000003o0000o`1A0000o`Gooooo0@000001ooooo`0000<00000ooooooooool0
0_oooolF06H0V@030000001<0;<0C02c02<0C02c00?o000003<0c00c0<`0;@0c0<`00ol000006@3V
01T0iP1@01T0iP03o`0000000?l0003o0580003o1Oooool10000007ooooo00000`00003ooooooooo
o`02oooooaD0IP2I00<0000004`0/`1<0;<08`1<0;<00ol00000<`3<03<0c00]03<0c003o`00000I
0>H06@3V05006@3V00?o00000000o`000?l0D`000?l5ooooo`4000000Oooool0000300000?oooooo
oooo00;ooooo501V09T00`000000C02c04`0/`0R04`0/`;o0000;`0c0<`00ol000006@3V01T0iP1@
01T0iP03o`0000000?l0003o05@0003o1Oooool10000007ooooo00000`00003oooooooooo`02oooo
oa<0IP2I00<0000004`0/`1<0;<08P1<0;<00ol00000<`3<03<0c00^03<0c003o`00000I0>H06@3V
05006@3V00?o00000000o`000?l0E@000?l5ooooo`4000000Oooool0000300000?oooooooooo00;o
oooo4P1V09T00`000000C02c04`0/`0R04`0/`03o`00000c0<`0<`3<02h0<`3<00?o000001T0iP0I
0>H0D00I0>H00ol00000003o0000o`1F0000o`Gooooo0@000001ooooo`0000<00000ooooooooool0
0_oooolB06H0V@030000001<0;<0C02c0280C02c00?o000003<0c00c0<`0;P0c0<`00ol000006@3V
01T0iP1@01T0iP03o`0000000?l0003o05H0003o1Oooool10000007ooooo00000`00003ooooooooo
o`02oooooa40IP2I00<0000004`0/`1<0;<08P1<0;<00ol00000<`3<03<0c00^03<0c003o`00000I
0>H06@3V05006@3V00?o00000000o`000?l0E`000?l5ooooo`4000000Oooool0000300000?oooooo
oooo00;ooooo401V09T00`000000C02c04`0/`0R04`0/`03o`00000c0<`0<`3<02h0<`3<00?o0000
01T0iP0I0>H0D00I0>H00ol00000003o0000o`1H0000o`Gooooo0@000001ooooo`0000<00000oooo
ooooool00_ooool?06H0V@030000001<0;<0C02c0280C02c00?o000003<0c00c0<`0;P0c0<`00ol0
00006@3V01T0iP1@01T0iP03o`0000000?l0003o05T0003o1Oooool10000007ooooo00000`00003o
ooooooooo`02ooooo`h0IP2I00<0000004`0/`1<0;<08P1<0;<00ol00000<`3<03<0c00^03<0c003
o`00000I0>H06@3V05006@3V00?o00000000o`000?l0FP000?l5ooooo`4000000Oooool000030000
0?oooooooooo00;ooooo3@1V09T00`000000C02c04`0/`0R04`0/`03o`00000c0<`0<`3<02h0<`3<
00?o000001T0iP0I0>H0D00I0>H00ol00000003o0000o`1K0000o`Gooooo0@000001ooooo`0000<0
0000ooooooooool00_ooool<06H0V@030000001<0;<0C02c0280C02c00?o000003<0c00c0<`0;P0c
0<`00ol000006@3V01T0iP1@01T0iP03o`0000000?l0003o05`0003o1Oooool10000007ooooo0000
0`00003oooooooooo`02ooooo`/0IP2I00<0000004`0/`1<0;<08P1<0;<00ol00000<`3<03<0c00^
03<0c003o`00000I0>H06@3V05006@3V00?o00000000o`000?l0G@000?l5ooooo`4000000Oooool0
000300000?oooooooooo00;ooooo2P1V09T00`000000C02c04`0/`0R04`0/`03o`00000c0<`0<`3<
02h0<`3<00?o000001T0iP0I0>H0D00I0>H00ol00000003o0000o`1N0000o`Gooooo0@000001oooo
o`0000<00000ooooooooool00_ooool906H0V@030000001<0;<0C02c0280C02c00?o000003<0c00c
0<`0;P0c0<`00ol000006@3V01T0iP1@01T0iP03o`0000000?l0003o05l0003o1Oooool10000007o
oooo00000`00003oooooooooo`02ooooo`P0IP2I00<0000004`0/`1<0;<08P1<0;<00ol00000<`3<
03<0c00^03<0c003o`00000I0>H06@3V05006@3V00?o00000000o`000?l0H0000?l5ooooo`400000
0Oooool0000300000?oooooooooo00;ooooo1`1V09T00`000000C02c04`0/`0R04`0/`03o`00000c
0<`0<`3<02h0<`3<00?o000001T0iP0I0>H0D00I0>H00ol00000003o0000o`1Q0000o`Gooooo0@00
0001ooooo`0000<00000ooooooooool00_ooool606H0V@030000001<0;<0C02c02<0C02c00?o0000
03<0c00c0<`0;@0c0<`00ol000006@3V01T0iP1@01T0iP03o`0000000?l0003o0680003o1Oooool1
0000007ooooo00000`00003oooooooooo`02ooooo`D0IP2I00<0000004`0/`1<0;<08`1<0;<00ol0
0000<`3<03<0c00]03<0c003o`00000I0>H06@3V05006@3V00?o00000000o`000?l0H`000?l5oooo
o`4000000Oooool0000300000?oooooooooo00;ooooo101V09T00`000000C02c04`0/`0S04`0/`03
o`00000c0<`0<`3<02d0<`3<00?o000001T0iP0I0>H0D00I0>H00ol00000003o0000o`1T0000o`Go
oooo0@000001ooooo`0000<00000ooooooooool00_ooool306H0V@030000001<0;<0C02c02<0C02c
00?o000003<0c00c0<`0;@0c0<`00ol000006@3V01T0iP1@01T0iP03o`0000000?l0003o06D0003o
1Oooool10000007ooooo00000`00003oooooooooo`02ooooo`80IP2I00<0000004`0/`1<0;<08`1<
0;<00ol00000<`3<03<0c00]03<0c003o`00000I0>H06@3V05006@3V00?o00000000o`000?l0IP00
0?l5ooooo`4000000Oooool0000300000?oooooooooo00;ooooo00<0IP2I0000001<0;<0901<0;<0
0ol00000<`3<03<0c00]03<0c003o`00000I0>H06@3V05006@3V00?o00000000o`000?l0I`000?l5
ooooo`4000000Oooool0000300000?oooooooooo00;ooooo00<0000004`0/`1<0;<08`1<0;<00ol0
0000<`3<03<0c00]03<0c003o`00000I0>H06@3V05006@3V00?o00000000o`000?l0J0000?l5oooo
o`4000000Oooool0000300000?oooooooooo00;ooooo9@1<0;<00ol00000<`3<03<0c00]03<0c003
o`00000I0>H06@3V05006@3V00?o00000000o`000?l0J@000?l5ooooo`4000000Oooool000030000
0?oooooooooo00;ooooo901<0;<00ol00000<`3<03<0c00]03<0c003o`00000I0>H06@3V05006@3V
00?o00000000o`000?l0JP000?l5ooooo`4000000Oooool0000300000?oooooooooo00;ooooo8P1<
0;<2o`0002l0<`3<00?o000001T0iP0I0>H0D00I0>H00ol00000003o0000o`1[0000o`Gooooo0@00
0001ooooo`0000<00000ooooooooool00_oooolQ04`0/`03o`00000c0<`0<`3<02h0<`3<00?o0000
01T0iP0I0>H0D00I0>H00ol00000003o0000o`1/0000o`Gooooo0@000001ooooo`0000<00000oooo
ooooool00_oooolQ04`0/`03o`00000c0<`0<`3<02h0<`3<00?o000001T0iP0I0>H0D00I0>H00ol0
0000003o0000o`1/0000o`Gooooo0@000001ooooo`0000<00000ooooooooool00_oooolP04`0/`03
o`00000c0<`0<`3<02h0<`3<00?o000001T0iP0I0>H0D00I0>H00ol00000003o0000o`1]0000o`Go
oooo0@000001ooooo`0000<00000ooooooooool00_oooolO04`0/`03o`00000c0<`0<`3<02h0<`3<
00?o000001T0iP0I0>H0D00I0>H00ol00000003o0000o`1^0000o`Gooooo0@000001ooooo`0000<0
0000ooooooooool00_oooolN04`0/`03o`00000c0<`0<`3<02h0<`3<00?o000001T0iP0I0>H0D00I
0>H00ol00000003o0000o`1_0000o`Gooooo0@000001ooooo`0000<00000ooooooooool00_oooolM
04`0/`03o`00000c0<`0<`3<02h0<`3<00?o000001T0iP0I0>H0D00I0>H00ol00000003o0000o`1`
0000o`Gooooo0@000001ooooo`0000<00000ooooooooool00_oooolL04`0/`03o`00000c0<`0<`3<
02h0<`3<00?o000001T0iP0I0>H0D00I0>H00ol00000003o0000o`1a0000o`Gooooo0@000001oooo
o`0000<00000ooooooooool00_oooolK04`0/`03o`00000c0<`0<`3<02h0<`3<00?o000001T0iP0I
0>H0D00I0>H00ol00000003o0000o`1b0000o`Gooooo0@000001ooooo`0000<00000ooooooooool0
0_oooolJ04`0/`03o`00000c0<`0<`3<02h0<`3<00?o000001T0iP0I0>H0D00I0>H00ol00000003o
0000o`1c0000o`Gooooo0@000001ooooo`0000<00000ooooooooool00_oooolI04`0/`03o`00000c
0<`0<`3<02h0<`3<00?o000001T0iP0I0>H0D00I0>H00ol00000003o0000o`1d0000o`Gooooo0@00
0001ooooo`0000<00000ooooooooool00_oooolH04`0/`03o`00000c0<`0<`3<02h0<`3<00?o0000
01T0iP0I0>H0D00I0>H00ol00000003o0000o`1e0000o`Gooooo0@000001ooooo`0000<00000oooo
ooooool00_oooolG04`0/`03o`00000c0<`0<`3<02h0<`3<00?o000001T0iP0I0>H0D00I0>H00ol0
0000003o0000o`1f0000o`Gooooo0@000001ooooo`0000<00000ooooooooool00_oooolF04`0/`03
o`00000c0<`0<`3<02h0<`3<00?o000001T0iP0I0>H0C`0I0>H2o`0007T0003o1Oooool10000007o
oooo00000`00003oooooooooo`02oooooaH0C02c00?o000003<0c00c0<`0;@0c0<`00ol000006@3V
01T0iP1?01T0iP03o`0000000?l0003o07T0003o1Oooool10000007ooooo00000`00003ooooooooo
o`02oooooaD0C02c00?o000003<0c00c0<`0;@0c0<`00ol000006@3V01T0iP1?01T0iP03o`000000
0?l0003o07X0003o1Oooool10000007ooooo00000`00003oooooooooo`02oooooa@0C02c00?o0000
03<0c00c0<`0;@0c0<`00ol000006@3V01T0iP1?01T0iP03o`0000000?l0003o07/0003o1Oooool1
0000007ooooo00000`00003oooooooooo`02oooooa<0C02c00?o000003<0c00c0<`0;@0c0<`00ol0
00006@3V01T0iP1?01T0iP03o`0000000?l0003o07`0003o1Oooool10000007ooooo00000`00003o
ooooooooo`02oooooa80C02c00?o000003<0c00c0<`0;@0c0<`00ol000006@3V01T0iP1@01T0iP03
o`0000000?l0003o07`0003o1Oooool10000007ooooo00000`00003oooooooooo`02oooooa40C02c
00?o000003<0c00c0<`0;@0c0<`00ol000006@3V01T0iP1@01T0iP03o`0000000?l0003o07d0003o
1Oooool10000007ooooo00000`00003oooooooooo`02oooooa00C02c00?o000003<0c00c0<`0;@0c
0<`00ol000006@3V01T0iP1@01T0iP03o`0000000?l0003o07h0003o1Oooool10000007ooooo0000
0`00003oooooooooo`02ooooo`l0C02c00?o000003<0c00c0<`0;@0c0<`00ol000006@3V01T0iP1@
01T0iP03o`0000000?l0003o07l0003o1Oooool10000007ooooo00000`00003oooooooooo`02oooo
o`h0C02c00?o000003<0c00c0<`0;@0c0<`00ol000006@3V01T0iP1@01T0iP03o`0000000?l0003o
0800003o1Oooool10000007ooooo00000`00003oooooooooo`02ooooo`d0C02c00?o000003<0c00c
0<`0;@0c0<`00ol000006@3V01T0iP1@01T0iP03o`0000000?l0003o0840003o1Oooool10000007o
oooo00000`00003oooooooooo`02ooooo`/0C02c0_l0000_03<0c003o`00000I0>H06@3V05006@3V
00?o00000000o`000?l0PP000?l5ooooo`4000000Oooool0000300000?oooooooooo00;ooooo2P1<
0;<00ol00000<`3<03<0c00^03<0c003o`00000I0>H06@3V05006@3V00?o00000000o`000?l0P`00
0?l5ooooo`4000000Oooool0000300000?oooooooooo00;ooooo2@1<0;<00ol00000<`3<03<0c00^
03<0c003o`00000I0>H06@3V05006@3V00?o00000000o`000?l0Q0000?l5ooooo`4000000Oooool0
000300000?oooooooooo00;ooooo201<0;<00ol00000<`3<03<0c00^03<0c003o`00000I0>H06@3V
05006@3V00?o00000000o`000?l0Q@000?l5ooooo`4000000Oooool0000300000?oooooooooo00;o
oooo1`1<0;<00ol00000<`3<03<0c00^03<0c003o`00000I0>H06@3V05006@3V00?o00000000o`00
0?l0QP000?l5ooooo`4000000Oooool0000300000?oooooooooo00;ooooo1P1<0;<00ol00000<`3<
03<0c00^03<0c003o`00000I0>H06@3V05006@3V00?o00000000o`000?l0Q`000?l5ooooo`400000
0Oooool0000300000?oooooooooo00;ooooo1@1<0;<00ol00000<`3<03<0c00^03<0c003o`00000I
0>H06@3V05406@3V00?o00000000o`000?l0Q`000?l5ooooo`4000000Oooool0000300000?oooooo
oooo00;ooooo101<0;<00ol00000<`3<03<0c00^03<0c003o`00000I0>H06@3V05406@3V00?o0000
0000o`000?l0R0000?l5ooooo`4000000Oooool0000300000?oooooooooo00;ooooo0`1<0;<00ol0
0000<`3<03<0c00^03<0c003o`00000I0>H06@3V05406@3V00?o00000000o`000?l0R@000?l5oooo
o`4000000Oooool0000300000?oooooooooo00;ooooo0P1<0;<00ol00000<`3<03<0c00^03<0c003
o`00000I0>H06@3V05406@3V00?o00000000o`000?l0RP000?l5ooooo`4000000Oooool000030000
0?oooooooooo00;ooooo00<0C02co`00000c0<`0;`0c0<`00ol000006@3V01T0iP1A01T0iP03o`00
00000?l0003o08/0003o1Oooool10000007ooooo00000`00003oooooooooo`02ooooo`03o`00000c
0<`0<`3<02h0<`3<00?o000001T0iP0I0>H0D@0I0>H00ol00000003o0000o`2<0000o`Gooooo0@00
0001ooooo`0000<00000ooooooooool00_ooool`03<0c003o`00000I0>H06@3V05406@3V00?o0000
0000o`000?l0S@000?l5ooooo`4000000Oooool0000300000?oooooooooo0?oooooo7?ooool10000
007ooooo00000`00003oooooooooo`3ooooooacooooo0@000001ooooo`0000<00000ooooooooool0
oooooolLooooo`4000000Oooool0000300000?oooooooooo0?oooooo7?ooool10000007ooooo003o
0000020000000Oooool00001\
\>"],
  ImageRangeCache->{{{0, 287}, {287, 0}} -> {-1.04092, -1.04092, 0.00725378, \
0.00725378}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% ContourGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.480769 0.5 0.480769 [
[ 0 0 -0.125 0 ]
[ 0 0 -0.125 0 ]
[ 0 1 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
0 0 m
1 0 L
s
0 0 m
0 1 L
s
0 1 m
1 1 L
s
1 0 m
1 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
0 0 1 r
.01923 .98077 m
.98077 .98077 L
.98077 .01923 L
.01923 .01923 L
F
0 g
.5 Mabswid
.1 0 .9 r
.01923 .37874 m
.02045 .37981 L
.05929 .40219 L
.08224 .41987 L
.09936 .4319 L
.13942 .4574 L
.14295 .45994 L
.17949 .48053 L
.20656 .5 L
.21955 .50575 L
.25962 .53235 L
.27109 .54006 L
.29968 .5551 L
.33826 .58013 L
.33974 .58075 L
.37981 .60258 L
.40931 .62019 L
.41987 .62509 L
.45994 .64637 L
.48608 .66026 L
.5 .6664 L
.54006 .68491 L
.57629 .70032 L
.58013 .70163 L
.62019 .71501 L
.66026 .72431 L
.70032 .72563 L
.73784 .70032 L
.74038 .68667 L
.74147 .66026 L
.74038 .65131 L
.7335 .62019 L
.71932 .58013 L
.70196 .54006 L
.70032 .53628 L
.68148 .5 L
.66027 .45994 L
.66026 .45991 L
.63589 .41987 L
.62019 .39207 L
.61214 .37981 L
.58603 .33974 L
.58013 .32883 L
.55944 .29968 L
.54006 .26809 L
.53386 .25962 L
.50493 .21955 L
.5 .20996 L
.47626 .17949 L
.45994 .15281 L
.44936 .13942 L
.42214 .09936 L
.41987 .09678 L
.38845 .05929 L
.37981 .04046 L
.35977 .01923 L
.01923 .01923 L
F
0 g
.01923 .37874 m
.02045 .37981 L
.05929 .40219 L
.08224 .41987 L
.09936 .4319 L
.13942 .4574 L
.14295 .45994 L
.17949 .48053 L
.20656 .5 L
.21955 .50575 L
.25962 .53235 L
.27109 .54006 L
.29968 .5551 L
.33826 .58013 L
.33974 .58075 L
.37981 .60258 L
.40931 .62019 L
.41987 .62509 L
.45994 .64637 L
.48608 .66026 L
.5 .6664 L
.54006 .68491 L
.57629 .70032 L
.58013 .70163 L
.62019 .71501 L
.66026 .72431 L
.70032 .72563 L
.73784 .70032 L
.74038 .68667 L
.74147 .66026 L
.74038 .65131 L
.7335 .62019 L
.71932 .58013 L
.70196 .54006 L
.70032 .53628 L
.68148 .5 L
.66027 .45994 L
.66026 .45991 L
.63589 .41987 L
.62019 .39207 L
.61214 .37981 L
.58603 .33974 L
.58013 .32883 L
.55944 .29968 L
.54006 .26809 L
.53386 .25962 L
.50493 .21955 L
.5 .20996 L
.47626 .17949 L
.45994 .15281 L
Mistroke
.44936 .13942 L
.42214 .09936 L
.41987 .09678 L
.38845 .05929 L
.37981 .04046 L
.35977 .01923 L
Mfstroke
.2 0 .8 r
.01923 .34198 m
.05929 .36758 L
.07721 .37981 L
.09936 .39162 L
.13942 .41818 L
.14206 .41987 L
.17949 .44093 L
.20989 .45994 L
.21955 .46468 L
.25962 .48757 L
.28114 .5 L
.29968 .50915 L
.33974 .53039 L
.35843 .54006 L
.37981 .54971 L
.41987 .56782 L
.44931 .58013 L
.45994 .58363 L
.5 .59628 L
.54006 .6042 L
.58013 .6029 L
.61034 .58013 L
.61443 .54006 L
.60687 .5 L
.59316 .45994 L
.58013 .42703 L
.57607 .41987 L
.55596 .37981 L
.54006 .34898 L
.53468 .33974 L
.51106 .29968 L
.5 .2799 L
.48706 .25962 L
.46211 .21955 L
.45994 .21558 L
.43519 .17949 L
.41987 .15444 L
.4092 .13942 L
.38196 .09936 L
.37981 .09532 L
.35279 .05929 L
.33974 .03721 L
.32529 .01923 L
.01923 .01923 L
F
0 g
.01923 .34198 m
.05929 .36758 L
.07721 .37981 L
.09936 .39162 L
.13942 .41818 L
.14206 .41987 L
.17949 .44093 L
.20989 .45994 L
.21955 .46468 L
.25962 .48757 L
.28114 .5 L
.29968 .50915 L
.33974 .53039 L
.35843 .54006 L
.37981 .54971 L
.41987 .56782 L
.44931 .58013 L
.45994 .58363 L
.5 .59628 L
.54006 .6042 L
.58013 .6029 L
.61034 .58013 L
.61443 .54006 L
.60687 .5 L
.59316 .45994 L
.58013 .42703 L
.57607 .41987 L
.55596 .37981 L
.54006 .34898 L
.53468 .33974 L
.51106 .29968 L
.5 .2799 L
.48706 .25962 L
.46211 .21955 L
.45994 .21558 L
.43519 .17949 L
.41987 .15444 L
.4092 .13942 L
.38196 .09936 L
.37981 .09532 L
.35279 .05929 L
.33974 .03721 L
.32529 .01923 L
s
.3 0 .7 r
.01923 .31942 m
.05038 .33974 L
.05929 .34429 L
.09936 .3686 L
.11766 .37981 L
.13942 .39157 L
.17949 .41496 L
.18807 .41987 L
.21955 .43634 L
.25962 .45767 L
.26391 .45994 L
.29968 .47696 L
.33974 .49525 L
.34969 .5 L
.37981 .5111 L
.41987 .52425 L
.45994 .5328 L
.5 .53318 L
.53767 .5 L
.53907 .45994 L
.53008 .41987 L
.51556 .37981 L
.5 .34332 L
.49791 .33974 L
.47756 .29968 L
.45994 .26641 L
.45595 .25962 L
.4323 .21955 L
.41987 .19798 L
.40816 .17949 L
.3829 .13942 L
.37981 .13409 L
.35634 .09936 L
.33974 .07308 L
.33012 .05929 L
.30265 .01923 L
.01923 .01923 L
F
0 g
.01923 .31942 m
.05038 .33974 L
.05929 .34429 L
.09936 .3686 L
.11766 .37981 L
.13942 .39157 L
.17949 .41496 L
.18807 .41987 L
.21955 .43634 L
.25962 .45767 L
.26391 .45994 L
.29968 .47696 L
.33974 .49525 L
.34969 .5 L
.37981 .5111 L
.41987 .52425 L
.45994 .5328 L
.5 .53318 L
.53767 .5 L
.53907 .45994 L
.53008 .41987 L
.51556 .37981 L
.5 .34332 L
.49791 .33974 L
.47756 .29968 L
.45994 .26641 L
.45595 .25962 L
.4323 .21955 L
.41987 .19798 L
.40816 .17949 L
.3829 .13942 L
.37981 .13409 L
.35634 .09936 L
.33974 .07308 L
.33012 .05929 L
.30265 .01923 L
s
.4 0 .6 r
.01923 .30167 m
.05929 .32525 L
.08383 .33974 L
.09936 .34815 L
.13942 .37071 L
.15594 .37981 L
.17949 .39187 L
.21955 .41236 L
.2346 .41987 L
.25962 .43114 L
.29968 .4484 L
.32912 .45994 L
.33974 .4631 L
.37981 .47444 L
.41987 .4801 L
.45994 .47283 L
.47456 .45994 L
.48354 .41987 L
.47727 .37981 L
.46447 .33974 L
.45994 .32629 L
.44791 .29968 L
.42856 .25962 L
.41987 .24217 L
.40742 .21955 L
.38466 .17949 L
.37981 .17083 L
.3607 .13942 L
.33974 .10506 L
.33608 .09936 L
.30993 .05929 L
.29968 .04315 L
.28364 .01923 L
.01923 .01923 L
F
0 g
.01923 .30167 m
.05929 .32525 L
.08383 .33974 L
.09936 .34815 L
.13942 .37071 L
.15594 .37981 L
.17949 .39187 L
.21955 .41236 L
.2346 .41987 L
.25962 .43114 L
.29968 .4484 L
.32912 .45994 L
.33974 .4631 L
.37981 .47444 L
.41987 .4801 L
.45994 .47283 L
.47456 .45994 L
.48354 .41987 L
.47727 .37981 L
.46447 .33974 L
.45994 .32629 L
.44791 .29968 L
.42856 .25962 L
.41987 .24217 L
.40742 .21955 L
.38466 .17949 L
.37981 .17083 L
.3607 .13942 L
.33974 .10506 L
.33608 .09936 L
.30993 .05929 L
.29968 .04315 L
.28364 .01923 L
s
.5 0 .5 r
.01923 .28458 m
.04613 .29968 L
.05929 .30721 L
.09936 .32942 L
.11864 .33974 L
.13942 .35032 L
.17949 .37037 L
.19915 .37981 L
.21955 .38871 L
.25962 .4054 L
.29968 .41922 L
.3019 .41987 L
.33974 .42937 L
.37981 .4328 L
.41625 .41987 L
.41987 .41647 L
.43392 .37981 L
.42957 .33974 L
.41987 .30575 L
.41784 .29968 L
.40198 .25962 L
.38312 .21955 L
.37981 .21266 L
.36238 .17949 L
.33998 .13942 L
.33974 .139 L
.31631 .09936 L
.29968 .07185 L
.2918 .05929 L
.26607 .01923 L
.01923 .01923 L
F
0 g
.01923 .28458 m
.04613 .29968 L
.05929 .30721 L
.09936 .32942 L
.11864 .33974 L
.13942 .35032 L
.17949 .37037 L
.19915 .37981 L
.21955 .38871 L
.25962 .4054 L
.29968 .41922 L
.3019 .41987 L
.33974 .42937 L
.37981 .4328 L
.41625 .41987 L
.41987 .41647 L
.43392 .37981 L
.42957 .33974 L
.41987 .30575 L
.41784 .29968 L
.40198 .25962 L
.38312 .21955 L
.37981 .21266 L
.36238 .17949 L
.33998 .13942 L
.33974 .139 L
.31631 .09936 L
.29968 .07185 L
.2918 .05929 L
.26607 .01923 L
s
.6 0 .4 r
.01923 .26724 m
.05929 .28928 L
.07924 .29968 L
.09936 .3099 L
.13942 .32966 L
.16109 .33974 L
.17949 .3476 L
.21955 .36389 L
.25962 .37706 L
.27008 .37981 L
.29968 .38617 L
.33974 .38764 L
.36315 .37981 L
.37981 .36278 L
.38678 .33974 L
.38389 .29968 L
.37981 .28245 L
.37307 .25962 L
.35763 .21955 L
.33974 .18066 L
.33904 .17949 L
.31869 .13942 L
.29968 .10489 L
.29646 .09936 L
.27305 .05929 L
.25962 .0391 L
.24873 .01923 L
.01923 .01923 L
F
0 g
.01923 .26724 m
.05929 .28928 L
.07924 .29968 L
.09936 .3099 L
.13942 .32966 L
.16109 .33974 L
.17949 .3476 L
.21955 .36389 L
.25962 .37706 L
.27008 .37981 L
.29968 .38617 L
.33974 .38764 L
.36315 .37981 L
.37981 .36278 L
.38678 .33974 L
.38389 .29968 L
.37981 .28245 L
.37307 .25962 L
.35763 .21955 L
.33974 .18066 L
.33904 .17949 L
.31869 .13942 L
.29968 .10489 L
.29646 .09936 L
.27305 .05929 L
.25962 .0391 L
.24873 .01923 L
s
.7 0 .3 r
.01923 .24897 m
.04341 .25962 L
.05929 .26922 L
.09936 .28874 L
.12383 .29968 L
.13942 .30615 L
.17949 .32207 L
.21955 .33456 L
.24343 .33974 L
.25962 .3423 L
.29968 .34123 L
.30486 .33974 L
.33896 .29968 L
.33786 .25962 L
.32799 .21955 L
.31294 .17949 L
.29968 .1483 L
.29485 .13942 L
.27473 .09936 L
.25962 .07134 L
.25285 .05929 L
.22953 .01923 L
.01923 .01923 L
F
0 g
.01923 .24897 m
.04341 .25962 L
.05929 .26922 L
.09936 .28874 L
.12383 .29968 L
.13942 .30615 L
.17949 .32207 L
.21955 .33456 L
.24343 .33974 L
.25962 .3423 L
.29968 .34123 L
.30486 .33974 L
.33896 .29968 L
.33786 .25962 L
.32799 .21955 L
.31294 .17949 L
.29968 .1483 L
.29485 .13942 L
.27473 .09936 L
.25962 .07134 L
.25285 .05929 L
.22953 .01923 L
s
.8 0 .2 r
.01923 .22659 m
.05929 .24589 L
.09239 .25962 L
.09936 .26234 L
.13942 .27768 L
.17949 .28923 L
.21955 .2952 L
.25962 .29247 L
.28753 .25962 L
.2887 .21955 L
.27996 .17949 L
.26559 .13942 L
.25962 .1235 L
.24861 .09936 L
.22863 .05929 L
.21955 .04788 L
.20754 .01923 L
.01923 .01923 L
F
0 g
.01923 .22659 m
.05929 .24589 L
.09239 .25962 L
.09936 .26234 L
.13942 .27768 L
.17949 .28923 L
.21955 .2952 L
.25962 .29247 L
.28753 .25962 L
.2887 .21955 L
.27996 .17949 L
.26559 .13942 L
.25962 .1235 L
.24861 .09936 L
.22863 .05929 L
.21955 .04788 L
.20754 .01923 L
s
.9 0 .1 r
.01923 .19773 m
.05929 .21336 L
.07329 .21955 L
.09936 .22619 L
.13942 .23559 L
.17949 .23729 L
.21467 .21955 L
.21955 .21305 L
.2286 .17949 L
.22359 .13942 L
.21955 .12414 L
.21221 .09936 L
.19645 .05929 L
.17949 .02439 L
.17729 .01923 L
.01923 .01923 L
F
0 g
.01923 .19773 m
.05929 .21336 L
.07329 .21955 L
.09936 .22619 L
.13942 .23559 L
.17949 .23729 L
.21467 .21955 L
.21955 .21305 L
.2286 .17949 L
.22359 .13942 L
.21955 .12414 L
.21221 .09936 L
.19645 .05929 L
.17949 .02439 L
.17729 .01923 L
s
1 0 0 r
.01923 .14682 m
.05929 .15535 L
.09936 .15519 L
.12795 .13942 L
.13942 .11983 L
.1429 .09936 L
.13942 .06369 L
.13862 .05929 L
.12809 .01923 L
.01923 .01923 L
F
0 g
.01923 .14682 m
.05929 .15535 L
.09936 .15519 L
.12795 .13942 L
.13942 .11983 L
.1429 .09936 L
.13942 .06369 L
.13862 .05929 L
.12809 .01923 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P000182000`400?l00000o`00003ooooooolQ
ooooo`00o`00000P0000007ooooo00000`00003oooooooooo`3ooooooacooooo0@000001ooooo`00
00<00000ooooooooool0oooooolLooooo`4000000Oooool0000300000?oooooooooo0?oooooo7?oo
ool10000007ooooo00000`00003oooooooooo`3ooooooacooooo0@000001ooooo`0000<00000oooo
ooooool08Oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00Kooooo00?o0000oooo
ooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00;ooooo00?o0000oooo
ooooool00_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Cooooo00?o0000oooo
ooooool01oooool00`00003oooooooooo`2dooooo`4000000Oooool0000300000?oooooooooo00;o
oooo7`3o00000ol00000iP0I0>H06@0;0>H06@03o`00003<03<0c00c00H0c00c00?o00000;<0C02c
04`00`2c04`00ol00000V@1V09T0IP0309T0IP03o`00001o07l0O`1o0080O`1o00?o000006H0V@1V
09T00P1V09T00ol00000C02c04`0/`0204`0/`03o`00000c0<`0<`3<00@0<`3<00?o000001T0iP0I
0>H0200I0>H00`000000003o0000o`2^0000o`Gooooo0@000001ooooo`0000<00000ooooooooool0
0_oooolO0?l00003o`00003V01T0iP0I00`0iP0I00?o00000<`0<`3<03<01P3<03<00ol00000/`1<
0;<0C0030;<0C003o`00002I06H0V@1V00<0V@1V00?o000007l0O`1o07l00P1o07l00ol00000IP2I
06H0V@0206H0V@03o`00001<0;<0C02c0080C02c00?o000003<0c00c0<`0100c0<`00ol000006@3V
01T0iP0801T0iP03000000000?l0003o0:d0003o1Oooool10000007ooooo00000`00003ooooooooo
o`02ooooob00o`0000?o00000>H06@3V01T02`3V01T00ol00000c00c0<`0<`060<`0<`03o`00002c
04`0/`1<00<0/`1<00?o000009T0IP2I06H00`2I06H00ol00000O`1o07l0O`0207l0O`03o`00001V
09T0IP2I00<0IP2I00?o000004`0/`1<0;<00P1<0;<00ol00000<`3<03<0c00403<0c003o`00000I
0>H06@3V00P06@3V00<000000000o`000?l0[0000?l5ooooo`4000000Oooool0000300000?oooooo
oooo00;ooooo803o00000ol00000iP0I0>H06@0<0>H06@03o`00003<03<0c00c00H0c00c00?o0000
0;<0C02c04`00`2c04`00ol00000V@1V09T0IP0309T0IP03o`00001o07l0O`1o0080O`1o00?o0000
06H0V@1V09T00`1V09T01Ol00000C02c04`0/`1<0;?o000000L0<`3<00?o000001T0iP0I0>H0200I
0>H00`000000003o0000o`2[0000o`Gooooo0@000001ooooo`0000<00000ooooooooool00_oooolP
0?l00003o`00003V01T0iP0I00`0iP0I00?o00000<`0<`3<03<01P3<03<00ol00000/`1<0;<0C004
0;<0C003o`00002I06H0V@1V0080V@1V00?o000007l0O`1o07l00`1o07l00ol00000IP2I06H0V@02
06H0V@03o`00001<0;<0C02c0080C02c00?o000003<0c00c0<`01@0c0<`00ol000006@3V01T0iP08
01T0iP03000000000?l0003o0:X0003o1Oooool10000007ooooo00000`00003oooooooooo`02oooo
ob00o`0000?o00000>H06@3V01T03@3V01T00ol00000c00c0<`0<`060<`0<`03o`00002c04`0/`1<
00<0/`1<00?o000009T0IP2I06H00`2I06H00ol00000O`1o07l0O`0207l0O`03o`00001V09T0IP2I
00<0IP2I00?o000004`0/`1<0;<00P1<0;<00ol00000<`3<03<0c00403<0c003o`00000I0>H06@3V
00T06@3V00<000000000o`000?l0Z@000?l5ooooo`4000000Oooool0000300000?oooooooooo00;o
oooo8@3o00000ol00000iP0I0>H06@0<0>H06@03o`00003<03<0c00c00H0c00c00?o00000;<0C02c
04`0102c04`00ol00000V@1V09T0IP0209T0IP03o`00001o07l0O`1o00<0O`1o00?o000006H0V@1V
09T00`1V09T01Ol00000C02c04`0/`1<0;?o000000L0<`3<00?o000001T0iP0I0>H0200I0>H00`00
0000003o0000o`2Y0000o`Gooooo0@000001ooooo`0000<00000ooooooooool00_oooolQ0?l00003
o`00003V01T0iP0I00d0iP0I00?o00000<`0<`3<03<01P3<03<00ol00000/`1<0;<0C0030;<0C003
o`00002I06H0V@1V00<0V@1V00?o000007l0O`1o07l00P1o07l00ol00000IP2I06H0V@0306H0V@03
o`00001<0;<0C02c0080C02c00?o000003<0c00c0<`0100c0<`00ol000006@3V01T0iP0901T0iP03
000000000?l0003o0:P0003o1Oooool10000007ooooo00000`00003oooooooooo`02ooooob40o`00
00?o00000>H06@3V01T03@3V01T00ol00000c00c0<`0<`060<`0<`03o`00002c04`0/`1<00@0/`1<
00?o000009T0IP2I06H00`2I06H00ol00000O`1o07l0O`0207l0O`03o`00001V09T0IP2I00<0IP2I
00?o000004`0/`1<0;<00P1<0;<00ol00000<`3<03<0c00403<0c003o`00000I0>H06@3V00P06@3V
00<000000000o`000?l0Z0000?l5ooooo`4000000Oooool0000300000?oooooooooo00;ooooo8@3o
00000ol00000iP0I0>H06@0>0>H06@03o`00003<03<0c00c00H0c00c00?o00000;<0C02c04`0102c
04`00ol00000V@1V09T0IP0209T0IP03o`00001o07l0O`1o00<0O`1o00?o000006H0V@1V09T00P1V
09T00ol00000C02c04`0/`0204`0/`03o`00000c0<`0<`3<00D0<`3<00?o000001T0iP0I0>H01`0I
0>H00`000000003o0000o`2X0000o`Gooooo0@000001ooooo`0000<00000ooooooooool00_oooolR
0?l00003o`00003V01T0iP0I00d0iP0I00?o00000<`0<`3<03<01P3<03<00ol00000/`1<0;<0C004
0;<0C003o`00002I06H0V@1V00<0V@1V00?o000007l0O`1o07l00P1o07l00ol00000IP2I06H0V@02
06H0V@03o`00001<0;<0C02c00<0C02c00?o000003<0c00c0<`0100c0<`00ol000006@3V01T0iP08
01T0iP03000000000?l0003o0:L0003o1Oooool10000007ooooo00000`00003oooooooooo`02oooo
ob80o`0000?o00000>H06@3V01T03P3V01T00ol00000c00c0<`0<`060<`0<`03o`00002c04`0/`1<
00@0/`1<00?o000009T0IP2I06H00`2I06H00ol00000O`1o07l0O`0207l0O`03o`00001V09T0IP2I
0080IP2I00?o000004`0/`1<0;<00`1<0;<00ol00000<`3<03<0c00403<0c003o`00000I0>H06@3V
00L06@3V00<000000000o`000?l0Y`000?l5ooooo`4000000Oooool0000300000?oooooooooo00;o
oooo8`3o00000ol00000iP0I0>H06@0=0>H06@03o`00003<03<0c00c00H0c00c00?o00000;<0C02c
04`0102c04`00ol00000V@1V09T0IP0309T0IP03o`00001o07l0O`1o00<0O`1o00Go000006H0V@1V
09T0IP2Io`00000504`0/`03o`00000c0<`0<`3<00@0<`3<00?o000001T0iP0I0>H01`0I0>H00`00
0000003o0000o`2W0000o`Gooooo0@000001ooooo`0000<00000ooooooooool00_oooolS0?l00003
o`00003V01T0iP0I00h0iP0I00?o00000<`0<`3<03<01P3<03<00ol00000/`1<0;<0C0040;<0C003
o`00002I06H0V@1V00<0V@1V00?o000007l0O`1o07l00`1o07l01Ol00000IP2I06H0V@1V09Wo0000
00D0C02c00?o000003<0c00c0<`0100c0<`00ol000006@3V01T0iP0701T0iP03000000000?l0003o
0:H0003o1Oooool10000007ooooo00000`00003oooooooooo`02ooooob<0o`0000?o00000>H06@3V
01T03P3V01T00ol00000c00c0<`0<`060<`0<`03o`00002c04`0/`1<00D0/`1<00?o000009T0IP2I
06H00`2I06H00ol00000O`1o07l0O`0307l0O`05o`00001V09T0IP2I06H0VOl000001@1<0;<00ol0
0000<`3<03<0c00403<0c003o`00000I0>H06@3V00L06@3V00<000000000o`000?l0Y@000?l5oooo
o`4000000Oooool0000300000?oooooooooo00;ooooo8`3o00000ol00000iP0I0>H06@0>0>H06@03
o`00003<03<0c00c00L0c00c00?o00000;<0C02c04`0102c04`00ol00000V@1V09T0IP0309T0IP03
o`00001o07l0O`1o00<0O`1o00?o000006H0V@1V09T00P1V09T00ol00000C02c04`0/`0304`0/`03
o`00000c0<`0<`3<00@0<`3<00?o000001T0iP0I0>H01`0I0>H00`000000003o0000o`2T0000o`Go
oooo0@000001ooooo`0000<00000ooooooooool00_oooolS0?l00003o`00003V01T0iP0I00l0iP0I
00?o00000<`0<`3<03<01P3<03<00ol00000/`1<0;<0C0050;<0C003o`00002I06H0V@1V00<0V@1V
00?o000007l0O`1o07l00`1o07l01Ol00000IP2I06H0V@1V09Wo000000D0C02c00?o000003<0c00c
0<`01@0c0<`00ol000006@3V01T0iP0701T0iP03000000000?l0003o0:<0003o1Oooool10000007o
oooo00000`00003oooooooooo`02ooooob<0o`0000?o00000>H06@3V01T03`3V01T00ol00000c00c
0<`0<`070<`0<`03o`00002c04`0/`1<00@0/`1<00?o000009T0IP2I06H0102I06H00ol00000O`1o
07l0O`0207l0O`03o`00001V09T0IP2I0080IP2I00?o000004`0/`1<0;<00`1<0;<00ol00000<`3<
03<0c00403<0c003o`00000I0>H06@3V00P06@3V00<000000000o`000?l0XP000?l5ooooo`400000
0Oooool0000300000?oooooooooo00;ooooo903o00000ol00000iP0I0>H06@0>0>H06@03o`00003<
03<0c00c00P0c00c00?o00000;<0C02c04`0102c04`00ol00000V@1V09T0IP0309T0IP03o`00001o
07l0O`1o00<0O`1o00?o000006H0V@1V09T00P1V09T00ol00000C02c04`0/`0304`0/`03o`00000c
0<`0<`3<00@0<`3<00?o000001T0iP0I0>H0200I0>H00`000000003o0000o`2Q0000o`Gooooo0@00
0001ooooo`0000<00000ooooooooool00_oooolT0?l00003o`00003V01T0iP0I00l0iP0I00?o0000
0<`0<`3<03<01`3<03<00ol00000/`1<0;<0C0040;<0C003o`00002I06H0V@1V00@0V@1V00?o0000
07l0O`1o07l00P1o07l00ol00000IP2I06H0V@0206H0V@03o`00001<0;<0C02c00@0C02c00?o0000
03<0c00c0<`0100c0<`00ol000006@3V01T0iP0801T0iP03000000000?l0003o0:00003o1Oooool1
0000007ooooo00000`00003oooooooooo`02ooooob@0o`0000?o00000>H06@3V01T03`3V01T00ol0
0000c00c0<`0<`080<`0<`03o`00002c04`0/`1<00@0/`1<00?o000009T0IP2I06H00`2I06H00ol0
0000O`1o07l0O`0307l0O`03o`00001V09T0IP2I0080IP2I00?o000004`0/`1<0;<00`1<0;<00ol0
0000<`3<03<0c00503<0c003o`00000I0>H06@3V00P06@3V00<000000000o`000?l0W`000?l5oooo
o`4000000Oooool0000300000?oooooooooo00;ooooo903o00000ol00000iP0I0>H06@0?0>H06@03
o`00003<03<0c00c00P0c00c00?o00000;<0C02c04`0102c04`00ol00000V@1V09T0IP0409T0IP03
o`00001o07l0O`1o0080O`1o00?o000006H0V@1V09T00`1V09T00ol00000C02c04`0/`0304`0/`03
o`00000c0<`0<`3<00D0<`3<00?o000001T0iP0I0>H0200I0>H00`000000003o0000o`2N0000o`Go
oooo0@000001ooooo`0000<00000ooooooooool00_oooolT0?l00003o`00003V01T0iP0I0100iP0I
00?o00000<`0<`3<03<0203<03<00ol00000/`1<0;<0C0040;<0C003o`00002I06H0V@1V00@0V@1V
00?o000007l0O`1o07l00P1o07l00ol00000IP2I06H0V@0306H0V@03o`00001<0;<0C02c00<0C02c
00?o000003<0c00c0<`0100c0<`00ol000006@3V01T0iP0901T0iP03o`0000000?l0003o09d0003o
1Oooool10000007ooooo00000`00003oooooooooo`02ooooob@0o`0000?o00000>H06@3V01T0403V
01T00ol00000c00c0<`0<`080<`0<`03o`00002c04`0/`1<00@0/`1<00?o000009T0IP2I06H0102I
06H00ol00000O`1o07l0O`0207l0O`03o`00001V09T0IP2I00<0IP2I00?o000004`0/`1<0;<00`1<
0;<00ol00000<`3<03<0c00403<0c003o`00000I0>H06@3V00T06@3V00<000000000o`000?l0W@00
0?l5ooooo`4000000Oooool0000300000?oooooooooo00;ooooo903o00000ol00000iP0I0>H06@0A
0>H06@03o`00003<03<0c00c00P0c00c00?o00000;<0C02c04`0102c04`00ol00000V@1V09T0IP04
09T0IP03o`00001o07l0O`1o0080O`1o00?o000006H0V@1V09T00`1V09T00ol00000C02c04`0/`03
04`0/`03o`00000c0<`0<`3<00@0<`3<00?o000001T0iP0I0>H02@0I0>H00`000000003o0000o`2L
0000o`Gooooo0@000001ooooo`0000<00000ooooooooool00_oooolT0?l00003o`00003V01T0iP0I
0140iP0I00?o00000<`0<`3<03<0203<03<00ol00000/`1<0;<0C0040;<0C003o`00002I06H0V@1V
00@0V@1V00?o000007l0O`1o07l00`1o07l00ol00000IP2I06H0V@0206H0V@03o`00001<0;<0C02c
00@0C02c00?o000003<0c00c0<`0100c0<`00ol000006@3V01T0iP0801T0iP03000000000?l0003o
09`0003o1Oooool10000007ooooo00000`00003oooooooooo`02ooooob<0o`0000?o00000>H06@3V
01T04`3V01T00ol00000c00c0<`0<`080<`0<`03o`00002c04`0/`1<00@0/`1<00?o000009T0IP2I
06H0102I06H00ol00000O`1o07l0O`0207l0O`03o`00001V09T0IP2I00<0IP2I00?o000004`0/`1<
0;<00`1<0;<00ol00000<`3<03<0c00403<0c003o`00000I0>H06@3V00T06@3V00<000000000o`00
0?l0V`000?l5ooooo`4000000Oooool0000300000?oooooooooo00;ooooo8`3o00000ol00000iP0I
0>H06@0C0>H06@03o`00003<03<0c00c00P0c00c00?o00000;<0C02c04`0102c04`00ol00000V@1V
09T0IP0409T0IP03o`00001o07l0O`1o00<0O`1o00?o000006H0V@1V09T00`1V09T00ol00000C02c
04`0/`0304`0/`03o`00000c0<`0<`3<00@0<`3<00?o000001T0iP0I0>H02@0I0>H00`000000003o
0000o`2J0000o`Gooooo0@000001ooooo`0000<00000ooooooooool00_oooolS0?l00003o`00003V
01T0iP0I01<0iP0I00?o00000<`0<`3<03<0203<03<00ol00000/`1<0;<0C0050;<0C003o`00002I
06H0V@1V00@0V@1V00?o000007l0O`1o07l00`1o07l00ol00000IP2I06H0V@0206H0V@03o`00001<
0;<0C02c00@0C02c00?o000003<0c00c0<`0100c0<`00ol000006@3V01T0iP0801T0iP0300000000
0?l0003o09X0003o1Oooool10000007ooooo00000`00003oooooooooo`02ooooob<0o`0000?o0000
0>H06@3V01T0503V01T00ol00000c00c0<`0<`080<`0<`03o`00002c04`0/`1<00@0/`1<00?o0000
09T0IP2I06H0102I06H00ol00000O`1o07l0O`0307l0O`03o`00001V09T0IP2I00<0IP2I00?o0000
04`0/`1<0;<0101<0;<00ol00000<`3<03<0c00303<0c003o`00000I0>H06@3V00T06@3V00<00000
0000o`000?l0V@000?l5ooooo`4000000Oooool0000300000?oooooooooo00;ooooo8P3o00000ol0
0000iP0I0>H06@0E0>H06@03o`00003<03<0c00c00P0c00c00?o00000;<0C02c04`01@2c04`00ol0
0000V@1V09T0IP0409T0IP03o`00001o07l0O`1o00<0O`1o00?o000006H0V@1V09T00P1V09T00ol0
0000C02c04`0/`0404`0/`03o`00000c0<`0<`3<00@0<`3<00?o000001T0iP0I0>H0200I0>H00`00
0000003o0000o`2I0000o`Gooooo0@000001ooooo`0000<00000ooooooooool00_oooolQ0?l00003
o`00003V01T0iP0I01H0iP0I00?o00000<`0<`3<03<02@3<03<00ol00000/`1<0;<0C0040;<0C003
o`00002I06H0V@1V00@0V@1V00?o000007l0O`1o07l00`1o07l00ol00000IP2I06H0V@0306H0V@03
o`00001<0;<0C02c00@0C02c00?o000003<0c00c0<`0100c0<`00ol000006@3V01T0iP0801T0iP03
000000000?l0003o09P0003o1Oooool10000007ooooo00000`00003oooooooooo`02ooooob40o`00
00?o00000>H06@3V01T05`3V01T00ol00000c00c0<`0<`080<`0<`03o`00002c04`0/`1<00D0/`1<
00?o000009T0IP2I06H0102I06H00ol00000O`1o07l0O`0307l0O`03o`00001V09T0IP2I00<0IP2I
00?o000004`0/`1<0;<0101<0;<00ol00000<`3<03<0c00303<0c003o`00000I0>H06@3V00T06@3V
00<000000000o`000?l0U`000?l5ooooo`4000000Oooool0000300000?oooooooooo00;ooooo803o
00000ol00000iP0I0>H06@0H0>H06@03o`00003<03<0c00c00P0c00c00?o00000;<0C02c04`01@2c
04`00ol00000V@1V09T0IP0409T0IP03o`00001o07l0O`1o00@0O`1o00?o000006H0V@1V09T00P1V
09T00ol00000C02c04`0/`0404`0/`03o`00000c0<`0<`3<00@0<`3<00?o000001T0iP0I0>H0200I
0>H00`000000003o0000o`2G0000o`Gooooo0@000001ooooo`0000<00000ooooooooool00_oooolN
0?l000;o00006`3V01T00ol00000c00c0<`0<`090<`0<`03o`00002c04`0/`1<00D0/`1<00?o0000
09T0IP2I06H0102I06H00ol00000O`1o07l0O`0307l0O`03o`00001V09T0IP2I00<0IP2I00?o0000
04`0/`1<0;<00`1<0;<00ol00000<`3<03<0c00503<0c003o`00000I0>H06@3V00P06@3V0P00002G
0000o`Gooooo0@000001ooooo`0000<00000ooooooooool00_oooolL0?l000;o00007@3V01T00ol0
0000c00c0<`0<`090<`0<`03o`00002c04`0/`1<00H0/`1<00?o000009T0IP2I06H00`2I06H00ol0
0000O`1o07l0O`0307l0O`03o`00001V09T0IP2I00<0IP2I00?o000004`0/`1<0;<00`1<0;<00ol0
0000<`3<03<0c00503<0c003o`00000I0>H06@3V00X06@3V00<000000000o`000?l0U0000?l5oooo
o`4000000Oooool0000300000?oooooooooo00;ooooo1?l0000F0?l000;o00007`3V01T00ol00000
c00c0<`0<`0:0<`0<`03o`00002c04`0/`1<00H0/`1<00?o000009T0IP2I06H00`2I06H00ol00000
O`1o07l0O`0307l0O`03o`00001V09T0IP2I00<0IP2I00?o000004`0/`1<0;<00`1<0;<00ol00000
<`3<03<0c00503<0c003o`00000I0>H06@3V00X06@3V00<000000000o`000?l0T`000?l5ooooo`40
00000Oooool0000300000?oooooooooo00;ooooo103V01T6o`0000h0o`000_l0000Q0>H06@03o`00
003<03<0c00c00X0c00c00?o00000;<0C02c04`01P2c04`00ol00000V@1V09T0IP0309T0IP03o`00
001o07l0O`1o00@0O`1o00?o000006H0V@1V09T00`1V09T00ol00000C02c04`0/`0304`0/`03o`00
000c0<`0<`3<00D0<`3<00?o000001T0iP0I0>H02P0I0>H00`000000003o0000o`2B0000o`Gooooo
0@000001ooooo`0000<00000ooooooooool00_ooool:0>H06@ko00008`3V01T00ol00000c00c0<`0
<`0:0<`0<`03o`00002c04`0/`1<00L0/`1<00?o000009T0IP2I06H00`2I06H00ol00000O`1o07l0
O`0307l0O`03o`00001V09T0IP2I00<0IP2I00?o000004`0/`1<0;<0101<0;<00ol00000<`3<03<0
c00503<0c003o`00000I0>H06@3V00T06@3V00<000000000o`000?l0TP000?l5ooooo`4000000Ooo
ool0000300000?oooooooooo00;ooooo>`3V01T00ol00000c00c0<`0<`0;0<`0<`03o`00002c04`0
/`1<00H0/`1<00?o000009T0IP2I06H00`2I06H00ol00000O`1o07l0O`0407l0O`03o`00001V09T0
IP2I00<0IP2I00?o000004`0/`1<0;<00`1<0;<00ol00000<`3<03<0c00503<0c003o`00000I0>H0
6@3V00X06@3V00<000000000o`000?l0T@000?l5ooooo`4000000Oooool0000300000?oooooooooo
00;ooooo?03V01T00ol00000c00c0<`0<`0:0<`0<`03o`00002c04`0/`1<00H0/`1<00?o000009T0
IP2I06H0102I06H00ol00000O`1o07l0O`0407l0O`03o`00001V09T0IP2I00<0IP2I00?o000004`0
/`1<0;<00`1<0;<00ol00000<`3<03<0c00503<0c003o`00000I0>H06@3V00T06@3V00<000000000
o`000?l0T@000?l5ooooo`4000000Oooool0000300000?oooooooooo00;ooooo?03V01T00ol00000
c00c0<`0<`0:0<`0<`03o`00002c04`0/`1<00L0/`1<00?o000009T0IP2I06H0102I06H00ol00000
O`1o07l0O`0307l0O`03o`00001V09T0IP2I00<0IP2I00?o000004`0/`1<0;<0101<0;<00ol00000
<`3<03<0c00403<0c003o`00000I0>H06@3V00X06@3V00<000000000o`000?l0T0000?l5ooooo`40
00000Oooool0000300000?oooooooooo00;ooooo?03V01T00ol00000c00c0<`0<`0;0<`0<`03o`00
002c04`0/`1<00H0/`1<00?o000009T0IP2I06H0102I06H00ol00000O`1o07l0O`0407l0O`03o`00
001V09T0IP2I00<0IP2I00?o000004`0/`1<0;<00`1<0;<00ol00000<`3<03<0c00503<0c003o`00
000I0>H06@3V00T06@3V00<000000000o`000?l0T0000?l5ooooo`4000000Oooool0000300000?oo
oooooooo00;ooooo?03V01T00ol00000c00c0<`0<`0;0<`0<`03o`00002c04`0/`1<00H0/`1<00?o
000009T0IP2I06H01@2I06H00ol00000O`1o07l0O`0307l0O`03o`00001V09T0IP2I00@0IP2I00?o
000004`0/`1<0;<00`1<0;<00ol00000<`3<03<0c00503<0c003o`00000I0>H06@3V00T06@3V00<0
00000000o`000?l0S`000?l5ooooo`4000000Oooool0000300000?oooooooooo00;ooooo?03V01T0
0ol00000c00c0<`0<`0;0<`0<`03o`00002c04`0/`1<00L0/`1<00?o000009T0IP2I06H0102I06H0
0ol00000O`1o07l0O`0407l0O`03o`00001V09T0IP2I00<0IP2I00?o000004`0/`1<0;<0101<0;<0
0ol00000<`3<03<0c00403<0c003o`00000I0>H06@3V00T06@3V00<000000000o`000?l0S`000?l5
ooooo`4000000Oooool0000300000?oooooooooo00;ooooo?03V01T00ol00000c00c0<`0<`0<0<`0
<`03o`00002c04`0/`1<00H0/`1<00?o000009T0IP2I06H01@2I06H00ol00000O`1o07l0O`0407l0
O`03o`00001V09T0IP2I00<0IP2I00?o000004`0/`1<0;<0101<0;<00ol00000<`3<03<0c00403<0
c003o`00000I0>H06@3V00T06@3V00<000000000o`000?l0SP000?l5ooooo`4000000Oooool00003
00000?oooooooooo00;ooooo?03V01T00ol00000c00c0<`0<`0<0<`0<`03o`00002c04`0/`1<00H0
/`1<00?o000009T0IP2I06H01@2I06H00ol00000O`1o07l0O`0407l0O`03o`00001V09T0IP2I00<0
IP2I00?o000004`0/`1<0;<0101<0;<00ol00000<`3<03<0c00403<0c003o`00000I0>H06@3V00T0
6@3V00<000000000o`000?l0SP000?l5ooooo`4000000Oooool0000300000?oooooooooo00;ooooo
?03V01T00ol00000c00c0<`0<`0<0<`0<`03o`00002c04`0/`1<00L0/`1<00?o000009T0IP2I06H0
1@2I06H00ol00000O`1o07l0O`0407l0O`03o`00001V09T0IP2I00<0IP2I00?o000004`0/`1<0;<0
101<0;<00ol00000<`3<03<0c00403<0c003o`00000I0>H06@3V00T06@3V00<000000000o`000?l0
S@000?l5ooooo`4000000Oooool0000300000?oooooooooo00;ooooo>`3V01T00ol00000c00c0<`0
<`0=0<`0<`03o`00002c04`0/`1<00L0/`1<00?o000009T0IP2I06H01@2I06H00ol00000O`1o07l0
O`0407l0O`03o`00001V09T0IP2I00<0IP2I00?o000004`0/`1<0;<01@1<0;<00ol00000<`3<03<0
c00403<0c003o`00000I0>H06@3V00T06@3V00<000000000o`000?l0S0000?l5ooooo`4000000Ooo
ool0000300000?oooooooooo00;ooooo>`3V01T00ol00000c00c0<`0<`0>0<`0<`03o`00002c04`0
/`1<00H0/`1<00?o000009T0IP2I06H01@2I06H00ol00000O`1o07l0O`0507l0O`03o`00001V09T0
IP2I00<0IP2I00?o000004`0/`1<0;<0101<0;<00ol00000<`3<03<0c00503<0c003o`00000I0>H0
6@3V00T06@3V00<000000000o`000?l0R`000?l5ooooo`4000000Oooool0000300000?oooooooooo
00;ooooo0_l0000i0>H06@03o`00003<03<0c00c00h0c00c00?o00000;<0C02c04`01`2c04`00ol0
0000V@1V09T0IP0509T0IP03o`00001o07l0O`1o00@0O`1o00?o000006H0V@1V09T00`1V09T00ol0
0000C02c04`0/`0504`0/`03o`00000c0<`0<`3<00D0<`3<00?o000001T0iP0I0>H02@0I0>H00`00
0000003o0000o`2:0000o`Gooooo0@000001ooooo`0000<00000ooooooooool00_ooool20<`0<`?o
0000=P3V01T00ol00000c00c0<`0<`0>0<`0<`03o`00002c04`0/`1<00L0/`1<00?o000009T0IP2I
06H01@2I06H00ol00000O`1o07l0O`0507l0O`03o`00001V09T0IP2I00<0IP2I00?o000004`0/`1<
0;<0101<0;<00ol00000<`3<03<0c00503<0c003o`00000I0>H06@3V00T06@3V00<000000000o`00
0?l0RP000?l5ooooo`4000000Oooool0000300000?oooooooooo00;ooooo1@3<03<2o`0003@0iP0I
00?o00000<`0<`3<03<03P3<03<00ol00000/`1<0;<0C0080;<0C003o`00002I06H0V@1V00D0V@1V
00?o000007l0O`1o07l0101o07l00ol00000IP2I06H0V@0306H0V@03o`00001<0;<0C02c00D0C02c
00?o000003<0c00c0<`01@0c0<`00ol000006@3V01T0iP0901T0iP03000000000?l0003o08T0003o
1Oooool10000007ooooo00000`00003oooooooooo`02ooooo`L0c00c0_l0000a0>H06@03o`00003<
03<0c00c00l0c00c00?o00000;<0C02c04`0202c04`00ol00000V@1V09T0IP0509T0IP03o`00001o
07l0O`1o00D0O`1o00?o000006H0V@1V09T00`1V09T00ol00000C02c04`0/`0404`0/`03o`00000c
0<`0<`3<00H0<`3<00?o000001T0iP0I0>H02@0I0>H00`000000003o0000o`280000o`Gooooo0@00
0001ooooo`0000<00000ooooooooool00_ooool90<`0<`?o0000;P3V01T00ol00000c00c0<`0<`0?
0<`0<`03o`00002c04`0/`1<00T0/`1<00?o000009T0IP2I06H01@2I06H00ol00000O`1o07l0O`04
07l0O`03o`00001V09T0IP2I00<0IP2I00?o000004`0/`1<0;<01@1<0;<00ol00000<`3<03<0c006
03<0c003o`00000I0>H06@3V00T06@3V00<000000000o`000?l0Q`000?l5ooooo`4000000Oooool0
000300000?oooooooooo00;ooooo303<03<2o`0002`0iP0I00?o00000<`0<`3<03<0403<03<00ol0
0000/`1<0;<0C0080;<0C003o`00002I06H0V@1V00D0V@1V00?o000007l0O`1o07l01@1o07l00ol0
0000IP2I06H0V@0306H0V@03o`00001<0;<0C02c00D0C02c00?o000003<0c00c0<`01P0c0<`00ol0
00006@3V01T0iP0801T0iP03000000000?l0003o08L0003o1Oooool10000007ooooo00000`00003o
ooooooooo`02ooooo`h0c00c0_l0000Y0>H06@03o`00003<03<0c00c0140c00c00?o00000;<0C02c
04`0202c04`00ol00000V@1V09T0IP0509T0IP03o`00001o07l0O`1o00D0O`1o00?o000006H0V@1V
09T00`1V09T00ol00000C02c04`0/`0504`0/`03o`00000c0<`0<`3<00H0<`3<00?o000001T0iP0I
0>H02@0I0>H00`000000003o0000o`260000o`Gooooo0@000001ooooo`0000<00000ooooooooool0
0_ooool@0<`0<`Go00008P3V01T2o`0001@0c00c00?o00000;<0C02c04`02@2c04`00ol00000V@1V
09T0IP0509T0IP03o`00001o07l0O`1o00@0O`1o00?o000006H0V@1V09T0101V09T00ol00000C02c
04`0/`0504`0/`03o`00000c0<`0<`3<00D0<`3<00?o000001T0iP0I0>H02@0I0>H00`000000003o
0000o`260000o`Gooooo0@000001ooooo`0000<00000ooooooooool00_oooolE0<`0<`Go00006`3V
01T2o`0001H0c00c00?o00000;<0C02c04`02@2c04`00ol00000V@1V09T0IP0509T0IP03o`00001o
07l0O`1o00@0O`1o00?o000006H0V@1V09T0101V09T00ol00000C02c04`0/`0504`0/`03o`00000c
0<`0<`3<00D0<`3<00?o000001T0iP0I0>H02@0I0>H00`000000003o0000o`260000o`Gooooo0@00
0001ooooo`0000<00000ooooooooool00_ooool2o`0001P0c00c1?l0000E0>H06@;o0000603<03<0
0ol00000/`1<0;<0C0090;<0C003o`00002I06H0V@1V00H0V@1V00?o000007l0O`1o07l0101o07l0
0ol00000IP2I06H0V@0406H0V@03o`00001<0;<0C02c00D0C02c00?o000003<0c00c0<`01@0c0<`0
0ol000006@3V01T0iP0901T0iP03000000000?l0003o08D0003o1Oooool10000007ooooo00000`00
003oooooooooo`02ooooo`80/`1<0ol0000I0<`0<`Co00003`3V01T2o`0001X0c00c00?o00000;<0
C02c04`02P2c04`00ol00000V@1V09T0IP0509T0IP03o`00001o07l0O`1o00@0O`1o00?o000006H0
V@1V09T01@1V09T00ol00000C02c04`0/`0404`0/`03o`00000c0<`0<`3<00H0<`3<00?o000001T0
iP0I0>H02@0I0>H00`000000003o0000o`240000o`Gooooo0@000001ooooo`0000<00000oooooooo
ool00_ooool50;<0C0;o00006`3<03<8o`0000D0iP0I0_l0000L0<`0<`03o`00002c04`0/`1<00X0
/`1<00?o000009T0IP2I06H01P2I06H00ol00000O`1o07l0O`0407l0O`03o`00001V09T0IP2I00@0
IP2I00?o000004`0/`1<0;<01@1<0;<00ol00000<`3<03<0c00503<0c003o`00000I0>H06@3V00X0
6@3V00<000000000o`000?l0P`000?l5ooooo`4000000Oooool0000300000?oooooooooo00;ooooo
1`2c04`2o`000240c00c1Ol0000N0<`0<`03o`00002c04`0/`1<00X0/`1<00?o000009T0IP2I06H0
1P2I06H00ol00000O`1o07l0O`0407l0O`03o`00001V09T0IP2I00D0IP2I00?o000004`0/`1<0;<0
101<0;<00ol00000<`3<03<0c00603<0c003o`00000I0>H06@3V00X06@3V00<000000000o`000?l0
PP000?l5ooooo`4000000Oooool0000300000?oooooooooo00;ooooo2@2c04`3o`000440c00c00?o
00000;<0C02c04`02`2c04`00ol00000V@1V09T0IP0609T0IP03o`00001o07l0O`1o00@0O`1o00?o
000006H0V@1V09T01@1V09T00ol00000C02c04`0/`0404`0/`03o`00000c0<`0<`3<00H0<`3<00?o
000001T0iP0I0>H02P0I0>H00`000000003o0000o`210000o`Gooooo0@000001ooooo`0000<00000
ooooooooool00_ooool<0;<0C0;o0000?`3<03<00ol00000/`1<0;<0C00;0;<0C003o`00002I06H0
V@1V00H0V@1V00?o000007l0O`1o07l01@1o07l00ol00000IP2I06H0V@0406H0V@03o`00001<0;<0
C02c00D0C02c00?o000003<0c00c0<`01@0c0<`00ol000006@3V01T0iP0:01T0iP03000000000?l0
003o0840003o1Oooool10000007ooooo00000`00003oooooooooo`02ooooo`;o0000302c04`2o`00
03d0c00c00?o00000;<0C02c04`02`2c04`00ol00000V@1V09T0IP0609T0IP03o`00001o07l0O`1o
00D0O`1o00?o000006H0V@1V09T01@1V09T00ol00000C02c04`0/`0404`0/`03o`00000c0<`0<`3<
00H0<`3<00?o000001T0iP0I0>H02P0I0>H00`000000003o0000o`200000o`Gooooo0@000001oooo
o`0000<00000ooooooooool00_ooool209T0IP?o00002`2c04`3o`0003X0c00c00?o00000;<0C02c
04`02`2c04`00ol00000V@1V09T0IP0709T0IP03o`00001o07l0O`1o00D0O`1o00?o000006H0V@1V
09T01@1V09T00ol00000C02c04`0/`0404`0/`03o`00000c0<`0<`3<00D0<`3<00?o000001T0iP0I
0>H02`0I0>H00`000000003o0000o`1o0000o`Gooooo0@000001ooooo`0000<00000ooooooooool0
0_ooool509T0IP;o0000302c04`2o`0003P0c00c00?o00000;<0C02c04`0302c04`00ol00000V@1V
09T0IP0609T0IP03o`00001o07l0O`1o00D0O`1o00?o000006H0V@1V09T01@1V09T00ol00000C02c
04`0/`0404`0/`03o`00000c0<`0<`3<00H0<`3<00?o000001T0iP0I0>H02`0I0>H00`000000003o
0000o`1n0000o`Gooooo0@000001ooooo`0000<00000ooooooooool00_ooool709T0IP;o0000302c
04`2o`0003H0c00c00?o00000;<0C02c04`0302c04`00ol00000V@1V09T0IP0709T0IP03o`00001o
07l0O`1o00D0O`1o00?o000006H0V@1V09T01@1V09T00ol00000C02c04`0/`0404`0/`03o`00000c
0<`0<`3<00H0<`3<00?o000001T0iP0I0>H02`0I0>H00`000000003o0000o`1m0000o`Gooooo0@00
0001ooooo`0000<00000ooooooooool00_ooool909T0IP;o0000302c04`3o`0003<0c00c00?o0000
0;<0C02c04`0302c04`00ol00000V@1V09T0IP0709T0IP03o`00001o07l0O`1o00D0O`1o00?o0000
06H0V@1V09T01@1V09T00ol00000C02c04`0/`0504`0/`03o`00000c0<`0<`3<00D0<`3<00?o0000
01T0iP0I0>H02`0I0>H00`000000003o0000o`1m0000o`Gooooo0@000001ooooo`0000<00000oooo
ooooool00_ooool2o`0000T0V@1V00?o00000;<0C02c04`0302c04`3o`0002l0c00c00?o00000;<0
C02c04`03@2c04`00ol00000V@1V09T0IP0709T0IP03o`00001o07l0O`1o00H0O`1o00?o000006H0
V@1V09T01@1V09T00ol00000C02c04`0/`0504`0/`03o`00000c0<`0<`3<00D0<`3<00?o000001T0
iP0I0>H02`0I0>H00`000000003o0000o`1l0000o`Gooooo0@000001ooooo`0000<00000oooooooo
ool00_ooool207l0O`;o0000202I06H2o`0000l0/`1<0ol0000[0<`0<`03o`00002c04`0/`1<00h0
/`1<00?o000009T0IP2I06H0202I06H00ol00000O`1o07l0O`0507l0O`03o`00001V09T0IP2I00D0
IP2I00?o000004`0/`1<0;<01@1<0;<00ol00000<`3<03<0c00603<0c003o`00000I0>H06@3V00X0
6@3V00<000000000o`000?l0O0000?l5ooooo`4000000Oooool0000300000?oooooooooo00;ooooo
101o07l00ol00000V@1V09T0IP0709T0IP;o0000402c04`3o`0002L0c00c00?o00000;<0C02c04`0
3`2c04`00ol00000V@1V09T0IP0809T0IP03o`00001o07l0O`1o00D0O`1o00?o000006H0V@1V09T0
1@1V09T00ol00000C02c04`0/`0604`0/`03o`00000c0<`0<`3<00D0<`3<00?o000001T0iP0I0>H0
2`0I0>H00`000000003o0000o`1k0000o`Gooooo0@000001ooooo`0000<00000ooooooooool00_oo
ool507l0O`;o00002@2I06H3o`000100/`1<0_l0000T0<`0<`03o`00002c04`0/`1<0100/`1<00?o
000009T0IP2I06H0202I06H00ol00000O`1o07l0O`0607l0O`03o`00001V09T0IP2I00D0IP2I00?o
000004`0/`1<0;<01@1<0;<00ol00000<`3<03<0c00603<0c003o`00000I0>H06@3V00/06@3V00<0
00000000o`000?l0NP000?l5ooooo`4000000Oooool0000300000?oooooooooo00;ooooo1`1o07l2
o`0000X0V@1V0_l0000@0;<0C0?o0000803<03<00ol00000/`1<0;<0C00A0;<0C003o`00002I06H0
V@1V00T0V@1V00?o000007l0O`1o07l01@1o07l00ol00000IP2I06H0V@0506H0V@03o`00001<0;<0
C02c00H0C02c00?o000003<0c00c0<`01P0c0<`00ol000006@3V01T0iP0:01T0iP03000000000?l0
003o07X0003o1Oooool10000007ooooo00000`00003oooooooooo`02ooooo`;o00001`1o07l00ol0
0000V@1V09T0IP0909T0IP;o00004@2c04`3o`0001`0c00c00?o00000;<0C02c04`04P2c04`00ol0
0000V@1V09T0IP0909T0IP03o`00001o07l0O`1o00D0O`1o00?o000006H0V@1V09T01P1V09T00ol0
0000C02c04`0/`0504`0/`03o`00000c0<`0<`3<00H0<`3<00?o000001T0iP0I0>H02`0I0>H00`00
0000003o0000o`1i0000o`Gooooo0@000001ooooo`0000<00000ooooooooool00_ooool206H0V@03
o`00001o07l0O`1o00D0O`1o0_l0000;09T0IP;o00004P2c04`3o`0001P0c00c00?o00000;<0C02c
04`04`2c04`00ol00000V@1V09T0IP0909T0IP03o`00001o07l0O`1o00H0O`1o00?o000006H0V@1V
09T01@1V09T00ol00000C02c04`0/`0604`0/`03o`00000c0<`0<`3<00H0<`3<00?o000001T0iP0I
0>H02P0I0>H00`000000003o0000o`1i0000o`Gooooo0@000001ooooo`0000<00000ooooooooool0
0_ooool306H0V@;o00001`1o07l2o`0000/0V@1V0_l0000C0;<0C0Oo00002`3<03<6o`0001H0/`1<
00?o000009T0IP2I06H02@2I06H00ol00000O`1o07l0O`0607l0O`03o`00001V09T0IP2I00H0IP2I
00?o000004`0/`1<0;<01@1<0;<00ol00000<`3<03<0c00603<0c003o`00000I0>H06@3V00/06@3V
00<000000000o`000?l0N0000?l5ooooo`4000000Oooool0000300000?oooooooooo00;ooooo1@1V
09T2o`0000L0O`1o0_l0000;09T0IP03o`00002c04`0/`1<01L0/`1<2ol0000L0;<0C003o`00002I
06H0V@1V00X0V@1V00?o000007l0O`1o07l01@1o07l00ol00000IP2I06H0V@0606H0V@03o`00001<
0;<0C02c00H0C02c00?o000003<0c00c0<`01P0c0<`00ol000006@3V01T0iP0;01T0iP0300000000
0?l0003o07L0003o1Oooool10000007ooooo00000`00003oooooooooo`02ooooo`L0IP2I00?o0000
07l0O`1o07l01P1o07l00ol00000V@1V09T0IP0909T0IP;o0000?P2c04`00ol00000V@1V09T0IP0:
09T0IP03o`00001o07l0O`1o00H0O`1o00?o000006H0V@1V09T01@1V09T00ol00000C02c04`0/`06
04`0/`03o`00000c0<`0<`3<00H0<`3<00?o000001T0iP0I0>H02`0I0>H00`000000003o0000o`1g
0000o`Gooooo0@000001ooooo`0000<00000ooooooooool00_ooool2o`0000H0IP2I0_l0000707l0
O`?o00002P2I06H4o`0003X0/`1<00?o000009T0IP2I06H02P2I06H00ol00000O`1o07l0O`0607l0
O`03o`00001V09T0IP2I00H0IP2I00?o000004`0/`1<0;<01P1<0;<00ol00000<`3<03<0c00603<0
c003o`00000I0>H06@3V00/06@3V00<000000000o`000?l0MP000?l5ooooo`4000000Oooool00003
00000?oooooooooo00;ooooo0P1<0;<2o`0000H0IP2I0_l0000807l0O`?o00002`2I06H3o`0003L0
/`1<00?o000009T0IP2I06H02P2I06H00ol00000O`1o07l0O`0707l0O`03o`00001V09T0IP2I00D0
IP2I00?o000004`0/`1<0;<01P1<0;<00ol00000<`3<03<0c00603<0c003o`00000I0>H06@3V00/0
6@3V00<000000000o`000?l0MP000?l5ooooo`4000000Oooool0000300000?oooooooooo00;ooooo
101<0;<00ol00000IP2I06H0V@0506H0V@;o00002@1o07l2o`0000`0V@1V0_l0000d0;<0C003o`00
002I06H0V@1V00/0V@1V00?o000007l0O`1o07l01`1o07l00ol00000IP2I06H0V@0606H0V@03o`00
001<0;<0C02c00H0C02c00?o000003<0c00c0<`01P0c0<`00ol000006@3V01T0iP0;01T0iP030000
00000?l0003o07D0003o1Oooool10000007ooooo00000`00003oooooooooo`02ooooo`D0C02c0_l0
000706H0V@;o00002@1o07l2o`0000`0V@1V0ol0000`0;<0C003o`00002I06H0V@1V00`0V@1V00?o
000007l0O`1o07l01`1o07l00ol00000IP2I06H0V@0606H0V@03o`00001<0;<0C02c00H0C02c00?o
000003<0c00c0<`01`0c0<`00ol000006@3V01T0iP0;01T0iP03000000000?l0003o07@0003o1Ooo
ool10000007ooooo00000`00003oooooooooo`02ooooo`L0C02c0_l0000706H0V@;o00002@1o07l2
o`0000d0V@1V0_l0000]0;<0C003o`00002I06H0V@1V00d0V@1V00?o000007l0O`1o07l0201o07l0
0ol00000IP2I06H0V@0606H0V@03o`00001<0;<0C02c00H0C02c00?o000003<0c00c0<`01P0c0<`0
0ol000006@3V01T0iP0<01T0iP03000000000?l0003o07<0003o1Oooool10000007ooooo00000`00
003oooooooooo`02ooooo`;o00001`1<0;<00ol00000IP2I06H0V@0606H0V@03o`00001o07l0O`1o
00P0O`1o0_l0000=09T0IP;o0000:P2c04`00ol00000V@1V09T0IP0>09T0IP03o`00001o07l0O`1o
00P0O`1o00?o000006H0V@1V09T01`1V09T00ol00000C02c04`0/`0504`0/`03o`00000c0<`0<`3<
00L0<`3<00?o000001T0iP0I0>H02`0I0>H00`000000003o0000o`1c0000o`Gooooo0@000001oooo
o`0000<00000ooooooooool00_ooool203<0c003o`00001<0;<0C02c00D0C02c0_l0000706H0V@;o
00002P1o07l2o`0000d0V@1V0ol0000V0;<0C003o`00002I06H0V@1V0100V@1V00?o000007l0O`1o
07l01`1o07l00ol00000IP2I06H0V@0706H0V@03o`00001<0;<0C02c00H0C02c00?o000003<0c00c
0<`01`0c0<`00ol000006@3V01T0iP0;01T0iP03000000000?l0003o0780003o1Oooool10000007o
oooo00000`00003oooooooooo`02ooooo`<0<`3<0_l0000704`0/`;o00001`1V09T2o`0000X0O`1o
0_l0000>09T0IP?o00008P2c04`00ol00000V@1V09T0IP0A09T0IP03o`00001o07l0O`1o00P0O`1o
00?o000006H0V@1V09T01`1V09T00ol00000C02c04`0/`0504`0/`03o`00000c0<`0<`3<00L0<`3<
00?o000001T0iP0I0>H0300I0>H00`000000003o0000o`1a0000o`Gooooo0@000001ooooo`0000<0
0000ooooooooool00_ooool503<0c003o`00001<0;<0C02c00H0C02c0_l0000706H0V@;o00002P1o
07l2o`0000l0V@1V0ol0000N0;<0C003o`00002I06H0V@1V0180V@1V00?o000007l0O`1o07l0201o
07l00ol00000IP2I06H0V@0706H0V@03o`00001<0;<0C02c00D0C02c00?o000003<0c00c0<`0200c
0<`00ol000006@3V01T0iP0<01T0iP03000000000?l0003o0700003o1Oooool10000007ooooo0000
0`00003oooooooooo`02ooooo`H0<`3<0_l0000804`0/`03o`00001V09T0IP2I00H0IP2I0_l0000:
07l0O`;o0000402I06H3o`0001X0/`1<00?o000009T0IP2I06H04`2I06H00ol00000O`1o07l0O`08
07l0O`03o`00001V09T0IP2I00L0IP2I00?o000004`0/`1<0;<01P1<0;<00ol00000<`3<03<0c007
03<0c003o`00000I0>H06@3V00`06@3V00<000000000o`000?l0L0000?l5ooooo`4000000Oooool0
000300000?oooooooooo00;ooooo200c0<`00ol00000C02c04`0/`0604`0/`;o0000201V09T2o`00
00X0O`1o0_l0000A09T0IPCo00005@2c04`00ol00000V@1V09T0IP0D09T0IP03o`00001o07l0O`1o
00T0O`1o00?o000006H0V@1V09T01`1V09T00ol00000C02c04`0/`0504`0/`03o`00000c0<`0<`3<
00P0<`3<00?o000001T0iP0I0>H0300I0>H00`000000003o0000o`1_0000o`Gooooo0@000001oooo
o`0000<00000ooooooooool00_ooool903<0c0?o00001`1<0;<2o`0000P0IP2I0_l0000:07l0O`;o
00004`2I06H6o`0000L0/`1<2?l0000G09T0IP03o`00001o07l0O`1o00T0O`1o00?o000006H0V@1V
09T01`1V09T00ol00000C02c04`0/`0604`0/`03o`00000c0<`0<`3<00P0<`3<00?o000001T0iP0I
0>H0300I0>H00`000000003o0000o`1^0000o`Gooooo0@000001ooooo`0000<00000ooooooooool0
0_ooool2o`0000X0<`3<0_l0000704`0/`;o0000201V09T2o`0000X0O`1o0ol0000F09T0IPOo0000
7`2I06H00ol00000O`1o07l0O`0907l0O`03o`00001V09T0IP2I00L0IP2I00?o000004`0/`1<0;<0
1`1<0;<00ol00000<`3<03<0c00703<0c003o`00000I0>H06@3V00`06@3V00<000000000o`000?l0
KP000?l5ooooo`4000000Oooool0000300000?oooooooooo00;ooooo0P0I0>H2o`0000X0<`3<00?o
000004`0/`1<0;<01P1<0;<2o`0000P0IP2I0_l0000;07l0O`;o0000>P2I06H00ol00000O`1o07l0
O`0907l0O`03o`00001V09T0IP2I00L0IP2I00?o000004`0/`1<0;<01`1<0;<00ol00000<`3<03<0
c00803<0c003o`00000I0>H06@3V00`06@3V00<000000000o`000?l0K@000?l5ooooo`4000000Ooo
ool0000300000?oooooooooo00;ooooo100I0>H00ol00000<`3<03<0c00803<0c0;o0000201<0;<2
o`0000P0IP2I0_l0000;07l0O`?o0000=P2I06H00ol00000O`1o07l0O`0:07l0O`03o`00001V09T0
IP2I00P0IP2I00?o000004`0/`1<0;<01`1<0;<00ol00000<`3<03<0c00703<0c003o`00000I0>H0
6@3V00`06@3V00<000000000o`000?l0K@000?l5ooooo`4000000Oooool0000300000?oooooooooo
00;ooooo1@0I0>H2o`0000X0<`3<0_l0000804`0/`03o`00001V09T0IP2I00L0IP2I0_l0000<07l0
O`;o0000=02I06H00ol00000O`1o07l0O`0:07l0O`03o`00001V09T0IP2I00P0IP2I00?o000004`0
/`1<0;<01`1<0;<00ol00000<`3<03<0c00703<0c003o`00000I0>H06@3V00d06@3V00<000000000
o`000?l0K0000?l5ooooo`4000000Oooool0000300000?oooooooooo00;ooooo1`0I0>H2o`0000X0
<`3<00?o000004`0/`1<0;<01P1<0;<2o`0000T0IP2I0_l0000<07l0O`;o0000<P2I06H00ol00000
O`1o07l0O`0:07l0O`03o`00001V09T0IP2I00P0IP2I00?o000004`0/`1<0;<01`1<0;<00ol00000
<`3<03<0c00803<0c003o`00000I0>H06@3V00d06@3V00<000000000o`000?l0J`000?l5ooooo`40
00000Oooool0000300000?oooooooooo00;ooooo2@0I0>H00ol00000<`3<03<0c00803<0c0;o0000
201<0;<2o`0000T0IP2I00?o000007l0O`1o07l02`1o07l3o`0002h0V@1V00?o000007l0O`1o07l0
2`1o07l00ol00000IP2I06H0V@0806H0V@03o`00001<0;<0C02c00P0C02c00?o000003<0c00c0<`0
1`0c0<`00ol000006@3V01T0iP0=01T0iP03000000000?l0003o06/0003o1Oooool10000007ooooo
00000`00003oooooooooo`02ooooo`X06@3V0_l0000:03<0c003o`00001<0;<0C02c00L0C02c00?o
000006H0V@1V09T01`1V09T2o`0000h0O`1o0_l0000/09T0IP03o`00001o07l0O`1o00`0O`1o00?o
000006H0V@1V09T0201V09T00ol00000C02c04`0/`0704`0/`03o`00000c0<`0<`3<00P0<`3<00?o
000001T0iP0I0>H03@0I0>H00`000000003o0000o`1Z0000o`Gooooo0@000001ooooo`0000<00000
ooooooooool00_ooool<01T0iP;o00002@0c0<`2o`0000P0C02c0_l0000906H0V@;o00003P1o07l3
o`0002P0V@1V00?o000007l0O`1o07l03@1o07l00ol00000IP2I06H0V@0806H0V@03o`00001<0;<0
C02c00L0C02c00?o000003<0c00c0<`02@0c0<`00ol000006@3V01T0iP0<01T0iP03000000000?l0
003o06X0003o1Oooool10000007ooooo00000`00003oooooooooo`02ooooo`h06@3V00?o000003<0
c00c0<`0200c0<`00ol00000C02c04`0/`0704`0/`;o00002@1V09T2o`0000l0O`1o0ol0000T09T0
IP03o`00001o07l0O`1o00h0O`1o00?o000006H0V@1V09T0201V09T00ol00000C02c04`0/`0804`0
/`03o`00000c0<`0<`3<00P0<`3<00?o000001T0iP0I0>H03@0I0>H00`000000003o0000o`1Y0000
o`Gooooo0@000001ooooo`0000<00000ooooooooool00_ooool?01T0iP03o`00000c0<`0<`3<00P0
<`3<00?o000004`0/`1<0;<0201<0;<00ol00000IP2I06H0V@0806H0V@;o0000401o07l3o`000200
V@1V00?o000007l0O`1o07l03`1o07l00ol00000IP2I06H0V@0806H0V@03o`00001<0;<0C02c00P0
C02c00?o000003<0c00c0<`02@0c0<`00ol000006@3V01T0iP0=01T0iP03000000000?l0003o06P0
003o1Oooool10000007ooooo00000`00003oooooooooo`02ooooo`03o`00000I0>H06@3V00d06@3V
00?o000003<0c00c0<`0200c0<`00ol00000C02c04`0/`0804`0/`03o`00001V09T0IP2I00T0IP2I
0_l0000A07l0O`?o0000702I06H00ol00000O`1o07l0O`0@07l0O`03o`00001V09T0IP2I00T0IP2I
00?o000004`0/`1<0;<01`1<0;<00ol00000<`3<03<0c00903<0c003o`00000I0>H06@3V00d06@3V
00<000000000o`000?l0J0000?l5ooooo`4000000Oooool0000300000?oooooooooo00;ooooo0P00
000?01T0iP;o00002@0c0<`2o`0000T0C02c0_l0000;06H0V@?o00004@1o07l6o`0001<0V@1V0ol0
000C07l0O`03o`00001V09T0IP2I00T0IP2I00?o000004`0/`1<0;<0201<0;<00ol00000<`3<03<0
c00903<0c003o`00000I0>H06@3V00d06@3V00<000000000o`000?l0I`000?l5ooooo`4000000Ooo
ool0000300000?oooooooooo00;ooooo0P000?l2000000l06@3V0_l0000903<0c0?o0000201<0;<3
o`0000/0IP2I0ol0000D07l0O`[o00001P2I06H3o`0001H0O`1o00?o000006H0V@1V09T02@1V09T0
0ol00000C02c04`0/`0804`0/`03o`00000c0<`0<`3<00T0<`3<00?o000001T0iP0I0>H03@0I0>H0
0`000000003o0000o`1W0000o`Gooooo0@000001ooooo`0000<00000ooooooooool00_ooool40000
o`8000003`0I0>H2o`0000X0<`3<0_l0000904`0/`;o0000301V09T2o`0001`0O`1o1_l0000H07l0
O`03o`00001V09T0IP2I00X0IP2I00?o000004`0/`1<0;<02@1<0;<00ol00000<`3<03<0c00903<0
c003o`00000I0>H06@3V00d06@3V00<000000000o`000?l0IP000?l5ooooo`4000000Oooool00003
00000?oooooooooo00;ooooo1P000?l2000000l06@3V0_l0000:03<0c0;o00002@1<0;<2o`0000`0
IP2I0_l0000h07l0O`03o`00001V09T0IP2I00X0IP2I00?o000004`0/`1<0;<02@1<0;<00ol00000
<`3<03<0c00903<0c003o`00000I0>H06@3V00h06@3V00<000000000o`000?l0I@000?l5ooooo`40
00000Oooool0000300000?oooooooooo00;ooooo20000?l2000000l06@3V00?o000003<0c00c0<`0
2@0c0<`00ol00000C02c04`0/`0804`0/`;o0000301V09T3o`0003D0O`1o00?o000006H0V@1V09T0
2`1V09T00ol00000C02c04`0/`0904`0/`03o`00000c0<`0<`3<00T0<`3<00?o000001T0iP0I0>H0
3@0I0>H00`000000003o0000o`1U0000o`Gooooo0@000001ooooo`0000<00000ooooooooool00_oo
ool:0000o`8000003P0I0>H2o`0000X0<`3<0_l0000:04`0/`;o00003@1V09T2o`000380O`1o00?o
000006H0V@1V09T0301V09T00ol00000C02c04`0/`0904`0/`03o`00000c0<`0<`3<00T0<`3<00?o
000001T0iP0I0>H03P0I0>H00`000000003o0000o`1T0000o`Gooooo0@000001ooooo`0000<00000
ooooooooool00_ooool<0000o`8000003P0I0>H00ol00000<`3<03<0c00903<0c0;o00002P1<0;<2
o`0000d0IP2I0_l0000`07l0O`03o`00001V09T0IP2I00`0IP2I00?o000004`0/`1<0;<02P1<0;<0
0ol00000<`3<03<0c00903<0c003o`00000I0>H06@3V00h06@3V00<000000000o`000?l0H`000?l5
ooooo`4000000Oooool0000300000?oooooooooo00;ooooo3P000?l00`0000006@3V01T0iP0<01T0
iP;o00002`0c0<`00ol00000C02c04`0/`0904`0/`;o00003@1V09T3o`0002`0O`1o00?o000006H0
V@1V09T03@1V09T00ol00000C02c04`0/`0:04`0/`03o`00000c0<`0<`3<00X0<`3<00?o000001T0
iP0I0>H03@0I0>H00`000000003o0000o`1S0000o`Gooooo0@000001ooooo`0000<00000oooooooo
ool00_ooool?0000o`030000000I0>H06@3V00d06@3V00?o000003<0c00c0<`02@0c0<`2o`0000/0
C02c0_l0000>06H0V@?o0000:@1o07l00ol00000IP2I06H0V@0=06H0V@03o`00001<0;<0C02c00X0
C02c00?o000003<0c00c0<`02P0c0<`00ol000006@3V01T0iP0>01T0iP03000000000?l0003o0680
003o1Oooool10000007ooooo00000`00003oooooooooo`02oooooa00003o00<0000001T0iP0I0>H0
3@0I0>H2o`0000/0<`3<00?o000004`0/`1<0;<02P1<0;<2o`0000l0IP2I0ol0000V07l0O`03o`00
001V09T0IP2I00h0IP2I00?o000004`0/`1<0;<02P1<0;<00ol00000<`3<03<0c00:03<0c003o`00
000I0>H06@3V00d06@3V00<000000000o`000?l0HP000?l5ooooo`4000000Oooool0000300000?oo
oooooooo00;ooooo4@000?l00`0000006@3V01T0iP0>01T0iP03o`00000c0<`0<`3<00T0<`3<0ol0
000;04`0/`;o0000401V09T3o`000280O`1o00?o000006H0V@1V09T03`1V09T00ol00000C02c04`0
/`0:04`0/`03o`00000c0<`0<`3<00X0<`3<00?o000001T0iP0I0>H03P0I0>H00`000000003o0000
o`1Q0000o`Gooooo0@000001ooooo`0000<00000ooooooooool00_oooolB0000o`8000003`0I0>H2
o`0000`0<`3<0_l0000;04`0/`;o00004@1V09T3o`0001d0O`1o0_l0000B06H0V@03o`00001<0;<0
C02c00/0C02c00?o000003<0c00c0<`02P0c0<`00ol000006@3V01T0iP0>01T0iP03000000000?l0
003o0600003o1Oooool10000007ooooo00000`00003oooooooooo`02oooooa@0003o0P00000?01T0
iP;o0000300c0<`2o`0000/0C02c0ol0000A06H0V@Co00005P1o07l3o`0001@0IP2I00?o000004`0
/`1<0;<02`1<0;<00ol00000<`3<03<0c00:03<0c003o`00000I0>H06@3V00h06@3V00<000000000
o`000?l0H0000?l5ooooo`4000000Oooool0000300000?oooooooooo00;ooooo5P000?l00`000000
6@3V01T0iP0>01T0iP;o0000300c0<`2o`0000`0C02c0_l0000C06H0V@?o00004@1o07l2o`0001L0
IP2I00?o000004`0/`1<0;<02`1<0;<00ol00000<`3<03<0c00;03<0c003o`00000I0>H06@3V00h0
6@3V00<000000000o`000?l0G`000?l5ooooo`4000000Oooool0000300000?oooooooooo00;ooooo
5`000?l2000001006@3V00?o000003<0c00c0<`02`0c0<`00ol00000C02c04`0/`0;04`0/`;o0000
501V09T8o`0000H0O`1o0ol0000I06H0V@03o`00001<0;<0C02c00/0C02c00?o000003<0c00c0<`0
2`0c0<`00ol000006@3V01T0iP0>01T0iP03000000000?l0003o05l0003o1Oooool10000007ooooo
00000`00003oooooooooo`02oooooaT0003o00<0000001T0iP0I0>H03P0I0>H2o`0000`0<`3<0_l0
000=04`0/`?o00006@1V09T6o`0001/0IP2I00?o000004`0/`1<0;<03@1<0;<00ol00000<`3<03<0
c00;03<0c003o`00000I0>H06@3V00h06@3V00<000000000o`000?l0GP000?l5ooooo`4000000Ooo
ool0000300000?oooooooooo00;ooooo6P000?l2000001006@3V0_l0000<03<0c0;o00003P1<0;<2
o`0003P0IP2I00?o000004`0/`1<0;<03@1<0;<00ol00000<`3<03<0c00;03<0c003o`00000I0>H0
6@3V00l06@3V00<000000000o`000?l0G@000?l5ooooo`4000000Oooool0000300000?oooooooooo
00;ooooo70000?l00`0000006@3V01T0iP0?01T0iP;o0000300c0<`2o`0000h0C02c0_l0000f06H0
V@03o`00001<0;<0C02c00d0C02c00?o000003<0c00c0<`02`0c0<`00ol000006@3V01T0iP0?01T0
iP03000000000?l0003o05d0003o1Oooool10000007ooooo00000`00003oooooooooo`02oooooad0
003o0P00000A01T0iP03o`00000c0<`0<`3<00/0<`3<0_l0000>04`0/`?o0000<`1V09T00ol00000
C02c04`0/`0=04`0/`03o`00000c0<`0<`3<00`0<`3<00?o000001T0iP0I0>H03`0I0>H00`000000
003o0000o`1L0000o`Gooooo0@000001ooooo`0000<00000ooooooooool00_oooolO0000o`030000
000I0>H06@3V00l06@3V0_l0000=03<0c003o`00001<0;<0C02c00h0C02c0_l0000a06H0V@03o`00
001<0;<0C02c00d0C02c00?o000003<0c00c0<`0300c0<`00ol000006@3V01T0iP0?01T0iP030000
00000?l0003o05`0003o1Oooool10000007ooooo00000`00003oooooooooo`02ooooob00003o0P00
000A01T0iP03o`00000c0<`0<`3<00/0<`3<0_l0000@04`0/`;o0000;`1V09T00ol00000C02c04`0
/`0=04`0/`03o`00000c0<`0<`3<00d0<`3<00?o000001T0iP0I0>H03`0I0>H00`000000003o0000
o`1K0000o`Gooooo0@000001ooooo`0000<00000ooooooooool00_oooolR0000o`030000000I0>H0
6@3V00l06@3V0_l0000=03<0c0;o0000401<0;<2o`0002`0IP2I00?o000004`0/`1<0;<03`1<0;<0
0ol00000<`3<03<0c00<03<0c003o`00000I0>H06@3V01006@3V00<000000000o`000?l0FP000?l5
ooooo`4000000Oooool0000300000?oooooooooo00;ooooo8`000?l00ol000006@3V01T0iP0@01T0
iP03o`00000c0<`0<`3<00`0<`3<00?o000004`0/`1<0;<03`1<0;<2o`0002X0IP2I00?o000004`0
/`1<0;<03`1<0;<00ol00000<`3<03<0c00<03<0c003o`00000I0>H06@3V01006@3V00<00000o`00
00000?l0FP000?l5ooooo`4000000Oooool0000300000?oooooooooo00;ooooo90000?l200000140
6@3V0ol0000<03<0c0;o00004@1<0;<6o`0002<0IP2I0_l0000A04`0/`03o`00000c0<`0<`3<00d0
<`3<00?o000001T0iP0I0>H0400I0>H00`000000003o0000o`1I0000o`Gooooo0@000001ooooo`00
00<00000ooooooooool00_oooolV0000o`8000004P0I0>H2o`0000`0<`3<0ol0000D04`0/`?o0000
7`1V09T00ol00000C02c04`0/`0A04`0/`03o`00000c0<`0<`3<00d0<`3<00?o000001T0iP0I0>H0
400I0>H00`000000003o0000o`1I0000o`Gooooo0@000001ooooo`0000<00000ooooooooool00_oo
oolX0000o`8000004P0I0>H2o`0000d0<`3<0ol0000D04`0/`?o00006`1V09T00ol00000C02c04`0
/`0B04`0/`03o`00000c0<`0<`3<00h0<`3<00?o000001T0iP0I0>H0400I0>H00`000000003o0000
o`1H0000o`Gooooo0@000001ooooo`0000<00000ooooooooool00_oooolZ0000o`8000004P0I0>H2
o`0000h0<`3<0ol0000D04`0/`?o0000501V09T4o`0001D0C02c00?o000003<0c00c0<`03P0c0<`0
0ol000006@3V01T0iP0@01T0iP03000000000?l0003o05P0003o1Oooool10000007ooooo00000`00
003oooooooooo`02ooooob`0003o0P00000B01T0iP03o`00000c0<`0<`3<00h0<`3<0_l0000E04`0
/`Oo00001`1V09T6o`0001T0C02c00?o000003<0c00c0<`03P0c0<`00ol000006@3V01T0iP0A01T0
iP03000000000?l0003o05L0003o1Oooool10000007ooooo00000`00003oooooooooo`02ooooobh0
003o0P00000A01T0iP;o0000400c0<`2o`0001X0C02c1ol0000O04`0/`03o`00000c0<`0<`3<00l0
<`3<00?o000001T0iP0I0>H0400I0>H00`000000003o0000o`1G0000o`Gooooo0@000001ooooo`00
00<00000ooooooooool00_ooool`0000o`030000000I0>H06@3V01006@3V0_l0000@03<0c0;o0000
?P1<0;<00ol00000<`3<03<0c00?03<0c003o`00000I0>H06@3V01406@3V00<000000000o`000?l0
EP000?l5ooooo`4000000Oooool0000300000?oooooooooo00;ooooo<@000?l00`0000006@3V01T0
iP0A01T0iP;o0000400c0<`00ol00000C02c04`0/`0k04`0/`03o`00000c0<`0<`3<00l0<`3<00?o
000001T0iP0I0>H04P0I0>H00`000000003o0000o`1E0000o`Gooooo0@000001ooooo`0000<00000
ooooooooool00_oooolb0000o`8000004`0I0>H00ol00000<`3<03<0c00>03<0c0;o0000>`1<0;<0
0ol00000<`3<03<0c00@03<0c003o`00000I0>H06@3V01406@3V00<000000000o`000?l0E@000?l5
ooooo`4000000Oooool0000300000?oooooooooo00;ooooo=0000?l00`0000006@3V01T0iP0A01T0
iP;o0000400c0<`2o`0003T0C02c00?o000003<0c00c0<`0400c0<`00ol000006@3V01T0iP0B01T0
iP03000000000?l0003o05@0003o1Oooool10000007ooooo00000`00003oooooooooo`02ooooocD0
003o00<0000001T0iP0I0>H04P0I0>H00ol00000<`3<03<0c00?03<0c0?o0000=P1<0;<00ol00000
<`3<03<0c00@03<0c003o`00000I0>H06@3V01806@3V00<000000000o`000?l0E0000?l5ooooo`40
00000Oooool0000300000?oooooooooo00;ooooo=P000?l2000001<06@3V0_l0000B03<0c0?o0000
<P1<0;<2o`0001<0<`3<00?o000001T0iP0I0>H04P0I0>H00`000000003o0000o`1C0000o`Gooooo
0@000001ooooo`0000<00000ooooooooool00_oooolh0000o`8000004`0I0>H2o`0001<0<`3<0ol0
000^04`0/`03o`00000c0<`0<`3<01<0<`3<00?o000001T0iP0I0>H04P0I0>H00`000000003o0000
o`1C0000o`Gooooo0@000001ooooo`0000<00000ooooooooool00_oooolj0000o`8000004`0I0>H2
o`0001@0<`3<0ol0000Z04`0/`03o`00000c0<`0<`3<01@0<`3<00?o000001T0iP0I0>H04`0I0>H0
0`000000003o0000o`1B0000o`Gooooo0@000001ooooo`0000<00000ooooooooool00_ooooll0000
o`030000000I0>H06@3V01806@3V0_l0000E03<0c0;o00009`1<0;<00ol00000<`3<03<0c00E03<0
c003o`00000I0>H06@3V01<06@3V00<000000000o`000?l0DP000?l5ooooo`4000000Oooool00003
00000?oooooooooo00;ooooo?@000?l2000001@06@3V0_l0000E03<0c0?o00008`1<0;<00ol00000
<`3<03<0c00G03<0c003o`00000I0>H06@3V01<06@3V00<000000000o`000?l0D@000?l5ooooo`40
00000Oooool0000300000?oooooooooo00;ooooo?`000?l2000001@06@3V0_l0000F03<0c0?o0000
7`1<0;<00ol00000<`3<03<0c00H03<0c003o`00000I0>H06@3V01<06@3V00<000000000o`000?l0
D@000?l5ooooo`4000000Oooool0000300000?oooooooooo00;ooooo@@000?l00`0000006@3V01T0
iP0C01T0iP03o`00000c0<`0<`3<01H0<`3<0ol0000K04`0/`03o`00000c0<`0<`3<01T0<`3<00?o
000001T0iP0I0>H0500I0>H00`000000003o0000o`1@0000o`Gooooo0@000001ooooo`0000<00000
ooooooooool00_oooom20000o`800000500I0>H2o`0001T0<`3<1?l0000F04`0/`03o`00000c0<`0
<`3<01X0<`3<00?o000001T0iP0I0>H0500I0>H00`000000003o0000o`1@0000o`Gooooo0@000001
ooooo`0000<00000ooooooooool00_oooom40000o`030000000I0>H06@3V01<06@3V0_l0000K03<0
c0Ko00003`1<0;<00ol00000<`3<03<0c00K03<0c003o`00000I0>H06@3V01D06@3V00<000000000
o`000?l0C`000?l5ooooo`4000000Oooool0000300000?oooooooooo00;oooooA@000?l2000001D0
6@3V0_l0000O03<0c0Wo00001@1<0;<00ol00000<`3<03<0c00M03<0c003o`00000I0>H06@3V01@0
6@3V00<000000000o`000?l0C`000?l5ooooo`4000000Oooool0000300000?oooooooooo00;ooooo
A`000?l00`0000006@3V01T0iP0D01T0iP?o00009@0c0<`5o`000200<`3<00?o000001T0iP0I0>H0
5@0I0>H00`000000003o0000o`1>0000o`Gooooo0@000001ooooo`0000<00000ooooooooool00_oo
oom80000o`8000005`0I0>H2o`0004P0<`3<00?o000001T0iP0I0>H05P0I0>H00ol00000003o0000
o`1=0000o`Gooooo0@000001ooooo`0000<00000ooooooooool00_oooom:0000o`8000005`0I0>H3
o`0004D0<`3<00?o000001T0iP0I0>H05P0I0>H00`000000003o0000o`1=0000o`Gooooo0@000001
ooooo`0000<00000ooooooooool00_oooom<0000o`800000600I0>H2o`0004<0<`3<00?o000001T0
iP0I0>H05`0I0>H00`000000003o0000o`1<0000o`Gooooo0@000001ooooo`0000<00000oooooooo
ool00_oooom>0000o`030000000I0>H06@3V01L06@3V0_l0001103<0c003o`00000I0>H06@3V01L0
6@3V00<000000000o`000?l0C0000?l5ooooo`4000000Oooool0000300000?oooooooooo00;ooooo
C`000?l2000001T06@3V0_l0000o03<0c003o`00000I0>H06@3V01L06@3V00<000000000o`000?l0
C0000?l5ooooo`4000000Oooool0000300000?oooooooooo00;oooooD@000?l2000001T06@3V0ol0
000l03<0c003o`00000I0>H06@3V01P06@3V00<000000000o`000?l0B`000?l5ooooo`4000000Ooo
ool0000300000?oooooooooo00;oooooD`000?l00`0000006@3V01T0iP0I01T0iP;o0000>P0c0<`0
0ol000006@3V01T0iP0H01T0iP03000000000?l0003o04/0003o1Oooool10000007ooooo00000`00
003oooooooooo`02oooooe@0003o0P00000K01T0iP;o0000=`0c0<`00ol000006@3V01T0iP0J01T0
iP03000000000?l0003o04X0003o1Oooool10000007ooooo00000`00003oooooooooo`02oooooeH0
003o0P00000K01T0iP;o0000=@0c0<`00ol000006@3V01T0iP0J01T0iP03000000000?l0003o04X0
003o1Oooool10000007ooooo00000`00003oooooooooo`02oooooeP0003o00<0000001T0iP0I0>H0
6P0I0>H2o`0003<0<`3<00?o000001T0iP0I0>H06`0I0>H00`000000003o0000o`190000o`Gooooo
0@000001ooooo`0000<00000ooooooooool00_oooomI0000o`800000700I0>H2o`000340<`3<00?o
000001T0iP0I0>H06`0I0>H00`000000003o0000o`190000o`Gooooo0@000001ooooo`0000<00000
ooooooooool00_oooomK0000o`030000000I0>H06@3V01/06@3V0_l0000_03<0c003o`00000I0>H0
6@3V01/06@3V00<000000000o`000?l0B@000?l5ooooo`4000000Oooool0000300000?oooooooooo
00;oooooG0000?l2000001d06@3V0ol0000[03<0c0;o00007P0I0>H00`000000003o0000o`180000
o`Gooooo0@000001ooooo`0000<00000ooooooooool00_oooomN0000o`8000007P0I0>H3o`0002L0
<`3<00?o000001T0iP0I0>H07P0I0>H00`000000003o0000o`180000o`Gooooo0@000001ooooo`00
00<00000ooooooooool00_oooomP0000o`8000007`0I0>H3o`0002<0<`3<00?o000001T0iP0I0>H0
800I0>H00`000000003o0000o`170000o`Gooooo0@000001ooooo`0000<00000ooooooooool00_oo
oomR0000o`800000800I0>H3o`0001h0<`3<0_l0000S01T0iP03000000000?l0003o04L0003o1Ooo
ool10000007ooooo00000`00003oooooooooo`02ooooof@0003o0P00000Q01T0iP?o00006P0c0<`0
0ol000006@3V01T0iP0S01T0iP03000000000?l0003o04L0003o1Oooool10000007ooooo00000`00
003oooooooooo`02ooooofH0003o0P00000R01T0iPCo00005@0c0<`00ol000006@3V01T0iP0U01T0
iP03000000000?l0003o04H0003o1Oooool10000007ooooo00000`00003oooooooooo`02ooooofP0
003o0P00000T01T0iPGo00003`0c0<`00ol000006@3V01T0iP0V01T0iP03000000000?l0003o04H0
003o1Oooool10000007ooooo00000`00003oooooooooo`02ooooofX0003o00<0000001T0iP0I0>H0
9P0I0>H?o`0002T06@3V00<000000000o`000?l0AP000?l5ooooo`4000000Oooool0000300000?oo
oooooooo00;oooooJ`000?l2000005l06@3V00<000000000o`000?l0A@000?l5ooooo`4000000Ooo
ool0000300000?oooooooooo00;oooooK@000?l2000005d06@3V00<000000000o`000?l0A@000?l5
ooooo`4000000Oooool0000300000?oooooooooo00;oooooK`000?l00`0000006@3V01T0iP1J01T0
iP03000000000?l0003o04D0003o1Oooool10000007ooooo00000`00003oooooooooo`02ooooog00
003o0P00001K01T0iP03000000000?l0003o04@0003o1Oooool10000007ooooo00000`00003ooooo
ooooo`02ooooog80003o00<0000001T0iP0I0>H0F00I0>H00`000000003o0000o`140000o`Gooooo
0@000001ooooo`0000<00000ooooooooool00_oooomc0000o`800000F00I0>H00`000000003o0000
o`140000o`Gooooo0@000001ooooo`0000<00000ooooooooool00_oooome0000o`800000E`0I0>H0
0`000000003o0000o`130000o`Gooooo0@000001ooooo`0000<00000ooooooooool00_oooomg0000
o`800000E@0I0>H00`000000003o0000o`130000o`Gooooo0@000001ooooo`0000<00000oooooooo
ool00_oooomi0000o`800000D`0I0>H00`000000003o0000o`130000o`Gooooo0@000001ooooo`00
00<00000ooooooooool00_oooomk0000o`800000D@0I0>H00`000000003o0000o`130000o`Gooooo
0@000001ooooo`0000<00000ooooooooool00_oooomm0000o`800000C`0I0>H00`000000003o0000
o`130000o`Gooooo0@000001ooooo`0000<00000ooooooooool00_oooomo0000o`800000CP0I0>H0
0`000000003o0000o`120000o`Gooooo0@000001ooooo`0000<00000ooooooooool00_oooon10000
o`800000C00I0>H00`000000003o0000o`120000o`Gooooo0@000001ooooo`0000<00000oooooooo
ool00_oooon30000o`030000000I0>H06@3V04T06@3V00<000000000o`000?l0@P000?l5ooooo`40
00000Oooool0000300000?oooooooooo00;oooooQ0000?l2000004T06@3V00<000000000o`000?l0
@P000?l5ooooo`4000000Oooool0000300000?oooooooooo00;oooooQP000?l2000004L06@3V00<0
00000000o`000?l0@P000?l5ooooo`4000000Oooool0000300000?oooooooooo00;oooooR0000?l2
000004D06@3V00<000000000o`000?l0@P000?l5ooooo`4000000Oooool0000300000?oooooooooo
00;oooooRP000?l2000004<06@3V00<000000000o`000?l0@P000?l5ooooo`4000000Oooool00003
00000?oooooooooo00;oooooS0000?l2000004406@3V00<000000000o`000?l0@P000?l5ooooo`40
00000Oooool0000300000?oooooooooo00;oooooSP000?l3000003h06@3V00<000000000o`000?l0
@P000?l5ooooo`4000000Oooool0000300000?oooooooooo00;oooooT@000?l2000003`06@3V00<0
00000000o`000?l0@P000?l5ooooo`4000000Oooool0000300000?oooooooooo00;oooooT`000?l2
000003X06@3V00<000000000o`000?l0@P000?l5ooooo`4000000Oooool0000300000?oooooooooo
00;oooooU@000?l2000003P06@3V00<000000000o`000?l0@P000?l5ooooo`4000000Oooool00003
00000?oooooooooo00;oooooU`000?l3000003D06@3V00<000000000o`000?l0@P000?l5ooooo`40
00000Oooool0000300000?oooooooooo00;oooooVP000?l3000003806@3V00<000000000o`000?l0
@P000?l5ooooo`4000000Oooool0000300000?oooooooooo00;oooooW@000?l3000002h06@3V00<0
00000000o`000?l0@`000?l5ooooo`4000000Oooool0000300000?oooooooooo00;oooooX0000?l0
0ol000006@3V01T0iP0Z01T0iP800000A@000?l5ooooo`4000000Oooool0000300000?oooooooooo
00;oooooX@000?l2000002T06@3V00<000000000o`000?l0A@000?l5ooooo`4000000Oooool00003
00000?oooooooooo00;oooooX`000?l3000002D06@3V00<000000000o`000?l0AP000?l5ooooo`40
00000Oooool0000300000?oooooooooo00;oooooYP000?l3000002006@3V0P0000190000o`Gooooo
0@000001ooooo`0000<00000ooooooooool00_oooonY0000o`<00000700I0>H00`000000003o0000
o`190000o`Gooooo0@000001ooooo`0000<00000ooooooooool00_oooon/0000o`@000005P0I0>H2
000004`0003o1Oooool10000007ooooo00000`00003oooooooooo`02oooook00003o1P00000?01T0
iP03000000000?l0003o04`0003o1Oooool10000007ooooo00000`00003oooooooooo`02oooookH0
003o2@00000501T0iP03000000000?l0003o04d0003o1Oooool10000007ooooo00000`00003ooooo
ooooo`02oooookl0003o1@00001@0000o`Gooooo0@000001ooooo`0000<00000ooooooooool00_oo
oooo0000oaD0003o1Oooool10000007ooooo00000`00003oooooooooo`02ooooool0003o5@000?l5
ooooo`4000000Oooool0000300000?oooooooooo00;oooooo`000?lE0000o`Gooooo0@000001oooo
o`0000<00000ooooooooool00_oooooo0000oaD0003o1Oooool10000007ooooo00000`00003ooooo
ooooo`02ooooool0003o5@000?l5ooooo`4000000Oooool0000300000?oooooooooo00;oooooo`00
0?lE0000o`Gooooo0@000001ooooo`0000<00000ooooooooool00_oooooo0000oaD0003o1Oooool1
0000007ooooo00000`00003oooooooooo`02ooooool0003o5@000?l5ooooo`4000000Oooool00003
00000?oooooooooo00;oooooo`000?lE0000o`Gooooo0@000001ooooo`0000<00000ooooooooool0
0_oooooo0000oaD0003o1Oooool10000007ooooo00000`00003oooooooooo`02ooooool0003o5@00
0?l5ooooo`4000000Oooool0000300000?oooooooooo00;oooooo`000?lE0000o`Gooooo0@000001
ooooo`0000<00000ooooooooool00_oooooo0000oaD0003o1Oooool10000007ooooo00000`00003o
ooooooooo`02ooooool0003o5@000?l5ooooo`4000000Oooool0000300000?oooooooooo00;ooooo
o`000?lE0000o`Gooooo0@000001ooooo`0000<00000ooooooooool00_oooooo0000oaD0003o1Ooo
ool10000007ooooo00000`00003oooooooooo`02ooooool0003o5@000?l5ooooo`4000000Oooool0
000300000?oooooooooo00;oooooo`000?lE0000o`Gooooo0@000001ooooo`0000<00000oooooooo
ool00_oooooo0000oaD0003o1Oooool10000007ooooo00000`00003oooooooooo`02ooooool0003o
5@000?l5ooooo`4000000Oooool0000300000?oooooooooo00;oooooo`000?lE0000o`Gooooo0@00
0001ooooo`0000<00000ooooooooool00_oooooo0000oaD0003o1Oooool10000007ooooo00000`00
003oooooooooo`02ooooool0003o5@000?l5ooooo`4000000Oooool0000300000?oooooooooo00;o
ooooo`000?lE0000o`Gooooo0@000001ooooo`0000<00000ooooooooool00_oooooo0000oaD0003o
1Oooool10000007ooooo00000`00003oooooooooo`02ooooool0003o5@000?l5ooooo`4000000Ooo
ool0000300000?oooooooooo00;oooooo`000?lE0000o`Gooooo0@000001ooooo`0000<00000oooo
ooooool00_oooooo0000oaD0003o1Oooool10000007ooooo00000`00003oooooooooo`02ooooool0
003o5@000?l5ooooo`4000000Oooool0000300000?oooooooooo00;oooooo`000?lE0000o`Gooooo
0@000001ooooo`0000<00000ooooooooool00_oooooo0000oaD0003o1Oooool10000007ooooo0000
0`00003oooooooooo`02ooooool0003o5@000?l5ooooo`4000000Oooool0000300000?oooooooooo
00;oooooo`000?lE0000o`Gooooo0@000001ooooo`0000<00000ooooooooool00_oooooo0000oaD0
003o1Oooool10000007ooooo00000`00003oooooooooo`02ooooool0003o5@000?l5ooooo`400000
0Oooool0000300000?oooooooooo00;oooooo`000?lE0000o`Gooooo0@000001ooooo`0000<00000
ooooooooool00_oooooo0000oaD0003o1Oooool10000007ooooo00000`00003oooooooooo`02oooo
ool0003o5@000?l5ooooo`4000000Oooool0000300000?oooooooooo00;oooooo`000?lE0000o`Go
oooo0@000001ooooo`0000<00000ooooooooool00_oooooo0000oaD0003o1Oooool10000007ooooo
00000`00003oooooooooo`02ooooool0003o5@000?l5ooooo`4000000Oooool0000300000?oooooo
oooo00;oooooo`000?lE0000o`Gooooo0@000001ooooo`0000<00000ooooooooool00_oooooo0000
oaD0003o1Oooool10000007ooooo00000`00003oooooooooo`02ooooool0003o5@000?l5ooooo`40
00000Oooool0000300000?oooooooooo00;oooooo`000?lE0000o`Gooooo0@000001ooooo`0000<0
0000ooooooooool00_oooooo0000oaD0003o1Oooool10000007ooooo00000`00003oooooooooo`02
ooooool0003o5@000?l5ooooo`4000000Oooool0000300000?oooooooooo00;oooooo`000?lE0000
o`Gooooo0@000001ooooo`0000<00000ooooooooool00_oooooo0000oaD0003o1Oooool10000007o
oooo00000`00003oooooooooo`02ooooool0003o5@000?l5ooooo`4000000Oooool0000300000?oo
oooooooo00;oooooo`000?lE0000o`Gooooo0@000001ooooo`0000<00000ooooooooool00_oooooo
0000oaD0003o1Oooool10000007ooooo00000`00003oooooooooo`02ooooool0003o5@000?l5oooo
o`4000000Oooool0000300000?oooooooooo00;oooooo`000?lE0000o`Gooooo0@000001ooooo`00
00<00000ooooooooool00_oooooo0000oaD0003o1Oooool10000007ooooo00000`00003ooooooooo
o`02ooooool0003o5@000?l5ooooo`4000000Oooool0000300000?oooooooooo00;oooooo`000?lE
0000o`Gooooo0@000001ooooo`0000<00000ooooooooool00_oooooo0000oaD0003o1Oooool10000
007ooooo00000`00003oooooooooo`02ooooool0003o5@000?l5ooooo`4000000Oooool000030000
0?oooooooooo00;oooooo`000?lE0000o`Gooooo0@000001ooooo`0000<00000ooooooooool00_oo
oooo0000oaD0003o1Oooool10000007ooooo00000`00003oooooooooo`02ooooool0003o5@000?l5
ooooo`4000000Oooool0000300000?oooooooooo00;oooooo`000?lE0000o`Gooooo0@000001oooo
o`0000<00000ooooooooool00_oooooo0000oaD0003o1Oooool10000007ooooo00000`00003ooooo
ooooo`02ooooool0003o5@000?l5ooooo`4000000Oooool0000300000?oooooooooo00;oooooo`00
0?lE0000o`Gooooo0@000001ooooo`0000<00000ooooooooool00_oooooo0000oaD0003o1Oooool1
0000007ooooo00000`00003oooooooooo`02ooooool0003o5@000?l5ooooo`4000000Oooool00003
00000?oooooooooo00;oooooo`000?lE0000o`Gooooo0@000001ooooo`0000<00000ooooooooool0
0_oooooo0000oaD0003o1Oooool10000007ooooo00000`00003oooooooooo`02ooooool0003o5@00
0?l5ooooo`4000000Oooool0000300000?oooooooooo00;oooooo`000?lE0000o`Gooooo0@000001
ooooo`0000<00000ooooooooool00_oooooo0000oaD0003o1Oooool10000007ooooo00000`00003o
ooooooooo`3ooooooacooooo0@000001ooooo`0000<00000ooooooooool0oooooolLooooo`400000
0Oooool0000300000?oooooooooo0?oooooo7?ooool10000007ooooo00000`00003oooooooooo`3o
oooooacooooo0@000001ooooo`00o`00000P0000007ooooo0000\
\>"],
  ImageRangeCache->{{{0, 287}, {287, 0}} -> {-1.04092, -1.04092, 0.00725378, \
0.00725378}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% ContourGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.480769 0.5 0.480769 [
[ 0 0 -0.125 0 ]
[ 0 0 -0.125 0 ]
[ 0 1 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
0 0 m
1 0 L
s
0 0 m
0 1 L
s
0 1 m
1 1 L
s
1 0 m
1 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
0 0 1 r
.01923 .98077 m
.98077 .98077 L
.98077 .01923 L
.01923 .01923 L
F
0 g
.5 Mabswid
.1 0 .9 r
.01923 .31951 m
.05019 .33974 L
.05929 .34564 L
.09936 .37368 L
.10989 .37981 L
.13942 .39832 L
.17236 .41987 L
.17949 .42398 L
.21955 .45031 L
.23559 .45994 L
.25962 .4742 L
.29968 .49915 L
.30159 .5 L
.33974 .52319 L
.37224 .54006 L
.37981 .54609 L
.41987 .56929 L
.44211 .58013 L
.45994 .59063 L
.5 .61165 L
.51863 .62019 L
.54006 .6308 L
.58013 .64566 L
.61071 .66026 L
.62019 .66185 L
.66026 .67274 L
.70032 .67757 L
.72521 .66026 L
.72787 .62019 L
.71281 .58013 L
.70032 .54341 L
.69403 .54006 L
.67157 .5 L
.66026 .48327 L
.64586 .45994 L
.62019 .42345 L
.61799 .41987 L
.58876 .37981 L
.58013 .37276 L
.55865 .33974 L
.54006 .32032 L
.52779 .29968 L
.5 .26675 L
.49597 .25962 L
.46295 .21955 L
.45994 .21561 L
.42944 .17949 L
.41987 .16729 L
.39572 .13942 L
.37981 .11972 L
.36194 .09936 L
.33974 .07279 L
.32799 .05929 L
.29968 .02445 L
.29347 .01923 L
.01923 .01923 L
F
0 g
.01923 .31951 m
.05019 .33974 L
.05929 .34564 L
.09936 .37368 L
.10989 .37981 L
.13942 .39832 L
.17236 .41987 L
.17949 .42398 L
.21955 .45031 L
.23559 .45994 L
.25962 .4742 L
.29968 .49915 L
.30159 .5 L
.33974 .52319 L
.37224 .54006 L
.37981 .54609 L
.41987 .56929 L
.44211 .58013 L
.45994 .59063 L
.5 .61165 L
.51863 .62019 L
.54006 .6308 L
.58013 .64566 L
.61071 .66026 L
.62019 .66185 L
.66026 .67274 L
.70032 .67757 L
.72521 .66026 L
.72787 .62019 L
.71281 .58013 L
.70032 .54341 L
.69403 .54006 L
.67157 .5 L
.66026 .48327 L
.64586 .45994 L
.62019 .42345 L
.61799 .41987 L
.58876 .37981 L
.58013 .37276 L
.55865 .33974 L
.54006 .32032 L
.52779 .29968 L
.5 .26675 L
.49597 .25962 L
.46295 .21955 L
.45994 .21561 L
.42944 .17949 L
.41987 .16729 L
.39572 .13942 L
.37981 .11972 L
Mistroke
.36194 .09936 L
.33974 .07279 L
.32799 .05929 L
.29968 .02445 L
.29347 .01923 L
Mfstroke
.2 0 .8 r
.01923 .30369 m
.05929 .33171 L
.07415 .33974 L
.09936 .3568 L
.13777 .37981 L
.13942 .38083 L
.17949 .40753 L
.20689 .41987 L
.21955 .43093 L
.25962 .45516 L
.2703 .45994 L
.29968 .47884 L
.33906 .5 L
.33974 .50057 L
.37981 .52341 L
.414 .54006 L
.41987 .5435 L
.45994 .55862 L
.49813 .58013 L
.5 .58095 L
.54006 .59413 L
.58013 .60789 L
.62019 .61598 L
.65802 .58013 L
.65023 .54006 L
.63204 .5 L
.62019 .47088 L
.61138 .45994 L
.58813 .41987 L
.58013 .40895 L
.5559 .37981 L
.54006 .35063 L
.53066 .33974 L
.50344 .29968 L
.5 .29789 L
.47328 .25962 L
.45994 .24898 L
.44234 .21955 L
.41987 .19713 L
.41029 .17949 L
.37981 .14511 L
.37688 .13942 L
.34295 .09936 L
.33974 .09543 L
.30942 .05929 L
.29968 .04541 L
.27578 .01923 L
.01923 .01923 L
F
0 g
.01923 .30369 m
.05929 .33171 L
.07415 .33974 L
.09936 .3568 L
.13777 .37981 L
.13942 .38083 L
.17949 .40753 L
.20689 .41987 L
.21955 .43093 L
.25962 .45516 L
.2703 .45994 L
.29968 .47884 L
.33906 .5 L
.33974 .50057 L
.37981 .52341 L
.414 .54006 L
.41987 .5435 L
.45994 .55862 L
.49813 .58013 L
.5 .58095 L
.54006 .59413 L
.58013 .60789 L
.62019 .61598 L
.65802 .58013 L
.65023 .54006 L
.63204 .5 L
.62019 .47088 L
.61138 .45994 L
.58813 .41987 L
.58013 .40895 L
.5559 .37981 L
.54006 .35063 L
.53066 .33974 L
.50344 .29968 L
.5 .29789 L
.47328 .25962 L
.45994 .24898 L
.44234 .21955 L
.41987 .19713 L
.41029 .17949 L
.37981 .14511 L
.37688 .13942 L
.34295 .09936 L
.33974 .09543 L
.30942 .05929 L
.29968 .04541 L
.27578 .01923 L
s
.3 0 .7 r
.01923 .29525 m
.02708 .29968 L
.05929 .32232 L
.09025 .33974 L
.09936 .34581 L
.13942 .37171 L
.15768 .37981 L
.17949 .39632 L
.21955 .41835 L
.22158 .41987 L
.25962 .44367 L
.2922 .45994 L
.29968 .46532 L
.33974 .48249 L
.36535 .5 L
.37981 .50823 L
.41987 .52488 L
.44755 .54006 L
.45994 .54286 L
.5 .5592 L
.54006 .57244 L
.58013 .57632 L
.61691 .54006 L
.60769 .5 L
.58916 .45994 L
.58013 .43754 L
.56753 .41987 L
.54164 .37981 L
.54006 .37436 L
.51193 .33974 L
.5 .31662 L
.48553 .29968 L
.45994 .26101 L
.45873 .25962 L
.42886 .21955 L
.41987 .21373 L
.39801 .17949 L
.37981 .16362 L
.36602 .13942 L
.33974 .11236 L
.32718 .09936 L
.29968 .06174 L
.29735 .05929 L
.26456 .01923 L
.01923 .01923 L
F
0 g
.01923 .29525 m
.02708 .29968 L
.05929 .32232 L
.09025 .33974 L
.09936 .34581 L
.13942 .37171 L
.15768 .37981 L
.17949 .39632 L
.21955 .41835 L
.22158 .41987 L
.25962 .44367 L
.2922 .45994 L
.29968 .46532 L
.33974 .48249 L
.36535 .5 L
.37981 .50823 L
.41987 .52488 L
.44755 .54006 L
.45994 .54286 L
.5 .5592 L
.54006 .57244 L
.58013 .57632 L
.61691 .54006 L
.60769 .5 L
.58916 .45994 L
.58013 .43754 L
.56753 .41987 L
.54164 .37981 L
.54006 .37436 L
.51193 .33974 L
.5 .31662 L
.48553 .29968 L
.45994 .26101 L
.45873 .25962 L
.42886 .21955 L
.41987 .21373 L
.39801 .17949 L
.37981 .16362 L
.36602 .13942 L
.33974 .11236 L
.32718 .09936 L
.29968 .06174 L
.29735 .05929 L
.26456 .01923 L
s
.4 0 .6 r
.01923 .28894 m
.03829 .29968 L
.05929 .31443 L
.09936 .3367 L
.10333 .33974 L
.13942 .36411 L
.17098 .37981 L
.17949 .38721 L
.21955 .40641 L
.23778 .41987 L
.25962 .4341 L
.29968 .45401 L
.30888 .45994 L
.33974 .47072 L
.37981 .49575 L
.38723 .5 L
.41987 .51173 L
.45994 .53032 L
.48738 .54006 L
.5 .54326 L
.54006 .55068 L
.57663 .54006 L
.58013 .53575 L
.5849 .5 L
.58013 .48082 L
.57261 .45994 L
.55203 .41987 L
.54006 .39423 L
.52958 .37981 L
.50237 .33974 L
.5 .33311 L
.4729 .29968 L
.45994 .27635 L
.44579 .25962 L
.41987 .22164 L
.41809 .21955 L
.38808 .17949 L
.37981 .17416 L
.35699 .13942 L
.33974 .12471 L
.31503 .09936 L
.29968 .07419 L
.28546 .05929 L
.25962 .02371 L
.25495 .01923 L
.01923 .01923 L
F
0 g
.01923 .28894 m
.03829 .29968 L
.05929 .31443 L
.09936 .3367 L
.10333 .33974 L
.13942 .36411 L
.17098 .37981 L
.17949 .38721 L
.21955 .40641 L
.23778 .41987 L
.25962 .4341 L
.29968 .45401 L
.30888 .45994 L
.33974 .47072 L
.37981 .49575 L
.38723 .5 L
.41987 .51173 L
.45994 .53032 L
.48738 .54006 L
.5 .54326 L
.54006 .55068 L
.57663 .54006 L
.58013 .53575 L
.5849 .5 L
.58013 .48082 L
.57261 .45994 L
.55203 .41987 L
.54006 .39423 L
.52958 .37981 L
.50237 .33974 L
.5 .33311 L
.4729 .29968 L
.45994 .27635 L
.44579 .25962 L
.41987 .22164 L
.41809 .21955 L
.38808 .17949 L
.37981 .17416 L
.35699 .13942 L
.33974 .12471 L
.31503 .09936 L
.29968 .07419 L
.28546 .05929 L
.25962 .02371 L
.25495 .01923 L
s
.5 0 .5 r
.01923 .28318 m
.04825 .29968 L
.05929 .30747 L
.09936 .32812 L
.11467 .33974 L
.13942 .35725 L
.17949 .37934 L
.18019 .37981 L
.21955 .39742 L
.25092 .41987 L
.25962 .42566 L
.29968 .44428 L
.32539 .45994 L
.33974 .46367 L
.37981 .48494 L
.41062 .5 L
.41987 .50254 L
.45994 .51724 L
.5 .52842 L
.54006 .52605 L
.56355 .5 L
.55608 .45994 L
.5401 .41987 L
.54006 .41978 L
.51749 .37981 L
.5 .34766 L
.49402 .33974 L
.46479 .29968 L
.45994 .28905 L
.43602 .25962 L
.41987 .23339 L
.40829 .21955 L
.37981 .17982 L
.37953 .17949 L
.34903 .13942 L
.33974 .13284 L
.30712 .09936 L
.29968 .08352 L
.27658 .05929 L
.25962 .03243 L
.24615 .01923 L
.01923 .01923 L
F
0 g
.01923 .28318 m
.04825 .29968 L
.05929 .30747 L
.09936 .32812 L
.11467 .33974 L
.13942 .35725 L
.17949 .37934 L
.18019 .37981 L
.21955 .39742 L
.25092 .41987 L
.25962 .42566 L
.29968 .44428 L
.32539 .45994 L
.33974 .46367 L
.37981 .48494 L
.41062 .5 L
.41987 .50254 L
.45994 .51724 L
.5 .52842 L
.54006 .52605 L
.56355 .5 L
.55608 .45994 L
.5401 .41987 L
.54006 .41978 L
.51749 .37981 L
.5 .34766 L
.49402 .33974 L
.46479 .29968 L
.45994 .28905 L
.43602 .25962 L
.41987 .23339 L
.40829 .21955 L
.37981 .17982 L
.37953 .17949 L
.34903 .13942 L
.33974 .13284 L
.30712 .09936 L
.29968 .08352 L
.27658 .05929 L
.25962 .03243 L
.24615 .01923 L
s
.6 0 .4 r
.01923 .27778 m
.05722 .29968 L
.05929 .30115 L
.09936 .32124 L
.12422 .33974 L
.13942 .35088 L
.17949 .37216 L
.19121 .37981 L
.21955 .3908 L
.25962 .41801 L
.26276 .41987 L
.29968 .43641 L
.33974 .45902 L
.34135 .45994 L
.37981 .47579 L
.41987 .49314 L
.44057 .5 L
.45994 .50524 L
.5 .51189 L
.53221 .5 L
.53987 .45994 L
.52738 .41987 L
.5073 .37981 L
.5 .36376 L
.48412 .33974 L
.45994 .30054 L
.45926 .29968 L
.42868 .25962 L
.41987 .24375 L
.40023 .21955 L
.37981 .18928 L
.37171 .17949 L
.3418 .13942 L
.33974 .13817 L
.30252 .09936 L
.29968 .09046 L
.27017 .05929 L
.25962 .03981 L
.23918 .01923 L
.01923 .01923 L
F
0 g
.01923 .27778 m
.05722 .29968 L
.05929 .30115 L
.09936 .32124 L
.12422 .33974 L
.13942 .35088 L
.17949 .37216 L
.19121 .37981 L
.21955 .3908 L
.25962 .41801 L
.26276 .41987 L
.29968 .43641 L
.33974 .45902 L
.34135 .45994 L
.37981 .47579 L
.41987 .49314 L
.44057 .5 L
.45994 .50524 L
.5 .51189 L
.53221 .5 L
.53987 .45994 L
.52738 .41987 L
.5073 .37981 L
.5 .36376 L
.48412 .33974 L
.45994 .30054 L
.45926 .29968 L
.42868 .25962 L
.41987 .24375 L
.40023 .21955 L
.37981 .18928 L
.37171 .17949 L
.3418 .13942 L
.33974 .13817 L
.30252 .09936 L
.29968 .09046 L
.27017 .05929 L
.25962 .03981 L
.23918 .01923 L
s
.7 0 .3 r
.01923 .27261 m
.05929 .29576 L
.06546 .29968 L
.09936 .31572 L
.13258 .33974 L
.13942 .34485 L
.17949 .36594 L
.2015 .37981 L
.21955 .38594 L
.25962 .41117 L
.27508 .41987 L
.29968 .42991 L
.33974 .45114 L
.35739 .45994 L
.37981 .46768 L
.41987 .48315 L
.45994 .49406 L
.5 .49167 L
.5242 .45994 L
.51492 .41987 L
.5 .38437 L
.49787 .37981 L
.47523 .33974 L
.45994 .31204 L
.45099 .29968 L
.423 .25962 L
.41987 .25343 L
.39352 .21955 L
.37981 .198 L
.36487 .17949 L
.33974 .14484 L
.33533 .13942 L
.30033 .09936 L
.29968 .09577 L
.26569 .05929 L
.25962 .04616 L
.2337 .01923 L
.01923 .01923 L
F
0 g
.01923 .27261 m
.05929 .29576 L
.06546 .29968 L
.09936 .31572 L
.13258 .33974 L
.13942 .34485 L
.17949 .36594 L
.2015 .37981 L
.21955 .38594 L
.25962 .41117 L
.27508 .41987 L
.29968 .42991 L
.33974 .45114 L
.35739 .45994 L
.37981 .46768 L
.41987 .48315 L
.45994 .49406 L
.5 .49167 L
.5242 .45994 L
.51492 .41987 L
.5 .38437 L
.49787 .37981 L
.47523 .33974 L
.45994 .31204 L
.45099 .29968 L
.423 .25962 L
.41987 .25343 L
.39352 .21955 L
.37981 .198 L
.36487 .17949 L
.33974 .14484 L
.33533 .13942 L
.30033 .09936 L
.29968 .09577 L
.26569 .05929 L
.25962 .04616 L
.2337 .01923 L
s
.8 0 .2 r
.01923 .2676 m
.05929 .29105 L
.07323 .29968 L
.09936 .31125 L
.13942 .33919 L
.14043 .33974 L
.17949 .36042 L
.21154 .37981 L
.21955 .38226 L
.25962 .40487 L
.28797 .41987 L
.29968 .42427 L
.33974 .44365 L
.37952 .45994 L
.37981 .46002 L
.41987 .47302 L
.45994 .48155 L
.5 .46344 L
.50218 .45994 L
.502 .41987 L
.5 .41284 L
.48786 .37981 L
.46689 .33974 L
.45994 .32551 L
.44322 .29968 L
.41987 .2628 L
.41744 .25962 L
.38775 .21955 L
.37981 .2064 L
.35878 .17949 L
.33974 .1523 L
.3295 .13942 L
.29968 .10063 L
.29868 .09936 L
.26261 .05929 L
.25962 .05183 L
.22935 .01923 L
.01923 .01923 L
F
0 g
.01923 .2676 m
.05929 .29105 L
.07323 .29968 L
.09936 .31125 L
.13942 .33919 L
.14043 .33974 L
.17949 .36042 L
.21154 .37981 L
.21955 .38226 L
.25962 .40487 L
.28797 .41987 L
.29968 .42427 L
.33974 .44365 L
.37952 .45994 L
.37981 .46002 L
.41987 .47302 L
.45994 .48155 L
.5 .46344 L
.50218 .45994 L
.502 .41987 L
.5 .41284 L
.48786 .37981 L
.46689 .33974 L
.45994 .32551 L
.44322 .29968 L
.41987 .2628 L
.41744 .25962 L
.38775 .21955 L
.37981 .2064 L
.35878 .17949 L
.33974 .1523 L
.3295 .13942 L
.29968 .10063 L
.29868 .09936 L
.26261 .05929 L
.25962 .05183 L
.22935 .01923 L
s
.9 0 .1 r
.01923 .26269 m
.05929 .28673 L
.08081 .29968 L
.09936 .3075 L
.13942 .33468 L
.14888 .33974 L
.17949 .35537 L
.21955 .37874 L
.22163 .37981 L
.25962 .39888 L
.29968 .41885 L
.30143 .41987 L
.33974 .43627 L
.37981 .45203 L
.40987 .45994 L
.41987 .46219 L
.45994 .46453 L
.47155 .45994 L
.48967 .41987 L
.47751 .37981 L
.45994 .34236 L
.45869 .33974 L
.43566 .29968 L
.41987 .27253 L
.41071 .25962 L
.38251 .21955 L
.37981 .21487 L
.35316 .17949 L
.33974 .15968 L
.32403 .13942 L
.29968 .10699 L
.2938 .09936 L
.2604 .05929 L
.25962 .05714 L
.2258 .01923 L
.01923 .01923 L
F
0 g
.01923 .26269 m
.05929 .28673 L
.08081 .29968 L
.09936 .3075 L
.13942 .33468 L
.14888 .33974 L
.17949 .35537 L
.21955 .37874 L
.22163 .37981 L
.25962 .39888 L
.29968 .41885 L
.30143 .41987 L
.33974 .43627 L
.37981 .45203 L
.40987 .45994 L
.41987 .46219 L
.45994 .46453 L
.47155 .45994 L
.48967 .41987 L
.47751 .37981 L
.45994 .34236 L
.45869 .33974 L
.43566 .29968 L
.41987 .27253 L
.41071 .25962 L
.38251 .21955 L
.37981 .21487 L
.35316 .17949 L
.33974 .15968 L
.32403 .13942 L
.29968 .10699 L
.2938 .09936 L
.2604 .05929 L
.25962 .05714 L
.2258 .01923 L
s
1 0 0 r
.01923 .25873 m
.02538 .25962 L
.05929 .28258 L
.08846 .29968 L
.09936 .30414 L
.13942 .33026 L
.15767 .33974 L
.17949 .35054 L
.21955 .37377 L
.23195 .37981 L
.25962 .39294 L
.29968 .41269 L
.3149 .41987 L
.33974 .42868 L
.37981 .44333 L
.41987 .45339 L
.45994 .44312 L
.47379 .41987 L
.46635 .37981 L
.45994 .36307 L
.45021 .33974 L
.42806 .29968 L
.41987 .28428 L
.40395 .25962 L
.37981 .2231 L
.37717 .21955 L
.34777 .17949 L
.33974 .1673 L
.31872 .13942 L
.29968 .11348 L
.28902 .09936 L
.25962 .06242 L
.25739 .05929 L
.22269 .01923 L
.01923 .01923 L
F
0 g
.01923 .25873 m
.02538 .25962 L
.05929 .28258 L
.08846 .29968 L
.09936 .30414 L
.13942 .33026 L
.15767 .33974 L
.17949 .35054 L
.21955 .37377 L
.23195 .37981 L
.25962 .39294 L
.29968 .41269 L
.3149 .41987 L
.33974 .42868 L
.37981 .44333 L
.41987 .45339 L
.45994 .44312 L
.47379 .41987 L
.46635 .37981 L
.45994 .36307 L
.45021 .33974 L
.42806 .29968 L
.41987 .28428 L
.40395 .25962 L
.37981 .2231 L
.37717 .21955 L
.34777 .17949 L
.33974 .1673 L
.31872 .13942 L
.29968 .11348 L
.28902 .09936 L
.25962 .06242 L
.25739 .05929 L
.22269 .01923 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P000182000`400?l00000o`00003ooooooolQ
ooooo`00o`00000P0000007ooooo00000`00003oooooooooo`3ooooooacooooo0@000001ooooo`00
00<00000ooooooooool0oooooolLooooo`4000000Oooool0000300000?oooooooooo0?oooooo7?oo
ool10000007ooooo00000`00003oooooooooo`3ooooooacooooo0@000001ooooo`0000<00000oooo
ooooool0??ooool3o`000005ooooool0003o0000ooooool000000_ooool00ol0003oooooo`000003
ooooo`03o`000?oooooooooo00;ooooo00<00000ooooooooool0aoooool10000007ooooo00000`00
003oooooooooo`02ooooocX0o`000_l000001`3<03?o0000o`00002I06Ko000007l0Ool000000P1V
09T2o`0000<0<`3<00?o000001T0iP0I0>H00`0I0>H00`000000003o0000o`310000o`Gooooo0@00
0001ooooo`0000<00000ooooooooool00_oooolk0?l000;o000000/0c00co`000?l00000V@1Vo`00
001o07oo000006H0VOl00000C02co`00000303<0c003o`00000I0>H06@3V00<06@3V00<000000000
o`000?l0`0000?l5ooooo`4000000Oooool0000300000?oooooooooo00;ooooo?03o0002o`00000;
0<`0<ol0003o000009T0I_l00000O`1oo`00001V09Wo000004`0/ol000000`0c0<`00ol000006@3V
01T0iP0201T0iP03000000000?l0003o0<00003o1Oooool10000007ooooo00000`00003ooooooooo
o`02ooooocd0o`000_l000002`3<03?o0000o`00002I06Ko000007l0Ool00000IP2Io`00001<0;?o
000000<0<`3<00?o000001T0iP0I0>H00P0I0>H00`000000003o0000o`2o0000o`Gooooo0@000001
ooooo`0000<00000ooooooooool00_ooooln0?l000;o000000@0c00co`000?l00000V@1V0_l00000
1@1V09Wo000004`0/`1<0;?o000000<0<`3<00?o000001T0iP0I0>H00P0I0>H00`000000003o0000
o`2n0000o`Gooooo0@000001ooooo`0000<00000ooooooooool00_oooolo0?l000;o000000@0c00c
o`000?l00000V@1V0_l000001@1V09Wo000004`0/`1<0;?o000000<0<`3<00?o000001T0iP0I0>H0
0P0I0>H00`000000003o0000o`2m0000o`Gooooo0@000001ooooo`0000<00000ooooooooool00_oo
oolo0?l00004o`00003V01Wo00000<`0<`?o000000H0O`1oo`00001V09Wo000004`0/ol0000403<0
c003o`00000I0>H06@3V00806@3V00<000000000o`000?l0_0000?l5ooooo`4000000Oooool00003
00000?oooooooooo00;ooooo@03o00001?l00000iP0Io`00003<03<4o`00000506H0VOl00000C02c
04`0/ol00000100c0<`01Ol000006@3V01T0iP0I0>H000000;h0003o1Oooool10000007ooooo0000
0`00003oooooooooo`02oooood40o`0000Co00000>H06Ol00000c00c0_l00000101o07oo000006H0
VOl0000204`0/`05o`00000c0<`0<`3<03<0c?l00000100I0>H00`000000003o0000o`2k0000o`Go
oooo0@000001ooooo`0000<00000ooooooooool00_oooom20?l00003o`00003V01Wo000000Co0000
00<0IP2Io`00001<0;<00P1<0;<01Ol00000<`3<03<0c00c0<co000000@06@3V00<000000000o`00
0?l0^P000?l5ooooo`4000000Oooool0000300000?oooooooooo00;ooooo@`3o00000ol00000iP0I
o`000002o`00000407l0Ool00000IP2Io`0000<0C02c00Co000003<0c00c0<co00001@0I0>H00`00
0000003o0000o`2i0000o`Gooooo0@000001ooooo`0000<00000ooooooooool00_oooom40?l000Go
000000<0O`1oo`00001V09T00_l0000204`0/`;o000000<0<`3<o`00000I0>H0100I0>H00`000000
003o0000o`2h0000o`Gooooo0@000001ooooo`0000<00000ooooooooool00_oooom50?l000;o0000
00D0/`1<o`000?l00000O`1oo`00000206H0V@06o`00001<0;<0C02co`00000c0<co00001P0I0>H0
0`000000003o0000o`2g0000o`Gooooo0@000001ooooo`0000<00000ooooooooool00_oooom50?l0
00?o000000D0/`1<o`000?l00000O`1oo`00000206H0V@06o`00001<0;<0C02co`00000c0<co0000
1P0I0>H00`000000003o0000o`2f0000o`Gooooo0@000001ooooo`0000<00000ooooooooool00_oo
oom60?l000?o000000D0/`1<o`000?l00000O`1oo`00000206H0V@06o`00001<0;<0C02co`00000c
0<co00001P0I0>H00`000000003o0000o`2e0000o`Gooooo0@000001ooooo`0000<00000oooooooo
ool00_oooom70?l000?o000000D0/`1<o`000?l00000O`1oo`00000206H0V@03o`00001<0;?o0000
0080<`3<00?o000001T0iP0I0>H00`0I0>H00`000000003o0000o`2e0000o`Gooooo0@000001oooo
o`0000<00000ooooooooool00_oooom80?l000?o000000L0/`1<o`000?l00000O`1oo`00001V09Wo
00000080C02c00Co000003<0c00c0<co00001@0I0>H00`000000003o0000o`2d0000o`Gooooo0@00
0001ooooo`0000<00000ooooooooool00_oooom90?l000?o000000L0/`1<o`000?l00000O`1oo`00
001V09Wo00000080C02c00Co000003<0c00c0<co00001@0I0>H00`000000003o0000o`2c0000o`Go
oooo0@000001ooooo`0000<00000ooooooooool00_oooom:0?l000?o000000@0/`1<o`000?l00000
O`1o0_l0000204`0/`05o`00000c0<`0<`3<03<0c?l000001@0I0>H00`000000003o0000o`2b0000
o`Gooooo0@000001ooooo`0000<00000ooooooooool00_oooom;0?l000?o000000H0/`1<o`000?l0
003o000006H0VOl0000204`0/`05o`00000c0<`0<`3<03<0c?l00000100I0>H00`000000003o0000
o`2b0000o`Gooooo0@000001ooooo`0000<00000ooooooooool00_oooom<0?l000?o000000P0/`1<
o`000?l0003o000006H0VOl00000C02co`0000@0<`3<00?o000001T0iP0I0>H00P0I0>H00`000000
003o0000o`2a0000o`Gooooo0@000001ooooo`0000<00000ooooooooool00_oooom=0?l000?o0000
00D0/`1<o`000?l00000IP2Io`00000204`0/`03o`00000c0<`0<`3<0080<`3<00?o000001T0iP0I
0>H00P0I0>H00`000000003o0000o`2`0000o`Gooooo0@000001ooooo`0000<00000ooooooooool0
0_oooom>0?l000Co000000@0O`1oo`00001V09Wo00000P1<0;<00ol00000<`3<03<0c00203<0c003
o`00000I0>H06@3V00806@3V00<000000000o`000?l0[`000?l5ooooo`4000000Oooool000030000
0?oooooooooo00;oooooCP3o00000ol00000iP0Io`000003o`000080IP2I00Co000004`0/`1<0;?o
00000`0c0<`00ol000006@3V01T0iP0301T0iP03000000000?l0003o0:h0003o1Oooool10000007o
oooo00000`00003oooooooooo`02ooooodl0o`0000?o00000>H06Ol000000ol0000206H0V@04o`00
001<0;<0C02co`0000<0<`3<00?o000001T0iP0I0>H00`0I0>H00`000000003o0000o`2]0000o`Go
oooo0@000001ooooo`0000<00000ooooooooool00_oooom@0?l000;o000000@0c00co`000?l0003o
00000P1V09T01?l00000C02c04`0/ol0000303<0c003o`00000I0>H06@3V00<06@3V00<000000000
o`000?l0[0000?l5ooooo`4000000Oooool0000300000?oooooooooo00;oooooD@3o0006o`000080
IP2I00Co000004`0/`1<0;?o00000`0c0<`00ol000006@3V01T0iP0301T0iP03000000000?l0003o
0:/0003o1Oooool10000007ooooo00000`00003oooooooooo`02oooooe40o`0000?o00000>H06Ol0
00001?l0000206H0V@04o`00001<0;<0C02co`0000<0<`3<00?o000001T0iP0I0>H00`0I0>H00`00
0000003o0000o`2Z0000o`Gooooo0@000001ooooo`0000<00000ooooooooool00_oooomB0?l000;o
000000<0c00co`000?l000000_l0000206H0V@04o`00001<0;<0C02co`0000<0<`3<00?o000001T0
iP0I0>H00`0I0>H00`000000003o0000o`2Y0000o`Gooooo0@000001ooooo`0000<00000oooooooo
ool00_oooomC0?l000Co000000<0V@1Vo`000?l000000P1V09T01?l00000C02c04`0/ol0000203<0
c003o`00000I0>H06@3V00<06@3V00<000000000o`000?l0Z@000?l5ooooo`4000000Oooool00003
00000?oooooooooo00;oooooD`3o00000ol00000iP0Io`000002o`00000309T0I_l0003o00000080
IP2I00Co000004`0/`1<0;?o00000P0c0<`00ol000006@3V01T0iP0301T0iP03000000000?l0003o
0:P0003o1Oooool10000007ooooo00000`00003oooooooooo`02oooooe@0o`0000?o00000>H06Ol0
00000_l000000`2I06Ko0000o`00000206H0V@04o`00001<0;<0C02co`000080<`3<00?o000001T0
iP0I0>H00`0I0>H00`000000003o0000o`2W0000o`Gooooo0@000001ooooo`0000<00000oooooooo
ool00_oooomD0?l00007o`00003V01Wo0000o`00002c04co000009T0IP03o`00000506H0VOl00000
C02c04`0/ol000000P0c0<`00ol000006@3V01T0iP0201T0iP03000000000?l0003o0:L0003o1Ooo
ool10000007ooooo00000`00003oooooooooo`02oooooeD0o`0000co00000>H06Ol0003o00000;<0
C?l00000V@1Vo`00001o07oo000006H0VOl0000204`0/`04o`00000c0<`0<`3<o`0000@06@3V00<0
00000000o`000?l0YP000?l5ooooo`4000000Oooool0000300000?oooooooooo00;oooooEP3o0000
3?l00000iP0Io`000?l00000/`1<o`00002I06Ko000007l0Ool00000IP2Io`000080C02c00Co0000
03<0c00c0<co0000100I0>H00`000000003o0000o`2U0000o`Gooooo0@000001ooooo`0000<00000
ooooooooool00_oooomF0?l00006o`00003V01Wo00000<`0<ol00000/`1<0_l00000101o07oo0000
06H0VOl0000204`0/`05o`00000c0<`0<`3<03<0c?l000000`0I0>H00`000000003o0000o`2U0000
o`Gooooo0@000001ooooo`0000<00000ooooooooool00_oooomG0?l00004o`00003V01Wo00000<`0
<`;o000000H0V@1Vo`00001o07oo000006H0VOl0000204`0/`04o`00000c0<`0<`3<o`0000@06@3V
00<000000000o`000?l0Y0000?l5ooooo`4000000Oooool0000300000?oooooooooo00;oooooF03o
00001?l00000iP0Io`00003<03<2o`00000809T0I_l00000O`1oo`00001V09Wo000004`0/ol00003
03<0c003o`00000I0>H06@3V00806@3V00<000000000o`000?l0X`000?l5ooooo`4000000Oooool0
000300000?oooooooooo00;oooooF@3o00002Ol00000iP0Io`000?l00000/`1<o`00002I06Ko0000
07l0O`02o`000080C02c00Go000003<0c00c0<`0<`3<o`00000401T0iP03000000000?l0003o0:80
003o1Oooool10000007ooooo00000`00003oooooooooo`02oooooeT0o`0000?o00000>H06@3V01T0
0ol000001P2I06Ko000007l0Ool00000IP2Io`000080C02c00Go000003<0c00c0<`0<`3<o`000004
01T0iP03000000000?l0003o0:40003o1Oooool10000007ooooo00000`00003oooooooooo`02oooo
oeX0o`0000Co00000>H06Ol00000c00c0_l00000202I06Ko000007l0Ool00000IP2Io`00001<0;?o
0000100c0<`00ol000006@3V01T0iP0201T0iP03000000000?l0003o0:00003o1Oooool10000007o
oooo00000`00003oooooooooo`02oooooe/0o`0000Co00000>H06Ol00000c00c0_l000001`2I06Ko
000007l0Ool00000IP2Io`00001<0;<00_l0000203<0c003o`00000I0>H06@3V00<06@3V00<00000
0000o`000?l0W`000?l5ooooo`4000000Oooool0000300000?oooooooooo00;oooooG03o00001Ol0
0000iP0Io`000?l00000/`1<00;o000000@0O`1oo`00001V09Wo00000`1<0;<01?l00000<`3<03<0
c?l0000501T0iP03000000000?l0003o09h0003o1Oooool10000007ooooo00000`00003ooooooooo
o`02oooooe`0o`0000Co00000>H06Ol00000c00c0_l000001P2I06Ko000007l0Ool00000IP2Io`00
00<0C02c00Co000003<0c00c0<co00001@0I0>H00`000000003o0000o`2M0000o`Gooooo0@000001
ooooo`0000<00000ooooooooool00_oooomM0?l00004o`00003V01Wo00000<`0<`;o000000D0V@1V
o`00001o07oo000006H0V@02o`000080C02c00Co000003<0c00c0<co00001@0I0>H00`000000003o
0000o`2L0000o`Gooooo0@000001ooooo`0000<00000ooooooooool00_oooomN0?l00004o`00003V
01Wo00000<`0<`;o000000<0V@1Vo`00001o07l00_l000001@1V09Wo000004`0/`1<0;?o00000080
<`3<00?o000001T0iP0I0>H00`0I0>H00`000000003o0000o`2K0000o`Gooooo0@000001ooooo`00
00<00000ooooooooool00_oooomN0?l0000=o`00003V01Wo00000<`0<ol00000/`1<o`00002I06Ko
000007l0Ool00000IP2Io`00000204`0/`04o`00000c0<`0<`3<o`0000D06@3V00<000000000o`00
0?l0V`000?l5ooooo`4000000Oooool0000300000?oooooooooo00;oooooG`3o00003Ol00000iP0I
o`00003<03?o00000;<0C?l00000V@1Vo`00001o07oo000006H0VOl000000P1<0;<01?l00000<`3<
03<0c?l0000501T0iP03000000000?l0003o09X0003o1Oooool10000007ooooo00000`00003ooooo
ooooo`02ooooof00o`0000go00000>H06Ol00000c00co`00002c04co000009T0I_l00000O`1oo`00
001V09Wo00000080C02c00Co000003<0c00c0<co00001@0I0>H00`000000003o0000o`2I0000o`Go
oooo0@000001ooooo`0000<00000ooooooooool00_oooomQ0?l00006o`00003V01Wo00000<`0<ol0
0000/`1<0_l000001`1o07oo000006H0V@1V09Wo000004`0/ol000000P0c0<`00ol000006@3V01T0
iP0401T0iP03000000000?l0003o09P0003o1Oooool10000007ooooo00000`00003oooooooooo`02
ooooof40o`0000?o00000>H06@3V01T00_l000020;<0C0;o000000@0O`1oo`00001V09Wo00000P1<
0;<01?l00000<`3<03<0c?l0000601T0iP03000000000?l0003o09L0003o1Oooool10000007ooooo
00000`00003oooooooooo`02ooooof80o`0000Ko00000>H06Ol00000c00co`00002c04`2o`000080
O`1o00Go000006H0VOl00000C02co`00000203<0c003o`00000I0>H06@3V00D06@3V00<000000000
o`000?l0UP000?l5ooooo`4000000Oooool0000300000?oooooooooo00;oooooH`3o00001_l00000
iP0Io`00003<03?o00000;<0C0;o000000L0O`1oo`00001V09T0IP2Io`00001<0;?o00000080<`3<
00?o000001T0iP0I0>H01@0I0>H00`000000003o0000o`2E0000o`Gooooo0@000001ooooo`0000<0
0000ooooooooool00_oooomT0?l00004o`00003V01Wo00000<`0<`;o000000@0V@1Vo`00001o07oo
00000P1V09T00ol00000C02co`00000203<0c003o`00000I0>H06@3V00D06@3V00<000000000o`00
0?l0U0000?l5ooooo`4000000Oooool0000300000?oooooooooo00;oooooI03o00000ol00000iP0I
0>H06@02o`0000030;<0C?l0003o00000080O`1o00Go000006H0VOl00000C02co`00000303<0c003
o`00000I0>H06@3V00D06@3V00<000000000o`000?l0T`000?l5ooooo`4000000Oooool000030000
0?oooooooooo00;oooooI@3o00000ol00000iP0I0>H06@03o`00000409T0I_l00000O`1oo`000080
IP2I00Co000004`0/ol0003o00000P0c0<`00ol000006@3V01T0iP0501T0iP03000000000?l0003o
0980003o1Oooool10000007ooooo00000`00003oooooooooo`02ooooofH0o`0000?o00000>H06Ol0
00000_l000001@2I06Ko000007l0O`1o07oo00000080IP2I00Co000004`0/`1<0;?o00000P0c0<`0
0ol000006@3V01T0iP0401T0iP03000000000?l0003o0980003o1Oooool10000007ooooo00000`00
003oooooooooo`02ooooofL0o`000_l000001@3<03?o0000o`00002I06Ko00000080O`1o00Co0000
06H0V@1V09Wo00000P1<0;<01?l00000<`3<03<0c?l0000501T0iP03000000000?l0003o0980003o
1Oooool10000007ooooo00000`00003oooooooooo`02ooooofP0o`0000Ko00000<`0<ol0003o0000
09T0I_l0000207l0O`04o`00001V09T0IP2Io`000080C02c00Co000003<0c00c0<co00001@0I0>H0
0`000000003o0000o`2B0000o`Gooooo0@000001ooooo`0000<00000ooooooooool00_oooomX0?l0
00;o000000D0c00co`000?l00000V@1Vo`00000207l0O`04o`00001V09T0IP2Io`000080C02c00Co
000003<0c00c0<co00001@0I0>H00`000000003o0000o`2A0000o`Gooooo0@000001ooooo`0000<0
0000ooooooooool00_oooomY0?l000;o000000D0c00co`000?l00000V@1Vo`00000207l0O`04o`00
001V09T0IP2Io`000080C02c00Co000003<0c00c0<co00001@0I0>H00`000000003o0000o`2@0000
o`Gooooo0@000001ooooo`0000<00000ooooooooool00_oooomZ0?l000;o000000D0c00co`000?l0
0000V@1Vo`00000207l0O`03o`00001V09Wo000000<0C02c00Co000003<0c00c0<co00001@0I0>H0
0`000000003o0000o`2?0000o`Gooooo0@000001ooooo`0000<00000ooooooooool00_oooomZ0?l0
00;o000000P0c00co`00002c04co000009T0I_l00000O`1oo`000080IP2I00Co000004`0/`1<0;?o
00000P0c0<`00ol000006@3V01T0iP0401T0iP03000000000?l0003o08h0003o1Oooool10000007o
oooo00000`00003oooooooooo`02ooooof/0o`000_l00000203<03?o00000;<0C?l00000V@1Vo`00
001o07oo00000P1V09T01?l00000C02c04`0/ol0000203<0c003o`00000I0>H06@3V00@06@3V00<0
00000000o`000?l0S@000?l5ooooo`4000000Oooool0000300000?oooooooooo00;oooooJ`3o0000
3Ol00000iP0Io`00003<03?o00000;<0C?l00000V@1Vo`00001o07oo000006H0VOl000000`1<0;<0
1?l00000<`3<03<0c?l0000601T0iP03000000000?l0003o08`0003o1Oooool10000007ooooo0000
0`00003oooooooooo`02ooooof`0o`000_l00000103<03?o00000;<0C02c04`2o`000080O`1o00?o
000006H0VOl000000P1<0;<01Ol00000<`3<03<0c00c0<co000000H06@3V00<000000000o`000?l0
R`000?l5ooooo`4000000Oooool0000300000?oooooooooo00;oooooK@3o0002o`0000040<`0<ol0
0000/`1<0;<0C0;o000000@0O`1oo`00001V09Wo00000`1<0;<01Ol00000<`3<03<0c00c0<co0000
00H06@3V00<000000000o`000?l0RP000?l5ooooo`4000000Oooool0000300000?oooooooooo00;o
ooooK@3o00003Ol00000iP0Io`00003<03?o00000;<0C?l00000V@1Vo`00001o07oo000006H0VOl0
00000`1<0;<01Ol00000<`3<03<0c00c0<co000000H06@3V00<000000000o`000?l0R@000?l5oooo
o`4000000Oooool0000300000?oooooooooo00;ooooo1?l0001Z0?l0000=o`00003V01Wo00000<`0
<ol00000/`1<o`00002I06Ko000007l0Ool00000IP2Io`00000304`0/`;o00000P0c0<`00ol00000
6@3V01T0iP0401T0iP03000000000?l0003o08P0003o1Oooool10000007ooooo00000`00003ooooo
ooooo`02ooooo`;o00000P3V01T00ol00000o`000?l0001W0?l00003o`00003V01Wo00000080c00c
0_l00000102I06Ko000007l0Ool0000206H0V@05o`00001<0;<0C02c04`0/ol000000P0c0<`00ol0
00006@3V01T0iP0401T0iP03000000000?l0003o08P0003o1Oooool10000007ooooo00000`00003o
ooooooooo`02ooooo`Co000000<0iP0Io`000?l00000J03o00002ol00000iP0Io`00003<03?o0000
0;<0C?l00000V@1Vo`00001o07oo00000080IP2I00Go000004`0/`1<0;<0C02co`00000203<0c003
o`00000I0>H06@3V00@06@3V00<000000000o`000?l0Q`000?l5ooooo`4000000Oooool000030000
0?oooooooooo00;ooooo0P2c04`3o`000080iP0I00?o00000?l0003o0000IP3o00002ol00000iP0I
o`00003<03?o00000;<0C?l00000V@1Vo`00001o07oo00000080IP2I00Co000004`0/`1<0;?o0000
0`0c0<`00ol000006@3V01T0iP0301T0iP03000000000?l0003o08L0003o1Oooool10000007ooooo
00000`00003oooooooooo`02ooooo`;o00000P2c04`3o`0000030>H06Ol00000o`0006L0o`0000Co
00000>H06Ol00000c00c0_l000001@2I06Ko000007l0O`1o07oo00000080IP2I00Co000004`0/`1<
0;?o00000`0c0<`00ol000006@3V01T0iP0301T0iP03000000000?l0003o08H0003o1Oooool10000
007ooooo00000`00003oooooooooo`02ooooo`Co000000<0/`1<o`000?l000001?l0001V0?l00009
o`00003V01Wo00000<`0<ol00000/`1<o`00002I06Ko00000080O`1o00Co000006H0V@1V09Wo0000
0P1<0;<01?l00000<`3<03<0c?l0000601T0iP03000000000?l0003o08D0003o1Oooool10000007o
oooo00000`00003oooooooooo`02ooooo`80O`1o00Go000009T0I_l0003o00000;<0C003o`000003
0>H06Ol00000o`0006D0o`0000_o00000>H06Ol00000c00co`00002c04co000009T0I_l00000O`1o
o`00000206H0V@04o`00001<0;<0C02co`0000<0<`3<00?o000001T0iP0I0>H0100I0>H00`000000
003o0000o`240000o`Gooooo0@000001ooooo`0000<00000ooooooooool00_ooool2o`00000407l0
Ool0003o000009T0IP;o000000<0/`1<o`000?l000000ol0001U0?l00004o`00003V01Wo00000<`0
<`;o000000D0V@1Vo`00001o07l0O`1oo`00000206H0V@04o`00001<0;<0C02co`0000<0<`3<00?o
000001T0iP0I0>H0100I0>H00`000000003o0000o`230000o`Gooooo0@000001ooooo`0000<00000
ooooooooool00_ooool3o`000080O`1o0_l000000`2I06Ko0000o`000005o`0006@0o`0000Wo0000
0>H06Ol00000c00co`00002c04co000009T0I_l000000P1o07l00ol00000IP2Io`00000204`0/`05
o`00000c0<`0<`3<03<0c?l000001P0I0>H00`000000003o0000o`230000o`Gooooo0@000001oooo
o`0000<00000ooooooooool00_ooool204`0/`?o00000P1o07l00ol00000V@1V09T0IP07o`0006<0
o`0000Wo00000>H06Ol00000c00co`00002c04co000009T0I_l000000P1o07l00ol00000IP2Io`00
000204`0/`05o`00000c0<`0<`3<03<0c?l000001P0I0>H00`000000003o0000o`220000o`Gooooo
0@000001ooooo`0000<00000ooooooooool00_ooool00ol00000C02c04`0/`04o`00000307l0Ool0
003o00000080V@1V00?o00000;<0C?l000001?l0001Q0?l00009o`00003V01Wo00000<`0<ol00000
/`1<o`00002I06Ko00000080O`1o00?o000006H0VOl000000`1<0;<01Ol00000<`3<03<0c00c0<co
000000H06@3V00<000000000o`000?l0P@000?l5ooooo`4000000Oooool0000300000?oooooooooo
00;ooooo00<0<`3<o`00001<0;<00P1<0;<00ol00000IP2Io`00000207l0O`03o`00002I06Ko0000
0080/`1<00Go00000<`0<ol00000iP0Io`00001P0?l0000:o`00003V01T0iP0Io`00003<03?o0000
0;<0C?l00000V@1Vo`000080O`1o0_l0000304`0/`03o`00000c0<`0<`3<0080<`3<00?o000001T0
iP0I0>H0100I0>H00`000000003o0000o`200000o`Gooooo0@000001ooooo`0000<00000oooooooo
ool00_ooool203<0c0;o00000P1<0;<4o`00000307l0Ool0003o000000;o000000<0/`1<o`000?l0
00001Ol0001N0?l00009o`00003V01T0iP0Io`00003<03?o00000;<0C?l00000V@1V00?o000000<0
IP2Io`00001<0;<00P1<0;<00ol00000<`3<03<0c00203<0c003o`00000I0>H06@3V00@06@3V00<0
00000000o`000?l0O`000?l5ooooo`4000000Oooool0000300000?oooooooooo00;ooooo0_l00002
03<0c0;o00000P1<0;<01?l00000IP2Io`000?l0000207l0O`_o0000G03o00001_l00000iP0I0>H0
6Ol00000c00co`000080/`1<00Ko000009T0I_l0003o000006H0VOl0000404`0/`05o`00000c0<`0
<`3<03<0c?l000001P0I0>H00`000000003o0000o`1o0000o`Gooooo0@000001ooooo`0000<00000
ooooooooool00_ooool201T0iP05o`00000c0<`0<`3<03<0c?l000000P1<0;<2o`00000306H0VOl0
003o00000080O`1o1?l000000`2c04co0000o`000004o`0005/0o`0000Ko00000>H06@3V01Wo0000
0<`0<ol000020;<0C006o`00002I06Ko0000o`00001V09Wo0000101<0;<01Ol00000<`3<03<0c00c
0<co000000H06@3V00<000000000o`000?l0OP000?l5ooooo`4000000Oooool0000300000?oooooo
oooo00;ooooo0`0I0>H2o`000080<`3<0_l0000204`0/`03o`00001V09T0IP2I00;o00000P1o07l0
0ol00000V@1Vo`000005o`0000030>H06Ol00000o`0005X0o`0000?o00000>H06Ol000000P3<03<0
0ol00000/`1<0;<0C002o`00000407l0Ool00000IP2Io`0000@0C02c00Go000003<0c00c0<`0<`3<
o`00000601T0iP03000000000?l0003o07d0003o1Oooool10000007ooooo00000`00003ooooooooo
o`02ooooo`D06@3V00Co000003<0c00c0<`0<`3<0_l000000`1<0;?o0000o`00000206H0V@;o0000
00<0O`1oo`000?l000000P2I06H7o`0005T0o`0000Co00000>H06@3V01Wo00000P3<03<02Ol00000
/`1<o`00002I06Ko000007l0Ool00000IP2Io`00000404`0/`05o`00000c0<`0<`3<03<0c?l00000
1@0I0>H00`000000003o0000o`1m0000o`Gooooo0@000001ooooo`0000<00000ooooooooool00_oo
ool2000000@06@3V0_l0000303<0c003o`00001<0;<0C02c00;o00000P1V09T00ol00000O`1o07l0
O`02o`000080V@1V1?l000000`3V01Wo0000o`00001H0?l00003o`00003V01Wo00000080c00c00?o
00000;<0C02c04`00_l000001@1o07oo000006H0V@1V09Wo000000<0C02c00Go000003<0c00c0<`0
<`3<o`00000601T0iP03000000000?l0003o07`0003o1Oooool10000007ooooo00000`00003ooooo
ooooo`02ooooo`80003o00<0000001T0iP0I0>H00`0I0>H01?l00000<`3<03<0c00c0<`2o`000080
C02c0_l000000`1V09Wo0000o`00000207l0O`;o000000<0V@1Vo`000?l000000ol000000`3V01Wo
00000?l0001G0?l00003o`00003V01Wo00000080c00c00Oo00000;<0C?l00000V@1Vo`00001o07oo
00000080IP2I00Go000004`0/`1<0;<0C02co`00000303<0c003o`00000I0>H06@3V00@06@3V00<0
00000000o`000?l0N`000?l5ooooo`4000000Oooool0000300000?oooooooooo00;ooooo0`000?l2
000000@06@3V0_l0000303<0c0;o00000P1<0;<00ol00000IP2I06H0V@02o`000080O`1o00?o0000
09T0IP2I06H01?l000000`3V01Wo0000o`00001F0?l00004o`00003V01T0iP0Io`000080c00c00Oo
00000;<0C?l00000V@1Vo`00001o07oo00000080IP2I00Co000004`0/`1<0;?o0000100c0<`00ol0
00006@3V01T0iP0401T0iP03000000000?l0003o07X0003o1Oooool10000007ooooo00000`00003o
ooooooooo`02ooooo`D0003o00<0000001T0iP0I0>H00`0I0>H00ol00000<`3<03<0c00203<0c0;o
000000<0C02co`000?l000000P1V09T2o`00000607l0Ool0003o000009T0I_l00000/`1<0ol00000
0`3V01Wo0000o`00001E0?l00003o`00003V01Wo00000080c00c00Oo00000;<0C?l00000V@1Vo`00
001o07oo000000<0IP2I00Co000004`0/`1<0;?o00000`0c0<`00ol000006@3V01T0iP0501T0iP03
000000000?l0003o07T0003o1Oooool10000007ooooo00000`00003oooooooooo`02ooooo`H0003o
0P00000401T0iP;o0000100c0<`00ol00000C02c04`0/`02o`000080IP2I0_l000000`1o07oo0000
09T0IP05o`000080iP0I0_l0001C0?l00004o`00003V01T0iP0Io`000080c00c00Oo00000;<0C?l0
0000V@1Vo`00001o07oo000000<0IP2I00?o000004`0/ol00000100c0<`00ol000006@3V01T0iP05
01T0iP03000000000?l0003o07P0003o1Oooool10000007ooooo00000`00003oooooooooo`02oooo
o`P0003o00<0000001T0iP0I0>H00`0I0>H2o`0000<0<`3<0_l0000204`0/`07o`00001V09T0IP2I
06H0VOl00000O`1oo`00000209T0IP03o`00002c04co000000;o00000P3V01T00ol00000o`000?l0
001A0?l00003o`00003V01Wo00000080c00c00Go00000;<0C?l00000V@1Vo`00000207l0O`06o`00
001V09T0IP2Io`00001<0;?o00001@0c0<`00ol000006@3V01T0iP0501T0iP03000000000?l0003o
07L0003o1Oooool10000007ooooo00000`00003oooooooooo`02ooooo`T0003o0P00000501T0iP;o
00000`0c0<`00ol00000C02c04`0/`02o`000080IP2I1?l000000`2I06Ko00000;<0C004o`000003
0>H06Ol0003o00000580o`0000?o00000>H06Ol000000P3<03<01Ol00000/`1<o`00002I06Ko0000
0080O`1o00Ko000006H0V@1V09Wo000004`0/ol0000503<0c003o`00000I0>H06@3V00D06@3V00<0
00000000o`000?l0MP000?l5ooooo`4000000Oooool0000300000?oooooooooo00;ooooo2`000?l0
0`0000006@3V01T0iP0401T0iP05o`00000c0<`0<`3<03<0c?l000000`1<0;<01_l00000IP2I06H0
V@1V09Wo000007l0O`?o00000P2c04`4o`0000030>H06Ol0003o00000500o`0000[o00000>H06@3V
01Wo00000<`0<ol00000/`1<o`00002I06Ko00000`1o07l01Ol00000IP2Io`00001<0;?o000000D0
<`3<00?o000001T0iP0I0>H01@0I0>H00`000000003o0000o`1f0000o`Gooooo0@000001ooooo`00
00<00000ooooooooool00_ooool<0000o`8000001@0I0>H2o`000080<`3<0_l0000204`0/`;o0000
0P1V09T2o`00000407l0Ool0003o0000o`000080/`1<1?l000000`3V01Wo0000o`00001?0?l00003
o`00003V01Wo00000080c00c00Go00000;<0C?l00000V@1Vo`00000307l0O`05o`00001V09Wo0000
04`0/ol000001@0c0<`00ol000006@3V01T0iP0501T0iP03000000000?l0003o07D0003o1Oooool1
0000007ooooo00000`00003oooooooooo`02ooooo`h0003o00<0000001T0iP0I0>H0100I0>H01?l0
0000<`3<03<0c00c0<`2o`000080C02c0_l0000206H0V@03o`00001o07oo000000?o00000P2c04`0
0ol00000c00co`0000020>H06@;o0000C@3o00002?l00000iP0I0>H06Ol00000c00co`00002c04co
00000P2I06H01_l00000O`1o07l0Ool00000IP2Io`000080C02c00?o000003<0c00c0<`00`0c0<`0
0ol000006@3V01T0iP0501T0iP03000000000?l0003o07@0003o1Oooool10000007ooooo00000`00
003oooooooooo`02ooooo`l0003o00<0000001T0iP0I0>H0100I0>H00ol00000<`3<03<0c00203<0
c005o`00001<0;<0C02c04`0/ol000000P1V09T00ol00000O`1o07l0O`04o`0000030;<0C?l0003o
000000;o00000P3V01T2o`0004`0o`0000?o00000>H06Ol000000P3<03<00ol00000/`1<o`000002
09T0IP06o`00001o07l0O`1oo`00001V09Wo00000P1<0;<00ol00000<`3<03<0c00203<0c003o`00
000I0>H06@3V00D06@3V00<000000000o`000?l0M0000?l5ooooo`4000000Oooool0000300000?oo
oooooooo00;ooooo40000?l2000000D06@3V0_l0000303<0c0;o00000P1<0;<2o`00000306H0VOl0
003o00000080O`1o0ol000020;<0C0Co00000P3V01T00ol00000o`000?l000190?l00008o`00003V
01T0iP0Io`00003<03?o00000;<0C?l0000209T0IP04o`00001o07l0O`1oo`000080IP2I00Co0000
04`0/`1<0;?o0000100c0<`00ol000006@3V01T0iP0501T0iP03000000000?l0003o07<0003o1Ooo
ool10000007ooooo00000`00003oooooooooo`02oooooa80003o00<0000001T0iP0I0>H0100I0>H0
0ol00000<`3<03<0c00203<0c0;o00000P1<0;<00ol00000IP2I06H0V@02o`000080O`1o0ol00002
0;<0C0Co000000<0iP0Io`000?l00000B@3o00001?l00000iP0I0>H06Ol000020<`0<`03o`00002c
04co00000080V@1V00Ko000007l0O`1o07oo000006H0VOl0000204`0/`03o`00000c0<`0<`3<0080
<`3<00?o000001T0iP0I0>H01@0I0>H00`000000003o0000o`1c0000o`Gooooo0@000001ooooo`00
00<00000ooooooooool00_oooolC0000o`8000001@0I0>H2o`0000@0<`3<00?o000004`0/`1<0;<0
0_l0000206H0V@;o000000<0O`1oo`000?l000000_l000020;<0C005o`00003<03?o0000o`00003V
01T00_l000180?l00008o`00003V01T0iP0Io`00003<03?o00000;<0C?l0000309T0IP03o`00001o
07oo00000080IP2I00Co000004`0/`1<0;?o0000100c0<`00ol000006@3V01T0iP0501T0iP030000
00000?l0003o0780003o1Oooool10000007ooooo00000`00003oooooooooo`02oooooaD0003o00<0
000001T0iP0I0>H0100I0>H2o`0000<0<`3<0_l0000204`0/`;o00000P1V09T00ol00000O`1o07l0
O`04o`0000040;<0C?l0003o00000<`0<`;o000000<0iP0Io`00003o0000AP3o00001?l00000iP0I
0>H06Ol000020<`0<`03o`00002c04co00000080V@1V00Ko000007l0O`1o07oo000006H0VOl00003
04`0/`03o`00000c0<`0<`3<0080<`3<00?o000001T0iP0I0>H01@0I0>H00`000000003o0000o`1a
0000o`Gooooo0@000001ooooo`0000<00000ooooooooool00_oooolF0000o`030000000I0>H06@3V
00D06@3V00?o000003<0c00c0<`00P0c0<`2o`000080C02c0_l000000`1V09Wo0000o`00000207l0
O`03o`00002I06Ko00000080/`1<00?o00000<`0<`3<03<01?l000150?l00004o`00003V01T0iP0I
o`000080c00c00?o00000;<0C?l000000`2I06H00ol00000O`1oo`00000206H0V@05o`00001<0;<0
C02c04`0/ol000000`0c0<`00ol000006@3V01T0iP0501T0iP03000000000?l0003o0740003o1Ooo
ool10000007ooooo00000`00003oooooooooo`02oooooaL0003o0P00000601T0iP;o0000100c0<`2
o`000080C02c00?o000006H0V@1V09T00_l000000`1o07oo000009T0IP02o`0000030;<0C?l0003o
00000080c00c1?l000140?l00004o`00003V01T0iP0Io`000080c00c00?o00000;<0C?l000000P2I
06H01?l00000O`1o07l0Ool0000206H0V@05o`00001<0;<0C02c04`0/ol000000`0c0<`00ol00000
6@3V01T0iP0501T0iP03000000000?l0003o0700003o1Oooool10000007ooooo00000`00003ooooo
ooooo`02oooooaT0003o00<0000001T0iP0I0>H01@0I0>H00ol00000<`3<03<0c00303<0c003o`00
001<0;<0C02c00;o00000P1V09T00ol00000O`1oo`00000209T0IP04o`00002c04`0/`1<o`0000<0
c00c00?o00000>H06Ol00000@`3o00001?l00000iP0I0>H06Ol000020<`0<`03o`00002c04co0000
0080V@1V00Co000007l0O`1o07oo00000P1V09T01Ol00000C02c04`0/`1<0;?o000000<0<`3<00?o
000001T0iP0I0>H01P0I0>H00`000000003o0000o`1_0000o`Gooooo0@000001ooooo`0000<00000
ooooooooool00_oooolJ0000o`8000001P0I0>H3o`0000<0<`3<0_l0000204`0/`05o`00001V09Wo
0000o`00001o07l02ol000000`3V01Wo0000o`0000110?l00005o`00003V01T0iP0I0>H06Ol00000
0P3<03<00ol00000/`1<o`00000209T0IP04o`00001o07l0O`1oo`000080IP2I00Go000004`0/`1<
0;<0C02co`00000303<0c003o`00000I0>H06@3V00H06@3V00<000000000o`000?l0KP000?l5oooo
o`4000000Oooool0000300000?oooooooooo00;ooooo70000?l2000000L06@3V00?o000003<0c00c
0<`00P0c0<`01?l00000C02c04`0/ol0000206H0V@?o000000D0O`1oo`000?l0003o000009T0IP06
o`0000040>H06Ol0003o0000o`0003h0o`0000Go00000>H06@3V01T0iP0Io`0000020<`0<`06o`00
002c04`0/`1<o`00002I06Ko00000P1o07l01?l00000IP2I06H0VOl0000304`0/`05o`00000c0<`0
<`3<03<0c?l00000200I0>H00`000000003o0000o`1^0000o`Gooooo0@000001ooooo`0000<00000
ooooooooool00_oooolN0000o`8000001P0I0>H2o`0000<0<`3<0_l000000`1<0;?o0000o`000003
06H0V@;o00000P1o07l3o`000080V@1V1Ol00000103V01Wo0000o`000?l0000k0?l00005o`00003V
01T0iP0I0>H06Ol000000`3<03<00ol00000/`1<o`00000209T0IP04o`00001o07l0O`1oo`000080
IP2I00Go000004`0/`1<0;<0C02co`00000303<0c003o`00000I0>H06@3V00H06@3V00<000000000
o`000?l0K@000?l5ooooo`4000000Oooool0000300000?oooooooooo00;ooooo80000?l00`000000
6@3V01T0iP0501T0iP;o00000`0c0<`00ol00000C02c04`0/`03o`000080IP2I0_l0000307l0O`;o
000000<0V@1Vo`00002c04`01?l000020>H06@;o0000>@3o00000ol00000iP0I0>H06@020>H06@04
o`00003<03<0c00co`000080/`1<00?o000009T0I_l000000P1o07l01Ol00000IP2I06H0V@1V09Wo
000000<0C02c00Go000003<0c00c0<`0<`3<o`00000801T0iP03000000000?l0003o06`0003o1Ooo
ool10000007ooooo00000`00003oooooooooo`02ooooob40003o0P00000701T0iP04o`00000c0<`0
<`3<03<0c0;o00000`1<0;<2o`000080IP2I0ol0000207l0O`07o`00002I06Ko0000o`00002c04co
00000<`0<`02o`000080iP0I0_l0000h0?l00005o`00003V01T0iP0I0>H06Ol000000P3<03<01?l0
0000/`1<0;<0C?l0000209T0IP04o`00001o07l0O`1oo`0000<0IP2I00Co000004`0/`1<0;?o0000
100c0<`00ol000006@3V01T0iP0601T0iP03000000000?l0003o06/0003o1Oooool10000007ooooo
00000`00003oooooooooo`02ooooob<0003o0P00000601T0iP;o00000`0c0<`2o`0000<0C02c0_l0
000306H0V@;o000000H0O`1oo`000?l00000V@1Vo`00002c04`2o`0000030<`0<ol0003o00000080
iP0I0_l0000f0?l00005o`00003V01T0iP0I0>H06Ol000000`3<03<00ol00000/`1<o`00000209T0
IP04o`00001o07l0O`1oo`0000<0IP2I00Go000004`0/`1<0;<0C02co`00000403<0c003o`00000I
0>H06@3V00H06@3V00<000000000o`000?l0JP000?l5ooooo`4000000Oooool0000300000?oooooo
oooo00;ooooo9@000?l00`0000006@3V01T0iP0501T0iP03o`00000c0<`0<`3<0080<`3<00?o0000
04`0/`1<0;<00P1<0;<3o`000080IP2I00?o000007l0O`1o07l01?l00000102c04co00000<`0<`3<
03<2o`000080iP0I0_l0000d0?l00003o`00003V01T0iP0I0080iP0I00Co00000<`0<`3<03?o0000
0P2c04`01?l00000V@1V09T0I_l0000207l0O`05o`00001V09T0IP2I06H0VOl000000`1<0;<00ol0
0000<`3<03<0c00203<0c003o`00000I0>H06@3V00H06@3V00<000000000o`000?l0J@000?l5oooo
o`4000000Oooool0000300000?oooooooooo00;ooooo9P000?l2000000H06@3V0_l0000303<0c0;o
00001@1<0;<2o`00000306H0VOl0003o00000080O`1o00Co000009T0I_l00000/`1<0_l000020<`0
<`;o00000P3V01T2o`000380o`0000?o00000>H06@3V01T00P3V01T01?l00000c00c0<`0<ol00002
0;<0C005o`00002I06H0V@1V09T0I_l000000P1o07l01?l00000IP2I06H0VOl0000304`0/`03o`00
000c0<`0<`3<00<0<`3<00?o000001T0iP0I0>H01@0I0>H00`000000003o0000o`1Y0000o`Gooooo
0@000001ooooo`0000<00000ooooooooool00_oooolX0000o`030000000I0>H06@3V00D06@3V0_l0
000303<0c0;o00001@1<0;<01?l00000IP2I06H0VOl0000207l0O`?o00000P2c04`2o`000080c00c
0_l000020>H06@;o0000<03o00000ol00000iP0I0>H06@020>H06@05o`00003<03<0c00c0<`0<ol0
00000P2c04`01?l00000V@1V09T0I_l0000207l0O`05o`00001V09T0IP2I06H0VOl000000`1<0;<0
0ol00000<`3<03<0c00303<0c003o`00000I0>H06@3V00D06@3V00<000000000o`000?l0J0000?l5
ooooo`4000000Oooool0000300000?oooooooooo00;ooooo:@000?l2000000L06@3V0_l0000303<0
c003o`00001<0;<0C02c00<0C02c00?o000006H0V@1V09T00_l0000207l0O`?o00000P2c04`2o`00
0080c00c0_l000020>H06@;o0000;`3o00001Ol00000iP0I0>H06@3V01Wo000000<0c00c00Co0000
0;<0C02c04co00000`2I06H01?l00000O`1o07l0Ool0000306H0V@04o`00001<0;<0C02co`0000D0
<`3<00?o000001T0iP0I0>H01P0I0>H00`000000003o0000o`1W0000o`Gooooo0@000001ooooo`00
00<00000ooooooooool00_ooool[0000o`030000000I0>H06@3V00H06@3V0_l0000203<0c0;o0000
101<0;<01Ol00000IP2I06H0V@1V09Wo00000080O`1o00?o000009T0I_l000000_l000000`2c04co
0000o`0000020<`0<`;o00000P3V01T2o`0002d0o`0000?o00000>H06@3V01T00P3V01T01?l00000
c00c0<`0<ol000020;<0C005o`00002I06H0V@1V09T0I_l000000P1o07l01Ol00000IP2I06H0V@1V
09Wo000000<0C02c00?o000003<0c00c0<`00`0c0<`00ol000006@3V01T0iP0601T0iP0300000000
0?l0003o06H0003o1Oooool10000007ooooo00000`00003oooooooooo`02ooooob`0003o0P000008
01T0iP;o00000P0c0<`2o`0000<0C02c0_l0000206H0V@03o`00001o07l0O`1o00;o00000P2I06H2
o`0000050;<0C?l0003o0000o`00003<03<00_l000020>H06@;o0000:`3o00000ol00000iP0I0>H0
6@020>H06@05o`00003<03<0c00c0<`0<ol000000P2c04`01Ol00000V@1V09T0IP2I06Ko00000080
O`1o0_l0000206H0V@05o`00001<0;<0C02c04`0/ol000001@0c0<`00ol000006@3V01T0iP0601T0
iP03000000000?l0003o06D0003o1Oooool10000007ooooo00000`00003oooooooooo`02ooooobh0
003o0P00000801T0iP05o`00000c0<`0<`3<03<0c?l00000101<0;<01?l00000IP2I06H0VOl00003
07l0O`;o00000P2I06H3o`0000030;<0C?l0003o000000?o00000P3V01T3o`0002P0o`0000?o0000
0>H06@3V01T00P3V01T01Ol00000c00c0<`0<`3<03?o00000080/`1<00Go000009T0IP2I06H0V@1V
o`00000307l0O`04o`00001V09T0IP2Io`0000<0C02c00?o000003<0c00c0<`00`0c0<`00ol00000
6@3V01T0iP0601T0iP03o`0000000?l0003o06D0003o1Oooool10000007ooooo00000`00003ooooo
ooooo`02oooooc00003o00<0000001T0iP0I0>H01P0I0>H01?l00000<`3<03<0c00c0<`2o`0000<0
C02c0_l000000`1V09Wo0000o`00000307l0O`?o00000P2I06H2o`000080/`1<1Ol000020>H06@;o
00009@3o00000ol00000iP0I0>H06@020>H06@03o`00003<03<0c00c0080c00c00Co00000;<0C02c
04co00000`2I06H00ol00000O`1o07l0O`0207l0O`04o`00001V09T0IP2Io`0000<0C02c00?o0000
03<0c00c0<`00`0c0<`00ol000006@3V01T0iP0501T0iP03000000000?l0003o06D0003o1Oooool1
0000007ooooo00000`00003oooooooooo`02oooooc40003o0P00000701T0iP;o00000`0c0<`2o`00
00<0C02c00?o000006H0V@1V09T00ol0000307l0O`;o00000P2I06H2o`000080/`1<0_l000000`3<
03?o0000o`0000020>H06@?o00008P3o00000ol00000iP0I0>H06@020>H06@03o`00003<03<0c00c
0080c00c00Go00000;<0C02c04`0/`1<o`00000309T0IP05o`00001o07l0O`1o07l0Ool000000P1V
09T00ol00000C02c04`0/`0204`0/`03o`00000c0<`0<`3<0080<`3<00?o000001T0iP0I0>H01P0I
0>H00`000000003o0000o`1T0000o`Gooooo0@000001ooooo`0000<00000ooooooooool00_oooolc
0000o`030000000I0>H06@3V00H06@3V00?o000003<0c00c0<`00P0c0<`01?l00000C02c04`0/`1<
0;<2o`0000<0IP2I0_l0000307l0O`;o00000P2I06H2o`000080/`1<00?o00000<`0<`3<03<00_l0
00030>H06@?o00007P3o00000ol00000iP0I0>H06@030>H06@03o`00003<03<0c00c0080c00c00Go
00000;<0C02c04`0/`1<o`00000309T0IP05o`00001o07l0O`1o07l0Ool000000`1V09T00ol00000
C02c04`0/`0204`0/`03o`00000c0<`0<`3<0080<`3<00?o000001T0iP0I0>H01P0I0>H00`000000
003o0000o`1S0000o`Gooooo0@000001ooooo`0000<00000ooooooooool00_oooold0000o`800000
1`0I0>H2o`0000<0<`3<0_l0000304`0/`;o00000`1V09T2o`0000<0O`1o0_l0000209T0IP;o0000
00<0/`1<o`000?l000000P3<03<3o`0000<0iP0I0ol0000K0?l00003o`00003V01T0iP0I0080iP0I
00?o00000<`0<`3<03<00`3<03<01Ol00000/`1<0;<0C02c04co000000<0V@1V00?o000007l0O`1o
07l00P1o07l01?l00000IP2I06H0VOl0000504`0/`03o`00000c0<`0<`3<0080<`3<00?o000001T0
iP0I0>H01P0I0>H00`000000003o0000o`1R0000o`Gooooo0@000001ooooo`0000<00000oooooooo
ool00_oooolf0000o`030000000I0>H06@3V00H06@3V0_l0000303<0c003o`00001<0;<0C02c0080
C02c0_l0000306H0V@?o00000P1o07l2o`000080V@1V00?o00000;<0C02c04`00_l000030<`0<`?o
00000`3V01T3o`0001P0o`0000?o00000>H06@3V01T00P3V01T00ol00000c00c0<`0<`030<`0<`05
o`00002c04`0/`1<0;<0C?l000000`2I06H00ol00000O`1o07l0O`0207l0O`05o`00001V09T0IP2I
06H0VOl00000101<0;<00ol00000<`3<03<0c00203<0c003o`00000I0>H06@3V00H06@3V00<00000
0000o`000?l0HP000?l5ooooo`4000000Oooool0000300000?oooooooooo00;ooooo=`000?l20000
00P06@3V00Co000003<0c00c0<`0<`3<0_l0000404`0/`;o0000101V09T2o`000080O`1o0_l00000
0`2I06Ko0000o`0000020;<0C0;o0000103<03<3o`0000<0iP0I0ol0000B0?l000?o0000103V01T0
0ol00000c00c0<`0<`040<`0<`03o`00002c04`0/`1<0080/`1<00Go000009T0IP2I06H0V@1Vo`00
000307l0O`05o`00001V09T0IP2I06H0VOl000001@1<0;<00ol00000<`3<03<0c00203<0c003o`00
000I0>H06@3V00H06@3V00<000000000o`000?l0H@000?l5ooooo`4000000Oooool0000300000?oo
oooooooo00;ooooo>@000?l00`0000006@3V01T0iP0601T0iP;o00000`0c0<`2o`0000@0C02c0_l0
000406H0V@05o`00001o07l0O`1o07l0Ool000000P2I06H2o`000080/`1<0_l000050<`0<`?o0000
0`3V01T4o`0000X0o`001?l000070>H06@03o`00003<03<0c00c00@0c00c00?o00000;<0C02c04`0
0P2c04`01Ol00000V@1V09T0IP2I06Ko000000@0O`1o00Go000006H0V@1V09T0IP2Io`00000404`0
/`03o`00000c0<`0<`3<0080<`3<00?o000001T0iP0I0>H01`0I0>H00`000000003o0000o`1P0000
o`Gooooo0@000001ooooo`0000<00000ooooooooool00_oooolj0000o`800000200I0>H00ol00000
<`3<03<0c00203<0c0;o0000101<0;<2o`0000<0IP2I0_l0000207l0O`;o00000P2I06H2o`000080
/`1<0ol000050<`0<`;o00001@3V01T3o`0000<0o`001?l0000:0>H06@03o`00003<03<0c00c00D0
c00c00?o00000;<0C02c04`00P2c04`01Ol00000V@1V09T0IP2I06Ko000000@0O`1o00Go000006H0
V@1V09T0IP2Io`00000504`0/`03o`00000c0<`0<`3<0080<`3<00?o000001T0iP0I0>H01P0I0>H0
0`000000003o0000o`1P0000o`Gooooo0@000001ooooo`0000<00000ooooooooool00_ooooll0000
o`030000000I0>H06@3V00H06@3V0_l0000403<0c003o`00001<0;<0C02c00<0C02c00?o000006H0
V@1V09T00P1V09T01?l00000O`1o07l0O`1o07l2o`000080V@1V0_l000030;<0C0;o00001@3<03<3
o`0000D0iP0I0ol0000>0>H06@03o`00003<03<0c00c00D0c00c00?o00000;<0C02c04`00P2c04`0
1Ol00000V@1V09T0IP2I06Ko000000@0O`1o00?o000006H0V@1V09T00P1V09T00ol00000C02c04`0
/`0204`0/`03o`00000c0<`0<`3<00<0<`3<00?o000001T0iP0I0>H01P0I0>H00`000000003o0000
o`1O0000o`Gooooo0@000001ooooo`0000<00000ooooooooool00_oooolm0000o`030000000I0>H0
6@3V00L06@3V00?o000003<0c00c0<`00P0c0<`2o`0000@0C02c00?o000006H0V@1V09T00P1V09T0
0ol00000O`1o07l0O`0207l0O`05o`00002I06H0V@1V09T0I_l00000102c04`2o`0000H0c00c0ol0
000C0>H06@03o`00003<03<0c00c00D0c00c00?o00000;<0C02c04`00`2c04`01Ol00000V@1V09T0
IP2I06Ko000000@0O`1o00Go000006H0V@1V09T0IP2Io`00000404`0/`03o`00000c0<`0<`3<00<0
<`3<00?o000001T0iP0I0>H01`0I0>H00`000000003o0000o`1N0000o`Gooooo0@000001ooooo`00
00<00000ooooooooool00_ooooln0000o`800000200I0>H2o`0000@0<`3<0ol0000204`0/`?o0000
0P1V09T3o`000080O`1o0_l0000209T0IP?o00000`2c04`4o`0000D0c00c2_l000070>H06@;o0000
203<03<00ol00000/`1<0;<0C0030;<0C005o`00002I06H0V@1V09T0I_l00000101o07l00ol00000
IP2I06H0V@0206H0V@03o`00001<0;<0C02c0080C02c00?o000003<0c00c0<`00`0c0<`00ol00000
6@3V01T0iP0701T0iP03000000000?l0003o05d0003o1Oooool10000007ooooo00000`00003ooooo
ooooo`02oooood00003o0P00000801T0iP;o00001@0c0<`2o`0000<0C02c0ol0000206H0V@?o0000
00@0O`1oo`000?l0003o00000P2I06H3o`0000@0/`1<1?l0000;0<`0<`Oo0000203<03<2o`0000H0
/`1<00Go000009T0IP2I06H0V@1Vo`00000407l0O`03o`00001V09T0IP2I0080IP2I00?o000004`0
/`1<0;<00P1<0;<00ol00000<`3<03<0c00303<0c003o`00000I0>H06@3V00L06@3V00<000000000
o`000?l0G@000?l5ooooo`4000000Oooool0000300000?oooooooooo00;ooooo@P000?l00`000000
6@3V01T0iP0701T0iP;o00001@0c0<`2o`0000@0C02c0ol0000206H0V@;o00000P1o07l3o`000080
V@1V0ol000050;<0C0?o00005@3<03<2o`0000L0/`1<00?o000009T0IP2I06H00P2I06H00ol00000
O`1o07l0O`0207l0O`03o`00001V09T0IP2I00<0IP2I00?o000004`0/`1<0;<00P1<0;<00ol00000
<`3<03<0c00303<0c003o`00000I0>H06@3V00L06@3V00<000000000o`000?l0G0000?l5ooooo`40
00000Oooool0000300000?oooooooooo00;ooooo@`000?l2000000T06@3V00?o000003<0c00c0<`0
100c0<`3o`0000@0C02c0_l0000206H0V@;o00000`1o07l3o`000080V@1V0ol000050;<0C0Co0000
3P3<03<3o`0000P0/`1<00?o000009T0IP2I06H00`2I06H00ol00000O`1o07l0O`0207l0O`03o`00
001V09T0IP2I00<0IP2I00?o000004`0/`1<0;<00P1<0;<00ol00000<`3<03<0c00403<0c003o`00
000I0>H06@3V00L06@3V00<000000000o`000?l0F`000?l5ooooo`4000000Oooool0000300000?oo
oooooooo00;oooooA@000?l2000000P06@3V0_l0000703<0c0;o0000101<0;<2o`000080IP2I0_l0
000407l0O`;o00000`2I06H3o`0000H0/`1<1?l000080<`0<`;o00002P2c04`00ol00000V@1V09T0
IP0309T0IP03o`00001o07l0O`1o00@0O`1o00?o000006H0V@1V09T00P1V09T00ol00000C02c04`0
/`0304`0/`03o`00000c0<`0<`3<00<0<`3<00?o000001T0iP0I0>H01`0I0>H00`000000003o0000
o`1K0000o`Gooooo0@000001ooooo`0000<00000ooooooooool00_oooom70000o`800000200I0>H2
o`0000L0<`3<0_l0000404`0/`04o`00001V09T0IP2I06H0V@;o0000101o07l2o`0000@0V@1V0ol0
00070;<0C0Co00000P3<03<2o`0000/0/`1<00?o000009T0IP2I06H0102I06H00ol00000O`1o07l0
O`0407l0O`03o`00001V09T0IP2I00<0IP2I00?o000004`0/`1<0;<00P1<0;<00ol00000<`3<03<0
c00403<0c003o`00000I0>H06@3V00L06@3V00<000000000o`000?l0FP000?l5ooooo`4000000Ooo
ool0000300000?oooooooooo00;oooooB@000?l00`0000006@3V01T0iP0701T0iP;o00001`0c0<`2
o`0000<0C02c0_l0000306H0V@;o0000101o07l3o`0000@0V@1V0ol000080;<0C0;o00003@2c04`0
0ol00000V@1V09T0IP0409T0IP03o`00001o07l0O`1o00@0O`1o00?o000006H0V@1V09T00`1V09T0
0ol00000C02c04`0/`0304`0/`03o`00000c0<`0<`3<00<0<`3<00?o000001T0iP0I0>H0200I0>H0
0`000000003o0000o`1I0000o`Gooooo0@000001ooooo`0000<00000ooooooooool00_oooom:0000
o`8000002@0I0>H2o`0000L0<`3<00?o000004`0/`1<0;<00P1<0;<2o`0000<0IP2I0_l0000507l0
O`;o00001@2I06H4o`000180/`1<00?o000009T0IP2I06H01@2I06H00ol00000O`1o07l0O`0407l0
O`03o`00001V09T0IP2I00<0IP2I00?o000004`0/`1<0;<00`1<0;<00ol00000<`3<03<0c00403<0
c003o`00000I0>H06@3V00L06@3V00<000000000o`000?l0F@000?l5ooooo`4000000Oooool00003
00000?oooooooooo00;oooooC0000?l2000000T06@3V00?o000003<0c00c0<`01@0c0<`2o`0000@0
C02c00?o000006H0V@1V09T00P1V09T2o`0000D0O`1o0_l0000709T0IPCo00003@2c04`00ol00000
V@1V09T0IP0609T0IP03o`00001o07l0O`1o00@0O`1o00?o000006H0V@1V09T00`1V09T00ol00000
C02c04`0/`0304`0/`03o`00000c0<`0<`3<00@0<`3<00?o000001T0iP0I0>H0200I0>H00`000000
003o0000o`1H0000o`Gooooo0@000001ooooo`0000<00000ooooooooool00_oooom>0000o`030000
000I0>H06@3V00L06@3V0_l0000703<0c003o`00001<0;<0C02c0080C02c0_l0000406H0V@;o0000
1@1o07l3o`0000P0V@1V3Ol0000809T0IP03o`00001o07l0O`1o00H0O`1o00?o000006H0V@1V09T0
0`1V09T00ol00000C02c04`0/`0304`0/`03o`00000c0<`0<`3<00@0<`3<00?o000001T0iP0I0>H0
200I0>H00`000000003o0000o`1G0000o`Gooooo0@000001ooooo`0000<00000ooooooooool00_oo
oom?0000o`8000002@0I0>H2o`0000H0<`3<00?o000004`0/`1<0;<00`1<0;<2o`0000@0IP2I0_l0
000607l0O`?o00006P2I06H00ol00000O`1o07l0O`0607l0O`03o`00001V09T0IP2I00<0IP2I00?o
000004`0/`1<0;<00`1<0;<00ol00000<`3<03<0c00403<0c003o`00000I0>H06@3V00P06@3V00<0
00000000o`000?l0E`000?l5ooooo`4000000Oooool0000300000?oooooooooo00;oooooD@000?l2
000000T06@3V0_l0000503<0c0;o00001@1<0;<3o`0000<0IP2I0ol0000607l0O`?o00005P2I06H2
o`0000P0O`1o00?o000006H0V@1V09T00`1V09T00ol00000C02c04`0/`0404`0/`03o`00000c0<`0
<`3<00@0<`3<00?o000001T0iP0I0>H0200I0>H00`000000003o0000o`1F0000o`Gooooo0@000001
ooooo`0000<00000ooooooooool00_oooomC0000o`030000000I0>H06@3V00P06@3V0_l0000503<0
c0?o00001@1<0;<3o`0000<0IP2I0ol0000607l0O`?o0000402I06H3o`0000T0O`1o00?o000006H0
V@1V09T0101V09T00ol00000C02c04`0/`0404`0/`03o`00000c0<`0<`3<00@0<`3<00?o000001T0
iP0I0>H0200I0>H00`000000003o0000o`1F0000o`Gooooo0@000001ooooo`0000<00000oooooooo
ool00_oooomD0000o`8000002P0I0>H00ol00000<`3<03<0c00503<0c0;o00001P1<0;<3o`0000<0
IP2I0ol0000607l0O`Oo00001P2I06H3o`0000/0O`1o00?o000006H0V@1V09T01@1V09T00ol00000
C02c04`0/`0404`0/`03o`00000c0<`0<`3<00D0<`3<00?o000001T0iP0I0>H0200I0>H00`000000
003o0000o`1E0000o`Gooooo0@000001ooooo`0000<00000ooooooooool00_oooomF0000o`800000
2@0I0>H2o`0000L0<`3<0_l0000704`0/`;o0000101V09T3o`0000X0O`1o1_l0000=07l0O`03o`00
001V09T0IP2I00H0IP2I00?o000004`0/`1<0;<01@1<0;<00ol00000<`3<03<0c00403<0c003o`00
000I0>H06@3V00T06@3V00<000000000o`000?l0E0000?l5ooooo`4000000Oooool0000300000?oo
oooooooo00;oooooF0000?l00`0000006@3V01T0iP0801T0iP;o00001`0c0<`3o`0000H0C02c0_l0
000506H0V@?o00006@1o07l00ol00000IP2I06H0V@0706H0V@03o`00001<0;<0C02c00D0C02c00?o
000003<0c00c0<`01@0c0<`00ol000006@3V01T0iP0801T0iP03000000000?l0003o05@0003o1Ooo
ool10000007ooooo00000`00003oooooooooo`02oooooeT0003o0P00000:01T0iP03o`00000c0<`0
<`3<00L0<`3<0_l0000604`0/`;o00001P1V09T3o`0001D0O`1o00?o000006H0V@1V09T0201V09T0
0ol00000C02c04`0/`0504`0/`03o`00000c0<`0<`3<00D0<`3<00?o000001T0iP0I0>H02@0I0>H0
0`000000003o0000o`1C0000o`Gooooo0@000001ooooo`0000<00000ooooooooool00_oooomK0000
o`030000000I0>H06@3V00P06@3V0_l0000903<0c0;o00001P1<0;<2o`0000L0IP2I1?l0000@07l0
O`03o`00001V09T0IP2I00P0IP2I00?o000004`0/`1<0;<01`1<0;<00ol00000<`3<03<0c00503<0
c003o`00000I0>H06@3V00T06@3V00<000000000o`000?l0DP000?l5ooooo`4000000Oooool00003
00000?oooooooooo00;oooooG0000?l2000000X06@3V0_l0000903<0c0;o00001P1<0;<2o`0000T0
IP2I0ol0000707l0O`Ko00002`1V09T00ol00000C02c04`0/`0704`0/`03o`00000c0<`0<`3<00D0
<`3<00?o000001T0iP0I0>H02@0I0>H00`000000003o0000o`1B0000o`Gooooo0@000001ooooo`00
00<00000ooooooooool00_oooomN0000o`8000002P0I0>H2o`0000T0<`3<0_l0000604`0/`;o0000
2P1V09T7o`000140IP2I00?o000004`0/`1<0;<01`1<0;<00ol00000<`3<03<0c00503<0c003o`00
000I0>H06@3V00X06@3V00<000000000o`000?l0D@000?l5ooooo`4000000Oooool0000300000?oo
oooooooo00;oooooH0000?l3000000T06@3V0ol0000803<0c0;o00001P1<0;<3o`0001l0IP2I00?o
000004`0/`1<0;<01`1<0;<00ol00000<`3<03<0c00603<0c003o`00000I0>H06@3V00T06@3V00<0
00000000o`000?l0D@000?l5ooooo`4000000Oooool0000300000?oooooooooo00;oooooH`000?l2
000000X06@3V0_l0000803<0c0;o00001`1<0;<3o`0001`0IP2I00?o000004`0/`1<0;<0201<0;<0
0ol00000<`3<03<0c00503<0c003o`00000I0>H06@3V00X06@3V00<000000000o`000?l0D0000?l5
ooooo`4000000Oooool0000300000?oooooooooo00;oooooI@000?l2000000X06@3V0_l0000803<0
c0?o00001`1<0;<4o`0001H0IP2I0_l0000;04`0/`03o`00000c0<`0<`3<00H0<`3<00?o000001T0
iP0I0>H02P0I0>H00`000000003o0000o`1?0000o`Gooooo0@000001ooooo`0000<00000oooooooo
ool00_oooomW0000o`030000000I0>H06@3V00T06@3V0_l0000903<0c0?o0000201<0;<4o`0000l0
IP2I0ol0000<04`0/`03o`00000c0<`0<`3<00L0<`3<00?o000001T0iP0I0>H02`0I0>H00ol00000
003o0000o`1>0000o`Gooooo0@000001ooooo`0000<00000ooooooooool00_oooomX0000o`800000
2`0I0>H3o`0000T0<`3<0_l0000:04`0/`Co0000201V09T3o`0000h0C02c00?o000003<0c00c0<`0
200c0<`00ol000006@3V01T0iP0;01T0iP03000000000?l0003o04h0003o1Oooool10000007ooooo
00000`00003oooooooooo`02ooooofX0003o00<0000001T0iP0I0>H02`0I0>H2o`0000T0<`3<0ol0
000;04`0/`?o00000P1V09T3o`000100C02c00?o000003<0c00c0<`02@0c0<`00ol000006@3V01T0
iP0<01T0iP03000000000?l0003o04d0003o1Oooool10000007ooooo00000`00003oooooooooo`02
ooooof/0003o0P00000=01T0iP;o00002P0c0<`2o`0000`0C02c0_l0000B04`0/`03o`00000c0<`0
<`3<00/0<`3<00?o000001T0iP0I0>H02`0I0>H00`000000003o0000o`1=0000o`Gooooo0@000001
ooooo`0000<00000ooooooooool00_oooom]0000o`8000003@0I0>H3o`0000T0<`3<0_l0000M04`0
/`03o`00000c0<`0<`3<00`0<`3<00?o000001T0iP0I0>H02`0I0>H00`000000003o0000o`1=0000
o`Gooooo0@000001ooooo`0000<00000ooooooooool00_oooom_0000o`030000000I0>H06@3V00d0
6@3V0_l0000903<0c0;o00006P1<0;<00ol00000<`3<03<0c00=03<0c003o`00000I0>H06@3V00`0
6@3V00<000000000o`000?l0C0000?l5ooooo`4000000Oooool0000300000?oooooooooo00;ooooo
L0000?l2000000l06@3V0_l0000903<0c0?o00005P1<0;<00ol00000<`3<03<0c00>03<0c003o`00
000I0>H06@3V00`06@3V00<000000000o`000?l0C0000?l5ooooo`4000000Oooool0000300000?oo
oooooooo00;oooooLP000?l00`0000006@3V01T0iP0>01T0iP03o`00000c0<`0<`3<00T0<`3<0ol0
000B04`0/`03o`00000c0<`0<`3<00l0<`3<00?o000001T0iP0I0>H0300I0>H00`000000003o0000
o`1<0000o`Gooooo0@000001ooooo`0000<00000ooooooooool00_oooomc0000o`8000003`0I0>H2
o`0000`0<`3<0ol0000>04`0/`03o`00000c0<`0<`3<0100<`3<00?o000001T0iP0I0>H03@0I0>H0
0`000000003o0000o`1;0000o`Gooooo0@000001ooooo`0000<00000ooooooooool00_oooome0000
o`8000003`0I0>H2o`0000d0<`3<1ol0000604`0/`03o`00000c0<`0<`3<0180<`3<00?o000001T0
iP0I0>H0300I0>H00`000000003o0000o`1;0000o`Gooooo0@000001ooooo`0000<00000oooooooo
ool00_oooomg0000o`8000003`0I0>H00ol00000<`3<03<0c00A03<0c0Ko00005@0c0<`00ol00000
6@3V01T0iP0<01T0iP03000000000?l0003o04/0003o1Oooool10000007ooooo00000`00003ooooo
ooooo`02ooooogT0003o0P00000>01T0iP?o0000:P0c0<`2o`0000l06@3V00<000000000o`000?l0
BP000?l5ooooo`4000000Oooool0000300000?oooooooooo00;oooooN`000?l2000000l06@3V0ol0
000V03<0c003o`00000I0>H06@3V00l06@3V00<000000000o`000?l0BP000?l5ooooo`4000000Ooo
ool0000300000?oooooooooo00;oooooO@000?l2000001006@3V0ol0000R03<0c003o`00000I0>H0
6@3V01406@3V00<000000000o`000?l0B@000?l5ooooo`4000000Oooool0000300000?oooooooooo
00;oooooO`000?l2000001406@3V0ol0000N03<0c003o`00000I0>H06@3V01806@3V00<000000000
o`000?l0B@000?l5ooooo`4000000Oooool0000300000?oooooooooo00;oooooP@000?l200000180
6@3V0ol0000J03<0c003o`00000I0>H06@3V01<06@3V00<000000000o`000?l0B@000?l5ooooo`40
00000Oooool0000300000?oooooooooo00;oooooP`000?l2000001<06@3V0ol0000F03<0c003o`00
000I0>H06@3V01D06@3V00<000000000o`000?l0B0000?l5ooooo`4000000Oooool0000300000?oo
oooooooo00;oooooQ@000?l00`0000006@3V01T0iP0C01T0iP?o00004P0c0<`00ol000006@3V01T0
iP0F01T0iP03000000000?l0003o04P0003o1Oooool10000007ooooo00000`00003oooooooooo`02
ooooohH0003o0P00000F01T0iP?o00003P0c0<`00ol000006@3V01T0iP0G01T0iP03000000000?l0
003o04P0003o1Oooool10000007ooooo00000`00003oooooooooo`02ooooohP0003o0P00000G01T0
iPCo00002@0c0<`00ol000006@3V01T0iP0I01T0iP03000000000?l0003o04L0003o1Oooool10000
007ooooo00000`00003oooooooooo`02ooooohX0003o0P00000I01T0iPGo00000`0c0<`00ol00000
6@3V01T0iP0J01T0iP03000000000?l0003o04L0003o1Oooool10000007ooooo00000`00003ooooo
ooooo`02oooooh`0003o0`00000K01T0iP?o00007@0I0>H00`000000003o0000o`170000o`Gooooo
0@000001ooooo`0000<00000ooooooooool00_oooon?0000o`800000>P0I0>H00`000000003o0000
o`160000o`Gooooo0@000001ooooo`0000<00000ooooooooool00_oooonA0000o`030000000I0>H0
6@3V03L06@3V00<000000000o`000?l0AP000?l5ooooo`4000000Oooool0000300000?oooooooooo
00;oooooTP000?l2000003L06@3V00<000000000o`000?l0AP000?l5ooooo`4000000Oooool00003
00000?oooooooooo00;oooooU0000?l00`0000006@3V01T0iP0d01T0iP03000000000?l0003o04H0
003o1Oooool10000007ooooo00000`00003oooooooooo`02oooooiD0003o0`00000c01T0iP030000
00000?l0003o04H0003o1Oooool10000007ooooo00000`00003oooooooooo`02oooooiP0003o0`00
000`01T0iP03000000000?l0003o04H0003o1Oooool10000007ooooo00000`00003oooooooooo`02
oooooi/0003o0`00000]01T0iP03000000000?l0003o04H0003o1Oooool10000007ooooo00000`00
003oooooooooo`02oooooih0003o0`00000Z01T0iP03000000000?l0003o04H0003o1Oooool10000
007ooooo00000`00003oooooooooo`02oooooj40003o0P00000X01T0iP03000000000?l0003o04H0
003o1Oooool10000007ooooo00000`00003oooooooooo`02oooooj<0003o0P00000V01T0iP030000
00000?l0003o04H0003o1Oooool10000007ooooo00000`00003oooooooooo`02ooooojD0003o0`00
000S01T0iP03000000000?l0003o04H0003o1Oooool10000007ooooo00000`00003oooooooooo`02
ooooojP0003o0P00000Q01T0iP03000000000?l0003o04H0003o1Oooool10000007ooooo00000`00
003oooooooooo`02ooooojX0003o1@00000K01T0iP800000B0000?l5ooooo`4000000Oooool00003
00000?oooooooooo00;ooooo[`000?l3000001L06@3V00<000000000o`000?l0B0000?l5ooooo`40
00000Oooool0000300000?oooooooooo00;ooooo/P000?l3000001806@3V0P00001;0000o`Gooooo
0@000001ooooo`0000<00000ooooooooool00_oooone0000o`<000003@0I0>H2000004d0003o1Ooo
ool10000007ooooo00000`00003oooooooooo`02oooookP0003o1`00000501T0iP03000000000?l0
003o04d0003o1Oooool10000007ooooo00000`00003oooooooooo`02oooookl0003o1@00001@0000
o`Gooooo0@000001ooooo`0000<00000ooooooooool00_oooooo0000oaD0003o1Oooool10000007o
oooo00000`00003oooooooooo`02ooooool0003o5@000?l5ooooo`4000000Oooool0000300000?oo
oooooooo00;oooooo`000?lE0000o`Gooooo0@000001ooooo`0000<00000ooooooooool00_oooooo
0000oaD0003o1Oooool10000007ooooo00000`00003oooooooooo`02ooooool0003o5@000?l5oooo
o`4000000Oooool0000300000?oooooooooo00;oooooo`000?lE0000o`Gooooo0@000001ooooo`00
00<00000ooooooooool00_oooooo0000oaD0003o1Oooool10000007ooooo00000`00003ooooooooo
o`02ooooool0003o5@000?l5ooooo`4000000Oooool0000300000?oooooooooo00;oooooo`000?lE
0000o`Gooooo0@000001ooooo`0000<00000ooooooooool00_oooooo0000oaD0003o1Oooool10000
007ooooo00000`00003oooooooooo`02ooooool0003o5@000?l5ooooo`4000000Oooool000030000
0?oooooooooo00;oooooo`000?lE0000o`Gooooo0@000001ooooo`0000<00000ooooooooool00_oo
oooo0000oaD0003o1Oooool10000007ooooo00000`00003oooooooooo`02ooooool0003o5@000?l5
ooooo`4000000Oooool0000300000?oooooooooo00;oooooo`000?lE0000o`Gooooo0@000001oooo
o`0000<00000ooooooooool00_oooooo0000oaD0003o1Oooool10000007ooooo00000`00003ooooo
ooooo`02ooooool0003o5@000?l5ooooo`4000000Oooool0000300000?oooooooooo00;oooooo`00
0?lE0000o`Gooooo0@000001ooooo`0000<00000ooooooooool00_oooooo0000oaD0003o1Oooool1
0000007ooooo00000`00003oooooooooo`02ooooool0003o5@000?l5ooooo`4000000Oooool00003
00000?oooooooooo00;oooooo`000?lE0000o`Gooooo0@000001ooooo`0000<00000ooooooooool0
0_oooooo0000oaD0003o1Oooool10000007ooooo00000`00003oooooooooo`02ooooool0003o5@00
0?l5ooooo`4000000Oooool0000300000?oooooooooo00;oooooo`000?lE0000o`Gooooo0@000001
ooooo`0000<00000ooooooooool00_oooooo0000oaD0003o1Oooool10000007ooooo00000`00003o
ooooooooo`02ooooool0003o5@000?l5ooooo`4000000Oooool0000300000?oooooooooo00;ooooo
o`000?lE0000o`Gooooo0@000001ooooo`0000<00000ooooooooool00_oooooo0000oaD0003o1Ooo
ool10000007ooooo00000`00003oooooooooo`02ooooool0003o5@000?l5ooooo`4000000Oooool0
000300000?oooooooooo00;oooooo`000?lE0000o`Gooooo0@000001ooooo`0000<00000oooooooo
ool00_oooooo0000oaD0003o1Oooool10000007ooooo00000`00003oooooooooo`02ooooool0003o
5@000?l5ooooo`4000000Oooool0000300000?oooooooooo00;oooooo`000?lE0000o`Gooooo0@00
0001ooooo`0000<00000ooooooooool00_oooooo0000oaD0003o1Oooool10000007ooooo00000`00
003oooooooooo`02ooooool0003o5@000?l5ooooo`4000000Oooool0000300000?oooooooooo00;o
ooooo`000?lE0000o`Gooooo0@000001ooooo`0000<00000ooooooooool00_oooooo0000oaD0003o
1Oooool10000007ooooo00000`00003oooooooooo`02ooooool0003o5@000?l5ooooo`4000000Ooo
ool0000300000?oooooooooo00;oooooo`000?lE0000o`Gooooo0@000001ooooo`0000<00000oooo
ooooool00_oooooo0000oaD0003o1Oooool10000007ooooo00000`00003oooooooooo`02ooooool0
003o5@000?l5ooooo`4000000Oooool0000300000?oooooooooo00;oooooo`000?lE0000o`Gooooo
0@000001ooooo`0000<00000ooooooooool00_oooooo0000oaD0003o1Oooool10000007ooooo0000
0`00003oooooooooo`02ooooool0003o5@000?l5ooooo`4000000Oooool0000300000?oooooooooo
00;oooooo`000?lE0000o`Gooooo0@000001ooooo`0000<00000ooooooooool00_oooooo0000oaD0
003o1Oooool10000007ooooo00000`00003oooooooooo`02ooooool0003o5@000?l5ooooo`400000
0Oooool0000300000?oooooooooo00;oooooo`000?lE0000o`Gooooo0@000001ooooo`0000<00000
ooooooooool00_oooooo0000oaD0003o1Oooool10000007ooooo00000`00003oooooooooo`02oooo
ool0003o5@000?l5ooooo`4000000Oooool0000300000?oooooooooo00;oooooo`000?lE0000o`Go
oooo0@000001ooooo`0000<00000ooooooooool00_oooooo0000oaD0003o1Oooool10000007ooooo
00000`00003oooooooooo`02ooooool0003o5@000?l5ooooo`4000000Oooool0000300000?oooooo
oooo00;oooooo`000?lE0000o`Gooooo0@000001ooooo`0000<00000ooooooooool00_oooooo0000
oaD0003o1Oooool10000007ooooo00000`00003oooooooooo`02ooooool0003o5@000?l5ooooo`40
00000Oooool0000300000?oooooooooo00;oooooo`000?lE0000o`Gooooo0@000001ooooo`0000<0
0000ooooooooool00_oooooo0000oaD0003o1Oooool10000007ooooo00000`00003oooooooooo`02
ooooool0003o5@000?l5ooooo`4000000Oooool0000300000?oooooooooo00;oooooo`000?lE0000
o`Gooooo0@000001ooooo`0000<00000ooooooooool00_oooooo0000oaD0003o1Oooool10000007o
oooo00000`00003oooooooooo`02ooooool0003o5@000?l5ooooo`4000000Oooool0000300000?oo
oooooooo00;oooooo`000?lE0000o`Gooooo0@000001ooooo`0000<00000ooooooooool00_oooooo
0000oaD0003o1Oooool10000007ooooo00000`00003oooooooooo`02ooooool0003o5@000?l5oooo
o`4000000Oooool0000300000?oooooooooo00;oooooo`000?lE0000o`Gooooo0@000001ooooo`00
00<00000ooooooooool00_oooooo0000oaD0003o1Oooool10000007ooooo00000`00003ooooooooo
o`02ooooool0003o5@000?l5ooooo`4000000Oooool0000300000?oooooooooo00;oooooo`000?lE
0000o`Gooooo0@000001ooooo`0000<00000ooooooooool00_oooooo0000oaD0003o1Oooool10000
007ooooo00000`00003oooooooooo`02ooooool0003o5@000?l5ooooo`4000000Oooool000030000
0?oooooooooo00;oooooo`000?lE0000o`Gooooo0@000001ooooo`0000<00000ooooooooool00_oo
oooo0000oaD0003o1Oooool10000007ooooo00000`00003oooooooooo`02ooooool0003o5@000?l5
ooooo`4000000Oooool0000300000?oooooooooo00;oooooo`000?lE0000o`Gooooo0@000001oooo
o`0000<00000ooooooooool00_oooooo0000oaD0003o1Oooool10000007ooooo00000`00003ooooo
ooooo`02ooooool0003o5@000?l5ooooo`4000000Oooool0000300000?oooooooooo00;oooooo`00
0?lE0000o`Gooooo0@000001ooooo`0000<00000ooooooooool00_oooooo0000oaD0003o1Oooool1
0000007ooooo00000`00003oooooooooo`02ooooool0003o5@000?l5ooooo`4000000Oooool00003
00000?oooooooooo00;oooooo`000?lE0000o`Gooooo0@000001ooooo`0000<00000ooooooooool0
0_oooooo0000oaD0003o1Oooool10000007ooooo00000`00003oooooooooo`02ooooool0003o5@00
0?l5ooooo`4000000Oooool0000300000?oooooooooo00;oooooo`000?lE0000o`Gooooo0@000001
ooooo`0000<00000ooooooooool00_oooooo0000oaD0003o1Oooool10000007ooooo00000`00003o
ooooooooo`02ooooool0003o5@000?l5ooooo`4000000Oooool0000300000?oooooooooo00;ooooo
o`000?lE0000o`Gooooo0@000001ooooo`0000<00000ooooooooool0oooooolLooooo`4000000Ooo
ool0000300000?oooooooooo0?oooooo7?ooool10000007ooooo00000`00003oooooooooo`3ooooo
oacooooo0@000001ooooo`0000<00000ooooooooool0oooooolLooooo`4000000Oooool00?l00000
80000001ooooo`00\
\>"],
  ImageRangeCache->{{{0, 287}, {287, 0}} -> {-1.04092, -1.04092, 0.00725378, \
0.00725378}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% ContourGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.480769 0.5 0.480769 [
[ 0 0 -0.125 0 ]
[ 0 0 -0.125 0 ]
[ 0 1 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
0 0 m
1 0 L
s
0 0 m
0 1 L
s
0 1 m
1 1 L
s
1 0 m
1 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
0 0 1 r
.01923 .98077 m
.98077 .98077 L
.98077 .01923 L
.01923 .01923 L
F
0 g
.5 Mabswid
.1 0 .9 r
.01923 .33817 m
.02431 .33974 L
.05929 .36213 L
.09936 .37767 L
.10778 .37981 L
.13942 .39817 L
.17949 .41596 L
.19493 .41987 L
.21955 .43169 L
.25962 .45161 L
.29428 .45994 L
.29968 .46362 L
.33974 .48149 L
.37981 .49464 L
.4025 .5 L
.41987 .50546 L
.45994 .51666 L
.5 .52377 L
.54006 .52067 L
.58013 .51386 L
.5938 .5 L
.59917 .45994 L
.59373 .41987 L
.58013 .38136 L
.57697 .37981 L
.55594 .33974 L
.54006 .31749 L
.53249 .29968 L
.50411 .25962 L
.5 .25315 L
.4771 .21955 L
.45994 .19665 L
.44916 .17949 L
.41987 .14469 L
.4167 .13942 L
.3824 .09936 L
.37981 .09593 L
.35033 .05929 L
.33974 .04125 L
.31945 .01923 L
.01923 .01923 L
F
0 g
.01923 .33817 m
.02431 .33974 L
.05929 .36213 L
.09936 .37767 L
.10778 .37981 L
.13942 .39817 L
.17949 .41596 L
.19493 .41987 L
.21955 .43169 L
.25962 .45161 L
.29428 .45994 L
.29968 .46362 L
.33974 .48149 L
.37981 .49464 L
.4025 .5 L
.41987 .50546 L
.45994 .51666 L
.5 .52377 L
.54006 .52067 L
.58013 .51386 L
.5938 .5 L
.59917 .45994 L
.59373 .41987 L
.58013 .38136 L
.57697 .37981 L
.55594 .33974 L
.54006 .31749 L
.53249 .29968 L
.50411 .25962 L
.5 .25315 L
.4771 .21955 L
.45994 .19665 L
.44916 .17949 L
.41987 .14469 L
.4167 .13942 L
.3824 .09936 L
.37981 .09593 L
.35033 .05929 L
.33974 .04125 L
.31945 .01923 L
s
.2 0 .8 r
.01923 .3308 m
.04662 .33974 L
.05929 .34751 L
.09936 .3692 L
.13369 .37981 L
.13942 .38305 L
.17949 .40538 L
.21955 .41443 L
.22723 .41987 L
.25962 .43722 L
.29968 .45108 L
.33261 .45994 L
.33974 .46308 L
.37981 .47741 L
.41987 .47706 L
.45994 .49039 L
.5 .49388 L
.54006 .48768 L
.5602 .45994 L
.55993 .41987 L
.55191 .37981 L
.54006 .35046 L
.53044 .33974 L
.51241 .29968 L
.5 .28518 L
.48825 .25962 L
.45994 .22155 L
.45815 .21955 L
.43233 .17949 L
.41987 .16422 L
.4039 .13942 L
.37981 .11168 L
.37149 .09936 L
.33974 .06691 L
.33236 .05929 L
.30381 .01923 L
.01923 .01923 L
F
0 g
.01923 .3308 m
.04662 .33974 L
.05929 .34751 L
.09936 .3692 L
.13369 .37981 L
.13942 .38305 L
.17949 .40538 L
.21955 .41443 L
.22723 .41987 L
.25962 .43722 L
.29968 .45108 L
.33261 .45994 L
.33974 .46308 L
.37981 .47741 L
.41987 .47706 L
.45994 .49039 L
.5 .49388 L
.54006 .48768 L
.5602 .45994 L
.55993 .41987 L
.55191 .37981 L
.54006 .35046 L
.53044 .33974 L
.51241 .29968 L
.5 .28518 L
.48825 .25962 L
.45994 .22155 L
.45815 .21955 L
.43233 .17949 L
.41987 .16422 L
.4039 .13942 L
.37981 .11168 L
.37149 .09936 L
.33974 .06691 L
.33236 .05929 L
.30381 .01923 L
s
.3 0 .7 r
.01923 .32423 m
.05929 .33807 L
.06319 .33974 L
.09936 .36176 L
.13942 .37232 L
.1523 .37981 L
.17949 .39637 L
.21955 .39969 L
.24905 .41987 L
.25962 .42598 L
.29968 .44172 L
.33974 .44924 L
.36572 .45994 L
.37981 .46411 L
.41987 .46357 L
.45994 .47312 L
.5 .47267 L
.5281 .45994 L
.54006 .43204 L
.54094 .41987 L
.54006 .40655 L
.53373 .37981 L
.51334 .33974 L
.5 .30213 L
.498 .29968 L
.47654 .25962 L
.45994 .2394 L
.44252 .21955 L
.42018 .17949 L
.41987 .1791 L
.39345 .13942 L
.37981 .12359 L
.36308 .09936 L
.33974 .08258 L
.31712 .05929 L
.29968 .0231 L
.29281 .01923 L
.01923 .01923 L
F
0 g
.01923 .32423 m
.05929 .33807 L
.06319 .33974 L
.09936 .36176 L
.13942 .37232 L
.1523 .37981 L
.17949 .39637 L
.21955 .39969 L
.24905 .41987 L
.25962 .42598 L
.29968 .44172 L
.33974 .44924 L
.36572 .45994 L
.37981 .46411 L
.41987 .46357 L
.45994 .47312 L
.5 .47267 L
.5281 .45994 L
.54006 .43204 L
.54094 .41987 L
.54006 .40655 L
.53373 .37981 L
.51334 .33974 L
.5 .30213 L
.498 .29968 L
.47654 .25962 L
.45994 .2394 L
.44252 .21955 L
.42018 .17949 L
.41987 .1791 L
.39345 .13942 L
.37981 .12359 L
.36308 .09936 L
.33974 .08258 L
.31712 .05929 L
.29968 .0231 L
.29281 .01923 L
s
.4 0 .6 r
.01923 .31806 m
.05929 .33202 L
.07586 .33974 L
.09936 .35481 L
.13942 .36605 L
.16655 .37981 L
.17949 .38812 L
.21955 .39152 L
.25962 .41795 L
.26656 .41987 L
.29968 .43312 L
.33974 .43952 L
.37981 .45379 L
.41297 .45994 L
.41987 .46003 L
.45994 .46191 L
.47954 .45994 L
.5 .45184 L
.52218 .41987 L
.51906 .37981 L
.50394 .33974 L
.5 .32105 L
.48666 .29968 L
.46607 .25962 L
.45994 .25231 L
.43294 .21955 L
.41987 .19076 L
.41175 .17949 L
.38411 .13942 L
.37981 .13437 L
.35532 .09936 L
.33974 .09121 L
.30894 .05929 L
.29968 .02959 L
.28596 .01923 L
.01923 .01923 L
F
0 g
.01923 .31806 m
.05929 .33202 L
.07586 .33974 L
.09936 .35481 L
.13942 .36605 L
.16655 .37981 L
.17949 .38812 L
.21955 .39152 L
.25962 .41795 L
.26656 .41987 L
.29968 .43312 L
.33974 .43952 L
.37981 .45379 L
.41297 .45994 L
.41987 .46003 L
.45994 .46191 L
.47954 .45994 L
.5 .45184 L
.52218 .41987 L
.51906 .37981 L
.50394 .33974 L
.5 .32105 L
.48666 .29968 L
.46607 .25962 L
.45994 .25231 L
.43294 .21955 L
.41987 .19076 L
.41175 .17949 L
.38411 .13942 L
.37981 .13437 L
.35532 .09936 L
.33974 .09121 L
.30894 .05929 L
.29968 .02959 L
.28596 .01923 L
s
.5 0 .5 r
.01923 .31204 m
.05929 .32628 L
.08647 .33974 L
.09936 .34806 L
.13942 .36279 L
.17879 .37981 L
.17949 .38025 L
.21955 .38752 L
.25962 .41403 L
.28601 .41987 L
.29968 .42482 L
.33974 .43259 L
.37981 .44536 L
.41987 .45135 L
.45994 .4506 L
.5 .42411 L
.50246 .41987 L
.50611 .37981 L
.5 .3521 L
.49644 .33974 L
.47742 .29968 L
.45994 .26342 L
.45774 .25962 L
.42709 .21955 L
.41987 .20114 L
.4055 .17949 L
.37981 .14284 L
.37924 .13942 L
.34783 .09936 L
.33974 .09572 L
.30532 .05929 L
.29968 .03673 L
.28206 .01923 L
.01923 .01923 L
F
0 g
.01923 .31204 m
.05929 .32628 L
.08647 .33974 L
.09936 .34806 L
.13942 .36279 L
.17879 .37981 L
.17949 .38025 L
.21955 .38752 L
.25962 .41403 L
.28601 .41987 L
.29968 .42482 L
.33974 .43259 L
.37981 .44536 L
.41987 .45135 L
.45994 .4506 L
.5 .42411 L
.50246 .41987 L
.50611 .37981 L
.5 .3521 L
.49644 .33974 L
.47742 .29968 L
.45994 .26342 L
.45774 .25962 L
.42709 .21955 L
.41987 .20114 L
.4055 .17949 L
.37981 .14284 L
.37924 .13942 L
.34783 .09936 L
.33974 .09572 L
.30532 .05929 L
.29968 .03673 L
.28206 .01923 L
s
.6 0 .4 r
.01923 .30601 m
.05929 .32066 L
.09685 .33974 L
.09936 .3413 L
.13942 .36033 L
.17949 .3727 L
.19172 .37981 L
.21955 .38527 L
.25962 .41008 L
.29968 .41627 L
.30659 .41987 L
.33974 .42644 L
.37981 .43667 L
.41987 .44071 L
.45994 .43459 L
.48158 .41987 L
.49332 .37981 L
.48631 .33974 L
.46863 .29968 L
.45994 .27765 L
.45175 .25962 L
.42265 .21955 L
.41987 .2122 L
.3997 .17949 L
.37981 .15017 L
.37798 .13942 L
.34035 .09936 L
.33974 .09905 L
.30376 .05929 L
.29968 .04471 L
.27902 .01923 L
.01923 .01923 L
F
0 g
.01923 .30601 m
.05929 .32066 L
.09685 .33974 L
.09936 .3413 L
.13942 .36033 L
.17949 .3727 L
.19172 .37981 L
.21955 .38527 L
.25962 .41008 L
.29968 .41627 L
.30659 .41987 L
.33974 .42644 L
.37981 .43667 L
.41987 .44071 L
.45994 .43459 L
.48158 .41987 L
.49332 .37981 L
.48631 .33974 L
.46863 .29968 L
.45994 .27765 L
.45175 .25962 L
.42265 .21955 L
.41987 .2122 L
.3997 .17949 L
.37981 .15017 L
.37798 .13942 L
.34035 .09936 L
.33974 .09905 L
.30376 .05929 L
.29968 .04471 L
.27902 .01923 L
s
.7 0 .3 r
.01923 .29976 m
.05929 .315 L
.09936 .33354 L
.10637 .33974 L
.13942 .35648 L
.17949 .36506 L
.20841 .37981 L
.21955 .38237 L
.25962 .40399 L
.29968 .40703 L
.33974 .41885 L
.34402 .41987 L
.37981 .42599 L
.41987 .42663 L
.44485 .41987 L
.45994 .41073 L
.47736 .37981 L
.47383 .33974 L
.45994 .30279 L
.45963 .29968 L
.44367 .25962 L
.41987 .22193 L
.41553 .21955 L
.39262 .17949 L
.37981 .16026 L
.37418 .13942 L
.33974 .10886 L
.33186 .09936 L
.30175 .05929 L
.29968 .05385 L
.27477 .01923 L
.01923 .01923 L
F
0 g
.01923 .29976 m
.05929 .315 L
.09936 .33354 L
.10637 .33974 L
.13942 .35648 L
.17949 .36506 L
.20841 .37981 L
.21955 .38237 L
.25962 .40399 L
.29968 .40703 L
.33974 .41885 L
.34402 .41987 L
.37981 .42599 L
.41987 .42663 L
.44485 .41987 L
.45994 .41073 L
.47736 .37981 L
.47383 .33974 L
.45994 .30279 L
.45963 .29968 L
.44367 .25962 L
.41987 .22193 L
.41553 .21955 L
.39262 .17949 L
.37981 .16026 L
.37418 .13942 L
.33974 .10886 L
.33186 .09936 L
.30175 .05929 L
.29968 .05385 L
.27477 .01923 L
s
.8 0 .2 r
.01923 .2911 m
.03157 .29968 L
.05929 .30913 L
.09936 .32495 L
.12128 .33974 L
.13942 .34907 L
.17949 .35706 L
.21955 .37491 L
.22774 .37981 L
.25962 .39366 L
.29968 .39707 L
.33974 .40686 L
.37981 .41207 L
.41987 .40808 L
.45656 .37981 L
.45883 .33974 L
.45259 .29968 L
.43135 .25962 L
.41987 .23759 L
.40456 .21955 L
.38255 .17949 L
.37981 .17534 L
.36503 .13942 L
.33974 .12032 L
.32267 .09936 L
.29968 .06472 L
.29501 .05929 L
.26724 .01923 L
.01923 .01923 L
F
0 g
.01923 .2911 m
.03157 .29968 L
.05929 .30913 L
.09936 .32495 L
.12128 .33974 L
.13942 .34907 L
.17949 .35706 L
.21955 .37491 L
.22774 .37981 L
.25962 .39366 L
.29968 .39707 L
.33974 .40686 L
.37981 .41207 L
.41987 .40808 L
.45656 .37981 L
.45883 .33974 L
.45259 .29968 L
.43135 .25962 L
.41987 .23759 L
.40456 .21955 L
.38255 .17949 L
.37981 .17534 L
.36503 .13942 L
.33974 .12032 L
.32267 .09936 L
.29968 .06472 L
.29501 .05929 L
.26724 .01923 L
s
.9 0 .1 r
.01923 .28093 m
.04856 .29968 L
.05929 .30279 L
.09936 .31532 L
.13942 .33691 L
.14566 .33974 L
.17949 .34828 L
.21955 .36283 L
.25962 .37784 L
.26638 .37981 L
.29968 .38566 L
.33974 .39188 L
.37981 .39312 L
.41868 .37981 L
.41987 .37882 L
.43957 .33974 L
.43283 .29968 L
.41987 .27198 L
.4141 .25962 L
.39164 .21955 L
.37981 .195 L
.36926 .17949 L
.34775 .13942 L
.33974 .13397 L
.31231 .09936 L
.29968 .07859 L
.28346 .05929 L
.25962 .02463 L
.25548 .01923 L
.01923 .01923 L
F
0 g
.01923 .28093 m
.04856 .29968 L
.05929 .30279 L
.09936 .31532 L
.13942 .33691 L
.14566 .33974 L
.17949 .34828 L
.21955 .36283 L
.25962 .37784 L
.26638 .37981 L
.29968 .38566 L
.33974 .39188 L
.37981 .39312 L
.41868 .37981 L
.41987 .37882 L
.43957 .33974 L
.43283 .29968 L
.41987 .27198 L
.4141 .25962 L
.39164 .21955 L
.37981 .195 L
.36926 .17949 L
.34775 .13942 L
.33974 .13397 L
.31231 .09936 L
.29968 .07859 L
.28346 .05929 L
.25962 .02463 L
.25548 .01923 L
s
1 0 0 r
.01923 .26792 m
.05929 .29146 L
.07952 .29968 L
.09936 .30357 L
.13942 .32054 L
.17949 .33649 L
.19116 .33974 L
.21955 .34557 L
.25962 .35767 L
.29968 .36555 L
.33974 .36627 L
.37981 .35238 L
.39036 .33974 L
.39818 .29968 L
.38792 .25962 L
.37981 .23643 L
.3722 .21955 L
.34878 .17949 L
.33974 .16013 L
.32646 .13942 L
.29968 .09984 L
.29935 .09936 L
.2675 .05929 L
.25962 .04627 L
.23888 .01923 L
.01923 .01923 L
F
0 g
.01923 .26792 m
.05929 .29146 L
.07952 .29968 L
.09936 .30357 L
.13942 .32054 L
.17949 .33649 L
.19116 .33974 L
.21955 .34557 L
.25962 .35767 L
.29968 .36555 L
.33974 .36627 L
.37981 .35238 L
.39036 .33974 L
.39818 .29968 L
.38792 .25962 L
.37981 .23643 L
.3722 .21955 L
.34878 .17949 L
.33974 .16013 L
.32646 .13942 L
.29968 .09984 L
.29935 .09936 L
.2675 .05929 L
.25962 .04627 L
.23888 .01923 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P000182000`400?l00000o`00003ooooooolQ
ooooo`00o`00000P0000007ooooo00000`00003oooooooooo`3ooooooacooooo0@000001ooooo`00
00<00000ooooooooool0oooooolLooooo`4000000Oooool0000300000?oooooooooo0?oooooo7?oo
ool10000007ooooo00000`00003oooooooooo`3ooooooacooooo0@000001ooooo`0000<00000oooo
ooooool0@Oooool00ol0003oooooooooo`02ooooo`07o`000?ooooooooooo`000?oooooo0000oooo
o`06o`000003ooooool0003ooooo00;ooooo00?o0000ooooooooool0`?ooool10000007ooooo0000
0`00003oooooooooo`02ooooocl0o`0000?o00000>H06@3V01T00P3V01T03Ol00000c00c0<`0<ol0
0000/`1<o`00002I06Ko000007l0Ool00000IP2Io`00001<0;<00_l0000401T0iP03o`0000000?l0
003o0;X0003o1Oooool10000007ooooo00000`00003oooooooooo`02oooood00o`0000?o00000>H0
6@3V01T00P3V01T02ol00000c00c0<`0<ol00000/`1<o`00002I06Ko000007l0Ool00000IP2I00;o
000000<0<`3<o`00000I0>H00`0I0>H00ol00000003o0000o`2i0000o`Gooooo0@000001ooooo`00
00<00000ooooooooool00_oooom10?l00005o`00003V01T0iP0I0>H06Ol000000`3<03<02?l00000
/`1<o`00002I06Ko000007l0Ool00000IP2I0_l000000`0c0<co000001T0iP0301T0iP03o`000000
0?l0003o0;P0003o1Oooool10000007ooooo00000`00003oooooooooo`02oooood80o`0000Go0000
0>H06@3V01T0iP0Io`0000020<`0<`07o`00002c04`0/`1<o`00002I06Ko000007l0O`03o`000003
03<0c?l000006@3V00@06@3V00?o00000000o`000?l0]`000?l5ooooo`4000000Oooool000030000
0?oooooooooo00;ooooo@P3o00000ol00000iP0I0>H06@020>H06@04o`00003<03<0c00co`000080
/`1<00Wo000009T0I_l00000O`1oo`00001<0;?o000003<0c?l000001@0I0>H00ol00000003o0000
o`2f0000o`Gooooo0@000001ooooo`0000<00000ooooooooool00_oooom30?l00005o`00003V01T0
iP0I0>H06Ol000000`3<03<00ol00000/`1<o`00000209T0IPCo00000P0c0<`00ol000006@3V01T0
iP0301T0iP03o`0000000?l0003o0;D0003o1Oooool10000007ooooo00000`00003oooooooooo`02
oooood@0o`0000Go00000>H06@3V01T0iP0Io`0000020<`0<`04o`00002c04`0/`1<o`000080V@1V
0_l00000101<0;?o000003<0c?l0000501T0iP03o`0000000?l0003o0;D0003o1Oooool10000007o
oooo00000`00003oooooooooo`02ooooodD0o`0000Go00000>H06@3V01T0iP0Io`0000020<`0<`05
o`00002c04`0/`1<o`00002I06H00_l000001@1<0;?o000003<0c00c0<co000000D06@3V00?o0000
0000o`000?l0]0000?l5ooooo`4000000Oooool0000300000?oooooooooo00;oooooA@3o00000ol0
0000iP0I0>H06@020>H06@04o`00003<03<0c00co`000080/`1<0ol000000`1<0;?o000003<0c002
03<0c003o`00000I0>H06@3V00806@3V00?o00000000o`000?l0]0000?l5ooooo`4000000Oooool0
000300000?oooooooooo00;oooooAP3o00001Ol00000iP0I0>H06@3V01Wo00000080c00c00Co0000
0;<0C02c04`0/`1<0_l0000204`0/`04o`00000c0<`0<`3<o`0000D06@3V00?o00000000o`000?l0
/`000?l5ooooo`4000000Oooool0000300000?oooooooooo00;oooooAP3o00000ol00000iP0I0>H0
6@020>H06@04o`00003<03<0c00co`000080/`1<0ol000000`1<0;?o000003<0c00203<0c003o`00
000I0>H06@3V00806@3V00?o00000000o`000?l0/`000?l5ooooo`4000000Oooool0000300000?oo
oooooooo00;oooooA`3o00000ol00000iP0I0>H06@020>H06@03o`00003<03<0c00c00Go00000P1<
0;<01Ol00000<`3<03<0c00c0<co000000@06@3V00?o00000000o`000?l0/P000?l5ooooo`400000
0Oooool0000300000?oooooooooo00;oooooA`3o00000ol00000iP0I0>H06@030>H06@04o`00003<
03<0c00c0<`0<`Co00000P1<0;<01Ol00000<`3<03<0c00c0<co000000<06@3V00?o00000000o`00
0?l0/P000?l5ooooo`4000000Oooool0000300000?oooooooooo00;oooooB03o00000ol00000iP0I
0>H06@030>H06@03o`00003<03<0c00c00Go00000P1<0;<01Ol00000<`3<03<0c00c0<co000000<0
6@3V00?o00000000o`000?l0/@000?l5ooooo`4000000Oooool0000300000?oooooooooo00;ooooo
B@3o00000ol00000iP0I0>H06@030>H06@03o`00003<03<0c00c00Go00000P1<0;<01Ol00000<`3<
03<0c00c0<co000000<06@3V00?o00000000o`000?l0/0000?l5ooooo`4000000Oooool000030000
0?oooooooooo00;oooooBP3o00000ol00000iP0I0>H06@030>H06@03o`00003<03<0c00c00Go0000
0P1<0;<01Ol00000<`3<03<0c00c0<co000000<06@3V00?o00000000o`000?l0[`000?l5ooooo`40
00000Oooool0000300000?oooooooooo00;oooooB`3o00000ol00000iP0I0>H06@030>H06@04o`00
003<03?o00000;<0C0Co00000P1<0;<01Ol00000<`3<03<0c00c0<co000000<06@3V00?o00000000
o`000?l0[P000?l5ooooo`4000000Oooool0000300000?oooooooooo00;oooooC03o00000ol00000
iP0I0>H06@020>H06@05o`00003<03<0c00co`00002c04`01?l0000204`0/`;o00000P0c0<`01Ol0
00006@3V01T0iP0I0>Ko00000:l0003o1Oooool10000007ooooo00000`00003oooooooooo`02oooo
od`0o`0000?o00000>H06@3V01T00`3V01T01_l00000c00co`00002c04co000009T0IP?o00000`1<
0;<01?l00000<`3<03<0c?l0000301T0iP03o`0000000?l0003o0:`0003o1Oooool10000007ooooo
00000`00003oooooooooo`02ooooodd0o`0000?o00000>H06@3V01T00P3V01T01ol00000c00c0<`0
<ol00000/`1<o`00002I06H00ol0000304`0/`;o000000<0<`3<o`00000I0>H00P0I0>H00ol00000
003o0000o`2[0000o`Gooooo0@000001ooooo`0000<00000ooooooooool00_oooom>0?l00003o`00
003V01T0iP0I0080iP0I00Oo00000<`0<`3<03?o00000;<0C?l00000V@1V00Co00000`1<0;<00ol0
0000<`3<o`00000301T0iP03o`0000000?l0003o0:X0003o1Oooool10000007ooooo00000`00003o
ooooooooo`02ooooodl0o`0000Go00000>H06@3V01T0iP0Io`0000020<`0<`05o`00002c04`0/`1<
o`00002I06H01_l00000101<0;?o000003<0c?l0000301T0iP03o`0000000?l0003o0:T0003o1Ooo
ool10000007ooooo00000`00003oooooooooo`02oooooe00o`000_l000020>H06@04o`00003<03<0
c00co`000080/`1<00Go000009T0I_l00000O`1oo`00000206H0V@05o`00001<0;?o000003<0c?l0
00000P0I0>H00ol00000003o0000o`2Y0000o`Gooooo0@000001ooooo`0000<00000ooooooooool0
0_oooomA0?l00004o`00003V01T0iP0Io`000080c00c00So00000;<0C02c04co000009T0I_l00000
O`1oo`000080IP2I00Go000004`0/ol00000<`3<o`00000201T0iP03o`0000000?l0003o0:T0003o
1Oooool10000007ooooo00000`00003oooooooooo`02oooooe80o`0000Co00000>H06@3V01Wo0000
0P3<03<02?l00000/`1<0;<0C?l00000V@1Vo`00001o07oo00000P1V09T01Ol00000C02co`00000c
0<co000000806@3V00?o00000000o`000?l0Z0000?l5ooooo`4000000Oooool0000300000?oooooo
oooo00;oooooDP3o00001Ol00000iP0I0>H06@3V01Wo00000080c00c00?o00000;<0C02c04`00ol0
00002@1o07oo000006H0V@1V09Wo000004`0/ol00000<`3<o`00000201T0iP03o`0000000?l0003o
0:L0003o1Oooool10000007ooooo00000`00003oooooooooo`02oooooe<0o`0000Go00000>H06@3V
01T0iP0Io`0000020<`0<`04o`00002c04`0/`1<0;<0C0;o000000@0O`1oo`00001V09Wo00000P1<
0;<00ol00000<`3<o`00000201T0iP03o`0000000?l0003o0:H0003o1Oooool10000007ooooo0000
0`00003oooooooooo`02oooooe@0o`0000Go00000>H06@3V01T0iP0Io`0000020<`0<`04o`00002c
04`0/`1<0;<0C0?o00000P1V09T01Ol00000C02co`00000c0<co000000<06@3V00?o00000000o`00
0?l0Y@000?l5ooooo`4000000Oooool0000300000?oooooooooo00;oooooE03o00001Ol00000iP0I
0>H06@3V01Wo000000<0c00c0_l000020;<0C0?o00000P1V09T01Ol00000C02co`00000c0<co0000
00<06@3V00?o00000000o`000?l0Y0000?l5ooooo`4000000Oooool0000300000?oooooooooo00;o
ooooE@3o00001Ol00000iP0I0>H06@3V01Wo000000@0c00c00?o00000;<0C02c04`00ol0000206H0
V@05o`00001<0;?o000003<0c?l000000P0I0>H00ol00000003o0000o`2T0000o`Gooooo0@000001
ooooo`0000<00000ooooooooool00_oooomE0?l00003o`00003V01T0iP0I0080iP0I00?o00000<`0
<`3<03<00P3<03<00ol00000/`1<0;<0C003o`00000406H0VOl00000C02co`000080<`3<00Co0000
01T0iP0I0>Ko0000Y@000?l5ooooo`4000000Oooool0000300000?oooooooooo00;oooooEP3o0000
0ol00000iP0I0>H06@020>H06@03o`00003<03<0c00c0080c00c00?o00000;<0C02c04`00_l00002
06H0V@05o`00001<0;?o000003<0c?l000000`0I0>H00ol00000003o0000o`2R0000o`Gooooo0@00
0001ooooo`0000<00000ooooooooool00_oooomG0?l00003o`00003V01T0iP0I0080iP0I00?o0000
0<`0<`3<03<00P3<03<00ol00000/`1<0;<0C002o`000080IP2I00Go000004`0/ol00000<`3<o`00
000301T0iP03o`0000000?l0003o0:40003o1Oooool10000007ooooo00000`00003oooooooooo`02
oooooeL0o`0000?o00000>H06@3V01T00`3V01T00ol00000c00c0<`0<`020<`0<`03o`00002c04`0
/`1<00;o000000@0IP2Io`00001<0;?o00000P0c0<`01Ol000006@3V01T0iP0I0>Ko00000:80003o
1Oooool10000007ooooo00000`00003oooooooooo`02oooooeP0o`0000?o00000>H06@3V01T00`3V
01T00ol00000c00c0<`0<`020<`0<`03o`00002c04`0/`1<00;o000000@0IP2Io`00001<0;?o0000
0P0c0<`01Ol000006@3V01T0iP0I0>Ko00000:40003o1Oooool10000007ooooo00000`00003ooooo
ooooo`02oooooeP0o`0000?o00000>H06@3V01T00`3V01T00ol00000c00c0<`0<`020<`0<`03o`00
002c04`0/`1<00Co000000D0C02co`00000c0<`0<`3<o`00000401T0iP03o`0000000?l0003o09h0
003o1Oooool10000007ooooo00000`00003oooooooooo`02oooooeT0o`0000?o00000>H06@3V01T0
0`3V01T00ol00000c00c0<`0<`020<`0<`03o`00002c04`0/`1<00;o000000@0IP2Io`00001<0;?o
00000P0c0<`01Ol000006@3V01T0iP0I0>Ko00000:00003o1Oooool10000007ooooo00000`00003o
ooooooooo`02oooooeX0o`0000?o00000>H06@3V01T00`3V01T01Ol00000c00c0<`0<`3<03?o0000
0080/`1<0ol00000101V09Wo000004`0/ol0000203<0c005o`00000I0>H06@3V01T0i_l00000W`00
0?l5ooooo`4000000Oooool0000300000?oooooooooo00;oooooFP3o00000ol00000iP0I0>H06@03
0>H06@03o`00003<03<0c00c0080c00c00[o00000;<0C?l0003o000007l0Ool00000IP2Io`00001<
0;?o00000P0c0<`01Ol000006@3V01T0iP0I0>Ko000009h0003o1Oooool10000007ooooo00000`00
003oooooooooo`02oooooe/0o`0000?o00000>H06@3V01T00`3V01T01Ol00000c00c0<`0<`3<03?o
00000080/`1<0ol00000101V09Wo000004`0/ol0000203<0c003o`00000I0>H06@3V00806@3V00?o
00000000o`000?l0V`000?l5ooooo`4000000Oooool0000300000?oooooooooo00;oooooG03o0000
0ol00000iP0I0>H06@030>H06@08o`00003<03<0c00c0<`0<ol00000/`1<o`00002I06H2o`000004
06H0VOl00000C02co`000080<`3<00?o000001T0iP0I0>H00P0I0>H00ol00000003o0000o`2J0000
o`Gooooo0@000001ooooo`0000<00000ooooooooool00_oooomL0?l00003o`00003V01T0iP0I00<0
iP0I00oo00000<`0<`3<03<0c00co`00002c04co000009T0I_l00000O`1oo`00001V09Wo000004`0
/ol000000P0c0<`01Ol000006@3V01T0iP0I0>Ko000009`0003o1Oooool10000007ooooo00000`00
003oooooooooo`02oooooed0o`0000?o00000>H06@3V01T00`3V01T02_l00000c00c0<`0<`3<03?o
00000;<0C?l00000V@1Vo`00001o07l2o`00000304`0/ol00000<`3<0080<`3<00Go000001T0iP0I
0>H06@3Vo`00002K0000o`Gooooo0@000001ooooo`0000<00000ooooooooool00_oooomN0?l00003
o`00003V01T0iP0I0080iP0I00Go00000<`0<`3<03<0c00co`0000020;<0C0;o000000H0O`1oo`00
001V09Wo000004`0/ol0000303<0c005o`00000I0>H06@3V01T0i_l00000VP000?l5ooooo`400000
0Oooool0000300000?oooooooooo00;oooooGP3o00000ol00000iP0I0>H06@030>H06@0?o`00003<
03<0c00c0<`0<ol00000/`1<o`00002I06Ko000007l0Ool00000IP2Io`00001<0;?o000000<0<`3<
00Go000001T0iP0I0>H06@3Vo`00002I0000o`Gooooo0@000001ooooo`0000<00000ooooooooool0
0_oooomO0?l00003o`00003V01T0iP0I00<0iP0I00Co00000<`0<`3<03?o00000P2c04`02Ol00000
V@1Vo`00001o07oo000006H0VOl00000C02co`00000303<0c005o`00000I0>H06@3V01T0i_l00000
V0000?l5ooooo`4000000Oooool0000300000?oooooooooo00;oooooG`3o00000ol00000iP0I0>H0
6@030>H06@04o`00003<03<0c00co`000080/`1<00Wo000009T0I_l00000O`1oo`00001V09Wo0000
04`0/ol000000`0c0<`01Ol000006@3V01T0iP0I0>Ko000009P0003o1Oooool10000007ooooo0000
0`00003oooooooooo`02ooooof00o`0000?o00000>H06@3V01T00`3V01T01?l00000c00c0<`0<ol0
00020;<0C009o`00002I06Ko000007l0Ool00000IP2Io`00001<0;?o000000<0<`3<00Go000001T0
iP0I0>H06@3Vo`00002G0000o`Gooooo0@000001ooooo`0000<00000ooooooooool00_oooomP0?l0
0003o`00003V01T0iP0I00@0iP0I00?o00000<`0<ol000000P2c04`01ol00000V@1V09T0I_l00000
O`1oo`00001V09T00_l0000303<0c003o`00000I0>H06@3V00806@3V00?o00000000o`000?l0U000
0?l5ooooo`4000000Oooool0000300000?oooooooooo00;oooooH@3o00000ol00000iP0I0>H06@03
0>H06@04o`00003<03<0c00co`000080/`1<00Wo000009T0I_l00000O`1oo`00001V09Wo000004`0
/ol000000`0c0<`00ol000006@3V01T0iP0201T0iP03o`0000000?l0003o09<0003o1Oooool10000
007ooooo00000`00003oooooooooo`02ooooof40o`0000?o00000>H06@3V01T0103V01T01?l00000
c00c0<`0<ol000020;<0C009o`00002I06Ko000007l0Ool00000IP2Io`00001<0;?o000000<0<`3<
00?o000001T0iP0I0>H00P0I0>H00ol00000003o0000o`2B0000o`Gooooo0@000001ooooo`0000<0
0000ooooooooool00_oooomR0?l00003o`00003V01T0iP0I00<0iP0I00Co00000<`0<`3<03?o0000
0P2c04`01Ol00000V@1V09T0I_l00000O`1o00;o000000<0C02co`00000c0<`00P0c0<`00ol00000
6@3V01T0iP0201T0iP03o`0000000?l0003o0980003o1Oooool10000007ooooo00000`00003ooooo
ooooo`02ooooof80o`0000?o00000>H06@3V01T0103V01T01?l00000c00c0<`0<ol000020;<0C009
o`00002I06Ko000007l0Ool00000IP2Io`00001<0;?o000000<0<`3<00?o000001T0iP0I0>H00P0I
0>H00ol00000003o0000o`2A0000o`Gooooo0@000001ooooo`0000<00000ooooooooool00_oooomS
0?l00003o`00003V01T0iP0I00<0iP0I00Co00000<`0<`3<03?o00000P2c04`01Ol00000V@1V09T0
I_l00000O`1o00;o000000<0C02co`00000c0<`00P0c0<`00ol000006@3V01T0iP0201T0iP03o`00
00000?l0003o0940003o1Oooool10000007ooooo00000`00003oooooooooo`02ooooof<0o`0000?o
00000>H06@3V01T0103V01T01?l00000c00c0<`0<ol000020;<0C003o`00002I06H0V@1V00?o0000
0P1<0;<01Ol00000<`3<03<0c00c0<co000000@06@3V00?o00000000o`000?l0T0000?l5ooooo`40
00000Oooool0000300000?oooooooooo00;oooooI03o00000ol00000iP0I0>H06@030>H06@05o`00
003<03<0c00c0<`0<ol000000P2c04`01_l00000V@1Vo`000?l00000IP2Io`000080C02c00Go0000
03<0c00c0<`0<`3<o`00000401T0iP03o`0000000?l0003o08l0003o1Oooool10000007ooooo0000
0`00003oooooooooo`02ooooof@0o`0000?o00000>H06@3V01T00`3V01T01Ol00000c00c0<`0<`3<
03?o00000080/`1<00?o000009T0IP2I06H00ol0000204`0/`05o`00000c0<`0<`3<03<0c?l00000
100I0>H00ol00000003o0000o`2?0000o`Gooooo0@000001ooooo`0000<00000ooooooooool00_oo
oomU0?l00003o`00003V01T0iP0I00<0iP0I00Go00000<`0<`3<03<0c00co`0000020;<0C0Co0000
00D0IP2Io`00001<0;<0C02co`00000303<0c0;o00000`0I0>H00ol00000003o0000o`2>0000o`Go
oooo0@000001ooooo`0000<00000ooooooooool00_oooomU0?l00003o`00003V01T0iP0I00<0iP0I
00Go00000<`0<`3<03<0c00co`0000030;<0C0?o000000<0IP2Io`00001<0;<00P1<0;<01Ol00000
<`3<03<0c00c0<co000000<06@3V00?o00000000o`000?l0SP000?l5ooooo`4000000Oooool00003
00000?oooooooooo00;oooooIP3o00000ol00000iP0I0>H06@030>H06@05o`00003<03<0c00c0<`0
<ol000000`2c04`3o`00000306H0VOl00000C02c0080C02c00Go000003<0c00c0<`0<`3<o`000003
01T0iP03o`0000000?l0003o08d0003o1Oooool10000007ooooo00000`00003oooooooooo`02oooo
ofL0o`0000?o00000>H06@3V01T00P3V01T00ol00000c00c0<`0<`020<`0<`04o`00002c04`0/`1<
0;<0C0?o000000<0IP2Io`00001<0;<00P1<0;<01Ol00000<`3<03<0c00c0<co000000<06@3V00?o
00000000o`000?l0S0000?l5ooooo`4000000Oooool0000300000?oooooooooo00;oooooJ03o0000
0ol00000iP0I0>H06@020>H06@03o`00003<03<0c00c0080c00c00Go00000;<0C02c04co000009T0
IP02o`00000306H0VOl00000C02c0080C02c00Go000003<0c00c0<`0<`3<o`00000301T0iP03o`00
00000?l0003o08/0003o1Oooool10000007ooooo00000`00003oooooooooo`02ooooofP0o`0000?o
00000>H06@3V01T00P3V01T00ol00000c00c0<`0<`030<`0<`03o`00002c04`0/`1<00;o000000@0
O`1oo`00001V09Wo00000`1<0;<01?l00000<`3<03<0c?l0000401T0iP03o`0000000?l0003o08X0
003o1Oooool10000007ooooo00000`00003oooooooooo`02ooooofP0o`0000?o00000>H06@3V01T0
0`3V01T00ol00000c00c0<`0<`020<`0<`04o`00002c04`0/`1<0;<0C0;o000000@0O`1oo`00001V
09Wo00000P1<0;<01Ol00000<`3<03<0c00c0<co000000<06@3V00?o00000000o`000?l0RP000?l5
ooooo`4000000Oooool0000300000?oooooooooo00;oooooJ@3o00000ol00000iP0I0>H06@030>H0
6@03o`00003<03<0c00c0080c00c00Go00000;<0C02c04co000009T0IP02o`000080IP2I00Co0000
04`0/`1<0;?o00000`0c0<`01Ol000006@3V01T0iP0I0>Ko000008/0003o1Oooool10000007ooooo
00000`00003oooooooooo`02ooooofT0o`0000?o00000>H06@3V01T00`3V01T00ol00000c00c0<`0
<`020<`0<`04o`00002c04`0/`1<0;<0C0;o000000D0O`1oo`00001V09T0IP2Io`00000204`0/`04
o`00000c0<`0<`3<o`0000@06@3V00?o00000000o`000?l0R0000?l5ooooo`4000000Oooool00003
00000?oooooooooo00;oooooJ@3o00000ol00000iP0I0>H06@040>H06@03o`00003<03<0c00c0080
c00c00So00000;<0C02c04co000009T0I_l00000O`1oo`000080IP2I00?o000004`0/ol000000`0c
0<`00ol000006@3V01T0iP0201T0iP03o`0000000?l0003o08L0003o1Oooool10000007ooooo0000
0`00003oooooooooo`02ooooofX0o`0000?o00000>H06@3V01T00`3V01T00ol00000c00c0<`0<`02
0<`0<`0;o`00002c04`0/`1<0;<0C?l00000V@1Vo`00001o07oo000006H0VOl000000P1<0;<01Ol0
0000<`3<03<0c00c0<co000000<06@3V00?o00000000o`000?l0Q`000?l5ooooo`4000000Oooool0
000300000?oooooooooo00;oooooJP3o00000ol00000iP0I0>H06@040>H06@03o`00003<03<0c00c
0080c00c00_o00000;<0C02c04`0/`1<o`00002I06Ko000007l0Ool00000IP2Io`00000204`0/`05
o`00000c0<`0<`3<03<0c?l000000`0I0>H00ol00000003o0000o`260000o`Gooooo0@000001oooo
o`0000<00000ooooooooool00_oooomZ0?l00003o`00003V01T0iP0I00@0iP0I00?o00000<`0<`3<
03<00P3<03<01ol00000/`1<0;<0C02c04co000009T0I_l000000P1o07l2o`000080C02c00Go0000
03<0c00c0<`0<`3<o`00000301T0iP03o`0000000?l0003o08H0003o1Oooool10000007ooooo0000
0`00003oooooooooo`02ooooo`;o0000J03o00000ol00000iP0I0>H06@050>H06@03o`00003<03<0
c00c0080c00c00_o00000;<0C02c04`0/`1<o`00002I06Ko000007l0Ool00000IP2Io`00000204`0
/`05o`00000c0<`0<`3<03<0c?l000000`0I0>H00ol00000003o0000o`250000o`Gooooo0@000001
ooooo`0000<00000ooooooooool00_ooool20>H06@;o0000I`3o00000ol00000iP0I0>H06@040>H0
6@03o`00003<03<0c00c0080c00c00Go00000;<0C02c04`0/`1<o`00000209T0IP04o`00001o07oo
0000o`000080C02c00Go000003<0c00c0<`0<`3<o`00000401T0iP03o`0000000?l0003o08@0003o
1Oooool10000007ooooo00000`00003oooooooooo`02ooooo`@0iP0I00?o00000?l0003o0000I03o
00000ol00000iP0I0>H06@050>H06@03o`00003<03<0c00c0080c00c00Co00000;<0C02c04co0000
0P2I06H01Ol00000O`1oo`00001V09Wo00000080C02c00Go000003<0c00c0<`0<`3<o`00000301T0
iP03o`0000000?l0003o08@0003o1Oooool10000007ooooo00000`00003oooooooooo`02ooooo`D0
iP0I0_l0001T0?l00003o`00003V01T0iP0I00D0iP0I00?o00000<`0<`3<03<00P3<03<01Ol00000
/`1<0;<0C02c04co00000080V@1V00Co000007l0Ool0003o00000P1<0;<01Ol00000<`3<03<0c00c
0<co000000@06@3V00?o00000000o`000?l0P`000?l5ooooo`4000000Oooool0000300000?oooooo
oooo00;ooooo0_l000050>H06@;o0000HP3o00000ol00000iP0I0>H06@060>H06@03o`00003<03<0
c00c0080c00c00Co00000;<0C02c04co00000P2I06H01Ol00000O`1oo`00001V09Wo00000080C02c
00Co000003<0c00c0<co00001@0I0>H00ol00000003o0000o`220000o`Gooooo0@000001ooooo`00
00<00000ooooooooool00_ooool20<`0<`03o`00003V01T0iP0I00@0iP0I00?o00000?l0003o0000
H03o00000ol00000iP0I0>H06@050>H06@03o`00003<03<0c00c0080c00c00Co00000;<0C02c04co
00000P2I06H00ol00000O`1o07l0O`02o`000080C02c00Go000003<0c00c0<`0<`3<o`00000401T0
iP03o`0000000?l0003o0880003o1Oooool10000007ooooo00000`00003oooooooooo`02ooooo`<0
c00c0_l000050>H06@;o0000H03o00000ol00000iP0I0>H06@060>H06@03o`00003<03<0c00c0080
c00c00Co00000;<0C02c04co00000P2I06H01Ol00000O`1oo`00001V09Wo00000080C02c00Co0000
03<0c00c0<co00001@0I0>H00ol00000003o0000o`210000o`Gooooo0@000001ooooo`0000<00000
ooooooooool00_ooool2o`0000<0c00c00?o00000>H06@3V01T0103V01T2o`0005h0o`0000?o0000
0>H06@3V01T01P3V01T00ol00000c00c0<`0<`020<`0<`04o`00002c04`0/`1<o`000080V@1V00Go
000007l0Ool00000IP2Io`00000204`0/`05o`00000c0<`0<`3<03<0c?l000001@0I0>H00ol00000
003o0000o`200000o`Gooooo0@000001ooooo`0000<00000ooooooooool00_ooool20;<0C004o`00
003<03<0c00c0<`0<`;o00001P3V01T2o`0005`0o`0000?o00000>H06@3V01T01`3V01T00ol00000
c00c0<`0<`020<`0<`03o`00002c04co00000080V@1V00Ko000007l0O`1o07oo000006H0VOl00002
04`0/`05o`00000c0<`0<`3<03<0c?l00000100I0>H00ol00000003o0000o`200000o`Gooooo0@00
0001ooooo`0000<00000ooooooooool00_ooool30;<0C003o`00003<03<0c00c0080c00c00?o0000
0>H06@3V01T01@3V01T00ol00000o`000?l0001J0?l00003o`00003V01T0iP0I00H0iP0I00?o0000
0<`0<`3<03<00P3<03<01?l00000/`1<0;<0C?l0000209T0IP05o`00001o07oo000006H0VOl00000
0P1<0;<00ol00000<`3<03<0c00203<0c003o`00000I0>H06@3V00806@3V00?o00000000o`000?l0
O`000?l5ooooo`4000000Oooool0000300000?oooooooooo00;ooooo0ol00000102c04co0000o`00
0?l000020<`0<`Go00000`3V01T4o`0005P0o`0000?o00000>H06@3V01T01`3V01T00ol00000c00c
0<`0<`020<`0<`06o`00002c04co0000o`00002I06Ko00000P1o07l00ol00000IP2Io`00000204`0
/`;o00000`0c0<`00ol000006@3V01T0iP0201T0iP03o`0000000?l0003o07h0003o1Oooool10000
007ooooo00000`00003oooooooooo`02ooooo`;o000000D0V@1Vo`000?l0003o00000;<0C004o`00
00<0c00c0ol000040>H06@Co0000E03o00000ol00000iP0I0>H06@070>H06@03o`00003<03<0c00c
0080c00c00Ko00000;<0C02c04co000009T0I_l0000207l0O`03o`00001V09Wo000000<0C02c00Go
000003<0c00c0<`0<`3<o`00000401T0iP03o`0000000?l0003o07h0003o1Oooool10000007ooooo
00000`00003oooooooooo`02ooooo`80O`1o0ol00000102I06Ko0000o`000?l000020;<0C0?o0000
0`3<03<3o`0000D0iP0I0ol0001A0?l00003o`00003V01T0iP0I00L0iP0I00?o00000<`0<`3<03<0
0P3<03<01?l00000/`1<0;<0C?l0000209T0IP06o`00001o07l0O`1oo`00001V09Wo00000`1<0;<0
1Ol00000<`3<03<0c00c0<co000000@06@3V00?o00000000o`000?l0O@000?l5ooooo`4000000Ooo
ool0000300000?oooooooooo00;ooooo0ol0000207l0O`;o00000P2I06H3o`000080/`1<0_l00004
0<`0<`?o00001@3V01T2o`0004l0o`0000?o00000>H06@3V01T01`3V01T00ol00000c00c0<`0<`02
0<`0<`07o`00002c04`0/`1<0;<0C?l00000V@1Vo`00000207l0O`04o`00001V09T0IP2Io`000080
C02c00Go000003<0c00c0<`0<`3<o`00000401T0iP03o`0000000?l0003o07d0003o1Oooool10000
007ooooo00000`00003oooooooooo`02ooooo`<0IP2I0ol000000`1o07oo0000o`00000309T0IP;o
00000P2c04`3o`0000@0c00c0_l000050>H06@;o0000C03o00000ol00000iP0I0>H06@090>H06@03
o`00003<03<0c00c0080c00c00Co00000;<0C02c04co00000P2I06H01_l00000O`1o07l0Ool00000
IP2Io`000080C02c00?o000003<0c00c0<`00P0c0<`01Ol000006@3V01T0iP0I0>Ko000007l0003o
1Oooool10000007ooooo00000`00003oooooooooo`02ooooo`?o00000`1V09T6o`000080V@1V0_l0
00030;<0C0;o0000103<03<2o`0000D0iP0I0ol000190?l00003o`00003V01T0iP0I00T0iP0I00?o
00000<`0<`3<03<00P3<03<01?l00000/`1<0;<0C?l0000209T0IP04o`00001o07l0O`1oo`000080
IP2I00Co000004`0/`1<0;?o00000`0c0<`00ol000006@3V01T0iP0201T0iP03o`0000000?l0003o
07`0003o1Oooool10000007ooooo00000`00003oooooooooo`02ooooo`<0C02c0ol0000306H0V@Go
00000P2I06H3o`000080/`1<0_l000040<`0<`;o00001P3V01T2o`0004L0o`0000?o00000>H06@3V
01T02@3V01T00ol00000c00c0<`0<`020<`0<`05o`00002c04`0/`1<0;<0C?l000000P2I06H01?l0
0000O`1o07l0Ool0000206H0V@03o`00001<0;?o000000@0<`3<00Go000001T0iP0I0>H06@3Vo`00
001n0000o`Gooooo0@000001ooooo`0000<00000ooooooooool00_ooool3o`0000<0C02c0ol00003
06H0V@Co00000`2I06H2o`000080/`1<0_l000040<`0<`;o00001P3V01T3o`0004@0o`0000?o0000
0>H06@3V01T02@3V01T00ol00000c00c0<`0<`020<`0<`05o`00002c04`0/`1<0;<0C?l000000P2I
06H01?l00000O`1o07l0Ool0000206H0V@03o`00001<0;?o000000@0<`3<00?o000001T0iP0I0>H0
0P0I0>H00ol00000003o0000o`1k0000o`Gooooo0@000001ooooo`0000<00000ooooooooool00_oo
ool2o`00000403<0c?l0003o0000o`0000<0C02c0ol0000206H0V@Co00000`2I06H2o`000080/`1<
00?o00000<`0<`3<03<00`3<03<2o`0000L0iP0I0ol000110?l00003o`00003V01T0iP0I00T0iP0I
00?o00000<`0<`3<03<00P3<03<01Ol00000/`1<0;<0C02c04co00000080V@1V00Co000007l0O`1o
07oo00000P1V09T01?l00000C02c04`0/ol0000303<0c003o`00000I0>H06@3V00<06@3V00?o0000
0000o`000?l0NP000?l5ooooo`4000000Oooool0000300000?oooooooooo00;ooooo0P0I0>H3o`00
000403<0c?l0003o0000o`0000<0C02c0_l0000206H0V@04o`00001o07oo0000o`0000<0V@1V00?o
00000;<0C02c04`00_l000050<`0<`;o0000203V01T3o`0003d0o`0000?o00000>H06@3V01T02`3V
01T00ol00000c00c0<`0<`020<`0<`04o`00002c04`0/`1<o`0000<0V@1V00Co000007l0O`1o07oo
00000P1V09T00ol00000C02co`00000403<0c003o`00000I0>H06@3V00<06@3V00?o00000000o`00
0?l0N@000?l5ooooo`4000000Oooool0000300000?oooooooooo00;ooooo1@0I0>H3o`00000403<0
c?l0003o0000o`000080C02c0_l00000101V09Wo0000o`00001o07l2o`000080V@1V00Go00000;<0
C02c04`0/`1<o`0000060<`0<`03o`00003V01T0iP0I00P0iP0I0ol0000j0?l00003o`00003V01T0
iP0I00/0iP0I00?o00000<`0<`3<03<00P3<03<01Ol00000/`1<0;<0C02c04co00000080V@1V00Co
000007l0O`1o07oo00000P1V09T00ol00000C02co`00000403<0c003o`00000I0>H06@3V00@06@3V
00?o00000000o`000?l0N0000?l5ooooo`4000000Oooool0000300000?oooooooooo00;ooooo1?l0
000401T0iP;o00000P0c0<`3o`00000404`0/ol0003o000006H0V@;o000000<0O`1oo`000?l00000
0ol000020;<0C0;o00001@3<03<4o`0000T0iP0I0ol0000g0?l00003o`00003V01T0iP0I00/0iP0I
00?o00000<`0<`3<03<00P3<03<01Ol00000/`1<0;<0C02c04co000000<0V@1V00Ko000007l0O`1o
07oo000006H0VOl0000204`0/`03o`00000c0<`0<`3<0080<`3<00?o000001T0iP0I0>H0100I0>H0
0ol00000003o0000o`1g0000o`Gooooo0@000001ooooo`0000<00000ooooooooool00_ooool40000
o`;o0000100I0>H2o`0000<0<`3<0_l00000101<0;?o0000o`00001V09T2o`000080O`1o1?l00002
0;<0C0;o00001`3<03<5o`0000L0iP0I1Ol0000b0?l00003o`00003V01T0iP0I00/0iP0I00?o0000
0<`0<`3<03<00P3<03<01Ol00000/`1<0;<0C02c04co000000<0V@1V00Ko000007l0O`1o07oo0000
06H0VOl0000204`0/`03o`00000c0<`0<`3<0080<`3<00?o000001T0iP0I0>H0100I0>H00ol00000
003o0000o`1g0000o`Gooooo0@000001ooooo`0000<00000ooooooooool00_ooool60000o`03o`00
000I0>H06@3V00<06@3V0_l0000303<0c004o`00001<0;<0C02co`000080IP2I0_l0000207l0O`Co
00000P2c04`2o`0000X0c00c0ol000090>H06@Co0000;@3o00000ol00000iP0I0>H06@0;0>H06@03
o`00003<03<0c00c00<0c00c00Go00000;<0C02c04`0/`1<o`00000309T0IP04o`00001o07l0O`1o
o`000080IP2I00Co000004`0/`1<0;?o0000100c0<`00ol000006@3V01T0iP0401T0iP03o`000000
0?l0003o07H0003o1Oooool10000007ooooo00000`00003oooooooooo`02ooooo`L0003o0_l00005
01T0iP;o00000P0c0<`2o`00000304`0/ol0003o00000080IP2I0ol000000`1o07oo0000o`000002
o`000080/`1<1?l000090<`0<`?o00002P3V01T4o`0002P0o`0000?o00000>H06@3V01T0303V01T0
0ol00000c00c0<`0<`030<`0<`05o`00002c04`0/`1<0;<0C?l000000`2I06H01ol00000O`1o07l0
O`1o07oo000006H0VOl000000P1<0;<00ol00000<`3<03<0c00303<0c003o`00000I0>H06@3V00<0
6@3V00?o00000000o`000?l0MP000?l5ooooo`4000000Oooool0000300000?oooooooooo00;ooooo
2@000?l2o`0000D06@3V0_l0000203<0c0;o000000@0C02co`000?l0003o00000P1V09T2o`000003
07l0Ool0003o000000;o0000102c04`5o`0000L0c00c0_l0000<0>H06@?o00008`3o0002o`0000h0
iP0I00?o00000<`0<`3<03<0103<03<00ol00000/`1<0;<0C0020;<0C005o`00002I06H0V@1V09T0
I_l000000P1o07l00ol00000IP2Io`00000304`0/`03o`00000c0<`0<`3<0080<`3<00?o000001T0
iP0I0>H0100I0>H00ol00000003o0000o`1e0000o`Gooooo0@000001ooooo`0000<00000oooooooo
ool00_ooool;0000o`03o`00000I0>H06@3V00@06@3V00Go000003<0c00c0<`0<`3<o`00000304`0
/`?o000000@0IP2Io`000?l00000O`1o1_l000050;<0C0Co00001@3<03<2o`0000d0iP0I1Ol0000K
0?l000?o0000403V01T00ol00000c00c0<`0<`040<`0<`03o`00002c04`0/`1<0080/`1<00Go0000
09T0IP2I06H0V@1Vo`00000207l0O`04o`00001V09T0IP2Io`000080C02c00?o000003<0c00c0<`0
0`0c0<`00ol000006@3V01T0iP0301T0iP03o`0000000?l0003o07D0003o1Oooool10000007ooooo
00000`00003oooooooooo`02ooooo``0003o0_l0000501T0iP;o00000P0c0<`3o`0000<0C02c2Ol0
00000`2I06Ko0000o`000003o`0000@0/`1<0ol000040<`0<`?o00003`3V01T6o`000180o`000ol0
000B0>H06@03o`00003<03<0c00c00D0c00c00?o00000;<0C02c04`00P2c04`01Ol00000V@1V09T0
IP2I06Ko00000080O`1o00Co000006H0V@1V09Wo00000`1<0;<00ol00000<`3<03<0c00203<0c003
o`00000I0>H06@3V00@06@3V00?o00000000o`000?l0M0000?l5ooooo`4000000Oooool000030000
0?oooooooooo00;ooooo3P000?l2o`0000D06@3V0_l0000303<0c0Co00000P1<0;<5o`00000307l0
Ool0003o000000;o00000P2I06H4o`0000<0/`1<0_l000050<`0<`;o00004`3V01T9o`0000H0o`00
0ol0000D0>H06@03o`00003<03<0c00c00H0c00c00?o00000;<0C02c04`00P2c04`01Ol00000V@1V
09T0IP2I06Ko000000<0O`1o00?o000006H0VOl000000`1<0;<00ol00000<`3<03<0c00303<0c003
o`00000I0>H06@3V00<06@3V00?o00000000o`000?l0M0000?l5ooooo`4000000Oooool000030000
0?oooooooooo00;ooooo40000?l3o`0000@06@3V0_l0000503<0c0Co000000<0C02co`000?l00000
0_l0000307l0O`?o00000`2I06H00ol00000/`1<0;<0C0020;<0C0;o00001@3<03<3o`0001T0iP0I
1_l0000G0>H06@03o`00003<03<0c00c00H0c00c00?o00000;<0C02c04`00P2c04`01Ol00000V@1V
09T0IP2I06Ko000000<0O`1o00Co000006H0V@1V09Wo00000`1<0;<00ol00000<`3<03<0c00203<0
c003o`00000I0>H06@3V00@06@3V00?o00000000o`000?l0L`000?l5ooooo`4000000Oooool00003
00000?oooooooooo00;ooooo4`000?l2o`0000@06@3V0ol0000603<0c0;o000000<0C02co`000?l0
00000ol0000307l0O`?o000000<0V@1Vo`000?l00000102c04`3o`0000D0c00c0ol0000b0>H06@03
o`00003<03<0c00c00L0c00c00?o00000;<0C02c04`00P2c04`01Ol00000V@1V09T0IP2I06Ko0000
00<0O`1o00Co000006H0V@1V09Wo00000`1<0;<00ol00000<`3<03<0c00203<0c003o`00000I0>H0
6@3V00@06@3V00?o00000000o`000?l0L`000?l5ooooo`4000000Oooool0000300000?oooooooooo
00;ooooo5@000?l2o`0000D06@3V0_l0000603<0c004o`00001<0;<0C02co`000080IP2I0_l00004
07l0O`03o`00002I06H0V@1V00;o00001@2c04`00ol00000c00c0<`0<`050<`0<`?o0000;`3V01T0
0ol00000c00c0<`0<`070<`0<`03o`00002c04`0/`1<00<0/`1<00Go000009T0IP2I06H0V@1Vo`00
000207l0O`04o`00001V09T0IP2Io`0000@0C02c00?o000003<0c00c0<`00P0c0<`00ol000006@3V
01T0iP0401T0iP03o`0000000?l0003o0780003o1Oooool10000007ooooo00000`00003ooooooooo
o`02oooooaL0003o0ol0000401T0iP?o0000100c0<`00ol00000C02c04`0/`02o`000080IP2I0_l0
000307l0O`05o`00002I06H0V@1V09T0I_l000001@2c04`00ol00000c00c0<`0<`070<`0<`;o0000
;03V01T00ol00000c00c0<`0<`080<`0<`03o`00002c04`0/`1<00<0/`1<00Go000009T0IP2I06H0
V@1Vo`00000307l0O`04o`00001V09T0IP2Io`0000<0C02c00?o000003<0c00c0<`00P0c0<`00ol0
00006@3V01T0iP0401T0iP03o`0000000?l0003o0780003o1Oooool10000007ooooo00000`00003o
ooooooooo`02oooooaX0003o0_l0000501T0iPCo000000<0<`3<o`000?l000000P1<0;<2o`000080
IP2I4?l000090<`0<`Ko0000903V01T3o`0000T0c00c0_l000050;<0C005o`00002I06H0V@1V09T0
I_l000000`1o07l01?l00000IP2I06H0VOl0000404`0/`03o`00000c0<`0<`3<0080<`3<00?o0000
01T0iP0I0>H0100I0>H2o`000780003o1Oooool10000007ooooo00000`00003oooooooooo`02oooo
oa`0003o0_l0000701T0iP03o`00000c0<`0<`3<00;o00000P1<0;<2o`0000@0IP2I3_l0000=0<`0
<`So0000603V01T4o`0000/0c00c00?o00000;<0C02c04`01@2c04`01Ol00000V@1V09T0IP2I06Ko
000000<0O`1o00Co000006H0V@1V09Wo0000101<0;<00ol00000<`3<03<0c00203<0c003o`00000I
0>H06@3V00D06@3V00?o00000000o`000?l0L0000?l5ooooo`4000000Oooool0000300000?oooooo
oooo00;ooooo7P000?l2o`0000H06@3V0_l0000203<0c0;o00000P1<0;<7o`0000<0IP2I1Ol00000
0`2I06Ko0000o`000003o`000180c00c1Ol0000@0>H06@?o00003P3<03<00ol00000/`1<0;<0C005
0;<0C003o`00002I06H0V@1V0080V@1V00Go000007l0O`1o07l0O`1oo`00000206H0V@03o`00001<
0;<0C02c0080C02c00?o000003<0c00c0<`00P0c0<`00ol000006@3V01T0iP0601T0iP03o`000000
0?l0003o06l0003o1Oooool10000007ooooo00000`00003oooooooooo`02ooooob00003o00?o0000
01T0iP0I0>H01@0I0>H2o`000080<`3<0_l0000704`0/`[o000000@0V@1Vo`00002c04`0/`1<0_l0
000E0<`0<a3o00003`3<03<2o`0000L0/`1<00?o000009T0IP2I06H00P2I06H00ol00000O`1o07l0
O`0207l0O`04o`00001V09T0IP2Io`0000@0C02c00?o000003<0c00c0<`00P0c0<`00ol000006@3V
01T0iP0601T0iP03o`0000000?l0003o06l0003o1Oooool10000007ooooo00000`00003ooooooooo
o`02ooooob40003o0_l0000701T0iP04o`00000c0<`0<`3<03<0c0Oo00001`1<0;<7o`000080/`1<
3ol0000T0<`0<`03o`00002c04`0/`1<00L0/`1<00?o000009T0IP2I06H00P2I06H00ol00000O`1o
07l0O`0207l0O`04o`00001V09T0IP2Io`0000D0C02c00?o000003<0c00c0<`00P0c0<`00ol00000
6@3V01T0iP0501T0iP03o`0000000?l0003o06l0003o1Oooool10000007ooooo00000`00003ooooo
ooooo`02ooooob<0003o0_l0000601T0iP;o0000200c0<`7o`00000304`0/ol0003o000000?o0000
00<0V@1Vo`000?l000003`2c04`4o`0001h0c00c0_l000090;<0C003o`00002I06H0V@1V00<0V@1V
00?o000007l0O`1o07l00P1o07l01?l00000IP2I06H0VOl0000504`0/`03o`00000c0<`0<`3<0080
<`3<00?o000001T0iP0I0>H01P0I0>H00ol00000003o0000o`1^0000o`Gooooo0@000001ooooo`00
00<00000ooooooooool00_oooolU0000o`;o00001P0I0>H00ol00000<`3<03<0c00<03<0c003o`00
001<0;<0C02c00Go000000<0V@1Vo`000?l000001Ol0000<0;<0C0?o00006P3<03<00ol00000/`1<
0;<0C0090;<0C003o`00002I06H0V@1V0080V@1V00?o000007l0O`1o07l00P1o07l00ol00000IP2I
06H0V@0206H0V@03o`00001<0;<0C02c0080C02c00?o000003<0c00c0<`00P0c0<`00ol000006@3V
01T0iP0601T0iP03o`0000000?l0003o06h0003o1Oooool10000007ooooo00000`00003ooooooooo
o`02ooooobL0003o0ol0000401T0iPCo00002`0c0<`01?l00000C02c04`0/`1<0;<4o`0000L0V@1V
1ol000080;<0C0Go0000503<03<00ol00000/`1<0;<0C0090;<0C003o`00002I06H0V@1V00<0V@1V
00?o000007l0O`1o07l00P1o07l00ol00000IP2I06H0V@0206H0V@03o`00001<0;<0C02c0080C02c
00?o000003<0c00c0<`00P0c0<`00ol000006@3V01T0iP0601T0iP03o`0000000?l0003o06h0003o
1Oooool10000007ooooo00000`00003oooooooooo`02ooooobX0003o0_l0000601T0iPKo00001P0c
0<`2o`000080C02c1ol0000:09T0IP?o00002P2c04`6o`0000P0c00c1_l0000:0;<0C0;o00001P2I
06H00ol00000O`1o07l0O`0207l0O`03o`00001V09T0IP2I0080IP2I00?o000004`0/`1<0;<00P1<
0;<00ol00000<`3<03<0c00203<0c003o`00000I0>H06@3V00L06@3V00?o00000000o`000?l0K@00
0?l5ooooo`4000000Oooool0000300000?oooooooooo00;ooooo;0000?l2o`0000X06@3V0ol00005
03<0c004o`00001<0;<0C02c04`0/`Co000000<0O`1oo`000?l000001?l0000709T0IP?o00003@2c
04`8o`0000h0/`1<0_l0000809T0IP03o`00001o07l0O`1o0080O`1o00?o000006H0V@1V09T00P1V
09T00ol00000C02c04`0/`0204`0/`03o`00000c0<`0<`3<00<0<`3<00?o000001T0iP0I0>H01P0I
0>H00ol00000003o0000o`1]0000o`Gooooo0@000001ooooo`0000<00000ooooooooool00_ooool^
0000o`Co00002@0I0>H00ol00000<`3<03<0c00303<0c004o`00001<0;<0C02c04`0/`;o000000<0
IP2Io`000?l000000_l0000307l0O`Co00001P2I06H3o`0001l0/`1<00?o000009T0IP2I06H01`2I
06H00ol00000O`1o07l0O`0307l0O`03o`00001V09T0IP2I0080IP2I00?o000004`0/`1<0;<00`1<
0;<00ol00000<`3<03<0c00203<0c003o`00000I0>H06@3V00H06@3V00?o00000000o`000?l0K@00
0?l5ooooo`4000000Oooool0000300000?oooooooooo00;ooooo<P000?l3o`0000L06@3V0_l00004
03<0c0;o00000`1<0;<2o`0000<0IP2I1?l0000307l0O`?o00001P2I06H5o`0001L0/`1<0ol00009
09T0IP;o00001@1o07l00ol00000IP2I06H0V@0206H0V@03o`00001<0;<0C02c00<0C02c00?o0000
03<0c00c0<`00P0c0<`00ol000006@3V01T0iP0701T0iP03o`0000000?l0003o06`0003o1Oooool1
0000007ooooo00000`00003oooooooooo`02ooooocD0003o0ol0000601T0iP;o0000100c0<`00ol0
0000C02c04`0/`0204`0/`?o0000101V09T4o`000080O`1o1Ol0000609T0IPGo00003`2c04`3o`00
00/0V@1V00?o000007l0O`1o07l00`1o07l2o`0000D0IP2I00?o000004`0/`1<0;<00`1<0;<00ol0
0000<`3<03<0c00203<0c003o`00000I0>H06@3V00L06@3V00?o00000000o`000?l0K0000?l5oooo
o`4000000Oooool0000300000?oooooooooo00;ooooo>0000?l2o`0000H06@3V0_l0000303<0c0?o
0000101<0;<2o`0000H0IP2I1?l0000307l0O`Co00001`2I06H?o`0000`0V@1V0_l0000507l0O`03
o`00001V09T0IP2I00@0IP2I00?o000004`0/`1<0;<0101<0;<00ol00000<`3<03<0c00203<0c003
o`00000I0>H06@3V00L06@3V00?o00000000o`000?l0K0000?l5ooooo`4000000Oooool000030000
0?oooooooooo00;ooooo>P000?l2o`0000H06@3V00?o000003<0c00c0<`00`0c0<`3o`0000<0C02c
0ol0000706H0V@?o0000101o07l4o`0001d0V@1V00?o000007l0O`1o07l0101o07l00ol00000IP2I
06H0V@0406H0V@03o`00001<0;<0C02c00@0C02c00?o000003<0c00c0<`00`0c0<`00ol000006@3V
01T0iP0701T0iP03o`0000000?l0003o06`0003o1Oooool10000007ooooo00000`00003ooooooooo
o`02oooooc`0003o0_l0000501T0iP;o00001P0c0<`3o`0000<0C02c1?l0000606H0V@Co0000101o
07l4o`0001D0V@1V1?l0000507l0O`;o00001`1V09T00ol00000C02c04`0/`0404`0/`03o`00000c
0<`0<`3<00<0<`3<00?o000001T0iP0I0>H01`0I0>H00ol00000003o0000o`1/0000o`Gooooo0@00
0001ooooo`0000<00000ooooooooool00_ooooln0000o`;o00001@0I0>H3o`0000H0<`3<0ol00004
04`0/`Go00001@1V09T4o`0000@0O`1o2?l0000709T0IPKo0000201o07l00ol00000IP2I06H0V@06
06H0V@03o`00001<0;<0C02c00D0C02c00?o000003<0c00c0<`00`0c0<`00ol000006@3V01T0iP07
01T0iP03o`0000000?l0003o06`0003o1Oooool10000007ooooo00000`00003oooooooooo`02oooo
od00003o00?o000001T0iP0I0>H01@0I0>H3o`0000H0<`3<1?l0000504`0/`Go0000101V09T4o`00
00P0O`1o1ol0000<07l0O`;o0000201V09T00ol00000C02c04`0/`0504`0/`03o`00000c0<`0<`3<
00@0<`3<00?o000001T0iP0I0>H01`0I0>H00ol00000003o0000o`1/0000o`Gooooo0@000001oooo
o`0000<00000ooooooooool00_oooom10000o`;o0000200I0>H3o`0000L0<`3<1Ol0000504`0/`?o
00001@1V09T5o`0001D0O`1o00?o000006H0V@1V09T0201V09T00ol00000C02c04`0/`0504`0/`03
o`00000c0<`0<`3<00@0<`3<00?o000001T0iP0I0>H0200I0>H00ol00000003o0000o`1[0000o`Go
oooo0@000001ooooo`0000<00000ooooooooool00_oooom30000o`;o00002@0I0>H3o`0000T0<`3<
1?l0000404`0/`?o00001`1V09T5o`0000l0O`1o00?o000006H0V@1V09T0201V09T00ol00000C02c
04`0/`0604`0/`03o`00000c0<`0<`3<00@0<`3<00?o000001T0iP0I0>H0200I0>H00ol00000003o
0000o`1[0000o`Gooooo0@000001ooooo`0000<00000ooooooooool00_oooom50000o`?o00002@0I
0>H3o`0000X0<`3<0_l0000504`0/`?o00002@1V09T?o`0000T0IP2I0_l0000804`0/`03o`00000c
0<`0<`3<00D0<`3<00?o000001T0iP0I0>H0200I0>H00ol00000003o0000o`1[0000o`Gooooo0@00
0001ooooo`0000<00000ooooooooool00_oooom80000o`?o00002@0I0>H3o`0000T0<`3<00?o0000
04`0/`1<0;<01@1<0;<3o`0001`0IP2I0_l0000:04`0/`03o`00000c0<`0<`3<00D0<`3<00?o0000
01T0iP0I0>H0200I0>H00ol00000003o0000o`1[0000o`Gooooo0@000001ooooo`0000<00000oooo
ooooool00_oooom;0000o`?o00002@0I0>H3o`0000L0<`3<0_l0000804`0/`Go00005@1V09T2o`00
00`0C02c00?o000003<0c00c0<`01@0c0<`00ol000006@3V01T0iP0801T0iP03o`0000000?l0003o
06/0003o1Oooool10000007ooooo00000`00003oooooooooo`02ooooodh0003o0ol0000901T0iPCo
00001@0c0<`4o`0000T0C02c5Ol0000<04`0/`;o0000200c0<`00ol000006@3V01T0iP0801T0iP03
o`0000000?l0003o06/0003o1Oooool10000007ooooo00000`00003oooooooooo`02oooooe40003o
0_l0000;01T0iP?o00001P0c0<`@o`0001L0C02c0ol0000:03<0c003o`00000I0>H06@3V00P06@3V
00?o00000000o`000?l0J`000?l5ooooo`4000000Oooool0000300000?oooooooooo00;oooooD`00
0?l2o`0000`06@3V0_l0000D03<0c0Ko00003P1<0;<3o`0000`0<`3<00?o000001T0iP0I0>H02@0I
0>H00ol00000003o0000o`1[0000o`Gooooo0@000001ooooo`0000<00000ooooooooool00_oooomE
0000o`?o00002`0I0>H2o`0001P0<`3<3_l0000>03<0c003o`00000I0>H06@3V00X06@3V00?o0000
0000o`000?l0J`000?l5ooooo`4000000Oooool0000300000?oooooooooo00;oooooF0000?l2o`00
00/06@3V0ol0000603<0c0So00008P0c0<`00ol000006@3V01T0iP0;01T0iP03o`0000000?l0003o
06/0003o1Oooool10000007ooooo00000`00003oooooooooo`02oooooeX0003o0_l0000<01T0iPKo
0000200I0>H3o`0001h0<`3<00?o000001T0iP0I0>H0300I0>H00ol00000003o0000o`1[0000o`Go
oooo0@000001ooooo`0000<00000ooooooooool00_oooomL0000o`?o00006P0I0>H3o`0001X0<`3<
00?o000001T0iP0I0>H0300I0>H00ol00000003o0000o`1/0000o`Gooooo0@000001ooooo`0000<0
0000ooooooooool00_oooomO0000o`Co00006@0I0>H3o`0001<0<`3<1?l0000?01T0iP03o`000000
0?l0003o06`0003o1Oooool10000007ooooo00000`00003oooooooooo`02ooooof<0003o1?l0000H
01T0iPOo00001`0c0<`5o`0001<06@3V00?o00000000o`000?l0K0000?l5ooooo`4000000Oooool0
000300000?oooooooooo00;oooooI`000?l4o`0001/06@3V1ol0000H01T0iP03o`0000000?l0003o
06`0003o1Oooool10000007ooooo00000`00003oooooooooo`02ooooof/0003o0ol0000g01T0iP03
o`0000000?l0003o06`0003o1Oooool10000007ooooo00000`00003oooooooooo`02ooooofh0003o
0_l0000e01T0iP03o`0000000?l0003o06`0003o1Oooool10000007ooooo00000`00003ooooooooo
o`02ooooog00003o0ol0000a01T0iP03o`0000000?l0003o06d0003o1Oooool10000007ooooo0000
0`00003oooooooooo`02ooooog<0003o0ol0000]01T0iP03o`0000000?l0003o06h0003o1Oooool1
0000007ooooo00000`00003oooooooooo`02ooooogH0003o1?l0000X01T0iP03o`0000000?l0003o
06l0003o1Oooool10000007ooooo00000`00003oooooooooo`02ooooogX0003o1?l0000P01T0iPCo
0000LP000?l5ooooo`4000000Oooool0000300000?oooooooooo00;oooooOP000?l5o`0001D06@3V
1_l0001f0000o`Gooooo0@000001ooooo`0000<00000ooooooooool00_oooon30000o`Go0000200I
0>H8o`0007`0003o1Oooool10000007ooooo00000`00003oooooooooo`02ooooohP0003o2?l00024
0000o`Gooooo0@000001ooooo`0000<00000ooooooooool00_oooooo0000oaD0003o1Oooool10000
007ooooo00000`00003oooooooooo`02ooooool0003o5@000?l5ooooo`4000000Oooool000030000
0?oooooooooo00;oooooo`000?lE0000o`Gooooo0@000001ooooo`0000<00000ooooooooool00_oo
oooo0000oaD0003o1Oooool10000007ooooo00000`00003oooooooooo`02ooooool0003o5@000?l5
ooooo`4000000Oooool0000300000?oooooooooo00;oooooo`000?lE0000o`Gooooo0@000001oooo
o`0000<00000ooooooooool00_oooooo0000oaD0003o1Oooool10000007ooooo00000`00003ooooo
ooooo`02ooooool0003o5@000?l5ooooo`4000000Oooool0000300000?oooooooooo00;oooooo`00
0?lE0000o`Gooooo0@000001ooooo`0000<00000ooooooooool00_oooooo0000oaD0003o1Oooool1
0000007ooooo00000`00003oooooooooo`02ooooool0003o5@000?l5ooooo`4000000Oooool00003
00000?oooooooooo00;oooooo`000?lE0000o`Gooooo0@000001ooooo`0000<00000ooooooooool0
0_oooooo0000oaD0003o1Oooool10000007ooooo00000`00003oooooooooo`02ooooool0003o5@00
0?l5ooooo`4000000Oooool0000300000?oooooooooo00;oooooo`000?lE0000o`Gooooo0@000001
ooooo`0000<00000ooooooooool00_oooooo0000oaD0003o1Oooool10000007ooooo00000`00003o
ooooooooo`02ooooool0003o5@000?l5ooooo`4000000Oooool0000300000?oooooooooo00;ooooo
o`000?lE0000o`Gooooo0@000001ooooo`0000<00000ooooooooool00_oooooo0000oaD0003o1Ooo
ool10000007ooooo00000`00003oooooooooo`02ooooool0003o5@000?l5ooooo`4000000Oooool0
000300000?oooooooooo00;oooooo`000?lE0000o`Gooooo0@000001ooooo`0000<00000oooooooo
ool00_oooooo0000oaD0003o1Oooool10000007ooooo00000`00003oooooooooo`02ooooool0003o
5@000?l5ooooo`4000000Oooool0000300000?oooooooooo00;oooooo`000?lE0000o`Gooooo0@00
0001ooooo`0000<00000ooooooooool00_oooooo0000oaD0003o1Oooool10000007ooooo00000`00
003oooooooooo`02ooooool0003o5@000?l5ooooo`4000000Oooool0000300000?oooooooooo00;o
ooooo`000?lE0000o`Gooooo0@000001ooooo`0000<00000ooooooooool00_oooooo0000oaD0003o
1Oooool10000007ooooo00000`00003oooooooooo`02ooooool0003o5@000?l5ooooo`4000000Ooo
ool0000300000?oooooooooo00;oooooo`000?lE0000o`Gooooo0@000001ooooo`0000<00000oooo
ooooool00_oooooo0000oaD0003o1Oooool10000007ooooo00000`00003oooooooooo`02ooooool0
003o5@000?l5ooooo`4000000Oooool0000300000?oooooooooo00;oooooo`000?lE0000o`Gooooo
0@000001ooooo`0000<00000ooooooooool00_oooooo0000oaD0003o1Oooool10000007ooooo0000
0`00003oooooooooo`02ooooool0003o5@000?l5ooooo`4000000Oooool0000300000?oooooooooo
00;oooooo`000?lE0000o`Gooooo0@000001ooooo`0000<00000ooooooooool00_oooooo0000oaD0
003o1Oooool10000007ooooo00000`00003oooooooooo`02ooooool0003o5@000?l5ooooo`400000
0Oooool0000300000?oooooooooo00;oooooo`000?lE0000o`Gooooo0@000001ooooo`0000<00000
ooooooooool00_oooooo0000oaD0003o1Oooool10000007ooooo00000`00003oooooooooo`02oooo
ool0003o5@000?l5ooooo`4000000Oooool0000300000?oooooooooo00;oooooo`000?lE0000o`Go
oooo0@000001ooooo`0000<00000ooooooooool00_oooooo0000oaD0003o1Oooool10000007ooooo
00000`00003oooooooooo`02ooooool0003o5@000?l5ooooo`4000000Oooool0000300000?oooooo
oooo00;oooooo`000?lE0000o`Gooooo0@000001ooooo`0000<00000ooooooooool00_oooooo0000
oaD0003o1Oooool10000007ooooo00000`00003oooooooooo`02ooooool0003o5@000?l5ooooo`40
00000Oooool0000300000?oooooooooo00;oooooo`000?lE0000o`Gooooo0@000001ooooo`0000<0
0000ooooooooool00_oooooo0000oaD0003o1Oooool10000007ooooo00000`00003oooooooooo`02
ooooool0003o5@000?l5ooooo`4000000Oooool0000300000?oooooooooo00;oooooo`000?lE0000
o`Gooooo0@000001ooooo`0000<00000ooooooooool00_oooooo0000oaD0003o1Oooool10000007o
oooo00000`00003oooooooooo`02ooooool0003o5@000?l5ooooo`4000000Oooool0000300000?oo
oooooooo00;oooooo`000?lE0000o`Gooooo0@000001ooooo`0000<00000ooooooooool00_oooooo
0000oaD0003o1Oooool10000007ooooo00000`00003oooooooooo`02ooooool0003o5@000?l5oooo
o`4000000Oooool0000300000?oooooooooo00;oooooo`000?lE0000o`Gooooo0@000001ooooo`00
00<00000ooooooooool00_oooooo0000oaD0003o1Oooool10000007ooooo00000`00003ooooooooo
o`02ooooool0003o5@000?l5ooooo`4000000Oooool0000300000?oooooooooo00;oooooo`000?lE
0000o`Gooooo0@000001ooooo`0000<00000ooooooooool00_oooooo0000oaD0003o1Oooool10000
007ooooo00000`00003oooooooooo`02ooooool0003o5@000?l5ooooo`4000000Oooool000030000
0?oooooooooo00;oooooo`000?lE0000o`Gooooo0@000001ooooo`0000<00000ooooooooool00_oo
oooo0000oaD0003o1Oooool10000007ooooo00000`00003oooooooooo`02ooooool0003o5@000?l5
ooooo`4000000Oooool0000300000?oooooooooo00;oooooo`000?lE0000o`Gooooo0@000001oooo
o`0000<00000ooooooooool00_oooooo0000oaD0003o1Oooool10000007ooooo00000`00003ooooo
ooooo`02ooooool0003o5@000?l5ooooo`4000000Oooool0000300000?oooooooooo00;oooooo`00
0?lE0000o`Gooooo0@000001ooooo`0000<00000ooooooooool00_oooooo0000oaD0003o1Oooool1
0000007ooooo00000`00003oooooooooo`02ooooool0003o5@000?l5ooooo`4000000Oooool00003
00000?oooooooooo00;oooooo`000?lE0000o`Gooooo0@000001ooooo`0000<00000ooooooooool0
0_oooooo0000oaD0003o1Oooool10000007ooooo00000`00003oooooooooo`02ooooool0003o5@00
0?l5ooooo`4000000Oooool0000300000?oooooooooo00;oooooo`000?lE0000o`Gooooo0@000001
ooooo`0000<00000ooooooooool00_oooooo0000oaD0003o1Oooool10000007ooooo00000`00003o
ooooooooo`02ooooool0003o5@000?l5ooooo`4000000Oooool0000300000?oooooooooo00;ooooo
o`000?lE0000o`Gooooo0@000001ooooo`0000<00000ooooooooool00_oooooo0000oaD0003o1Ooo
ool10000007ooooo00000`00003oooooooooo`02ooooool0003o5@000?l5ooooo`4000000Oooool0
000300000?oooooooooo00;oooooo`000?lE0000o`Gooooo0@000001ooooo`0000<00000oooooooo
ool00_oooooo0000oaD0003o1Oooool10000007ooooo00000`00003oooooooooo`02ooooool0003o
5@000?l5ooooo`4000000Oooool0000300000?oooooooooo00;oooooo`000?lE0000o`Gooooo0@00
0001ooooo`0000<00000ooooooooool00_oooooo0000oaD0003o1Oooool10000007ooooo00000`00
003oooooooooo`02ooooool0003o5@000?l5ooooo`4000000Oooool0000300000?oooooooooo00;o
ooooo`000?lE0000o`Gooooo0@000001ooooo`0000<00000ooooooooool00_oooooo0000oaD0003o
1Oooool10000007ooooo00000`00003oooooooooo`02ooooool0003o5@000?l5ooooo`4000000Ooo
ool0000300000?oooooooooo00;oooooo`000?lE0000o`Gooooo0@000001ooooo`0000<00000oooo
ooooool00_oooooo0000oaD0003o1Oooool10000007ooooo00000`00003oooooooooo`02ooooool0
003o5@000?l5ooooo`4000000Oooool0000300000?oooooooooo00;oooooo`000?lE0000o`Gooooo
0@000001ooooo`0000<00000ooooooooool00_oooooo0000oaD0003o1Oooool10000007ooooo0000
0`00003oooooooooo`02ooooool0003o5@000?l5ooooo`4000000Oooool0000300000?oooooooooo
00;oooooo`000?lE0000o`Gooooo0@000001ooooo`0000<00000ooooooooool00_oooooo0000oaD0
003o1Oooool10000007ooooo00000`00003oooooooooo`02ooooool0003o5@000?l5ooooo`400000
0Oooool0000300000?oooooooooo00;oooooo`000?lE0000o`Gooooo0@000001ooooo`0000<00000
ooooooooool00_oooooo0000oaD0003o1Oooool10000007ooooo00000`00003oooooooooo`02oooo
ool0003o5@000?l5ooooo`4000000Oooool0000300000?oooooooooo00;oooooo`000?lE0000o`Go
oooo0@000001ooooo`0000<00000ooooooooool00_oooooo0000oaD0003o1Oooool10000007ooooo
00000`00003oooooooooo`02ooooool0003o5@000?l5ooooo`4000000Oooool0000300000?oooooo
oooo00;oooooo`000?lE0000o`Gooooo0@000001ooooo`0000<00000ooooooooool00_oooooo0000
oaD0003o1Oooool10000007ooooo00000`00003oooooooooo`02ooooool0003o5@000?l5ooooo`40
00000Oooool0000300000?oooooooooo00;oooooo`000?lE0000o`Gooooo0@000001ooooo`0000<0
0000ooooooooool00_oooooo0000oaD0003o1Oooool10000007ooooo00000`00003oooooooooo`02
ooooool0003o5@000?l5ooooo`4000000Oooool0000300000?oooooooooo00;oooooo`000?lE0000
o`Gooooo0@000001ooooo`0000<00000ooooooooool00_oooooo0000oaD0003o1Oooool10000007o
oooo00000`00003oooooooooo`02ooooool0003o5@000?l5ooooo`4000000Oooool0000300000?oo
oooooooo00;oooooo`000?lE0000o`Gooooo0@000001ooooo`0000<00000ooooooooool00_oooooo
0000oaD0003o1Oooool10000007ooooo00000`00003oooooooooo`02ooooool0003o5@000?l5oooo
o`4000000Oooool0000300000?oooooooooo00;oooooo`000?lE0000o`Gooooo0@000001ooooo`00
00<00000ooooooooool00_oooooo0000oaD0003o1Oooool10000007ooooo00000`00003ooooooooo
o`02ooooool0003o5@000?l5ooooo`4000000Oooool0000300000?oooooooooo00;oooooo`000?lE
0000o`Gooooo0@000001ooooo`0000<00000ooooooooool00_oooooo0000oaD0003o1Oooool10000
007ooooo00000`00003oooooooooo`02ooooool0003o5@000?l5ooooo`4000000Oooool000030000
0?oooooooooo00;oooooo`000?lE0000o`Gooooo0@000001ooooo`0000<00000ooooooooool00_oo
oooo0000oaD0003o1Oooool10000007ooooo00000`00003oooooooooo`02ooooool0003o5@000?l5
ooooo`4000000Oooool0000300000?oooooooooo00;oooooo`000?lE0000o`Gooooo0@000001oooo
o`0000<00000ooooooooool00_oooooo0000oaD0003o1Oooool10000007ooooo00000`00003ooooo
ooooo`02ooooool0003o5@000?l5ooooo`4000000Oooool0000300000?oooooooooo00;oooooo`00
0?lE0000o`Gooooo0@000001ooooo`0000<00000ooooooooool00_oooooo0000oaD0003o1Oooool1
0000007ooooo00000`00003oooooooooo`02ooooool0003o5@000?l5ooooo`4000000Oooool00003
00000?oooooooooo0?oooooo7?ooool10000007ooooo00000`00003oooooooooo`3ooooooacooooo
0@000001ooooo`0000<00000ooooooooool0oooooolLooooo`4000000Oooool0000300000?oooooo
oooo0?oooooo7?ooool10000007ooooo003o0000020000000Oooool00001\
\>"],
  ImageRangeCache->{{{0, 287}, {287, 0}} -> {-1.04092, -1.04092, 0.00725378, \
0.00725378}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% ContourGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.480769 0.5 0.480769 [
[ 0 0 -0.125 0 ]
[ 0 0 -0.125 0 ]
[ 0 1 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
0 0 m
1 0 L
s
0 0 m
0 1 L
s
0 1 m
1 1 L
s
1 0 m
1 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
0 0 1 r
.01923 .98077 m
.98077 .98077 L
.98077 .01923 L
.01923 .01923 L
F
0 g
.5 Mabswid
.1 0 .9 r
.01923 .45725 m
.05929 .45958 L
.06368 .45994 L
.09936 .47562 L
.13942 .4906 L
.17949 .49457 L
.21955 .49599 L
.25962 .49692 L
.29968 .49788 L
.33974 .49885 L
.37981 .49954 L
.41987 .49955 L
.45994 .49852 L
.5 .49526 L
.54006 .484 L
.58013 .46051 L
.58093 .45994 L
.61778 .41987 L
.62019 .41362 L
.6314 .37981 L
.63652 .33974 L
.63298 .29968 L
.62338 .25962 L
.62019 .24887 L
.61735 .21955 L
.61117 .17949 L
.58673 .13942 L
.58013 .12534 L
.57666 .09936 L
.56385 .05929 L
.54006 .02895 L
.53782 .01923 L
.01923 .01923 L
F
0 g
.01923 .45725 m
.05929 .45958 L
.06368 .45994 L
.09936 .47562 L
.13942 .4906 L
.17949 .49457 L
.21955 .49599 L
.25962 .49692 L
.29968 .49788 L
.33974 .49885 L
.37981 .49954 L
.41987 .49955 L
.45994 .49852 L
.5 .49526 L
.54006 .484 L
.58013 .46051 L
.58093 .45994 L
.61778 .41987 L
.62019 .41362 L
.6314 .37981 L
.63652 .33974 L
.63298 .29968 L
.62338 .25962 L
.62019 .24887 L
.61735 .21955 L
.61117 .17949 L
.58673 .13942 L
.58013 .12534 L
.57666 .09936 L
.56385 .05929 L
.54006 .02895 L
.53782 .01923 L
s
.2 0 .8 r
.01923 .45298 m
.05929 .45505 L
.0962 .45994 L
.09936 .46296 L
.13942 .48062 L
.17949 .48792 L
.21955 .49054 L
.25962 .49186 L
.29968 .49285 L
.33974 .49365 L
.37981 .49402 L
.41987 .49346 L
.45994 .49115 L
.5 .48446 L
.54006 .46667 L
.54664 .45994 L
.58013 .44116 L
.5993 .41987 L
.61125 .37981 L
.62019 .35011 L
.62107 .33974 L
.62019 .31005 L
.61854 .29968 L
.61545 .25962 L
.61065 .21955 L
.6006 .17949 L
.58013 .15038 L
.57778 .13942 L
.571 .09936 L
.55079 .05929 L
.54006 .04616 L
.53309 .01923 L
.01923 .01923 L
F
0 g
.01923 .45298 m
.05929 .45505 L
.0962 .45994 L
.09936 .46296 L
.13942 .48062 L
.17949 .48792 L
.21955 .49054 L
.25962 .49186 L
.29968 .49285 L
.33974 .49365 L
.37981 .49402 L
.41987 .49346 L
.45994 .49115 L
.5 .48446 L
.54006 .46667 L
.54664 .45994 L
.58013 .44116 L
.5993 .41987 L
.61125 .37981 L
.62019 .35011 L
.62107 .33974 L
.62019 .31005 L
.61854 .29968 L
.61545 .25962 L
.61065 .21955 L
.6006 .17949 L
.58013 .15038 L
.57778 .13942 L
.571 .09936 L
.55079 .05929 L
.54006 .04616 L
.53309 .01923 L
s
.3 0 .7 r
.01923 .449 m
.05929 .45086 L
.09936 .4565 L
.11324 .45994 L
.13942 .47215 L
.17949 .48188 L
.21955 .48551 L
.25962 .48717 L
.29968 .48821 L
.33974 .48889 L
.37981 .48899 L
.41987 .48795 L
.45994 .48459 L
.5 .4753 L
.53064 .45994 L
.54006 .45434 L
.58013 .426 L
.58549 .41987 L
.59521 .37981 L
.60823 .33974 L
.6061 .29968 L
.60979 .25962 L
.6046 .21955 L
.59175 .17949 L
.58013 .16669 L
.57289 .13942 L
.56581 .09936 L
.54128 .05929 L
.54006 .05793 L
.52872 .01923 L
.01923 .01923 L
F
0 g
.01923 .449 m
.05929 .45086 L
.09936 .4565 L
.11324 .45994 L
.13942 .47215 L
.17949 .48188 L
.21955 .48551 L
.25962 .48717 L
.29968 .48821 L
.33974 .48889 L
.37981 .48899 L
.41987 .48795 L
.45994 .48459 L
.5 .4753 L
.53064 .45994 L
.54006 .45434 L
.58013 .426 L
.58549 .41987 L
.59521 .37981 L
.60823 .33974 L
.6061 .29968 L
.60979 .25962 L
.6046 .21955 L
.59175 .17949 L
.58013 .16669 L
.57289 .13942 L
.56581 .09936 L
.54128 .05929 L
.54006 .05793 L
.52872 .01923 L
s
.4 0 .6 r
.01923 .44519 m
.05929 .44689 L
.09936 .45174 L
.12991 .45994 L
.13942 .46451 L
.17949 .47614 L
.21955 .4807 L
.25962 .4827 L
.29968 .48379 L
.33974 .48436 L
.37981 .48423 L
.41987 .48276 L
.45994 .47842 L
.5 .46695 L
.51363 .45994 L
.54006 .44539 L
.57456 .41987 L
.58013 .41347 L
.58672 .37981 L
.60058 .33974 L
.59998 .29968 L
.60448 .25962 L
.59888 .21955 L
.58382 .17949 L
.58013 .17596 L
.5683 .13942 L
.56086 .09936 L
.54006 .06603 L
.53543 .05929 L
.52454 .01923 L
.01923 .01923 L
F
0 g
.01923 .44519 m
.05929 .44689 L
.09936 .45174 L
.12991 .45994 L
.13942 .46451 L
.17949 .47614 L
.21955 .4807 L
.25962 .4827 L
.29968 .48379 L
.33974 .48436 L
.37981 .48423 L
.41987 .48276 L
.45994 .47842 L
.5 .46695 L
.51363 .45994 L
.54006 .44539 L
.57456 .41987 L
.58013 .41347 L
.58672 .37981 L
.60058 .33974 L
.59998 .29968 L
.60448 .25962 L
.59888 .21955 L
.58382 .17949 L
.58013 .17596 L
.5683 .13942 L
.56086 .09936 L
.54006 .06603 L
.53543 .05929 L
.52454 .01923 L
s
.5 0 .5 r
.01923 .44147 m
.05929 .44302 L
.09936 .44719 L
.13942 .4577 L
.14512 .45994 L
.17949 .47052 L
.21955 .47599 L
.25962 .47833 L
.29968 .47948 L
.33974 .47996 L
.37981 .4796 L
.41987 .4777 L
.45994 .47241 L
.49821 .45994 L
.5 .45908 L
.54006 .43886 L
.56578 .41987 L
.58013 .40217 L
.583 .37981 L
.59637 .33974 L
.5977 .29968 L
.59934 .25962 L
.5933 .21955 L
.58013 .18426 L
.57699 .17949 L
.56388 .13942 L
.55602 .09936 L
.54006 .07224 L
.53028 .05929 L
.52046 .01923 L
.01923 .01923 L
F
0 g
.01923 .44147 m
.05929 .44302 L
.09936 .44719 L
.13942 .4577 L
.14512 .45994 L
.17949 .47052 L
.21955 .47599 L
.25962 .47833 L
.29968 .47948 L
.33974 .47996 L
.37981 .4796 L
.41987 .4777 L
.45994 .47241 L
.49821 .45994 L
.5 .45908 L
.54006 .43886 L
.56578 .41987 L
.58013 .40217 L
.583 .37981 L
.59637 .33974 L
.5977 .29968 L
.59934 .25962 L
.5933 .21955 L
.58013 .18426 L
.57699 .17949 L
.56388 .13942 L
.55602 .09936 L
.54006 .07224 L
.53028 .05929 L
.52046 .01923 L
s
.6 0 .4 r
.01923 .43777 m
.05929 .4392 L
.09936 .44273 L
.13942 .4517 L
.16204 .45994 L
.17949 .46487 L
.21955 .47128 L
.25962 .47396 L
.29968 .47518 L
.33974 .47557 L
.37981 .47499 L
.41987 .47265 L
.45994 .46638 L
.4816 .45994 L
.5 .45171 L
.54006 .43293 L
.5573 .41987 L
.58013 .38918 L
.5813 .37981 L
.59347 .33974 L
.59682 .29968 L
.59422 .25962 L
.5877 .21955 L
.58013 .19576 L
.57089 .17949 L
.55951 .13942 L
.55117 .09936 L
.54006 .07831 L
.52527 .05929 L
.51641 .01923 L
.01923 .01923 L
F
0 g
.01923 .43777 m
.05929 .4392 L
.09936 .44273 L
.13942 .4517 L
.16204 .45994 L
.17949 .46487 L
.21955 .47128 L
.25962 .47396 L
.29968 .47518 L
.33974 .47557 L
.37981 .47499 L
.41987 .47265 L
.45994 .46638 L
.4816 .45994 L
.5 .45171 L
.54006 .43293 L
.5573 .41987 L
.58013 .38918 L
.5813 .37981 L
.59347 .33974 L
.59682 .29968 L
.59422 .25962 L
.5877 .21955 L
.58013 .19576 L
.57089 .17949 L
.55951 .13942 L
.55117 .09936 L
.54006 .07831 L
.52527 .05929 L
.51641 .01923 L
s
.7 0 .3 r
.01923 .43404 m
.05929 .43536 L
.09936 .43827 L
.13942 .4457 L
.17949 .45882 L
.1822 .45994 L
.21955 .46645 L
.25962 .46952 L
.29968 .47082 L
.33974 .47112 L
.37981 .4703 L
.41987 .46748 L
.45994 .46015 L
.46073 .45994 L
.5 .44427 L
.54006 .42581 L
.54756 .41987 L
.57629 .37981 L
.58013 .37256 L
.58978 .33974 L
.59486 .29968 L
.589 .25962 L
.58192 .21955 L
.58013 .21285 L
.5648 .17949 L
.55512 .13942 L
.54619 .09936 L
.54006 .08602 L
.52028 .05929 L
.51231 .01923 L
.01923 .01923 L
F
0 g
.01923 .43404 m
.05929 .43536 L
.09936 .43827 L
.13942 .4457 L
.17949 .45882 L
.1822 .45994 L
.21955 .46645 L
.25962 .46952 L
.29968 .47082 L
.33974 .47112 L
.37981 .4703 L
.41987 .46748 L
.45994 .46015 L
.46073 .45994 L
.5 .44427 L
.54006 .42581 L
.54756 .41987 L
.57629 .37981 L
.58013 .37256 L
.58978 .33974 L
.59486 .29968 L
.589 .25962 L
.58192 .21955 L
.58013 .21285 L
.5648 .17949 L
.55512 .13942 L
.54619 .09936 L
.54006 .08602 L
.52028 .05929 L
.51231 .01923 L
s
.8 0 .2 r
.01923 .43022 m
.05929 .43142 L
.09936 .43372 L
.13942 .43957 L
.17949 .4509 L
.20884 .45994 L
.21955 .46136 L
.25962 .46489 L
.29968 .46629 L
.33974 .4665 L
.37981 .46542 L
.41987 .46205 L
.43511 .45994 L
.45994 .4515 L
.5 .43649 L
.53514 .41987 L
.54006 .41557 L
.56626 .37981 L
.58013 .34993 L
.58317 .33974 L
.58935 .29968 L
.58352 .25962 L
.58013 .23658 L
.5742 .21955 L
.55856 .17949 L
.5506 .13942 L
.54095 .09936 L
.54006 .09713 L
.51517 .05929 L
.50807 .01923 L
.01923 .01923 L
F
0 g
.01923 .43022 m
.05929 .43142 L
.09936 .43372 L
.13942 .43957 L
.17949 .4509 L
.20884 .45994 L
.21955 .46136 L
.25962 .46489 L
.29968 .46629 L
.33974 .4665 L
.37981 .46542 L
.41987 .46205 L
.43511 .45994 L
.45994 .4515 L
.5 .43649 L
.53514 .41987 L
.54006 .41557 L
.56626 .37981 L
.58013 .34993 L
.58317 .33974 L
.58935 .29968 L
.58352 .25962 L
.58013 .23658 L
.5742 .21955 L
.55856 .17949 L
.5506 .13942 L
.54095 .09936 L
.54006 .09713 L
.51517 .05929 L
.50807 .01923 L
s
.9 0 .1 r
.01923 .42622 m
.05929 .42732 L
.09936 .42896 L
.13942 .43307 L
.17949 .44186 L
.21955 .453 L
.25962 .45989 L
.26003 .45994 L
.29968 .46146 L
.33974 .46156 L
.37981 .46017 L
.3845 .45994 L
.41987 .45354 L
.45994 .44129 L
.5 .42799 L
.51908 .41987 L
.54006 .40139 L
.55465 .37981 L
.57226 .33974 L
.57843 .29968 L
.57579 .25962 L
.56439 .21955 L
.55193 .17949 L
.54584 .13942 L
.54006 .11146 L
.53206 .09936 L
.50982 .05929 L
.50358 .01923 L
.01923 .01923 L
F
0 g
.01923 .42622 m
.05929 .42732 L
.09936 .42896 L
.13942 .43307 L
.17949 .44186 L
.21955 .453 L
.25962 .45989 L
.26003 .45994 L
.29968 .46146 L
.33974 .46156 L
.37981 .46017 L
.3845 .45994 L
.41987 .45354 L
.45994 .44129 L
.5 .42799 L
.51908 .41987 L
.54006 .40139 L
.55465 .37981 L
.57226 .33974 L
.57843 .29968 L
.57579 .25962 L
.56439 .21955 L
.55193 .17949 L
.54584 .13942 L
.54006 .11146 L
.53206 .09936 L
.50982 .05929 L
.50358 .01923 L
s
1 0 0 r
.01923 .42193 m
.05929 .42292 L
.09936 .42383 L
.13942 .42587 L
.17949 .4308 L
.21955 .43975 L
.25962 .44789 L
.29968 .45155 L
.33974 .45156 L
.37981 .44785 L
.41987 .43921 L
.45994 .42818 L
.49362 .41987 L
.5 .41652 L
.53947 .37981 L
.54006 .37899 L
.55562 .33974 L
.56369 .29968 L
.56146 .25962 L
.5517 .21955 L
.54454 .17949 L
.54063 .13942 L
.54006 .13538 L
.51865 .09936 L
.50398 .05929 L
.5 .02701 L
.4971 .01923 L
.01923 .01923 L
F
0 g
.01923 .42193 m
.05929 .42292 L
.09936 .42383 L
.13942 .42587 L
.17949 .4308 L
.21955 .43975 L
.25962 .44789 L
.29968 .45155 L
.33974 .45156 L
.37981 .44785 L
.41987 .43921 L
.45994 .42818 L
.49362 .41987 L
.5 .41652 L
.53947 .37981 L
.54006 .37899 L
.55562 .33974 L
.56369 .29968 L
.56146 .25962 L
.5517 .21955 L
.54454 .17949 L
.54063 .13942 L
.54006 .13538 L
.51865 .09936 L
.50398 .05929 L
.5 .02701 L
.4971 .01923 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P000182000`400?l00000o`00003ooooooolQ
ooooo`00o`00000P0000007ooooo00000`00003oooooooooo`3ooooooacooooo0@000001ooooo`00
00<00000ooooooooool0oooooolLooooo`4000000Oooool0000300000?oooooooooo0?oooooo7?oo
ool10000007ooooo00000`00003oooooooooo`3ooooooacooooo0@000001ooooo`0000<00000oooo
ooooool0Roooool01Ol0003oooooo`000?l0003ooooo00Ko000000?oooooo`000?ooool0P_ooool1
0000007ooooo00000`00003oooooooooo`02ooooohT0o`0000Go00000>H06Ol0003o00000;<0C006
o`00000301T0i_l00000003o07d0003o1Oooool10000007ooooo00000`00003oooooooooo`02oooo
ohX0o`000ol000000`2c04co0000o`000004o`00000301T0i_l00000003o07d0003o1Oooool10000
007ooooo00000`00003oooooooooo`02ooooohX0o`000ol00000102c04co0000o`00001o07l5o`00
07h0003o1Oooool10000007ooooo00000`00003oooooooooo`02ooooohX0o`0000Go00000>H06Ol0
003o00000;<0C007o`0007h0003o1Oooool10000007ooooo00000`00003oooooooooo`02ooooohX0
o`0000Go00000>H06Ol0003o00000;<0C006o`00000301T0i_l00000003o07`0003o1Oooool10000
007ooooo00000`00003oooooooooo`02ooooohX0o`0000Go00000>H06Ol0003o00000;<0C004o`00
000504`0/ol000006@3V01T0i_l00000O0000?l5ooooo`4000000Oooool0000300000?oooooooooo
00;oooooRP3o00001Ol00000iP0Io`000?l00000/`1<00;o000000<0O`1oo`000?l000000_l00002
01T0iP03o`0000000?l0003o07T0003o1Oooool10000007ooooo00000`00003oooooooooo`02oooo
oh/0o`000ol00000102c04co0000o`00001o07l4o`0000<06@3V00?o00000000o`000?l0N0000?l5
ooooo`4000000Oooool0000300000?oooooooooo00;oooooR`3o0003o`0000040;<0C?l0003o0000
07l0O`?o000000D0<`3<o`00000I0>H06@3Vo`00001j0000o`Gooooo0@000001ooooo`0000<00000
ooooooooool00_oooon;0?l00005o`00003V01Wo0000o`00002c04`01?l00000101<0;?o000003<0
c?l0000201T0iP03o`0000000?l0003o07L0003o1Oooool10000007ooooo00000`00003ooooooooo
o`02oooooh/0o`0000Go00000>H06Ol0003o00000;<0C002o`00000407l0Ool0003o0000o`000080
<`3<00Co000001T0iP0I0>Ko0000N0000?l5ooooo`4000000Oooool0000300000?oooooooooo00;o
ooooR`3o00001Ol00000iP0Io`000?l00000/`1<00;o000000D0O`1oo`000?l00000C02co`000002
03<0c004o`00000I0>H06@3Vo`0007L0003o1Oooool10000007ooooo00000`00003oooooooooo`02
oooooh/0o`0000Go00000>H06Ol0003o00000;<0C002o`00000507l0Ool0003o000004`0/ol00000
0P0c0<`01?l000006@3V01T0i_l0001g0000o`Gooooo0@000001ooooo`0000<00000ooooooooool0
0_oooon<0?l00005o`00003V01Wo0000o`00002c04`00_l000001@1o07oo0000o`00001<0;?o0000
0080<`3<00Co000001T0iP0I0>Ko0000MP000?l5ooooo`4000000Oooool0000300000?oooooooooo
00;oooooS03o00001_l00000iP0Io`00003<03?o00000;<0C0;o000000L0O`1oo`00001<0;<0C02c
o`00000c0<co000000806@3V00?o00000000o`000?l0M0000?l5ooooo`4000000Oooool000030000
0?oooooooooo00;oooooS03o00000ol00000iP0I0>H06@02o`000080/`1<1?l000001`1<0;?o0000
03<0c00c0<co000001T0i_l00000MP000?l5ooooo`4000000Oooool0000300000?oooooooooo00;o
ooooS@3o00002?l00000iP0Io`00003<03?o00000;<0C?l00000V@1V0ol00000101<0;?o000003<0
c?l0000201T0iP03o`0000000?l0003o07<0003o1Oooool10000007ooooo00000`00003ooooooooo
o`02ooooohd0o`0000Oo00000>H06@3V01Wo00000<`0<ol00000/`1<00;o000000T0O`1oo`00001<
0;<0C02co`00000c0<co000001T0i_l00000M@000?l5ooooo`4000000Oooool0000300000?oooooo
oooo00;oooooS@3o00002?l00000iP0I0>H06@3V01Wo00000<`0<ol00000/`1<1?l000001P1<0;?o
000003<0c?l000006@3Vo`0007D0003o1Oooool10000007ooooo00000`00003oooooooooo`02oooo
ohh0o`0000Wo00000>H06@3V01Wo00000<`0<ol00000/`1<o`00002I06H00ol000000`1<0;?o0000
o`00000201T0iP03o`0000000?l0003o0780003o1Oooool10000007ooooo00000`00003ooooooooo
o`02ooooohh0o`0000So00000>H06@3V01T0iP0Io`00003<03?o00000;<0C0Co000000H0C02co`00
000c0<co000001T0i_l0001d0000o`Gooooo0@000001ooooo`0000<00000ooooooooool00_oooon>
0?l00005o`00003V01T0iP0I0>H06Ol000000P3<03<2o`00000509T0I_l0003o0000o`00001<0;<0
0_l000000`0I0>Ko00000000o`1c0000o`Gooooo0@000001ooooo`0000<00000ooooooooool00_oo
oon?0?l00005o`00003V01T0iP0I0>H06Ol000000P3<03<2o`00000509T0I_l0003o0000o`00001<
0;<00_l000000`0I0>Ko00000000o`1b0000o`Gooooo0@000001ooooo`0000<00000ooooooooool0
0_oooon?0?l00005o`00003V01T0iP0I0>H06Ol000000P3<03<2o`00000509T0I_l0003o0000o`00
001<0;<00_l000000`0I0>Ko00000000o`1b0000o`Gooooo0@000001ooooo`0000<00000oooooooo
ool00_oooon@0?l00006o`00003V01T0iP0I0>H06Ol00000c00c0_l000001@2I06Ko0000o`000?l0
0000C02c00;o000000<06@3Vo`0000000?l0LP000?l5ooooo`4000000Oooool0000300000?oooooo
oooo00;oooooT@3o00001?l00000iP0I0>H06Ol000020<`0<`Co000000H0IP2Io`000?l0003o0000
01T0i_l0001c0000o`Gooooo0@000001ooooo`0000<00000ooooooooool00_oooonA0?l00006o`00
003V01T0iP0I0>H06Ol00000c00c0_l000001@2I06Ko0000o`000?l00000C02c00?o0000L`000?l5
ooooo`4000000Oooool0000300000?oooooooooo00;oooooTP3o00001Ol00000iP0I0>H06Ol00000
c00c00;o000000D0V@1Vo`000?l0003o000004`0/`02o`00000301T0i_l00000003o0740003o1Ooo
ool10000007ooooo00000`00003oooooooooo`02oooooi80o`0000Go00000>H06@3V01Wo00000<`0
<`02o`00000509T0I_l0003o0000o`00001<0;<00_l000000`0I0>Ko00000000o`1a0000o`Gooooo
0@000001ooooo`0000<00000ooooooooool00_oooonC0?l00005o`00003V01T0iP0Io`00003<03<0
1?l000001P1V09Wo0000o`000?l000006@3Vo`000780003o1Oooool10000007ooooo00000`00003o
ooooooooo`02oooooi@0o`0000Co00000>H06Ol00000c00c1?l000001P1V09Wo0000o`000?l00000
6@3Vo`000780003o1Oooool10000007ooooo00000`00003oooooooooo`02oooooi@0o`0000Co0000
0>H06Ol00000c00c1?l000001P1V09Wo0000o`000?l000006@3Vo`000780003o1Oooool10000007o
oooo00000`00003oooooooooo`02oooooiD0o`000_l00000103<03?o0000o`00002I06H3o`000005
04`0/ol0003o000001T0i_l00000L@000?l5ooooo`4000000Oooool0000300000?oooooooooo00;o
ooooU@3o00001?l00000iP0Io`00003<03<4o`00000606H0VOl0003o0000o`00000I0>Ko0000L@00
0?l5ooooo`4000000Oooool0000300000?oooooooooo00;oooooUP3o0002o`0000030<`0<ol0003o
000000;o000000@0IP2Io`000?l0003o00000P0I0>H00ol00000003o0000o`1^0000o`Gooooo0@00
0001ooooo`0000<00000ooooooooool00_oooonF0?l000;o000000<0c00co`000?l000000_l00000
101V09Wo0000o`000?l0000201T0iP03o`0000000?l0003o06h0003o1Oooool10000007ooooo0000
0`00003oooooooooo`02oooooiH0o`000_l000001@3<03?o0000o`000?l00000O`1o00?o000000D0
<`3<o`00000I0>H06@3Vo`00001_0000o`Gooooo0@000001ooooo`0000<00000ooooooooool00_oo
oonF0?l000;o000000<0c00co`00002c04`00ol00000101V09Wo0000o`000?l0000301T0iP03o`00
00000?l0003o06`0003o1Oooool10000007ooooo00000`00003oooooooooo`02oooooiH0o`0000Co
00000>H06Ol00000c00c1?l00000101V09Wo0000o`000?l0000301T0iP03o`0000000?l0003o06`0
003o1Oooool10000007ooooo00000`00003oooooooooo`02oooooiH0o`0000Co00000>H06Ol00000
c00c0ol000001P1o07oo0000o`000?l00000<`3<o`0000<06@3V00?o00000000o`000?l0J`000?l5
ooooo`4000000Oooool0000300000?oooooooooo00;oooooU`3o0002o`0000030<`0<ol00000/`1<
00?o000000D0IP2Io`000?l00000<`3<o`00000301T0iP03o`0000000?l0003o06X0003o1Oooool1
0000007ooooo00000`00003oooooooooo`02oooooiL0o`000_l000000`3<03?o00000;<0C003o`00
000306H0VOl0003o00000080<`3<00Co000001T0iP0I0>Ko0000K0000?l5ooooo`4000000Oooool0
000300000?oooooooooo00;oooooU`3o0002o`0000030<`0<ol00000/`1<00;o000000@0O`1oo`00
0?l0003o00000P0c0<`01Ol000006@3V01T0iP0I0>Ko000006/0003o1Oooool10000007ooooo0000
0`00003oooooooooo`02oooooiL0o`0000Co00000>H06Ol00000c00c0ol000000`1o07oo000006H0
V@02o`000080<`3<00Co000001T0iP0I0>Ko0000J`000?l5ooooo`4000000Oooool0000300000?oo
oooooooo00;oooooU`3o00001_l00000iP0Io`00003<03?o00000;<0C0?o000000@0IP2Io`00001<
0;?o00000P0c0<`01?l000006@3V01T0i_l0001Z0000o`Gooooo0@000001ooooo`0000<00000oooo
ooooool00_oooonG0?l00006o`00003V01Wo00000<`0<ol00000/`1<0_l000001P1o07oo000006H0
VOl00000C02co`000080<`3<00Co000001T0iP0I0>Ko0000J@000?l5ooooo`4000000Oooool00003
00000?oooooooooo00;oooooU`3o00001_l00000iP0Io`00003<03?o00000;<0C0;o00000P1o07l2
o`00000504`0/ol00000<`3<03<0c?l000000P0I0>H00ol00000003o0000o`1W0000o`Gooooo0@00
0001ooooo`0000<00000ooooooooool00_oooonG0?l00003o`00003V01Wo00000080c00c00co0000
0;<0C?l0003o000007l0Ool00000IP2Io`00001<0;?o000003<0c?l0000201T0iP03o`0000000?l0
003o06L0003o1Oooool10000007ooooo00000`00003oooooooooo`02oooooiL0o`0000_o00000>H0
6@3V01Wo00000<`0<ol00000/`1<o`00002I06Ko000007l0O`02o`00000704`0/ol00000<`3<03<0
c?l000006@3Vo`00001Y0000o`Gooooo0@000001ooooo`0000<00000ooooooooool00_oooonH0?l0
000:o`00003V01Wo00000<`0<ol00000/`1<o`00002I06Ko000007l0O`;o000000D0C02co`00000c
0<`0<`3<o`00000201T0iP03o`0000000?l0003o06H0003o1Oooool10000007ooooo00000`00003o
ooooooooo`02oooooiP0o`0000?o00000>H06Ol000000P3<03<01?l00000/`1<o`00002I06H2o`00
000606H0VOl00000C02co`00000c0<co00000P0I0>H00ol00000003o0000o`1V0000o`Gooooo0@00
0001ooooo`0000<00000ooooooooool00_oooonH0?l00003o`00003V01Wo00000080c00c00Ko0000
0;<0C?l00000V@1Vo`00001o07l2o`00000404`0/ol00000<`3<o`0000806@3V00?o00000000o`00
0?l0IP000?l5ooooo`4000000Oooool0000300000?oooooooooo00;oooooV03o00001_l00000iP0I
0>H06Ol00000c00co`000080/`1<0_l000001@1o07oo0000o`00001<0;?o00000080<`3<00?o0000
01T0i_l00000J0000?l5ooooo`4000000Oooool0000300000?oooooooooo00;oooooV03o00001?l0
0000iP0I0>H06Ol000020<`0<`04o`00002c04co000009T0IP;o000000P0IP2Io`00001<0;?o0000
03<0c?l000006@3Vo`0006P0003o1Oooool10000007ooooo00000`00003oooooooooo`02oooooiP0
o`0000Co00000>H06@3V01Wo00000P3<03<01_l00000/`1<o`00002I06Ko000007l0O`;o000000H0
C02co`00000c0<co000001T0i_l0001X0000o`Gooooo0@000001ooooo`0000<00000ooooooooool0
0_oooonI0?l00003o`00003V01Wo00000080c00c00?o00000;<0C02c04`00_l000001`1o07oo0000
o`00001<0;?o000003<0c?l000000P0I0>H00ol00000003o0000o`1U0000o`Gooooo0@000001oooo
o`0000<00000ooooooooool00_oooonI0?l00004o`00003V01T0iP0Io`000080c00c00Co00000;<0
C?l00000V@1V0_l00000201V09Wo000004`0/ol00000<`3<o`00000I0>Ko0000I`000?l5ooooo`40
00000Oooool0000300000?oooooooooo00;oooooV@3o00001?l00000iP0I0>H06Ol000020<`0<`06
o`00002c04co000009T0I_l00000O`1o0_l000001P1<0;?o000003<0c?l000006@3Vo`0006L0003o
1Oooool10000007ooooo00000`00003oooooooooo`02oooooiT0o`0000Co00000>H06@3V01Wo0000
0P3<03<01_l00000/`1<o`00002I06Ko000007l0O`;o000000H0C02co`00000c0<co000001T0i_l0
001W0000o`Gooooo0@000001ooooo`0000<00000ooooooooool00_oooonI0?l00005o`00003V01T0
iP0I0>H06Ol000000P3<03<2o`00000309T0I_l00000O`1o00;o000000H0C02co`00000c0<co0000
01T0i_l0001W0000o`Gooooo0@000001ooooo`0000<00000ooooooooool00_oooonJ0?l00004o`00
003V01T0iP0Io`000080c00c00Go00000;<0C?l0003o000007l0O`02o`00000604`0/ol00000<`3<
o`00000I0>Ko0000I`000?l5ooooo`4000000Oooool0000300000?oooooooooo00;oooooVP3o0000
1?l00000iP0I0>H06Ol000030<`0<`;o000000@0V@1Vo`000?l00000IP2I0_l00000100c0<co0000
01T0i_l0001W0000o`Gooooo0@000001ooooo`0000<00000ooooooooool00_oooonJ0?l00005o`00
003V01T0iP0I0>H06Ol000000P3<03<2o`00000409T0I_l0003o000006H0V@;o000000@0<`3<o`00
000I0>Ko0000I`000?l5ooooo`4000000Oooool0000300000?oooooooooo00;oooooV`3o00001?l0
0000iP0I0>H06Ol000020<`0<`05o`00002c04co0000o`00001o07l00_l000000`1<0;?o000003<0
c002o`0006L0003o1Oooool10000007ooooo00000`00003oooooooooo`02oooooi/0o`0000Co0000
0>H06@3V01Wo00000P3<03<01Ol00000/`1<o`000?l00000O`1o00;o000000<0C02co`00000c0<`0
0_l0001W0000o`Gooooo0@000001ooooo`0000<00000ooooooooool00_oooonK0?l00005o`00003V
01T0iP0I0>H06Ol000000P3<03<3o`00000607l0Ool0003o000004`0/ol00000<`3<0_l0001W0000
o`Gooooo0@000001ooooo`0000<00000ooooooooool00_oooonK0?l00005o`00003V01T0iP0I0>H0
6Ol000000P3<03<2o`00000409T0I_l0003o000006H0V@;o000000<0<`3<o`000?l00000I`000?l5
ooooo`4000000Oooool0000300000?oooooooooo00;oooooW03o00001?l00000iP0I0>H06Ol00002
0<`0<`03o`00002c04co000000;o000000L0IP2Io`000?l00000<`3<o`00000I0>Ko000006H0003o
1Oooool10000007ooooo00000`00003oooooooooo`02oooooi`0o`0000So00000>H06@3V01T0iP0I
o`00003<03?o00000;<0C0?o000000L0IP2Io`000?l00000<`3<o`00000I0>Ko000006H0003o1Ooo
ool10000007ooooo00000`00003oooooooooo`02oooooi`0o`0000So00000>H06@3V01T0iP0Io`00
003<03?o00000;<0C0?o000000L0IP2Io`000?l00000<`3<o`00000I0>Ko000006H0003o1Oooool1
0000007ooooo00000`00003oooooooooo`02oooooi`0o`0000So00000>H06@3V01T0iP0Io`00003<
03?o00000;<0C0?o000000L0IP2Io`000?l00000<`3<o`00000I0>Ko000006H0003o1Oooool10000
007ooooo00000`00003oooooooooo`02oooooi`0o`0000So00000>H06@3V01T0iP0Io`00003<03?o
00000;<0C0?o000000D0IP2Io`000?l00000<`3<o`00000201T0iP03o`0000000?l0003o06<0003o
1Oooool10000007ooooo00000`00003oooooooooo`02oooooi`0o`0000Go00000>H06@3V01T0iP0I
o`0000020<`0<`Co000000D0IP2Io`000?l00000<`3<o`00000201T0iP03o`0000000?l0003o06<0
003o1Oooool10000007ooooo00000`00003oooooooooo`02oooooi`0o`0000Go00000>H06@3V01T0
iP0Io`0000020<`0<`Co000000D0IP2Io`000?l00000<`3<o`00000201T0iP03o`0000000?l0003o
06<0003o1Oooool10000007ooooo00000`00003oooooooooo`02oooooi`0o`0000Go00000>H06@3V
01T0iP0Io`0000020<`0<`Co000000D0IP2Io`000?l00000<`3<o`00000201T0iP03o`0000000?l0
003o06<0003o1Oooool10000007ooooo00000`00003oooooooooo`02oooooi`0o`0000Go00000>H0
6@3V01T0iP0Io`0000020<`0<`03o`00002c04co000000?o00000`0c0<`01?l000006@3V01T0i_l0
001T0000o`Gooooo0@000001ooooo`0000<00000ooooooooool00_oooonL0?l00005o`00003V01T0
iP0I0>H06Ol000000P3<03<00ol00000/`1<o`000003o`0000<0<`3<00Co000001T0iP0I0>Ko0000
I0000?l5ooooo`4000000Oooool0000300000?oooooooooo00;oooooW03o00001Ol00000iP0I0>H0
6@3V01Wo00000080c00c00?o00000;<0C?l000000ol0000303<0c004o`00000I0>H06@3Vo`0006@0
003o1Oooool10000007ooooo00000`00003oooooooooo`02oooooi`0o`0000Go00000>H06@3V01T0
iP0Io`0000030<`0<`Go00000`0c0<`01?l000006@3V01T0i_l0001T0000o`Gooooo0@000001oooo
o`0000<00000ooooooooool00_oooonL0?l00005o`00003V01T0iP0I0>H06Ol000000`3<03<5o`00
00<0<`3<00Go000001T0iP0I0>H06@3Vo`00001S0000o`Gooooo0@000001ooooo`0000<00000oooo
ooooool00_oooonL0?l00005o`00003V01T0iP0I0>H06Ol000000`3<03<5o`0000<0<`3<00Go0000
01T0iP0I0>H06@3Vo`00001S0000o`Gooooo0@000001ooooo`0000<00000ooooooooool00_oooonL
0?l00005o`00003V01T0iP0I0>H06Ol000000`3<03<5o`0000<0<`3<00Go000001T0iP0I0>H06@3V
o`00001S0000o`Gooooo0@000001ooooo`0000<00000ooooooooool00_oooonL0?l00005o`00003V
01T0iP0I0>H06Ol000000`3<03<5o`0000<0<`3<00Go000001T0iP0I0>H06@3Vo`00001S0000o`Go
oooo0@000001ooooo`0000<00000ooooooooool00_oooonL0?l00005o`00003V01T0iP0I0>H06Ol0
00000`3<03<5o`0000<0<`3<00Go000001T0iP0I0>H06@3Vo`00001S0000o`Gooooo0@000001oooo
o`0000<00000ooooooooool00_oooonK0?l00003o`00003V01T0iP0I0080iP0I00Go00000<`0<`3<
03?o00000;<0C004o`0000<0<`3<00Go000001T0iP0I0>H06@3Vo`00001S0000o`Gooooo0@000001
ooooo`0000<00000ooooooooool00_oooonK0?l00003o`00003V01T0iP0I0080iP0I00Go00000<`0
<`3<03?o00000;<0C004o`0000<0<`3<00Go000001T0iP0I0>H06@3Vo`00001S0000o`Gooooo0@00
0001ooooo`0000<00000ooooooooool00_oooonK0?l00005o`00003V01T0iP0I0>H06Ol000000`3<
03<5o`00000504`0/ol00000<`3<03<0c?l00000100I0>H00ol00000003o0000o`1P0000o`Gooooo
0@000001ooooo`0000<00000ooooooooool00_oooonK0?l00005o`00003V01T0iP0I0>H06Ol00000
0`3<03<5o`00000504`0/ol00000<`3<03<0c?l00000100I0>H00ol00000003o0000o`1P0000o`Go
oooo0@000001ooooo`0000<00000ooooooooool00_oooonK0?l00005o`00003V01T0iP0I0>H06Ol0
00000`3<03<5o`00000304`0/ol00000<`3<0080<`3<00Go000001T0iP0I0>H06@3Vo`00001R0000
o`Gooooo0@000001ooooo`0000<00000ooooooooool00_oooonJ0?l00003o`00003V01T0iP0I0080
iP0I00Go00000<`0<`3<03?o00000;<0C004o`00000304`0/ol00000<`3<0080<`3<00Go000001T0
iP0I0>H06@3Vo`00001R0000o`Gooooo0@000001ooooo`0000<00000ooooooooool00_oooonJ0?l0
0003o`00003V01T0iP0I0080iP0I00Go00000<`0<`3<03?o00000;<0C004o`00000304`0/ol00000
<`3<0080<`3<00Go000001T0iP0I0>H06@3Vo`00001R0000o`Gooooo0@000001ooooo`0000<00000
ooooooooool00_oooonJ0?l00003o`00003V01T0iP0I0080iP0I00Go00000<`0<`3<03?o00000;<0
C004o`00000304`0/ol00000<`3<0080<`3<00Go000001T0iP0I0>H06@3Vo`00001R0000o`Gooooo
0@000001ooooo`0000<00000ooooooooool00_oooonJ0?l00003o`00003V01T0iP0I0080iP0I00Go
00000<`0<`3<03?o00000;<0C004o`00000304`0/ol00000<`3<0080<`3<00Go000001T0iP0I0>H0
6@3Vo`00001R0000o`Gooooo0@000001ooooo`0000<00000ooooooooool00_oooonI0?l00003o`00
003V01T0iP0I0080iP0I00Go00000<`0<`3<03?o00000;<0C004o`00000304`0/ol00000<`3<0080
<`3<00?o000001T0iP0I0>H00P0I0>H00ol00000003o0000o`1P0000o`Gooooo0@000001ooooo`00
00<00000ooooooooool00_oooonI0?l00003o`00003V01T0iP0I0080iP0I00Go00000<`0<`3<03?o
00000;<0C004o`00000304`0/ol00000<`3<0080<`3<00?o000001T0iP0I0>H00P0I0>H00ol00000
003o0000o`1P0000o`Gooooo0@000001ooooo`0000<00000ooooooooool00_oooonH0?l00003o`00
003V01T0iP0I00<0iP0I00Go00000<`0<`3<03?o00000;<0C004o`00000304`0/ol00000<`3<0080
<`3<00?o000001T0iP0I0>H00P0I0>H00ol00000003o0000o`1P0000o`Gooooo0@000001ooooo`00
00<00000ooooooooool00_oooonH0?l00003o`00003V01T0iP0I0080iP0I00Go00000<`0<`3<03?o
00000;<0C004o`00000304`0/ol00000<`3<00<0<`3<00?o000001T0iP0I0>H00P0I0>H00ol00000
003o0000o`1P0000o`Gooooo0@000001ooooo`0000<00000ooooooooool00_oooonG0?l00003o`00
003V01T0iP0I00<0iP0I00Go00000<`0<`3<03?o00000;<0C004o`00000304`0/ol00000<`3<0080
<`3<00?o000001T0iP0I0>H00`0I0>H00ol00000003o0000o`1P0000o`Gooooo0@000001ooooo`00
00<00000ooooooooool00_oooonG0?l00003o`00003V01T0iP0I0080iP0I00Co00000<`0<`3<03?o
00000P2c04`4o`00000304`0/ol00000<`3<0080<`3<00?o000001T0iP0I0>H00P0I0>H00ol00000
003o0000o`1Q0000o`Gooooo0@000001ooooo`0000<00000ooooooooool00_oooonG0?l00003o`00
003V01T0iP0I0080iP0I00Go00000<`0<`3<03?o00000;<0C004o`00000304`0/ol00000<`3<00<0
<`3<00?o000001T0iP0I0>H00P0I0>H00ol00000003o0000o`1Q0000o`Gooooo0@000001ooooo`00
00<00000ooooooooool00_oooonF0?l00003o`00003V01T0iP0I0080iP0I00Ko00000<`0<`3<03<0
c00co`00002c04`4o`00000304`0/ol00000<`3<00<0<`3<00?o000001T0iP0I0>H00P0I0>H00ol0
0000003o0000o`1Q0000o`Gooooo0@000001ooooo`0000<00000ooooooooool00_oooonF0?l00003
o`00003V01T0iP0I0080iP0I00Co00000<`0<`3<03?o00000P2c04`4o`00000304`0/ol00000<`3<
00<0<`3<00?o000001T0iP0I0>H00P0I0>H00ol00000003o0000o`1Q0000o`Gooooo0@000001oooo
o`0000<00000ooooooooool00_oooonE0?l00003o`00003V01T0iP0I00<0iP0I00Go00000<`0<`3<
03?o00000;<0C004o`00000304`0/ol00000<`3<00<0<`3<00?o000001T0iP0I0>H00`0I0>H00ol0
0000003o0000o`1Q0000o`Gooooo0@000001ooooo`0000<00000ooooooooool00_oooonD0?l000;o
0000103V01T01?l00000c00c0<`0<ol000020;<0C0Co000000<0C02co`00000c0<`00`0c0<`00ol0
00006@3V01T0iP0301T0iP03o`0000000?l0003o0640003o1Oooool10000007ooooo00000`00003o
ooooooooo`02oooooi<0o`0000?o00000>H06@3V01T0103V01T01?l00000c00c0<`0<ol000020;<0
C0Co000000<0C02co`00000c0<`00`0c0<`00ol000006@3V01T0iP0301T0iP03o`0000000?l0003o
0640003o1Oooool10000007ooooo00000`00003oooooooooo`02oooooi80o`0000?o00000>H06@3V
01T0103V01T01?l00000c00c0<`0<ol000020;<0C003o`00002I06Ko000000;o000000<0C02co`00
000c0<`00P0c0<`00ol000006@3V01T0iP0301T0iP03o`0000000?l0003o0680003o1Oooool10000
007ooooo00000`00003oooooooooo`02oooooi40o`0000?o00000>H06@3V01T0103V01T01?l00000
c00c0<`0<ol000020;<0C003o`00002I06H0V@1V00;o00000P1<0;<01Ol00000<`3<03<0c00c0<co
000000D06@3V00?o00000000o`000?l0HP000?l5ooooo`4000000Oooool0000300000?oooooooooo
00;oooooT03o00000ol00000iP0I0>H06@040>H06@04o`00003<03<0c00co`000080/`1<00?o0000
09T0IP2I06H00ol000000`1<0;?o000003<0c00303<0c003o`00000I0>H06@3V00806@3V00?o0000
0000o`000?l0H`000?l5ooooo`4000000Oooool0000300000?oooooooooo00;oooooS`3o00000ol0
0000iP0I0>H06@040>H06@04o`00003<03<0c00co`0000<0/`1<00Co000009T0I_l00000O`1o0_l0
00000`1<0;?o000003<0c00203<0c003o`00000I0>H06@3V00<06@3V00?o00000000o`000?l0H`00
0?l5ooooo`4000000Oooool0000300000?oooooooooo00;oooooSP3o00000ol00000iP0I0>H06@03
0>H06@;o00000`3<03<01_l00000/`1<0;<0C?l00000V@1Vo`000080O`1o0_l000000`1<0;?o0000
03<0c00203<0c003o`00000I0>H06@3V00<06@3V00?o00000000o`000?l0H`000?l5ooooo`400000
0Oooool0000300000?oooooooooo00;oooooS@3o00000ol00000iP0I0>H06@030>H06@03o`00003<
03<0c00c0080c00c00Ko00000;<0C02c04co000009T0I_l0000307l0O`;o000000<0C02co`00000c
0<`00P0c0<`00ol000006@3V01T0iP0201T0iP03o`0000000?l0003o06@0003o1Oooool10000007o
oooo00000`00003oooooooooo`02oooooh`0o`0000?o00000>H06@3V01T00`3V01T00ol00000c00c
0<`0<`020<`0<`07o`00002c04`0/`1<0;<0C?l00000V@1Vo`00000207l0O`;o00000P1<0;<01?l0
0000<`3<03<0c?l0000501T0iP03o`0000000?l0003o06@0003o1Oooool10000007ooooo00000`00
003oooooooooo`02oooooh/0o`0000?o00000>H06@3V01T00`3V01T00ol00000c00c0<`0<`020<`0
<`07o`00002c04`0/`1<0;<0C?l00000V@1Vo`00000207l0O`05o`00001V09Wo000004`0/ol00000
0`0c0<`00ol000006@3V01T0iP0201T0iP03o`0000000?l0003o06D0003o1Oooool10000007ooooo
00000`00003oooooooooo`02ooooohT0o`000_l000050>H06@03o`00003<03<0c00c0080c00c00Oo
00000;<0C02c04`0/`1<o`00002I06Ko00000080O`1o00?o000006H0VOl000000P1<0;<01Ol00000
<`3<03<0c00c0<co000000@06@3V00?o00000000o`000?l0I@000?l5ooooo`4000000Oooool00003
00000?oooooooooo00;oooooQP3o0003o`0000D0iP0I0_l000030<`0<`;o00000P2c04`4o`000003
07l0Ool0003o000000;o00000`1<0;<01?l00000<`3<03<0c?l0000501T0iP03o`0000000?l0003o
06D0003o1Oooool10000007ooooo00000`00003oooooooooo`02oooooako0000H`3o0005o`0000D0
iP0I0ol000030<`0<`;o00000`2c04`00ol00000V@1Vo`00000207l0O`03o`00001V09Wo000000@0
C02c00Go000003<0c00c0<`0<`3<o`00000501T0iP03o`0000000?l0003o06D0003o1Oooool10000
007ooooo00000`00003oooooooooo`02oooooa?o00002`3V01T<o`0005@0o`000ol000080>H06@;o
0000103<03<2o`0000<0/`1<0_l000000`2I06Ko000007l0O`04o`0000<0C02c0_l0000303<0c003
o`00000I0>H06@3V00<06@3V00?o00000000o`000?l0IP000?l5ooooo`4000000Oooool000030000
0?oooooooooo00;ooooo7_l0000<0>H06@Oo0000BP3o0003o`0000P0iP0I0ol000040<`0<`;o0000
0`2c04`2o`000080V@1V0ol000000`1V09Wo000004`0/`0304`0/`03o`00000c0<`0<`3<0080<`3<
00?o000001T0iP0I0>H00`0I0>H00ol00000003o0000o`1W0000o`Gooooo0@000001ooooo`0000<0
0000ooooooooool00_oooolKo`0000<0c00c2Ol0000:0>H06@Co0000@`3o0003o`0000P0iP0I0ol0
00050<`0<`;o00000P2c04`3o`000080V@1V0ol0000206H0V@04o`00001<0;<0C02c04`0/`;o0000
100c0<`00ol000006@3V01T0iP0301T0iP03o`0000000?l0003o06P0003o1Oooool10000007ooooo
00000`00003oooooooooo`02ooooo`Oo0000302I06H>o`0000H0c00c1Ol000090>H06@Co0000?03o
0003o`0000P0iP0I0ol000060<`0<`;o00000P2c04`2o`0000<0V@1V1?l000000`1V09Wo0000o`00
000304`0/`03o`00000c0<`0<`3<00<0<`3<00?o000001T0iP0I0>H00`0I0>H00ol00000003o0000
o`1Y0000o`Gooooo0@000001ooooo`0000<00000ooooooooool00_oooolCo`0000P0V@1V2ol00006
0<`0<`Go0000203V01T5o`000380o`001Ol000090>H06@;o00001P3<03<3o`000080/`1<0_l00002
09T0IPGo00000P1V09T01?l00000C02c04`0/`1<0;<2o`0000@0<`3<0_l0000501T0iP03o`000000
0?l0003o06X0003o1Oooool10000007ooooo00000`00003oooooooooo`02oooooa_o00001P2I06H4
o`0000030;<0C?l0003o000000;o00001`3<03<3o`0000X0iP0I1Ol0000X0?l000Go00002`3V01T3
o`0000D0c00c0ol000030;<0C0;o00000P2I06H2o`00000307l0Ool0003o00000080IP2I0_l00003
04`0/`03o`00000c0<`0<`3<0080<`3<0_l0000601T0iP03o`0000000?l0003o06/0003o1Oooool1
0000007ooooo00000`00003oooooooooo`02oooooa[o000000<0O`1oo`000?l000001?l0000409T0
IP?o00000P2c04`3o`0000L0c00c0ol0000<0>H06@Wo00005P3o0009o`0000d0iP0I0ol000050<`0
<`?o0000102c04`2o`000080V@1V0_l0000207l0O`05o`00001V09T0IP2I06H0VOl000000`1<0;<2
o`0000@0<`3<00?o000001T0iP0I0>H01@0I0>H00ol00000003o0000o`1/0000o`Gooooo0@000001
ooooo`0000<00000ooooooooool00_ooool703<0c0Wo00000`1<0;<;o`0000<0O`1o1?l0000309T0
IP?o00000P2c04`4o`0000H0c00c0ol0000B0>H06AKo00004`3V01T3o`0000H0c00c0_l000040;<0
C0?o00000P2I06H2o`000080O`1o0_l0000206H0V@;o00000`1<0;<00ol00000<`3<03<0c00203<0
c0;o00001`0I0>H00ol00000003o0000o`1]0000o`Gooooo0@000001ooooo`0000<00000oooooooo
ool00_oooolEo`0000D0C02c0ol000000`1V09Wo0000o`000002o`0000<0O`1o0_l0000409T0IP?o
00000`2c04`3o`0000H0c00c1ol0000`0>H06@Co00001P3<03<3o`0000@0/`1<0_l0000309T0IP;o
00000P1o07l2o`0000<0IP2I00?o000004`0/`1<0;<00P1<0;<01?l00000<`3<03<0c00c0<`2o`00
00P06@3V00?o00000000o`000?l0KP000?l5ooooo`4000000Oooool0000300000?oooooooooo00;o
oooo3Ol0000301T0iP[o00000`1<0;<3o`000080IP2I0_l0000307l0O`;o00001@2I06H00ol00000
/`1<0;<0C0030;<0C0?o00002P3<03<5o`0002H0iP0I1Ol000070<`0<`?o00001@2c04`2o`0000@0
V@1V00Go000007l0O`1o07l0O`1oo`00000406H0V@03o`00001<0;<0C02c0080C02c00Go000003<0
c00c0<`0<`3<o`00000901T0iP03o`0000000?l0003o06l0003o1Oooool10000007ooooo00000`00
003oooooooooo`02ooooo`d0003o0_l0000601T0iPCo000000@0<`3<o`000?l0003o00000`1<0;<3
o`00000406H0VOl0003o0000o`000080O`1o1?l0000209T0IPOo000000<0/`1<o`000?l000002?l0
00040<`0<bOo00000P3<03<:o`0000@0/`1<1?l0000209T0IPCo000000@0O`1oo`000?l0003o0000
0`1V09T2o`0000<0C02c0_l0000203<0c0;o0000200I0>H2o`000780003o1Oooool10000007ooooo
00000`00003oooooooooo`02ooooo`l0003o0ol0000701T0iP?o000000@0<`3<o`000?l0003o0000
0`1<0;<3o`00000406H0VOl0003o0000o`0000<0O`1o1Ol0000409T0ISSo0000202c04`<o`000080
O`1o0ol0000406H0V@;o00000`1<0;<2o`000080<`3<0_l0000801T0iP;o0000M0000?l5ooooo`40
00000Oooool0000300000?oooooooooo00;ooooo4P000?l2o`0000P06@3V0_l0000203<0c0?o0000
0`1<0;<7o`0000D0O`1o1_l0000909T0IP_o00005P2c04`Jo`0000D0O`1o0ol0000406H0V@?o0000
0P1<0;<3o`000080<`3<0_l0000801T0iP;o0000MP000?l5ooooo`4000000Oooool0000300000?oo
oooooooo00;ooooo50000?l3o`0000L06@3V0_l0000303<0c0?o0000101<0;<;o`0000<0O`1o2Ol0
000;09T0IQKo0000302I06H8o`0000H0O`1o1Ol0000306H0V@Co00000`1<0;<2o`0000<0<`3<0_l0
000801T0iP;o0000N0000?l5ooooo`4000000Oooool0000300000?oooooooooo00;ooooo5`000?l3
o`0000H06@3V0ol0000303<0c0Co00000`1<0;=1o`0000P0O`1o1_l0000506H0V@?o0000101<0;<3
o`0000@0<`3<00?o000001T0iP0I0>H01P0I0>H2o`0007X0003o1Oooool10000007ooooo00000`00
003oooooooooo`02oooooaX0003o0ol0000601T0iP?o0000100c0<`3o`0000P0C02c@Ol0000306H0
V@So00000`1<0;<4o`0000D0<`3<0_l0000701T0iP;o0000O0000?l5ooooo`4000000Oooool00003
00000?oooooooooo00;ooooo7@000?l3o`0000H06@3V1?l0000303<0c0So0000301<0;<Go`0000X0
IP2I5ol0000804`0/`?o00001`0c0<`2o`0000L06@3V0_l0001n0000o`Gooooo0@000001ooooo`00
00<00000ooooooooool00_oooolP0000o`?o00001`0I0>H3o`0000P0<`3<5ol0000<04`0/`[o0000
5`1<0;<8o`0000@0<`3<1_l0000601T0iP?o0000P0000?l5ooooo`4000000Oooool0000300000?oo
oooooooo00;ooooo8`000?l7o`0000<06@3V5?l0000;03<0c3Wo00002@0I0>H3o`0008<0003o1Ooo
ool10000007ooooo00000`00003oooooooooo`02ooooobX0003o2ol0000<01T0iSSo00004P0I0>H3
o`0008H0003o1Oooool10000007ooooo00000`00003oooooooooo`02ooooocD0003o8ol0000]01T0
iPKo0000R@000?l5ooooo`4000000Oooool0000300000?oooooooooo00;oooooF0000?l]o`0008l0
003o1Oooool10000007ooooo00000`00003oooooooooo`02ooooool0003o5@000?l5ooooo`400000
0Oooool0000300000?oooooooooo00;oooooo`000?lE0000o`Gooooo0@000001ooooo`0000<00000
ooooooooool00_oooooo0000oaD0003o1Oooool10000007ooooo00000`00003oooooooooo`02oooo
ool0003o5@000?l5ooooo`4000000Oooool0000300000?oooooooooo00;oooooo`000?lE0000o`Go
oooo0@000001ooooo`0000<00000ooooooooool00_oooooo0000oaD0003o1Oooool10000007ooooo
00000`00003oooooooooo`02ooooool0003o5@000?l5ooooo`4000000Oooool0000300000?oooooo
oooo00;oooooo`000?lE0000o`Gooooo0@000001ooooo`0000<00000ooooooooool00_oooooo0000
oaD0003o1Oooool10000007ooooo00000`00003oooooooooo`02ooooool0003o5@000?l5ooooo`40
00000Oooool0000300000?oooooooooo00;oooooo`000?lE0000o`Gooooo0@000001ooooo`0000<0
0000ooooooooool00_oooooo0000oaD0003o1Oooool10000007ooooo00000`00003oooooooooo`02
ooooool0003o5@000?l5ooooo`4000000Oooool0000300000?oooooooooo00;oooooo`000?lE0000
o`Gooooo0@000001ooooo`0000<00000ooooooooool00_oooooo0000oaD0003o1Oooool10000007o
oooo00000`00003oooooooooo`02ooooool0003o5@000?l5ooooo`4000000Oooool0000300000?oo
oooooooo00;oooooo`000?lE0000o`Gooooo0@000001ooooo`0000<00000ooooooooool00_oooooo
0000oaD0003o1Oooool10000007ooooo00000`00003oooooooooo`02ooooool0003o5@000?l5oooo
o`4000000Oooool0000300000?oooooooooo00;oooooo`000?lE0000o`Gooooo0@000001ooooo`00
00<00000ooooooooool00_oooooo0000oaD0003o1Oooool10000007ooooo00000`00003ooooooooo
o`02ooooool0003o5@000?l5ooooo`4000000Oooool0000300000?oooooooooo00;oooooo`000?lE
0000o`Gooooo0@000001ooooo`0000<00000ooooooooool00_oooooo0000oaD0003o1Oooool10000
007ooooo00000`00003oooooooooo`02ooooool0003o5@000?l5ooooo`4000000Oooool000030000
0?oooooooooo00;oooooo`000?lE0000o`Gooooo0@000001ooooo`0000<00000ooooooooool00_oo
oooo0000oaD0003o1Oooool10000007ooooo00000`00003oooooooooo`02ooooool0003o5@000?l5
ooooo`4000000Oooool0000300000?oooooooooo00;oooooo`000?lE0000o`Gooooo0@000001oooo
o`0000<00000ooooooooool00_oooooo0000oaD0003o1Oooool10000007ooooo00000`00003ooooo
ooooo`02ooooool0003o5@000?l5ooooo`4000000Oooool0000300000?oooooooooo00;oooooo`00
0?lE0000o`Gooooo0@000001ooooo`0000<00000ooooooooool00_oooooo0000oaD0003o1Oooool1
0000007ooooo00000`00003oooooooooo`02ooooool0003o5@000?l5ooooo`4000000Oooool00003
00000?oooooooooo00;oooooo`000?lE0000o`Gooooo0@000001ooooo`0000<00000ooooooooool0
0_oooooo0000oaD0003o1Oooool10000007ooooo00000`00003oooooooooo`02ooooool0003o5@00
0?l5ooooo`4000000Oooool0000300000?oooooooooo00;oooooo`000?lE0000o`Gooooo0@000001
ooooo`0000<00000ooooooooool00_oooooo0000oaD0003o1Oooool10000007ooooo00000`00003o
ooooooooo`02ooooool0003o5@000?l5ooooo`4000000Oooool0000300000?oooooooooo00;ooooo
o`000?lE0000o`Gooooo0@000001ooooo`0000<00000ooooooooool00_oooooo0000oaD0003o1Ooo
ool10000007ooooo00000`00003oooooooooo`02ooooool0003o5@000?l5ooooo`4000000Oooool0
000300000?oooooooooo00;oooooo`000?lE0000o`Gooooo0@000001ooooo`0000<00000oooooooo
ool00_oooooo0000oaD0003o1Oooool10000007ooooo00000`00003oooooooooo`02ooooool0003o
5@000?l5ooooo`4000000Oooool0000300000?oooooooooo00;oooooo`000?lE0000o`Gooooo0@00
0001ooooo`0000<00000ooooooooool00_oooooo0000oaD0003o1Oooool10000007ooooo00000`00
003oooooooooo`02ooooool0003o5@000?l5ooooo`4000000Oooool0000300000?oooooooooo00;o
ooooo`000?lE0000o`Gooooo0@000001ooooo`0000<00000ooooooooool00_oooooo0000oaD0003o
1Oooool10000007ooooo00000`00003oooooooooo`02ooooool0003o5@000?l5ooooo`4000000Ooo
ool0000300000?oooooooooo00;oooooo`000?lE0000o`Gooooo0@000001ooooo`0000<00000oooo
ooooool00_oooooo0000oaD0003o1Oooool10000007ooooo00000`00003oooooooooo`02ooooool0
003o5@000?l5ooooo`4000000Oooool0000300000?oooooooooo00;oooooo`000?lE0000o`Gooooo
0@000001ooooo`0000<00000ooooooooool00_oooooo0000oaD0003o1Oooool10000007ooooo0000
0`00003oooooooooo`02ooooool0003o5@000?l5ooooo`4000000Oooool0000300000?oooooooooo
00;oooooo`000?lE0000o`Gooooo0@000001ooooo`0000<00000ooooooooool00_oooooo0000oaD0
003o1Oooool10000007ooooo00000`00003oooooooooo`02ooooool0003o5@000?l5ooooo`400000
0Oooool0000300000?oooooooooo00;oooooo`000?lE0000o`Gooooo0@000001ooooo`0000<00000
ooooooooool00_oooooo0000oaD0003o1Oooool10000007ooooo00000`00003oooooooooo`02oooo
ool0003o5@000?l5ooooo`4000000Oooool0000300000?oooooooooo00;oooooo`000?lE0000o`Go
oooo0@000001ooooo`0000<00000ooooooooool00_oooooo0000oaD0003o1Oooool10000007ooooo
00000`00003oooooooooo`02ooooool0003o5@000?l5ooooo`4000000Oooool0000300000?oooooo
oooo00;oooooo`000?lE0000o`Gooooo0@000001ooooo`0000<00000ooooooooool00_oooooo0000
oaD0003o1Oooool10000007ooooo00000`00003oooooooooo`02ooooool0003o5@000?l5ooooo`40
00000Oooool0000300000?oooooooooo00;oooooo`000?lE0000o`Gooooo0@000001ooooo`0000<0
0000ooooooooool00_oooooo0000oaD0003o1Oooool10000007ooooo00000`00003oooooooooo`02
ooooool0003o5@000?l5ooooo`4000000Oooool0000300000?oooooooooo00;oooooo`000?lE0000
o`Gooooo0@000001ooooo`0000<00000ooooooooool00_oooooo0000oaD0003o1Oooool10000007o
oooo00000`00003oooooooooo`02ooooool0003o5@000?l5ooooo`4000000Oooool0000300000?oo
oooooooo00;oooooo`000?lE0000o`Gooooo0@000001ooooo`0000<00000ooooooooool00_oooooo
0000oaD0003o1Oooool10000007ooooo00000`00003oooooooooo`02ooooool0003o5@000?l5oooo
o`4000000Oooool0000300000?oooooooooo00;oooooo`000?lE0000o`Gooooo0@000001ooooo`00
00<00000ooooooooool00_oooooo0000oaD0003o1Oooool10000007ooooo00000`00003ooooooooo
o`02ooooool0003o5@000?l5ooooo`4000000Oooool0000300000?oooooooooo00;oooooo`000?lE
0000o`Gooooo0@000001ooooo`0000<00000ooooooooool00_oooooo0000oaD0003o1Oooool10000
007ooooo00000`00003oooooooooo`02ooooool0003o5@000?l5ooooo`4000000Oooool000030000
0?oooooooooo00;oooooo`000?lE0000o`Gooooo0@000001ooooo`0000<00000ooooooooool00_oo
oooo0000oaD0003o1Oooool10000007ooooo00000`00003oooooooooo`02ooooool0003o5@000?l5
ooooo`4000000Oooool0000300000?oooooooooo00;oooooo`000?lE0000o`Gooooo0@000001oooo
o`0000<00000ooooooooool00_oooooo0000oaD0003o1Oooool10000007ooooo00000`00003ooooo
ooooo`02ooooool0003o5@000?l5ooooo`4000000Oooool0000300000?oooooooooo00;oooooo`00
0?lE0000o`Gooooo0@000001ooooo`0000<00000ooooooooool00_oooooo0000oaD0003o1Oooool1
0000007ooooo00000`00003oooooooooo`02ooooool0003o5@000?l5ooooo`4000000Oooool00003
00000?oooooooooo00;oooooo`000?lE0000o`Gooooo0@000001ooooo`0000<00000ooooooooool0
0_oooooo0000oaD0003o1Oooool10000007ooooo00000`00003oooooooooo`02ooooool0003o5@00
0?l5ooooo`4000000Oooool0000300000?oooooooooo00;oooooo`000?lE0000o`Gooooo0@000001
ooooo`0000<00000ooooooooool00_oooooo0000oaD0003o1Oooool10000007ooooo00000`00003o
ooooooooo`02ooooool0003o5@000?l5ooooo`4000000Oooool0000300000?oooooooooo00;ooooo
o`000?lE0000o`Gooooo0@000001ooooo`0000<00000ooooooooool00_oooooo0000oaD0003o1Ooo
ool10000007ooooo00000`00003oooooooooo`02ooooool0003o5@000?l5ooooo`4000000Oooool0
000300000?oooooooooo00;oooooo`000?lE0000o`Gooooo0@000001ooooo`0000<00000oooooooo
ool00_oooooo0000oaD0003o1Oooool10000007ooooo00000`00003oooooooooo`02ooooool0003o
5@000?l5ooooo`4000000Oooool0000300000?oooooooooo00;oooooo`000?lE0000o`Gooooo0@00
0001ooooo`0000<00000ooooooooool00_oooooo0000oaD0003o1Oooool10000007ooooo00000`00
003oooooooooo`02ooooool0003o5@000?l5ooooo`4000000Oooool0000300000?oooooooooo00;o
ooooo`000?lE0000o`Gooooo0@000001ooooo`0000<00000ooooooooool00_oooooo0000oaD0003o
1Oooool10000007ooooo00000`00003oooooooooo`02ooooool0003o5@000?l5ooooo`4000000Ooo
ool0000300000?oooooooooo00;oooooo`000?lE0000o`Gooooo0@000001ooooo`0000<00000oooo
ooooool00_oooooo0000oaD0003o1Oooool10000007ooooo00000`00003oooooooooo`02ooooool0
003o5@000?l5ooooo`4000000Oooool0000300000?oooooooooo00;oooooo`000?lE0000o`Gooooo
0@000001ooooo`0000<00000ooooooooool00_oooooo0000oaD0003o1Oooool10000007ooooo0000
0`00003oooooooooo`02ooooool0003o5@000?l5ooooo`4000000Oooool0000300000?oooooooooo
00;oooooo`000?lE0000o`Gooooo0@000001ooooo`0000<00000ooooooooool00_oooooo0000oaD0
003o1Oooool10000007ooooo00000`00003oooooooooo`02ooooool0003o5@000?l5ooooo`400000
0Oooool0000300000?oooooooooo00;oooooo`000?lE0000o`Gooooo0@000001ooooo`0000<00000
ooooooooool00_oooooo0000oaD0003o1Oooool10000007ooooo00000`00003oooooooooo`02oooo
ool0003o5@000?l5ooooo`4000000Oooool0000300000?oooooooooo00;oooooo`000?lE0000o`Go
oooo0@000001ooooo`0000<00000ooooooooool00_oooooo0000oaD0003o1Oooool10000007ooooo
00000`00003oooooooooo`02ooooool0003o5@000?l5ooooo`4000000Oooool0000300000?oooooo
oooo00;oooooo`000?lE0000o`Gooooo0@000001ooooo`0000<00000ooooooooool00_oooooo0000
oaD0003o1Oooool10000007ooooo00000`00003oooooooooo`02ooooool0003o5@000?l5ooooo`40
00000Oooool0000300000?oooooooooo00;oooooo`000?lE0000o`Gooooo0@000001ooooo`0000<0
0000ooooooooool00_oooooo0000oaD0003o1Oooool10000007ooooo00000`00003oooooooooo`02
ooooool0003o5@000?l5ooooo`4000000Oooool0000300000?oooooooooo00;oooooo`000?lE0000
o`Gooooo0@000001ooooo`0000<00000ooooooooool00_oooooo0000oaD0003o1Oooool10000007o
oooo00000`00003oooooooooo`02ooooool0003o5@000?l5ooooo`4000000Oooool0000300000?oo
oooooooo00;oooooo`000?lE0000o`Gooooo0@000001ooooo`0000<00000ooooooooool00_oooooo
0000oaD0003o1Oooool10000007ooooo00000`00003oooooooooo`3ooooooacooooo0@000001oooo
o`0000<00000ooooooooool0oooooolLooooo`4000000Oooool0000300000?oooooooooo0?oooooo
7?ooool10000007ooooo00000`00003oooooooooo`3ooooooacooooo0@000001ooooo`00o`00000P
0000007ooooo0000\
\>"],
  ImageRangeCache->{{{0, 287}, {287, 0}} -> {-1.04092, -1.04092, 0.00725378, \
0.00725378}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% ContourGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.480769 0.5 0.480769 [
[ 0 0 -0.125 0 ]
[ 0 0 -0.125 0 ]
[ 0 1 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
0 0 m
1 0 L
s
0 0 m
0 1 L
s
0 1 m
1 1 L
s
1 0 m
1 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
0 0 1 r
.01923 .98077 m
.98077 .98077 L
.98077 .01923 L
.01923 .01923 L
F
0 g
.5 Mabswid
.1 0 .9 r
.01923 .53514 m
.05929 .53601 L
.09936 .53637 L
.13942 .53655 L
.17949 .53667 L
.21955 .53678 L
.25962 .53687 L
.29968 .53691 L
.33974 .53684 L
.37981 .53653 L
.41987 .53567 L
.45994 .53314 L
.5 .52387 L
.54006 .50467 L
.55396 .5 L
.58013 .49441 L
.62019 .46487 L
.62609 .45994 L
.66007 .41987 L
.66026 .41938 L
.68378 .37981 L
.69491 .33974 L
.69726 .29968 L
.69768 .25962 L
.69737 .21955 L
.69675 .17949 L
.69589 .13942 L
.69388 .09936 L
.68531 .05929 L
.66274 .01923 L
.01923 .01923 L
F
0 g
.01923 .53514 m
.05929 .53601 L
.09936 .53637 L
.13942 .53655 L
.17949 .53667 L
.21955 .53678 L
.25962 .53687 L
.29968 .53691 L
.33974 .53684 L
.37981 .53653 L
.41987 .53567 L
.45994 .53314 L
.5 .52387 L
.54006 .50467 L
.55396 .5 L
.58013 .49441 L
.62019 .46487 L
.62609 .45994 L
.66007 .41987 L
.66026 .41938 L
.68378 .37981 L
.69491 .33974 L
.69726 .29968 L
.69768 .25962 L
.69737 .21955 L
.69675 .17949 L
.69589 .13942 L
.69388 .09936 L
.68531 .05929 L
.66274 .01923 L
s
.2 0 .8 r
.01923 .52925 m
.05929 .53105 L
.09936 .53179 L
.13942 .53214 L
.17949 .53233 L
.21955 .53244 L
.25962 .53249 L
.29968 .53244 L
.33974 .53218 L
.37981 .53147 L
.41987 .52966 L
.45994 .52462 L
.5 .51044 L
.5191 .5 L
.54006 .49612 L
.58013 .48355 L
.6097 .45994 L
.62019 .45175 L
.6498 .41987 L
.66026 .39518 L
.66904 .37981 L
.68612 .33974 L
.69102 .29968 L
.69227 .25962 L
.69225 .21955 L
.6916 .17949 L
.69021 .13942 L
.68637 .09936 L
.67268 .05929 L
.66026 .03616 L
.65665 .01923 L
.01923 .01923 L
F
0 g
.01923 .52925 m
.05929 .53105 L
.09936 .53179 L
.13942 .53214 L
.17949 .53233 L
.21955 .53244 L
.25962 .53249 L
.29968 .53244 L
.33974 .53218 L
.37981 .53147 L
.41987 .52966 L
.45994 .52462 L
.5 .51044 L
.5191 .5 L
.54006 .49612 L
.58013 .48355 L
.6097 .45994 L
.62019 .45175 L
.6498 .41987 L
.66026 .39518 L
.66904 .37981 L
.68612 .33974 L
.69102 .29968 L
.69227 .25962 L
.69225 .21955 L
.6916 .17949 L
.69021 .13942 L
.68637 .09936 L
.67268 .05929 L
.66026 .03616 L
.65665 .01923 L
s
.3 0 .7 r
.01923 .52383 m
.05929 .52644 L
.09936 .52752 L
.13942 .52802 L
.17949 .52827 L
.21955 .52839 L
.25962 .52841 L
.29968 .52827 L
.33974 .52785 L
.37981 .52679 L
.41987 .52416 L
.45994 .51711 L
.5 .50074 L
.50106 .5 L
.54006 .49061 L
.58013 .4744 L
.5981 .45994 L
.62019 .44234 L
.64108 .41987 L
.65922 .37981 L
.66026 .37713 L
.67842 .33974 L
.68535 .29968 L
.68731 .25962 L
.68752 .21955 L
.68684 .17949 L
.68499 .13942 L
.67962 .09936 L
.66323 .05929 L
.66026 .05375 L
.65232 .01923 L
.01923 .01923 L
F
0 g
.01923 .52383 m
.05929 .52644 L
.09936 .52752 L
.13942 .52802 L
.17949 .52827 L
.21955 .52839 L
.25962 .52841 L
.29968 .52827 L
.33974 .52785 L
.37981 .52679 L
.41987 .52416 L
.45994 .51711 L
.5 .50074 L
.50106 .5 L
.54006 .49061 L
.58013 .4744 L
.5981 .45994 L
.62019 .44234 L
.64108 .41987 L
.65922 .37981 L
.66026 .37713 L
.67842 .33974 L
.68535 .29968 L
.68731 .25962 L
.68752 .21955 L
.68684 .17949 L
.68499 .13942 L
.67962 .09936 L
.66323 .05929 L
.66026 .05375 L
.65232 .01923 L
s
.4 0 .6 r
.01923 .51866 m
.05929 .52203 L
.09936 .52343 L
.13942 .52407 L
.17949 .52437 L
.21955 .5245 L
.25962 .52449 L
.29968 .52428 L
.33974 .5237 L
.37981 .52231 L
.41987 .51892 L
.45994 .51012 L
.48397 .5 L
.5 .49489 L
.54006 .48544 L
.58013 .4661 L
.58777 .45994 L
.62019 .43374 L
.63306 .41987 L
.65317 .37981 L
.66026 .36225 L
.67126 .33974 L
.67996 .29968 L
.68257 .25962 L
.68301 .21955 L
.68229 .17949 L
.68001 .13942 L
.67326 .09936 L
.66026 .06842 L
.65677 .05929 L
.64822 .01923 L
.01923 .01923 L
F
0 g
.01923 .51866 m
.05929 .52203 L
.09936 .52343 L
.13942 .52407 L
.17949 .52437 L
.21955 .5245 L
.25962 .52449 L
.29968 .52428 L
.33974 .5237 L
.37981 .52231 L
.41987 .51892 L
.45994 .51012 L
.48397 .5 L
.5 .49489 L
.54006 .48544 L
.58013 .4661 L
.58777 .45994 L
.62019 .43374 L
.63306 .41987 L
.65317 .37981 L
.66026 .36225 L
.67126 .33974 L
.67996 .29968 L
.68257 .25962 L
.68301 .21955 L
.68229 .17949 L
.68001 .13942 L
.67326 .09936 L
.66026 .06842 L
.65677 .05929 L
.64822 .01923 L
s
.5 0 .5 r
.01923 .51359 m
.05929 .5177 L
.09936 .51942 L
.13942 .5202 L
.17949 .52056 L
.21955 .5207 L
.25962 .52066 L
.29968 .52038 L
.33974 .51965 L
.37981 .51793 L
.41987 .51379 L
.45994 .50338 L
.46803 .5 L
.5 .48959 L
.54006 .48044 L
.57909 .45994 L
.58013 .45841 L
.62019 .42546 L
.62537 .41987 L
.64745 .37981 L
.66026 .34847 L
.66437 .33974 L
.6747 .29968 L
.67795 .25962 L
.67861 .21955 L
.67783 .17949 L
.67512 .13942 L
.66707 .09936 L
.66026 .08233 L
.65155 .05929 L
.64424 .01923 L
.01923 .01923 L
F
0 g
.01923 .51359 m
.05929 .5177 L
.09936 .51942 L
.13942 .5202 L
.17949 .52056 L
.21955 .5207 L
.25962 .52066 L
.29968 .52038 L
.33974 .51965 L
.37981 .51793 L
.41987 .51379 L
.45994 .50338 L
.46803 .5 L
.5 .48959 L
.54006 .48044 L
.57909 .45994 L
.58013 .45841 L
.62019 .42546 L
.62537 .41987 L
.64745 .37981 L
.66026 .34847 L
.66437 .33974 L
.6747 .29968 L
.67795 .25962 L
.67861 .21955 L
.67783 .17949 L
.67512 .13942 L
.66707 .09936 L
.66026 .08233 L
.65155 .05929 L
.64424 .01923 L
s
.6 0 .4 r
.01923 .50849 m
.05929 .51338 L
.09936 .51542 L
.13942 .51635 L
.17949 .51677 L
.21955 .51692 L
.25962 .51685 L
.29968 .51649 L
.33974 .5156 L
.37981 .51356 L
.41987 .50863 L
.45213 .5 L
.45994 .49671 L
.5 .48443 L
.54006 .47548 L
.57414 .45994 L
.58013 .4514 L
.61764 .41987 L
.62019 .41704 L
.64185 .37981 L
.65748 .33974 L
.66026 .33476 L
.66943 .29968 L
.67333 .25962 L
.6742 .21955 L
.67338 .17949 L
.67022 .13942 L
.66087 .09936 L
.66026 .09768 L
.64648 .05929 L
.64032 .01923 L
.01923 .01923 L
F
0 g
.01923 .50849 m
.05929 .51338 L
.09936 .51542 L
.13942 .51635 L
.17949 .51677 L
.21955 .51692 L
.25962 .51685 L
.29968 .51649 L
.33974 .5156 L
.37981 .51356 L
.41987 .50863 L
.45213 .5 L
.45994 .49671 L
.5 .48443 L
.54006 .47548 L
.57414 .45994 L
.58013 .4514 L
.61764 .41987 L
.62019 .41704 L
.64185 .37981 L
.65748 .33974 L
.66026 .33476 L
.66943 .29968 L
.67333 .25962 L
.6742 .21955 L
.67338 .17949 L
.67022 .13942 L
.66087 .09936 L
.66026 .09768 L
.64648 .05929 L
.64032 .01923 L
s
.7 0 .3 r
.01923 .50325 m
.05929 .50897 L
.09936 .51137 L
.13942 .51245 L
.17949 .51294 L
.21955 .5131 L
.25962 .513 L
.29968 .51256 L
.33974 .51151 L
.37981 .50909 L
.41987 .50332 L
.43363 .5 L
.45994 .48994 L
.5 .47927 L
.54006 .47043 L
.56725 .45994 L
.58013 .44435 L
.60954 .41987 L
.62019 .40798 L
.63621 .37981 L
.65039 .33974 L
.66026 .31729 L
.664 .29968 L
.66862 .25962 L
.66972 .21955 L
.66883 .17949 L
.66518 .13942 L
.66026 .11305 L
.65391 .09936 L
.64142 .05929 L
.63638 .01923 L
.01923 .01923 L
F
0 g
.01923 .50325 m
.05929 .50897 L
.09936 .51137 L
.13942 .51245 L
.17949 .51294 L
.21955 .5131 L
.25962 .513 L
.29968 .51256 L
.33974 .51151 L
.37981 .50909 L
.41987 .50332 L
.43363 .5 L
.45994 .48994 L
.5 .47927 L
.54006 .47043 L
.56725 .45994 L
.58013 .44435 L
.60954 .41987 L
.62019 .40798 L
.63621 .37981 L
.65039 .33974 L
.66026 .31729 L
.664 .29968 L
.66862 .25962 L
.66972 .21955 L
.66883 .17949 L
.66518 .13942 L
.66026 .11305 L
.65391 .09936 L
.64142 .05929 L
.63638 .01923 L
s
.8 0 .2 r
.01923 .49667 m
.03726 .5 L
.05929 .50436 L
.09936 .50718 L
.13942 .50843 L
.17949 .50899 L
.21955 .50917 L
.25962 .50904 L
.29968 .50851 L
.33974 .50727 L
.37981 .50444 L
.41097 .5 L
.41987 .49668 L
.45994 .4829 L
.5 .47398 L
.54006 .46516 L
.55609 .45994 L
.58013 .43704 L
.60099 .41987 L
.62019 .39826 L
.63039 .37981 L
.64299 .33974 L
.65736 .29968 L
.66026 .28939 L
.66368 .25962 L
.66505 .21955 L
.66408 .17949 L
.66026 .14176 L
.65966 .13942 L
.64647 .09936 L
.63627 .05929 L
.63235 .01923 L
.01923 .01923 L
F
0 g
.01923 .49667 m
.03726 .5 L
.05929 .50436 L
.09936 .50718 L
.13942 .50843 L
.17949 .50899 L
.21955 .50917 L
.25962 .50904 L
.29968 .50851 L
.33974 .50727 L
.37981 .50444 L
.41097 .5 L
.41987 .49668 L
.45994 .4829 L
.5 .47398 L
.54006 .46516 L
.55609 .45994 L
.58013 .43704 L
.60099 .41987 L
.62019 .39826 L
.63039 .37981 L
.64299 .33974 L
.65736 .29968 L
.66026 .28939 L
.66368 .25962 L
.66505 .21955 L
.66408 .17949 L
.66026 .14176 L
.65966 .13942 L
.64647 .09936 L
.63627 .05929 L
.63235 .01923 L
s
.9 0 .1 r
.01923 .48723 m
.05929 .49895 L
.06333 .5 L
.09936 .50273 L
.13942 .5042 L
.17949 .50485 L
.21955 .50504 L
.25962 .50487 L
.29968 .50424 L
.33974 .50277 L
.37589 .5 L
.37981 .49897 L
.41987 .48714 L
.45994 .47532 L
.5 .46841 L
.53876 .45994 L
.54006 .45911 L
.58013 .42912 L
.59155 .41987 L
.62019 .38726 L
.62413 .37981 L
.63498 .33974 L
.6476 .29968 L
.65691 .25962 L
.65984 .21955 L
.65796 .17949 L
.65026 .13942 L
.63833 .09936 L
.63087 .05929 L
.62815 .01923 L
.01923 .01923 L
F
0 g
.01923 .48723 m
.05929 .49895 L
.06333 .5 L
.09936 .50273 L
.13942 .5042 L
.17949 .50485 L
.21955 .50504 L
.25962 .50487 L
.29968 .50424 L
.33974 .50277 L
.37589 .5 L
.37981 .49897 L
.41987 .48714 L
.45994 .47532 L
.5 .46841 L
.53876 .45994 L
.54006 .45911 L
.58013 .42912 L
.59155 .41987 L
.62019 .38726 L
.62413 .37981 L
.63498 .33974 L
.6476 .29968 L
.65691 .25962 L
.65984 .21955 L
.65796 .17949 L
.65026 .13942 L
.63833 .09936 L
.63087 .05929 L
.62815 .01923 L
s
1 0 0 r
.01923 .4747 m
.05929 .48687 L
.09936 .49525 L
.13942 .49911 L
.15614 .5 L
.17949 .50035 L
.21955 .50057 L
.25962 .50036 L
.28309 .5 L
.29968 .49911 L
.33974 .49522 L
.37981 .48676 L
.41987 .47443 L
.45994 .46669 L
.5 .46227 L
.51594 .45994 L
.54006 .44554 L
.58013 .41991 L
.58018 .41987 L
.61393 .37981 L
.62019 .36968 L
.62574 .33974 L
.63445 .29968 L
.64384 .25962 L
.64769 .21955 L
.64538 .17949 L
.6372 .13942 L
.62888 .09936 L
.62499 .05929 L
.62365 .01923 L
.01923 .01923 L
F
0 g
.01923 .4747 m
.05929 .48687 L
.09936 .49525 L
.13942 .49911 L
.15614 .5 L
.17949 .50035 L
.21955 .50057 L
.25962 .50036 L
.28309 .5 L
.29968 .49911 L
.33974 .49522 L
.37981 .48676 L
.41987 .47443 L
.45994 .46669 L
.5 .46227 L
.51594 .45994 L
.54006 .44554 L
.58013 .41991 L
.58018 .41987 L
.61393 .37981 L
.62019 .36968 L
.62574 .33974 L
.63445 .29968 L
.64384 .25962 L
.64769 .21955 L
.64538 .17949 L
.6372 .13942 L
.62888 .09936 L
.62499 .05929 L
.62365 .01923 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P000182000`400?l00000o`00003ooooooolQ
ooooo`00o`00000P0000007ooooo00000`00003oooooooooo`3ooooooacooooo0@000001ooooo`00
00<00000ooooooooool0oooooolLooooo`4000000Oooool0000300000?oooooooooo0?oooooo7?oo
ool10000007ooooo00000`00003oooooooooo`3ooooooacooooo0@000001ooooo`0000<00000oooo
ooooool0[oooool00`00003oooooo`000004o`000006ooooool0003o0000o`000?oooooo0000Gooo
ool10000007ooooo00000`00003oooooooooo`02ooooojd0o`0000<000000>H06Ol000001?l00000
1P1V09Wo0000o`000?l000006@3Vo`0005X0003o1Oooool10000007ooooo00000`00003ooooooooo
o`02ooooojd0o`0000<000000>H06Ol000001?l00000101V09Wo0000o`000?l0000201T0iP03o`00
00000?l0003o05L0003o1Oooool10000007ooooo00000`00003oooooooooo`02ooooojd0o`0000<0
00000>H06Ol000001?l000000`1V09Wo000004`0/`02o`00000301T0i_l00000003o05P0003o1Ooo
ool10000007ooooo00000`00003oooooooooo`02ooooojd0o`0000D000000>H06Ol0003o00000;<0
C003o`00000406H0VOl0003o0000o`0000806@3V00?o00000000o`000?l0EP000?l5ooooo`400000
0Oooool0000300000?oooooooooo00;ooooo[@3o00001@000000iP0Io`000?l00000/`1<00?o0000
00@0IP2Io`000?l0003o00000P0I0>H00ol00000003o0000o`1F0000o`Gooooo0@000001ooooo`00
00<00000ooooooooool00_oooon]0?l000050000003V01Wo0000o`00002c04`00ol00000101V09Wo
0000o`000?l0000301T0iP03o`0000000?l0003o05D0003o1Oooool10000007ooooo00000`00003o
ooooooooo`02ooooojh0o`0000<000000>H06Ol000001?l000001@1V09Wo0000o`00000c0<co0000
00806@3V00?o00000000o`000?l0E@000?l5ooooo`4000000Oooool0000300000?oooooooooo00;o
oooo[P3o00000`000000iP0Io`000004o`00000306H0VOl00000C02c00;o00000`0I0>H00ol00000
003o0000o`1D0000o`Gooooo0@000001ooooo`0000<00000ooooooooool00_oooon^0?l000030000
003V01Wo000000Co000000H0IP2Io`00001<0;?o000003<0c?l0000201T0iP03o`0000000?l0003o
05@0003o1Oooool10000007ooooo00000`00003oooooooooo`02ooooojh0o`0000D000000>H06Ol0
003o00000;<0C003o`00000306H0VOl0003o00000080<`3<00Co000001T0iP0I0>Ko0000E@000?l5
ooooo`4000000Oooool0000300000?oooooooooo00;ooooo[P3o00001@000000iP0Io`000?l00000
/`1<00?o000000<0IP2Io`000?l000000P0c0<`01?l000006@3V01T0i_l0001E0000o`Gooooo0@00
0001ooooo`0000<00000ooooooooool00_oooon^0?l000050000003V01Wo0000o`00002c04`00ol0
0000101V09Wo000004`0/ol0000203<0c004o`00000I0>H06@3Vo`0005@0003o1Oooool10000007o
oooo00000`00003oooooooooo`02ooooojh0o`0000D000000>H06Ol0003o00000;<0C003o`000004
06H0VOl00000C02co`000080<`3<00Co000001T0iP0I0>Ko0000E0000?l5ooooo`4000000Oooool0
000300000?oooooooooo00;ooooo[P3o00001`000000iP0Io`000?l00000/`1<o`00002I06H00_l0
00001P1V09Wo000004`0/ol00000<`3<o`0000806@3V00?o00000000o`000?l0DP000?l5ooooo`40
00000Oooool0000300000?oooooooooo00;ooooo[P3o00001P000000iP0Io`00003<03?o00000;<0
C0?o000000@0IP2Io`00001<0;?o00000P0c0<`01?l000006@3V01T0i_l0001C0000o`Gooooo0@00
0001ooooo`0000<00000ooooooooool00_oooon^0?l000030000003V01T0iP0I00;o000000/0/`1<
o`000?l00000O`1oo`00001V09Wo000004`0/ol00000<`3<o`00000201T0iP03o`0000000?l0003o
0540003o1Oooool10000007ooooo00000`00003oooooooooo`02ooooojh0o`0000<000000>H06@3V
01T00_l000000`2c04co000009T0IP02o`00000606H0VOl00000C02co`00000c0<co00000P0I0>H0
0ol00000003o0000o`1A0000o`Gooooo0@000001ooooo`0000<00000ooooooooool00_oooon_0?l0
00060000003V01Wo00000<`0<ol00000/`1<0_l00000201o07oo000006H0VOl00000C02co`00000c
0<co00000P0I0>H00ol00000003o0000o`1@0000o`Gooooo0@000001ooooo`0000<00000oooooooo
ool00_oooon_0?l000060000003V01Wo00000<`0<ol00000/`1<0_l00000201o07oo000006H0VOl0
0000C02co`00000c0<co00000P0I0>H00ol00000003o0000o`1@0000o`Gooooo0@000001ooooo`00
00<00000ooooooooool00_oooon_0?l0000:0000003V01Wo00000<`0<ol00000/`1<o`00002I06Ko
000007l0O`;o000000@0C02co`00000c0<co00000P0I0>H00ol00000003o0000o`1@0000o`Gooooo
0@000001ooooo`0000<00000ooooooooool00_oooon_0?l000030000003V01T0iP0I00;o000000T0
/`1<o`00002I06Ko000007l0Ool00000IP2Io`00001<0;<00_l0000201T0iP03o`0000000?l0003o
0500003o1Oooool10000007ooooo00000`00003oooooooooo`02ooooojl0o`0000L000000>H06@3V
01Wo00000<`0<ol00000/`1<00;o000000P0O`1oo`00001V09Wo000004`0/ol00000<`3<o`000080
6@3V00?o00000000o`000?l0C`000?l5ooooo`4000000Oooool0000300000?oooooooooo00;ooooo
[`3o00003`000000iP0I0>H06Ol00000c00co`00002c04co000009T0I_l00000O`1oo`00001V09Wo
000004`0/`02o`0000806@3V00?o00000000o`000?l0C`000?l5ooooo`4000000Oooool000030000
0?oooooooooo00;ooooo[`3o00003`000000iP0I0>H06Ol00000c00co`00002c04co000009T0I_l0
0000O`1oo`00001V09Wo000004`0/`02o`0000806@3V00?o00000000o`000?l0C`000?l5ooooo`40
00000Oooool0000300000?oooooooooo00;ooooo[`3o000010000000iP0I0>H06Ol000020<`0<`09
o`00002c04co0000o`00001o07oo000006H0VOl00000C02c00;o00000P0I0>H00ol00000003o0000
o`1?0000o`Gooooo0@000001ooooo`0000<00000ooooooooool00_oooon_0?l0000:0000003V01T0
iP0I0>H06Ol00000c00co`00002c04co000009T0IP;o000000<0IP2Io`00001<0;<00_l0000201T0
iP03o`0000000?l0003o04l0003o1Oooool10000007ooooo00000`00003oooooooooo`02oooook00
o`0000H000000>H06@3V01Wo00000<`0<ol000020;<0C0;o000000<0O`1oo`00001V09T00_l00000
100c0<co000001T0i_l0001A0000o`Gooooo0@000001ooooo`0000<00000ooooooooool00_oooon`
0?l000040000003V01T0iP0Io`000080c00c00Oo00000;<0C?l0003o000007l0Ool00000IP2I00;o
000000@0<`3<o`00000I0>Ko0000D@000?l5ooooo`4000000Oooool0000300000?oooooooooo00;o
oooo/03o000010000000iP0I0>H06Ol000020<`0<`07o`00002c04co0000o`00001o07oo000006H0
V@02o`00000403<0c?l000006@3Vo`000540003o1Oooool10000007ooooo00000`00003ooooooooo
o`02oooook00o`0000X000000>H06@3V01T0iP0Io`00003<03?o00000;<0C?l00000V@1V0_l00000
0`1V09Wo000004`0/`02o`00000301T0i_l00000003o0500003o1Oooool10000007ooooo00000`00
003oooooooooo`02oooook00o`0000D000000>H06@3V01T0iP0Io`0000020<`0<`;o000000H0V@1V
o`000?l00000IP2Io`00001<0;<2o`00000301T0i_l00000003o0500003o1Oooool10000007ooooo
00000`00003oooooooooo`02oooook00o`0000D000000>H06@3V01T0iP0Io`0000020<`0<`03o`00
002c04co000000;o000000<0IP2Io`00001<0;<00_l000000`0I0>Ko00000000o`1@0000o`Gooooo
0@000001ooooo`0000<00000ooooooooool00_oooona0?l000040000003V01T0iP0Io`000080c00c
00Oo00000;<0C?l0003o000007l0Ool00000IP2I00;o000000<0<`3<o`000?l00000D@000?l5oooo
o`4000000Oooool0000300000?oooooooooo00;ooooo/@3o00001@000000iP0I0>H06@3V01Wo0000
0080c00c0_l00000102I06Ko0000o`00001V09T2o`00000303<0c?l0003o00000540003o1Oooool1
0000007ooooo00000`00003oooooooooo`02oooook40o`0000D000000>H06@3V01T0iP0Io`000002
0<`0<`;o000000@0V@1Vo`000?l00000IP2I0_l000000`0c0<co0000o`00001A0000o`Gooooo0@00
0001ooooo`0000<00000ooooooooool00_oooona0?l000050000003V01T0iP0I0>H06Ol000000P3<
03<2o`00000409T0I_l0003o000006H0V@;o000000<0<`3<o`000?l00000D@000?l5ooooo`400000
0Oooool0000300000?oooooooooo00;ooooo/@3o00001@000000iP0I0>H06@3V01Wo00000080c00c
0_l00000102I06Ko0000o`00001V09T2o`00000303<0c?l0003o00000540003o1Oooool10000007o
oooo00000`00003oooooooooo`02oooook80o`0000@000000>H06@3V01Wo00000P3<03<2o`000004
09T0I_l0003o000006H0V@;o000000<0<`3<o`000?l00000D@000?l5ooooo`4000000Oooool00003
00000?oooooooooo00;ooooo/P3o00001P000000iP0I0>H06@3V01Wo00000<`0<`;o000000@0V@1V
o`000?l00000IP2I0_l000000`0c0<co0000o`00001A0000o`Gooooo0@000001ooooo`0000<00000
ooooooooool00_oooonb0?l000060000003V01T0iP0I0>H06Ol00000c00c0_l00000102I06Ko0000
o`00001V09T2o`00000303<0c?l0003o00000540003o1Oooool10000007ooooo00000`00003ooooo
ooooo`02oooook<0o`0000@000000>H06@3V01Wo00000P3<03<2o`00000509T0I_l0003o0000o`00
001<0;<00ol0001A0000o`Gooooo0@000001ooooo`0000<00000ooooooooool00_oooonc0?l00004
0000003V01T0iP0Io`000080c00c0_l000001@2I06Ko0000o`000?l00000C02c00?o0000D@000?l5
ooooo`4000000Oooool0000300000?oooooooooo00;ooooo/`3o000010000000iP0I0>H06Ol00002
0<`0<`;o000000D0V@1Vo`000?l0003o000004`0/`03o`000540003o1Oooool10000007ooooo0000
0`00003oooooooooo`02oooook<0o`0000H000000>H06@3V01T0iP0Io`00003<03<2o`00000509T0
I_l0003o0000o`00001<0;<00ol0001A0000o`Gooooo0@000001ooooo`0000<00000ooooooooool0
0_oooond0?l000050000003V01T0iP0Io`00003<03<00_l000001@2I06Ko0000o`000?l00000C02c
00?o0000D@000?l5ooooo`4000000Oooool0000300000?oooooooooo00;ooooo]03o00001@000000
iP0I0>H06Ol00000c00c00;o000000D0V@1Vo`000?l0003o000004`0/`03o`000540003o1Oooool1
0000007ooooo00000`00003oooooooooo`02oooook@0o`0000D000000>H06@3V01Wo00000<`0<`02
o`00000509T0I_l0003o0000o`00001<0;<00ol0001A0000o`Gooooo0@000001ooooo`0000<00000
ooooooooool00_oooond0?l000050000003V01T0iP0Io`00003<03<00_l000001@2I06Ko0000o`00
0?l00000C02c00?o0000D@000?l5ooooo`4000000Oooool0000300000?oooooooooo00;ooooo]03o
00001@000000iP0I0>H06Ol00000c00c00;o000000D0V@1Vo`000?l0003o000004`0/`03o`000540
003o1Oooool10000007ooooo00000`00003oooooooooo`02oooook@0o`0000D000000>H06@3V01Wo
00000<`0<`02o`00000509T0I_l0003o0000o`00001<0;<00ol0001A0000o`Gooooo0@000001oooo
o`0000<00000ooooooooool00_oooond0?l000050000003V01T0iP0Io`00003<03<00_l000001@2I
06Ko0000o`000?l00000C02c00?o0000D@000?l5ooooo`4000000Oooool0000300000?oooooooooo
00;ooooo]03o00001@000000iP0I0>H06Ol00000c00c00;o000000D0V@1Vo`000?l0003o000004`0
/`03o`000540003o1Oooool10000007ooooo00000`00003oooooooooo`02oooook@0o`0000@00000
0>H06@3V01T0iP0I0_l000000`2c04co0000o`000002o`00000504`0/ol0003o000001T0i_l00000
D0000?l5ooooo`4000000Oooool0000300000?oooooooooo00;ooooo]03o000010000000iP0I0>H0
6@3V01T2o`0000030;<0C?l0003o000000;o000000D0C02co`000?l000006@3Vo`00001@0000o`Go
oooo0@000001ooooo`0000<00000ooooooooool00_oooond0?l000040000003V01T0iP0I0>H06@;o
000000<0/`1<o`000?l000000_l000001@1<0;?o0000o`00000I0>Ko00000500003o1Oooool10000
007ooooo00000`00003oooooooooo`02oooook@0o`0000@000000>H06@3V01T0iP0I0_l000000`2c
04co0000o`000002o`00000504`0/ol0003o000001T0i_l00000D0000?l5ooooo`4000000Oooool0
000300000?oooooooooo00;ooooo]03o000010000000iP0I0>H06@3V01T2o`0000030;<0C?l0003o
000000;o000000D0C02co`000?l000006@3Vo`00001@0000o`Gooooo0@000001ooooo`0000<00000
ooooooooool00_oooond0?l000040000003V01T0iP0I0>H06@;o000000<0/`1<o`000?l000000_l0
00001@1<0;?o0000o`00000I0>Ko00000500003o1Oooool10000007ooooo00000`00003ooooooooo
o`02oooook@0o`0000@000000>H06@3V01T0iP0I0_l000000`2c04co0000o`000002o`00000504`0
/ol0003o000001T0i_l00000D0000?l5ooooo`4000000Oooool0000300000?oooooooooo00;ooooo
]03o000010000000iP0I0>H06@3V01T2o`0000030;<0C?l0003o000000;o000000D0C02co`000?l0
00006@3Vo`00001@0000o`Gooooo0@000001ooooo`0000<00000ooooooooool00_oooond0?l00004
0000003V01T0iP0I0>H06@;o000000<0/`1<o`000?l000000_l000001@1<0;?o0000o`00000I0>Ko
00000500003o1Oooool10000007ooooo00000`00003oooooooooo`02oooook@0o`0000@000000>H0
6@3V01T0iP0I0_l000000`2c04co0000o`000002o`00000504`0/ol0003o000001T0i_l00000D000
0?l5ooooo`4000000Oooool0000300000?oooooooooo00;ooooo]03o000010000000iP0I0>H06@3V
01T2o`0000030;<0C?l0003o000000;o000000D0C02co`000?l000006@3Vo`00001@0000o`Gooooo
0@000001ooooo`0000<00000ooooooooool00_oooonc0?l000060000003V01T0iP0I0>H06Ol00000
c00c0_l000001@2I06Ko0000o`000?l00000C02c00;o000000<06@3Vo`0000000?l0C`000?l5oooo
o`4000000Oooool0000300000?oooooooooo00;ooooo/`3o00001P000000iP0I0>H06@3V01Wo0000
0<`0<`;o000000D0V@1Vo`000?l0003o000004`0/`02o`00000301T0i_l00000003o04l0003o1Ooo
ool10000007ooooo00000`00003oooooooooo`02oooook<0o`0000H000000>H06@3V01T0iP0Io`00
003<03<2o`00000509T0I_l0003o0000o`00001<0;<00_l000000`0I0>Ko00000000o`1?0000o`Go
oooo0@000001ooooo`0000<00000ooooooooool00_oooonc0?l000060000003V01T0iP0I0>H06Ol0
0000c00c0_l000001@2I06Ko0000o`000?l00000C02c00;o000000<06@3Vo`0000000?l0C`000?l5
ooooo`4000000Oooool0000300000?oooooooooo00;ooooo/`3o00001P000000iP0I0>H06@3V01Wo
00000<`0<`;o000000D0V@1Vo`000?l0003o000004`0/`02o`00000301T0i_l00000003o04l0003o
1Oooool10000007ooooo00000`00003oooooooooo`02oooook<0o`0000H000000>H06@3V01T0iP0I
o`00003<03<2o`00000509T0I_l0003o0000o`00001<0;<00_l000000`0I0>Ko00000000o`1?0000
o`Gooooo0@000001ooooo`0000<00000ooooooooool00_oooonc0?l000060000003V01T0iP0I0>H0
6Ol00000c00c0_l000001@2I06Ko0000o`000?l00000C02c00;o000000<06@3Vo`0000000?l0C`00
0?l5ooooo`4000000Oooool0000300000?oooooooooo00;ooooo/`3o00001P000000iP0I0>H06@3V
01Wo00000<`0<`;o000000D0V@1Vo`000?l0003o000004`0/`02o`00000301T0i_l00000003o04l0
003o1Oooool10000007ooooo00000`00003oooooooooo`02oooook<0o`0000@000000>H06@3V01Wo
00000P3<03<2o`00000509T0I_l0003o0000o`00001<0;<00_l000000`0I0>Ko00000000o`1?0000
o`Gooooo0@000001ooooo`0000<00000ooooooooool00_oooonb0?l000050000003V01T0iP0I0>H0
6Ol000000P3<03<2o`00000509T0I_l0003o0000o`00001<0;<00_l000000`0I0>Ko00000000o`1?
0000o`Gooooo0@000001ooooo`0000<00000ooooooooool00_oooonb0?l0000:0000003V01T0iP0I
0>H06Ol00000c00co`00002c04co000009T0IP?o000000D0C02co`000?l000006@3Vo`00001@0000
o`Gooooo0@000001ooooo`0000<00000ooooooooool00_oooonb0?l0000:0000003V01T0iP0I0>H0
6Ol00000c00co`00002c04co000009T0IP?o000000D0C02co`000?l000006@3Vo`00001@0000o`Go
oooo0@000001ooooo`0000<00000ooooooooool00_oooonb0?l000040000003V01T0iP0Io`000080
c00c0_l00000102I06Ko0000o`00001V09T2o`00000403<0c?l000006@3Vo`000500003o1Oooool1
0000007ooooo00000`00003oooooooooo`02oooook80o`0000@000000>H06@3V01Wo00000P3<03<2
o`00000409T0I_l0003o000006H0V@;o000000@0<`3<o`00000I0>Ko0000D0000?l5ooooo`400000
0Oooool0000300000?oooooooooo00;ooooo/P3o000010000000iP0I0>H06Ol000020<`0<`;o0000
00@0V@1Vo`000?l00000IP2I0_l00000100c0<co000001T0i_l0001@0000o`Gooooo0@000001oooo
o`0000<00000ooooooooool00_oooona0?l000050000003V01T0iP0I0>H06Ol000000P3<03<2o`00
000409T0I_l0003o000006H0V@;o000000@0<`3<o`00000I0>Ko0000D0000?l5ooooo`4000000Ooo
ool0000300000?oooooooooo00;ooooo/@3o000010000000iP0I0>H06Ol000020<`0<`04o`00002c
04co000009T0IP;o000000L0IP2Io`000?l00000<`3<o`00000I0>Ko00000500003o1Oooool10000
007ooooo00000`00003oooooooooo`02oooook40o`0000@000000>H06@3V01Wo00000P3<03<01?l0
0000/`1<o`00002I06H2o`00000706H0VOl0003o000003<0c?l000006@3Vo`00001@0000o`Gooooo
0@000001ooooo`0000<00000ooooooooool00_oooona0?l000040000003V01T0iP0Io`000080c00c
00Co00000;<0C?l00000V@1V0_l000001`1V09Wo0000o`00000c0<co000001T0i_l00000D0000?l5
ooooo`4000000Oooool0000300000?oooooooooo00;ooooo/@3o00001P000000iP0I0>H06Ol00000
c00co`000080/`1<00Go000009T0I_l0003o000006H0V@02o`00000403<0c?l000006@3Vo`000500
003o1Oooool10000007ooooo00000`00003oooooooooo`02oooook00o`0000@000000>H06@3V01Wo
00000P3<03<01?l00000/`1<o`00002I06H2o`00000806H0VOl00000C02co`00000c0<co000001T0
i_l0001@0000o`Gooooo0@000001ooooo`0000<00000ooooooooool00_oooon`0?l000040000003V
01T0iP0Io`000080c00c00Co00000;<0C?l00000V@1V0_l000001@1V09Wo0000o`00000c0<co0000
00806@3V00?o00000000o`000?l0CP000?l5ooooo`4000000Oooool0000300000?oooooooooo00;o
oooo/03o00001P000000iP0I0>H06Ol00000c00co`000080/`1<00Go000009T0I_l0003o000006H0
V@02o`00000503<0c?l000006@3V01T0i_l00000D0000?l5ooooo`4000000Oooool0000300000?oo
oooooooo00;ooooo[`3o000010000000iP0I0>H06Ol000020<`0<`03o`00002c04`0/`1<00?o0000
00P0IP2Io`00001<0;?o000003<0c?l000006@3Vo`000540003o1Oooool10000007ooooo00000`00
003oooooooooo`02ooooojl0o`0000@000000>H06@3V01Wo00000P3<03<01?l00000/`1<o`00002I
06H2o`00000806H0VOl00000C02co`00000c0<co000001T0i_l0001A0000o`Gooooo0@000001oooo
o`0000<00000ooooooooool00_oooon_0?l000060000003V01T0iP0Io`00003<03?o00000P2c04`0
3?l00000V@1Vo`000?l00000IP2Io`00001<0;?o000003<0c?l000006@3Vo`000540003o1Oooool1
0000007ooooo00000`00003oooooooooo`02ooooojl0o`0000d000000>H06@3V01Wo00000<`0<ol0
0000/`1<o`00002I06Ko000007l0Ool00000IP2I00;o000000D0<`3<o`00000I0>H06@3Vo`00001A
0000o`Gooooo0@000001ooooo`0000<00000ooooooooool00_oooon^0?l000040000003V01T0iP0I
o`000080c00c00Co00000;<0C?l00000V@1V0_l000001P1V09Wo000004`0/ol00000<`3<o`000080
6@3V00?o00000000o`000?l0C`000?l5ooooo`4000000Oooool0000300000?oooooooooo00;ooooo
[P3o00004P000000iP0I0>H06Ol00000c00co`00002c04co000009T0I_l00000O`1oo`00001V09Wo
000004`0/ol00000<`3<o`0000806@3V00?o00000000o`000?l0C`000?l5ooooo`4000000Oooool0
000300000?oooooooooo00;ooooo[P3o00004P000000iP0I0>H06Ol00000c00co`00002c04co0000
09T0I_l00000O`1oo`00001V09Wo000004`0/ol00000<`3<o`0000806@3V00?o00000000o`000?l0
C`000?l5ooooo`4000000Oooool0000300000?oooooooooo00;ooooo[P3o00000`000000iP0I0>H0
6@02o`00000<0;<0C?l00000V@1Vo`00001o07oo000006H0VOl00000C02co`00000c0<co00000`0I
0>H00ol00000003o0000o`1?0000o`Gooooo0@000001ooooo`0000<00000ooooooooool00_oooon]
0?l0000B0000003V01T0iP0Io`00003<03?o00000;<0C?l00000V@1Vo`00001o07oo000006H0VOl0
0000C02co`00000c0<co00000P0I0>H00ol00000003o0000o`1@0000o`Gooooo0@000001ooooo`00
00<00000ooooooooool00_oooon]0?l0000;0000003V01T0iP0Io`00003<03?o00000;<0C?l00000
V@1Vo`00001o07l00_l000001@1<0;?o000003<0c00c0<co000000806@3V00?o00000000o`000?l0
D0000?l5ooooo`4000000Oooool0000300000?oooooooooo00;ooooo[@3o00000`000000iP0I0>H0
6@02o`00000<0;<0C?l00000V@1Vo`00001o07oo000006H0VOl00000C02co`00000c0<co00000`0I
0>H00ol00000003o0000o`1@0000o`Gooooo0@000001ooooo`0000<00000ooooooooool00_oooon]
0?l000030000003V01T0iP0I00;o000000D0/`1<o`00002I06Ko000007l0O`02o`00000504`0/ol0
0000<`3<03<0c?l000000`0I0>H00ol00000003o0000o`1@0000o`Gooooo0@000001ooooo`0000<0
0000ooooooooool00_oooon]0?l000080000003V01Wo00000<`0<ol00000/`1<o`00002I06H2o`00
000606H0VOl00000C02co`00000c0<co00000`0I0>H00ol00000003o0000o`1A0000o`Gooooo0@00
0001ooooo`0000<00000ooooooooool00_oooon/0?l000030000003V01T0iP0I00;o000000D0/`1<
o`00002I06Ko000007l0O`02o`000080C02c00?o000003<0c?l000000`0I0>H00ol00000003o0000
o`1A0000o`Gooooo0@000001ooooo`0000<00000ooooooooool00_oooon/0?l000030000003V01T0
iP0I00;o000000D0/`1<o`00002I06Ko000007l0O`02o`00000404`0/ol00000<`3<o`0000@06@3V
00?o00000000o`000?l0D@000?l5ooooo`4000000Oooool0000300000?oooooooooo00;ooooo[03o
00000`000000iP0I0>H06@02o`0000030;<0C?l00000V@1V00;o000000H0IP2Io`00001<0;?o0000
03<0c?l0000401T0iP03o`0000000?l0003o0540003o1Oooool10000007ooooo00000`00003ooooo
ooooo`02oooooj/0o`0000<000000>H06@3V01T00_l000001@2c04co000009T0I_l00000O`1o00;o
000000D0C02co`00000c0<`0<`3<o`00000301T0iP03o`0000000?l0003o0580003o1Oooool10000
007ooooo00000`00003oooooooooo`02oooooj/0o`0000<000000>H06@3V01T00_l000000`2c04co
000009T0IP02o`00000606H0VOl00000C02co`00000c0<co0000100I0>H00ol00000003o0000o`1B
0000o`Gooooo0@000001ooooo`0000<00000ooooooooool00_oooon[0?l000080000003V01Wo0000
0<`0<ol00000/`1<o`00002I06H2o`00000606H0VOl00000C02co`00000c0<co0000100I0>H00ol0
0000003o0000o`1B0000o`Gooooo0@000001ooooo`0000<00000ooooooooool00_oooonZ0?l00008
0000003V01Wo00000<`0<ol00000/`1<o`00002I06H2o`00000606H0VOl00000C02co`00000c0<co
0000100I0>H00ol00000003o0000o`1C0000o`Gooooo0@000001ooooo`0000<00000ooooooooool0
0_oooonY0?l000030000003V01T0iP0I00;o000000`0/`1<o`00002I06Ko000007l0Ool00000IP2I
o`00001<0;?o000003<0c?l0000301T0iP03o`0000000?l0003o05@0003o1Oooool10000007ooooo
00000`00003oooooooooo`02ooooojP0o`0000T000000>H06@3V01Wo00000<`0<ol00000/`1<o`00
002I06H00_l000001P1V09Wo000004`0/ol00000<`3<o`0000@06@3V00?o00000000o`000?l0E000
0?l5ooooo`4000000Oooool0000300000?oooooooooo00;oooooY`3o00004P000000iP0I0>H06Ol0
0000c00co`00002c04co000009T0I_l00000O`1oo`00001V09Wo000004`0/ol00000<`3<o`0000<0
6@3V00?o00000000o`000?l0E@000?l5ooooo`4000000Oooool0000300000?oooooooooo00;ooooo
YP3o000010000000iP0I0>H06Ol000020<`0<`0<o`00002c04co0000o`00001o07oo000006H0VOl0
0000C02co`00000c0<co00000`0I0>H00ol00000003o0000o`1F0000o`Gooooo0@000001ooooo`00
00<00000ooooooooool00_oooonU0?l000040000003V01T0iP0Io`000080c00c00[o00000;<0C?l0
003o000007l0Ool00000IP2Io`00001<0;?o00000P0c0<`01Ol000006@3V01T0iP0I0>Ko000005P0
003o1Oooool10000007ooooo00000`00003oooooooooo`02oooooj@0o`0000@000000>H06@3V01Wo
00000P3<03<03Ol00000/`1<o`00002I06Ko000007l0Ool00000IP2Io`00001<0;?o000003<0c?l0
00000`0I0>H00ol00000003o0000o`1G0000o`Gooooo0@000001ooooo`0000<00000ooooooooool0
0_oooonS0?l000040000003V01T0iP0Io`000080c00c00_o00000;<0C?l00000V@1Vo`00001o07oo
000006H0VOl00000C02co`00000203<0c005o`00000I0>H06@3V01T0i_l00000F@000?l5ooooo`40
00000Oooool0000300000?oooooooooo00;oooooXP3o000010000000iP0I0>H06Ol000020<`0<`05
o`00002c04co000009T0I_l000000P1o07l01Ol00000IP2Io`00001<0;?o00000080<`3<00Co0000
01T0iP0I0>Ko0000FP000?l5ooooo`4000000Oooool0000300000?oooooooooo00;oooooX03o0002
00000080iP0I00?o00000<`0<ol000000ol000002@2I06Ko0000o`00001o07oo000006H0VOl00000
C02co`00000203<0c004o`00000I0>H06@3Vo`0005/0003o1Oooool10000007ooooo00000`00003o
ooooooooo`02oooooih0o`000P0000030>H06@05o`00003<03?o00000;<0C?l000000P2I06H02?l0
0000O`1o07l0Ool00000IP2Io`00001<0;?o00000P0c0<`01Ol000006@3V01T0iP0I0>Ko000005/0
003o1Oooool10000007ooooo00000`00003oooooooooo`02oooooid0o`0000<000000>H06@3V01T0
0P3V01T01Ol00000c00co`00002c04co00000080V@1V00So000007l0Ool0003o000006H0VOl00000
C02co`000080<`3<00Go000001T0iP0I0>H06@3Vo`00001L0000o`Gooooo0@000001ooooo`0000<0
0000ooooooooool00_oooonK0?l0008000000`3V01T2o`0000040<`0<ol00000/`1<o`000080V@1V
00?o000007l0Ool000000P1V09T00ol00000C02co`00000203<0c005o`00000I0>H06@3V01T0i_l0
0000G@000?l5ooooo`4000000Oooool0000300000?oooooooooo00;oooooV@3o0002000000@0iP0I
00Oo00000<`0<`3<03?o00000;<0C?l00000V@1V00;o000000<0O`1oo`00001V09T00_l000001@1<
0;?o000003<0c00c0<co000000<06@3V00?o00000000o`000?l0G0000?l5ooooo`4000000Oooool0
000300000?oooooooooo00;oooooV03o00000`000000iP0I0>H06@020>H06@;o00000P3<03<01Ol0
0000/`1<o`00002I06Ko00000080O`1o00?o000006H0VOl000000P1<0;<01?l00000<`3<03<0c?l0
000301T0iP03o`0000000?l0003o05d0003o1Oooool10000007ooooo00000`00003oooooooooo`02
oooooiH0o`000P0000040>H06@0:o`00003<03<0c00c0<`0<ol00000/`1<o`00002I06Ko000007l0
O`;o000000D0IP2Io`00001<0;<0C02co`00000203<0c005o`00000I0>H06@3V01T0i_l00000H000
0?l5ooooo`4000000Oooool0000300000?oooooooooo00;oooooU03o0002000000@0iP0I0_l00003
0<`0<`07o`00002c04co000009T0I_l00000O`1oo`00000206H0V@04o`00001<0;<0C02co`000080
<`3<00?o000001T0iP0I0>H00P0I0>H00ol00000003o0000o`1N0000o`Gooooo0@000001ooooo`00
00<00000ooooooooool00_oooonC0?l000030000003V01T0iP0I00<0iP0I00?o00000<`0<`3<03<0
0P3<03<00ol00000/`1<0;<0C002o`00000507l0Ool00000IP2I06H0VOl000000P1<0;<01?l00000
<`3<03<0c?l0000401T0iP03o`0000000?l0003o05l0003o1Oooool10000007ooooo00000`00003o
ooooooooo`02oooooi80o`0000<000000>H06@3V01T00P3V01T2o`0000@0c00c00?o00000;<0C02c
04`00_l000001@1o07oo000006H0V@1V09Wo00000080C02c00Co000003<0c00c0<co0000100I0>H0
0ol00000003o0000o`1P0000o`Gooooo0@000001ooooo`0000<00000ooooooooool00_oooonA0?l0
00030000003V01T0iP0I0080iP0I00?o00000<`0<`3<03<00`3<03<01Ol00000/`1<0;<0C?l00000
V@1V00;o00000P1V09T01?l00000C02c04`0/ol0000203<0c003o`00000I0>H06@3V00806@3V00?o
00000000o`000?l0H@000?l5ooooo`4000000Oooool0000300000?oooooooooo00;oooooT03o0000
0`000000iP0I0>H06@020>H06@03o`00003<03<0c00c00<0c00c00Go00000;<0C02c04co000009T0
IP02o`000080IP2I00Co000004`0/`1<0;?o00000P0c0<`00ol000006@3V01T0iP0201T0iP03o`00
00000?l0003o0680003o1Oooool10000007ooooo00000`00003oooooooooo`02ooooohD0o`002`00
00020>H06@Co00000P3<03<3o`0000030;<0C?l0003o000000Ko000000@0C02co`000?l00000<`3<
0_l0000301T0iP;o0000I@000?l5ooooo`4000000Oooool0000300000?oooooooooo00;oooooO@3o
0008000000P0iP0I1Ol000000`3<03?o0000o`000003o`0000030;<0C?l0003o000000Oo00000P1<
0;<01?l00000<`3<03<0c?l0000301T0iP;o0000I`000?l5ooooo`4000000Oooool0000300000?oo
oooooooo00;oooooN@3o0004000000X0iP0I1_l000020<`0<`Co00000`2c04`7o`00000306H0VOl0
003o000000<0C02c00Co000003<0c00c0<co00000`0I0>H00ol00000003o0000o`1W0000o`Gooooo
0@000001ooooo`0000<00000ooooooooool00_oooome0?l000@000002@3V01T5o`0000D0c00c0ol0
00030;<0C0Wo000000<0IP2Io`000?l00000101<0;<01?l00000<`3<o`000?l0000301T0iP03o`00
00000?l0003o06P0003o1Oooool10000007ooooo00000`00003oooooooooo`02ooooo`<00000KP3o
0004000000P0iP0I1Ol000050<`0<`Go000000<0/`1<o`000?l000000ol000000`2I06Ko0000o`00
0004o`00000306H0VOl0003o000000@0C02c0_l000000`0c0<co000001T0iP0201T0iP;o0000J`00
0?l5ooooo`4000000Oooool0000300000?oooooooooo00;ooooo0`3V01T4000006H0o`0010000008
0>H06@Co00001@3<03<5o`0000030;<0C?l0003o000000?o00000P2I06H7o`000080IP2I0_l00003
04`0/`?o00000P0c0<`01Ol000006@3V01T0iP0I0>Ko000006d0003o1Oooool10000007ooooo0000
0`00003oooooooooo`02ooooo`L0iP0I1000001O0?l000<00000203V01T4o`0000D0c00c1?l00002
0;<0C0Co0000102I06H7o`0000<0IP2I0_l0000204`0/`?o00000`0c0<`2o`0000806@3V0_l0001^
0000o`Gooooo0@000001ooooo`0000<00000ooooooooool00_ooool3o`0000P0iP0I1000001G0?l0
00@00000203V01T3o`0000H0c00c0ol000030;<0C0?o0000102I06H7o`0000@0IP2I0ol00000101<
0;?o0000o`000?l0000303<0c0?o00000`0I0>H00ol00000003o0000o`1^0000o`Gooooo0@000001
ooooo`0000<00000ooooooooool00_ooool30<`0<`?o00002@3V01T4000004l0o`00100000090>H0
6@?o00001P3<03<3o`0000<0/`1<0ol0000309T0IPCo000000@0O`1oo`000?l0003o00000`1V09T8
o`0000<0<`3<0ol0000501T0iP03o`0000000?l0003o06l0003o1Oooool10000007ooooo00000`00
003oooooooooo`02ooooo`H0c00c0ol0000:0>H06@<00000B03o0004000000X0iP0I0ol000060<`0
<`?o00000`2c04`3o`0000<0V@1V0ol0000207l0O`?o00000`1V09T7o`0000@0<`3<0ol0000501T0
iP?o0000LP000?l5ooooo`4000000Oooool0000300000?oooooooooo00;ooooo1?l000050<`0<`?o
00002P3V01T8000003T0o`001`00000;0>H06@?o00001P3<03<3o`0000<0/`1<0ol0000309T0IP?o
00000P1o07l3o`000080IP2I1ol0000303<0c0Go0000100I0>H4o`0007D0003o1Oooool10000007o
oooo00000`00003oooooooooo`02ooooo`@0/`1<1_l000020<`0<`Oo00002`3V01Ti000000X0iP0I
2?l000030<`0<`Ko00000`2c04`3o`000080V@1V1?l0000207l0O`?o000000<0IP2Io`000?l00000
0_l00000101<0;?o0000o`000?l0000203<0c0Co00001@0I0>H4o`0007T0003o1Oooool10000007o
oooo00000`00003oooooooooo`02ooooo`Co00001P2c04aGo`0000030<`0<ol0003o000000So0000
102c04`:o`0000<0O`1o0ol0000206H0V@;o00000`1<0;<2o`0000<0<`3<0_l0000601T0iP?o0000
O@000?l5ooooo`4000000Oooool0000300000?oooooooooo00;ooooo2_l000090;<0C1Oo00008@3<
03<Go`0000T0/`1<2_l0000407l0O`Co00000`1V09T2o`000080C02c0ol0000403<0c003o`00000I
0>H06@3V00@06@3V0_l000200000o`Gooooo0@000001ooooo`0000<00000ooooooooool00_ooool4
07l0Oa[o0000302c04`Qo`0000`0/`1<6Ol0000507l0O`Co00000`1V09T4o`000080C02c0_l00005
03<0c0;o00001@0I0>H2o`000880003o1Oooool10000007ooooo00000`00003oooooooooo`02oooo
o`Oo00000`1o07mQo`0000<0O`1o1ol000000`1V09Wo0000o`000004o`0000@0C02c0_l0000403<0
c0?o00001P0I0>H00ol00000003o0000o`220000o`Gooooo0@000001ooooo`0000<00000oooooooo
ool00_oooolCo`0000/0O`1o>Ol0000;07l0OaCo00001P1<0;<4o`0000<0<`3<0ol0000701T0iP;o
0000Q@000?l5ooooo`4000000Oooool0000300000?oooooooooo00;ooooo1`1<0;=Wo`0000P0C02c
1_l0000403<0c0?o0000200I0>H2o`0008L0003o1Oooool10000007ooooo00000`00003ooooooooo
o`02ooooo`Oo0000301<0;=?o`0000`0C02c2?l0000603<0c0Co0000200I0>H3o`0008T0003o1Ooo
ool10000007ooooo00000`00003oooooooooo`02ooooofko0000200c0<`6o`0000P06@3V1?l0002<
0000o`Gooooo0@000001ooooo`0000<00000ooooooooool00_ooool701T0iVoo00002`0I0>H3o`00
0900003o1Oooool10000007ooooo00000`00003oooooooooo`02ooooob[o0000>00I0>HOo`0009<0
003o1Oooool10000007ooooo00000`00003oooooooooo`02ooooobX0003o>?l0002b0000o`Gooooo
0@000001ooooo`0000<00000ooooooooool00_oooooo0000oaD0003o1Oooool10000007ooooo0000
0`00003oooooooooo`02ooooool0003o5@000?l5ooooo`4000000Oooool0000300000?oooooooooo
00;oooooo`000?lE0000o`Gooooo0@000001ooooo`0000<00000ooooooooool00_oooooo0000oaD0
003o1Oooool10000007ooooo00000`00003oooooooooo`02ooooool0003o5@000?l5ooooo`400000
0Oooool0000300000?oooooooooo00;oooooo`000?lE0000o`Gooooo0@000001ooooo`0000<00000
ooooooooool00_oooooo0000oaD0003o1Oooool10000007ooooo00000`00003oooooooooo`02oooo
ool0003o5@000?l5ooooo`4000000Oooool0000300000?oooooooooo00;oooooo`000?lE0000o`Go
oooo0@000001ooooo`0000<00000ooooooooool00_oooooo0000oaD0003o1Oooool10000007ooooo
00000`00003oooooooooo`02ooooool0003o5@000?l5ooooo`4000000Oooool0000300000?oooooo
oooo00;oooooo`000?lE0000o`Gooooo0@000001ooooo`0000<00000ooooooooool00_oooooo0000
oaD0003o1Oooool10000007ooooo00000`00003oooooooooo`02ooooool0003o5@000?l5ooooo`40
00000Oooool0000300000?oooooooooo00;oooooo`000?lE0000o`Gooooo0@000001ooooo`0000<0
0000ooooooooool00_oooooo0000oaD0003o1Oooool10000007ooooo00000`00003oooooooooo`02
ooooool0003o5@000?l5ooooo`4000000Oooool0000300000?oooooooooo00;oooooo`000?lE0000
o`Gooooo0@000001ooooo`0000<00000ooooooooool00_oooooo0000oaD0003o1Oooool10000007o
oooo00000`00003oooooooooo`02ooooool0003o5@000?l5ooooo`4000000Oooool0000300000?oo
oooooooo00;oooooo`000?lE0000o`Gooooo0@000001ooooo`0000<00000ooooooooool00_oooooo
0000oaD0003o1Oooool10000007ooooo00000`00003oooooooooo`02ooooool0003o5@000?l5oooo
o`4000000Oooool0000300000?oooooooooo00;oooooo`000?lE0000o`Gooooo0@000001ooooo`00
00<00000ooooooooool00_oooooo0000oaD0003o1Oooool10000007ooooo00000`00003ooooooooo
o`02ooooool0003o5@000?l5ooooo`4000000Oooool0000300000?oooooooooo00;oooooo`000?lE
0000o`Gooooo0@000001ooooo`0000<00000ooooooooool00_oooooo0000oaD0003o1Oooool10000
007ooooo00000`00003oooooooooo`02ooooool0003o5@000?l5ooooo`4000000Oooool000030000
0?oooooooooo00;oooooo`000?lE0000o`Gooooo0@000001ooooo`0000<00000ooooooooool00_oo
oooo0000oaD0003o1Oooool10000007ooooo00000`00003oooooooooo`02ooooool0003o5@000?l5
ooooo`4000000Oooool0000300000?oooooooooo00;oooooo`000?lE0000o`Gooooo0@000001oooo
o`0000<00000ooooooooool00_oooooo0000oaD0003o1Oooool10000007ooooo00000`00003ooooo
ooooo`02ooooool0003o5@000?l5ooooo`4000000Oooool0000300000?oooooooooo00;oooooo`00
0?lE0000o`Gooooo0@000001ooooo`0000<00000ooooooooool00_oooooo0000oaD0003o1Oooool1
0000007ooooo00000`00003oooooooooo`02ooooool0003o5@000?l5ooooo`4000000Oooool00003
00000?oooooooooo00;oooooo`000?lE0000o`Gooooo0@000001ooooo`0000<00000ooooooooool0
0_oooooo0000oaD0003o1Oooool10000007ooooo00000`00003oooooooooo`02ooooool0003o5@00
0?l5ooooo`4000000Oooool0000300000?oooooooooo00;oooooo`000?lE0000o`Gooooo0@000001
ooooo`0000<00000ooooooooool00_oooooo0000oaD0003o1Oooool10000007ooooo00000`00003o
ooooooooo`02ooooool0003o5@000?l5ooooo`4000000Oooool0000300000?oooooooooo00;ooooo
o`000?lE0000o`Gooooo0@000001ooooo`0000<00000ooooooooool00_oooooo0000oaD0003o1Ooo
ool10000007ooooo00000`00003oooooooooo`02ooooool0003o5@000?l5ooooo`4000000Oooool0
000300000?oooooooooo00;oooooo`000?lE0000o`Gooooo0@000001ooooo`0000<00000oooooooo
ool00_oooooo0000oaD0003o1Oooool10000007ooooo00000`00003oooooooooo`02ooooool0003o
5@000?l5ooooo`4000000Oooool0000300000?oooooooooo00;oooooo`000?lE0000o`Gooooo0@00
0001ooooo`0000<00000ooooooooool00_oooooo0000oaD0003o1Oooool10000007ooooo00000`00
003oooooooooo`02ooooool0003o5@000?l5ooooo`4000000Oooool0000300000?oooooooooo00;o
ooooo`000?lE0000o`Gooooo0@000001ooooo`0000<00000ooooooooool00_oooooo0000oaD0003o
1Oooool10000007ooooo00000`00003oooooooooo`02ooooool0003o5@000?l5ooooo`4000000Ooo
ool0000300000?oooooooooo00;oooooo`000?lE0000o`Gooooo0@000001ooooo`0000<00000oooo
ooooool00_oooooo0000oaD0003o1Oooool10000007ooooo00000`00003oooooooooo`02ooooool0
003o5@000?l5ooooo`4000000Oooool0000300000?oooooooooo00;oooooo`000?lE0000o`Gooooo
0@000001ooooo`0000<00000ooooooooool00_oooooo0000oaD0003o1Oooool10000007ooooo0000
0`00003oooooooooo`02ooooool0003o5@000?l5ooooo`4000000Oooool0000300000?oooooooooo
00;oooooo`000?lE0000o`Gooooo0@000001ooooo`0000<00000ooooooooool00_oooooo0000oaD0
003o1Oooool10000007ooooo00000`00003oooooooooo`02ooooool0003o5@000?l5ooooo`400000
0Oooool0000300000?oooooooooo00;oooooo`000?lE0000o`Gooooo0@000001ooooo`0000<00000
ooooooooool00_oooooo0000oaD0003o1Oooool10000007ooooo00000`00003oooooooooo`02oooo
ool0003o5@000?l5ooooo`4000000Oooool0000300000?oooooooooo00;oooooo`000?lE0000o`Go
oooo0@000001ooooo`0000<00000ooooooooool00_oooooo0000oaD0003o1Oooool10000007ooooo
00000`00003oooooooooo`02ooooool0003o5@000?l5ooooo`4000000Oooool0000300000?oooooo
oooo00;oooooo`000?lE0000o`Gooooo0@000001ooooo`0000<00000ooooooooool00_oooooo0000
oaD0003o1Oooool10000007ooooo00000`00003oooooooooo`02ooooool0003o5@000?l5ooooo`40
00000Oooool0000300000?oooooooooo00;oooooo`000?lE0000o`Gooooo0@000001ooooo`0000<0
0000ooooooooool00_oooooo0000oaD0003o1Oooool10000007ooooo00000`00003oooooooooo`02
ooooool0003o5@000?l5ooooo`4000000Oooool0000300000?oooooooooo00;oooooo`000?lE0000
o`Gooooo0@000001ooooo`0000<00000ooooooooool00_oooooo0000oaD0003o1Oooool10000007o
oooo00000`00003oooooooooo`02ooooool0003o5@000?l5ooooo`4000000Oooool0000300000?oo
oooooooo00;oooooo`000?lE0000o`Gooooo0@000001ooooo`0000<00000ooooooooool00_oooooo
0000oaD0003o1Oooool10000007ooooo00000`00003oooooooooo`02ooooool0003o5@000?l5oooo
o`4000000Oooool0000300000?oooooooooo00;oooooo`000?lE0000o`Gooooo0@000001ooooo`00
00<00000ooooooooool00_oooooo0000oaD0003o1Oooool10000007ooooo00000`00003ooooooooo
o`02ooooool0003o5@000?l5ooooo`4000000Oooool0000300000?oooooooooo00;oooooo`000?lE
0000o`Gooooo0@000001ooooo`0000<00000ooooooooool00_oooooo0000oaD0003o1Oooool10000
007ooooo00000`00003oooooooooo`02ooooool0003o5@000?l5ooooo`4000000Oooool000030000
0?oooooooooo00;oooooo`000?lE0000o`Gooooo0@000001ooooo`0000<00000ooooooooool00_oo
oooo0000oaD0003o1Oooool10000007ooooo00000`00003oooooooooo`02ooooool0003o5@000?l5
ooooo`4000000Oooool0000300000?oooooooooo00;oooooo`000?lE0000o`Gooooo0@000001oooo
o`0000<00000ooooooooool00_oooooo0000oaD0003o1Oooool10000007ooooo00000`00003ooooo
ooooo`02ooooool0003o5@000?l5ooooo`4000000Oooool0000300000?oooooooooo00;oooooo`00
0?lE0000o`Gooooo0@000001ooooo`0000<00000ooooooooool00_oooooo0000oaD0003o1Oooool1
0000007ooooo00000`00003oooooooooo`02ooooool0003o5@000?l5ooooo`4000000Oooool00003
00000?oooooooooo00;oooooo`000?lE0000o`Gooooo0@000001ooooo`0000<00000ooooooooool0
0_oooooo0000oaD0003o1Oooool10000007ooooo00000`00003oooooooooo`02ooooool0003o5@00
0?l5ooooo`4000000Oooool0000300000?oooooooooo00;oooooo`000?lE0000o`Gooooo0@000001
ooooo`0000<00000ooooooooool00_oooooo0000oaD0003o1Oooool10000007ooooo00000`00003o
ooooooooo`02ooooool0003o5@000?l5ooooo`4000000Oooool0000300000?oooooooooo00;ooooo
o`000?lE0000o`Gooooo0@000001ooooo`0000<00000ooooooooool00_oooooo0000oaD0003o1Ooo
ool10000007ooooo00000`00003oooooooooo`02ooooool0003o5@000?l5ooooo`4000000Oooool0
000300000?oooooooooo00;oooooo`000?lE0000o`Gooooo0@000001ooooo`0000<00000oooooooo
ool00_oooooo0000oaD0003o1Oooool10000007ooooo00000`00003oooooooooo`02ooooool0003o
5@000?l5ooooo`4000000Oooool0000300000?oooooooooo00;oooooo`000?lE0000o`Gooooo0@00
0001ooooo`0000<00000ooooooooool00_oooooo0000oaD0003o1Oooool10000007ooooo00000`00
003oooooooooo`02ooooool0003o5@000?l5ooooo`4000000Oooool0000300000?oooooooooo00;o
ooooo`000?lE0000o`Gooooo0@000001ooooo`0000<00000ooooooooool00_oooooo0000oaD0003o
1Oooool10000007ooooo00000`00003oooooooooo`02ooooool0003o5@000?l5ooooo`4000000Ooo
ool0000300000?oooooooooo00;oooooo`000?lE0000o`Gooooo0@000001ooooo`0000<00000oooo
ooooool00_oooooo0000oaD0003o1Oooool10000007ooooo00000`00003oooooooooo`02ooooool0
003o5@000?l5ooooo`4000000Oooool0000300000?oooooooooo00;oooooo`000?lE0000o`Gooooo
0@000001ooooo`0000<00000ooooooooool00_oooooo0000oaD0003o1Oooool10000007ooooo0000
0`00003oooooooooo`02ooooool0003o5@000?l5ooooo`4000000Oooool0000300000?oooooooooo
00;oooooo`000?lE0000o`Gooooo0@000001ooooo`0000<00000ooooooooool00_oooooo0000oaD0
003o1Oooool10000007ooooo00000`00003oooooooooo`02ooooool0003o5@000?l5ooooo`400000
0Oooool0000300000?oooooooooo00;oooooo`000?lE0000o`Gooooo0@000001ooooo`0000<00000
ooooooooool00_oooooo0000oaD0003o1Oooool10000007ooooo00000`00003oooooooooo`3ooooo
oacooooo0@000001ooooo`0000<00000ooooooooool0oooooolLooooo`4000000Oooool000030000
0?oooooooooo0?oooooo7?ooool10000007ooooo00000`00003oooooooooo`3ooooooacooooo0@00
0001ooooo`00o`00000P0000007ooooo0000\
\>"],
  ImageRangeCache->{{{0, 287}, {287, 0}} -> {-1.04092, -1.04092, 0.00725378, \
0.00725378}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% ContourGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.480769 0.5 0.480769 [
[ 0 0 -0.125 0 ]
[ 0 0 -0.125 0 ]
[ 0 1 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
0 0 m
1 0 L
s
0 0 m
0 1 L
s
0 1 m
1 1 L
s
1 0 m
1 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
0 0 1 r
.01923 .98077 m
.98077 .98077 L
.98077 .01923 L
.01923 .01923 L
F
0 g
.5 Mabswid
.1 0 .9 r
.01923 .53516 m
.05929 .53602 L
.09936 .53638 L
.13942 .53656 L
.17949 .53668 L
.21955 .53678 L
.25962 .53687 L
.29968 .53691 L
.33974 .53684 L
.37981 .53653 L
.41987 .53567 L
.45994 .53316 L
.5 .5239 L
.54006 .50469 L
.55402 .5 L
.58013 .49443 L
.62019 .4649 L
.62612 .45994 L
.66009 .41987 L
.66026 .41943 L
.68384 .37981 L
.69493 .33974 L
.69727 .29968 L
.6977 .25962 L
.69738 .21955 L
.69677 .17949 L
.69591 .13942 L
.69393 .09936 L
.68552 .05929 L
.66291 .01923 L
.01923 .01923 L
F
0 g
.01923 .53516 m
.05929 .53602 L
.09936 .53638 L
.13942 .53656 L
.17949 .53668 L
.21955 .53678 L
.25962 .53687 L
.29968 .53691 L
.33974 .53684 L
.37981 .53653 L
.41987 .53567 L
.45994 .53316 L
.5 .5239 L
.54006 .50469 L
.55402 .5 L
.58013 .49443 L
.62019 .4649 L
.62612 .45994 L
.66009 .41987 L
.66026 .41943 L
.68384 .37981 L
.69493 .33974 L
.69727 .29968 L
.6977 .25962 L
.69738 .21955 L
.69677 .17949 L
.69591 .13942 L
.69393 .09936 L
.68552 .05929 L
.66291 .01923 L
s
.2 0 .8 r
.01923 .52929 m
.05929 .53107 L
.09936 .5318 L
.13942 .53215 L
.17949 .53233 L
.21955 .53244 L
.25962 .53249 L
.29968 .53244 L
.33974 .53219 L
.37981 .53148 L
.41987 .52967 L
.45994 .52464 L
.5 .51048 L
.51917 .5 L
.54006 .49613 L
.58013 .48358 L
.60974 .45994 L
.62019 .45177 L
.64983 .41987 L
.66026 .39526 L
.6691 .37981 L
.68616 .33974 L
.69104 .29968 L
.69229 .25962 L
.69227 .21955 L
.69162 .17949 L
.69025 .13942 L
.68646 .09936 L
.67295 .05929 L
.66026 .03574 L
.65672 .01923 L
.01923 .01923 L
F
0 g
.01923 .52929 m
.05929 .53107 L
.09936 .5318 L
.13942 .53215 L
.17949 .53233 L
.21955 .53244 L
.25962 .53249 L
.29968 .53244 L
.33974 .53219 L
.37981 .53148 L
.41987 .52967 L
.45994 .52464 L
.5 .51048 L
.51917 .5 L
.54006 .49613 L
.58013 .48358 L
.60974 .45994 L
.62019 .45177 L
.64983 .41987 L
.66026 .39526 L
.6691 .37981 L
.68616 .33974 L
.69104 .29968 L
.69229 .25962 L
.69227 .21955 L
.69162 .17949 L
.69025 .13942 L
.68646 .09936 L
.67295 .05929 L
.66026 .03574 L
.65672 .01923 L
s
.3 0 .7 r
.01923 .52389 m
.05929 .52647 L
.09936 .52754 L
.13942 .52803 L
.17949 .52827 L
.21955 .52839 L
.25962 .52841 L
.29968 .52828 L
.33974 .52786 L
.37981 .5268 L
.41987 .52418 L
.45994 .51714 L
.5 .50078 L
.50112 .5 L
.54006 .49062 L
.58013 .47443 L
.59814 .45994 L
.62019 .44238 L
.64111 .41987 L
.65926 .37981 L
.66026 .37723 L
.67847 .33974 L
.68538 .29968 L
.68733 .25962 L
.68755 .21955 L
.68687 .17949 L
.68505 .13942 L
.67975 .09936 L
.6635 .05929 L
.66026 .05328 L
.65237 .01923 L
.01923 .01923 L
F
0 g
.01923 .52389 m
.05929 .52647 L
.09936 .52754 L
.13942 .52803 L
.17949 .52827 L
.21955 .52839 L
.25962 .52841 L
.29968 .52828 L
.33974 .52786 L
.37981 .5268 L
.41987 .52418 L
.45994 .51714 L
.5 .50078 L
.50112 .5 L
.54006 .49062 L
.58013 .47443 L
.59814 .45994 L
.62019 .44238 L
.64111 .41987 L
.65926 .37981 L
.66026 .37723 L
.67847 .33974 L
.68538 .29968 L
.68733 .25962 L
.68755 .21955 L
.68687 .17949 L
.68505 .13942 L
.67975 .09936 L
.6635 .05929 L
.66026 .05328 L
.65237 .01923 L
s
.4 0 .6 r
.01923 .51873 m
.05929 .52206 L
.09936 .52345 L
.13942 .52408 L
.17949 .52438 L
.21955 .52451 L
.25962 .5245 L
.29968 .52429 L
.33974 .52371 L
.37981 .52233 L
.41987 .51894 L
.45994 .51016 L
.48406 .5 L
.5 .49492 L
.54006 .48546 L
.58013 .46614 L
.58782 .45994 L
.62019 .43378 L
.63311 .41987 L
.65321 .37981 L
.66026 .36238 L
.67133 .33974 L
.68 .29968 L
.6826 .25962 L
.68304 .21955 L
.68233 .17949 L
.68007 .13942 L
.67342 .09936 L
.66026 .0679 L
.65694 .05929 L
.64826 .01923 L
.01923 .01923 L
F
0 g
.01923 .51873 m
.05929 .52206 L
.09936 .52345 L
.13942 .52408 L
.17949 .52438 L
.21955 .52451 L
.25962 .5245 L
.29968 .52429 L
.33974 .52371 L
.37981 .52233 L
.41987 .51894 L
.45994 .51016 L
.48406 .5 L
.5 .49492 L
.54006 .48546 L
.58013 .46614 L
.58782 .45994 L
.62019 .43378 L
.63311 .41987 L
.65321 .37981 L
.66026 .36238 L
.67133 .33974 L
.68 .29968 L
.6826 .25962 L
.68304 .21955 L
.68233 .17949 L
.68007 .13942 L
.67342 .09936 L
.66026 .0679 L
.65694 .05929 L
.64826 .01923 L
s
.5 0 .5 r
.01923 .51368 m
.05929 .51774 L
.09936 .51944 L
.13942 .52021 L
.17949 .52057 L
.21955 .52071 L
.25962 .52067 L
.29968 .52039 L
.33974 .51966 L
.37981 .51795 L
.41987 .51381 L
.45994 .50343 L
.46814 .5 L
.5 .48961 L
.54006 .48046 L
.57912 .45994 L
.58013 .45845 L
.62019 .42551 L
.62542 .41987 L
.64748 .37981 L
.66026 .34862 L
.66444 .33974 L
.67475 .29968 L
.67799 .25962 L
.67864 .21955 L
.67788 .17949 L
.6752 .13942 L
.66725 .09936 L
.66026 .08178 L
.6517 .05929 L
.64428 .01923 L
.01923 .01923 L
F
0 g
.01923 .51368 m
.05929 .51774 L
.09936 .51944 L
.13942 .52021 L
.17949 .52057 L
.21955 .52071 L
.25962 .52067 L
.29968 .52039 L
.33974 .51966 L
.37981 .51795 L
.41987 .51381 L
.45994 .50343 L
.46814 .5 L
.5 .48961 L
.54006 .48046 L
.57912 .45994 L
.58013 .45845 L
.62019 .42551 L
.62542 .41987 L
.64748 .37981 L
.66026 .34862 L
.66444 .33974 L
.67475 .29968 L
.67799 .25962 L
.67864 .21955 L
.67788 .17949 L
.6752 .13942 L
.66725 .09936 L
.66026 .08178 L
.6517 .05929 L
.64428 .01923 L
s
.6 0 .4 r
.01923 .5086 m
.05929 .51342 L
.09936 .51545 L
.13942 .51636 L
.17949 .51678 L
.21955 .51693 L
.25962 .51686 L
.29968 .5165 L
.33974 .51562 L
.37981 .51357 L
.41987 .50866 L
.45225 .5 L
.45994 .49676 L
.5 .48445 L
.54006 .47549 L
.57419 .45994 L
.58013 .45144 L
.61769 .41987 L
.62019 .4171 L
.64188 .37981 L
.65755 .33974 L
.66026 .33491 L
.66948 .29968 L
.67337 .25962 L
.67425 .21955 L
.67343 .17949 L
.67031 .13942 L
.66108 .09936 L
.66026 .0971 L
.6466 .05929 L
.64035 .01923 L
.01923 .01923 L
F
0 g
.01923 .5086 m
.05929 .51342 L
.09936 .51545 L
.13942 .51636 L
.17949 .51678 L
.21955 .51693 L
.25962 .51686 L
.29968 .5165 L
.33974 .51562 L
.37981 .51357 L
.41987 .50866 L
.45225 .5 L
.45994 .49676 L
.5 .48445 L
.54006 .47549 L
.57419 .45994 L
.58013 .45144 L
.61769 .41987 L
.62019 .4171 L
.64188 .37981 L
.65755 .33974 L
.66026 .33491 L
.66948 .29968 L
.67337 .25962 L
.67425 .21955 L
.67343 .17949 L
.67031 .13942 L
.66108 .09936 L
.66026 .0971 L
.6466 .05929 L
.64035 .01923 L
s
.7 0 .3 r
.01923 .50337 m
.05929 .50902 L
.09936 .5114 L
.13942 .51247 L
.17949 .51295 L
.21955 .51311 L
.25962 .51301 L
.29968 .51257 L
.33974 .51152 L
.37981 .50911 L
.41987 .50336 L
.43379 .5 L
.45994 .48998 L
.5 .47928 L
.54006 .47045 L
.56732 .45994 L
.58013 .44439 L
.60959 .41987 L
.62019 .40804 L
.63624 .37981 L
.65046 .33974 L
.66026 .31755 L
.66406 .29968 L
.66866 .25962 L
.66977 .21955 L
.6689 .17949 L
.66529 .13942 L
.66026 .11241 L
.65413 .09936 L
.64153 .05929 L
.63641 .01923 L
.01923 .01923 L
F
0 g
.01923 .50337 m
.05929 .50902 L
.09936 .5114 L
.13942 .51247 L
.17949 .51295 L
.21955 .51311 L
.25962 .51301 L
.29968 .51257 L
.33974 .51152 L
.37981 .50911 L
.41987 .50336 L
.43379 .5 L
.45994 .48998 L
.5 .47928 L
.54006 .47045 L
.56732 .45994 L
.58013 .44439 L
.60959 .41987 L
.62019 .40804 L
.63624 .37981 L
.65046 .33974 L
.66026 .31755 L
.66406 .29968 L
.66866 .25962 L
.66977 .21955 L
.6689 .17949 L
.66529 .13942 L
.66026 .11241 L
.65413 .09936 L
.64153 .05929 L
.63641 .01923 L
s
.8 0 .2 r
.01923 .49686 m
.0366 .5 L
.05929 .50443 L
.09936 .50721 L
.13942 .50845 L
.17949 .50901 L
.21955 .50918 L
.25962 .50905 L
.29968 .50853 L
.33974 .50728 L
.37981 .50446 L
.41114 .5 L
.41987 .49674 L
.45994 .48293 L
.5 .474 L
.54006 .46518 L
.55618 .45994 L
.58013 .43707 L
.60104 .41987 L
.62019 .39832 L
.63041 .37981 L
.64305 .33974 L
.65746 .29968 L
.66026 .28977 L
.66373 .25962 L
.6651 .21955 L
.66416 .17949 L
.66026 .14101 L
.65985 .13942 L
.64667 .09936 L
.63635 .05929 L
.63238 .01923 L
.01923 .01923 L
F
0 g
.01923 .49686 m
.0366 .5 L
.05929 .50443 L
.09936 .50721 L
.13942 .50845 L
.17949 .50901 L
.21955 .50918 L
.25962 .50905 L
.29968 .50853 L
.33974 .50728 L
.37981 .50446 L
.41114 .5 L
.41987 .49674 L
.45994 .48293 L
.5 .474 L
.54006 .46518 L
.55618 .45994 L
.58013 .43707 L
.60104 .41987 L
.62019 .39832 L
.63041 .37981 L
.64305 .33974 L
.65746 .29968 L
.66026 .28977 L
.66373 .25962 L
.6651 .21955 L
.66416 .17949 L
.66026 .14101 L
.65985 .13942 L
.64667 .09936 L
.63635 .05929 L
.63238 .01923 L
s
.9 0 .1 r
.01923 .48743 m
.05929 .4991 L
.06277 .5 L
.09936 .50277 L
.13942 .50422 L
.17949 .50486 L
.21955 .50506 L
.25962 .50489 L
.29968 .50426 L
.33974 .50279 L
.37611 .5 L
.37981 .49903 L
.41987 .4872 L
.45994 .47534 L
.5 .46842 L
.53882 .45994 L
.54006 .45915 L
.58013 .42915 L
.59159 .41987 L
.62019 .38732 L
.62415 .37981 L
.63502 .33974 L
.64769 .29968 L
.65701 .25962 L
.65995 .21955 L
.6581 .17949 L
.65046 .13942 L
.63848 .09936 L
.63093 .05929 L
.62817 .01923 L
.01923 .01923 L
F
0 g
.01923 .48743 m
.05929 .4991 L
.06277 .5 L
.09936 .50277 L
.13942 .50422 L
.17949 .50486 L
.21955 .50506 L
.25962 .50489 L
.29968 .50426 L
.33974 .50279 L
.37611 .5 L
.37981 .49903 L
.41987 .4872 L
.45994 .47534 L
.5 .46842 L
.53882 .45994 L
.54006 .45915 L
.58013 .42915 L
.59159 .41987 L
.62019 .38732 L
.62415 .37981 L
.63502 .33974 L
.64769 .29968 L
.65701 .25962 L
.65995 .21955 L
.6581 .17949 L
.65046 .13942 L
.63848 .09936 L
.63093 .05929 L
.62817 .01923 L
s
1 0 0 r
.01923 .47486 m
.05929 .48705 L
.09936 .49536 L
.13942 .49917 L
.15488 .5 L
.17949 .50038 L
.21955 .50059 L
.25962 .50037 L
.28396 .5 L
.29968 .49915 L
.33974 .49528 L
.37981 .48683 L
.41987 .47447 L
.45994 .46671 L
.5 .46228 L
.51602 .45994 L
.54006 .4456 L
.58013 .41993 L
.58021 .41987 L
.61398 .37981 L
.62019 .36977 L
.62577 .33974 L
.63452 .29968 L
.64397 .25962 L
.64784 .21955 L
.64557 .17949 L
.63739 .13942 L
.62896 .09936 L
.62502 .05929 L
.62366 .01923 L
.01923 .01923 L
F
0 g
.01923 .47486 m
.05929 .48705 L
.09936 .49536 L
.13942 .49917 L
.15488 .5 L
.17949 .50038 L
.21955 .50059 L
.25962 .50037 L
.28396 .5 L
.29968 .49915 L
.33974 .49528 L
.37981 .48683 L
.41987 .47447 L
.45994 .46671 L
.5 .46228 L
.51602 .45994 L
.54006 .4456 L
.58013 .41993 L
.58021 .41987 L
.61398 .37981 L
.62019 .36977 L
.62577 .33974 L
.63452 .29968 L
.64397 .25962 L
.64784 .21955 L
.64557 .17949 L
.63739 .13942 L
.62896 .09936 L
.62502 .05929 L
.62366 .01923 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P000182000`400?l00000o`00003ooooooolQ
ooooo`00o`00000P0000007ooooo00000`00003oooooooooo`3ooooooacooooo0@000001ooooo`00
00<00000ooooooooool0oooooolLooooo`4000000Oooool0000300000?oooooooooo0?oooooo7?oo
ool10000007ooooo00000`00003oooooooooo`3ooooooacooooo0@000001ooooo`0000<00000oooo
ooooool0[oooool00ol0003oooooo`000004o`000006ooooool0003o0000o`000?oooooo0000Gooo
ool10000007ooooo00000`00003oooooooooo`02ooooojd0o`0000?o00000>H06Ol000001?l00000
1P1V09Wo0000o`000?l000006@3Vo`0005X0003o1Oooool10000007ooooo00000`00003ooooooooo
o`02ooooojd0o`0000?o00000>H06Ol000001?l00000101V09Wo0000o`000?l0000201T0iP03o`00
00000?l0003o05L0003o1Oooool10000007ooooo00000`00003oooooooooo`02ooooojd0o`0000?o
00000>H06Ol000000ol00000101o07oo0000o`00001<0;<2o`00000301T0i_l00000003o05P0003o
1Oooool10000007ooooo00000`00003oooooooooo`02ooooojd0o`0000Go00000>H06Ol0003o0000
0;<0C003o`00000406H0VOl0003o0000o`0000806@3V00?o00000000o`000?l0EP000?l5ooooo`40
00000Oooool0000300000?oooooooooo00;ooooo[@3o00001Ol00000iP0Io`000?l00000/`1<00?o
000000@0IP2Io`000?l0003o00000P0I0>H00ol00000003o0000o`1F0000o`Gooooo0@000001oooo
o`0000<00000ooooooooool00_oooon]0?l00005o`00003V01Wo0000o`00002c04`00ol00000101V
09Wo0000o`000?l0000301T0iP03o`0000000?l0003o05D0003o1Oooool10000007ooooo00000`00
003oooooooooo`02ooooojh0o`0000?o00000>H06Ol000000ol000001P1o07oo0000o`000?l00000
<`3<o`0000806@3V00?o00000000o`000?l0E@000?l5ooooo`4000000Oooool0000300000?oooooo
oooo00;ooooo[P3o00000ol00000iP0Io`000003o`00000407l0Ool0003o000004`0/`;o00000`0I
0>H00ol00000003o0000o`1D0000o`Gooooo0@000001ooooo`0000<00000ooooooooool00_oooon^
0?l00003o`00003V01Wo000000?o000000L0O`1oo`000?l00000C02co`00000c0<co000000806@3V
00?o00000000o`000?l0E0000?l5ooooo`4000000Oooool0000300000?oooooooooo00;ooooo[P3o
00001Ol00000iP0Io`000?l00000/`1<00?o000000<0IP2Io`000?l000000P0c0<`01?l000006@3V
01T0i_l0001E0000o`Gooooo0@000001ooooo`0000<00000ooooooooool00_oooon^0?l00005o`00
003V01Wo0000o`00002c04`00_l00000101o07oo0000o`000?l0000203<0c004o`00000I0>H06@3V
o`0005D0003o1Oooool10000007ooooo00000`00003oooooooooo`02ooooojh0o`0000Go00000>H0
6Ol0003o00000;<0C002o`00000507l0Ool0003o000004`0/ol000000P0c0<`01?l000006@3V01T0
i_l0001D0000o`Gooooo0@000001ooooo`0000<00000ooooooooool00_oooon^0?l00005o`00003V
01Wo0000o`00002c04`00_l000001@1o07oo0000o`00001<0;?o00000080<`3<00Co000001T0iP0I
0>Ko0000E0000?l5ooooo`4000000Oooool0000300000?oooooooooo00;ooooo[P3o00002Ol00000
iP0Io`000?l00000/`1<o`00002I06Ko000007l0O`02o`00000404`0/ol00000<`3<o`0000806@3V
00?o00000000o`000?l0DP000?l5ooooo`4000000Oooool0000300000?oooooooooo00;ooooo[P3o
00001_l00000iP0Io`00003<03?o00000;<0C0;o000000D0O`1oo`000?l00000C02co`00000203<0
c004o`00000I0>H06@3Vo`0005<0003o1Oooool10000007ooooo00000`00003oooooooooo`02oooo
ojh0o`0000?o00000>H06@3V01T00_l000002`2c04co0000o`00001o07oo000006H0VOl00000C02c
o`00000c0<co000000806@3V00?o00000000o`000?l0D@000?l5ooooo`4000000Oooool000030000
0?oooooooooo00;ooooo[P3o00000ol00000iP0I0>H06@02o`0000050;<0C?l00000V@1Vo`00001o
07l00_l00000101<0;?o000003<0c?l0000201T0iP03o`0000000?l0003o0540003o1Oooool10000
007ooooo00000`00003oooooooooo`02ooooojl0o`0000Ko00000>H06Ol00000c00co`00002c04`2
o`00000807l0Ool00000IP2Io`00001<0;?o000003<0c?l0000201T0iP03o`0000000?l0003o0500
003o1Oooool10000007ooooo00000`00003oooooooooo`02ooooojl0o`0000So00000>H06Ol00000
c00co`00002c04co000009T0IP;o000000H0IP2Io`00001<0;?o000003<0c?l0000201T0iP03o`00
00000?l0003o0500003o1Oooool10000007ooooo00000`00003oooooooooo`02ooooojl0o`0000[o
00000>H06Ol00000c00co`00002c04co000009T0I_l00000O`1o0_l00000101<0;?o000003<0c?l0
000201T0iP03o`0000000?l0003o0500003o1Oooool10000007ooooo00000`00003oooooooooo`02
ooooojl0o`0000?o00000>H06@3V01T00_l000002@2c04co000009T0I_l00000O`1oo`00001V09Wo
000004`0/`02o`0000806@3V00?o00000000o`000?l0D0000?l5ooooo`4000000Oooool000030000
0?oooooooooo00;ooooo[`3o00002Ol00000iP0I0>H06Ol00000c00co`00002c04co000009T0IP02
o`00000606H0VOl00000C02co`00000c0<co00000P0I0>H00ol00000003o0000o`1?0000o`Gooooo
0@000001ooooo`0000<00000ooooooooool00_oooon_0?l0000?o`00003V01T0iP0Io`00003<03?o
00000;<0C?l00000V@1Vo`00001o07oo000006H0VOl00000C02c00;o00000P0I0>H00ol00000003o
0000o`1?0000o`Gooooo0@000001ooooo`0000<00000ooooooooool00_oooon_0?l0000?o`00003V
01T0iP0Io`00003<03?o00000;<0C?l00000V@1Vo`00001o07oo000006H0VOl00000C02c00;o0000
0P0I0>H00ol00000003o0000o`1?0000o`Gooooo0@000001ooooo`0000<00000ooooooooool00_oo
oon_0?l00004o`00003V01T0iP0Io`000080c00c00Wo00000;<0C?l0003o000007l0Ool00000IP2I
o`00001<0;<00_l0000201T0iP03o`0000000?l0003o04l0003o1Oooool10000007ooooo00000`00
003oooooooooo`02ooooojl0o`0000[o00000>H06@3V01T0iP0Io`00003<03?o00000;<0C?l00000
V@1V0_l000000`1V09Wo000004`0/`02o`0000806@3V00?o00000000o`000?l0C`000?l5ooooo`40
00000Oooool0000300000?oooooooooo00;ooooo/03o00001_l00000iP0I0>H06Ol00000c00co`00
0080/`1<0_l000000`1o07oo000006H0V@02o`00000403<0c?l000006@3Vo`000540003o1Oooool1
0000007ooooo00000`00003oooooooooo`02oooook00o`0000Co00000>H06@3V01Wo00000P3<03<0
1ol00000/`1<o`000?l00000O`1oo`00001V09T00_l00000100c0<co000001T0i_l0001A0000o`Go
oooo0@000001ooooo`0000<00000ooooooooool00_oooon`0?l00004o`00003V01T0iP0Io`000080
c00c00Oo00000;<0C?l0003o000007l0Ool00000IP2I00;o000000@0<`3<o`00000I0>Ko0000D@00
0?l5ooooo`4000000Oooool0000300000?oooooooooo00;ooooo/03o00002_l00000iP0I0>H06@3V
01Wo00000<`0<ol00000/`1<o`00002I06H2o`00000306H0VOl00000C02c00;o000000<06@3Vo`00
00000?l0D0000?l5ooooo`4000000Oooool0000300000?oooooooooo00;ooooo/03o00001Ol00000
iP0I0>H06@3V01Wo00000080c00c0_l000001P2I06Ko0000o`00001V09Wo000004`0/`;o000000<0
6@3Vo`0000000?l0D0000?l5ooooo`4000000Oooool0000300000?oooooooooo00;ooooo/03o0000
1Ol00000iP0I0>H06@3V01Wo00000080c00c00?o00000;<0C?l000000_l000000`1V09Wo000004`0
/`02o`00000301T0i_l00000003o0500003o1Oooool10000007ooooo00000`00003oooooooooo`02
oooook40o`0000Co00000>H06@3V01Wo00000P3<03<01ol00000/`1<o`000?l00000O`1oo`00001V
09T00_l000000`0c0<co0000o`00001A0000o`Gooooo0@000001ooooo`0000<00000ooooooooool0
0_oooona0?l00005o`00003V01T0iP0I0>H06Ol000000P3<03<2o`00000409T0I_l0003o000006H0
V@;o000000<0<`3<o`000?l00000D@000?l5ooooo`4000000Oooool0000300000?oooooooooo00;o
oooo/@3o00001Ol00000iP0I0>H06@3V01Wo00000080c00c0_l00000102I06Ko0000o`00001V09T2
o`00000303<0c?l0003o00000540003o1Oooool10000007ooooo00000`00003oooooooooo`02oooo
ok40o`0000Go00000>H06@3V01T0iP0Io`0000020<`0<`;o000000@0V@1Vo`000?l00000IP2I0_l0
00000`0c0<co0000o`00001A0000o`Gooooo0@000001ooooo`0000<00000ooooooooool00_oooona
0?l00005o`00003V01T0iP0I0>H06Ol000000P3<03<2o`00000409T0I_l0003o000006H0V@;o0000
00<0<`3<o`000?l00000D@000?l5ooooo`4000000Oooool0000300000?oooooooooo00;ooooo/P3o
00001?l00000iP0I0>H06Ol000020<`0<`;o000000@0V@1Vo`000?l00000IP2I0_l000000`0c0<co
0000o`00001A0000o`Gooooo0@000001ooooo`0000<00000ooooooooool00_oooonb0?l00006o`00
003V01T0iP0I0>H06Ol00000c00c0_l00000102I06Ko0000o`00001V09T2o`00000303<0c?l0003o
00000540003o1Oooool10000007ooooo00000`00003oooooooooo`02oooook80o`0000Ko00000>H0
6@3V01T0iP0Io`00003<03<2o`00000409T0I_l0003o000006H0V@;o000000<0<`3<o`000?l00000
D@000?l5ooooo`4000000Oooool0000300000?oooooooooo00;ooooo/`3o00001?l00000iP0I0>H0
6Ol000020<`0<`;o000000D0V@1Vo`000?l0003o000004`0/`03o`000540003o1Oooool10000007o
oooo00000`00003oooooooooo`02oooook<0o`0000Co00000>H06@3V01Wo00000P3<03<2o`000005
09T0I_l0003o0000o`00001<0;<00ol0001A0000o`Gooooo0@000001ooooo`0000<00000oooooooo
ool00_oooonc0?l00004o`00003V01T0iP0Io`000080c00c0_l000001@2I06Ko0000o`000?l00000
C02c00?o0000D@000?l5ooooo`4000000Oooool0000300000?oooooooooo00;ooooo/`3o00001_l0
0000iP0I0>H06@3V01Wo00000<`0<`;o000000D0V@1Vo`000?l0003o000004`0/`03o`000540003o
1Oooool10000007ooooo00000`00003oooooooooo`02oooook@0o`0000Go00000>H06@3V01Wo0000
0<`0<`02o`00000509T0I_l0003o0000o`00001<0;<00ol0001A0000o`Gooooo0@000001ooooo`00
00<00000ooooooooool00_oooond0?l00005o`00003V01T0iP0Io`00003<03<00_l000001@2I06Ko
0000o`000?l00000C02c00?o0000D@000?l5ooooo`4000000Oooool0000300000?oooooooooo00;o
oooo]03o00001Ol00000iP0I0>H06Ol00000c00c00;o000000D0V@1Vo`000?l0003o000004`0/`03
o`000540003o1Oooool10000007ooooo00000`00003oooooooooo`02oooook@0o`0000Go00000>H0
6@3V01Wo00000<`0<`02o`00000509T0I_l0003o0000o`00001<0;<00ol0001A0000o`Gooooo0@00
0001ooooo`0000<00000ooooooooool00_oooond0?l00005o`00003V01T0iP0Io`00003<03<00_l0
00001@2I06Ko0000o`000?l00000C02c00?o0000D@000?l5ooooo`4000000Oooool0000300000?oo
oooooooo00;ooooo]03o00001Ol00000iP0I0>H06Ol00000c00c00;o000000D0V@1Vo`000?l0003o
000004`0/`03o`000540003o1Oooool10000007ooooo00000`00003oooooooooo`02oooook@0o`00
00Go00000>H06@3V01Wo00000<`0<`02o`00000509T0I_l0003o0000o`00001<0;<00ol0001A0000
o`Gooooo0@000001ooooo`0000<00000ooooooooool00_oooond0?l00005o`00003V01T0iP0Io`00
003<03<00_l000001@2I06Ko0000o`000?l00000C02c00?o0000D@000?l5ooooo`4000000Oooool0
000300000?oooooooooo00;ooooo]03o00001?l00000iP0I0>H06@3V01T2o`0000030;<0C?l0003o
000000;o000000D0C02co`000?l000006@3Vo`00001@0000o`Gooooo0@000001ooooo`0000<00000
ooooooooool00_oooond0?l00004o`00003V01T0iP0I0>H06@;o000000<0/`1<o`000?l000000_l0
00001@1<0;?o0000o`00000I0>Ko00000500003o1Oooool10000007ooooo00000`00003ooooooooo
o`02oooook@0o`0000Co00000>H06@3V01T0iP0I0_l000000`2c04co0000o`000002o`00000504`0
/ol0003o000001T0i_l00000D0000?l5ooooo`4000000Oooool0000300000?oooooooooo00;ooooo
]03o00001?l00000iP0I0>H06@3V01T2o`0000030;<0C?l0003o000000;o000000D0C02co`000?l0
00006@3Vo`00001@0000o`Gooooo0@000001ooooo`0000<00000ooooooooool00_oooond0?l00004
o`00003V01T0iP0I0>H06@;o000000<0/`1<o`000?l000000_l000001@1<0;?o0000o`00000I0>Ko
00000500003o1Oooool10000007ooooo00000`00003oooooooooo`02oooook@0o`0000Co00000>H0
6@3V01T0iP0I0_l000000`2c04co0000o`000002o`00000504`0/ol0003o000001T0i_l00000D000
0?l5ooooo`4000000Oooool0000300000?oooooooooo00;ooooo]03o00001?l00000iP0I0>H06@3V
01T2o`0000030;<0C?l0003o000000;o000000D0C02co`000?l000006@3Vo`00001@0000o`Gooooo
0@000001ooooo`0000<00000ooooooooool00_oooond0?l00004o`00003V01T0iP0I0>H06@;o0000
00<0/`1<o`000?l000000_l000001@1<0;?o0000o`00000I0>Ko00000500003o1Oooool10000007o
oooo00000`00003oooooooooo`02oooook@0o`0000Co00000>H06@3V01T0iP0I0_l000000`2c04co
0000o`000002o`00000504`0/ol0003o000001T0i_l00000D0000?l5ooooo`4000000Oooool00003
00000?oooooooooo00;ooooo]03o00001?l00000iP0I0>H06@3V01T2o`0000030;<0C?l0003o0000
00;o000000D0C02co`000?l000006@3Vo`00001@0000o`Gooooo0@000001ooooo`0000<00000oooo
ooooool00_oooond0?l00004o`00003V01T0iP0I0>H06@;o000000<0/`1<o`000?l000000_l00000
1@1<0;?o0000o`00000I0>Ko00000500003o1Oooool10000007ooooo00000`00003oooooooooo`02
oooook<0o`0000Ko00000>H06@3V01T0iP0Io`00003<03<2o`00000509T0I_l0003o0000o`00001<
0;<00_l000000`0I0>Ko00000000o`1?0000o`Gooooo0@000001ooooo`0000<00000ooooooooool0
0_oooonc0?l00006o`00003V01T0iP0I0>H06Ol00000c00c0_l000001@2I06Ko0000o`000?l00000
C02c00;o000000<06@3Vo`0000000?l0C`000?l5ooooo`4000000Oooool0000300000?oooooooooo
00;ooooo/`3o00001_l00000iP0I0>H06@3V01Wo00000<`0<`;o000000D0V@1Vo`000?l0003o0000
04`0/`02o`00000301T0i_l00000003o04l0003o1Oooool10000007ooooo00000`00003ooooooooo
o`02oooook<0o`0000Ko00000>H06@3V01T0iP0Io`00003<03<2o`00000509T0I_l0003o0000o`00
001<0;<00_l000000`0I0>Ko00000000o`1?0000o`Gooooo0@000001ooooo`0000<00000oooooooo
ool00_oooonc0?l00006o`00003V01T0iP0I0>H06Ol00000c00c0_l000001@2I06Ko0000o`000?l0
0000C02c00;o000000<06@3Vo`0000000?l0C`000?l5ooooo`4000000Oooool0000300000?oooooo
oooo00;ooooo/`3o00001_l00000iP0I0>H06@3V01Wo00000<`0<`;o000000D0V@1Vo`000?l0003o
000004`0/`02o`00000301T0i_l00000003o04l0003o1Oooool10000007ooooo00000`00003ooooo
ooooo`02oooook<0o`0000Ko00000>H06@3V01T0iP0Io`00003<03<2o`00000509T0I_l0003o0000
o`00001<0;<00_l000000`0I0>Ko00000000o`1?0000o`Gooooo0@000001ooooo`0000<00000oooo
ooooool00_oooonc0?l00006o`00003V01T0iP0I0>H06Ol00000c00c0_l000001@2I06Ko0000o`00
0?l00000C02c00;o000000<06@3Vo`0000000?l0C`000?l5ooooo`4000000Oooool0000300000?oo
oooooooo00;ooooo/`3o00001?l00000iP0I0>H06Ol000020<`0<`;o000000D0V@1Vo`000?l0003o
000004`0/`02o`00000301T0i_l00000003o04l0003o1Oooool10000007ooooo00000`00003ooooo
ooooo`02oooook80o`0000Go00000>H06@3V01T0iP0Io`0000020<`0<`;o000000D0V@1Vo`000?l0
003o000004`0/`02o`00000301T0i_l00000003o04l0003o1Oooool10000007ooooo00000`00003o
ooooooooo`02oooook80o`0000[o00000>H06@3V01T0iP0Io`00003<03?o00000;<0C?l00000V@1V
0ol000001@1<0;?o0000o`00000I0>Ko00000500003o1Oooool10000007ooooo00000`00003ooooo
ooooo`02oooook80o`0000[o00000>H06@3V01T0iP0Io`00003<03?o00000;<0C?l00000V@1V0ol0
00001@1<0;?o0000o`00000I0>Ko00000500003o1Oooool10000007ooooo00000`00003ooooooooo
o`02oooook80o`0000Co00000>H06@3V01Wo00000P3<03<2o`00000409T0I_l0003o000006H0V@;o
000000@0<`3<o`00000I0>Ko0000D0000?l5ooooo`4000000Oooool0000300000?oooooooooo00;o
oooo/P3o00001?l00000iP0I0>H06Ol000020<`0<`;o000000@0V@1Vo`000?l00000IP2I0_l00000
100c0<co000001T0i_l0001@0000o`Gooooo0@000001ooooo`0000<00000ooooooooool00_oooonb
0?l00004o`00003V01T0iP0Io`000080c00c0_l00000102I06Ko0000o`00001V09T2o`00000403<0
c?l000006@3Vo`000500003o1Oooool10000007ooooo00000`00003oooooooooo`02oooook40o`00
00Go00000>H06@3V01T0iP0Io`0000020<`0<`;o000000@0V@1Vo`000?l00000IP2I0_l00000100c
0<co000001T0i_l0001@0000o`Gooooo0@000001ooooo`0000<00000ooooooooool00_oooona0?l0
0004o`00003V01T0iP0Io`000080c00c00Co00000;<0C?l00000V@1V0_l000001`1V09Wo0000o`00
000c0<co000001T0i_l00000D0000?l5ooooo`4000000Oooool0000300000?oooooooooo00;ooooo
/@3o00001?l00000iP0I0>H06Ol000020<`0<`04o`00002c04co000009T0IP;o000000L0IP2Io`00
0?l00000<`3<o`00000I0>Ko00000500003o1Oooool10000007ooooo00000`00003oooooooooo`02
oooook40o`0000Co00000>H06@3V01Wo00000P3<03<01?l00000/`1<o`00002I06H2o`00000706H0
VOl0003o000003<0c?l000006@3Vo`00001@0000o`Gooooo0@000001ooooo`0000<00000oooooooo
ool00_oooona0?l00006o`00003V01T0iP0Io`00003<03?o00000P2c04`01Ol00000V@1Vo`000?l0
0000IP2I00;o000000@0<`3<o`00000I0>Ko0000D0000?l5ooooo`4000000Oooool0000300000?oo
oooooooo00;ooooo/03o00001?l00000iP0I0>H06Ol000020<`0<`04o`00002c04co000009T0IP;o
000000P0IP2Io`00001<0;?o000003<0c?l000006@3Vo`000500003o1Oooool10000007ooooo0000
0`00003oooooooooo`02oooook00o`0000Co00000>H06@3V01Wo00000P3<03<01?l00000/`1<o`00
002I06H2o`00000506H0VOl0003o000003<0c?l000000P0I0>H00ol00000003o0000o`1>0000o`Go
oooo0@000001ooooo`0000<00000ooooooooool00_oooon`0?l00006o`00003V01T0iP0Io`00003<
03?o00000P2c04`01Ol00000V@1Vo`000?l00000IP2I00;o000000D0<`3<o`00000I0>H06@3Vo`00
001@0000o`Gooooo0@000001ooooo`0000<00000ooooooooool00_oooon_0?l00004o`00003V01T0
iP0Io`000080c00c00?o00000;<0C02c04`00ol00000201V09Wo000004`0/ol00000<`3<o`00000I
0>Ko0000D@000?l5ooooo`4000000Oooool0000300000?oooooooooo00;ooooo[`3o00001?l00000
iP0I0>H06Ol000020<`0<`04o`00002c04co000009T0IP;o000000P0IP2Io`00001<0;?o000003<0
c?l000006@3Vo`000540003o1Oooool10000007ooooo00000`00003oooooooooo`02ooooojl0o`00
00Ko00000>H06@3V01Wo00000<`0<ol000020;<0C00<o`00002I06Ko0000o`00001V09Wo000004`0
/ol00000<`3<o`00000I0>Ko0000D@000?l5ooooo`4000000Oooool0000300000?oooooooooo00;o
oooo[`3o00003Ol00000iP0I0>H06Ol00000c00co`00002c04co000009T0I_l00000O`1oo`00001V
09T00_l000001@0c0<co000001T0iP0I0>Ko00000540003o1Oooool10000007ooooo00000`00003o
ooooooooo`02ooooojh0o`0000Co00000>H06@3V01Wo00000P3<03<01?l00000/`1<o`00002I06H2
o`00000606H0VOl00000C02co`00000c0<co00000P0I0>H00ol00000003o0000o`1?0000o`Gooooo
0@000001ooooo`0000<00000ooooooooool00_oooon^0?l0000Bo`00003V01T0iP0Io`00003<03?o
00000;<0C?l00000V@1Vo`00001o07oo000006H0VOl00000C02co`00000c0<co00000P0I0>H00ol0
0000003o0000o`1?0000o`Gooooo0@000001ooooo`0000<00000ooooooooool00_oooon^0?l0000B
o`00003V01T0iP0Io`00003<03?o00000;<0C?l00000V@1Vo`00001o07oo000006H0VOl00000C02c
o`00000c0<co00000P0I0>H00ol00000003o0000o`1?0000o`Gooooo0@000001ooooo`0000<00000
ooooooooool00_oooon^0?l00003o`00003V01T0iP0I00;o000000`0/`1<o`00002I06Ko000007l0
Ool00000IP2Io`00001<0;?o000003<0c?l0000301T0iP03o`0000000?l0003o04l0003o1Oooool1
0000007ooooo00000`00003oooooooooo`02ooooojd0o`0001;o00000>H06@3V01Wo00000<`0<ol0
0000/`1<o`00002I06Ko000007l0Ool00000IP2Io`00001<0;?o000003<0c?l0000201T0iP03o`00
00000?l0003o0500003o1Oooool10000007ooooo00000`00003oooooooooo`02ooooojd0o`0000_o
00000>H06@3V01Wo00000<`0<ol00000/`1<o`00002I06Ko000007l0O`02o`00000504`0/ol00000
<`3<03<0c?l000000P0I0>H00ol00000003o0000o`1@0000o`Gooooo0@000001ooooo`0000<00000
ooooooooool00_oooon]0?l00003o`00003V01T0iP0I00;o000000`0/`1<o`00002I06Ko000007l0
Ool00000IP2Io`00001<0;?o000003<0c?l0000301T0iP03o`0000000?l0003o0500003o1Oooool1
0000007ooooo00000`00003oooooooooo`02ooooojd0o`0000?o00000>H06@3V01T00_l000001`2c
04co000009T0I_l00000O`1oo`00001V09T00_l0000203<0c005o`00000I0>H06@3V01T0i_l00000
DP000?l5ooooo`4000000Oooool0000300000?oooooooooo00;ooooo[@3o00002?l00000iP0Io`00
003<03?o00000;<0C?l00000V@1V0_l000001P1V09Wo000004`0/ol00000<`3<o`0000<06@3V00?o
00000000o`000?l0D@000?l5ooooo`4000000Oooool0000300000?oooooooooo00;ooooo[03o0000
0ol00000iP0I0>H06@02o`00000<0;<0C?l00000V@1Vo`00001o07oo000006H0VOl00000C02co`00
000c0<co00000`0I0>H00ol00000003o0000o`1A0000o`Gooooo0@000001ooooo`0000<00000oooo
ooooool00_oooon/0?l00003o`00003V01T0iP0I00;o000000D0/`1<o`00002I06Ko000007l0O`02
o`00000404`0/ol00000<`3<o`0000@06@3V00?o00000000o`000?l0D@000?l5ooooo`4000000Ooo
ool0000300000?oooooooooo00;ooooo[03o00000ol00000iP0I0>H06@02o`0000030;<0C?l00000
V@1V00;o000000H0IP2Io`00001<0;?o000003<0c?l0000401T0iP03o`0000000?l0003o0540003o
1Oooool10000007ooooo00000`00003oooooooooo`02oooooj/0o`0000?o00000>H06@3V01T00_l0
00001`2c04co000009T0I_l00000O`1oo`00001V09T00_l0000203<0c005o`00000I0>H06@3V01T0
i_l00000E0000?l5ooooo`4000000Oooool0000300000?oooooooooo00;oooooZ`3o00000ol00000
iP0I0>H06@02o`0000030;<0C?l00000V@1V00;o000000H0IP2Io`00001<0;?o000003<0c?l00004
01T0iP03o`0000000?l0003o0580003o1Oooool10000007ooooo00000`00003oooooooooo`02oooo
oj/0o`0000So00000>H06Ol00000c00co`00002c04co000009T0IP;o000000H0IP2Io`00001<0;?o
000003<0c?l0000401T0iP03o`0000000?l0003o0580003o1Oooool10000007ooooo00000`00003o
ooooooooo`02ooooojX0o`0000So00000>H06Ol00000c00co`00002c04co000009T0IP;o000000H0
IP2Io`00001<0;?o000003<0c?l0000401T0iP03o`0000000?l0003o05<0003o1Oooool10000007o
oooo00000`00003oooooooooo`02ooooojT0o`0000?o00000>H06@3V01T00_l00000302c04co0000
09T0I_l00000O`1oo`00001V09Wo000004`0/ol00000<`3<o`0000<06@3V00?o00000000o`000?l0
E0000?l5ooooo`4000000Oooool0000300000?oooooooooo00;oooooZ03o00002Ol00000iP0I0>H0
6Ol00000c00co`00002c04co000009T0IP02o`00000606H0VOl00000C02co`00000c0<co0000100I
0>H00ol00000003o0000o`1D0000o`Gooooo0@000001ooooo`0000<00000ooooooooool00_oooonW
0?l0000Bo`00003V01T0iP0Io`00003<03?o00000;<0C?l00000V@1Vo`00001o07oo000006H0VOl0
0000C02co`00000c0<co00000`0I0>H00ol00000003o0000o`1E0000o`Gooooo0@000001ooooo`00
00<00000ooooooooool00_oooonV0?l00004o`00003V01T0iP0Io`000080c00c00co00000;<0C?l0
003o000007l0Ool00000IP2Io`00001<0;?o000003<0c?l0000301T0iP03o`0000000?l0003o05H0
003o1Oooool10000007ooooo00000`00003oooooooooo`02ooooojD0o`0000Co00000>H06@3V01Wo
00000P3<03<02_l00000/`1<o`000?l00000O`1oo`00001V09Wo000004`0/ol0000203<0c005o`00
000I0>H06@3V01T0i_l00000F0000?l5ooooo`4000000Oooool0000300000?oooooooooo00;ooooo
Y03o00001?l00000iP0I0>H06Ol000020<`0<`0=o`00002c04co000009T0I_l00000O`1oo`00001V
09Wo000004`0/ol00000<`3<o`00000301T0iP03o`0000000?l0003o05L0003o1Oooool10000007o
oooo00000`00003oooooooooo`02oooooj<0o`0000Co00000>H06@3V01Wo00000P3<03<02ol00000
/`1<o`00002I06Ko000007l0Ool00000IP2Io`00001<0;?o00000080<`3<00Go000001T0iP0I0>H0
6@3Vo`00001I0000o`Gooooo0@000001ooooo`0000<00000ooooooooool00_oooonR0?l00004o`00
003V01T0iP0Io`000080c00c00Go00000;<0C?l00000V@1Vo`00000207l0O`05o`00001V09Wo0000
04`0/ol000000P0c0<`01?l000006@3V01T0i_l0001J0000o`Gooooo0@000001ooooo`0000<00000
ooooooooool00_oooonP0?l000;o00000P3V01T00ol00000c00co`000003o`00000909T0I_l0003o
000007l0Ool00000IP2Io`00001<0;?o00000080<`3<00Co000001T0iP0I0>Ko0000F`000?l5oooo
o`4000000Oooool0000300000?oooooooooo00;oooooWP3o0002o`0000<0iP0I00Go00000<`0<ol0
0000/`1<o`00000209T0IP08o`00001o07l0O`1oo`00001V09Wo000004`0/ol0000203<0c005o`00
000I0>H06@3V01T0i_l00000F`000?l5ooooo`4000000Oooool0000300000?oooooooooo00;ooooo
W@3o00000ol00000iP0I0>H06@020>H06@05o`00003<03?o00000;<0C?l000000P2I06H02?l00000
O`1oo`000?l00000IP2Io`00001<0;?o00000P0c0<`01Ol000006@3V01T0iP0I0>Ko000005`0003o
1Oooool10000007ooooo00000`00003oooooooooo`02oooooi/0o`000_l000030>H06@;o000000@0
c00co`00002c04co00000P2I06H00ol00000O`1oo`00000206H0V@03o`00001<0;?o00000080<`3<
00Go000001T0iP0I0>H06@3Vo`00001M0000o`Gooooo0@000001ooooo`0000<00000ooooooooool0
0_oooonI0?l000;o0000103V01T01ol00000c00c0<`0<ol00000/`1<o`00002I06H00_l000000`1o
07oo000006H0V@02o`00000504`0/ol00000<`3<03<0c?l000000`0I0>H00ol00000003o0000o`1L
0000o`Gooooo0@000001ooooo`0000<00000ooooooooool00_oooonH0?l00003o`00003V01T0iP0I
0080iP0I0_l000020<`0<`05o`00002c04co000009T0I_l000000P1o07l00ol00000IP2Io`000002
04`0/`04o`00000c0<`0<`3<o`0000<06@3V00?o00000000o`000?l0G@000?l5ooooo`4000000Ooo
ool0000300000?oooooooooo00;oooooUP3o0002o`0000@0iP0I00[o00000<`0<`3<03<0c00co`00
002c04co000009T0I_l00000O`1o0_l000001@1V09Wo000004`0/`1<0;?o00000080<`3<00Go0000
01T0iP0I0>H06@3Vo`00001P0000o`Gooooo0@000001ooooo`0000<00000ooooooooool00_oooonD
0?l000;o0000103V01T2o`0000<0c00c00Oo00000;<0C?l00000V@1Vo`00001o07oo00000080IP2I
00Co000004`0/`1<0;?o00000P0c0<`00ol000006@3V01T0iP0201T0iP03o`0000000?l0003o05h0
003o1Oooool10000007ooooo00000`00003oooooooooo`02oooooi<0o`0000?o00000>H06@3V01T0
0`3V01T00ol00000c00c0<`0<`020<`0<`03o`00002c04`0/`1<00;o000000D0O`1oo`00001V09T0
IP2Io`00000204`0/`04o`00000c0<`0<`3<o`0000@06@3V00?o00000000o`000?l0G`000?l5oooo
o`4000000Oooool0000300000?oooooooooo00;oooooTP3o00000ol00000iP0I0>H06@020>H06@;o
0000103<03<00ol00000/`1<0;<0C002o`00000507l0Ool00000IP2I06H0VOl000000P1<0;<01?l0
0000<`3<03<0c?l0000401T0iP03o`0000000?l0003o0600003o1Oooool10000007ooooo00000`00
003oooooooooo`02oooooi40o`0000?o00000>H06@3V01T00P3V01T00ol00000c00c0<`0<`030<`0
<`05o`00002c04`0/`1<o`00002I06H00_l0000206H0V@04o`00001<0;<0C02co`000080<`3<00?o
000001T0iP0I0>H00P0I0>H00ol00000003o0000o`1Q0000o`Gooooo0@000001ooooo`0000<00000
ooooooooool00_oooon@0?l00003o`00003V01T0iP0I0080iP0I00?o00000<`0<`3<03<00`3<03<0
1Ol00000/`1<0;<0C?l00000V@1V00;o00000P1V09T01?l00000C02c04`0/ol0000203<0c003o`00
000I0>H06@3V00806@3V00?o00000000o`000?l0HP000?l5ooooo`4000000Oooool0000300000?oo
oooooooo00;oooooQ@3o000;o`000080iP0I1?l000020<`0<`?o000000<0/`1<o`000?l000001_l0
0000101<0;?o0000o`00000c0<`2o`0000<06@3V0_l0001U0000o`Gooooo0@000001ooooo`0000<0
0000ooooooooool00_oooomm0?l000So0000203V01T5o`0000030<`0<ol0003o000000?o000000<0
/`1<o`000?l000001ol0000204`0/`04o`00000c0<`0<`3<o`0000<06@3V0_l0001W0000o`Gooooo
0@000001ooooo`0000<00000ooooooooool00_oooomi0?l000Co00002P3V01T6o`000080c00c1?l0
00030;<0C0Oo000000<0IP2Io`000?l000000`1<0;<01?l00000<`3<03<0c?l0000301T0iP03o`00
00000?l0003o06L0003o1Oooool10000007ooooo00000`00003oooooooooo`02ooooogD0o`001?l0
00090>H06@Go00001@3<03<3o`0000<0/`1<2Ol000000`1V09Wo0000o`00000404`0/`04o`00000c
0<co0000o`0000<06@3V00?o00000000o`000?l0J0000?l5ooooo`4000000Oooool0000300000?oo
oooooooo00;ooooo0ol0001^0?l000Co0000203V01T5o`0000D0c00c1Ol000000`2c04co0000o`00
0003o`00000309T0I_l0003o000000Co000000<0IP2Io`000?l00000101<0;<2o`00000303<0c?l0
00006@3V00806@3V0_l0001[0000o`Gooooo0@000001ooooo`0000<00000ooooooooool00_ooool3
0>H06@Co0000IP3o0004o`0000P0iP0I1?l000050<`0<`Go000000<0/`1<o`000?l000000ol00002
09T0IPOo00000P1V09T2o`0000<0C02c0ol0000203<0c005o`00000I0>H06@3V01T0i_l00000K@00
0?l5ooooo`4000000Oooool0000300000?oooooooooo00;ooooo1`3V01T4o`0005l0o`000ol00008
0>H06@Co00001@3<03<4o`000080/`1<1?l0000409T0IPOo00000`1V09T2o`000080C02c0ol00003
03<0c0;o00000P0I0>H2o`0006h0003o1Oooool10000007ooooo00000`00003oooooooooo`02oooo
o`?o0000203V01T4o`0005L0o`001?l000080>H06@?o00001P3<03<3o`0000<0/`1<0ol0000409T0
IPOo0000101V09T3o`00000404`0/ol0003o0000o`0000<0<`3<0ol0000301T0iP03o`0000000?l0
003o06h0003o1Oooool10000007ooooo00000`00003oooooooooo`02ooooo`<0c00c0ol000090>H0
6@Co0000C`3o0004o`0000T0iP0I0ol000060<`0<`?o00000`2c04`3o`0000<0V@1V1?l00000101o
07oo0000o`000?l0000306H0V@So00000`0c0<`3o`0000D06@3V00?o00000000o`000?l0K`000?l5
ooooo`4000000Oooool0000300000?oooooooooo00;ooooo1P3<03<3o`0000X0iP0I0ol000180?l0
00Co00002P3V01T3o`0000H0c00c0ol000030;<0C0?o00000`2I06H3o`000080O`1o0ol0000306H0
V@Oo0000100c0<`3o`0000D06@3V0ol0001b0000o`Gooooo0@000001ooooo`0000<00000oooooooo
ool00_ooool4o`0000D0c00c0ol0000:0>H06@So0000>@3o0007o`0000/0iP0I0ol000060<`0<`?o
00000`2c04`3o`0000<0V@1V0ol0000207l0O`?o00000P1V09T7o`0000<0<`3<1Ol0000401T0iPCo
0000M@000?l5ooooo`4000000Oooool0000300000?oooooooooo00;ooooo102c04`6o`000080c00c
1ol0000;0>H06CWo00002P3V01T8o`0000@0c00c1Ol000030;<0C0?o00000P2I06H4o`000080O`1o
0ol000000`1V09Wo0000o`000002o`00000404`0/ol0003o0000o`000080<`3<1?l0000501T0iPCo
0000N@000?l5ooooo`4000000Oooool0000300000?oooooooooo00;ooooo1?l000060;<0C5Oo0000
00<0c00co`000?l000002Ol000030;<0C0[o00000`1o07l3o`000080IP2I0_l0000304`0/`;o0000
0`0c0<`2o`0000H06@3V0ol0001m0000o`Gooooo0@000001ooooo`0000<00000ooooooooool00_oo
ool:o`0000T0/`1<5ol0000Q0<`0<aOo00002@2c04`:o`0000@0O`1o1?l0000306H0V@;o00000P1<
0;<3o`0000@0<`3<00?o000001T0iP0I0>H0100I0>H2o`000800003o1Oooool10000007ooooo0000
0`00003oooooooooo`02ooooo`@0O`1o6_l0000<0;<0C27o0000302c04`Io`0000D0O`1o1?l00003
06H0V@Co00000P1<0;<2o`0000D0<`3<0_l0000501T0iP;o0000PP000?l5ooooo`4000000Oooool0
000300000?oooooooooo00;ooooo1ol0000307l0Of7o00000`1o07l7o`00000306H0VOl0003o0000
00Co0000101<0;<2o`0000@0<`3<0ol0000601T0iP03o`0000000?l0003o0880003o1Oooool10000
007ooooo00000`00003oooooooooo`02oooooa?o00002`1o07lio`0000/0O`1o5?l0000604`0/`Co
00000`0c0<`3o`0000L06@3V0_l000250000o`Gooooo0@000001ooooo`0000<00000ooooooooool0
0_ooool704`0/fOo0000201<0;<6o`0000@0<`3<0ol0000801T0iP;o0000Q`000?l5ooooo`400000
0Oooool0000300000?oooooooooo00;ooooo1ol0000<04`0/doo0000301<0;<8o`0000H0<`3<1?l0
000801T0iP?o0000R@000?l5ooooo`4000000Oooool0000300000?oooooooooo00;oooooK_l00008
03<0c0Ko0000200I0>H4o`0008`0003o1Oooool10000007ooooo00000`00003oooooooooo`02oooo
o`L06@3VKol0000;01T0iP?o0000T0000?l5ooooo`4000000Oooool0000300000?oooooooooo00;o
oooo:_l0000h01T0iQoo0000T`000?l5ooooo`4000000Oooool0000300000?oooooooooo00;ooooo
:P000?lho`000;80003o1Oooool10000007ooooo00000`00003oooooooooo`02ooooool0003o5@00
0?l5ooooo`4000000Oooool0000300000?oooooooooo00;oooooo`000?lE0000o`Gooooo0@000001
ooooo`0000<00000ooooooooool00_oooooo0000oaD0003o1Oooool10000007ooooo00000`00003o
ooooooooo`02ooooool0003o5@000?l5ooooo`4000000Oooool0000300000?oooooooooo00;ooooo
o`000?lE0000o`Gooooo0@000001ooooo`0000<00000ooooooooool00_oooooo0000oaD0003o1Ooo
ool10000007ooooo00000`00003oooooooooo`02ooooool0003o5@000?l5ooooo`4000000Oooool0
000300000?oooooooooo00;oooooo`000?lE0000o`Gooooo0@000001ooooo`0000<00000oooooooo
ool00_oooooo0000oaD0003o1Oooool10000007ooooo00000`00003oooooooooo`02ooooool0003o
5@000?l5ooooo`4000000Oooool0000300000?oooooooooo00;oooooo`000?lE0000o`Gooooo0@00
0001ooooo`0000<00000ooooooooool00_oooooo0000oaD0003o1Oooool10000007ooooo00000`00
003oooooooooo`02ooooool0003o5@000?l5ooooo`4000000Oooool0000300000?oooooooooo00;o
ooooo`000?lE0000o`Gooooo0@000001ooooo`0000<00000ooooooooool00_oooooo0000oaD0003o
1Oooool10000007ooooo00000`00003oooooooooo`02ooooool0003o5@000?l5ooooo`4000000Ooo
ool0000300000?oooooooooo00;oooooo`000?lE0000o`Gooooo0@000001ooooo`0000<00000oooo
ooooool00_oooooo0000oaD0003o1Oooool10000007ooooo00000`00003oooooooooo`02ooooool0
003o5@000?l5ooooo`4000000Oooool0000300000?oooooooooo00;oooooo`000?lE0000o`Gooooo
0@000001ooooo`0000<00000ooooooooool00_oooooo0000oaD0003o1Oooool10000007ooooo0000
0`00003oooooooooo`02ooooool0003o5@000?l5ooooo`4000000Oooool0000300000?oooooooooo
00;oooooo`000?lE0000o`Gooooo0@000001ooooo`0000<00000ooooooooool00_oooooo0000oaD0
003o1Oooool10000007ooooo00000`00003oooooooooo`02ooooool0003o5@000?l5ooooo`400000
0Oooool0000300000?oooooooooo00;oooooo`000?lE0000o`Gooooo0@000001ooooo`0000<00000
ooooooooool00_oooooo0000oaD0003o1Oooool10000007ooooo00000`00003oooooooooo`02oooo
ool0003o5@000?l5ooooo`4000000Oooool0000300000?oooooooooo00;oooooo`000?lE0000o`Go
oooo0@000001ooooo`0000<00000ooooooooool00_oooooo0000oaD0003o1Oooool10000007ooooo
00000`00003oooooooooo`02ooooool0003o5@000?l5ooooo`4000000Oooool0000300000?oooooo
oooo00;oooooo`000?lE0000o`Gooooo0@000001ooooo`0000<00000ooooooooool00_oooooo0000
oaD0003o1Oooool10000007ooooo00000`00003oooooooooo`02ooooool0003o5@000?l5ooooo`40
00000Oooool0000300000?oooooooooo00;oooooo`000?lE0000o`Gooooo0@000001ooooo`0000<0
0000ooooooooool00_oooooo0000oaD0003o1Oooool10000007ooooo00000`00003oooooooooo`02
ooooool0003o5@000?l5ooooo`4000000Oooool0000300000?oooooooooo00;oooooo`000?lE0000
o`Gooooo0@000001ooooo`0000<00000ooooooooool00_oooooo0000oaD0003o1Oooool10000007o
oooo00000`00003oooooooooo`02ooooool0003o5@000?l5ooooo`4000000Oooool0000300000?oo
oooooooo00;oooooo`000?lE0000o`Gooooo0@000001ooooo`0000<00000ooooooooool00_oooooo
0000oaD0003o1Oooool10000007ooooo00000`00003oooooooooo`02ooooool0003o5@000?l5oooo
o`4000000Oooool0000300000?oooooooooo00;oooooo`000?lE0000o`Gooooo0@000001ooooo`00
00<00000ooooooooool00_oooooo0000oaD0003o1Oooool10000007ooooo00000`00003ooooooooo
o`02ooooool0003o5@000?l5ooooo`4000000Oooool0000300000?oooooooooo00;oooooo`000?lE
0000o`Gooooo0@000001ooooo`0000<00000ooooooooool00_oooooo0000oaD0003o1Oooool10000
007ooooo00000`00003oooooooooo`02ooooool0003o5@000?l5ooooo`4000000Oooool000030000
0?oooooooooo00;oooooo`000?lE0000o`Gooooo0@000001ooooo`0000<00000ooooooooool00_oo
oooo0000oaD0003o1Oooool10000007ooooo00000`00003oooooooooo`02ooooool0003o5@000?l5
ooooo`4000000Oooool0000300000?oooooooooo00;oooooo`000?lE0000o`Gooooo0@000001oooo
o`0000<00000ooooooooool00_oooooo0000oaD0003o1Oooool10000007ooooo00000`00003ooooo
ooooo`02ooooool0003o5@000?l5ooooo`4000000Oooool0000300000?oooooooooo00;oooooo`00
0?lE0000o`Gooooo0@000001ooooo`0000<00000ooooooooool00_oooooo0000oaD0003o1Oooool1
0000007ooooo00000`00003oooooooooo`02ooooool0003o5@000?l5ooooo`4000000Oooool00003
00000?oooooooooo00;oooooo`000?lE0000o`Gooooo0@000001ooooo`0000<00000ooooooooool0
0_oooooo0000oaD0003o1Oooool10000007ooooo00000`00003oooooooooo`02ooooool0003o5@00
0?l5ooooo`4000000Oooool0000300000?oooooooooo00;oooooo`000?lE0000o`Gooooo0@000001
ooooo`0000<00000ooooooooool00_oooooo0000oaD0003o1Oooool10000007ooooo00000`00003o
ooooooooo`02ooooool0003o5@000?l5ooooo`4000000Oooool0000300000?oooooooooo00;ooooo
o`000?lE0000o`Gooooo0@000001ooooo`0000<00000ooooooooool00_oooooo0000oaD0003o1Ooo
ool10000007ooooo00000`00003oooooooooo`02ooooool0003o5@000?l5ooooo`4000000Oooool0
000300000?oooooooooo00;oooooo`000?lE0000o`Gooooo0@000001ooooo`0000<00000oooooooo
ool00_oooooo0000oaD0003o1Oooool10000007ooooo00000`00003oooooooooo`02ooooool0003o
5@000?l5ooooo`4000000Oooool0000300000?oooooooooo00;oooooo`000?lE0000o`Gooooo0@00
0001ooooo`0000<00000ooooooooool00_oooooo0000oaD0003o1Oooool10000007ooooo00000`00
003oooooooooo`02ooooool0003o5@000?l5ooooo`4000000Oooool0000300000?oooooooooo00;o
ooooo`000?lE0000o`Gooooo0@000001ooooo`0000<00000ooooooooool00_oooooo0000oaD0003o
1Oooool10000007ooooo00000`00003oooooooooo`02ooooool0003o5@000?l5ooooo`4000000Ooo
ool0000300000?oooooooooo00;oooooo`000?lE0000o`Gooooo0@000001ooooo`0000<00000oooo
ooooool00_oooooo0000oaD0003o1Oooool10000007ooooo00000`00003oooooooooo`02ooooool0
003o5@000?l5ooooo`4000000Oooool0000300000?oooooooooo00;oooooo`000?lE0000o`Gooooo
0@000001ooooo`0000<00000ooooooooool00_oooooo0000oaD0003o1Oooool10000007ooooo0000
0`00003oooooooooo`02ooooool0003o5@000?l5ooooo`4000000Oooool0000300000?oooooooooo
00;oooooo`000?lE0000o`Gooooo0@000001ooooo`0000<00000ooooooooool00_oooooo0000oaD0
003o1Oooool10000007ooooo00000`00003oooooooooo`02ooooool0003o5@000?l5ooooo`400000
0Oooool0000300000?oooooooooo00;oooooo`000?lE0000o`Gooooo0@000001ooooo`0000<00000
ooooooooool00_oooooo0000oaD0003o1Oooool10000007ooooo00000`00003oooooooooo`02oooo
ool0003o5@000?l5ooooo`4000000Oooool0000300000?oooooooooo00;oooooo`000?lE0000o`Go
oooo0@000001ooooo`0000<00000ooooooooool00_oooooo0000oaD0003o1Oooool10000007ooooo
00000`00003oooooooooo`02ooooool0003o5@000?l5ooooo`4000000Oooool0000300000?oooooo
oooo00;oooooo`000?lE0000o`Gooooo0@000001ooooo`0000<00000ooooooooool00_oooooo0000
oaD0003o1Oooool10000007ooooo00000`00003oooooooooo`02ooooool0003o5@000?l5ooooo`40
00000Oooool0000300000?oooooooooo00;oooooo`000?lE0000o`Gooooo0@000001ooooo`0000<0
0000ooooooooool00_oooooo0000oaD0003o1Oooool10000007ooooo00000`00003oooooooooo`02
ooooool0003o5@000?l5ooooo`4000000Oooool0000300000?oooooooooo00;oooooo`000?lE0000
o`Gooooo0@000001ooooo`0000<00000ooooooooool00_oooooo0000oaD0003o1Oooool10000007o
oooo00000`00003oooooooooo`02ooooool0003o5@000?l5ooooo`4000000Oooool0000300000?oo
oooooooo00;oooooo`000?lE0000o`Gooooo0@000001ooooo`0000<00000ooooooooool00_oooooo
0000oaD0003o1Oooool10000007ooooo00000`00003oooooooooo`02ooooool0003o5@000?l5oooo
o`4000000Oooool0000300000?oooooooooo00;oooooo`000?lE0000o`Gooooo0@000001ooooo`00
00<00000ooooooooool00_oooooo0000oaD0003o1Oooool10000007ooooo00000`00003ooooooooo
o`02ooooool0003o5@000?l5ooooo`4000000Oooool0000300000?oooooooooo00;oooooo`000?lE
0000o`Gooooo0@000001ooooo`0000<00000ooooooooool00_oooooo0000oaD0003o1Oooool10000
007ooooo00000`00003oooooooooo`02ooooool0003o5@000?l5ooooo`4000000Oooool000030000
0?oooooooooo00;oooooo`000?lE0000o`Gooooo0@000001ooooo`0000<00000ooooooooool00_oo
oooo0000oaD0003o1Oooool10000007ooooo00000`00003oooooooooo`02ooooool0003o5@000?l5
ooooo`4000000Oooool0000300000?oooooooooo00;oooooo`000?lE0000o`Gooooo0@000001oooo
o`0000<00000ooooooooool00_oooooo0000oaD0003o1Oooool10000007ooooo00000`00003ooooo
ooooo`02ooooool0003o5@000?l5ooooo`4000000Oooool0000300000?oooooooooo00;oooooo`00
0?lE0000o`Gooooo0@000001ooooo`0000<00000ooooooooool00_oooooo0000oaD0003o1Oooool1
0000007ooooo00000`00003oooooooooo`02ooooool0003o5@000?l5ooooo`4000000Oooool00003
00000?oooooooooo00;oooooo`000?lE0000o`Gooooo0@000001ooooo`0000<00000ooooooooool0
0_oooooo0000oaD0003o1Oooool10000007ooooo00000`00003oooooooooo`02ooooool0003o5@00
0?l5ooooo`4000000Oooool0000300000?oooooooooo00;oooooo`000?lE0000o`Gooooo0@000001
ooooo`0000<00000ooooooooool00_oooooo0000oaD0003o1Oooool10000007ooooo00000`00003o
ooooooooo`02ooooool0003o5@000?l5ooooo`4000000Oooool0000300000?oooooooooo00;ooooo
o`000?lE0000o`Gooooo0@000001ooooo`0000<00000ooooooooool00_oooooo0000oaD0003o1Ooo
ool10000007ooooo00000`00003oooooooooo`02ooooool0003o5@000?l5ooooo`4000000Oooool0
000300000?oooooooooo0?oooooo7?ooool10000007ooooo00000`00003oooooooooo`3ooooooaco
oooo0@000001ooooo`0000<00000ooooooooool0oooooolLooooo`4000000Oooool0000300000?oo
oooooooo0?oooooo7?ooool10000007ooooo003o0000020000000Oooool00001\
\>"],
  ImageRangeCache->{{{0, 287}, {287, 0}} -> {-1.04092, -1.04092, 0.00725378, \
0.00725378}}]
}, Closed]]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}, Closed]]
},
FrontEndVersion->"5.0 for Macintosh",
ScreenRectangle->{{0, 800}, {0, 574}},
WindowSize->{656, 717},
WindowMargins->{{81, Automatic}, {Automatic, 2}},
ShowSelection->True,
CellLabelAutoDelete->True,
StyleDefinitions -> "Classroom.nb"
]

(*******************************************************************
Cached data follows.  If you edit this Notebook file directly, not
using Mathematica, you must remove the line containing CacheID at
the top of  the file.  The cache data will then be recreated when
you save this file from within Mathematica.
*******************************************************************)

(*CellTagsOutline
CellTagsIndex->{}
*)

(*CellTagsIndex
CellTagsIndex->{}
*)

(*NotebookFileOutline
Notebook[{
Cell[1754, 51, 47, 0, 62, "Title"],
Cell[1804, 53, 129, 3, 28, "Text"],

Cell[CellGroupData[{
Cell[1958, 60, 36, 0, 59, "Section"],

Cell[CellGroupData[{
Cell[2019, 64, 60, 0, 49, "Subsection"],
Cell[2082, 66, 1439, 24, 303, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[3558, 95, 144, 5, 49, "Subsection"],
Cell[3705, 102, 77, 1, 47, "Input"],
Cell[3785, 105, 1040, 18, 223, "Input"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{
Cell[4874, 129, 63, 0, 39, "Section"],

Cell[CellGroupData[{
Cell[4962, 133, 37, 0, 49, "Subsection"],

Cell[CellGroupData[{
Cell[5024, 137, 36, 0, 42, "Subsubsection"],
Cell[5063, 139, 236, 6, 75, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[5336, 150, 36, 0, 42, "Subsubsection"],
Cell[5375, 152, 234, 5, 75, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[5646, 162, 36, 0, 42, "Subsubsection"],
Cell[5685, 164, 73, 1, 27, "Input"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{
Cell[5807, 171, 37, 0, 33, "Subsection"],
Cell[5847, 173, 346, 8, 95, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[6230, 186, 35, 0, 33, "Subsection"],

Cell[CellGroupData[{
Cell[6290, 190, 39, 0, 43, "Subsubsection"],
Cell[6332, 192, 147, 2, 43, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[6516, 199, 39, 0, 35, "Subsubsection"],

Cell[CellGroupData[{
Cell[6580, 203, 126, 3, 47, "Input"],
Cell[6709, 208, 18820, 331, 296, 1858, 117, "GraphicsData", "PostScript", \
"Graphics"]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{
Cell[25602, 547, 31, 0, 39, "Section"],

Cell[CellGroupData[{
Cell[25658, 551, 45, 0, 49, "Subsection"],
Cell[25706, 553, 130, 2, 43, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[25873, 560, 43, 0, 33, "Subsection"],

Cell[CellGroupData[{
Cell[25941, 564, 82, 1, 27, "Input"],
Cell[26026, 567, 53, 1, 70, "Output"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{
Cell[26128, 574, 43, 0, 33, "Subsection"],

Cell[CellGroupData[{
Cell[26196, 578, 38, 0, 43, "Subsubsection"],

Cell[CellGroupData[{
Cell[26259, 582, 74, 1, 47, "Input"],
Cell[26336, 585, 359252, 8855, 408, 229726, 7253, "GraphicsData", \
"PostScript", "Graphics"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[385637, 9446, 36, 0, 43, "Subsubsection"],

Cell[CellGroupData[{
Cell[385698, 9450, 76, 1, 47, "Input"],
Cell[385777, 9453, 314263, 7620, 408, 215978, 6403, "GraphicsData", \
"PostScript", "Graphics"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[700089, 17079, 108, 3, 43, "Subsubsection"],

Cell[CellGroupData[{
Cell[700222, 17086, 63, 1, 47, "Input"],
Cell[700288, 17089, 42404, 941, 186, 5786, 484, "GraphicsData", "PostScript", \
"Graphics"]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[742753, 18037, 34, 0, 49, "Subsection"],
Cell[742790, 18039, 48, 1, 47, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[742875, 18045, 31, 0, 33, "Subsection"],

Cell[CellGroupData[{
Cell[742931, 18049, 80, 1, 47, "Input"],

Cell[CellGroupData[{
Cell[743036, 18054, 359265, 8856, 408, 229726, 7253, "GraphicsData", \
"PostScript", "Graphics"],
Cell[1102304, 26912, 364218, 9181, 408, 234971, 7582, "GraphicsData", \
"PostScript", "Graphics"],
Cell[1466525, 36095, 367803, 9397, 408, 238321, 7795, "GraphicsData", \
"PostScript", "Graphics"],
Cell[1834331, 45494, 342844, 8554, 408, 227898, 7132, "GraphicsData", \
"PostScript", "Graphics"],
Cell[2177178, 54050, 316554, 7675, 408, 216803, 6440, "GraphicsData", \
"PostScript", "Graphics"],
Cell[2493735, 61727, 314259, 7617, 408, 216072, 6402, "GraphicsData", \
"PostScript", "Graphics"],
Cell[2807997, 69346, 314263, 7620, 408, 215978, 6403, "GraphicsData", \
"PostScript", "Graphics"]
}, Closed]]
}, Open  ]]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{
Cell[3122333, 76974, 44, 0, 39, "Section"],

Cell[CellGroupData[{
Cell[3122402, 76978, 27, 0, 49, "Subsection"],

Cell[CellGroupData[{
Cell[3122454, 76982, 47, 0, 43, "Subsubsection"],
Cell[3122504, 76984, 119, 3, 43, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[3122660, 76992, 62, 1, 35, "Subsubsection"],
Cell[3122725, 76995, 114, 3, 43, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[3122876, 77003, 59, 0, 35, "Subsubsection"],
Cell[3122938, 77005, 189, 4, 43, "Input"]
}, Closed]]
}, Open  ]],

Cell[CellGroupData[{
Cell[3123176, 77015, 144, 5, 49, "Subsection"],

Cell[CellGroupData[{
Cell[3123345, 77024, 54, 0, 43, "Subsubsection"],

Cell[CellGroupData[{
Cell[3123424, 77028, 113, 2, 47, "Input"],
Cell[3123540, 77032, 32144, 621, 296, 4118, 270, "GraphicsData", \
"PostScript", "Graphics"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[3155733, 77659, 170, 5, 43, "Subsubsection"],

Cell[CellGroupData[{
Cell[3155928, 77668, 130, 2, 47, "Input"],

Cell[CellGroupData[{
Cell[3156083, 77674, 32145, 621, 296, 4118, 270, "GraphicsData", \
"PostScript", "Graphics"],
Cell[3188231, 78297, 4240, 274, 296, 4121, 270, "GraphicsData", "PostScript", \
"Graphics",
  ImageCacheValid->False],
Cell[3192474, 78573, 4240, 274, 296, 4121, 270, "GraphicsData", "PostScript", \
"Graphics",
  ImageCacheValid->False],
Cell[3196717, 78849, 4240, 274, 296, 4121, 270, "GraphicsData", "PostScript", \
"Graphics",
  ImageCacheValid->False],
Cell[3200960, 79125, 4240, 274, 296, 4121, 270, "GraphicsData", "PostScript", \
"Graphics",
  ImageCacheValid->False],
Cell[3205203, 79401, 4240, 274, 296, 4121, 270, "GraphicsData", "PostScript", \
"Graphics",
  ImageCacheValid->False],
Cell[3209446, 79677, 4240, 274, 296, 4121, 270, "GraphicsData", "PostScript", \
"Graphics",
  ImageCacheValid->False],
Cell[3213689, 79953, 4235, 274, 296, 4116, 270, "GraphicsData", "PostScript", \
"Graphics",
  ImageCacheValid->False],
Cell[3217927, 80229, 4240, 274, 296, 4121, 270, "GraphicsData", "PostScript", \
"Graphics",
  ImageCacheValid->False],
Cell[3222170, 80505, 4238, 274, 296, 4119, 270, "GraphicsData", "PostScript", \
"Graphics",
  ImageCacheValid->False],
Cell[3226411, 80781, 4240, 274, 296, 4121, 270, "GraphicsData", "PostScript", \
"Graphics",
  ImageCacheValid->False],
Cell[3230654, 81057, 4238, 274, 296, 4119, 270, "GraphicsData", "PostScript", \
"Graphics",
  ImageCacheValid->False],
Cell[3234895, 81333, 4239, 274, 296, 4120, 270, "GraphicsData", "PostScript", \
"Graphics",
  ImageCacheValid->False],
Cell[3239137, 81609, 4240, 274, 296, 4121, 270, "GraphicsData", "PostScript", \
"Graphics",
  ImageCacheValid->False],
Cell[3243380, 81885, 4240, 274, 296, 4121, 270, "GraphicsData", "PostScript", \
"Graphics",
  ImageCacheValid->False],
Cell[3247623, 82161, 4240, 274, 296, 4121, 270, "GraphicsData", "PostScript", \
"Graphics",
  ImageCacheValid->False],
Cell[3251866, 82437, 4240, 274, 296, 4121, 270, "GraphicsData", "PostScript", \
"Graphics",
  ImageCacheValid->False],
Cell[3256109, 82713, 4240, 274, 296, 4121, 270, "GraphicsData", "PostScript", \
"Graphics",
  ImageCacheValid->False],
Cell[3260352, 82989, 4240, 274, 296, 4121, 270, "GraphicsData", "PostScript", \
"Graphics",
  ImageCacheValid->False],
Cell[3264595, 83265, 4238, 274, 296, 4119, 270, "GraphicsData", "PostScript", \
"Graphics",
  ImageCacheValid->False],
Cell[3268836, 83541, 4240, 274, 296, 4121, 270, "GraphicsData", "PostScript", \
"Graphics",
  ImageCacheValid->False],
Cell[3273079, 83817, 4238, 274, 296, 4119, 270, "GraphicsData", "PostScript", \
"Graphics",
  ImageCacheValid->False],
Cell[3277320, 84093, 4240, 274, 296, 4121, 270, "GraphicsData", "PostScript", \
"Graphics",
  ImageCacheValid->False],
Cell[3281563, 84369, 4237, 274, 296, 4118, 270, "GraphicsData", "PostScript", \
"Graphics",
  ImageCacheValid->False],
Cell[3285803, 84645, 4240, 274, 296, 4121, 270, "GraphicsData", "PostScript", \
"Graphics",
  ImageCacheValid->False],
Cell[3290046, 84921, 4236, 274, 296, 4117, 270, "GraphicsData", "PostScript", \
"Graphics",
  ImageCacheValid->False],
Cell[3294285, 85197, 4240, 274, 296, 4121, 270, "GraphicsData", "PostScript", \
"Graphics",
  ImageCacheValid->False],
Cell[3298528, 85473, 4240, 274, 296, 4121, 270, "GraphicsData", "PostScript", \
"Graphics",
  ImageCacheValid->False],
Cell[3302771, 85749, 4236, 274, 296, 4117, 270, "GraphicsData", "PostScript", \
"Graphics",
  ImageCacheValid->False],
Cell[3307010, 86025, 4240, 274, 296, 4121, 270, "GraphicsData", "PostScript", \
"Graphics",
  ImageCacheValid->False],
Cell[3311253, 86301, 4238, 274, 296, 4119, 270, "GraphicsData", "PostScript", \
"Graphics",
  ImageCacheValid->False],
Cell[3315494, 86577, 4240, 274, 296, 4121, 270, "GraphicsData", "PostScript", \
"Graphics",
  ImageCacheValid->False],
Cell[3319737, 86853, 4240, 274, 296, 4121, 270, "GraphicsData", "PostScript", \
"Graphics",
  ImageCacheValid->False],
Cell[3323980, 87129, 4240, 274, 296, 4121, 270, "GraphicsData", "PostScript", \
"Graphics",
  ImageCacheValid->False],
Cell[3328223, 87405, 4240, 274, 296, 4121, 270, "GraphicsData", "PostScript", \
"Graphics",
  ImageCacheValid->False],
Cell[3332466, 87681, 4240, 274, 296, 4121, 270, "GraphicsData", "PostScript", \
"Graphics",
  ImageCacheValid->False],
Cell[3336709, 87957, 4239, 274, 296, 4120, 270, "GraphicsData", "PostScript", \
"Graphics",
  ImageCacheValid->False],
Cell[3340951, 88233, 4240, 274, 296, 4121, 270, "GraphicsData", "PostScript", \
"Graphics",
  ImageCacheValid->False],
Cell[3345194, 88509, 4238, 274, 296, 4119, 270, "GraphicsData", "PostScript", \
"Graphics",
  ImageCacheValid->False],
Cell[3349435, 88785, 4240, 274, 296, 4121, 270, "GraphicsData", "PostScript", \
"Graphics",
  ImageCacheValid->False],
Cell[3353678, 89061, 4238, 274, 296, 4119, 270, "GraphicsData", "PostScript", \
"Graphics",
  ImageCacheValid->False],
Cell[3357919, 89337, 32116, 620, 296, 4118, 270, "GraphicsData", \
"PostScript", "Graphics"],
Cell[3390038, 89959, 32111, 620, 296, 4121, 270, "GraphicsData", \
"PostScript", "Graphics"],
Cell[3422152, 90581, 32160, 621, 296, 4121, 270, "GraphicsData", \
"PostScript", "Graphics"],
Cell[3454315, 91204, 32138, 621, 296, 4119, 270, "GraphicsData", \
"PostScript", "Graphics"],
Cell[3486456, 91827, 32127, 620, 296, 4121, 270, "GraphicsData", \
"PostScript", "Graphics"],
Cell[3518586, 92449, 32152, 621, 296, 4121, 270, "GraphicsData", \
"PostScript", "Graphics"],
Cell[3550741, 93072, 32148, 621, 296, 4121, 270, "GraphicsData", \
"PostScript", "Graphics"],
Cell[3582892, 93695, 32158, 621, 296, 4119, 270, "GraphicsData", \
"PostScript", "Graphics"],
Cell[3615053, 94318, 32148, 621, 296, 4121, 270, "GraphicsData", \
"PostScript", "Graphics"],
Cell[3647204, 94941, 32180, 621, 296, 4121, 270, "GraphicsData", \
"PostScript", "Graphics"],
Cell[3679387, 95564, 32152, 621, 296, 4121, 270, "GraphicsData", \
"PostScript", "Graphics"],
Cell[3711542, 96187, 32160, 621, 296, 4121, 270, "GraphicsData", \
"PostScript", "Graphics"],
Cell[3743705, 96810, 32146, 621, 296, 4119, 270, "GraphicsData", \
"PostScript", "Graphics"],
Cell[3775854, 97433, 32152, 621, 296, 4121, 270, "GraphicsData", \
"PostScript", "Graphics"],
Cell[3808009, 98056, 32188, 621, 296, 4121, 270, "GraphicsData", \
"PostScript", "Graphics"],
Cell[3840200, 98679, 32146, 621, 296, 4119, 270, "GraphicsData", \
"PostScript", "Graphics"],
Cell[3872349, 99302, 32160, 621, 296, 4121, 270, "GraphicsData", \
"PostScript", "Graphics"],
Cell[3904512, 99925, 32170, 621, 296, 4119, 270, "GraphicsData", \
"PostScript", "Graphics"],
Cell[3936685, 100548, 32160, 621, 296, 4121, 270, "GraphicsData", \
"PostScript", "Graphics"]
}, Closed]]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[3968918, 101177, 42, 0, 49, "Subsection"],

Cell[CellGroupData[{
Cell[3968985, 101181, 36, 0, 43, "Subsubsection"],
Cell[3969024, 101183, 137, 2, 27, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[3969198, 101190, 38, 0, 35, "Subsubsection"],

Cell[CellGroupData[{
Cell[3969261, 101194, 319, 5, 111, "Input"],
Cell[3969583, 101201, 70990, 1451, 296, 10304, 697, "GraphicsData", \
"PostScript", "Graphics"]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{
Cell[4040646, 102660, 44, 0, 39, "Section"],

Cell[CellGroupData[{
Cell[4040715, 102664, 27, 0, 49, "Subsection"],

Cell[CellGroupData[{
Cell[4040767, 102668, 47, 0, 43, "Subsubsection"],
Cell[4040817, 102670, 122, 3, 47, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[4040976, 102678, 62, 1, 43, "Subsubsection"],
Cell[4041041, 102681, 114, 3, 43, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[4041192, 102689, 59, 0, 35, "Subsubsection"],
Cell[4041254, 102691, 189, 4, 63, "Input"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{
Cell[4041492, 102701, 144, 5, 33, "Subsection"],

Cell[CellGroupData[{
Cell[4041661, 102710, 54, 0, 43, "Subsubsection"],

Cell[CellGroupData[{
Cell[4041740, 102714, 116, 2, 47, "Input"],
Cell[4041859, 102718, 24381, 468, 296, 3038, 200, "GraphicsData", \
"PostScript", "Graphics"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[4066289, 103192, 170, 5, 43, "Subsubsection"],

Cell[CellGroupData[{
Cell[4066484, 103201, 133, 2, 47, "Input"],

Cell[CellGroupData[{
Cell[4066642, 103207, 24382, 468, 296, 3038, 200, "GraphicsData", \
"PostScript", "Graphics"],
Cell[4091027, 103677, 24355, 468, 296, 3039, 200, "GraphicsData", \
"PostScript", "Graphics"],
Cell[4115385, 104147, 24407, 468, 296, 3039, 200, "GraphicsData", \
"PostScript", "Graphics"],
Cell[4139795, 104617, 24189, 466, 296, 3039, 200, "GraphicsData", \
"PostScript", "Graphics"],
Cell[4163987, 105085, 24225, 466, 296, 3039, 200, "GraphicsData", \
"PostScript", "Graphics"],
Cell[4188215, 105553, 24359, 468, 296, 3039, 200, "GraphicsData", \
"PostScript", "Graphics"],
Cell[4212577, 106023, 24379, 468, 296, 3039, 200, "GraphicsData", \
"PostScript", "Graphics"],
Cell[4236959, 106493, 24406, 468, 296, 3038, 200, "GraphicsData", \
"PostScript", "Graphics"],
Cell[4261368, 106963, 24379, 468, 296, 3039, 200, "GraphicsData", \
"PostScript", "Graphics"],
Cell[4285750, 107433, 24458, 469, 296, 3037, 200, "GraphicsData", \
"PostScript", "Graphics"],
Cell[4310211, 107904, 24318, 467, 296, 3039, 200, "GraphicsData", \
"PostScript", "Graphics"],
Cell[4334532, 108373, 24407, 468, 296, 3039, 200, "GraphicsData", \
"PostScript", "Graphics"],
Cell[4358942, 108843, 24313, 467, 296, 3038, 200, "GraphicsData", \
"PostScript", "Graphics"],
Cell[4383258, 109312, 24355, 468, 296, 3039, 200, "GraphicsData", \
"PostScript", "Graphics"],
Cell[4407616, 109782, 24278, 467, 296, 3039, 200, "GraphicsData", \
"PostScript", "Graphics"],
Cell[4431897, 110251, 24359, 468, 296, 3039, 200, "GraphicsData", \
"PostScript", "Graphics"],
Cell[4456259, 110721, 24233, 466, 296, 3039, 200, "GraphicsData", \
"PostScript", "Graphics"],
Cell[4480495, 111189, 24387, 468, 296, 3039, 200, "GraphicsData", \
"PostScript", "Graphics"],
Cell[4504885, 111659, 24379, 468, 296, 3039, 200, "GraphicsData", \
"PostScript", "Graphics"],
Cell[4529267, 112129, 24330, 467, 296, 3039, 200, "GraphicsData", \
"PostScript", "Graphics"],
Cell[4553600, 112598, 24205, 466, 296, 3039, 200, "GraphicsData", \
"PostScript", "Graphics"],
Cell[4577808, 113066, 24411, 468, 296, 3039, 200, "GraphicsData", \
"PostScript", "Graphics"],
Cell[4602222, 113536, 24407, 468, 296, 3039, 200, "GraphicsData", \
"PostScript", "Graphics"],
Cell[4626632, 114006, 24374, 468, 296, 3038, 200, "GraphicsData", \
"PostScript", "Graphics"],
Cell[4651009, 114476, 24407, 468, 296, 3039, 200, "GraphicsData", \
"PostScript", "Graphics"],
Cell[4675419, 114946, 24395, 468, 296, 3039, 200, "GraphicsData", \
"PostScript", "Graphics"],
Cell[4699817, 115416, 24379, 468, 296, 3039, 200, "GraphicsData", \
"PostScript", "Graphics"],
Cell[4724199, 115886, 24407, 468, 296, 3039, 200, "GraphicsData", \
"PostScript", "Graphics"],
Cell[4748609, 116356, 24407, 468, 296, 3039, 200, "GraphicsData", \
"PostScript", "Graphics"],
Cell[4773019, 116826, 24407, 468, 296, 3039, 200, "GraphicsData", \
"PostScript", "Graphics"],
Cell[4797429, 117296, 24359, 468, 296, 3039, 200, "GraphicsData", \
"PostScript", "Graphics"],
Cell[4821791, 117766, 24407, 468, 296, 3039, 200, "GraphicsData", \
"PostScript", "Graphics"],
Cell[4846201, 118236, 24407, 468, 296, 3039, 200, "GraphicsData", \
"PostScript", "Graphics"],
Cell[4870611, 118706, 24399, 468, 296, 3039, 200, "GraphicsData", \
"PostScript", "Graphics"],
Cell[4895013, 119176, 24395, 468, 296, 3039, 200, "GraphicsData", \
"PostScript", "Graphics"],
Cell[4919411, 119646, 24278, 467, 296, 3039, 200, "GraphicsData", \
"PostScript", "Graphics"],
Cell[4943692, 120115, 24394, 468, 296, 3038, 200, "GraphicsData", \
"PostScript", "Graphics"],
Cell[4968089, 120585, 24399, 468, 296, 3039, 200, "GraphicsData", \
"PostScript", "Graphics"],
Cell[4992491, 121055, 24387, 468, 296, 3039, 200, "GraphicsData", \
"PostScript", "Graphics"],
Cell[5016881, 121525, 24355, 468, 296, 3039, 200, "GraphicsData", \
"PostScript", "Graphics"],
Cell[5041239, 121995, 24393, 468, 296, 3037, 200, "GraphicsData", \
"PostScript", "Graphics"],
Cell[5065635, 122465, 24338, 468, 296, 3038, 200, "GraphicsData", \
"PostScript", "Graphics"],
Cell[5089976, 122935, 24294, 467, 296, 3039, 200, "GraphicsData", \
"PostScript", "Graphics"],
Cell[5114273, 123404, 24375, 468, 296, 3035, 200, "GraphicsData", \
"PostScript", "Graphics"],
Cell[5138651, 123874, 24387, 468, 296, 3039, 200, "GraphicsData", \
"PostScript", "Graphics"],
Cell[5163041, 124344, 24359, 468, 296, 3039, 200, "GraphicsData", \
"PostScript", "Graphics"],
Cell[5187403, 124814, 24387, 468, 296, 3039, 200, "GraphicsData", \
"PostScript", "Graphics"],
Cell[5211793, 125284, 24359, 468, 296, 3039, 200, "GraphicsData", \
"PostScript", "Graphics"],
Cell[5236155, 125754, 24397, 468, 296, 3037, 200, "GraphicsData", \
"PostScript", "Graphics"],
Cell[5260555, 126224, 24254, 467, 296, 3039, 200, "GraphicsData", \
"PostScript", "Graphics"],
Cell[5284812, 126693, 24416, 469, 296, 3039, 200, "GraphicsData", \
"PostScript", "Graphics"],
Cell[5309231, 127164, 24213, 466, 296, 3039, 200, "GraphicsData", \
"PostScript", "Graphics"],
Cell[5333447, 127632, 24274, 467, 296, 3039, 200, "GraphicsData", \
"PostScript", "Graphics"],
Cell[5357724, 128101, 24193, 466, 296, 3039, 200, "GraphicsData", \
"PostScript", "Graphics"],
Cell[5381920, 128569, 24379, 468, 296, 3039, 200, "GraphicsData", \
"PostScript", "Graphics"],
Cell[5406302, 129039, 24436, 469, 296, 3039, 200, "GraphicsData", \
"PostScript", "Graphics"],
Cell[5430741, 129510, 24395, 468, 296, 3039, 200, "GraphicsData", \
"PostScript", "Graphics"],
Cell[5455139, 129980, 24407, 468, 296, 3039, 200, "GraphicsData", \
"PostScript", "Graphics"],
Cell[5479549, 130450, 24420, 469, 296, 3039, 200, "GraphicsData", \
"PostScript", "Graphics"],
Cell[5503972, 130921, 24391, 468, 296, 3039, 200, "GraphicsData", \
"PostScript", "Graphics"]
}, Closed]]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[5528436, 131397, 42, 0, 49, "Subsection"],

Cell[CellGroupData[{
Cell[5528503, 131401, 36, 0, 43, "Subsubsection"],
Cell[5528542, 131403, 137, 2, 27, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[5528716, 131410, 38, 0, 35, "Subsubsection"],

Cell[CellGroupData[{
Cell[5528779, 131414, 319, 5, 111, "Input"],
Cell[5529101, 131421, 70990, 1451, 296, 10304, 697, "GraphicsData", \
"PostScript", "Graphics"]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{
Cell[5600164, 132880, 98, 3, 39, "Section"],

Cell[CellGroupData[{
Cell[5600287, 132887, 175, 5, 49, "Subsection"],

Cell[CellGroupData[{
Cell[5600487, 132896, 41, 0, 43, "Subsubsection"],

Cell[CellGroupData[{
Cell[5600553, 132900, 273, 4, 79, "Input"],

Cell[CellGroupData[{
Cell[5600851, 132908, 32179, 622, 296, 4118, 270, "GraphicsData", \
"PostScript", "Graphics"],
Cell[5633033, 133532, 31352, 603, 296, 3980, 260, "GraphicsData", \
"PostScript", "Graphics"],
Cell[5664388, 134137, 29862, 574, 296, 3762, 247, "GraphicsData", \
"PostScript", "Graphics"],
Cell[5694253, 134713, 27443, 526, 296, 3404, 224, "GraphicsData", \
"PostScript", "Graphics"],
Cell[5721699, 135241, 24861, 479, 296, 3139, 206, "GraphicsData", \
"PostScript", "Graphics"],
Cell[5746563, 135722, 24385, 469, 296, 3035, 200, "GraphicsData", \
"PostScript", "Graphics"],
Cell[5770951, 136193, 24388, 469, 296, 3038, 200, "GraphicsData", \
"PostScript", "Graphics"]
}, Closed]]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[5795412, 136670, 73, 0, 49, "Subsection"],

Cell[CellGroupData[{
Cell[5795510, 136674, 44, 0, 43, "Subsubsection"],
Cell[5795557, 136676, 161, 2, 43, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[5795755, 136683, 54, 0, 35, "Subsubsection"],

Cell[CellGroupData[{
Cell[5795834, 136687, 385, 7, 127, "Input"],

Cell[CellGroupData[{
Cell[5796244, 136698, 70990, 1451, 296, 10304, 697, "GraphicsData", \
"PostScript", "Graphics"],
Cell[5867237, 138151, 64612, 1366, 296, 10216, 690, "GraphicsData", \
"PostScript", "Graphics"],
Cell[5931852, 139519, 66609, 1595, 296, 14112, 942, "GraphicsData", \
"PostScript", "Graphics"],
Cell[5998464, 141116, 56157, 1320, 296, 11392, 763, "GraphicsData", \
"PostScript", "Graphics"],
Cell[6054624, 142438, 44559, 1136, 296, 10530, 711, "GraphicsData", \
"PostScript", "Graphics"],
Cell[6099186, 143576, 44981, 1156, 296, 10770, 729, "GraphicsData", \
"PostScript", "Graphics"],
Cell[6144170, 144734, 45001, 1156, 296, 10762, 729, "GraphicsData", \
"PostScript", "Graphics"]
}, Closed]]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}, Closed]]
}
]
*)



(*******************************************************************
End of Mathematica Notebook file.
*******************************************************************)

